<-- This file is part 18 of the GNU version of
    The Collaborative International Dictionary of English (GCIDE)

    Copyright (C) 1992-2012 Patrick J. Cassidy
    Copyright (C) 2012-2024 Sergey Poznyakoff

    GCIDE is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 3, or (at your option)
    any later version.

    GCIDE is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this copy of GCIDE.  If not, see <http://www.gnu.org/licenses/>.
-->

<p><centered><point16>R.</point16></centered></p>

<p><ent>R</ent><br/
<hw>R</hw> <pr>(<aum/r)</pr>. <def>R, the eighteenth letter of the
English alphabet, is a vocal consonant. It is sometimes called a
<xex>semivowel</xex>, and a <xex>liquid</xex>. See <xex>Guide to
Pronunciation</xex>, <sect/<sect/ 178, 179, and 250-254.</def>
<ldquo/<xex>R</xex> is the dog's letter and hurreth in the sound.<rdquo/
<rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<note><p>In words derived from the Greek language the letter
<xex>h</xex> is generally written after <xex>r</xex> to represent the
aspirated sound of the Greek <grk>"r</grk>, but does not affect the
pronunciation of the English word, as <xex>rhapsody</xex>,
<xex>rhetoric</xex>.<br/
[<source>1913 Webster</source>]</p>

<p> The English letter derives its form from the Greek through the
Latin, the Greek letter being derived from the Ph<oe/nician, which, it
is believed, is ultimately of Egyptian origin. Etymologically, R is most
closely related to <it>l</it>, <it>s</it>, and <it>n</it>; as in
bando<it>r</it>e, mando<it>l</it>e; purp<it>l</it>e, L.
purpu<it>r</it>a; E. chapte<it>r</it>, F. chapit<it>r</it>e, L.
capitu<it>l</it>um; E. wa<it>s</it>, we<it>r</it>e; ha<it>r</it>e, G.
ha<it>s</it>e; E. orde<it>r</it>, F. ord<it>r</it>e, L. ordo,
ordi<it>n</it>is; E. coffe<it>r</it>, coffi<it>n.</it><br/
[<source>1913 Webster</source>]</p></note>

<p><cs><col><b>The three Rs</b></col>, <cd>a jocose expression for
reading, (w)riting, and (a)rithmetic, -- the fundamentals of an
education.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>R&D</ent><br/
<hw>R&D</hw> <pr>(<aum/r"<acr/n*d<emac/")</pr>, <pos>n.</pos>
<ety>[<ets>r</ets>esearch and <ets>d</ets>evelopment.]</ety>
<def>Research and development; used mostly to refer to the division of a
corporation responsible for performing research and developing new
products, or the activitie performed by that division; -- a commonly
used abbreviation.</def><br/
<syn><b>Syn. --</b> R and D, research and development.</syn>
[<source>PJC</source>]</p>

<p><ent>Ra</ent><br/
<hw>Ra</hw> <pr>(r<aum/)</pr>, <pos>n.</pos> <def>A roe; a deer.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ra-</ent><br/
<hw>Ra-</hw>. <def>A prefix, from the Latin <xex>re</xex> and
<xex>ad</xex> combined, coming to us through the French and Italian. See
<er>Re-</er>, and <er>Ad-</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raash</ent><br/
<hw>Raash</hw> <pr>(r<aum/sh)</pr>, <pos>n.</pos> <ety>[Cf. Ar.
<ets>ra'ash</ets> trembling, tremor.]</ety> <fld>(Zool.)</fld> <def>The
electric catfish.</def> <altsp>[Written also
<asp>raasch</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rab</ent><br/
<hw>Rab</hw> <pr>(r<acr/b)</pr>, <pos>n.</pos> <def>A rod or stick used
by masons in mixing hair with mortar.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rabat</ent><br/
<hw>Rab"at</hw> <pr>(r<acr/b"<acr/t)</pr>, <pos>n.</pos> <ety>[See
<er>Rabot</er>.]</ety> <def>A polishing material made of potter's clay
that has failed in baking.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rabat</ent><br/
\'d8<hw>Ra`bat"</hw> <pr>(r<adot/*b<amac/t")</pr>, <pos>n.</pos>
<ety>[F. Cf. <er>Rabato</er>.]</ety> <fld>(Eccl.)</fld> <sd>(a)</sd>
<def>A clerical linen collar.</def> <sd>(b)</sd> <def>A kind of clerical
scarf fitted to a collar; <as>as, a black silk
<ex>rabat</ex></as>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Rabate</ent><br/
<hw>Ra*bate"</hw> <pr>(r<adot/*b<amac/t")</pr>, <pos>v. t.</pos>
<ety>[F. <ets>rabattre</ets> to beat down; pref. <ets>re-</ets> +
<ets>abattre</ets>. See <er>Abate</er>, and cf. <er>Rebate</er>,
<pos>v.</pos>]</ety> <fld>(Falconry)</fld> <def>To recover to the fist,
as a hawk.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rabatine</ent><br/
<hw>Rab"a*tine</hw> <pr>(r<acr/b"<adot/*t<icr/n)</pr>, <pos>n.</pos>
<ety>[See <er>Rabato</er>.]</ety> <def>A collar or cape.</def>
<mark>[Obs.]</mark> <rj><au>Sir W. Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rabato</ent><br/
<hw>Ra*ba"to</hw> <pr>(r<adot/*b<amac/"t<osl/)</pr>, <pos>n.</pos>
<ety>[F. <ets>rabat</ets>, fr. <ets>rabattre</ets>. See
<er>Rabate</er>.]</ety> <def>A kind of ruff for the neck; a turned-down
collar; a rebato.</def> <mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rabbate</ent><br/
<hw>Rab*bate"</hw> <pr>(r<acr/b*b<amac/t")</pr>, <pos>v. t.</pos>
<ety>[See <er>Rabate</er>.]</ety> <def>To abate or diminish.</def>
<mark>[Obs.]</mark> -- <def2><pos>n.</pos> <def>Abatement.</def>
<mark>[Obs.]</mark></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rabbet</ent><br/
<hw>Rab"bet</hw> <pr>(r<acr/b"b<ecr/t)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Rabbeted</conjf>; <pos>p. pr. &
vb. n.</pos> <conjf>Rabbeting</conjf>.]</vmorph> <ety>[F.
<ets>raboter</ets> to plane, plane down,<ets>rabot</ets> a plane; pref.
<ets>re-</ets> re- + OF. <ets>abouter</ets>, <ets>aboter</ets>. See
<er>Abut</er>, and cf. <er>Rebut</er>.]</ety> <sn>1.</sn> <def>To cut a
rabbet in; to furnish with a rabbet.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To unite the edges of, as boards, etc., in a rabbet
joint.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rabbet</ent><br/
<hw>Rab"bet</hw>, <pos>n.</pos> <ety>[See <er>Rabbet</er>,
<pos>v.</pos>, and cf. <er>Rebate</er>, <pos>n.</pos>]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <fld>(Carp.)</fld> <def>A longitudinal channel, groove,
or recess cut out of the edge or face of any body; especially, one
intended to receive another member, so as to break or cover the joint,
or more easily to hold the members in place; thus, the groove cut for a
panel, for a pane of glass, or for a door, is a <xex>rabbet</xex>, or
rebate.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Same as <xex>Rabbet joint</xex>, below.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Rabbet joint</b></col> <fld>(Carp.)</fld>, <cd>a joint
formed by fitting together rabbeted boards or timbers; -- called also
<altname>rabbet</altname>.</cd> -- <col><b>Rabbet plane</b></col>, <cd>a
joiner's plane for cutting a rabbet.</cd> <au>Moxon.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rabbi</ent><br/
<hw>Rab"bi</hw> <pr>(r<acr/r"b<imac/ <it>or</it> r<acr/r"b<icr/;
277)</pr>, <pos>n.</pos>; <plu><it>pl.</it> <plw>Rabbis</plw>
<pr>(r<acr/r"b<imac/z <it>or</it> r<acr/r"b<icr/z)</pr> or
<plw>Rabbies</plw>.</plu> <ety>[L., fr. Gr. <grk>"rabbi`</grk>, Heb.
<ets>rab<imac/</ets> my master, from <ets>rab</ets> master, lord,
teacher, akin to Ar. <ets>rabb</ets>.]</ety> <def>Master; lord; teacher;
-- a Jewish title of respect or honor for a teacher or doctor of the
law.</def> <ldquo/The gravest <xex>rabbies</xex>.<rdquo/
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Be not ye called <qex>Rabbi</qex>, for one is your Master, even
Christ, and all ye are brethren.</q> <rj><qau>Matt. xxiii.
8.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rabbin</ent><br/
<hw>Rab"bin</hw> <pr>(r<acr/b"b<icr/n)</pr>, <pos>n.</pos>
<ety>[F.]</ety> <def>Same as <er>Rabbi</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rabbinical</ent><br/
<ent>Rabbinic</ent><br/
<mhw>{ <hw>Rab*bin"ic</hw> <pr>(r<acr/b*b<icr/n"<icr/k)</pr>,
<hw>Rab*bin"ic*al</hw> <pr>(r<acr/b*b<icr/n"<icr/*k<ait/l)</pr>, }</mhw>
<pos>a.</pos> <ety>[Cf. F. <ets>rabbinique</ets>.]</ety> <def>Of or
pertaining to the rabbins or rabbis, or pertaining to the opinions,
learning, or language of the rabbins.</def> <ldquo/Comments staler than
<xex>rabbinic</xex>.<rdquo/ <rj><au>Lowell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>We will not buy your <qex>rabbinical</qex> fumes.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rabbinic</ent><br/
<hw>Rab*bin"ic</hw> <pr>(r<acr/b*b<icr/n"<icr/k)</pr>, <pos>n.</pos>
<def>The language or dialect of the rabbins; the later Hebrew.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rabbinically</ent><br/
<hw>Rab*bin"ic*al*ly</hw>, <pos>adv.</pos> <def>In a rabbinical manner;
after the manner of the rabbins.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rabbinism</ent><br/
<hw>Rab"bin*ism</hw> <pr>(r<acr/b"b<icr/n*<icr/z'm)</pr>, <pos>n.</pos>
<ety>[Cf. F. <ets>rabbinisme</ets>.]</ety> <sn>1.</sn> <def>A rabbinic
expression or phraseology; a peculiarity of the language of the
rabbins.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The teachings and traditions of the
rabbins.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rabbinist</ent><br/
<hw>Rab"bin*ist</hw> <pr>(r<acr/b"b<icr/n*<icr/st)</pr>, <pos>n.</pos>
<ety>[Cf. F. <ets>rabbiniste</ets>.]</ety> <def>One among the Jews who
adhered to the Talmud and the traditions of the rabbins, in opposition
to the <xex>Karaites</xex>, who rejected the traditions.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rabbinite</ent><br/
<hw>Rab"bin*ite</hw> <pr>(r<acr/b"b<icr/n*<imac/t)</pr>, <pos>n.</pos>
<def>Same as <er>Rabbinist</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rabbit</ent><br/
<hw>Rab"bit</hw> <pr>(r<acr/b"b<icr/t)</pr>, <pos>n.</pos> <ety>[OE.
<ets>rabet</ets>, akin to OD. <ets>robbe</ets>,
<ets>robbeken</ets>.]</ety> <fld>(Zool.)</fld> <def>Any of the smaller
species of the genus Lepus, especially the common European species
(<spn>Lepus cuniculus</spn>), which is often kept as a pet, and has been
introduced into many countries. It is remarkably prolific, and has
become a pest in some parts of Australia and New Zealand.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The common American rabbit (<spn>Lepus sylvatica</spn>)
is similar but smaller. See <er>Cottontail</er>, and <cref>Jack
rabbit</cref>, under 2d <er>Jack</er>. The larger species of Lepus are
commonly called <xex>hares</xex>. See <er>Hare</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Angora rabbit</b></col> <fld>(Zool.)</fld>, <cd>a variety
of the domestic rabbit having long, soft fur.</cd> -- <col><b>Rabbit
burrow</b></col>, <cd>a hole in the earth made by rabbits for shelter
and habitation.</cd> -- <col><b>Rabbit fish</b></col>.
<fld>(Zool.)</fld> <sd>(a)</sd> <cd>The northern chimaera (<spn>Chimaera
monstrosa</spn>)</cd>. <sd>(b)</sd> <cd>Any one of several species of
plectognath fishes, as the bur fish, and puffer. The term is also
locally applied to other fishes.</cd> -- <col><b>Rabbits'
ears</b></col>. <fld>(Bot.)</fld> <cd>See <er>Cyclamen</er>.</cd><-- a
type of antenna with two long narrow metal prongs, usually arranged so
as to remeniscent of erect rabbit's ears. --> -- <col><b>Rabbit
warren</b></col>, <cd>a piece of ground appropriated to the breeding and
preservation of rabbits.</cd> <au>Wright.</au> -- <col><b>Rock
rabbit</b></col>. <sd>(a)</sd> <fld>(Zool.)</fld> <cd>See
<er>Daman</er>, and <er>Klipdas</er>.</cd> <sd>(b)</sd> <cd>the
<er>pika</er>.</cd> -- <col><b>Welsh rabbit</b></col>, <cd>a dish of
which the chief constituents are melted cheese over toasted bread,
flavored in various ways, as with ale, beer, milk, or spices. The name
is popularly said to be a corruption of <altname>Welsh rare
bit</altname>, but it is probably merely a humorous designation; -- also
called <altname>Welsh rarebit</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>rabbit</ent><br/
<hw>rabbit</hw> <pos>v. i.</pos> <def>To hunt rabbits.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Rabbiting</ent><br/
<hw>Rab"bit*ing</hw>, <pos>n.</pos> <def>The hunting of rabbits.</def>
<rj><au>T. Hughes.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rabbitry</ent><br/
<hw>Rab"bit*ry</hw> <pr>(r<acr/b"b<icr/t*r<ycr/)</pr>, <pos>n.</pos>
<def>A place where rabbits are kept; especially, a collection of hutches
for tame rabbits.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rabble</ent><br/
<hw>Rab"ble</hw> <pr>(r<acr/b"b'l)</pr>, <pos>n.</pos> <ety>[Etymol.
uncertain.]</ety> <fld>(Iron Manuf.)</fld> <def>An iron bar, with the
end bent, used in stirring or skimming molten iron in the process of
puddling.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rabble</ent><br/
<hw>Rab"ble</hw>, <pos>v. t.</pos> <def>To stir or skim with a rabble,
as molten iron.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rabble</ent><br/
<hw>Rab"ble</hw>, <pos>v. i.</pos> <ety>[Akin to D. <ets>rabbelen</ets>,
Prov. G. <ets>rabbeln</ets>, to prattle, to chatter: cf. L.
<ets>rabula</ets> a brawling advocate, a pettifogger, fr.
<ets>rabere</ets> to rave. Cf. <er>Rage</er>.]</ety> <def>To speak in a
confused manner.</def> <mark>[Prov. Eng. & Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rabble</ent><br/
<hw>Rab"ble</hw>, <pos>n.</pos> <ety>[Probably named from the noise made
by it (see <er>Rabble</er>, <pos>v. i.</pos>) cf. D. <ets>rapalje</ets>
rabble, OF. & Prov. F. <ets>rapaille</ets>.]</ety> <sn>1.</sn> <def>A
tumultuous crowd of vulgar, noisy people; a mob; a confused, disorderly
throng.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I saw, I say, come out of London, even unto the presence of the
prince, a great <qex>rabble</qex> of mean and light persons.</q>
<rj><qau>Ascham.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Jupiter, Mercury, Bacchus, Venus, Mars, and the whole
<qex>rabble</qex> of licentious deities.</q> <rj><qau>Bp.
Warburton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A confused, incoherent discourse; a medley of
voices; a chatter.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>The rabble</b></col>, <cd>the lowest class of people,
without reference to an assembly; the dregs of the people.</cd>
<ldquo/<xex>The rabble</xex> call him <lsquo/lord.'<rdquo/
<rj><au>Shak.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rabble</ent><br/
<hw>Rab"ble</hw>, <pos>a.</pos> <def>Of or pertaining to a rabble; like,
or suited to, a rabble; disorderly; vulgar.</def> <mark>[R.]</mark>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rabble</ent><br/
<hw>Rab"ble</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Rabbled</conjf> <pr>(r<acr/b"b'ld)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Rabbling</conjf> <pr>(r<acr/b"bl<icr/ng)</pr>.]</vmorph>
<sn>1.</sn> <def>To insult, or assault, by a mob; to mob; <as>as, to
<ex>rabble</ex> a curate</as>.</def> <rj><au>Macaulay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The bishops' carriages were stopped and the prelates themselves
<qex>rabbled</qex> on their way to the house.</q> <rj><qau>J. R.
Green.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To utter glibly and incoherently; to mouth without
intelligence.</def> <mark>[Obs. or Scot.]</mark>
<rj><au>Foxe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To rumple; to crumple.</def>
<mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rabblement</ent><br/
<hw>Rab"ble*ment</hw> <pr>(r<acr/b"b'l*m<eit/nt)</pr>, <pos>n.</pos>
<def>A tumultuous crowd of low people; a rabble.</def> <ldquo/Rude
<xex>rablement</xex>.<rdquo/ <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And still, as he refused it, the <qex>rabblement</qex> hooted.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rabbler</ent><br/
<hw>Rab"bler</hw> <pr>(r<acr/b"bl<etil/r)</pr>, <pos>n.</pos> <ety>[See
2d <er>Rabble</er>.]</ety> <fld>(Mech.)</fld> <def>A scraping tool for
smoothing metal.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rabble-rout</ent><br/
<hw>Rab"ble-rout`</hw> <pr>(r<acr/b"b'l-rout`)</pr>, <pos>n.</pos>
<def>A tumultuous crowd; a rabble; a noisy throng.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rabdoidal</ent><br/
<hw>Rab*doid"al</hw> <pr>(r<acr/b*doid"<ait/l)</pr>, <pos>a.</pos>
<ety>[Gr. <grk>"ra`bdos</grk> a rod + <ets>-oid</ets> +
<ets>-al</ets>.]</ety> <fld>(Anat.)</fld> <def>See
<er>Sagittal</er>.</def> <altsp>[Written also
<asp>rhabdoidal</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rabdology</ent><br/
<hw>Rab*dol"o*gy</hw> <pr>(r<acr/b*d<ocr/l"<osl/*j<ycr/)</pr>,
<pos>n.</pos> <ety>[Gr. <grk>"ra`bdos</grk> rod, stick +
<ets>-logy</ets>: cf. F. <ets>rabdologie</ets>.]</ety> <def>The method
or art of performing arithmetical operations by means of Napier's bones.
See <er>Napier's bones</er>.</def> <altsp>[Written also
<asp>rhabdology</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rabdomancy</ent><br/
<hw>Rab"do*man`cy</hw> <pr>(r<acr/b"d<osl/*m<acr/n`s<ycr/)</pr>,
<pos>n.</pos> <ety>[Gr. <grk>"ra`bdos</grk> rod +
<ets>-mancy</ets>.]</ety> <def>Divination by means of rods or
wands.</def> <altsp>[Written also <asp>rhabdomancy</asp>.]</altsp>
<rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rabid</ent><br/
<hw>Rab"id</hw> <pr>(r<acr/b"<icr/d)</pr>, <pos>a.</pos> <ety>[L.
<ets>rabidus</ets>, from <ets>rabere</ets> to rave. See <er>Rage</er>,
<pos>n.</pos>]</ety> <sn>1.</sn> <def>Furious; raging; extremely
violent.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>rabid</qex> flight<br/
Of winds that ruin ships.</q> <rj><qau>Chapman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Extreme, unreasonable, or fanatical in opinion;
excessively zealous; <as>as, a <ex>rabid</ex> socialist</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Affected with the distemper called
<xex>rabies</xex>; mad; <as>as, a <ex>rabid</ex> dog or
fox</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Med.)</fld> <def>Of or pertaining to rabies, or
hydrophobia; <as>as, <ex>rabid</ex> virus</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rabidity</ent><br/
<hw>Ra*bid"i*ty</hw> <pr>(r<adot/*b<icr/d"<icr/*t<ycr/)</pr>,
<pos>n.</pos> <def>Rabidness; furiousness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rabidly</ent><br/
<hw>Rab"id*ly</hw> <pr>(r<acr/b"<icr/d*l<ycr/)</pr>, <pos>adv.</pos>
<def>In a rabid manner; with extreme violence.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rabidness</ent><br/
<hw>Rab"id*ness</hw>, <pos>n.</pos> <def>The quality or state of being
rabid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rabies</ent><br/
\'d8<hw>Ra"bi*es</hw> <pr>(r<amac/"b<icr/*<emac/z)</pr>, <pos>n.</pos>
<ety>[L. See <er>Rage</er>, <pos>n.</pos>]</ety> <def>Same as
<er>Hydrophobia</er> <sd>(b)</sd>; canine madness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rabinet</ent><br/
<hw>Rab"i*net</hw> <pr>(r<acr/b"<icr/*n<ecr/t)</pr>, <pos>n.</pos>
<ety>[Etymol. uncertain.]</ety> <fld>(Mil.)</fld> <def>A kind of small
ordnance formerly in use.</def> <altsp>[Written also
<asp>rabanet</asp>.]</altsp> <rj><au>Ainsworth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rabious</ent><br/
<hw>Ra"bi*ous</hw> <pr>(r<amac/"b<icr/*<ucr/s)</pr>, <pos>a.</pos>
<def>Fierce.</def> <mark>[Obs.]</mark> <rj><au>Daniel.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rabot</ent><br/
<hw>Ra"bot</hw> <pr>(r<amac/"b<ocr/t)</pr>, <pos>n.</pos>
<ety>[F.]</ety> <def>A rubber of hard wood used in smoothing marble to
be polished.</def> <rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raca</ent><br/
\'d8<hw>Ra"ca</hw> <pr>(r<amac/"k<adot/)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>"raka`</grk>, from Chaldee <ets>r<emac/k<amac/</ets>.]</ety> <def>A
term of reproach used by the Jews of our Savior's time, meaning
<ldquo/worthless.<rdquo/</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Whosoever shall say to his brother, <qex>Raca</qex>, shall be in
danger of the council.</q> <rj><qau>Matt. v. 22.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Racahout</ent><br/
\'d8<hw>Ra`ca`hout"</hw> <pr>(r<adot/`k<adot/`<oomac/")</pr>,
<pos>n.</pos> <ety>[F. <ets>racahout</ets>, probably fr. Ar.
<ets>r<amac/qaut</ets>.]</ety> <def>A preparation from acorns used by
the Arabs as a substitute for chocolate, and also as a beverage for
invalids.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raccoon</ent><br/
<hw>Rac*coon"</hw> <pr>(r<acr/k*k<oomac/n")</pr>, <pos>n.</pos> <ety>[F.
<ets>raton</ets>, prop., a little rat, fr. <ets>rat</ets> rat, perhaps
of German origin. See <er>Rat</er>.]</ety> <fld>(Zool.)</fld> <def>A
North American nocturnal carnivore (<spn>Procyon lotor</spn>) allied to
the bears, but much smaller, and having a long, full tail, banded with
black and gray. Its body is gray, varied with black and white. Called
also <altname>coon</altname>, and <altname>mapach</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Raccoon dog</b></col> <fld>(Zool.)</fld>, <cd>the
tanate.</cd> -- <col><b>Raccoon fox</b></col> <fld>(Zool.)</fld>,
<cd>the cacomixle.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Race</ent><br/
<hw>Race</hw> <pr>(r<amac/s)</pr>, <pos>v. t.</pos> <def>To raze.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1182 pr=vmg --></p>

<p><ent>Race</ent><br/
<hw>Race</hw> <pr>(r<amac/s)</pr>, <pos>n.</pos> <ety>[OF.
<ets>ra<ium/z</ets>, L. <ets>radix</ets>, <ets>-icis</ets>. See
<er>Radix</er>.]</ety> <def>A root.</def> <ldquo/A <xex>race</xex> or
two of ginger.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Race ginger</b></col>, <cd>ginger in the root, or not
pulverized.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Race</ent><br/
<hw>Race</hw>, <pos>n.</pos> <ety>[F. <ets>race</ets>; cf. Pr. & Sp.
<ets>raza</ets>, It. <ets>razza</ets>; all from OHG. <ets>reiza</ets>
line, akin to E. <ets>write</ets>. See <er>Write</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>The descendants of a common ancestor; a family,
tribe, people, or nation, believed or presumed to belong to the same
stock; a lineage; a breed.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The whole <qex>race</qex> of mankind.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Whence the long <qex>race</qex> of Alban fathers come.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Naturalists and ethnographers divide mankind into
several distinct varieties, or races. Cuvier refers them all to three,
Pritchard enumerates seven, Agassiz eight, Pickering describes eleven.
One of the common classifications is that of Blumenbach, who makes five
races: the <xex>Caucasian</xex>, or white race, to which belong the
greater part of the European nations and those of Western Asia; the
<xex>Mongolian</xex>, or yellow race, occupying Tartary, China, Japan,
etc.; the <xex>Ethiopian</xex>, or negro race, occupying most of Africa
(except the north), Australia, Papua, and other Pacific Islands; the
<xex>American</xex>, or red race, comprising the Indians of North and
South America; and the <xex>Malayan</xex>, or brown race, which occupies
the islands of the Indian Archipelago, etc. Many recent writers classify
the Malay and American races as branches of the Mongolian. See
<xex>Illustration</xex> in Appendix.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Company; herd; breed.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>For do but note a wild and wanton herd,<br/
Or <qex>race</qex> of youthful and unhandled colts,<br/
Fetching mad bounds.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Bot.)</fld> <def>A variety of such fixed character
that it may be propagated by seed.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Peculiar flavor, taste, or strength, as of wine;
that quality, or assemblage of qualities, which indicates origin or
kind, as in wine; hence, characteristic flavor; smack.</def> <ldquo/A
<xex>race</xex> of heaven.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Is it [the wine] of the right <qex>race</qex> ?</q>
<rj><qau>Massinger.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Hence, characteristic quality or disposition.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>And now I give my sensual <qex>race</qex> the rein.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Some . . . great <qex>race</qex> of fancy or judgment.</q>
<rj><qau>Sir W. Temple.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Lineage; line; family; house; breed; offspring;
progeny; issue.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Race</ent><br/
<hw>Race</hw>, <pos>n.</pos> <ety>[OE. <ets>ras</ets>, <ets>res</ets>,
<ets>rees</ets>, AS. <ets>r<aemac/s</ets> a rush, running; akin to Icel.
<ets>r<amac/s</ets> course, race. <root/118.]</ety> <sn>1.</sn> <def>A
progress; a course; a movement or progression.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Esp., swift progress; rapid course; a
running.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The flight of many birds is swifter than the <qex>race</qex> of
any beasts.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Hence: The act or process of running in competition;
a contest of speed in any way, as in running, riding, driving, skating,
rowing, sailing; in the plural, usually, a meeting for contests in the
running of horses; <as>as, he attended the
<ex>races</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>race</qex> is not to the swift.</q> <rj><qau>Eccl. ix.
11.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I wield the gauntlet, and I run the <qex>race</qex>.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Competitive action of any kind, especially when
prolonged; hence, career; course of life.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>My <qex>race</qex> of glory run, and <qex>race</qex> of shame.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A strong or rapid current of water, or the channel
or passage for such a current; a powerful current or heavy sea,
sometimes produced by the meeting of two tides; <as>as, the Portland
<ex>Race</ex>; the <ex>Race</ex> of Alderney.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>The current of water that turns a water wheel, or
the channel in which it flows; a mill race.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The part of the channel above the wheel is sometimes
called the <xex>headrace</xex>, the part below, the
<xex>tailrace</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Mach.)</fld> <def>A channel or guide along which a
shuttle is driven back and forth, as in a loom, sewing machine,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Race cloth</b></col>, <cd>a cloth worn by horses in
racing, having pockets to hold the weights prescribed.</cd> --
<col><b>Race course</b></col>. <sd>(a)</sd> <cd>The path, generally
circular or elliptical, over which a race is run</cd>. <sd>(b)</sd>
<cd>Same as <cref>Race way</cref>, below.</cd> -- <col><b>Race
cup</b></col>, <cd>a cup given as a prize to the victor in a race.</cd>
-- <col><b>Race glass</b></col>, <cd>a kind of field glass.</cd> --
<col><b>Race horse</b></col>. <sd>(a)</sd> <cd>A horse that runs in
competition; specifically, a horse bred or kept for running races</cd>.
<sd>(b)</sd> <cd>A breed of horses remarkable for swiftness in
running</cd>. <sd>(c)</sd> <fld>(Zool.)</fld> <cd>The steamer duck</cd>.
<sd>(d)</sd> <fld>(Zool.)</fld> <cd>A mantis.</cd> -- <col><b>Race
knife</b></col>, <cd>a cutting tool with a blade that is hooked at the
point, for marking outlines, on boards or metals, as by a pattern, --
used in shipbuilding.</cd> -- <col><b>Race saddle</b></col>, <cd>a light
saddle used in racing.</cd> -- <col><b>Race track</b></col>. <cd>Same as
<cref>Race course</cref> <sd>(a)</sd>, above.</cd> -- <col><b>Race
way</b></col>, <cd>the canal for the current that drives a water
wheel.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Race</ent><br/
<hw>Race</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Raced</conjf> <pr>(r<amac/st)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Racing</conjf> <pr>(r<amac/"s<icr/ng)</pr>.]</vmorph> <sn>1.</sn>
<def>To run swiftly; to contend in a race; <as>as, the animals
<ex>raced</ex> over the ground; the ships <ex>raced</ex> from port to
port.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Steam Mach.)</fld> <def>To run too fast at times,
as a marine engine or screw, when the screw is lifted out of water by
the action of a heavy sea.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Race</ent><br/
<hw>Race</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To cause to contend in
a race; to drive at high speed; <as>as, to <ex>race</ex>
horses</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To run a race with.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raceabout</ent><br/
<hw>Race"a*bout`</hw> <pr>(r<amac/s"<adot/*bout`)</pr>, <pos>n.</pos>
<fld>(Naut.)</fld> <def>A small sloop-rigged racing yacht carrying about
six hundred square feet of sail, distinguished from a knockabout by
having a short bowsprit.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Racemate</ent><br/
<hw>Ra*ce"mate</hw> <pr>(r<adot/*s<emac/"m<asl/t)</pr>, <pos>n.</pos>
<fld>(Chem.)</fld> <def>A salt of racemic acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Racemation</ent><br/
<hw>Rac`e*ma"tion</hw> <pr>(r<acr/s`<esl/*m<amac/"sh<ucr/n)</pr>,
<pos>n.</pos> <ety>[L. <ets>racematio</ets> a gleaning, fr.
<ets>racemari</ets> to glean, <ets>racemus</ets> a cluster of grapes.
See <er>Raceme</er>.]</ety> <sn>1.</sn> <def>A cluster or bunch, as of
grapes.</def> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Cultivation or gathering of clusters of
grapes.</def> <mark>[R.]</mark> <rj><au>Bp. Burnet.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raceme</ent><br/
<hw>Ra*ceme"</hw> <pr>(r<adot/*s<emac/m"; 277)</pr>, <pos>n.</pos>
<ety>[L. <ets>racemus</ets> a bunch of berries, a cluster of grapes. See
<er>Raisin</er>.]</ety> <fld>(Bot.)</fld> <def>A flower cluster with an
elongated axis and many one-flowered lateral pedicels, as in the currant
and chokecherry.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Compound raceme</b></col>, <cd>one having the lower
pedicels developed into secondary racemes.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Racemed</ent><br/
<hw>Ra*cemed"</hw> <pr>(r<adot/*s<emac/md")</pr>, <pos>a.</pos>
<fld>(Bot.)</fld> <def>Arranged in a raceme, or in racemes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Racemic</ent><br/
<hw>Ra*ce"mic</hw> <pr>(r<adot/*s<emac/"m<icr/k)</pr>, <pos>a.</pos>
<ety>[Cf. F. <ets>rac<eacute/mique</ets>. See <er>Raceme</er>.]</ety>
<fld>(Chem.)</fld> <def>Pertaining to, or designating, an acid found in
many kinds of grapes. It is also obtained from tartaric acid, with which
it is isomeric, and from sugar, gum, etc., by oxidation. It is a sour
white crystalline substance, consisting of a combination of
dextrorotatory and levorotatory tartaric acids.</def>
<rj><au>Gregory.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Racemiferous</ent><br/
<hw>Rac`e*mif"er*ous</hw>
<pr>(r<acr/s`<esl/*m<icr/f"<etil/r*<ucr/s)</pr>, <pos>a.</pos> <ety>[L.
<ets>racemifer</ets> bearing clusters; <ets>racemus</ets> cluster +
<ets>ferre</ets> to bear: cf. F.
<ets>rac<eacute/mif<egrave/re</ets>.]</ety> <fld>(Bot.)</fld>
<def>Bearing racemes, as the currant.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Racemiform</ent><br/
<hw>Ra*cem"i*form</hw> <pr>(r<adot/*s<ecr/m"<icr/*f<ocir/rm)</pr>,
<pos>a.</pos> <def>Having the form of a raceme.</def>
<rj><au>Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Racemose</ent><br/
<hw>Rac"e*mose`</hw> <pr>(r<acr/s"<esl/*m<omac/s`)</pr>, <pos>a.</pos>
<ety>[L. <ets>racemosus</ets> full of clusters.]</ety> <def>Resembling a
raceme; growing in the form of a raceme; <as>as, <fld>(Bot.)</fld>
<ex>racemose</ex> berries or flowers; <fld>(Anat.)</fld> the
<ex>racemose</ex> glands, in which the ducts are branched and clustered
like a raceme</as>.</def> <rj><au>Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Racemous</ent><br/
<hw>Rac"e*mous</hw> <pr>(r<acr/s"<esl/*m<ucr/s <or/
r<adot/*s<emac/"m<ucr/s; 277)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>rac<eacute/meux</ets>.]</ety> <def>See <er>Racemose</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Racemule</ent><br/
<hw>Rac"e*mule</hw> <pr>(r<acr/s"<esl/*m<umac/l)</pr>, <pos>n.</pos>
<fld>(Bot.)</fld> <def>A little raceme.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Racemulose</ent><br/
<hw>Ra*cem"u*lose`</hw> <pr>(r<adot/*s<ecr/m"<usl/*l<omac/s`)</pr>,
<pos>a.</pos> <fld>(Bot.)</fld> <def>Growing in very small
racemes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Racer</ent><br/
<hw>Ra"cer</hw> <pr>(r<amac/"s<etil/r)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>One who, or that which, races, or contends in a race; esp., a race
horse.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And bade the nimblest <qex>racer</qex> seize the prize.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>The common American black
snake.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Mil.)</fld> <def>One of the circular iron or steel
rails on which the chassis of a heavy gun is turned.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Race suicide</ent><br/
<hw>Race suicide</hw>. <def>The voluntary failure of the members of a
race or people to have a number of children sufficient to keep the birth
rate equal to the death rate.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Rache</ent><br/
<ent>Rach</ent><br/
<mhw>{ <hw>Rach</hw>, <hw>Rache</hw> <pr>(r<acr/ch)</pr> }</mhw>,
<pos>n.</pos> <ety>[AS. <ets>r<ae/cc</ets>; akin to Icel.
<ets>rakki</ets>.]</ety> <fld>(Zool.)</fld> <def>A dog that pursued his
prey by scent, as distinguished from the greyhound.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rachialgia</ent><br/
\'d8<hw>Ra`chi*al"gi*a</hw>
<pr>(r<amac/`k<icr/*<acr/l"j<icr/*<adot/)</pr>, <pos>n.</pos> <ety>[NL.,
fr. Gr. <grk>"ra`chis</grk> backbone + <grk>'a`lgos</grk> pain.]</ety>
<fld>(Med.)</fld> <def>A painful affection of the spine; especially,
<stype>Pott's disease</stype>; also, formerly, lead colic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rachidian</ent><br/
<hw>Ra*chid"i*an</hw> <pr>(r<adot/*k<icr/d"<icr/*<ait/n)</pr>,
<pos>a.</pos> <ety>[See <er>Rachis</er>.]</ety> <fld>(Anat. &
Zool.)</fld> <def>Of or pertaining to the rachis; spinal; vertebral.
Same as <er>Rhachidian</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rachilla</ent><br/
\'d8<hw>Ra*chil"la</hw> <pr>(r<adot/*k<icr/l"l<adot/)</pr>,
<pos>n.</pos> <ety>[NL.]</ety> <fld>(Bot.)</fld> <def>Same as
<er>Rhachilla</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rachiodont</ent><br/
<hw>Ra"chi*o*dont</hw> <pr>(r<amac/"k<icr/*<osl/*d<ocr/nt)</pr>,
<pos>a.</pos> <fld>(Zool.)</fld> <def>Same as
<er>Rhachiodont</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rachis</ent><br/
\'d8<hw>Ra"chis</hw> <pr>(r<amac/"k<icr/s)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> E. <plw>Rachises</plw>
<pr>(r<amac/"k<icr/s*<ecr/z)</pr>, L. <plw>Rachides</plw>
<pr>(r<acr/k"<icr/*d<emac/z)</pr>.</plu> <ety>[NL., fr. Gr.
<grk>"ra`chis</grk>, <grk>-ios</grk>.]</ety> <altsp>[Written also
<asp>rhachis</asp>.]</altsp> <sn>1.</sn> <fld>(Anat.)</fld> <def>The
spine; the vertebral column.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot. & Zool.)</fld> <def>Same as
<er>Rhachis</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rachitic</ent><br/
<hw>Ra*chit"ic</hw> <pr>(r<adot/*k<icr/t"<icr/k)</pr>, <pos>a.</pos>
<ety>[Cf. F. <ets>rachitique</ets>. See <er>Rachitis</er>.]</ety>
<fld>(Med.)</fld> <def>Of or pertaining to rachitis; affected by
rachitis; rickety.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rachitis</ent><br/
\'d8<hw>Ra*chi"tis</hw> <pr>(r<adot/*k<imac/"t<icr/s)</pr>,
<pos>n.</pos> <ety>[NL., fr. Gr. <grk>"rachi^tis</grk> (sc.
<grk>nosos</grk>), fr. <grk>"ra`chis</grk>, <grk>-ios</grk>, the
spine.]</ety> <altsp>[Written also <asp>rhachitis</asp>.]</altsp>
<sn>1.</sn> <fld>(Med.)</fld> <def>Literally, inflammation of the spine,
but commonly applied to the rickets. See <er>Rickets</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>A disease which produces abortion
in the fruit or seeds.</def> <rj><au>Henslow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rachitome</ent><br/
<hw>Ra"chi*tome</hw> <pr>(r<amac/"k<icr/*t<omac/m)</pr>, <pos>n.</pos>
<ety>[F., fr. Gr. <grk>"ra`chis</grk>, <grk>-ios</grk>, the spine +
<grk>te`mnein</grk> to cut.]</ety> <def>A dissecting instrument for
opening the spinal canal.</def> <altsp>[Written also
<asp>rachiotome</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Racial</ent><br/
<hw>Ra"cial</hw> <pr>(r<amac/"sh<ait/l)</pr>, <pos>a.</pos> <def>Of or
pertaining to a race or family of men; <as>as, the <ex>racial</ex>
complexion</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Racily</ent><br/
<hw>Ra"ci*ly</hw> <pr>(r<amac/"s<icr/*l<ycr/)</pr>, <pos>adv.</pos>
<def>In a racy manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raciness</ent><br/
<hw>Ra"ci*ness</hw> <pr>(r<amac/"s<icr/*n<ecr/s)</pr>, <pos>n.</pos>
<def>The quality of being racy; peculiar and piquant flavor.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The general characteristics of his [Cobbett's] style were
perspicuity, unequaled and inimitable; . . . a purity always simple, and
<qex>raciness</qex> often elegant.</q> <rj><qau>London
Times.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Racing</ent><br/
<hw>Ra"cing</hw> <pr>(r<amac/"s<icr/ng)</pr>, <def><pos>a. & n.</pos>
from <er>Race</er>, <pos>v. t. & i.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Racing crab</b></col> <fld>(Zool.)</fld>, <cd>an
ocypodian.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rack</ent><br/
<hw>Rack</hw> <pr>(r<acr/k)</pr>, <pos>n.</pos> <def>Same as
<er>Arrack</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rack</ent><br/
<hw>Rack</hw>, <pos>n.</pos> <ety>[AS. <ets>hracca</ets> neck, hinder
part of the head; cf. AS. <ets>hraca</ets> throat, G. <ets>rachen</ets>
throat, E. <ets>retch</ets>.]</ety> <def>The neck and spine of a fore
quarter of veal or mutton.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rack</ent><br/
<hw>Rack</hw>, <pos>n.</pos> <ety>[See <er>Wreck</er>.]</ety> <def>A
wreck; destruction.</def> <mark>[Obs., except in a few
phrases.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Rack and ruin</b></col>, <cd>destruction; utter
ruin.</cd> <mark>[Colloq.]</mark> -- <col><b>To go to rack</b></col>,
<cd>to perish; to be destroyed.</cd> <mark>[Colloq.]</mark> <ldquo/All
<xex>goes to rack</xex>.<rdquo/ <au>Pepys.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rack</ent><br/
<hw>Rack</hw>, <pos>n.</pos> <ety>[Prob. fr. Icel. <ets>rek</ets> drift,
motion, and akin to <ets>reka</ets> to drive, and E. <ets>wrack</ets>,
<ets>wreck</ets>. <root/282.]</ety> <def>Thin, flying, broken clouds, or
any portion of floating vapor in the sky.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The winds in the upper region, which move the clouds above, which
we call the <qex>rack</qex>, . . . pass without noise.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And the night <qex>rack</qex> came rolling up.</q> <rj><qau>C.
Kingsley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rack</ent><br/
<hw>Rack</hw>, <pos>v. i.</pos> <def>To fly, as vapor or broken
clouds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rack</ent><br/
<hw>Rack</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Racked</conjf> <pr>(r<acr/kt)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Racking</conjf>.]</vmorph> <ety>[See <er>Rack</er> that which
stretches, or <er>Rock</er>, <pos>v.</pos>]</ety> <def>To amble fast,
causing a rocking or swaying motion of the body; to pace; -- said of a
horse.</def> <rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rack</ent><br/
<hw>Rack</hw>, <pos>n.</pos> <def>A fast amble.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rack</ent><br/
<hw>Rack</hw>, <pos>v. t.</pos> <ety>[Cf. OF. <ets>vin
raqu<eacute/</ets> wine squeezed from the dregs of the grapes.]</ety>
<def>To draw off from the lees or sediment, as wine.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It is in common practice to draw wine or beer from the lees (which
we call <qex>racking</qex>), whereby it will clarify much the
sooner.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Rack vintage</b></col>, <cd>wine cleansed and drawn from
the lees.</cd> <au>Cowell.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rack</ent><br/
<hw>Rack</hw>, <pos>n.</pos> <ety>[Probably fr. D. <ets>rek</ets>,
<ets>rek</ets>bank, a rack, <ets>rekken</ets> to stretch; akin to G.
<ets>reck</ets>, <ets>reck</ets>bank, a rack, <ets>recken</ets> to
stretch, Dan. <ets>r<ae/kke</ets>, Sw. <ets>r<aum/cka</ets>, Icel.
<ets>rekja</ets> to spread out, Goth. <ets>refrakjan</ets> to stretch
out; cf. L. <ets>porrigere</ets>, Gr. <grk>'ore`gein</grk>. <root/115.
Cf. <er>Right</er>, <pos>a.</pos>, <er>Ratch</er>.]</ety> <sn>1.</sn>
<def>An instrument or frame used for stretching, extending, retaining,
or displaying, something.</def> Specifically: <sd>(a)</sd> <def>An
engine of torture, consisting of a large frame, upon which the body was
gradually stretched until, sometimes, the joints were dislocated; --
formerly used judicially for extorting confessions from criminals or
suspected persons.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>During the troubles of the fifteenth century, a <qex>rack</qex>
was introduced into the Tower, and was occasionally used under the plea
of political necessity.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(b)</sd> <def>An instrument for bending a bow.</def> <sd>(c)</sd>
<def>A grate on which bacon is laid.</def> <sd>(d)</sd> <def>A frame or
device of various construction for holding, and preventing the waste of,
hay, grain, etc., supplied to beasts.</def> <sd>(e)</sd> <def>A frame on
which articles are deposited for keeping or arranged for display; as, a
clothes <xex>rack</xex>; a bottle <xex>rack</xex>, etc.</def>
<sd>(f)</sd> <fld>(Naut.)</fld> <def>A piece or frame of wood, having
several sheaves, through which the running rigging passes; -- called
also <altname>rack block</altname>. Also, a frame to hold shot.</def>
<sd>(g)</sd> <fld>(Mining)</fld> <def>A frame or table on which ores are
separated or washed.</def> <sd>(h)</sd> <def>A frame fitted to a wagon
for carrying hay, straw, or grain on the stalk, or other bulky
loads.</def> <sd>(i)</sd> <def>A distaff.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mech.)</fld> <def>A bar with teeth on its face, or
edge, to work with those of a wheel, pinion, or worm, which is to drive
it or be driven by it.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which is extorted; exaction.</def>
<mark>[Obs.]</mark> <rj><au>Sir E. Sandys.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Mangle rack</b></col>. <fld>(Mach.)</fld> <cd>See under
<er>Mangle</er>. <pos>n.</pos></cd> -- <col><b>Rack block</b></col>.
<fld>(Naut.)</fld> <cd>See def. 1 <sd>(f)</sd>, above.</cd> --
<col><b>Rack lashing</b></col>, <cd>a lashing or binding where the rope
is tightened, and held tight by the use of a small stick of wood twisted
around.</cd> -- <col><b>Rack rail</b></col> <fld>(Railroads)</fld>,
<cd>a toothed rack, laid as a rail, to afford a hold for teeth on the
driving wheel of a locomotive for climbing steep gradients, as in
ascending a mountain.</cd> -- <col><b>Rack saw</b></col>, <cd>a saw
having wide teeth.</cd> -- <col><b>Rack stick</b></col>, <cd>the stick
used in a rack lashing.</cd> -- <col><b>To be on the rack</b></col>,
<cd>to suffer torture, physical or mental.</cd> -- <col><b>To live at
rack and manger</b></col>, <cd>to live on the best at another's
expense.</cd> <mark>[Colloq.]</mark> -- <col><b>To put to the
rack</b></col>, <cd>to subject to torture; to torment.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><q>A fit of the stone <qex>puts</qex> a king <qex>to the rack</qex>,
and makes him as miserable as it does the meanest subject.</q>
<rj><qau>Sir W. Temple.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rack</ent><br/
<hw>Rack</hw> <pr>(r<acr/k)</pr>, <pos>v. t.</pos> <sn>1.</sn> <def>To
extend by the application of force; to stretch or strain; specifically,
to stretch on the rack or wheel; to torture by an engine which strains
the limbs and pulls the joints.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He was <qex>racked</qex> and miserably tormented.</q>
<rj><qau>Foxe.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To torment; to torture; to affect with extreme pain
or anguish.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Vaunting aloud but <qex>racked</qex> with deep despair.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To stretch or strain, in a figurative sense; hence,
to harass, or oppress by extortion.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The landlords there shamefully <qex>rack</qex> their tenants.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>They [landlords] <qex>rack</qex> their rents an ace too high.</q>
<rj><qau>Gascoigne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Grant that I may never <qex>rack</qex> a Scripture simile beyond
the true intent thereof.</q> <rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Try what my credit can in Venice do;<br/
That shall be <qex>racked</qex> even to the uttermost.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Mining)</fld> <def>To wash on a rack, as metals or
ore.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Naut.)</fld> <def>To bind together, as two ropes,
with cross turns of yarn, marline, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>To rack one's brains</b></col> <it>or</it>
<col><b>To rack one's brains out</b></col> <it>or</it> <col><b>To rack
one's wits</b></col></mcol>, <cd>to exert one's thinking processes to
the utmost for the purpose of accomplishing something; <as>as, I
<ex>racked my brains out</ex> trying to find a way to solve the
problem</as>.</cd></cs><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><syn><b>Syn.</b> -- To torture; torment; rend; tear.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rackabones</ent><br/
<hw>Rack"a*bones`</hw> <pr>(r<acr/k"<adot/*b<omac/nz`)</pr>,
<pos>n.</pos> <def>A very lean animal, esp. a horse.</def>
<mark>[Colloq. U. S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rackarock</ent><br/
<hw>Rack"a*rock`</hw> <pr>(r<acr/k"<adot/*r<ocr/k`)</pr>, <pos>n.</pos>
<ety>[<ets>Rack</ets> to stretch, strain + <ets>a</ets> +
<ets>rock</ets>.]</ety> <def>A Sprengel explosive consisting of
potassium chlorate and mono-nitrobenzene.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Racker</ent><br/
<hw>Rack"er</hw> <pr>(r<acr/k"<etil/r)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>One who racks.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A horse that has a racking gait.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Racket</ent><br/
<hw>Rack"et</hw> <pr>(r<acr/k"<ecr/t)</pr>, <pos>n.</pos> <ety>[F.
<ets>raquette</ets>; cf. Sp. <ets>raqueta</ets>, It.
<ets>racchetta</ets>, which is perhaps for <ets>retichetta</ets>, and
fr. L. <ets>rete</ets> a net (cf. <er>Reticule</er>); or perh. from the
Arabic; cf. Ar. <ets>r<amac/ha</ets> the palm of the hand (used at first
to strike the ball), and OF. <ets>rachette</ets>, <ets>rasquette</ets>,
carpus, tarsus.]</ety> <altsp>[Written also <asp>racquet</asp>.]</altsp>
<sn>1.</sn> <def>A thin strip of wood, having the ends brought together,
forming a somewhat elliptical hoop, across which a network of catgut or
cord is stretched. It is furnished with a handle, and is used for
catching or striking a ball in tennis and similar games.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Each one [of the Indians] has a bat curved like a crosier, and
ending in a <qex>racket</qex>.</q> <rj><qau>Bancroft.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A variety of the game of tennis played with peculiar
long-handled rackets; -- chiefly in the plural.</def>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A snowshoe formed of cords stretched across a long
and narrow frame of light wood.</def> <mark>[Canada]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A broad wooden shoe or patten for a man or horse, to
enable him to step on marshy or soft ground.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Racket court</b></col>, <cd>a court for playing the game
of rackets.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Racket</ent><br/
<hw>Rack"et</hw>, <pos>v. t.</pos> <def>To strike with, or as with, a
racket.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Poor man [is] <qex>racketed</qex> from one temptation to
another.</q> <rj><qau>Hewyt.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Racket</ent><br/
<hw>Rack"et</hw>, <pos>n.</pos> <ety>[Gael. <ets>racaid</ets> a noise,
disturbance.]</ety> <sn>1.</sn> <def>confused, clattering noise; din;
noisy talk or sport.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A carouse; any reckless dissipation.</def>
<mark>[Slang]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Racket</ent><br/
<hw>Rack"et</hw>, <pos>n.</pos> <sn>1.</sn> <def>A scheme, dodge, trick,
or the like; something taking place considered as exciting, trying,
unusual, or the like; also, such occurrence considered as an ordeal;
<as>as, to work a <ex>racket</ex>; to stand upon the
<ex>racket</ex></as>.</def> <mark>[Slang]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>an organized illegal activity, such as illegal
gambling, bootlegging, or extortion.</def><br/
[<source>PJC</source>]</p>

<p><ent>Racket</ent><br/
<hw>Rack"et</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Racketed</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Racketing</conjf>.]</vmorph> <sn>1.</sn> <def>To make a confused
noise or racket.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To engage in noisy sport; to frolic.</def>
<rj><au>Sterne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To carouse or engage in dissipation.</def>
<mark>[Slang]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Racketer</ent><br/
<hw>Rack"et*er</hw> <pr>(r<acr/k"<ecr/t*<etil/r)</pr>, <pos>n.</pos>
<def>One who makes, or engages in, a racket.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rackett</ent><br/
<hw>Rack"ett</hw> <pr>(r<acr/k"<ecr/t)</pr>, <pos>n.</pos> <ety>[Etymol.
uncertain.]</ety> <fld>(Mus.)</fld> <def>An old wind instrument of the
double bassoon kind, having ventages but not keys.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Racket-tail</ent><br/
<hw>Rack"et-tail</hw> <pr>(r<acr/k"<ecr/t-t<amac/l)</pr>, <pos>n.</pos>
<fld>(Zool.)</fld> <def>Any one of several species of humming birds of
the genus <gen>Steganura</gen>, having two of the tail feathers very
long and racket-shaped.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Racket-tailed</ent><br/
<hw>Rack"et-tailed`</hw> <pr>(r<acr/k"<ecr/t-t<amac/ld`)</pr>,
<pos>a.</pos> <fld>(Zool.)</fld> <def>Having long and spatulate, or
racket-shaped, tail feathers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rackety</ent><br/
<hw>Rack"et*y</hw> <pr>(r<acr/k"<ecr/t*<ycr/)</pr>, <pos>a.</pos>
<def>Making a tumultuous noise.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Racking</ent><br/
<hw>Rack"ing</hw>, <pos>n.</pos> <fld>(Naut.)</fld> <def>Spun yarn used
in racking ropes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rack-rent</ent><br/
<hw>Rack"-rent`</hw> <pr>(r<acr/k"r<ecr/nt`)</pr>, <pos>n.</pos> <def>A
rent of the full annual value of the tenement, or near it; an excessive
or unreasonably high rent.</def> <rj><au>Blackstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rack-rent</ent><br/
<hw>Rack"-rent`</hw>, <pos>v. t.</pos> <def>To subject to rack-rent, as
a farm or tenant.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rack-renter</ent><br/
<hw>Rack"-rent`er</hw> <pr>(r<acr/k"r<ecr/nt`<etil/r)</pr>,
<pos>n.</pos> <sn>1.</sn> <def>One who is subjected to paying
rack-rent.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who exacts rack-rent.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1183 pr=vmg --></p>

<p><ent>Racktail</ent><br/
<hw>Rack"tail`</hw> <pr>(r<acr/k"t<amac/l`)</pr>, <pos>n.</pos>
<fld>(Horol.)</fld> <def>An arm attached to a swinging notched arc or
rack, to let off the striking mechanism of a repeating clock.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rackwork</ent><br/
<hw>Rack"work`</hw> <pr>(r<acr/k"w<ucir/rk`)</pr>, <pos>n.</pos>
<def>Any mechanism having a rack, as a rack and pinion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Racle</ent><br/
<hw>Ra"cle</hw> <pr>(r<aum/"k'l)</pr>, <pos>a.</pos> <def>See
<er>Rakel</er>.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Racleness</ent><br/
<hw>Ra"cle*ness</hw>, <pos>n.</pos> <def>See <er>Rakelness</er>.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raconteur</ent><br/
\'d8<hw>Ra`con`teur"</hw> <pr>(r<adot/`k<ocir/N`t<etil/r")</pr>,
<pos>n.</pos> <ety>[F.]</ety> <def>A relater; a storyteller.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Racoonda</ent><br/
\'d8<hw>Ra*coon"da</hw> <pr>(r<adot/*k<oomac/n"d<adot/)</pr>,
<pos>n.</pos> <ety>[From a native name.]</ety> <fld>(Zool.)</fld>
<def>The coypu.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Racovian</ent><br/
<hw>Ra*co"vi*an</hw> <pr>(r<adot/*k<omac/"v<icr/*<ait/n)</pr>,
<pos>n.</pos> <ety>[From <ets>Racow</ets>.]</ety> <fld>(Eccl.
Hist.)</fld> <def>One of a sect of Socinians or Unitarians in
Poland.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Racquet</ent><br/
<hw>Rac"quet</hw> <pr>(r<acr/k"k<ecr/t)</pr>, <pos>n.</pos> <def>See
<er>Racket</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Racy</ent><br/
<hw>Ra"cy</hw> <pr>(r<amac/"s<ycr/)</pr>, <pos>a.</pos>
<amorph>[<pos>Compar.</pos> <adjf>Racier</adjf>
<pr>(r<amac/"s<icr/*<etil/r)</pr>; <pos>superl.</pos>
<adjf>Raciest</adjf>.]</amorph> <ety>[From <er>Race</er> a tribe,
family.]</ety> <sn>1.</sn> <def>Having a strong flavor indicating
origin; of distinct characteristic taste; tasting of the soil; hence,
fresh; rich.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>racy</qex> wine,<br/
Late from the mellowing cask restored to light.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <specif>Hence:</specif> <def>Exciting to the mental taste
by a strong or distinctive character of thought or language; peculiar
and piquant; fresh and lively; vigorous; spirited.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Our <qex>raciest</qex>, most idiomatic popular words.</q>
<rj><qau>M. Arnold.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Burns's English, though not so <qex>racy</qex> as his Scotch, is
generally correct.</q> <rj><qau>H. Coleridge.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The rich and <qex>racy</qex> humor of a natural converser fresh
from the plow.</q> <rj><qau>Prof. Wilson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Somewhat suggestive of sexual themes; slightly
improper; risqu<eacute/.</def><br/
[<source>PJC</source>]</p>

<p><syn><b>Syn.</b> -- Spicy; spirited; lively; smart; piquant;
risqu<eacute/.</syn> <usage> -- <er>Racy</er>, <er>Spicy</er>.
<xex>Racy</xex> refers primarily to that peculiar flavor which certain
wines are supposed to derive from the soil in which the grapes were
grown; and hence we call a style or production <xex>racy</xex> when it
<ldquo/smacks of the soil,<rdquo/ or has an uncommon degree of natural
freshness and distinctiveness of thought and language. <xex>Spicy</xex>,
when applied to style, has reference to a spirit and pungency added by
art, seasoning the matter like a condiment. It does not, like
<xex>racy</xex>, suggest native peculiarity. A <xex>spicy</xex> article
in a magazine; a <xex>spicy</xex> retort. <xex>Racy</xex> in
conversation; a <xex>racy</xex> remark.</usage><br/
[<source>1913 Webster</source>]</p>

<p><q>Rich, <qex>racy</qex> verses, in which we<br/
The soil from which they come, taste, smell, and see.</q>
<rj><qau>Cowley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rad</ent><br/
<hw>Rad</hw> <pr>(r<acr/d)</pr>, <pos>n.</pos>
<ety>[<ets>r</ets>adiation <ets>a</ets>bsorbed <ets>d</ets>ose.]</ety>
<def>A unit of measurement of the amount of ionizing radiation absorbed
by an object, equal to an energy of 100 ergs per gram of irradiated
material (equal to 0.01 gray).</def><br/
[<source>PJC</source>]</p>

<p><ent>Rad</ent><br/
<hw>Rad</hw> <pr>(r<acr/d)</pr>, <mark>obs.</mark> <def><pos>imp. & p.
p.</pos> of <er>Read</er>, <er>Rede</er>.</def>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>radar</ent><br/
<hw>ra"dar</hw> <pr>(r<amac/"d<aum/r)</pr>, <pos>n.</pos> <ety>[acronym
from <ets>RA</ets>dio <ets>D</ets>etection <ets>A</ets>nd
<ets>R</ets>anging.]</ety> <sn>1.</sn> <def>An electronic device
designed to detect objects at a distance, and determine their distance
from the device, by transmitting a pulse of radio waves and measuring
the time required for the echo of the pulse to return to the emitting
device; <as>as, the <ex>radar</ex> showed a plane approaching
rapidly</as>.</def> <mark>[acronym]</mark> <br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>The method of detecting objects, finding their
distance, or determining their speed, by use of a radar{1} device;
<as>as, modern <ex>radar</ex> can detect objects as small as
raindrops</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Radde</ent><br/
<hw>Rad"de</hw> <pr>(r<acr/d"d<eit/)</pr>, <mark>obs.</mark>
<def><pos>imp.</pos> of <er>Read</er>, <er>Rede</er>.</def>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raddle</ent><br/
<hw>Rad"dle</hw> <pr>(r<acr/d"d'l)</pr>, <pos>n.</pos> <ety>[Cf. G.
<ets>r<aum/der</ets>, <ets>r<aum/del</ets>, sieve, or perhaps E.
<ets>reed</ets>.]</ety> <sn>1.</sn> <def>A long, flexible stick, rod, or
branch, which is interwoven with others, between upright posts or
stakes, in making a kind of hedge or fence.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A hedge or fence made with raddles; -- called also
<altname>raddle hedge</altname>.</def> <rj><au>Todd.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>An instrument consisting of a wooden bar, with a row
of upright pegs set in it, used by domestic weavers to keep the warp of
a proper width, and prevent tangling when it is wound upon the beam of
the loom.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raddle</ent><br/
<hw>Rad"dle</hw> <pr>(r<acr/d"d'l)</pr>, <pos>v. t.</pos> <def>To
interweave or twist together.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Raddling</qex> or working it up like basket work.</q>
<rj><qau>De Foe.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raddle</ent><br/
<hw>Rad"dle</hw> <pr>(r<acr/d"d'l)</pr>, <pos>n.</pos> <ety>[Cf.
<er>Ruddle</er>.]</ety> <def>A red pigment used in marking sheep, and in
some mechanical processes; ruddle.</def> <ldquo/A <xex>raddle</xex> of
rouge.<rdquo/ <rj><au>Thackeray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raddle</ent><br/
<hw>Rad"dle</hw>, <pos>v. t.</pos> <def>To mark or paint with, or as
with, raddle.</def> <ldquo/Whitened and <qex>raddled</qex> old
women.<rdquo/ <rj><au>Thackeray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raddock</ent><br/
<hw>Rad"dock</hw> <pr>(r<acr/d"d<ucr/k)</pr>, <pos>n.</pos>
<fld>(Zool.)</fld> <def>The ruddock.</def> <mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rade</ent><br/
<hw>Rade</hw> <pr>(r<amac/d)</pr>, <pos>n.</pos> <def>A raid.</def>
<mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Radeau</ent><br/
\'d8<hw>Ra`deau"</hw> <pr>(r<adot/`d<omac/")</pr>, <pos>n.</pos>
<ety>[F.]</ety> <def>A float; a raft.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Three vessels under sail, and one at anchor, above Split Rock, and
behind it the <qex>radeau</qex> Thunderer.</q> <rj><qau>W.
Irving.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Radial</ent><br/
<hw>Ra"di*al</hw> <pr>(r<amac/"d<icr/*<ait/l)</pr>, <pos>a.</pos>
<ety>[Cf. F. <ets>radial</ets>. See <er>Radius</er>.]</ety> <def>Of or
pertaining to a radius or ray; consisting of, or like, radii or rays;
radiated; <as>as, <fld>(Bot.)</fld> <ex>radial</ex> projections;
<fld>(Zool.)</fld> <ex>radial</ex> vessels or canals; <fld>(Anat.)</fld>
the <ex>radial</ex> artery</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Radial symmetry</b></col>. <fld>(Biol.)</fld> <cd>See
under <er>Symmetry</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Radiale</ent><br/
\'d8<hw>Ra`di*a"le</hw> <pr>(r<amac/`d<icr/*<amac/"l<esl/)</pr>,
<pos>n.</pos>; <plu><it>pl.</it> <plw>Radialia</plw>
<pr>(r<amac/`d<icr/*<amac/"l<icr/*<adot/)</pr>.</plu> <ety>[NL. See
<er>Radial</er>.]</ety> <sn>1.</sn> <fld>(Anat.)</fld> <def>The bone or
cartilage of the carpus which articulates with the radius and
corresponds to the scaphoid bone in man.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <pluf>pl.</pluf> <fld>(Zool.)</fld> <def>Radial plates in
the calyx of a crinoid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Radial engine</ent><br/
<hw>Radial engine</hw>. <fld>(Mach.)</fld> <def>An engine, usually an
internal-combustion engine of a certain type (the <col><b>radial
type</b></col>) having several cylinders arranged radially like the
spokes of a complete wheel. The <col><b>semiradial engine</b></col> has
radiating cylinders on only one side of the crank shaft.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Radially</ent><br/
<hw>Ra"di*al*ly</hw> <pr>(r<amac/"d<icr/*<ait/l*l<ycr/)</pr>,
<pos>adv.</pos> <def>In a radial manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Radial tire</ent><br/
<hw>Radial tire</hw>. <fld>(Automobiles)</fld> <def>a motor vehicle tire
in which the cords run at right angles to the plane of the tire
(considered as a disk).</def><br/
[<source>PJC</source>]</p>

<p><ent>Radian</ent><br/
<hw>Ra"di*an</hw> <pr>(r<amac/"d<icr/*<ait/n)</pr>, <pos>n.</pos>
<ety>[From <er>Radius</er>.]</ety> <fld>(Math.)</fld> <def>An arc of a
circle which is equal to the radius, or the angle measured by such an
arc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Radiancy</ent><br/
<ent>Radiance</ent><br/
<mhw>{ <hw>Ra"di*ance</hw> <pr>(r<amac/"d<icr/*<ait/ns)</pr>,
<hw>Ra"di*an*cy</hw> <pr>(r<amac/"d<icr/*<ait/n*s<ycr/)</pr>, }</mhw>
<pos>n.</pos> <def>The quality of being radiant; brilliancy; effulgence;
vivid brightness; <as>as, the <ex>radiance</ex> of the
sun</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Girt with omnipotence, with <qex>radiance</qex> crowned.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>What <qex>radiancy</qex> of glory,<br/
What light beyond compare !</q> <rj><qau>Neale.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Luster; brilliancy; splendor; glare;
glitter.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Radiant</ent><br/
<hw>Ra"di*ant</hw> <pr>(r<amac/"d<icr/*<ait/nt)</pr>, <pos>a.</pos>
<ety>[L. <ets>radians</ets>, <ets>-antis</ets>, p. pr. of
<ets>radiare</ets> to emit rays or beams, fr. <ets>radius</ets> ray: cf.
F. <ets>radiant</ets>. See <er>Radius</er>, <er>Ray</er> a divergent
line.]</ety> <sn>1.</sn> <def>Emitting or proceeding as from a center;
resembling rays; radiating; radiate.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Especially, emitting or darting rays of light or
heat; issuing in beams or rays; beaming with brightness; emitting a
vivid light or splendor; <as>as, the <ex>radiant</ex>
sun</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Mark what <qex>radiant</qex> state she spreads.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Beaming with vivacity and happiness; <as>as, a
<ex>radiant</ex> face</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Her.)</fld> <def>Giving off rays; -- said of a
bearing; <as>as, the sun <ex>radiant</ex>; a crown
<ex>radiant</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Bot.)</fld> <def>Having a raylike appearance, as
the large marginal flowers of certain umbelliferous plants; -- said also
of the cluster which has such marginal flowers.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Physics)</fld> <def>Emitted or transmitted by
radiation; <as>as, a <ex>radiant</ex> energy; <ex>radiant</ex>
heat</as>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><cs><col><b>Radiant energy</b></col> <fld>(Physics)</fld>, <cd>energy
given out or transmitted by radiation, as in the case of light and
radiant heat.</cd> -- <col><b>Radiant heat</b></col>, <cd>heat
proceeding in right lines, or directly from the heated body, after the
manner of light, in distinction from heat <xex>conducted</xex> or
carried by intervening media.</cd> -- <col><b>Radiant point</b></col>.
<fld>(Astron.)</fld> <cd>See <er>Radiant</er>, <pos>n.</pos>,
3.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Radiant</ent><br/
<hw>Ra"di*ant</hw>, <pos>n.</pos> <sn>1.</sn> <fld>(Opt.)</fld> <def>The
luminous point or object from which light emanates; also, a body
radiating light brightly.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Geom.)</fld> <def>A straight line proceeding from a
given point, or fixed pole, about which it is conceived to
revolve.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Astron.)</fld> <def>The point in the heavens at
which the apparent paths of shooting stars meet, when traced backward,
or whence they appear to radiate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Radiant engine</ent><br/
<hw>Radiant engine</hw>. <fld>(Mach.)</fld> <def>A semiradial engine.
See <er>Radial engine</er>, above.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Radiantly</ent><br/
<hw>Ra"di*ant*ly</hw> <pr>(r<amac/"d<icr/*<ait/nt*l<ycr/)</pr>,
<pos>adv.</pos> <def>In a radiant manner; with glittering
splendor.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Radiary</ent><br/
<hw>Ra"di*a*ry</hw> <pr>(r<amac/"d<icr/*<asl/*r<ycr/)</pr>,
<pos>n.</pos> <ety>[Cf. F. <ets>radiaire</ets>.]</ety>
<fld>(Zool.)</fld> <def>A radiate.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Radiata</ent><br/
\'d8<hw>Ra`di*a"ta</hw> <pr>(r<amac/"d<icr/*<amac/"t<adot/)</pr>,
<pos>n. pl.</pos> <ety>[NL., fr. <ets>radiatus</ets>, p. p. See
<er>Radiate</er>.]</ety> <fld>(Zool.)</fld> <def>An extensive artificial
group of invertebrates, having all the parts arranged radially around
the vertical axis of the body, and the various organs repeated
symmetrically in each ray or spheromere.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ It includes the c<oe/lenterates and the echinoderms.
Formerly, the group was supposed to be a natural one, and was considered
one of the grand divisions of the animal kingdom.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Radiate</ent><br/
<hw>Ra"di*ate</hw> <pr>(r<amac/"d<icr/*<amac/t)</pr>, <pos>v. i.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Radiated</conjf>
<pr>(r<amac/"d<icr/*<amac/`t<ecr/d)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Radiating</conjf>.]</vmorph> <ety>[L. <ets>radiatus</ets>, p. p.
of <ets>radiare</ets> to furnish with spokes or rays, to radiate, fr.
<ets>radius</ets> ray. See <er>Radius</er>, <er>Ray</er> a divergent
line.]</ety> <sn>1.</sn> <def>To emit rays; to be radiant; to
shine.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Virtues shine more clear<br/
In them [kings], and <qex>radiate</qex> like the sun at noon.</q>
<rj><qau>Howell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To proceed in direct lines from a point or surface;
to issue in rays, as light or heat.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Light <qex>radiates</qex> from luminous bodies directly to our
eyes.</q> <rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Radiate</ent><br/
<hw>Ra"di*ate</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To emit or send
out in direct lines from a point or points; <as>as, to <ex>radiate</ex>
heat</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To enlighten; to illuminate; to shed light or
brightness on; to irradiate.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Radiate</ent><br/
<hw>Ra"di*ate</hw> <pr>(r<amac/"d<icr/*<asl/t)</pr>, <pos>a.</pos>
<ety>[L. <ets>radiatus</ets>, p. p.]</ety> <sn>1.</sn> <def>Having rays
or parts diverging from a center; radiated; <as>as, a <ex>radiate</ex>
crystal</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>Having in a capitulum large ray
florets which are unlike the disk florets, as in the aster, daisy,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <def>Belonging to the
Radiata.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Radiate</ent><br/
<hw>Ra"di*ate</hw>, <pos>n.</pos> <fld>(Zool.)</fld> <def>One of the
Radiata.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Radiated</ent><br/
<hw>Ra"di*a`ted</hw> <pr>(r<amac/"d<icr/*<amac/`t<ecr/d)</pr>,
<pos>a.</pos> <sn>1.</sn> <def>Emitted, or sent forth, in rays or direct
lines; <as>as, <ex>radiated</ex> heat</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Formed of, or arranged like, rays or radii; having
parts or markings diverging, like radii, from a common center or axis;
<as>as, a <ex>radiated</ex> structure; a <ex>radiated</ex> group of
crystals.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <def>Belonging to the
Radiata.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Radiately</ent><br/
<hw>Ra"di*ate*ly</hw> <pr>(r<amac/"d<icr/*<asl/t*l<ycr/)</pr>,
<pos>adv.</pos> <def>In a radiate manner; with radiation or divergence
from a center.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Radiate-veined</ent><br/
<hw>Ra"di*ate-veined`</hw> <pr>(r<amac/"d<icr/*<asl/t-v<amac/nd`)</pr>,
<pos>a.</pos> <fld>(Bot.)</fld> <def>Having the principal veins
radiating, or diverging, from the apex of the petiole; -- said of such
leaves as those of the grapevine, most maples, and the castor-oil
plant.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Radiatiform</ent><br/
<hw>Ra`di*at"i*form</hw>
<pr>(r<amac/`d<icr/*<acr/t"<icr/*f<ocir/rm)</pr>, <pos>a.</pos>
<fld>(Bot.)</fld> <def>Having the marginal florets enlarged and
radiating but not ligulate, as in the capitula or heads of the
cornflower.</def> <rj><au>Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Radiation</ent><br/
<hw>Ra`di*a"tion</hw> <pr>(r<amac/`d<icr/*<amac/"sh<ucr/n)</pr>,
<pos>n.</pos> <ety>[L. <ets>radiatio</ets>: cf. F.
<ets>radiation</ets>.]</ety> <sn>1.</sn> <def>The act of radiating, or
the state of being radiated; emission and diffusion of rays of light;
beamy brightness.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The shooting forth of anything from a point or
surface, like the diverging rays of light; <as>as, the
<ex>radiation</ex> of heat</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Radiative</ent><br/
<hw>Ra"di*a*tive</hw> <pr>(r<amac/"d<icr/*<asl/*t<icr/v)</pr>,
<pos>a.</pos> <def>Capable of radiating; acting by radiation.</def>
<rj><au>Tyndall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Radiator</ent><br/
<hw>Ra"di*a`tor</hw> <pr>(r<amac/"d<icr/*<amac/`t<etil/r)</pr>,
<pos>n.</pos> <sn>1.</sn> <def>That which radiates or emits rays,
whether of light or heat; especially, that part of a heating apparatus
from which the heat is radiated or diffused; <as>as, a steam
<ex>radiator</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Any of various devices for cooling an internal
substance by radiation, as a system of rings on a gun barrel for cooling
it, or a nest of tubes with large radiating surface for cooling
circulating water, as in an automobile.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>3.</sn> <fld>(Wireless Teleg.)</fld> <def>An
oscillator.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Radical</ent><br/
<hw>Rad"i*cal</hw> <pr>(r<acr/d"<icr/*k<ait/l)</pr>, <pos>a.</pos>
<ety>[F., fr. L. <ets>radicalis</ets> having roots, fr.
<ets>radix</ets>, <ets>-icis</ets>, a root. See <er>Radix</er>.]</ety>
<sn>1.</sn> <def>Of or pertaining to the root; proceeding directly from
the root.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence: Of or pertaining to the root or origin;
reaching to the center, to the foundation, to the ultimate sources, to
the principles, or the like; original; fundamental; thorough-going;
unsparing; extreme; <as>as, <ex>radical</ex> evils; <ex>radical</ex>
reform; a <ex>radical</ex> party.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>The most determined exertions of that authority, against them,
only showed their <qex>radical</qex> independence.</q>
<rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Bot.)</fld> <sd>(a)</sd> <def>Belonging to, or
proceeding from, the root of a plant; <as>as, <ex>radical</ex> tubers or
hairs</as>.</def> <sd>(b)</sd> <def>Proceeding from a rootlike stem, or
one which does not rise above the ground; <as>as, the <ex>radical</ex>
leaves of the dandelion and the sidesaddle flower</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Philol.)</fld> <def>Relating, or belonging, to the
root, or ultimate source of derivation; <as>as, a <ex>radical</ex>
verbal form</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Math.)</fld> <def>Of or pertaining to a radix or
root; <as>as, a <ex>radical</ex> quantity; a <ex>radical</ex> sign. See
below.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Radical axis of two circles</b></col>. <fld>(Geom.)</fld>
<cd>See under <er>Axis</er>.</cd> -- <col><b>Radical pitch</b></col>,
<cd>the pitch or tone with which the utterance of a syllable
begins.</cd> <au>Rush.</au> -- <col><b>Radical quantity</b></col>
<fld>(Alg.)</fld>, <cd>a quantity to which the radical sign is prefixed;
specifically, a quantity which is not a perfect power of the degree
indicated by the radical sign; a surd.</cd> -- <col><b>Radical
sign</b></col> <fld>(Math.)</fld>, <cd>the sign <root/ (originally the
letter <xex>r</xex>, the initial of <xex>radix</xex>, root), placed
before any quantity, denoting that its root is to be extracted; thus,
<root/<it>a</it>, or <root/(<it>a</it> + <it>b</it>). To indicate any
other than the square root, a corresponding figure is placed over the
sign; thus, <cuberoot/<it>a</it>, indicates the third or cube root of
<it>a</it>.</cd> -- <col><b>Radical stress</b></col>
<fld>(Elocution)</fld>, <cd>force of utterance falling on the initial
part of a syllable or sound.</cd> -- <col><b>Radical vessels</b></col>
<fld>(Anat.)</fld>, <cd>minute vessels which originate in the substance
of the tissues.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Primitive; original; natural; underived;
fundamental; entire.</syn> <usage> -- <er>Radical</er>, <er>Entire</er>.
These words are frequently employed as interchangeable in describing
some marked alteration in the condition of things. There is, however, an
obvious difference between them. A <xex>radical</xex> cure, reform,
etc., is one which goes to the root of the thing in question; and it is
<xex>entire</xex>, in the sense that, by affecting the root, it affects
in an appropriate degree the <xex>entire</xex> body nourished by the
root; but it may not be <xex>entire</xex> in the sense of making a
change complete in its nature, as well as in its extent. Hence, we speak
of a <xex>radical</xex> change; a <xex>radical</xex> improvement;
<xex>radical</xex> differences of opinion; while an <xex>entire</xex>
change, an <xex>entire</xex> improvement, an <xex>entire</xex>
difference of opinion, might indicate more than was actually intended. A
certain change may be both <xex>radical</xex> and <xex>entire</xex>, in
every sense.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Radical</ent><br/
<hw>Rad"i*cal</hw> <pr>(r<acr/d"<icr/*k<ait/l)</pr>, <pos>n.</pos>
<sn>1.</sn> <fld>(Philol.)</fld> <sd>(a)</sd> <def>A primitive word; a
radix, root, or simple, underived, uncompounded word; an etymon.</def>
<sd>(b)</sd> <def>A primitive letter; a letter that belongs to the
radix.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The words we at present make use of, and understand only by common
agreement, assume a new air and life in the understanding, when you
trace them to their <qex>radicals</qex>, where you find every word
strongly stamped with nature; full of energy, meaning, character,
painting, and poetry.</q> <rj><qau>Cleland.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Politics)</fld> <def>One who advocates radical
changes in government or social institutions, especially such changes as
are intended to level class inequalities; -- opposed to
<xex>conservative</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In politics they [the Independents] were, to use the phrase of
their own time, <ldquo/Root-and-Branch men,<rdquo/ or, to use the
kindred phrase of our own, <qex>Radicals</qex>.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Chem.)</fld> <sd>(a)</sd> <def>A characteristic,
essential, and fundamental constituent of any compound; hence,
sometimes, an atom.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>As a general rule, the metallic atoms are basic
<qex>radicals</qex>, while the nonmetallic atoms are acid
<qex>radicals</qex>.</q> <rj><qau>J. P. Cooke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(b)</sd> <def>Specifically, a group of two or more atoms, not
completely saturated, which are so linked that their union implies
certain properties, and are conveniently regarded as playing the part of
a single atom; a residue; -- called also a <altname>compound
radical</altname>. Cf. <er>Residue</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Alg.)</fld> <def>A radical quantity. See under
<er>Radical</er>, <pos>a.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><q>An indicated root of a perfect power of the degree indicated is
not a <qex>radical</qex> but a rational quantity under a radical
form.</q> <rj><qau>Davies & Peck (Math. Dict.)</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Anat.)</fld> <def>A radical vessel. See under
<er>Radical</er>, <pos>a.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Radicalism</ent><br/
<hw>Rad"i*cal*ism</hw> <pr>(r<acr/d"<icr/*k<ait/l*<icr/z'm)</pr>,
<pos>n.</pos> <ety>[Cf. F. <ets>radicalisme</ets>.]</ety> <def>The
quality or state of being radical; specifically, the doctrines or
principles of radicals in politics or social reform.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Radicalism</qex> means root work; the uprooting of all
falsehoods and abuses.</q> <rj><qau>F. W. Robertson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Radicality</ent><br/
<hw>Rad`i*cal"i*ty</hw> <pr>(r<acr/d`<icr/*k<acr/l"<icr/*t<ycr/)</pr>,
<pos>n.</pos> <sn>1.</sn> <def>Germinal principle; source;
origination.</def> <mark>[Obs.]</mark> <rj><au>Sir T.
Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Radicalness; relation to a root in essential nature
or principle.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Radically</ent><br/
<hw>Rad"i*cal*ly</hw> <pr>(r<acr/d"<icr/*k<ait/l*l<ycr/)</pr>,
<pos>adv.</pos> <sn>1.</sn> <def>In a radical manner; at, or from, the
origin or root; fundamentally; <as>as, a scheme or system
<ex>radically</ex> wrong or defective</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Without derivation; primitively; essentially.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>These great orbs thus <qex>radically</qex> bright.</q>
<rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Radicalness</ent><br/
<hw>Rad"i*cal*ness</hw>, <pos>n.</pos> <def>Quality or state of being
radical.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Radicant</ent><br/
<hw>Rad"i*cant</hw> <pr>(r<acr/d"<icr/*k<ait/nt)</pr>, <pos>a.</pos>
<ety>[L. <ets>radicans</ets>, p. pr.: cf. F. <ets>radicant</ets>. See
<er>Radicate</er>, <pos>a.</pos>]</ety> <fld>(Bot.)</fld> <def>Taking
root on, or above, the ground; rooting from the stem, as the trumpet
creeper and the ivy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Radicate</ent><br/
<hw>Rad"i*cate</hw> <pr>(r<acr/d"<icr/*k<asl/t)</pr>, <pos>a.</pos>
<ety>[L. <ets>radicatus</ets>, p. p. of <ets>radicari</ets> to take
root, fr. <ets>radix</ets>. See <er>Radix</er>.]</ety>
<def>Radicated.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Radicate</ent><br/
<hw>Rad"i*cate</hw> <pr>(r<acr/d"<icr/*k<amac/t)</pr>, <pos>v. i.</pos>
<def>To take root; to become rooted.</def> <rj><au>Evelyn.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Radicate</ent><br/
<hw>Rad"i*cate</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Radicated</conjf> <pr>(r<acr/d"<icr/*k<amac/`t<ecr/d)</pr>;
<pos>p. pr. & vb. n.</pos> <conjf>Radicating</conjf>.]</vmorph> <def>To
cause to take root; to plant deeply and firmly; to root.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Time should . . . rather confirm and <qex>radicate</qex> in us the
remembrance of God's goodness.</q> <rj><qau>Barrow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Radicated</ent><br/
<hw>Rad"i*ca`ted</hw> <pr>(r<acr/d"<icr/*k<amac/`t<ecr/d)</pr>,
<pos>a.</pos> <def>Rooted</def>; specifically: <sd>(a)</sd>
<fld>(Bot.)</fld> <def>Having roots, or possessing a well-developed
root.</def> <sd>(b)</sd> <fld>(Zool.)</fld> <def>Having rootlike organs
for attachment.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Radication</ent><br/
<hw>Rad`i*ca"tion</hw> <pr>(r<acr/d"<icr/*k<amac/"sh<ucr/n)</pr>,
<pos>n.</pos> <ety>[Cf. F. <ets>radication</ets>.]</ety> <sn>1.</sn>
<def>The process of taking root, or state of being rooted; <as>as, the
<ex>radication</ex> of habits</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>The disposition of the roots of a
plant.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Radicel</ent><br/
<hw>Rad"i*cel</hw> <pr>(r<acr/d"<icr/*s<ecr/l)</pr>, <pos>n.</pos>
<ety>[Dim. of <ets>radix</ets>.]</ety> <fld>(Bot.)</fld> <def>A small
branch of a root; a rootlet.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Radiciflorous</ent><br/
<hw>Ra*dic`i*flo"rous</hw>
<pr>(r<adot/*d<icr/s`<icr/*fl<omac/"r<ucr/s)</pr>, <pos>a.</pos>
<ety>[L. <ets>radix</ets>, <ets>-icis</ets>, root + <ets>flos</ets>,
<ets>floris</ets>, a flower.]</ety> <fld>(Bot.)</fld>
<def>Rhizanthous.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Radiciform</ent><br/
<hw>Ra*dic"i*form</hw> <pr>(r<adot/*d<icr/s"<icr/*f<ocir/m)</pr>,
<pos>a.</pos> <fld>(Bot.)</fld> <def>Having the nature or appearance of
a radix or root.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Radicle</ent><br/
<hw>Rad"i*cle</hw> <pr>(r<acr/d"<icr/*k'l)</pr>, <pos>n.</pos> <ety>[L.
<ets>radicula</ets>, dim. of <ets>radix</ets>, <ets>-icis</ets>, root:
cf. F. <ets>radicule</ets>. See <er>Radix</er>.]</ety> <fld>(Bot.)</fld>
<sd>(a)</sd> <def>The rudimentary stem of a plant which supports the
cotyledons in the seed, and from which the root is developed downward;
the stem of the embryo; the caulicle.</def> <sd>(b)</sd> <def>A rootlet;
a radicel.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Radicular</ent><br/
<hw>Ra*dic"u*lar</hw> <pr>(r<adot/*d<icr/k"<usl/*l<etil/r)</pr>,
<pos>a.</pos> <def>Of or pertaining to roots, or the root of a
plant.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Radicule</ent><br/
<hw>Rad"i*cule</hw> <pr>(r<acr/d"<icr/*k<umac/l)</pr>, <pos>n.</pos>
<fld>(Bot.)</fld> <def>A radicle.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Radiculose</ent><br/
<hw>Ra*dic"u*lose`</hw> <pr>(r<adot/*d<icr/k"<usl/*l<omac/s`)</pr>,
<pos>a.</pos> <fld>(Bot.)</fld> <def>Producing numerous radicles, or
rootlets.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Radii</ent><br/
<hw>Ra"di*i</hw> <pr>(r<amac/"d<icr/*<imac/)</pr>, <pos>n.</pos>,
<def><pos>pl.</pos> of <er>Radius</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Radio-</ent><br/
<hw>Ra"di*o-</hw> <pr>(r<amac/"d<icr/*<osl/-)</pr>, <pos>a.</pos>
<sn>1.</sn> <def>Of or pertaining to, or employing, or operated by,
radiant energy, specifically that of electromagnetic waves with
frequencies between those of infrared radiation and X-rays; hence,
pertaining to, or employed in, broadcast radio or television,
microwaves, radiotelephones, etc.; <as>as, <ex>radio</ex>
waves</as>.</def><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>of or pertaining to broadcast radio; <as>as, a
<ex>radio</ex> program</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Radio-</ent><br/
<hw>Ra"di*o-</hw> <pr>(r<amac/"d<icr/*<osl/-)</pr>. <def>A combining
form indicating <sig>connection with</sig>, or <sig>relation to</sig>,
<sig>a radius</sig> or <sig>ray</sig>; <specif>specifically</specif>
<fld>(Anat.)</fld>, <sig>with the radius of the forearm</sig>; <as>as,
<ex>radio-</ex>ulnar, <ex>radio-</ex>muscular,
<ex>radio-</ex>carpal</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>radioactive</ent><br/
<hw>ra`di*o*ac"tive</hw> <pr>(r<amac/`d<icr/*<osl/*<acr/k"t<icr/v)</pr>,
<pos>a.</pos> <ety>[<ets>Radio-</ets> + <ets>active</ets>.]</ety>
<sn>1.</sn> <fld>(Physics)</fld> <def>Capable of luminescence under the
action of cathode rays, X rays, or any of the allied forms of
radiation.</def> <mark>[obsolete]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <fld>(Physics)</fld> <def>of, exhibiting, or caused by
<er>radioactivity</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>radioactivity</ent><br/
<hw>ra`di*o*ac*tiv"i*ty</hw>
<pr>(r<amac/`d<icr/*<osl/*<acr/k*t<icr/v"<icr/*t<ycr/)</pr>,
<pos>n.</pos> <fld>(Physics)</fld> <def>a form of instability which is a
property of the atomic nuclei of certain isotopes, which causes a
spontaneous change in the structure of the nucleus, accompanied by
emission of energetic radiation. The radiation emitted is usually
sufficient to cause ionization in matter through which it passes, and is
therefore called <er>ionizing radiation</er>. The radiation emitted by
most radioactive substances is one of three types: <er>alpha rays</er>,
<er>beta rays</er>, or <er>gamma rays</er>. Some chemical elements have
no stable isotopes, and these are referred to as <it>radioactive
elements</it>, and the element itself is said to possess
<ex>radioactivity</ex>.</def> <note>The changes in radioactive nuclei
which cause radiation in most cases cause the chemical identity of the
nucleus itself to change, as when tritium (an isotope of hydrogen) emits
a beta ray and converts to helium. The radioactive decay process is a
first-order reaction, and the rate of decay of a particular isotope can
therefore be expressed as the <er>half life</er> of the isotope, which
is the time it takes for one half of the remaining undecayed isotope to
decay, and is a constant independent of the proportion of original
material which has already decayed. The half life of tritium, for
example, is 12.3 years.</note><br/
[<source>PJC</source>]</p>

<p><ent>Radioconductor</ent><br/
<hw>Ra`di*o*con*duc"tor</hw>
<pr>(r<amac/`d<icr/*<osl/*k<ocr/n*d<ucr/k"t<etil/r)</pr>, <pos>n.</pos>
<fld>(Elec.)</fld> <def>A substance or device that has its conductivity
altered in some way by electric waves, as a coherer.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Radio-flagellata</ent><br/
\'d8<hw>Ra`di*o-flag`el*la"ta</hw>
<pr>(r<amac/`d<icr/*<osl/*fl<acr/j`<ecr/l*l<amac/"t<adot/)</pr>, <pos>n.
pl.</pos> <ety>[NL. See <er>Radiate</er>, and
<er>Flagellata</er>.]</ety> <fld>(Zool.)</fld> <def>A group of Protozoa
having both flagella and pseudopodia.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>radiograph</ent><br/
<hw>ra"di*o*graph</hw> <pr>(r<amac/"d<icr/*<osl/*gr<acr/f)</pr>,
<pos>n.</pos> <ety>[<ets>Radio-</ets> + <ets>-graph</ets>.]</ety>
<sn>1.</sn> <def>An instrument for measuring and recording solar
radiation.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>An image or picture produced upon a sensitive
surface, as of a photographic or fluorescent plate, by some form of
penetrating radiation other than light, as X-rays, beta rays, etc.;
esp., a picture of the internal structure of opaque objects traversed by
the rays; a skiagraph. When the picture is produced upon photographic
film by X-rays, the picture is usually called an <altname>X-ray
photo</altname> or <altname>X-ray</altname>. When an image is produced
on photographic film by a radioactive substance in close proximity to
the film, in a manner so as to record the spatial distribution of the
radioactive substance, the resulting image is called an
<stype>autoradiograph</stype> or
<stype><er>autoradiogram</er></stype>.</def><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><ent>radiograph</ent><br/
<hw>ra"di*o*graph</hw> <pr>(r<amac/"d<icr/*<osl/*gr<acr/f)</pr>, <pos>v.
t.</pos> <def>To make a radiograph of.</def> --
<wordforms><wf>ra`di*og"ra*pher</wf>
<pr>(r<amac/`d<icr/*<ocr/g"r<adot/*f<etil/r)</pr>,
<pos>n.</pos></wordforms><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>radiography</ent><br/
<hw>ra`di*og"ra*phy</hw>
<pr>(r<amac/`d<icr/*<ocr/g"r<adot/*f<ycr/)</pr>, <pos>n.</pos> <def>Art
or process of making radiographs, radiograms, or autoradiograms.</def>
-- <wordforms><wf>ra`di*o*graph"ic</wf>
<pr>(r<amac/`d<icr/*<osl/*gr<acr/f"<icr/k)</pr>,
<wf>ra`di*o*graph"ic*al</wf>
<pr>(r<amac/`d<icr/*<osl/*gr<acr/f"<icr/*k<ait/l)</pr>, <pos>a.</pos> --
<wf>Ra`di*o*graph"ic*al*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><-- p. 1184 pr=vmg --></p>

<p><ent>Radiolaria</ent><br/
\'d8<hw>Ra`di*o*la"ri*a</hw>
<pr>(r<amac/`d<icr/*<osl/*l<amac/"r<icr/*<adot/)</pr>, <pos>n. pl.</pos>
<ety>[NL. See <er>Radioli</er>.]</ety> <fld>(Zool.)</fld> <def>Order of
rhizopods, usually having a siliceous skeleton, or shell, and sometimes
radiating spicules. The pseudopodia project from the body like rays. It
includes the polycystines. See <er>Polycystina</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Radiolarian</ent><br/
<hw>Ra`di*o*la"ri*an</hw>
<pr>(r<amac/`d<icr/*<osl/*l<amac/"r<icr/*<ait/n)</pr>, <pos>a.</pos>
<fld>(Zool.)</fld> <def>Of or pertaining to the Radiolaria.</def> --
<def2><pos>n.</pos> <def>One of the Radiolaria.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Radioli</ent><br/
\'d8<hw>Ra*di"o*li</hw> <pr>(r<adot/*d<imac/"<osl/*l<imac/)</pr>,
<pos>n. pl.</pos>; <sing>sing. <singw>Radiolus</singw>
<pr>(r<adot/*d<imac/"<osl/*l<ucr/s)</pr></sing>. <ety>[NL., dim. of L.
<ets>radius</ets> radius: cf. L. <ets>radiolus</ets> a feeble
sunbeam.]</ety> <fld>(Zool.)</fld> <def>The barbs of the radii of a
feather; barbules.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Radiolite</ent><br/
<hw>Ra"di*o*lite</hw> <pr>(r<amac/"d<icr/*<osl/*l<imac/t)</pr>,
<pos>n.</pos> <ety>[L. <ets>radius</ets> ray + <ets>-lite</ets>: cf. F.
<ets>radiolithe</ets>.]</ety> <fld>(Paleon.)</fld> <def>A
hippurite.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Radiometer</ent><br/
<hw>Ra`di*om"e*ter</hw> <pr>(r<amac/`d<icr/*<ocr/m"<esl/*t<etil/r)</pr>,
<pos>n.</pos> <ety>[L. <ets>radius</ets> radius + <ets>-meter</ets>: cf.
F. <ets>radiom<egrave/tre</ets>.]</ety> <sn>1.</sn> <fld>(Naut.)</fld>
<def>A forestaff.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Physics)</fld> <def>An instrument designed for
measuring the mechanical effect of radiant energy.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ It consists of a number of light disks, blackened on one
side, placed at the ends of extended arms, supported on a pivot in an
exhausted glass vessel. When exposed to rays of light or heat, the arms
rotate.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Radiometry</ent><br/
<hw>Ra`di*om"e*try</hw> <pr>(r<amac/`d<icr/*<ocr/m"<esl/*tr<ycr/)</pr>,
<pos>n.</pos> <fld>(Physics)</fld> <def>The use of the radiometer, or
the measurement of radiation.</def> --
<wordforms><wf>Ra`di*o*met"ric</wf>
<pr>(r<amac/`d<icr/*<osl/*m<ecr/t"r<icr/k)</pr>,
<pos>a.</pos></wordforms><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Radiomicrometer</ent><br/
<hw>Ra`di*o*mi*crom"e*ter</hw>
<pr>(r<amac/`d<icr/*<osl/*m<isl/*kr<ocr/m"<esl/*t<etil/r)</pr>,
<pos>n.</pos> <ety>[<ets>Radio-</ets> + <ets>micrometer</ets>.]</ety>
<fld>(Physics)</fld> <def>A very sensitive modification or application
of the thermopile, used for indicating minute changes of radiant heat,
or temperature.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Radiophare</ent><br/
<hw>Ra"di*o*phare</hw> <pr>(r<amac/"d<icr/*<osl/*f<acir/r)</pr>,
<pos>n.</pos> <ety>[<ets>Radio-</ets> + <ets>phare</ets>.]</ety> <def>A
radiotelegraphic station serving solely for determining the position of
ships. The radius of operation of such stations was restricted by the
International Radiotelegraphic Convention (1912) to 30 nautical
miles.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Radiophone</ent><br/
<hw>Ra"di*o*phone</hw> <pr>(r<amac/"d<icr/*<osl/*f<omac/n)</pr>,
<pos>n.</pos> <ety>[<ets>Radio-</ets> + Gr. <grk>fwnh`</grk>
sound.]</ety> <sn>1.</sn> <fld>(Physics)</fld> <def>An apparatus for the
production of sound by the action of luminous or thermal rays. It is
essentially the same as the photophone.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>a telephone using radio waves, rather than wires, to
convey the voice signal.</def><br/
[<source>PJC</source>]</p>

<p><ent>Radiophony</ent><br/
<hw>Ra`di*oph"o*ny</hw>
<pr>(r<amac/`d<icr/*<osl/*<ocr/f"<osl/*n<ycr/)</pr>, <pos>n.</pos>
<fld>(Physics)</fld> <def>The art or practice of using the
radiophone.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Radiopticon</ent><br/
<hw>Ra`di*op"ti*con</hw>
<pr>(r<amac/`d<icr/*<ocr/p"t<icr/*k<ocr/n)</pr>, <pos>n.</pos>
<ety>[<ets>Radio-</ets> + stere<ets>opticon</ets>.]</ety> <def>See
<er>Projector</er>, above.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Radioscopy</ent><br/
<hw>Ra`di*os"co*py</hw> <pr>(r<amac/`d<icr/*<ocr/s"k<osl/*p<ycr/)</pr>,
<pos>n.</pos> <ety>[<ets>Radio-</ets> + <ets>-scopy</ets>.]</ety>
<def>Direct observation of objects opaque to light by means of some
other form of radiant energy, as x-rays.</def> --
<wordforms><wf>Ra`di*o*scop"ic</wf>
<pr>(r<amac/`d<icr/*<ocr/*sk<ocr/p"<icr/k)</pr>,
<wf>Ra`di*o*scop"ic*al</wf>
<pr>(r<amac/`d<icr/*<ocr/*sk<ocr/p"<icr/*k<ait/l)</pr>,
<pos>a.</pos></wordforms><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Radiotelegram</ent><br/
<hw>Ra`di*o*tel"e*gram</hw>
<pr>(r<amac/`d<icr/*<ocr/*t<ecr/l"<esl/*gr<acr/m)</pr>, <pos>n.</pos>
<def>A message transmitted by radiotelegraph.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Radiotelegraph</ent><br/
<hw>Ra`di*o*tel"e*graph</hw>
<pr>(r<amac/`d<icr/*<ocr/*t<ecr/l"<esl/*gr<acr/f)</pr>, <pos>n.</pos>
<ety>[<ets>Radio-</ets> + <ets>telegraph</ets>.]</ety> <def>A wireless
telegraph.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Radiotelegraphic</ent><br/
<hw>Ra`di*o*tel`e*graph"ic</hw>
<pr>(r<amac/`d<icr/*<ocr/*t<ecr/l`<esl/*gr<acr/f"<icr/k)</pr>,
<pos>a.</pos> <def>Of or pertaining to radiotelegraphy; employing, or
used or employed in, radiotelegraphy.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Radiotelegraphy</ent><br/
<hw>Ra`di*o*te*leg"ra*phy</hw>
<pr>(r<amac/`d<icr/*<ocr/*t<ecr/*l<ecr/g"r<adot/*f<ycr/)</pr>,
<pos>n.</pos> <ety>[<ets>Radio-</ets> + <ets>telegraphy</ets>.]</ety>
<def>Telegraphy using the radiant energy of radio waves; wireless
telegraphy; -- the term adopted for use by the Radiotelegraphic
Convention of 1912.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Radiotelephone</ent><br/
<hw>Ra`di*o*tel"e*phone</hw>
<pr>(r<amac/`d<icr/*<ocr/*t<ecr/l"<esl/*f<omac/n)</pr>, <pos>n.</pos>
<def>A wireless telephone, in which the signal is conveyed by radio
waves.</def> -- <wordforms><wf>Ra`di*o*te*leph"o*ny</wf> <pr>(#)</pr>,
<pos>n.</pos></wordforms><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Radiotherapy</ent><br/
<hw>Ra`di*o*ther"a*py</hw>
<pr>(r<amac/`d<icr/*<ocr/*th<ecr/r"<adot/*p<ycr/)</pr>, <pos>n.</pos>
<ety>[<ets>Radio-</ets> + <ets>therapy</ets>.]</ety> <fld>(Med.)</fld>
<def>Treatment of disease by means of x-rays or radioactivity.
Radiotherapy of cancer is based on the fact that cancer cells are more
sensitive to radiation than most other cells in the body.</def><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><ent>radiothorium</ent><br/
<hw>ra`di*o*tho"ri*um</hw>
<pr>(r<amac/`d<icr/*<ocr/*th<ocir/r"<emac/*<ucr/m)</pr>, <pos>n.</pos>
<fld>(Chem.)</fld> <def>an earlier name for the thorium isotope
<altname>thorium-228</altname>, given by its discoverer <person>Otto
Hahn</person>. It is a radioactive substance formed as one of series of
products in the chain of radioactive decay of thorium. Its immediate
predecessor in the chain is Actinium-228, and it decays by alpha
emission to radium-224 with a half-life of 1.91 years. The name
<ex>radiothorium</ex> was given prior to the full understanding of the
nature of isotopes of elements.</def><br/
[<source>PJC</source>]</p>

<p><ent>radious</ent><br/
<hw>ra"di*ous</hw> <pr>(r<amac/"d<icr/*<ucr/s)</pr>, <pos>a.</pos>
<ety>[L. <ets>radiosus</ets>.]</ety> <sn>1.</sn> <def>Consisting of
rays, as light.</def> <mark>[R.]</mark> <rj><au>Berkeley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Radiating; radiant.</def> <mark>[Obs.]</mark>
<rj><au>G. Fletcher.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Radish</ent><br/
<hw>Rad"ish</hw> <pr>(r<acr/d"<icr/sh)</pr>, <pos>n.</pos> <ety>[F.
<ets>radis</ets>; cf. It. <ets>radice</ets>, Pr. <ets>raditz</ets>: all
fr. L. <ets>radix</ets>, <ets>-icis</ets>, a root, an edible root,
especially a radish, akin to E. <ets>wort</ets>. See <er>Wort</er>, and
cf. <er>Eradicate</er>, <er>Race</er> a root, <er>Radix</er>.]</ety>
<fld>(Bot.)</fld> <def>The pungent fleshy root of a well-known
cruciferous plant (<spn>Raphanus sativus</spn>); also, the whole
plant.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Radish fly</b></col> <fld>(Zool.)</fld>, <cd>a small
two-winged fly (<spn>Anthomyia raphani</spn>) whose larvae burrow in
radishes. It resembles the onion fly.</cd> -- <col><b>Rat-tailed
radish</b></col> <fld>(Bot.)</fld>, <cd>an herb (<spn>Raphanus
caudatus</spn>) having a long, slender pod, which is sometimes
eaten.</cd> -- <col><b>Wild radish</b></col> <fld>(Bot.)</fld>, <cd>the
jointed charlock.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Radium</ent><br/
<hw>Ra`di*um</hw> <pr>(r<amac/"d<icr/*<ucr/m)</pr>, <pos>n.</pos>
<ety>[NL., fr. L. <ets>radius</ets> ray.]</ety> <fld>(Chem.)</fld>
<def>An intensely radioactive metallic element found (combined) in
minute quantities in pitchblende, and various other uranium minerals.
Symbol, <it>Ra</it>; atomic weight, 226.4. Radium was discovered by M.
and <person>Mme. Curie</person>, of Paris, who in 1902 separated
compounds of it by a tedious process from pitchblende. Its compounds
color flames carmine and give a characteristic spectrum. It is divalent,
resembling barium chemically. The main isotope of radium found in
pitchblende, radium-226, has a half-life of 1620 years, decaying first
by alpha emission to <er>radon</er>.</def> <note>Radium preparations are
remarkable for maintaining themselves at a higher temperature than their
surroundings, and for their radiations, which are of three kinds:
<emits>alpha rays</emits>, <emits>beta rays</emits>, and <emits>gamma
rays</emits> (see these terms). The beta and gamma rays seen in radium
preparations are in fact due to disintegration of decay products of
radium rather than the radium itself. By reason of these rays they
ionize gases, affect photographic plates, cause sores on the skin, and
produce many other striking effects. Their degree of activity depends on
the proportion of radium present, but not on its state of chemical
combination or on external conditions. The radioactivity of radium is
therefore an atomic property, and is due to an inherent instability of
the atomic nucleus which causes its decay in a process whose rate is
first order. The disintegration of the radium nucleus is only the first
in a series of nuclear disintegrations leading to production of a series
of elements and isotopes. The chain has at least seven stages; the
successive main products have been studied and are <er>radon</er>, a
gaseous radioactive element belonging chemically to the inert noble gas
series (originally called <ecol><b>radium emanation</b></ecol> or
<ecol><b>exradio</b></ecol>, <ecol><b>radium A</b></ecol>,
<ecol><b>radium B</b></ecol>, <ecol><b>radium C</b></ecol>, etc. The
successive products are unstable isotopes of several different elements,
each with an atomic weight a little lower than its predecessor. Lead is
the stable end product. At the same time, the light gas helium is
formed, being generated when the expelled alpha particles (positively
charged helium nuclei) acquire electrons. Radium, in turn, is formed in
the pitchblende ore by a slow disintegration of uranium. Natural radium
and also an isotope (radium-228, also called mesothorium I) formed by
the decay of thorium, were at one time used to make a luminous paint for
watch dials, until the danger of the radioactivity became fully
appreciated, and use of such material in watches was discontinued. See
also <er>mesothorium</er>.</note><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><ent>Radius</ent><br/
<hw>Ra"di*us</hw> <pr>(r<amac/"d<icr/*<ucr/s)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> L. <plw>Radii</plw> <pr>(r<amac/"d<icr/*<imac/)</pr>;
E. <plw>Radiuses</plw> <pr>(r<amac/"d<icr/*<ucr/s*<ecr/z)</pr>.</plu>
<ety>[L., a staff, rod, spoke of a wheel, radius, ray. See <er>Ray</er>
a divergent line.]</ety> <sn>1.</sn> <fld>(Geom.)</fld> <def>A right
line drawn or extending from the center of a circle to the periphery;
the semidiameter of a circle or sphere.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Anat.)</fld> <def>The preaxial bone of the forearm,
or brachium, corresponding to the tibia of the hind limb. See
<xex>Illust.</xex> of <er>Artiodactyla</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The radius is on the same side of the limb as the thumb,
or pollex, and in man it is so articulated that its lower end is capable
of partial rotation about the ulna.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Bot.)</fld> <def>A ray, or outer floret, of the
capitulum of such plants as the sunflower and the daisy. See
<er>Ray</er>, 2.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <pluf>pl.</pluf> <fld>(Zool.)</fld> <sd>(a)</sd> <def>The
barbs of a perfect feather.</def> <sd>(b)</sd> <def>Radiating organs, or
color-markings, of the radiates.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>The movable limb of a sextant or other angular
instrument.</def> <rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Radius bar</b></col> <fld>(Mach.)</fld>, <cd>a bar
pivoted at one end, about which it swings, and having its other end
attached to a piece which it causes to move in a circular arc.</cd> --
<col><b>Radius of curvature</b></col>. <cd>See under
<er>Curvature</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Radius vector</ent><br/
\'d8<hw>Ra"di*us vec"tor</hw> <pr>(v<ecr/k"t<ocr/r)</pr>. <sn>1.</sn>
<fld>(Math.)</fld> <def>A straight line (or the length of such line)
connecting any point, as of a curve, with a fixed point, or pole, round
which the straight line turns, and to which it serves to refer the
successive points of a curve, in a system of polar coordinates. See
<er>Coordinate</er>, <pos>n.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Astron.)</fld> <def>An ideal straight line joining
the center of an attracting body with that of a body describing an orbit
around it, as a line joining the sun and a planet or comet, or a planet
and its satellite.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Radix</ent><br/
<hw>Ra"dix</hw> <pr>(r<amac/"d<icr/ks)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> L. <plw>Radices</plw>
<pr>(r<acr/d"<icr/*s<emac/z)</pr>, E. <plw>Radixes</plw>
<pr>(r<amac/"d<icr/ks*<ecr/z)</pr>.</plu> <ety>[L. <ets>radix</ets>,
<ets>-icis</ets>, root. See <er>Radish</er>.]</ety> <sn>1.</sn>
<fld>(Philol.)</fld> <def>A primitive word, from which spring other
words; a radical; a root; an etymon.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Math.)</fld> <sd>(a)</sd> <def>A number or quantity
which is arbitrarily made the fundamental number of any system; a base.
<as>Thus, 10 is the <ex>radix</ex>, or base, of the common system of
logarithms, and also of the decimal system of numeration</as>.</def>
<sd>(b)</sd> <fld>(Alg.)</fld> <def>A finite expression, from which a
series is derived.</def> <mark>[R.]</mark> <rj><au>Hutton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Bot.)</fld> <def>The root of a plant.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Radon</ent><br/
<hw>Ra"don</hw> <pr>(r<amac/"d<ocr/n)</pr>, <pos>n.</pos>
<fld>(Chem.)</fld> <def>An intensely radioactive gaseous element
produced by the radioactive decay of radium-226, which is the main
isotope of radium found in pitchblende. Chemically it is an inert noble
gas. Its atomic symbol is <it>Rn</it>. It has an atomic number of 86.
The radon isotope produced by decay of radium has an atomic weight of
222.017, and this isotope decays by alpha emission with a half-life of
3.82 days. Numerous other isotopes have been observed, all radioactive
and all having half-lives shorter than that of radon-222. Radon was
discovered by M. and Mme. Curie, of Paris, in their studies of the
radioactive substances in pitchblende. Radon was originally called
<altname>radium emanation</altname> or
<altname>exradio</altname>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Radula</ent><br/
\'d8<hw>Rad"u*la</hw> <pr>(r<acr/d"<usl/*l<adot/)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Radulae</plw>
<pr>(r<acr/d"<usl/*l<emac/)</pr>.</plu> <ety>[L., a scraper, fr.
<ets>radere</ets> to scrape.]</ety> <fld>(Zool.)</fld> <def>The
chitinous ribbon bearing the teeth of mollusks; -- called also
<altname>lingual ribbon</altname>, and <altname>tongue</altname>. See
<er>Odontophore</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raduliform</ent><br/
<hw>Ra*du"li*form</hw> <pr>(r<adot/*d<umac/"l<icr/*f<ocir/rm)</pr>,
<pos>a.</pos> <ety>[L. <ets>radula</ets> a scraper +
<ets>-form</ets>.]</ety> <def>Rasplike; <as>as, <ex>raduliform</ex>
teeth</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raff</ent><br/
<hw>Raff</hw> <pr>(r<adot/f)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Raffed</conjf> <pr>(r<adot/ft)</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>Raffing</conjf>.]</vmorph> <ety>[OF.
<ets>raffer</ets>, of German origin; cf. G. <ets>raffen</ets>; akin to
E. <ets>rap</ets> to snatch. See <er>Rap</er>, and cf.
<er>Riffraff</er>, <er>Rip</er> to tear.]</ety> <def>To sweep, snatch,
draw, or huddle together; to take by a promiscuous sweep.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Causes and effects which I thus <qex>raff</qex> up together.</q>
<rj><qau>Carew.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raff</ent><br/
<hw>Raff</hw>, <pos>n.</pos> <sn>1.</sn> <def>A promiscuous heap; a
jumble; a large quantity; lumber; refuse.</def> <ldquo/A <xex>raff</xex>
of errors.<rdquo/ <rj><au>Barrow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The sweepings of society; the rabble; the mob; --
chiefly used in the compound or duplicate,
<xex>riffraff</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A low fellow; a churl.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Raff merchant</b></col>, <cd>a dealer in lumber and odd
refuse.</cd> <mark>[Prov. Eng.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raffaelesque</ent><br/
<hw>Raf`fa*el*esque"</hw> <pr>(r<acr/f`f<adot/*<ecr/l*<ecr/sk")</pr>,
<pos>a.</pos> <def>Raphaelesque.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raffia</ent><br/
<hw>Raf"fi*a</hw> <pr>(r<acr/f"f<icr/*<adot/)</pr>, <pos>n.</pos>
<fld>(Bot.)</fld> <def>A fibrous material used for tying plants, said to
come from the leaves of a palm tree of the genus
<gen>Raphia</gen>.</def> <rj><au>J. Smith (Dict. Econ.
Plants).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raffia palm</ent><br/
<hw>Raf"fi*a palm</hw> <pr>(r<acr/f"f<icr/*<adot/ p<aum/m`)</pr>.
<sd>(a)</sd> <def>A pinnate-leaved palm (<spn>Raphia ruffia</spn>)
native of Madagascar, and of considerable economic importance on account
of the strong fiber (raffia) obtained from its leafstalks.</def>
<sd>(b)</sd> <def>The jupati palm.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Raffinose</ent><br/
<hw>Raf"fi*nose`</hw> <pr>(r<acr/f"f<icr/*n<omac/s`)</pr>, <pos>n.</pos>
<ety>[F. <ets>raffiner</ets> to refine.]</ety> <fld>(Chem.)</fld> <def>A
colorless crystalline slightly sweet substance obtained from the
molasses of the sugar beet.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raffish</ent><br/
<hw>Raff"ish</hw> <pr>(r<adot/f"<icr/sh)</pr>, <pos>a.</pos>
<def>Resembling, or having the character of, raff, or a raff; worthless;
low.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A sad, <qex>raffish</qex>, disreputable character.</q>
<rj><qau>Thackeray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Mildly disreputable; disregarding conventional
morality; charmingly dissolute{3} or nonconformist.</def><br/
[<source>PJC</source>]</p>

<p><q>Tales of his [Ted Kennedy's] drinking and <qex>raffish</qex>
behavior have become part of his public persona, often lumped under a
vaster damnation known as <ldquo/the character issue<rdquo/.<br/
. . .<br/
He appears to compartmentalize his off-duty conduct and his Senate
responsibilities; during dozens of interviews for this article, with
friends and foes, not one could cite an instance in which drinking
appeared to impair him professionally. His adversaries grumble about it
anyway; friends portray it as relatively harmless and charming.<br/
<br/
<person>Orrin Hatch</person>, the conservative Utah Republican who is
also a Mormon, tells this story with what he describes as <ldquo/a
tremendous brotherly affection.<rdquo/ Two days before the Senate
adjourned in October 1988, <persfn>Hatch</persfn> took a call from
<person>Frank Madsen</person>, a former aide who had moved to
<city>Boston</city> to supervise 200 young Mormon missionaries. Would
<persfn>Hatch</persfn> come speak to them? Would he bring
<persfn>Kennedy</persfn>? Would he ask <persfn>Kennedy</persfn> to
reserve Faneuil Hall for the event?<br/
<br/
With some misgivings, Hatch agreed to try. Shortly before midnight, he
found <persfn>Kennedy</persfn> and <person>Chris Dodd</person> in the
Capitol. Neither was feeling any pain.<br/
<br/
<ldquo/Ted, I've got a favor to ask.<rdquo/<br/
<br/
Kennedy wrapped an arm around Hatch. <ldquo/Done!<rdquo/<br/
<br/
Hatch held up a restraining hand. <ldquo/No, hear me out. You remember
my aide, Frank Madsen -- <rdquo/<br/
<br/
<ldquo/Great fellow! Great fellow!<rdquo/<br/
<br/
<ldquo/He's now in Boston -- <rdquo/<br/
<br/
<ldquo/My home town! My home town!<rdquo/<br/
<br/
<persfn>Hatch</persfn> eventually made his request.
<persfn>Kennedy</persfn> assented. Hatch returned to his office, typed
out the agreement and sent it to Kennedy's office. The next day, Hatch
spied Kennedy reading the memo. <ldquo/Orrin,<rdquo/ Kennedy called in
mock horror, <ldquo/what else did I agree to?<rdquo/ Three months later,
in January 1989, Hatch and Kennedy stood elbow-to-elbow in Faneuil Hall,
addressing the Mormon missionaries.</q> <qau>Rick Atkinson, Washington
Post, Sept. 29, 1990</qau><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>Dissolute; rakish.</def><br/
[<source>PJC</source>]</p>

<p><q> Of all such places, <city>Santa Fe</city> may well be the least
<qex>raffish</qex>. At least in the off-season, it's a town that goes to
bed early, showing all the prudent reserve of a city of bankers and
claims adjusters. In the historic center, a visitor searches in vain for
tawdry traces of the hard-drinking, wild-womanizing, heavy-gambling
cowboy town this once must have been.</q> <qau>Brad Leithauser
(<ldquo/Santa Fe<rdquo/, in New York Times Magazine / May 13,
2001).</qau><br/
[<source>PJC</source>]</p>

<p><q> Over the years, it [Macau] has maintained a downright
<qex>raffish</qex> atmosphere, complete with warring gangsters.</q>
<qau>Yvette Ziols.</qau><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <def>Vulgarly gaudy; cheap and tawdry; <as>as, a tendency
toward gaudy jewelry, bright colors and generally <ex>raffish</ex>
dress</as>.</def><br/
[<source>PJC</source>]</p>

<p><q> A lonely orphan, Lilli, lands a job with a <qex>raffish</qex> and
run-down carnival. The wide-eyed and innocent orphan is mesmerized by
its gritty, tawdry glamour.</q> <qau>Anonymous review of the play
<i>Carnival</i>
(https://web.archive.org/web/20040904064952/http://www.kt-online.org/plays/02-carnival-frame.html)</qau><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <def>Appealing to or frequented by dissolute or
disreputable people; <as>as, a <ex>raffish</ex> night
club</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Raffle</ent><br/
<hw>Raf"fle</hw> <pr>(r<acr/f"f'l)</pr>, <pos>n.</pos> <ety>[F.
<ets>rafle</ets>; <ets>faire rafle</ets> to sweep stakes, fr.
<ets>rafler</ets> to carry or sweep away, <ets>rafler tout</ets> to
sweep stakes; of German origin; cf. G. <ets>raffeln</ets> to snatch up,
to rake. See <er>Raff</er>, <pos>v.</pos>]</ety> <sn>1.</sn> <def>A kind
of lottery, in which several persons pay, in shares, the value of
something put up as a stake, and then determine by chance (as by casting
dice) which one of them shall become the sole possessor.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A game of dice in which he who threw three alike won
all the stakes.</def> <mark>[Obs.]</mark>
<rj><au>Cotgrave.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raffle</ent><br/
<hw>Raf"fle</hw> <pr>(r<acr/f"f'l)</pr>, <pos>n.</pos> <ety>[See
<er>Raff</er>, <pos>n. & v.</pos>, and <er>Raffle</er>.]</ety>
<def>Refuse; rubbish; raff.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Raffle</ent><br/
<hw>Raf"fle</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Raffled</conjf> <pr>(r<acr/f"f'ld)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Raffling</conjf> <pr>(r<acr/f"fl<icr/ng)</pr>.]</vmorph>
<def>To engage in a raffle; <as>as, to <ex>raffle</ex> for a
watch</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raffle</ent><br/
<hw>Raf"fle</hw>, <pos>v. t.</pos> <def>To dispose of by means of a
raffle; -- often followed by <xex>off</xex>; <as>as, to <ex>raffle</ex>
off a horse</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raffler</ent><br/
<hw>Raf"fler</hw> <pr>(r<acr/f"fl<etil/r)</pr>, <pos>n.</pos> <def>One
who raffles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rafflesia</ent><br/
\'d8<hw>Raf*fle"si*a</hw> <pr>(r<acr/f*fl<emac/"zh<icr/*<adot/)</pr>,
<pos>n.</pos> <ety>[NL. Named from its discoverer, <person>Sir S.
<etsep>Raffles</etsep></person>.]</ety> <fld>(Bot.)</fld> <def>A genus
of stemless, leafless plants, living parasitically upon the roots and
stems of grapevines in Malaysia. The flowers have a carrionlike odor,
and are very large, in one species (<spn>Rafflesia Arnoldi</spn>) having
a diameter of two or three feet.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raft</ent><br/
<hw>Raft</hw> <pr>(r<adot/ft)</pr>, <mark>obs.</mark> <def><pos>imp. &
p. p.</pos> of <er>Reave</er>.</def> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raft</ent><br/
<hw>Raft</hw>, <pos>n.</pos> <ety>[Originally, a rafter, spar, and fr.
Icel. <ets>raptr</ets> a rafter; akin to Dan. <ets>raft</ets>, Prov. G.
<ets>raff</ets> a rafter, spar; cf. OHG. <ets>r<amac/fo</ets>,
<ets>r<amac/vo</ets>, a beam, rafter, Icel. <ets>r<amac/f</ets> roof.
Cf. <er>Rafter</er>, <pos>n.</pos>]</ety> <sn>1.</sn> <def>A collection
of logs, boards, pieces of timber, or the like, fastened together,
either for their own collective conveyance on the water, or to serve as
a support in conveying other things; a float.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A collection of logs, fallen trees, etc. (such as is
formed in some Western rivers of the United States), which obstructs
navigation.</def> <mark>[U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <ety>[Perhaps akin to <ets>raff</ets> a heap.]</ety>
<def>A large collection of people or things taken
indiscriminately.</def> <mark>[Slang, U. S.]</mark> <ldquo/A whole
<xex>raft</xex> of folks.<rdquo/ <rj><au>W. D. Howells.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Raft bridge</b></col>. <sd>(a)</sd> <cd>A bridge whose
points of support are rafts</cd>. <sd>(b)</sd> <cd>A bridge that
consists of floating timbers fastened together.</cd> -- <col><b>Raft
duck</b></col>. <ety>[The name alludes to its swimming in dense
flocks.]</ety> <fld>(Zool.)</fld> <sd>(a)</sd> <cd>The bluebill, or
greater scaup duck; -- called also <altname>flock duck</altname>. See
<er>Scaup</er>.</cd> <sd>(b)</sd> <cd>The redhead.</cd> -- <col><b>Raft
port</b></col> <fld>(Naut.)</fld>, <cd>a large, square port in a
vessel's side for loading or unloading timber or other bulky articles; a
timber or lumber port.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raft</ent><br/
<hw>Raft</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Rafted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Rafting</conjf>.]</vmorph> <def>To transport on a raft, or in the
form of a raft; to make into a raft; <as>as, to <ex>raft</ex>
timber</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rafte</ent><br/
<hw>Raf"te</hw> <pr>(r<adot/f"t<eit/)</pr>, <mark>obs.</mark>
<def><pos>imp.</pos> of <er>Reave</er>.</def>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rafter</ent><br/
<hw>Raft"er</hw> <pr>(r<adot/ft"<etil/r)</pr>, <pos>n.</pos> <def>A
raftsman.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rafter</ent><br/
<hw>Raft"er</hw>, <pos>n.</pos> <ety>[AS. <ets>r<ae/fter</ets>; akin to
E. <ets>raft</ets>, n. See <er>Raft</er>.]</ety> <fld>(Arch.)</fld>
<def>Originally, any rough and somewhat heavy piece of timber. Now,
commonly, one of the timbers of a roof which are put on sloping,
according to the inclination of the roof. See <xex>Illust.</xex> of
<er>Queen-post</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>[Courtesy] oft is sooner found in lowly sheds,<br/
With smoky <qex>rafters</qex>, than in tapestry halls.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rafter</ent><br/
<hw>Raft"er</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To make into
rafters, as timber.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To furnish with rafters, as a house.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Agric.)</fld> <def>To plow so as to turn the grass
side of each furrow upon an unplowed ridge; to ridge.</def>
<mark>[Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rafting</ent><br/
<hw>Raft"ing</hw>, <pos>n.</pos> <def>The business of making or managing
rafts.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raftsman</ent><br/
<hw>Rafts"man</hw> <pr>(r<adot/fts"m<ait/n)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Raftsmen</plw>
<pr>(r<adot/fts"m<eit/n)</pr>.</plu> <def>A man engaged in
rafting.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rafty</ent><br/
<hw>Raf"ty</hw> <pr>(r<adot/f"t<ycr/)</pr>, <pos>a.</pos> <ety>[Perhaps
akin to G. <ets>reif</ets> hoarfrost.]</ety> <def>Damp; musty.</def>
<mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rag</ent><br/
<hw>Rag</hw> <pr>(r<acr/g)</pr>, <pos>v. t.</pos> <ety>[Cf. Icel.
<ets>r<ae/gja</ets> to calumniate, OHG. <ets>ruogen</ets> to accuse, G.
<ets>r<uum/gen</ets> to censure, AS. <ets>wr<emac/gan</ets>, Goth.
<ets>wr<omac/hjan</ets> to accuse.]</ety> <def>To scold or rail at; to
rate; to tease; to torment; to banter.</def> <mark>[Prov. Eng.]</mark>
<rj><au>Pegge.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rag</ent><br/
<hw>Rag</hw>, <pos>n.</pos> <ety>[OE. <ets>ragge</ets>, probably of
Scand, origin; cf. Icel. <ets>r<oum/gg</ets> a tuft, shagginess, Sw.
<ets>ragg</ets> rough hair. Cf. <er>Rug</er>, <pos>n.</pos>]</ety>
<sn>1.</sn> <def>A piece of cloth torn off; a tattered piece of cloth; a
shred; a tatter; a fragment.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Cowls, hoods, and habits, with their wearers, tossed,<br/
And fluttered into <qex>rags</qex>.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Not having otherwise any <qex>rag</qex> of legality to cover the
shame of their cruelty.</q> <rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <pluf>pl.</pluf> <def>Hence, mean or tattered attire;
worn-out dress.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And virtue, though in <qex>rags</qex>, will keep me warm.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A shabby, beggarly fellow; a ragamuffin.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The other zealous <qex>rag</qex> is the compositor.</q>
<rj><qau>B. Jonson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Upon the proclamation, they all came in, both tag and
<qex>rag</qex>.</q> <rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Geol.)</fld> <def>A coarse kind of rock, somewhat
cellular in texture.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Metal Working)</fld> <def>A ragged edge.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>A sail, or any piece of canvas.</def>
<mark>[Nautical Slang]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Our ship was a clipper with every <qex>rag</qex> set.</q>
<rj><qau>Lowell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Rag bolt</b></col>, <cd>an iron pin with barbs on its
shank to retain it in place.</cd> -- <col><b>Rag carpet</b></col>, <cd>a
carpet of which the weft consists of narrow strips of cloth sewed
together, end to end.</cd> -- <col><b>Rag dust</b></col>, <cd>fine
particles of ground-up rags, used in making papier-mach<eacute/ and wall
papers.</cd> -- <col><b>Rag wheel</b></col>. <sd>(a)</sd> <cd>A chain
wheel; a sprocket wheel</cd>. <sd>(b)</sd> <cd>A polishing wheel made of
disks of cloth clamped together on a mandrel.</cd> -- <col><b>Rag
wool</b></col>, <cd>wool obtained by tearing woolen rags into fine bits,
shoddy.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rag</ent><br/
<hw>Rag</hw> <pr>(r<acr/g)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Ragged</conjf> <pr>(r<acr/gd)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Ragging</conjf> <pr>(r<acr/g"g<icr/ng)</pr>.]</vmorph>
<def>To become tattered.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rag</ent><br/
<hw>Rag</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To break (ore) into
lumps for sorting.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To cut or dress roughly, as a grindstone.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rag</ent><br/
<hw>Rag</hw>, <pos>v. t.</pos> <sn>1.</sn> <fld>(Music)</fld> <def>To
play or compose (a piece, melody, etc.) in syncopated time.</def>
<mark>[Colloq.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>To dance to ragtime music, esp. in some manner
considered indecorous.</def> <mark>[Colloq. or Slang]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Ragabrash</ent><br/
<ent>Ragabash</ent><br/
<mhw>{ <hw>Rag"a*bash`</hw> <pr>(r<acr/g"<adot/*b<acr/sh`)</pr>,
<hw>Rag"a*brash`</hw> <pr>(r<acr/g"<adot/*br<acr/sh`)</pr>, }</mhw>
<pos>n.</pos> <def>An idle, ragged person.</def> <rj><au>Nares.</au>
<au>Grose.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ragamuffin</ent><br/
<hw>Rag`a*muf"fin</hw> <pr>(r<acr/g`<adot/*m<ucr/f"f<icr/n)</pr>,
<pos>n.</pos> <ety>[Cf. <ets>Ragamofin</ets>, the name of a demon in
some of the old mysteries.]</ety> <sn>1.</sn> <def>A paltry or
disreputable fellow; a mean wretch.</def> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A person who wears ragged clothing.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <def>The long-tailed titmouse.</def>
<mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rage</ent><br/
<hw>Rage</hw> <pr>(r<amac/j)</pr>, <pos>n.</pos> <ety>[F., fr. L.
<ets>rabies</ets>, fr. <ets>rabere</ets> to rave; cf. Skr.
<ets>rabh</ets> to seize, <ets>rabhas</ets> violence. Cf.
<er>Rabid</er>, <er>Rabies</er>, <er>Rave</er>.]</ety> <sn>1.</sn>
<def>Violent excitement; eager passion; extreme vehemence of desire,
emotion, or suffering, mastering the will.</def> <ldquo/In great
<xex>rage</xex> of pain.<rdquo/ <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He appeased the <qex>rage</qex> of hunger with some scraps of
broken meat.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Convulsed with a <qex>rage</qex> of grief.</q>
<rj><qau>Hawthorne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Especially, anger accompanied with raving;
overmastering wrath; violent anger; fury.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>torment, and loud lament, and furious <qex>rage</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A violent or raging wind.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The subject of eager desire; that which is sought
after, or prosecuted, with unreasonable or excessive passion; <as>as, to
be all the <ex>rage</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Anger; vehemence; excitement; passion; fury. See
<er>Anger</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rage</ent><br/
<hw>Rage</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Raged</conjf> <pr>(r<amac/jd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Raging</conjf> <pr>(r<amac/"j<icr/ng)</pr>.]</vmorph> <ety>[OF.
<ets>ragier</ets>. See <er>Rage</er>, <pos>n.</pos>]</ety> <sn>1.</sn>
<def>To be furious with anger; to be exasperated to fury; to be
violently agitated with passion.</def> <ldquo/Whereat he inly
<xex>raged</xex>.<rdquo/ <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>When one so great begins to <qex>rage</qex>, he is hunted<br/
Even to falling.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Rage</qex>, <qex>rage</qex> against the dying of the
light<br/
Do not go gentle into that good night.</q> <rj><qau>Dylan
Thomas.</qau></rj><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>To be violent and tumultuous; to be violently driven
or agitated; to act or move furiously; <as>as, the <ex>raging</ex> sea
or winds</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Why do the heathen <qex>rage</qex>?</q> <rj><qau>Ps. ii.
1.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The madding wheels<br/
Of brazen chariots <qex>raged</qex>; dire was the noise.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To ravage; to prevail without restraint, or with
destruction or fatal effect; <as>as, the plague <ex>raged</ex> in
Cairo</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To toy or act wantonly; to sport.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To storm; fret; chafe; fume.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rage</ent><br/
<hw>Rage</hw>, <pos>v. t.</pos> <def>To enrage.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rageful</ent><br/
<hw>Rage"ful</hw> <pr>(r<amac/j"f<usdot/l)</pr>, <pos>a.</pos> <def>Full
of rage; expressing rage.</def> <mark>[Obs.]</mark>
<ldquo/<xex>Rageful</xex> eyes.<rdquo/ <rj><au>Sir P.
Sidney.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ragery</ent><br/
<hw>Ra"ger*y</hw> <pr>(r<amac/"j<etil/r*<ycr/)</pr>, <pos>n.</pos>
<def>Wantonness.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ragged</ent><br/
<hw>Rag"ged</hw> <pr>(r<acr/g"g<ecr/d)</pr>, <pos>a.</pos> <ety>[From
<er>Rag</er>, <pos>n.</pos>]</ety> <sn>1.</sn> <def>Rent or worn into
tatters, or till the texture is broken; <as>as, a <ex>ragged</ex> coat;
a <ex>ragged</ex> sail.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Broken with rough edges; having jags; uneven; rough;
jagged; <as>as, <ex>ragged</ex> rocks</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Hence, harsh and disagreeable to the ear;
dissonant.</def> <mark>[R.]</mark> <ldquo/A <xex>ragged</xex> noise of
mirth.<rdquo/ <rj><au>Herbert.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Wearing tattered clothes; <as>as, a <ex>ragged</ex>
fellow</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Rough; shaggy; rugged.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>What shepherd owns those <qex>ragged</qex> sheep?</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Ragged lady</b></col> <fld>(Bot.)</fld>, <cd>the fennel
flower (<spn>Nigella Damascena</spn>).</cd> -- <col><b>Ragged
robin</b></col> <fld>(Bot.)</fld>, <cd>a plant of the genus
<gen>Lychnis</gen> (<spn>Lychnis Flos-cuculi</spn>), cultivated for its
handsome flowers, which have the petals cut into narrow lobes.</cd> --
<col><b>Ragged sailor</b></col> <fld>(Bot.)</fld>, <cd>prince's feather
(<spn>Polygonum orientale</spn>).</cd> -- <col><b>Ragged
school</b></col>, <cd>a free school for poor children, where they are
taught and in part fed; -- a name given at first because they came in
their common clothing.</cd> <mark>[Eng.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Rag"ged*ly</wf>, <pos>adv.</pos> --
<wf>Rag"ged*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raggy</ent><br/
<ent>Raggie</ent><br/
<mhw>{ <hw>Rag"gie</hw> <pr>(r<acr/g"g<icr/)</pr>, <it>or</it>
<hw>Rag"gy</hw> }</mhw>, <pos>a.</pos> <def>Ragged; rough.</def>
<mark>[Obs.]</mark> <ldquo/A stony and <xex>raggie</xex> hill.<rdquo/
<rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raghuvansa</ent><br/
\'d8<hw>Ragh`u*van"sa</hw> <pr>(r<ucr/g`<usdot/*v<ucr/n"s<adot/)</pr>,
<pos>n.</pos> <ety>[Skr. <ets>Raguva<msdot/<cced/a</ets>.]</ety> <def>A
celebrated Sanskrit poem having for its subject the Raghu
dynasty.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raging</ent><br/
<hw>Ra"ging</hw> <pr>(r<amac/"j<icr/ng)</pr>, <def><pos>a. & n.</pos>
from <er>Rage</er>, <pos>v. i.</pos></def> --
<wordforms><wf>Ra"ging*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ragious</ent><br/
<hw>Ra"gious</hw> <pr>(r<amac/"j<ucr/s)</pr>, <pos>a.</pos> <def>Raging;
furious; rageful.</def> <mark>[Obs.]</mark> --
<wordforms><wf>Ra"gious*ness</wf>, <pos>n.</pos>
<mark>[Obs.]</mark></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raglan</ent><br/
<hw>Rag"lan</hw> <pr>(r<acr/g"l<ait/n)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>A loose overcoat with large sleeves; -- named after <person>Lord
<etsep>Raglan</etsep></person>, an English general who was an
aide-de-camp to <persfn>Wellington</persfn> at Waterlooo.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An overcoat with <er>raglan sleeves</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>raglan sleeve</ent><br/
<hw>rag"lan sleeve`</hw> <pr>(r<acr/g"l<ait/n sl<emac/v`)</pr>,
<pos>n.</pos> <def>A sleeve joined to the body of a garment by a long
slanting seam starting at the neck and continuing around the armhole.
Contrasted to a <er>set-in sleeve</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Ragman</ent><br/
<hw>Rag"man</hw> <pr>(r<acr/g"m<ait/n)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Ragmen</plw> <pr>(r<acr/g"m<eit/n)</pr>.</plu>
<def>A man who collects, or deals in, rags.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ragman</ent><br/
<hw>Rag"man</hw>, <pos>n.</pos> <ety>[See <er>Ragman's roll</er>.]</ety>
<def>A document having many names or numerous seals, as a papal
bull.</def> <mark>[Obs.]</mark> <rj><au>Piers Plowman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ragman's roll</ent><br/
<hw>Rag"man's roll`</hw> <pr>(r<acr/g"m<ait/nz r<omac/l`)</pr>.
<ety>[For <ets>ragman roll</ets> a long list of names, the devil's roll
or list; where <ets>ragman</ets> is of Scand. origin; cf. Icel.
<ets>ragmenni</ets> a craven person, Sw. <ets>raggen</ets> the devil.
Icel. <ets>ragmenni</ets> is fr. <ets>ragr</ets> cowardly (another form
of <ets>argr</ets>, akin to AS. <ets>earg</ets> cowardly, vile, G.
<ets>arg</ets> bad) + <ets>menni</ets> (in comp.) man, akin to E.
<ets>man</ets>. See <er>Roll</er>, and cf. <er>Rigmarole</er>.]</ety>
<def>The rolls of deeds on parchment in which the Scottish nobility and
gentry subscribed allegiance to Edward I. of England, <sc>A. D.</sc>
1296.</def> <altsp>[Also written <asp>ragman-roll</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ragnarok</ent><br/
<ent>Ragnarok</ent><br/
<mhw>{ <hw>Rag"na*rok"</hw> <pr>(r<adot/"n<adot/*r<ocr/k")</pr>,
\'d8<hw>Rag"na*r<oum/k"</hw> <pr>(r<adot/"n<adot/*r<ucir/k")</pr>
}</mhw>, <pos>n.</pos> <ety>[Icel., fr. <ets>regin</ets>,
<ets>r<oum/gn</ets>, gods + <ets>r<oum/k</ets> reason, origin, history;
confused with <ets>ragna-r<oum/kr</ets> the twilight of the gods.]</ety>
<fld>(Norse Myth.)</fld> <def>The so-called <ldquo/Twilight of the
Gods<rdquo/ (called in German
<altname>G<oum/tterd<aum/mmerung</altname>), the final destruction of
the world in the great conflict between the Aesir (gods) on the one
hand, and on the other, the giants and the powers of Hel under the
leadership of Loki (who is escaped from bondage).</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Ragout</ent><br/
<hw>Ra*gout"</hw> <pr>(r<adot/*g<oomac/")</pr>, <pos>n.</pos> <ety>[F.
<ets>rago<ucir/t</ets>, fr. <ets>rago<ucir/ter</ets> to restore one's
appetite, fr. L. pref. <ets>re-</ets> re- + <ets>ad</ets> to +
<ets>gustare</ets> to taste, <ets>gustus</ets> taste. See <er>Gust</er>
relish.]</ety> <def>A dish made of pieces of meat, stewed, and highly
seasoned; <as>as, a <ex>ragout</ex> of mutton</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ragpicker</ent><br/
<hw>Rag"pick`er</hw> <pr>(r<acr/g"p<icr/k`<etil/r)</pr>, <pos>n.</pos>
<def>One who gets a living by picking up rags and refuse things in the
streets.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ragtime</ent><br/
<hw>Rag"time`</hw>, <pos>n.</pos> <fld>(Mus.)</fld> <def>a rhythm with a
regular accompaniment in two-four time and a melody characterized by
syncopation, first recognized in many negro melodies; also a style of
American music in this rhythm.</def><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><ent>Ragguled</ent><br/
<ent>Raguled</ent><br/
<mhw>{ <hw>Ra*guled"</hw> <pr>(r<adot/*g<umac/ld")</pr>,
<hw>Rag*guled"</hw> <pr>(r<acr/g*g<umac/ld")</pr>, }</mhw> <pos>a.</pos>
<ety>[Cf. F. <ets>raguer</ets> to chafe, fret, rub, or E.
<ets>rag</ets>.]</ety> <fld>(Her.)</fld> <def>Notched in regular
diagonal breaks; -- said of a line, or a bearing having such an
edge.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1185 pr=vmg --></p>

<p><ent>Ragweed</ent><br/
<hw>Rag"weed`</hw> <pr>(r<acr/g"w<emac/d`)</pr>, <pos>n.</pos>
<fld>(Bot.)</fld> <def>A common American composite weed (<spn>Ambrosia
artemisiaefolia</spn>) with finely divided leaves; hogweed.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Great ragweed</b></col>, <cd>a coarse American herb
(<spn>Ambrosia trifida</spn>), with rough three-lobed opposite
leaves.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ragwork</ent><br/
<hw>Rag"work`</hw> <pr>(r<acr/g"w<ucir/rk`)</pr>, <pos>n.</pos>
<fld>(Masonry)</fld> <def>A kind of rubblework. In the United States,
any rubblework of thin and small stones.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ragwort</ent><br/
<hw>Rag"wort`</hw> <pr>(r<acr/g"w<ucir/rt`)</pr>, <pos>n.</pos>
<fld>(Bot.)</fld> <def>A name given to several species of the composite
genus <gen>Senecio</gen>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <spn>Senecio aureus</spn> is the golden ragwort of the
United States; <spn>Senecio elegans</spn> is the purple ragwort of South
Africa.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raia</ent><br/
\'d8<hw>Ra"ia</hw> <pr>(r<amac/"y<adot/)</pr>, <pos>n.</pos> <ety>[L., a
ray. Cf. <er>Ray</er> the fish.]</ety> <fld>(Zool.)</fld> <def>A genus
of rays which includes the skates. See <er>Skate</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raiae</ent><br/
\'d8<hw>Ra"iae</hw> <pr>(r<amac/"y<emac/)</pr>, <pos>n. pl.</pos>
<ety>[NL. See <er>Raia</er>.]</ety> <fld>(Zool.)</fld> <def>The order of
elasmobranch fishes which includes the sawfishes, skates, and rays; --
called also <altname>Rajae</altname>, and
<altname>Rajii</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raid</ent><br/
<hw>Raid</hw> <pr>(r<amac/d)</pr>, <pos>n.</pos> <ety>[Icel.
<ets>rei<edh/</ets> a riding, raid; akin to E. <ets>road</ets>. See
<er>Road</er> a way.]</ety> <sn>1.</sn> <def>A hostile or predatory
incursion; an inroad or incursion of mounted men; a sudden and rapid
invasion by a cavalry force; a foray.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Marauding chief! his sole delight<br/
The moonlight <qex>raid</qex>, the morning fight.</q> <rj><qau>Sir W.
Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>There are permanent conquests, temporary occupations, and
occasional <qex>raids</qex>.</q> <rj><qau>H. Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ A Scottish word which came into common use in the United
States during the Civil War, and was soon extended in its
application.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An attack or invasion for the purpose of making
arrests, seizing property, or plundering; <as>as, a <ex>raid</ex> of the
police upon a gambling house; a <ex>raid</ex> of contractors on the
public treasury.</as></def> <mark>[Colloq. U. S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raid</ent><br/
<hw>Raid</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Raided</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Raiding</conjf>.]</vmorph> <def>To make a raid upon or into;
<as>as, two regiments <ex>raided</ex> the border
counties</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raider</ent><br/
<hw>Raid"er</hw> <pr>(r<amac/d"<etil/r)</pr>, <pos>n.</pos> <def>One who
engages in a raid.</def> <mark>[U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raiffeisen</ent><br/
<hw>Raif"fei`sen</hw> <pr>(r<imac/f"<imac/`z'n)</pr>, <pos>a.</pos>
<fld>(Economics)</fld> <def>Designating, or pertaining to, a form of
cooperative bank founded among the German agrarian population by
<person>Friedrich Wilhelm Raiffeisen</person> (1818-88); <as>as,
<ex>Raiffeisen</ex> banks, the <ex>Raiffeisen</ex> system, etc.</as> The
banks are unlimited-liability institutions making small loans at a low
rate of interest, for a designated purpose, to worthy members
only.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Rail</ent><br/
<hw>Rail</hw> <pr>(r<amac/l)</pr>, <pos>n.</pos> <ety>[OE.
<ets>reil</ets>, <ets>re<yogh/el</ets>, AS. <ets>hr<ae/gel</ets>,
<ets>hr<ae/gl</ets>, a garment; akin to OHG. <ets>hregil</ets>, OFries.
<ets>hreil</ets>.]</ety> <def>An outer cloak or covering; a neckerchief
for women.</def> <rj><au>Fairholt.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rail</ent><br/
<hw>Rail</hw>, <pos>v. i.</pos> <ety>[Etymol. uncertain.]</ety> <def>To
flow forth; to roll out; to course.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Streams of tears from her fair eyes forth <qex>railing</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rail</ent><br/
<hw>Rail</hw>, <pos>n.</pos> <ety>[Akin to LG. & Sw. <ets>regel</ets>
bar, bolt, G. <ets>riegel</ets> a rail, bar, or bolt, OHG.
<ets>rigil</ets>, <ets>rigel</ets>, bar, bolt, and possibly to E.
<ets>row</ets> a line.]</ety> <sn>1.</sn> <def>A bar of timber or metal,
usually horizontal or nearly so, extending from one post or support to
another, as in fences, balustrades, staircases, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Arch.)</fld> <def>A horizontal piece in a frame or
paneling. See <xex>Illust.</xex> of <er>Style</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Railroad)</fld> <def>A bar of steel or iron,
forming part of the track on which the wheels roll. It is usually shaped
with reference to vertical strength, and is held in place by chairs,
splices, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Naut.)</fld> <sd>(a)</sd> <def>The stout, narrow
plank that forms the top of the bulwarks.</def> <sd>(b)</sd> <def>The
light, fencelike structures of wood or metal at the break of the deck,
and elsewhere where such protection is needed.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A railroad as a means of transportation; <as>as, to
go by <ex>rail</ex>; a place not accesible by
<ex>rail</ex></as>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>6.</sn> <def>a railing.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Rail fence</b></col>. <cd>See under <er>Fence</er>.</cd>
-- <col><b>Rail guard</b></col>. <sd>(a)</sd> <cd>A device attached to
the front of a locomotive on each side for clearing the rail of
obstructions</cd>. <sd>(b)</sd> <cd>A guard rail. See under
<er>Guard</er>.</cd> -- <col><b>Rail joint</b></col>
<fld>(Railroad)</fld>, <cd>a splice connecting the adjacent ends of
rails, in distinction from a <xex>chair</xex>, which is merely a seat.
The two devices are sometimes united. Among several hundred varieties,
the <xex>fish joint</xex> is standard. See <cref>Fish joint</cref>,
under <er>Fish</er>.</cd> -- <col><b>Rail train</b></col> <fld>(Iron &
Steel Manuf.)</fld>, <cd>a train of rolls in a rolling mill, for making
rails for railroads from blooms or billets.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rail</ent><br/
<hw>Rail</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Railed</conjf> <pr>(r<amac/ld)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Railing</conjf>.]</vmorph> <sn>1.</sn> <def>To inclose with rails
or a railing.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It ought to be fenced in and <qex>railed</qex>.</q>
<rj><qau>Ayliffe.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To range in a line.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>They were brought to London all <qex>railed</qex> in ropes, like a
team of horses in a cart.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rail</ent><br/
<hw>Rail</hw>, <pos>n.</pos> <ety>[F. <ets>r<acir/le</ets>, fr.
<ets>r<acir/ler</ets> to have a rattling in the throat; of German
origin, and akin to E. <ets>rattle</ets>. See <er>Rattle</er>,
<pos>v.</pos>]</ety> <fld>(Zool.)</fld> <def>Any one of numerous species
of limicoline birds of the family <fam>Rallidae</fam>, especially those
of the genus <gen>Rallus</gen>, and of closely allied genera. They are
prized as game birds.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The common European water rail (<spn>Rallus
aquaticus</spn>) is called also <stype>bilcock</stype>, <stype>skitty
coot</stype>, and <stype>brook runner</stype>. The best known American
species are the clapper rail, or salt-marsh hen (<spn>Rallus
longirostris</spn>, var. <varn>crepitans</varn>); the king, or
red-breasted, rail (<spn>Rallus elegans</spn>) (called also
<stype>fresh-water marshhen</stype>); the lesser clapper, or Virginia,
rail (<spn>Rallus Virginianus</spn>); and the Carolina, or sora, rail
(<spn>Porzana Carolina</spn>). See <er>Sora</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Land rail</b></col> <fld>(Zool.)</fld>, <cd>the
corncrake.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rail</ent><br/
<hw>Rail</hw>, <pos>v. i.</pos> <ety>[F. <ets>railler</ets>; cf. Sp.
<ets>rallar</ets> to grate, scrape, molest; perhaps fr. (assumed) LL.
<ets>radiculare</ets>, fr. L. <ets>radere</ets> to scrape, grate. Cf.
<er>Rally</er> to banter, <er>Rase</er>.]</ety> <def>To use insolent and
reproachful language; to utter reproaches; to scoff; -- followed by
<ptcl>at</ptcl> or <ptcl>against</ptcl>, formerly by
<ptcl>on</ptcl>.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And <qex>rail</qex> at arts he did not understand.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Lesbia forever on me <qex>rails</qex>.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rail</ent><br/
<hw>Rail</hw> <pr>(r<amac/l)</pr>, <pos>v. t.</pos> <sn>1.</sn> <def>To
rail at.</def> <mark>[Obs.]</mark> <rj><au>Feltham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To move or influence by railing.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Rail</qex> the seal from off my bond.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Railer</ent><br/
<hw>Rail"er</hw> <pr>(r<amac/l"<etil/r)</pr>, <pos>n.</pos> <def>One who
rails; one who scoffs, insults, censures, or reproaches with opprobrious
language.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Railing</ent><br/
<hw>Rail"ing</hw>, <pos>a.</pos> <def>Expressing reproach;
insulting.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Angels, which are greater in power and might, bring not
<qex>railing</qex> accusation against them.</q> <rj><qau>2 Pet. ii.
11.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Railing</ent><br/
<hw>Rail"ing</hw>, <pos>n.</pos> <sn>1.</sn> <def>A barrier made of a
rail or of rails, together with vertical supports. The typical railing
in the interior of structures or on porches has a horizontal rail near
waist height, and multiple vertical supports. Its function is usually to
provide a safety barrier at the edge of a verticle drop to prevent
falls.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>Rails in general; also, material for making
rails.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Railingly</ent><br/
<hw>Rail"ing*ly</hw>, <pos>adv.</pos> <def>With scoffing or insulting
language.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raillery</ent><br/
<hw>Rail"ler*y</hw> <pr>(r<acr/l"l<etil/r*<ycr/ <it>or</it> r<amac/l"-;
277)</pr>, <pos>n.</pos> <ety>[F. <ets>raillerie</ets>, fr.
<ets>railler</ets>. See <er>Rail</er> to scoff.]</ety> <def>Pleasantry
or slight satire; banter; jesting language; satirical
merriment.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Let <qex>raillery</qex> be without malice or heat.</q> <rj><qau>B.
Jonson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Studies employed on low objects; the very naming of them is
sufficient to turn them into <qex>raillery</qex>.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Railleur</ent><br/
\'d8<hw>Rail`leur"</hw> <pr>(r<adot/`ly<etil/r" <or/
r<adot/`y<etil/r")</pr>, <pos>n.</pos> <ety>[F.]</ety> <def>A banterer;
a jester; a mocker.</def> <mark>[R.]</mark>
<rj><au>Wycherley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Railway</ent><br/
<ent>Railroad</ent><br/
<mhw>{ <hw>Rail"road`</hw> <pr>(r<amac/l"r<omac/d`)</pr>,
<hw>Rail"way`</hw> <pr>(r<amac/l"w<amac/`)</pr>, }</mhw> <pos>n.</pos>
<sn>1.</sn> <def>A road or way consisting of one or more parallel series
of iron or steel rails, patterned and adjusted to be tracks for the
wheels of vehicles, and suitably supported on a bed or
substructure.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The modern railroad is a development and adaptation of
the older tramway.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The road, track, etc., with all the lands,
buildings, rolling stock, franchises, etc., pertaining to them and
constituting one property; <as>as, a certain <ex>railroad</ex> has been
put into the hands of a receiver</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Railway</xex> is the commoner word in England;
<xex>railroad</xex> the commoner word in the United States.</note><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In the following and similar phrases <xex>railroad</xex>
and <xex>railway</xex> are used interchangeably: --</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Atmospheric railway</b></col>, <col><b>Elevated
railway</b></col></mcol>, <cd>etc. See under <er>Atmospheric</er>,
<er>Elevated</er>, etc.</cd> -- <col><b>Cable railway</b></col>. <cd>See
<cref>Cable road</cref>, under <er>Cable</er>.</cd> -- <col><b>Ferry
railway</b></col>, <cd>a submerged track on which an elevated platform
runs, for carrying a train of cars across a water course.</cd> --
<col><b>Gravity railway</b></col>, <cd>a railway, in a hilly country, on
which the cars run by gravity down gentle slopes for long distances
after having been hauled up steep inclines to an elevated point by
stationary engines.</cd> -- <col><b>Railway brake</b></col>, <cd>a brake
used in stopping railway cars or locomotives.</cd> -- <col><b>Railway
car</b></col>, <cd>a large, heavy vehicle with flanged wheels fitted for
running on a railway.</cd> <mark>[U.S.]</mark> -- <col><b>Railway
carriage</b></col>, <cd>a railway passenger car.</cd>
<mark>[Eng.]</mark> -- <col><b>Railway scale</b></col>, <cd>a platform
scale bearing a track which forms part of the line of a railway, for
weighing loaded cars.</cd> -- <col><b>Railway slide</b></col>. <cd>See
<cref>Transfer table</cref>, under <er>Transfer</er>.</cd> --
<col><b>Railway spine</b></col> <fld>(Med.)</fld>, <cd>an abnormal
condition due to severe concussion of the spinal cord, such as occurs in
railroad accidents. It is characterized by ataxia and other disturbances
of muscular function, sensory disorders, pain in the back, impairment of
general health, and cerebral disturbance, -- the symptoms often not
developing till some months after the injury.</cd> --
<mcol><col><b>Underground railroad</b></col> <col><b>Underground
railway</b></col></mcol>. <sd>(a)</sd> <cd>A railroad or railway running
through a tunnel, as beneath the streets of a city</cd>. <sd>(b)</sd>
<cd>Formerly, a system of cooperation among certain active antislavery
people in the <country>United States</country> prior to 1866, by which
fugitive slaves were secretly helped to reach
<country>Canada</country>.</cd> <note>[In the latter sense
<xex>railroad</xex>, and not <xex>railway</xex>, was usually
used.]</note> <ldquo/Their house was a principal
<xex>entrep<ocir/t</xex> of the <xex>underground railroad</xex>.<rdquo/
<au>W. D. Howells.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Railroad</ent><br/
<hw>Rail"road`</hw>, <pos>v. t.</pos> <def>To carry or send by railroad;
usually fig., to send or put through at high speed or in great haste; to
hurry or rush unduly; <as>as, to <ex>railroad</ex> a bill through
Condress</as>.</def> <mark>[Colloq., U. S.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Railroading</ent><br/
<hw>Rail"road`ing</hw>, <pos>n.</pos> <def>The construction of a
railroad; the business of managing or operating a railroad.</def>
<mark>[Colloq. U. S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raiment</ent><br/
<hw>Rai"ment</hw> <pr>(r<amac/"m<eit/nt)</pr>, <pos>n.</pos>
<ety>[Abbrev. fr. <ets>arraiment</ets>. See <er>Array</er>.]</ety>
<sn>1.</sn> <def>Clothing in general; vesture; garments; -- usually
singular in form, with a collective sense.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Living, both food and <qex>raiment</qex> she supplies.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An article of dress.</def> <mark>[R. or Obs.]</mark>
<rj><au>Sir P. Sidney.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rain</ent><br/
<hw>Rain</hw> <pr>(r<amac/n)</pr>, <pos>n. & v.</pos> <def>Reign.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rain</ent><br/
<hw>Rain</hw> <pr>(r<amac/n)</pr>, <pos>n.</pos> <ety>[OE.
<ets>rein</ets>, AS. <ets>regen</ets>; akin to OFries. <ets>rein</ets>,
D. & G. <ets>regen</ets>, OS. & OHG. <ets>regan</ets>, Icel., Dan., &
Sw. <ets>regn</ets>, Goth. <ets>rign</ets>, and prob. to L.
<ets>rigare</ets> to water, to wet; cf. Gr. <grk>bre`chein</grk> to wet,
to rain.]</ety> <def>Water falling in drops from the clouds; the descent
of water from the clouds in drops.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Rain</qex> is water by the heat of the sun divided into very
small parts ascending in the air, till, encountering the cold, it be
condensed into clouds, and descends in drops.</q>
<rj><qau>Ray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Fair days have oft contracted wind and <qex>rain</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Rain</xex> is distinguished from <xex>mist</xex> by
the size of the drops, which are distinctly visible. When water falls in
very small drops or particles, it is called <xex>mist</xex>; and
<xex>fog</xex> is composed of particles so fine as to be not only
individually indistinguishable, but to float or be suspended in the air.
See <er>Fog</er>, and <er>Mist</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Rain band</b></col> <fld>(Meteorol.)</fld>, <cd>a dark
band in the yellow portion of the solar spectrum near the sodium line,
caused by the presence of watery vapor in the atmosphere, and hence
sometimes used in weather predictions.</cd> -- <col><b>Rain
bird</b></col> <fld>(Zool.)</fld>, <cd>the yaffle, or green woodpecker.
<mark>[Prov. Eng.]</mark> The name is also applied to various other
birds, as to <spn>Saurothera vetula</spn> of the West Indies.</cd> --
<col><b>Rain fowl</b></col> <fld>(Zool.)</fld>, <cd>the channel-bill
cuckoo (<spn>Scythrops Novae-Hollandiae</spn>) of Australia.</cd> --
<col><b>Rain gauge</b></col>, <cd>an instrument of various forms for
measuring the quantity of rain that falls at any given place in a given
time; a pluviometer; an ombrometer.</cd> -- <col><b>Rain goose</b></col>
<fld>(Zool.)</fld>, <cd>the red-throated diver, or loon.</cd>
<mark>[Prov. Eng.]</mark> -- <col><b>Rain prints</b></col>
<fld>(Geol.)</fld>, <cd>markings on the surfaces of stratified rocks,
presenting an appearance similar to those made by rain on mud and sand,
and believed to have been so produced.</cd> -- <col><b>Rain
quail</b></col>. <fld>(Zool.)</fld> <cd>See <er>Quail</er>,
<pos>n.</pos>, 1.</cd> -- <col><b>Rain water</b></col>, <cd>water that
has fallen from the clouds in rain.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rain</ent><br/
<hw>Rain</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Rained</conjf> <pr>(r<amac/nd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Raining</conjf>.]</vmorph> <ety>[AS. <ets>regnian</ets>, akin to
G. <ets>regnen</ets>, Goth. <ets>rignjan</ets>. See <er>Rain</er>,
<pos>n.</pos>]</ety> <sn>1.</sn> <def>To fall in drops from the clouds,
as water; -- used mostly with <xex>it</xex> for a nominative; <as>as, it
<ex>rains</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The rain it <qex>raineth</qex> every day.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To fall or drop like water from the clouds; <as>as,
tears <ex>rained</ex> from their eyes</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rain</ent><br/
<hw>Rain</hw> <pr>(r<amac/n)</pr>, <pos>v. t.</pos> <sn>1.</sn> <def>To
pour or shower down from above, like rain from the clouds.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Then said the Lord unto Moses, Behold, I will <qex>rain</qex>
bread from heaven for you.</q> <rj><qau>Ex. xvi. 4.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To bestow in a profuse or abundant manner; <as>as,
to <ex>rain</ex> favors upon a person</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rainbow</ent><br/
<hw>Rain"bow`</hw> <pr>(r<amac/n"b<omac/`)</pr>, <pos>n.</pos> <ety>[AS.
<ets>regenboga</ets>, akin to G. <ets>regenbogen</ets>. See
<er>Rain</er>, and <er>Bow</er> anything bent.]</ety> <def>A bow or arch
exhibiting, in concentric bands, the several colors of the spectrum, and
formed in the part of the hemisphere opposite to the sun by the
refraction and reflection of the sun's rays in drops of falling
rain.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Besides the ordinary bow, called also <xex>primary
rainbow</xex>, which is formed by two refractions and one reflection,
there is also another often seen exterior to it, called the
<xex>secondary rainbow</xex>, concentric with the first, and separated
from it by a small interval. It is formed by two refractions and two
reflections, is much fainter than the primary bow, and has its colors
arranged in the reverse order from those of the latter.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Lunar rainbow</b></col>, <cd>a fainter arch or rainbow,
formed by the moon.</cd> -- <mcol><col><b>Marine rainbow</b></col>,
<col><b>Sea bow</b></col></mcol>, <cd>a similar bow seen in the spray of
waves at sea.</cd> -- <col><b>Rainbow trout</b></col>
<fld>(Zool.)</fld>, <cd>a bright-colored trout (<spn>Salmo
irideus</spn>), native of the mountains of <state>California</state>,
but now extensively introduced into the <geog>Eastern States</geog>,
<country>Japan</country>, and other countries; -- called also
<altname>brook trout</altname>, <altname>mountain trout</altname>, and
<altname>golden trout</altname>.</cd> -- <col><b>Rainbow
wrasse</b></col>. <fld>(Zool.)</fld> <cd>See under <er>Wrasse</er>.</cd>
-- <col><b>Supernumerary rainbow</b></col>, <cd>a smaller bow, usually
of red and green colors only, sometimes seen within the primary or
without the secondary rainbow, and in contact with them.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rainbowed</ent><br/
<hw>Rain"bowed`</hw> <pr>(r<amac/n"b<omac/d`)</pr>, <pos>a.</pos>
<def>Formed with or like a rainbow.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raindeer</ent><br/
<hw>Rain"deer`</hw> <pr>(r<amac/n"d<emac/r`)</pr>, <pos>n.</pos>
<fld>(Zool.)</fld> <def>See <er>Reindeer</er>.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raindrop</ent><br/
<hw>Rain"drop`</hw> <pr>(r<amac/n"dr<ocr/p`)</pr>, <pos>n.</pos> <def>A
drop of rain.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rainfall</ent><br/
<hw>Rain"fall`</hw> <pr>(r<amac/n"f<add/l`)</pr>, <pos>n.</pos> <def>A
fall or descent of rain; the water, or amount of water, that falls in
rain; <as>as, the average annual <ex>rainfall</ex> of a
region</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Supplied by the <qex>rainfall</qex> of the outer ranges of Sinchul
and Singaleleh.</q> <rj><qau>Hooker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raininess</ent><br/
<hw>Rain"i*ness</hw> <pr>(r<amac/n"<icr/*n<ecr/s)</pr>, <pos>n.</pos>
<def>The state of being rainy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rainless</ent><br/
<hw>Rain"less</hw> <pr>(r<amac/n"l<ecr/s)</pr>, <pos>a.</pos>
<def>Destitute of rain; <as>as, a <ex>rainless</ex>
region</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rain-tight</ent><br/
<hw>Rain"-tight`</hw> <pr>(r<amac/n"t<imac/t`)</pr>, <pos>a.</pos>
<def>So tight as to exclude rain; <as>as, a <ex>rain-tight</ex>
roof</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rainy</ent><br/
<hw>Rain"y</hw> <pr>(r<amac/n"<ycr/)</pr>, <pos>a.</pos> <ety>[AS.
<ets>regenig</ets>.]</ety> <def>Abounding with rain; wet; showery;
<as>as, <ex>rainy</ex> weather; a <ex>rainy</ex> day or
season</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raip</ent><br/
<hw>Raip</hw> <pr>(r<amac/p)</pr>, <pos>n.</pos> <ety>[Cf. Icel.
<ets>reip</ets> rope. Cf. <er>Rope</er>.]</ety> <def>A rope; also, a
measure equal to a rod.</def> <mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rais</ent><br/
<hw>Rais</hw> <pr>(r<imac/s)</pr>, <pos>n.</pos> <def>Same as 2d
<er>Reis</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raisable</ent><br/
<hw>Rais"a*ble</hw> <pr>(r<amac/z"<adot/*b'l)</pr>, <pos>a.</pos>
<def>Capable of being raised.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raise</ent><br/
<hw>Raise</hw> <pr>(r<amac/z)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Raised</conjf> <pr>(r<amac/zd)</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>Raising</conjf>.]</vmorph> <ety>[OE.
<ets>reisen</ets>, Icel. <ets>reisa</ets>, causative of
<ets>r<imac/sa</ets> to rise. See <er>Rise</er>, and cf. <er>Rear</er>
to raise.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>To cause to rise; to bring from a lower to a higher
place; to lift upward; to elevate; to heave; <as>as, to <ex>raise</ex> a
stone or weight</as>.</def> Hence, figuratively: --<br/
[<source>1913 Webster</source>]</p>

<p><sd>(a)</sd> <def>To bring to a higher condition or situation; to
elevate in rank, dignity, and the like; to increase the value or
estimation of; to promote; to exalt; to advance; to enhance; <as>as, to
<ex>raise</ex> from a low estate; to <ex>raise</ex> to office; to
<ex>raise</ex> the price, and the like</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This gentleman came to be <qex>raised</qex> to great titles.</q>
<rj><qau>Clarendon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The plate pieces of eight were <qex>raised</qex> three pence in
the piece.</q> <rj><qau>Sir W. Temple.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(b)</sd> <def>To increase the strength, vigor, or vehemence of;
to excite; to intensify; to invigorate; to heighten; <as>as, to
<ex>raise</ex> the pulse; to <ex>raise</ex> the voice; to <ex>raise</ex>
the spirits or the courage; to <ex>raise</ex> the heat of a
furnace</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sd>(c)</sd> <def>To elevate in degree according to some scale;
<as>as, to <ex>raise</ex> the pitch of the voice; to <ex>raise</ex> the
temperature of a room</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To cause to rise up, or assume an erect position or
posture; to set up; to make upright; <as>as, to <ex>raise</ex> a mast or
flagstaff</as>.</def> Hence: --<br/
[<source>1913 Webster</source>]</p>

<p><sd>(a)</sd> <def>To cause to spring up from a recumbent position,
from a state of quiet, or the like; to awaken; to arouse.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They shall not awake, nor be <qex>raised</qex> out of their
sleep.</q> <rj><qau>Job xiv. 12.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(b)</sd> <def>To rouse to action; to stir up; to incite to
tumult, struggle, or war; to excite.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He commandeth, and <qex>raiseth</qex> the stormy wind.</q>
<rj><qau>Ps. cvii. 25.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Aeneas . . . employs his pains,<br/
In parts remote, to <qex>raise</qex> the Tuscan swains.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(c)</sd> <def>To bring up from the lower world; to call up, as a
spirit from the world of spirits; to recall from death; to give life
to.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Why should it be thought a thing incredible with you, that God
should <qex>raise</qex> the dead ?</q> <rj><qau>Acts xxvi.
8.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To cause to arise, grow up, or come into being or to
appear; to give rise to; to originate, produce, cause, effect, or the
like.</def> <specif>Hence, specifically: --</specif><br/
[<source>1913 Webster</source>]</p>

<p><sd>(a)</sd> <def>To form by the accumulation of materials or
constituent parts; to build up; to erect; <as>as, to <ex>raise</ex> a
lofty structure, a wall, a heap of stones</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I will <qex>raise</qex> forts against thee.</q> <rj><qau>Isa.
xxix. 3.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(b)</sd> <def>To bring together; to collect; to levy; to get
together or obtain for use or service; <as>as, to <ex>raise</ex> money,
troops, and the like</as>.</def> <ldquo/To <xex>raise</xex> up a
rent.<rdquo/ <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(c)</sd> <def>To cause to grow; to procure to be produced, bred,
or propagated; to grow; <as>as, to <ex>raise</ex> corn, barley, hops,
etc.; to<ex>raise</ex> cattle</as>.</def> <ldquo/He <xex>raised</xex>
sheep.<rdquo/ <ldquo/He <xex>raised</xex> wheat where none grew
before.<rdquo/ <rj><au>Johnson's Dict.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1186 pr=vmg --></p>

<p><note><hand/ In some parts of the United States, notably in the
Southern States, <xex>raise</xex> is also commonly applied to the
rearing or bringing up of children.</note><br/
[<source>1913 Webster</source>]</p>

<p><q>I was <qex>raised</qex>, as they say in Virginia, among the
mountains of the North.</q> <rj><qau>Paulding.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(d)</sd> <def>To bring into being; to produce; to cause to arise,
come forth, or appear; -- often with <xex>up</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I will <qex>raise</qex> them up a prophet from among their
brethren, like unto thee.</q> <rj><qau>Deut. xviii. 18.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>God vouchsafes to <qex>raise</qex> another world<br/
From him [Noah], and all his anger to forget.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(e)</sd> <def>To give rise to; to set agoing; to occasion; to
start; to originate; <as>as, to <ex>raise</ex> a smile or a
blush</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou shalt not <qex>raise</qex> a false report.</q> <rj><qau>Ex.
xxiii. 1.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(f)</sd> <def>To give vent or utterance to; to utter; to strike
up.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Soon as the prince appears, they <qex>raise</qex> a cry.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(g)</sd> <def>To bring to notice; to submit for consideration;
<as>as, to <ex>raise</ex> a point of order; to <ex>raise</ex> an
objection</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To cause to rise, as by the effect of leaven; to
make light and spongy, as bread.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Miss Liddy can dance a jig, and <qex>raise</qex> paste.</q>
<rj><qau>Spectator.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Naut.)</fld> <sd>(a)</sd> <def>To cause (the land
or any other object) to seem higher by drawing nearer to it; <as>as, to
<ex>raise</ex> Sandy Hook light</as>.</def> <sd>(b)</sd> <def>To let go;
<as>as in the command, <ex>Raise</ex> tacks and sheets, <it>i. e.</it>,
Let go tacks and sheets</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Law)</fld> <def>To create or constitute; <as>as, to
<ex>raise</ex> a use, that is, to create it</as>.</def>
<rj><au>Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To raise a blockade</b></col> <fld>(Mil.)</fld>, <cd>to
remove or break up a blockade, either by withdrawing the ships or forces
employed in enforcing it, or by driving them away or dispersing
them.</cd> -- <mcol><col><b>To raise a check</b></col>,
<col><b>note</b></col>, <col><b>bill of exchange</b></col></mcol>,
<cd>etc., to increase fraudulently its nominal value by changing the
writing, figures, or printing in which the sum payable is
specified.</cd><-- or money order --> -- <col><b>To raise a
siege</b></col>, <cd>to relinquish an attempt to take a place by
besieging it, or to cause the attempt to be relinquished.</cd> --
<col><b>To raise steam</b></col>, <cd>to produce steam of a required
pressure.</cd> -- <col><b>To raise the wind</b></col>, <cd>to procure
ready money by some temporary expedient.</cd> <mark>[Colloq.]</mark> --
<mcol><col><b>To raise Cain</b></col>, <it>or</it> <col><b>To raise the
devil</b></col></mcol>, <cd>to cause a great disturbance; to make great
trouble.</cd> <mark>[Slang]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To lift; exalt; elevate; erect; originate; cause;
produce; grow; heighten; aggravate; excite.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raised</ent><br/
<hw>Raised</hw> <pr>(r<amac/zd)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Lifted up; showing above the surroundings; <as>as, <ex>raised</ex>
or embossed metal work</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Leavened; made with leaven, or yeast; -- used of
bread, cake, etc., as distinguished from that made with cream of tartar,
soda, etc. See <er>Raise</er>, <pos>v. t.</pos>, 4.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Raised beach</b></col>. <cd>See under <er>Beach</er>,
<pos>n.</pos></cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raiser</ent><br/
<hw>Rais"er</hw> <pr>(r<amac/z"<etil/r)</pr>, <pos>n.</pos> <def>One
who, or that which, raises (in various senses of the verb).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raisin</ent><br/
<hw>Rai"sin</hw> <pr>(r<amac/"z'n)</pr>, <pos>n.</pos> <ety>[F.
<ets>raisin</ets> grape, raisin, L. <ets>racemus</ets> cluster of grapes
or berries; cf. Gr. <grk>"ra`x</grk>, <grk>"rago`s</grk>, berry, grape.
Cf. <er>Raceme</er>.]</ety> <sn>1.</sn> <def>A grape, or a bunch of
grapes.</def> <mark>[Obs.]</mark> <rj><au>Cotgrave.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A grape dried in the sun or by artificial
heat.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Raisin tree</b></col> <fld>(Bot.)</fld>, <cd>the common
red currant bush, whose fruit resembles the small raisins of Corinth
called <prod>currants</prod>.</cd> <mark>[Eng.]</mark> <rj><au>Dr.
Prior.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raising</ent><br/
<hw>Rais"ing</hw> <pr>(r<amac/z"<icr/ng)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>The act of lifting, setting up, elevating, exalting, producing, or
restoring to life.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Specifically, the operation or work of setting up
the frame of a building; <as>as, to help at a
<ex>raising</ex></as>.</def> <mark>[U.S.]</mark><-- e.g., barn raising
--><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The operation of embossing sheet metal, or of
forming it into cup-shaped or hollow articles, by hammering, stamping,
or spinning.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Raising bee</b></col>, <cd>a bee for raising the frame of
a building. See <er>Bee</er>, <pos>n.</pos>, 2.</cd> <mark>[U.S.]</mark>
<au>W. Irving.</au> -- <col><b>Raising hammer</b></col>, <cd>a hammer
with a rounded face, used in raising sheet metal.</cd> --
<col><b>Raising plate</b></col> <fld>(Carp.)</fld>, <cd>the plate, or
longitudinal timber, on which a roof is raised and rests.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raisonne</ent><br/
\'d8<hw>Rai`son`n<eacute/"</hw> <pr>(r<asl/`z<osl/`n<asl/")</pr>,
<pos>a.</pos> <ety>[F. <ets>raisonn<eacute/</ets>, p. p. of
<ets>raisonner</ets> to reason.]</ety> <def>Arranged systematically, or
according to classes or subjects; <as>as, a catalogue
<ex>raisonn<eacute/</ex></as>. See under <er>Catalogue</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raivel</ent><br/
<hw>Rai"vel</hw> <pr>(r<amac/"v<eit/l)</pr>, <pos>n.</pos>
<fld>(Weaving)</fld> <def>A separator.</def> <mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raj</ent><br/
\'d8<hw>Raj</hw> <pr>(r<aum/j)</pr>, <pos>n.</pos> <ety>[See
<er>Rajah</er>.]</ety> <def>Reign; rule.</def> <mark>[India]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raja</ent><br/
\'d8<hw>Ra"ja</hw> <pr>(r<aum/"j<aum/ <or/ r<amac/"j<adot/)</pr>,
<pos>n.</pos> <def>Same as <er>Rajah</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rajah</ent><br/
<hw>Ra"jah</hw> <pr>(r<aum/"j<aum/ <or/ r<amac/"j<adot/)</pr>,
<pos>n.</pos> <ety>[Hind. <ets>r<amac/j<amac/</ets>, Skr.
<ets>r<amac/jan</ets>, akin to L. <ets>rex</ets>, <ets>regis</ets>. See
<er>Regal</er>, <pos>a.</pos>]</ety> <def>A native prince or king; also,
a landholder or person of importance in the agricultural
districts.</def> <mark>[India]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rajahship</ent><br/
<hw>Ra"jah*ship</hw>, <pos>n.</pos> <def>The office or dignity of a
rajah.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rajput</ent><br/
<ent>Rajpoot</ent><br/
<mhw>{ \'d8<hw>Raj`poot"</hw>, \'d8<hw>Raj`put"</hw> }</mhw>
<pr>(r<aum/j`p<oomac/t")</pr>, <pos>n.</pos> <ety>[Hind.
<ets>r<amac/j-p<umac/t</ets>, Skr. <ets>r<amac/ja-putra</ets> king's
son.]</ety> <def>A Hindoo of the second, or royal and military, caste; a
Kshatriya; especially, an inhabitant of the country of Rajpootana, in
northern central India.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rake</ent><br/
<hw>Rake</hw> <pr>(r<amac/k)</pr>, <pos>n.</pos> <ety>[AS.
<ets>race</ets>; akin to OD. <ets>rake</ets>, D. <ets>reek</ets>, OHG.
<ets>rehho</ets>, G. <ets>rechen</ets>, Icel. <ets>reka</ets> a shovel,
and to Goth. <ets>rikan</ets> to heap up, collect, and perhaps to Gr.
<grk>'ore`gein</grk> to stretch out, and E. <ets>rack</ets> to stretch.
Cf. <er>Reckon</er>.]</ety> <sn>1.</sn> <def>An implement consisting of
a headpiece having teeth, and a long handle at right angles to it, --
used for collecting hay, or other light things which are spread over a
large surface, or for breaking and smoothing the earth.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A toothed machine drawn by a horse, -- used for
collecting hay or grain; a horserake.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <ety>[Perhaps a different word.]</ety>
<fld>(Mining)</fld> <def>A fissure or mineral vein traversing the strata
vertically, or nearly so; -- called also
<altname>rake-vein</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Gill rakes</b></col>. <fld>(Anat.)</fld> <cd>See under
1st <er>Gill</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rake</ent><br/
<hw>Rake</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Raked</conjf> <pr>(r<amac/kt)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Raking</conjf>.]</vmorph> <ety>[AS. <ets>racian</ets>. See 1st
<er>Rake</er>.]</ety> <sn>1.</sn> <def>To collect with a rake; <as>as,
to <ex>rake</ex> hay</as>; -- often with <ptcl>up</ptcl>; <as>as, he
<ex>raked</ex> up the fallen leaves</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> Hence: <def>To collect or draw together with laborious
industry; to gather from a wide space; to scrape together; <as>as, to
<ex>rake</ex> together wealth; to <ex>rake</ex> together slanderous
tales; to <ex>rake</ex> together the rabble of a town.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To pass a rake over; to scrape or scratch with a
rake for the purpose of collecting and clearing off something, or for
stirring up the soil; <as>as, to <ex>rake</ex> a lawn; to <ex>rake</ex>
a flower bed.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To search through; to scour; to ransack.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The statesman <qex>rakes</qex> the town to find a plot.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To scrape or scratch across; to pass over quickly
and lightly, as a rake does.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Like clouds that <qex>rake</qex> the mountain summits.</q>
<rj><qau>Wordsworth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Mil.)</fld> <def>To enfilade; to fire in a
direction with the length of; in naval engagements, to cannonade, as a
ship, on the stern or head so that the balls range the whole length of
the deck.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To rake up</b></col>. <sd>(a)</sd> <cd>To collect
together, as the fire (live coals), and cover with ashes</cd>.
<sd>(b)</sd> <cd>To bring up; to search out and bring to notice again;
<as>as, <ex>to rake up</ex> old scandals</as>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rake</ent><br/
<hw>Rake</hw> <pr>(r<amac/k)</pr>, <pos>v. i.</pos> <sn>1.</sn> <def>To
use a rake, as for searching or for collecting; to scrape; to search
minutely.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>One is for <qex>raking</qex> in Chaucer for antiquated words.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To pass with violence or rapidity; to scrape
along.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Pas could not stay, but over him did <qex>rake</qex>.</q>
<rj><qau>Sir P. Sidney.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rake</ent><br/
<hw>Rake</hw>, <pos>n.</pos> <ety>[Cf. dial. Sw. <ets>raka</ets> to
reach, and E. <ets>reach</ets>.]</ety> <def>The inclination of anything
from a perpendicular direction; <as>as, the <ex>rake</ex> of a roof, a
staircase, etc.</as></def>; especially <fld>(Naut.)</fld>, <def>the
inclination of a mast or funnel, or, in general, of any part of a vessel
not perpendicular to the keel.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rake</ent><br/
<hw>Rake</hw>, <pos>v. i.</pos> <def>To incline from a perpendicular
direction; <as>as, a mast <ex>rakes</ex> aft</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Raking course</b></col> <fld>(Bricklaying)</fld>, <cd>a
course of bricks laid diagonally between the face courses in a thick
wall, to strengthen it.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rake</ent><br/
<hw>Rake</hw>, <pos>n.</pos> <ety>[OE. <ets>rakel</ets> rash; cf. Icel.
<ets>reikall</ets> wandering, unsettled, <ets>reika</ets> to
wander.]</ety> <def>A loose, disorderly, vicious man; a person addicted
to lewdness and other scandalous vices; a debauchee; a
rou<eacute/.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>An illiterate and frivolous old <qex>rake</qex>.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rake</ent><br/
<hw>Rake</hw>, <pos>v. i.</pos> <sn>1.</sn> <ety>[Icel.
<ets>reika</ets>. Cf. <er>Rake</er> a debauchee.]</ety> <def>To walk
about; to gad or ramble idly.</def> <mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <ety>[See <er>Rake</er> a debauchee.]</ety> <def>To act
the rake; to lead a dissolute, debauched life.</def>
<rj><au>Shenstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To rake out</b></col> <fld>(Falconry)</fld>, <cd>to fly
too far and wide from its master while hovering above waiting till the
game is sprung; -- said of the hawk.</cd> <rj><au>Encyc.
Brit.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rakehell</ent><br/
<hw>Rake"hell`</hw> <pr>(r<amac/k"h<ecr/l`)</pr>, <pos>n.</pos>
<ety>[See <er>Rakel</er>.]</ety> <def>A lewd, dissolute fellow; a
debauchee; a rake.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It seldom doth happen, in any way of life, that a sluggard and a
<qex>rakehell</qex> do not go together.</q>
<rj><qau>Barrow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rakehelly</ent><br/
<ent>Rakehell</ent><br/
<mhw>{ <hw>Rake"hell`</hw>, <hw>Rake"hell`y</hw>
<pr>(r<amac/k"h<ecr/l`<ycr/)</pr>, }</mhw> <pos>a.</pos> <def>Dissolute;
wild; lewd; rakish.</def> <mark>[Obs.]</mark> <rj><au>Spenser. B.
Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rakel</ent><br/
<hw>Ra"kel</hw> <pr>(r<aum/"k<ecr/l)</pr>, <pos>a.</pos> <ety>[OE. See
<er>Rake</er> a debauchee.]</ety> <def>Hasty; reckless; rash.</def>
<mark>[Obs.]</mark> <au>Chaucer.</au> --
<wordforms><wf>Ra"kel*ness</wf>, <pos>n.</pos>
<mark>[Obs.]</mark></wordforms> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raker</ent><br/
<hw>Rak"er</hw> <pr>(r<amac/k"<etil/r)</pr>, <pos>n.</pos> <ety>[See 1st
<er>Rake</er>.]</ety> <sn>1.</sn> <def>One who, or that which,
rakes</def>; as: <sd>(a)</sd> <def>A person who uses a rake.</def>
<sd>(b)</sd> <def>A machine for raking grain or hay by horse or other
power.</def> <sd>(c)</sd> <def>A gun so placed as to rake an enemy's
ship.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>See <cref>Gill rakers</cref>,
under 1st <er>Gill</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rakery</ent><br/
<hw>Rak"er*y</hw> <pr>(r<amac/k"<etil/r*<ycr/)</pr>, <pos>n.</pos>
<def>Debauchery; lewdness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>rakery</qex> and intrigues of the lewd town.</q>
<rj><qau>R. North.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rakeshame</ent><br/
<hw>Rake"shame`</hw> <pr>(r<amac/k"sh<amac/m`)</pr>, <pos>n.</pos>
<ety>[Cf. <er>Rakehell</er>, <er>Ragabash</er>.]</ety> <def>A vile,
dissolute wretch.</def> <mark>[Obs.]</mark>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rakestale</ent><br/
<hw>Rake"stale`</hw> <pr>(r<amac/k"st<amac/l`)</pr>, <pos>n.</pos>
<ety>[<ets>Rake</ets> the instrument + <ets>stale</ets> a handle.]</ety>
<def>The handle of a rake.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That tale is not worth a <qex>rakestele</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rake-vein</ent><br/
<hw>Rake"-vein`</hw> <pr>(r<amac/k"v<amac/n`)</pr>, <pos>n.</pos>
<def>See <er>Rake</er>, a mineral vein.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rakee</ent><br/
<ent>Raki</ent><br/
<mhw>{ \'d8<hw>Ra`ki"</hw>, \'d8<hw>Ra`kee"</hw> }</mhw>
<pr>(r<adot/`k<emac/"; r<acr/k"<esl/)</pr>, <pos>n.</pos> <ety>[Turk.
<ets>r<amac/q<imac/</ets> arrack.]</ety> <def>A kind of <isa>ardent
spirits</isa> used in southern Europe and the East, distilled from grape
juice, grain, etc.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Raking</ent><br/
<hw>Rak"ing</hw> <pr>(r<amac/k"<icr/ng)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>The act or process of using a rake; the going over a space with a
rake.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A space gone over with a rake; also, the work done,
or the quantity of hay, grain, etc., collected, by going once over a
space with a rake.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rakish</ent><br/
<hw>Rak"ish</hw> <pr>(r<amac/k"<icr/sh)</pr>, <pos>a.</pos>
<def>Dissolute; lewd; debauched.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The arduous task of converting a <qex>rakish</qex> lover.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rakish</ent><br/
<hw>Rak"ish</hw> <pr>(r<amac/k"<icr/sh)</pr>, <pos>a.</pos>
<fld>(Naut.)</fld> <def>Having a saucy appearance indicative of speed
and dash.</def> <rj><au>Ham. Nav. Encyc.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rakishly</ent><br/
<hw>Rak"ish*ly</hw> <pr>(r<amac/k"<icr/sh*l<ycr/)</pr>, <pos>adv.</pos>
<def>In a rakish manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rakishness</ent><br/
<hw>Rak"ish*ness</hw>, <pos>n.</pos> <def>The quality or state of being
rakish.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raku ware</ent><br/
\'d8<hw>Ra"ku ware`</hw> <pr>(r<aum/"k<oomac/ w<acir/r`)</pr>. <def>A
kind of earthenware made in Japan, resembling Satsuma ware, but having a
paler color.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rale</ent><br/
\'d8<hw>R<acir/le</hw> <pr>(r<aum/l)</pr>, <pos>n.</pos> <ety>[F.
<ets>r<acir/le</ets>. Cf. <er>Rail</er> the bird.]</ety>
<fld>(Med.)</fld> <def>An adventitious sound, usually of morbid origin,
accompanying the normal respiratory sounds. See
<er>Rhonchus</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Various kinds are distinguished by pathologists;
differing in intensity, as loud and small; in quality, as moist, dry,
clicking, whistling, and sonorous; and in origin, as tracheal,
pulmonary, and pleural.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rallentando</ent><br/
\'d8<hw>Ral`len*tan"do</hw> <pr>(r<aum/l`l<ecr/n*t<aum/n"d<osl/)</pr>,
<pos>a.</pos> <ety>[It.]</ety> <fld>(Mus.)</fld> <def>Slackening; -- a
direction to perform a passage with a gradual decrease in time and
force; ritardando.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ralliance</ent><br/
<hw>Ral"li*ance</hw> <pr>(r<acr/l"l<icr/*<ait/ns)</pr>, <pos>n.</pos>
<ety>[Cf. OF. <ets>raliance</ets>. See <er>Rally</er> to reunite.]</ety>
<def>The act of rallying.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rallier</ent><br/
<hw>Ral"li*er</hw> <pr>(r<acr/l"l<icr/*<etil/r)</pr>, <pos>n.</pos>
<def>One who rallies.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rallies</ent><br/
\'d8<hw>Ral"li<eacute/s"</hw> <pr>(r<adot/l`y<amac/")</pr>, <pos>n.
pl.</pos> <ety>[F., p. p. pl. See <er>Rally</er>, <pos>v.
t.</pos>]</ety> <def>A French political group, also known as the
Constitutional Right from its position in the Chambers, mainly
monarchists who rallied to the support of the Republic in obedience to
the encyclical put forth by <person>Pope Leo XIII.</person> in Feb.,
1892.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Ralline</ent><br/
<hw>Ral"line</hw> <pr>(r<acr/l"l<imac/n)</pr>, <pos>a.</pos>
<fld>(Zool.)</fld> <def>Pertaining to the rails.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rally</ent><br/
<hw>Ral"ly</hw> <pr>(r<acr/l"l<ycr/)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Rallied</conjf>
<pr>(r<acr/l"l<icr/d)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Rallying</conjf>.]</vmorph> <ety>[OF. <ets>ralier</ets>, F.
<ets>rallier</ets>, fr. L. pref. <ets>re-</ets> + <ets>ad</ets> +
<ets>ligare</ets> to bind. See <er>Ra-</er>, and 1st
<er>Ally</er>.]</ety> <def>To collect, and reduce to order, as troops
dispersed or thrown into confusion; to gather again; to
reunite.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rally</ent><br/
<hw>Ral"ly</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To come into orderly
arrangement; to renew order, or united effort, as troops scattered or
put to flight; to assemble; to unite.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The Grecians <qex>rally</qex>, and their powers unite.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Innumerable parts of matter chanced just then to <qex>rally</qex>
together, and to form themselves into this new world.</q>
<rj><qau>Tillotson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To collect one's vital powers or forces; to regain
health or consciousness; to recuperate.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To recover strength after a decline in prices; --
said of the market, stocks, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rally</ent><br/
<hw>Ral"ly</hw>, <pos>n.</pos>; <plu><it>pl.</it> <plw>Rallies</plw>
<pr>(r<acr/l"l<icr/z)</pr>.</plu> <sn>1.</sn> <def>The act or process of
rallying (in any of the senses of that word).</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A political mass meeting.</def> <mark>[Colloq. U.
S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rally</ent><br/
<hw>Ral"ly</hw>, <pos>v. t.</pos> <ety>[F. <ets>railler</ets>. See
<er>Rail</er> to scoff.]</ety> <def>To attack with raillery, either in
good humor and pleasantry, or with slight contempt or satire.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Honeycomb . . . <qex>rallies</qex> me upon a country life.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Strephon had long confessed his amorous pain,<br/
Which gay Corinna <qex>rallied</qex> with disdain.</q>
<rj><qau>Gay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To banter; ridicule; satirize; deride;
mock.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rally</ent><br/
<hw>Ral"ly</hw> <pr>(r<acr/l"l<ycr/)</pr>, <pos>v. i.</pos> <def>To use
pleasantry, or satirical merriment.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rally</ent><br/
<hw>Ral"ly</hw>, <pos>n.</pos> <def>Good-humored raillery.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ralph</ent><br/
<hw>Ralph</hw> <pr>(r<acr/lf)</pr>, <pos>n.</pos> <def>A name sometimes
given to the raven.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ralstonite</ent><br/
<hw>Ral"ston*ite</hw> <pr>(r<add/l"st<ucr/n*<imac/t)</pr>, <pos>n.</pos>
<ety>[So named after <person>J. G. <etsep>Ralston</etsep></person> of
Norristown, Penn.]</ety> <fld>(Min.)</fld> <def>A fluoride of alumina
and soda occurring with the Greenland cryolite in octahedral
crystals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ram</ent><br/
<hw>Ram</hw> <pr>(r<acr/m)</pr>, <pos>n.</pos> <ety>[AS.
<ets>ramm</ets>, <ets>ram</ets>; akin to OHG. & D. <ets>ram</ets>, Prov.
G. <ets>ramm</ets>, and perh. to Icel. <ets>ramr</ets> strong.]</ety>
<sn>1.</sn> <def>The male of the sheep and allied animals. In some parts
of England a ram is called a <altname>tup</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Astron.)</fld> <sd>(a)</sd> <def>Aries, the sign of
the zodiac which the sun enters about the 21st of March.</def>
<sd>(b)</sd> <def>The constellation Aries, which does not now, as
formerly, occupy the sign of the same name.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>An engine of war used for butting or
battering.</def> Specifically: <sd>(a)</sd> <def>In ancient warfare, a
long beam suspended by slings in a framework, and used for battering the
walls of cities; a battering-ram.</def> <sd>(b)</sd> <def>A heavy steel
or iron beak attached to the prow of a steam war vessel for piercing or
cutting down the vessel of an enemy; also, a vessel carrying such a
beak.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A hydraulic ram. See under
<er>Hydraulic</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>The weight which strikes the blow, in a pile driver,
steam hammer, stamp mill, or the like.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>The plunger of a hydraulic press.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Ram's horn</b></col>. <sd>(a)</sd> <fld>(Fort.)</fld>
<cd>A low semicircular work situated in and commanding a ditch</cd>.
<altsp>[Written also <asp>ramshorn</asp>.]</altsp> <au>Farrow.</au>
<sd>(b)</sd> <fld>(Paleon.)</fld> <cd>An ammonite.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ram</ent><br/
<hw>Ram</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Rammed</conjf> <pr>(r<acr/md)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Ramming</conjf>.]</vmorph> <sn>1.</sn> <def>To butt or strike
against; to drive a ram against or through; to thrust or drive with
violence; to force in; to drive together; to cram; <as>as, to
<ex>ram</ex> an enemy's vessel; to <ex>ram</ex> piles, cartridges,
etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>[They] <qex>rammed</qex> me in with foul shirts, and smocks,
socks, foul stockings, greasy napkins.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To fill or compact by pounding or driving.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A ditch . . . was filled with some sound materials, and
<qex>rammed</qex> to make the foundation solid.</q>
<rj><qau>Arbuthnot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ramadan</ent><br/
\'d8<hw>Ram`a*dan"</hw> <pr>(r<acr/m`<adot/*d<acr/n")</pr>,
<pos>n.</pos> <ety>[Ar. <ets>rama<dsdot/<amac/n</ets>, or
<ets>ramaz<amac/n</ets>, properly, the hot month.]</ety> <altsp>[Written
also <asp>Ramadhan</asp>, <asp>Ramadzan</asp>, and
<asp>Rhamadan</asp>.]</altsp> <sn>1.</sn> <def>The ninth Mohammedan
month.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The great annual fast of the Mohammedans, kept
during daylight through the ninth month.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ramage</ent><br/
<hw>Ram"age</hw> <pr>(r<acr/m"<asl/j; 48)</pr>, <pos>n.</pos> <ety>[F.,
fr. L. <ets>ramus</ets> a branch.]</ety> <sn>1.</sn> <def>Boughs or
branches.</def> <mark>[Obs.]</mark> <rj><au>Crabb.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Warbling of birds in trees.</def>
<mark>[Obs.]</mark> <rj><au>Drummond.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ramage</ent><br/
<hw>Ra*mage"</hw> <pr>(r<adot/*m<amac/j")</pr>, <pos>a.</pos> <def>Wild;
untamed.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ramagious</ent><br/
<hw>Ra*ma"gi*ous</hw> <pr>(r<adot/*m<amac/"j<icr/*<ucr/s)</pr>,
<pos>a.</pos> <def>Wild; not tame.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Now is he tame that was so <qex>ramagious</qex>.</q>
<rj><qau>Remedy of Love.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ramal</ent><br/
<hw>Ra"mal</hw> <pr>(r<amac/"m<ait/l)</pr>, <pos>a.</pos> <ety>[L.
<ets>ramus</ets> branch.]</ety> <def>Of or pertaining to a ramus, or
branch; rameal.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ramayana</ent><br/
\'d8<hw>Ra*ma"ya*na</hw> <pr>(r<aum/*m<aum/"y<adot/*n<adot/)</pr>,
<pos>n.</pos> <ety>[Skr. <ets>R<amac/m<amac/ya<nsdot/a</ets>.]</ety>
<def>The more ancient of the two great epic poems in Sanskrit. The hero
and heroine are <persfn>Rama</persfn> and his wife
<persfn>Sita</persfn>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ramberge</ent><br/
<hw>Ram"berge</hw> <pr>(r<acr/m"b<etil/rj)</pr>, <pos>n.</pos> <ety>[F.,
fr. <ets>rame</ets> oar + <ets>barge</ets> barge.]</ety> <def>Formerly,
a kind of large war galley.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ramble</ent><br/
<hw>Ram"ble</hw> <pr>(r<acr/m"b'l)</pr>, <pos>v. i.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Rambled</conjf>
<pr>(r<acr/m"b'ld)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Rambling</conjf> <pr>(r<acr/m"bl<icr/ng)</pr>.]</vmorph>
<ety>[For <ets>rammle</ets>, fr. Prov. E. <ets>rame</ets> to roam. Cf.
<er>Roam</er>.]</ety> <sn>1.</sn> <def>To walk, ride, or sail, from
place to place, without any determinate object in view; to roam
carelessly or irregularly; to rove; to wander; <as>as, to
<ex>ramble</ex> about the city; to <ex>ramble</ex> over the
world.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>He that is at liberty to <qex>ramble</qex> in perfect darkness,
what is his liberty better than if driven up and down as a bubble by the
wind?</q> <rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To talk or write in a discursive, aimless
way.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To extend or grow at random.</def>
<rj><au>Thomson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To rove; roam; wander; range; stroll.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ramble</ent><br/
<hw>Ram"ble</hw>, <pos>n.</pos> <sn>1.</sn> <def>A going or moving from
place to place without any determinate business or object; an excursion
or stroll merely for recreation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Coming home, after a short Christmas <qex>ramble</qex>.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <ety>[Cf. <er>Rammel</er>.]</ety> <fld>(Coal
Mining)</fld> <def>A bed of shale over the seam.</def>
<rj><au>Raymond.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A section of woods suitable for leisurely
walking.</def><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <def>a type of dance; <as>as, the Muskrat
<ex>ramble</ex></as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Rambler</ent><br/
<hw>Ram"bler</hw> <pr>(r<acr/m"bl<etil/r)</pr>, <pos>n.</pos> <def>One
who rambles; a rover; a wanderer.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rambling</ent><br/
<hw>Ram"bling</hw> <pr>(r<acr/m"bl<icr/ng)</pr>, <pos>a.</pos>
<def>Roving; wandering; discursive; <as>as, a <ex>rambling</ex> fellow,
talk, or building</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ramblingly</ent><br/
<hw>Ram"bling*ly</hw> <pr>(r<acr/m"bl<icr/ng*l<ycr/)</pr>,
<pos>adv.</pos> <def>In a rambling manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rambooze</ent><br/
<hw>Ram"booze</hw> <pr>(r<acr/m"b<oomac/z)</pr>, <pos>n.</pos> <def>A
beverage made of wine, ale (or milk), sugar, etc.</def>
<mark>[Obs.]</mark> <rj><au>Blount.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rambutan</ent><br/
<hw>Ram*bu"tan</hw> <pr>(r<acr/m*b<oomac/"t<acr/n)</pr>, <pos>n.</pos>
<ety>[Malay <ets>ramb<umac/tan</ets>, fr. <ets>rambut</ets> hair of the
head.]</ety> <fld>(Bot.)</fld> <def>A Malayan fruit produced by the tree
<spn>Nephelium lappaceum</spn>, and closely related to the litchi nut.
It is bright red, oval in shape, covered with coarse hairs (whence the
name), and contains a pleasant acid pulp. Called also
<altname>ramboostan</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rameal</ent><br/
<hw>Ra"me*al</hw> <pr>(r<amac/"m<esl/*<ait/l)</pr>, <pos>a.</pos>
<def>Same as <er>Ramal</er>.</def> <rj><au>Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ramean</ent><br/
<hw>Ra"me*an</hw> <pr>(r<amac/"m<esl/*<ait/n)</pr>, <pos>n.</pos> <def>A
Ramist.</def> <rj><au>Shipley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ramed</ent><br/
<hw>Ramed</hw> <pr>(r<acr/md)</pr>, <pos>a.</pos> <def>Having the
frames, stem, and sternpost adjusted; -- said of a ship on the
stocks.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ramee</ent><br/
<hw>Ram"ee</hw> <pr>(r<acr/m"<esl/)</pr>, <pos>n.</pos>
<fld>(Bot.)</fld> <def>See <er>Ramie</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ramekin</ent><br/
<hw>Ram"e*kin</hw> <pr>(r<acr/m"<esl/*k<icr/n)</pr>, <pos>n.</pos>
<def>same as <er>Ramequin</er>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Rament</ent><br/
<hw>Ram"ent</hw> <pr>(r<acr/m"<eit/nt)</pr>, <pos>n.</pos> <ety>[L.
<ets>ramenta</ets>, pl.]</ety> <sn>1.</sn> <def>A scraping; a
shaving.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <pluf>pl.</pluf> <fld>(Bot.)</fld>
<def>Ramenta.</def></p>

<p><ent>Ramenta</ent><br/
\'d8<hw>Ra*men"ta</hw> <pr>(r<adot/*m<ecr/n"t<adot/)</pr>, <pos>n.
pl.</pos> <ety>[L., scrapings.]</ety> <fld>(Bot.)</fld> <def>Thin
brownish chaffy scales upon the leaves or young shoots of some plants,
especially upon the petioles and leaves of ferns.</def>
<rj><au>Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1187 pr=vmg --></p>

<p><ent>Ramentaceous</ent><br/
<hw>Ram`en*ta"ceous</hw> <pr>(r<acr/m`<ecr/n*t<amac/"sh<ucr/s)</pr>,
<pos>a.</pos> <fld>(Bot.)</fld> <def>Covered with ramenta.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rameous</ent><br/
<hw>Ra"me*ous</hw> <pr>(r<amac/"m<esl/*<ucr/s)</pr>, <pos>a.</pos>
<ety>[L. <ets>rameus</ets>, from <ets>ramus</ets> branch, bough.]</ety>
<fld>(Bot.)</fld> <def>Ramal.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ramequin</ent><br/
<hw>Ram"e*quin</hw> <pr>(r<acr/m"<esl/*k<icr/n)</pr>, <pos>n.</pos>
<ety>[F.]</ety> <sn>1.</sn> <fld>(Cookery)</fld> <def>A mixture of
cheese, eggs, etc., formed in a mold, or served on bread.</def>
<altsp>[Written also <asp>ramekin</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The porcelian or earthen mold in which ramequins are
baked and served, by extension, any dish so used.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Ramie</ent><br/
<hw>Ram"ie</hw> <pr>(r<acr/m"<esl/)</pr>, <pos>n.</pos> <ety>[From
Malay.]</ety> <fld>(Bot.)</fld> <def>The grasscloth plant
(<spn>B<oe/hmeria nivea</spn>); also, its fiber, which is very fine and
exceedingly strong; -- called also <altname>China grass</altname>, and
<altname>rhea</altname>. See <cref>Grass-cloth plant</cref>, under
<er>Grass</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ramification</ent><br/
<hw>Ram`i*fi*ca"tion</hw>
<pr>(r<acr/m`<icr/*f<icr/*k<amac/"sh<ucr/n)</pr>, <pos>n.</pos>
<ety>[Cf. F. <ets>ramification</ets>. See <er>Ramify</er>.]</ety>
<sn>1.</sn> <def>The process of branching, or the development of
branches or offshoots from a stem; also, the mode of their
arrangement.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A small branch or offshoot proceeding from a main
stock or channel; <as>as, the <ex>ramifications</ex> of an artery, vein,
or nerve</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A division into principal and subordinate classes,
heads, or departments; also, one of the subordinate parts; <as>as, the
<ex>ramifications</ex> of a subject or scheme</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The production of branchlike figures.</def>
<rj><au>Crabb.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ramiflorous</ent><br/
<hw>Ram`i*flo"rous</hw> <pr>(r<acr/m`<icr/*fl<omac/"r<ucr/s)</pr>,
<pos>a.</pos> <ety>[L. <ets>ramus</ets> branch + <ets>flos</ets>,
<ets>floris</ets>, flower.]</ety> <fld>(Bot.)</fld> <def>Flowering on
the branches.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ramiform</ent><br/
<hw>Ram"i*form</hw> <pr>(r<acr/m"<icr/*f<ocir/rm)</pr>, <pos>a.</pos>
<ety>[L. <ets>ramus</ets> branch + <ets>-form</ets>.]</ety>
<fld>(Bot.)</fld> <def>Having the form of a branch.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ramify</ent><br/
<hw>Ram"i*fy</hw> <pr>(r<acr/m"<icr/*f<imac/)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Ramified</conjf>
<pr>(-f<imac/d)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Ramifying</conjf> <pr>(?)</pr>.]</vmorph> <ety>[F.
<ets>ramifier</ets>, LL. <ets>ramificare</ets>, fr. L. <ets>ramus</ets>
a branch + <ets>-ficare</ets> (in comp.) to make. See
<er>-fy</er>.]</ety> <def>To divide into branches or subdivisions;
<as>as, to <ex>ramify</ex> an art, subject, scheme</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ramify</ent><br/
<hw>Ram"i*fy</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To shoot, or
divide, into branches or subdivisions, as the stem of a plant.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>When they [asparagus plants] . . . begin to <qex>ramify</qex>.</q>
<rj><qau>Arbuthnot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To be divided or subdivided, as a main
subject.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ramigerous</ent><br/
<hw>Ra*mig"er*ous</hw> <pr>(r<adot/*m<icr/j"<etil/r*<ucr/s)</pr>,
<pos>a.</pos> <ety>[L. <ets>ramus</ets> a branch +
<ets>-gerous</ets>.]</ety> <fld>(Bot.)</fld> <def>Bearing branches;
branched.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ramiparous</ent><br/
<hw>Ra*mip"a*rous</hw> <pr>(r<adot/*m<icr/p"<adot/*r<ucr/s)</pr>,
<pos>a.</pos> <ety>[L. <ets>ramus + parere</ets> to bear.]</ety>
<fld>(Bot.)</fld> <def>Producing branches; ramigerous.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ramist</ent><br/
<hw>Ra"mist</hw> <pr>(r<amac/"m<icr/st)</pr>, <pos>n.</pos> <def>A
follower of <person>Pierre <etsep>Ram<eacute/</etsep></person>, better
known as <person><it>Ramus</it></person>, a celebrated French scholar,
who was professor of rhetoric and philosophy at Paris in the reign of
<person>Henry II.</person>, and opposed the Aristotelians.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ramline</ent><br/
<hw>Ram"line</hw> <pr>(r<acr/m"l<icr/n)</pr>, <pos>n.</pos> <def>A line
used to get a straight middle line, as on a spar, or from stem to stern
in building a vessel.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rammel</ent><br/
<hw>Ram"mel</hw> <pr>(r<acr/m"m<ecr/l)</pr>, <pos>n.</pos> <def>Refuse
matter.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Filled with any rubbish, <qex>rammel</qex> and broken stones.</q>
<rj><qau>Holland.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rammer</ent><br/
<hw>Ram"mer</hw> <pr>(r<acr/m"m<etil/r)</pr>, <pos>n.</pos> <def>One
who, or that which, rams or drives.</def> Specifically: <sd>(a)</sd>
<def>An instrument for driving anything with force; <as>as, a
<ex>rammer</ex> for driving stones or piles, or for beating the earth to
more solidity</as>.</def> <sd>(b)</sd> <def>A rod for forcing down the
charge of a gun; a ramrod.</def> <sd>(c)</sd> <fld>(Founding)</fld>
<def>An implement for pounding the sand of a mold to render it
compact.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rammish</ent><br/
<hw>Ram"mish</hw> <pr>(r<acr/m"m<icr/sh)</pr>, <pos>a.</pos> <def>Like a
ram; hence, rank; lascivious.</def> <ldquo/Their savor is so
<xex>rammish</xex>.<rdquo/ <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rammishness</ent><br/
<hw>Ram"mish*ness</hw>, <pos>n.</pos> <def>The quality of being
rammish.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rammy</ent><br/
<hw>Ram"my</hw> <pr>(r<acr/m"m<ycr/)</pr>, <pos>a.</pos> <def>Like a
ram; rammish.</def> <rj><au>Burton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ramollescence</ent><br/
<hw>Ram`ol*les"cence</hw> <pr>(r<acr/m`<ocr/l*l<ecr/s"s<eit/ns)</pr>,
<pos>n.</pos> <ety>[F. <ets>ramollir</ets> to make soft, to soften;
pref. <ets>re-</ets> re- + <ets>amollir</ets> to soften; <ets>a</ets>
(L. <ets>ad</ets>) + <ets>mollir</ets> to soften, L. <ets>mollire</ets>,
fr. <ets>mollis</ets> soft.]</ety> <def>A softening or mollifying.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ramoon</ent><br/
<hw>Ra*moon"</hw> <pr>(r<adot/*m<oomac/n")</pr>, <pos>n.</pos>
<fld>(Bot.)</fld> <def>A small West Indian tree (<spn>Trophis
Americana</spn>) of the Mulberry family, whose leaves and twigs are used
as fodder for cattle.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ramose</ent><br/
<hw>Ra*mose"</hw> <pr>(r<adot/*m<omac/s")</pr>, <pos>a.</pos> <ety>[L.
<ets>ramosus</ets>, from <ets>ramus</ets> a branch.]</ety>
<def>Branched, as the stem or root of a plant; having lateral divisions;
consisting of, or having, branches; full of branches; ramifying;
branching; branchy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ramous</ent><br/
<hw>Ra"mous</hw> <pr>(r<amac/"m<ucr/s)</pr>, <pos>a.</pos>
<def>Ramose.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ramp</ent><br/
<hw>Ramp</hw> <pr>(r<acr/mp)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Ramped</conjf> <pr>(r<acr/mt; 215)</pr>; <pos>p. pr.
& vb. n.</pos> <conjf>Ramping</conjf>.]</vmorph> <ety>[F.
<ets>ramper</ets> to creep, OF., to climb; of German origin; cf. G.
<ets>raffen</ets> to snatch, LG. & D. <ets>rapen</ets>. See <er>Rap</er>
to snatch, and cf. <er>Romp</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>To spring; to leap; to bound; to rear; to prance; to
become rampant; hence, to frolic; to romp.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To move by leaps, or as by leaps; hence, to move
swiftly or with violence.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Their bridles they would champ,<br/
And trampling the fine element would fiercely <qex>ramp</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To climb, as a plant; to creep up.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With claspers and tendrils, they [plants] catch hold, . . . and so
<qex>ramping</qex> upon trees, they mount up to a great height.</q>
<rj><qau>Ray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ramp</ent><br/
<hw>Ramp</hw>, <pos>n.</pos> <sn>1.</sn> <def>A leap; a spring; a
hostile advance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The bold Ascalonite<br/
Fled from his lion <qex>ramp</qex>.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A highwayman; a robber.</def> <mark>[Prov.
Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A romping woman; a prostitute.</def>
<mark>[Obs.]</mark> <rj><au>Lyly.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <ety>[F. <ets>rampe</ets>.]</ety> <fld>(Arch.)</fld>
<sd>(a)</sd> <def>Any sloping member, other than a purely constructional
one, such as a continuous parapet to a staircase.</def> <sd>(b)</sd>
<def>A short bend, slope, or curve, where a hand rail or cap changes its
direction.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <ety>[F. <ets>rampe</ets>.]</ety> <fld>(Fort.)</fld>
<def>An inclined plane serving as a communication between different
interior levels.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rampacious</ent><br/
<hw>Ram*pa"cious</hw> <pr>(r<acr/m*p<amac/"sh<ucr/s)</pr>, <pos>a.</pos>
<def>High-spirited; rampageous.</def> <mark>[Slang]</mark>
<rj><au>Dickens.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rampage</ent><br/
<hw>Ramp"age</hw> <pr>(r<acr/mp"<asl/j; 48)</pr>, <pos>n.</pos>
<ety>[See <er>Ramp</er>, <pos>v.</pos>]</ety> <def>Violent or riotous
behavior; a state of excitement, passion, or debauchery; <as>as, to be
on the <ex>rampage</ex></as>.</def> <mark>[Prov. or Low]</mark>
<rj><au>Dickens.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rampage</ent><br/
<hw>Ramp"age</hw>, <pos>v. i.</pos> <def>To leap or prance about, as an
animal; to be violent; to rage.</def> <mark>[Prov. or Low]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rampageous</ent><br/
<hw>Ram*pa"geous</hw> <pr>(r<acr/m*p<amac/"j<ucr/s)</pr>, <pos>a.</pos>
<def>Characterized by violence and passion; unruly; rampant.</def>
<mark>[Prov. or Low]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>In the primitive ages of a <qex>rampageous</qex> antiquity.</q>
<rj><qau>Galt.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rampallian</ent><br/
<hw>Ram*pal"lian</hw> <pr>(r<acr/m*p<acr/l"y<ait/n)</pr>, <pos>n.</pos>
<ety>[Cf. <ets>ramp</ets> a prostitute, or <ets>rabble</ets>.]</ety>
<def>A mean wretch.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rampancy</ent><br/
<hw>Ramp"an*cy</hw> <pr>(r<acr/mp"<ait/n*s<ycr/)</pr>, <pos>n.</pos>
<def>The quality or state of being rampant; excessive action or
development; exuberance; extravagance.</def> <ldquo/They are come to
this height and <xex>rampancy</xex> of vice.<rdquo/
<rj><au>South.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rampant</ent><br/
<hw>Ramp"ant</hw> <pr>(r<acr/mp"<ait/nt)</pr>, <pos>a.</pos> <ety>[F.,
p. pr. of <ets>ramper</ets> to creep. See <er>Ramp</er>,
<pos>v.</pos>]</ety> <sn>1.</sn> <def>Ramping; leaping; springing;
rearing upon the hind legs; hence, raging; furious.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The fierce lion in his kind<br/
Which goeth <qex>rampant</qex> after his prey.</q>
<rj><qau>Gower.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>[The] lion . . . <qex>rampant</qex> shakes his brinded mane.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Ascending; climbing; rank in growth;
exuberant.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>rampant</qex> stalk is of unusual altitude.</q>
<rj><qau>I. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Her.)</fld> <def>Rising with fore paws in the air
as if attacking; -- said of a beast of prey, especially a lion. The
right fore leg and right hind leg should be raised higher than the
left.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Rampant arch</b></col>. <sd>(a)</sd> <cd>An arch which
has one abutment higher than the other</cd>. <sd>(b)</sd> <cd>Same as
<cref>Rampant vault</cref>, below.</cd> -- <col><b>Rampant
gardant</b></col> <fld>(Her.)</fld>, <cd>rampant, but with the face
turned to the front.</cd> -- <col><b>Rampant regardant</b></col>,
<cd>rampant, but looking backward.</cd> -- <col><b>Rampant
vault</b></col> <fld>(Arch.)</fld>, <cd>a continuous wagon vault, or
cradle vault, whose two abutments are located on an inclined plane, such
as the vault supporting a stairway, or forming the ceiling of a
stairway.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rampantly</ent><br/
<hw>Ramp"ant*ly</hw>, <pos>adv.</pos> <def>In a rampant
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rampart</ent><br/
<hw>Ram"part</hw> <pr>(r<acr/m"p<aum/rt)</pr>, <pos>n.</pos> <ety>[F.
<ets>rempart</ets>, OF. <ets>rempar</ets>, fr. <ets>remparer</ets> to
fortify, <ets>se remparer</ets> to fence or intrench one's self; pref.
<ets>re-</ets> re- + pref. <ets>en-</ets> (L. <ets>in</ets>) +
<ets>parer</ets> to defend, parry, prepare, L. <ets>parare</ets> to
prepare. See <er>Pare</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>That which fortifies and defends from assault; that
which secures safety; a defense or bulwark.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Fort.)</fld> <def>A broad embankment of earth round
a place, upon which the parapet is raised. It forms the substratum of
every permanent fortification.</def> <rj><au>Mahan.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Bulwark; fence; security; guard.</syn> <usage> --
<er>Rampart</er>, <er>Bulwark</er>. These words were formerly
interchanged; but in modern usage a distinction has sprung up between
them. The <xex>rampart</xex> of a fortified place is the enceinte or
entire main embankment or wall which surrounds it. The term
<xex>bulwark</xex> is now applied to peculiarly strong outworks which
project for the defense of the <xex>rampart</xex>, or main work. A
single bastion is a <xex>bulwark</xex>. In using these words
figuratively, <xex>rampart</xex> is properly applied to that which
protects by walling out; <xex>bulwark</xex> to that which stands in the
forefront of danger, to meet and repel it. Hence, we speak of a
distinguished individual as the <xex>bulwark</xex>, not the
<xex>rampart</xex>, of the state. This distinction, however, is often
disregarded.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rampart</ent><br/
<hw>Ram"part</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Ramparted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Ramparting</conjf>.]</vmorph> <def>To surround or protect with,
or as with, a rampart or ramparts.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Those grassy hills, those glittering dells,<br/
Proudly <qex>ramparted</qex> with rocks.</q>
<rj><qau>Coleridge.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Rampart gun</b></col> <fld>(Fort.)</fld>, <cd>a cannon or
large gun for use on a rampart and not as a fieldpiece.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rampe</ent><br/
<hw>Rampe</hw> <pr>(r<acr/mp)</pr>, <pos>n.</pos> <ety>[In allusion to
its supposed aphrodisiac qualities. See <er>Ramp</er>.]</ety>
<fld>(Bot.)</fld> <def>The cuckoopint.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rampier</ent><br/
<hw>Ram"pier</hw> <pr>(r<acr/m"p<emac/r)</pr>, <pos>n.</pos> <def>See
<er>Rampart</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rampion</ent><br/
<hw>Ram"pi*on</hw> <pr>(r<acr/m"p<icr/*<ucr/n)</pr>, <pos>n.</pos>
<ety>[Cf. F. <ets>raiponce</ets>, Sp. <ets>ruiponce</ets>,
<ets>reponche</ets>, L. <ets>raperonzo</ets>, NL. <ets>rapuntium</ets>,
fr. L. <ets>rapum</ets>, <ets>rapa</ets>, a turnip, rape. Cf.
<er>Rape</er> a plant.]</ety> <fld>(Bot.)</fld> <def>A plant
(<spn>Campanula Rapunculus</spn>) of the Bellflower family, with a
tuberous esculent root; -- also called
<altname>ramps</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The name is sometimes given to plants of the genus
<gen>Phyteuma</gen>, herbs of the Bellflower family, and to the American
evening primrose (<spn><OE/nothera biennis</spn>), which has run wild in
some parts of Europe.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rampire</ent><br/
<hw>Ram"pire</hw> <pr>(r<acr/m"p<imac/r)</pr>, <pos>n.</pos> <def>A
rampart.</def> <mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The Trojans round the place a <qex>rampire</qex> cast.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rampire</ent><br/
<hw>Ram"pire</hw>, <pos>v. t.</pos> <def>To fortify with a rampire; to
form into a rampire.</def> <mark>[Archaic]</mark> <au>Chapman.</au>
<ldquo/<xex>Rampired</xex> walls of gold.<rdquo/ <rj><au>R.
Browning.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rampler</ent><br/
<hw>Ram"pler</hw> <pr>(r<acr/m"pl<etil/r)</pr>, <pos>n.</pos> <def>A
rambler.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rampler</ent><br/
<hw>Ram"pler</hw>, <pos>a.</pos> <def>Roving; rambling.</def>
<mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ramrod</ent><br/
<hw>Ram"rod`</hw> <pr>(r<acr/m"r<ocr/d`)</pr>, <pos>n.</pos> <def>The
rod used in ramming home the charge in a muzzle-loading
firearm.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ramshackle</ent><br/
<hw>Ram"shac*kle</hw> <pr>(r<acr/m"sh<acr/k*k'l)</pr>, <pos>a.</pos>
<ety>[Etymol. uncertain.]</ety> <def>Loose; disjointed; falling to
pieces; out of repair.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There came . . . my lord the cardinal, in his
<qex>ramshackle</qex> coach.</q> <rj><qau>Thackeray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ramshackle</ent><br/
<hw>Ram"shac*kle</hw>, <pos>v. t.</pos> <def>To search or ransack; to
rummage.</def> <mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ramson</ent><br/
<hw>Ram"son</hw> <pr>(r<acr/m"z'n)</pr>, <pos>n.</pos> <ety>[AS.
<ets>hramsan</ets>, pl., akin to G. <ets>rams</ets>, Sw.
<ets>rams</ets>, <ets>rams</ets>l<oum/k; cf. Gr. <grk>kro`myon</grk>
onion.]</ety> <fld>(Bot.)</fld> <def>A broad-leaved species of garlic
(<spn>Allium ursinum</spn>), common in European gardens; -- called also
<altname>buckram</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ramsted</ent><br/
<hw>Ram"sted</hw> <pr>(r<acr/m"st<ecr/d)</pr>, <pos>n.</pos>
<fld>(Bot.)</fld> <def>A yellow-flowered weed; -- so named from a Mr.
Ramsted who introduced it into Pennsylvania. See <er>Toad flax</er>.
Called also <altname>Ramsted weed</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ramtil</ent><br/
<hw>Ram"til</hw> <pr>(r<acr/m"t<icr/l)</pr>, <pos>n.</pos> <ety>[Bengali
<ets>ram-til</ets>.]</ety> <def>A tropical African asteraceous shrub
(<spn>Guizotia abyssinica</spn>) cultivated for its seeds (called
<prod><ecol><b>ramtil seeds</b></ecol></prod> <it>or</it>
<prod><ecol><b>niger seeds</b></ecol></prod>) which yield a valuable oil
used for food and as an illuminant.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Ramulose</ent><br/
<hw>Ram"u*lose`</hw> <pr>(r<acr/m"<usl/*l<omac/s`)</pr>, <pos>a.</pos>
<ety>[L. <ets>ramulosus</ets>, fr. <ets>ramulus</ets>, dim. of
<ets>ramus</ets> a branch.]</ety> <fld>(Nat. Hist.)</fld> <def>Having
many small branches, or ramuli.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ramulous</ent><br/
<hw>Ram"u*lous</hw> <pr>(r<acr/m"<usl/*l<ucr/s)</pr>, <pos>a.</pos>
<fld>(Nat. Hist.)</fld> <def>Ramulose.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ramulus</ent><br/
\'d8<hw>Ram"u*lus</hw> <pr>(r<acr/m"<usl/*l<ucr/s)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Ramuli</plw>
<pr>(r<acr/m"<usl/*l<imac/)</pr>.</plu> <fld>(Zool.)</fld> <def>A small
branch, or branchlet, of corals, hydroids, and similar
organisms.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ramus</ent><br/
\'d8<hw>Ra"mus</hw> <pr>(r<amac/"m<ucr/s)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Rami</plw> <pr>(r<amac/"m<imac/)</pr>.</plu>
<fld>(Nat. Hist.)</fld> <def>A branch; a projecting part or prominent
process; a ramification.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ramuscule</ent><br/
<hw>Ra*mus"cule</hw> <pr>(r<adot/*m<ucr/s"k<usl/l)</pr>, <pos>n.</pos>
<ety>[L. <ets>ramusculus</ets>.]</ety> <fld>(Nat. Hist.)</fld> <def>A
small ramus, or branch.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ran</ent><br/
<hw>Ran</hw> <pr>(r<acr/n)</pr>, <def><pos>imp.</pos> of
<er>Run</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ran</ent><br/
<hw>Ran</hw>, <pos>n.</pos> <ety>[AS. <ets>r<amac/n</ets>.]</ety>
<def>Open robbery.</def> <mark>[Obs.]</mark>
<rj><au>Lambarde.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ran</ent><br/
<hw>Ran</hw>, <pos>n.</pos> <fld>(Naut.)</fld> <def>Yarns coiled on a
spun-yarn winch.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rana</ent><br/
\'d8<hw>Ra"na</hw> <pr>(r<amac/"n<adot/)</pr>, <pos>n.</pos> <ety>[L., a
frog.]</ety> <fld>(Zool.)</fld> <def>A genus of anurous batrachians,
including the common frogs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ranal</ent><br/
<hw>Ra"nal</hw> <pr>(r<amac/"n<ait/l)</pr>, <pos>a.</pos>
<fld>(Bot.)</fld> <def>Having a general affinity to ranunculaceous
plants.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Ranal alliance</b></col> <fld>(Bot.)</fld>, <cd>a name
proposed by Lindley for a group of natural orders, including
Ranunculaceae, Magnoliaceae, Papaveraceae, and others related to
them.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rance</ent><br/
<hw>Rance</hw> <pr>(r<acr/ns)</pr>, <pos>n.</pos> <ety>[Etymol.
uncertain.]</ety> <sn>1.</sn> <def>A prop or shore.</def>
<mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A round between the legs of a chair; also called a
<altname>spreader</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rancescent</ent><br/
<hw>Ran*ces"cent</hw> <pr>(r<acr/n*s<ecr/s"s<eit/nt)</pr>, <pos>a.</pos>
<ety>[L. <ets>rancescens</ets>, p. pr. of <ets>rancescere</ets>, v.
incho. from <ets>rancere</ets> to be rancid.]</ety> <def>Becoming rancid
or sour.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ranch</ent><br/
<hw>Ranch</hw> <pr>(r<acr/nch)</pr>, <pos>v. t.</pos> <altsp>[Written
also <asp>raunch</asp>.]</altsp> <ety>[Cf. <er>Wrench</er>.]</ety>
<def>To wrench; to tear; to sprain; to injure by violent straining or
contortion.</def> <mark>[R.]</mark> <au>Dryden.</au> <ldquo/Hasting to
<xex>raunch</xex> the arrow out.<rdquo/ <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ranch</ent><br/
<hw>Ranch</hw>, <pos>n.</pos> <ety>[See <er>Rancho</er>.]</ety> <def>A
tract of land used for grazing and the rearing of horses, cattle, or
sheep. See <er>Rancho</er>, 2.</def> <mark>[Western U. S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rancheria</ent><br/
\'d8<hw>Ran`che*ri"a</hw> <pr>(r<adot/n`ch<asl/"r<emac/"<adot/)</pr>,
<pos>n.</pos> <ety>[Sp. <ets>rancheria</ets>.]</ety> <sn>1.</sn> <def>A
dwelling place of a ranchero.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>A small settlement or collection of ranchos, or rude
huts, esp. for Indians.</def> <mark>[Sp. Amer. & Southwestern U.
S.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>3.</sn> <def>Formerly, in the Philippines, a political division
of the pagan tribes.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Ranchero</ent><br/
\'d8<hw>Ran*che"ro</hw> <pr>(r<acr/n*ch<amac/"r<osl/)</pr>,
<pos>n.</pos>; <plu><it>pl.</it> <plw>Rancheros</plw>
<pr>(r<acr/n*ch<amac/"r<omac/z)</pr>.</plu> <ety>[Sp.]</ety>
<mark>[Mexico & Western U. S.]</mark> <sn>1.</sn> <def>A herdsman; a
peasant employed on a ranch or rancho.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The owner and occupant of a ranch or
rancho.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ranchman</ent><br/
<hw>Ranch"man</hw> <pr>(r<acr/nch"m<ait/n)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Ranchmen</plw>
<pr>(r<acr/nch"m<eit/n)</pr>.</plu> <def>An owner or occupant of, or
laborer on, a ranch; a herdsman.</def> <mark>[Western U. S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rancho</ent><br/
\'d8<hw>Ran"cho</hw> <pr>(r<acr/n"ch<osl/)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Ranchos</plw> <pr>(r<acr/n"ch<omac/z)</pr>.</plu>
<ety>[Sp., properly, a mess, mess room. Cf. 2d <er>Ranch</er>.]</ety>
<sn>1.</sn> <def>A rude hut, as of posts, covered with branches or
thatch, where herdsmen or farm laborers may live or lodge at
night.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A large grazing farm where horses and cattle are
raised; -- distinguished from <contr>hacienda</contr>, a cultivated farm
or plantation.</def> <mark>[Mexico & California]</mark>
<rj><au>Bartlett.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rancid</ent><br/
<hw>Ran"cid</hw> <pr>(r<acr/n"s<icr/d)</pr>, <pos>a.</pos> <ety>[L.
<ets>rancidus</ets>, fr. <ets>rancere</ets> to be rancid or rank.]</ety>
<def>Having a rank smell or taste, from chemical change or
decomposition; musty; <as>as, <ex>rancid</ex> oil or
butter</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rancidity</ent><br/
<hw>Ran*cid"i*ty</hw> <pr>(r<acr/n*s<icr/d"<icr/*t<ycr/)</pr>,
<pos>n.</pos> <ety>[Cf. F. <ets>rancidit<eacute/</ets>.]</ety> <def>The
quality or state of being rancid; a rancid scent or flavor, as of old
oil.</def> <rj><au>Ure.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rancidly</ent><br/
<hw>Ran"cid*ly</hw> <pr>(r<acr/n"s<icr/d*l<ycr/)</pr>, <pos>adv.</pos>
<def>In a rancid manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rancidness</ent><br/
<hw>Ran"cid*ness</hw>, <pos>n.</pos> <def>The quality of being
rancid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rancor</ent><br/
<hw>Ran"cor</hw> <pr>(r<acr/<nsm/"k<etil/r)</pr>, <pos>n.</pos>
<altsp>[Written also <asp>rancour</asp>.]</altsp> <ety>[OE.
<ets>rancour</ets>, OF. <ets>rancor</ets>, <ets>rancur</ets>, F.
<ets>rancune</ets>, fr. L. <ets>rancor</ets> rancidity, rankness;
tropically, an old grudge, rancor, fr. <ets>rancere</ets> to be rank or
rancid.]</ety> <def>The deepest malignity or spite; deep-seated enmity
or malice; inveterate hatred.</def> <ldquo/To stint <xex>rancour</xex>
and dissencioun.<rdquo/ <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>It would not be easy to conceive the passion, <qex>rancor</qex>,
and malice of their tongues and hearts.</q>
<rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Enmity; hatred; ill will; malice; spite; grudge;
animosity; malignity.</syn> <usage> -- <er>Rancor</er>, <er>Enmity</er>.
<xex>Enmity</xex> and <xex>rancor</xex> both describe hostile feelings;
but <xex>enmity</xex> may be generous and open, while <xex>rancor</xex>
implies personal malice of the worst and most enduring nature, and is
the strongest word in our language to express hostile
feelings.</usage><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Rancor</qex> will out; proud prelate, in thy face<br/
I see thy fury.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Rancor</qex> is that degree of malice which preys upon the
possessor.</q> <rj><qau>Cogan.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rancorous</ent><br/
<hw>Ran"cor*ous</hw> <pr>(r<acr/<nsm/"k<etil/r*<ucr/s)</pr>,
<pos>a.</pos> <ety>[OF. <ets>rancuros</ets>.]</ety> <def>Full of rancor;
evincing, or caused by, rancor; deeply malignant; implacably spiteful or
malicious; intensely virulent.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>So flamed his eyes with rage and <qex>rancorous</qex> ire.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rancorously</ent><br/
<hw>Ran"cor*ous*ly</hw>, <pos>adv.</pos> <def>In a rancorous
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rand</ent><br/
<hw>Rand</hw> <pr>(r<acr/nd)</pr>, <pos>n.</pos> <ety>[AS.
<ets>rand</ets>, <ets>rond</ets>; akin to D., Dan., Sw., & G.
<ets>rand</ets>, Icel. <ets>r<oum/nd</ets>, and probably to E.
<ets>rind</ets>.]</ety> <sn>1.</sn> <def>A border; edge; margin.</def>
<mark>[Obs. or Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A long, fleshy piece, as of beef, cut from the flank
or leg; a sort of steak.</def> <rj><au>Beau. & Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A thin inner sole for a shoe; also, a leveling slip
of leather applied to the sole before attaching the heel.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rand</ent><br/
<hw>Rand</hw> <pr>(r<acr/nd)</pr>, <pos>n.</pos> <ety>[D.]</ety>
<pr>(<it>D. pron.</it> r<adot/nt)</pr> <def>Rim; edge; border.</def>
<mark>[South Africa]</mark></p>

<p><sn>2.</sn> <def>The monetary unit of the Union of South
Africa.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>The Rand</b></col>, <cd>a rocky gold-bearing ridge in
South Africa, about thirty miles long, on which Johannesburg is
situated; also, the gold-mining district including this
ridge.</cd></cs><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Rand</ent><br/
<hw>Rand</hw>, <pos>v. i.</pos> <ety>[See <er>Rant</er>.]</ety> <def>To
rant; to storm.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I wept, . . . and raved, and <qex>randed</qex>, and railed.</q>
<rj><qau>J. Webster.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>R and D</ent><br/
<hw>R and D</hw> <pr>(<aum/r`<acr/n*d<emac/")</pr>, <pos>n.</pos>
<ety>[<ets>r</ets>esearch <ets>and</ets> <ets>d</ets>evelopment.]</ety>
<def>research and development; -- used mostly to refer to the division
of a corporation responsible for performing research and developing new
products; -- a commonly used abbreviation.</def> <br/
<syn><b>Syn. --</b> R&D.</syn>
[<source>PJC</source>]</p>

<p><ent>Randall grass</ent><br/
<hw>Ran"dall grass`</hw> <pr>(r<acr/n"d<ait/l gr<adot/s`)</pr>.
<fld>(Bot.)</fld> <def>The meadow fescue (<spn>Festuca elatior</spn>).
See under <er>Grass</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Randan</ent><br/
<hw>Ran"dan</hw> <pr>(r<acr/n"d<acr/n)</pr>, <pos>n.</pos> <def>The
product of a second sifting of meal; the finest part of the bran.</def>
<mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Randan</ent><br/
<hw>Ran"dan</hw>, <pos>n.</pos> <def>A boat propelled by three rowers
with four oars, the middle rower pulling two.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Randing</ent><br/
<hw>Rand"ing</hw> <pr>(r<acr/nd"<icr/ng)</pr>, <pos>n.</pos> <sn>1.</sn>
<fld>(Shoemaking)</fld> <def>The act or process of making and applying
rands for shoes.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mil.)</fld> <def>A kind of basket work used in
gabions.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Random</ent><br/
<hw>Ran"dom</hw> <pr>(r<acr/n"d<ucr/m)</pr>, <pos>n.</pos> <ety>[OE.
<ets>randon</ets>, OF. <ets>randon</ets> force, violence, rapidity,
<agrave/ <ets>randon</ets>, de <ets>randon</ets>, violently, suddenly,
rapidly, prob. of German origin; cf. G. <ets>rand</ets> edge, border,
OHG. <ets>rant</ets> shield, edge of a shield, akin to E.
<ets>rand</ets>, n. See <er>Rand</er>, <pos>n.</pos>]</ety> <sn>1.</sn>
<def>Force; violence.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>For courageously the two kings newly fought with great
<qex>random</qex> and force.</q> <rj><qau>E. Hall.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A roving motion; course without definite direction;
want of direction, rule, or method; hazard; chance; -- commonly used in
the phrase <xex>at random</xex>, that is, without a settled point of
direction; at hazard.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Counsels, when they fly<br/
<qex>At random</qex>, sometimes hit most happily.</q>
<rj><qau>Herrick.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>O, many a shaft, <qex>at random</qex> sent,<br/
Finds mark the archer little meant!</q> <rj><qau>Sir W.
Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Distance to which a missile is cast; range; reach;
<as>as, the <ex>random</ex> of a rifle ball</as>.</def> <rj><au>Sir K.
Digby.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Mining)</fld> <def>The direction of a
rake-vein.</def> <rj><au>Raymond.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Random</ent><br/
<hw>Ran"dom</hw>, <pos>a.</pos> <sn>1.</sn> <def>Going at random or by
chance; done or made at hazard, or without settled direction, aim, or
purpose; hazarded without previous calculation; left to chance;
haphazard; <as>as, a <ex>random</ex> guess</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Some <qex>random</qex> truths he can impart.</q>
<rj><qau>Wordsworth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>So sharp a spur to the lazy, and so strong a bridle to the
<qex>random</qex>.</q> <rj><qau>H. Spencer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Statistics)</fld> <def>Of, pertaining to, or
resulting from a process of selection from a starting set of items, in
which the probability of selecting any one object in the starting set is
equal to the probability of selecting any other.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <fld>(Construction)</fld> <def>of unequal size or shape;
made from components of unequal size or shape.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>at random</b></col> <cd>in a manner so that all possible
results have an equal probability of occurrence; for processes, each
possible result is counted separately although the same type of result
may occur more than once .</cd> -- <col><b>Random courses</b></col>
<fld>(Masonry)</fld>, <cd>courses of stone of unequal thickness.</cd> --
<col><b>Random shot</b></col>, <cd>a shot not directed or aimed toward
any particular object, or a shot with the muzzle of the gun much
elevated.</cd> -- <col><b>Random work</b></col> <fld>(Masonry)</fld>,
<cd>stonework consisting of stones of unequal sizes fitted together, but
not in courses nor always with flat beds.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1188 pr=vmg --></p>

<p><ent>Randomize</ent><br/
<hw>Ran"dom*ize</hw>, <pos>v. t.</pos> <def>To arrange or rearrange so
that there is no predetermined order; to make random; to select by a
random process; to assign (members of a group) into subgroups by a
random process.</def><br/
<syn><b>Syn. --</b> make random.</syn><br/
[<source>PJC</source>]</p>

<p><ent>Randomly</ent><br/
<hw>Ran"dom*ly</hw> <pr>(r<acr/n"d<ucr/m*l<ycr/)</pr>, <pos>adv.</pos>
<def>In a random manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Randon</ent><br/
<hw>Ran"don</hw> <pr>(r<acr/n"d<ucr/n)</pr>, <pos>n.</pos>
<def>Random.</def> <mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Randon</ent><br/
<hw>Ran"don</hw>, <pos>v. i.</pos> <def>To go or stray at random.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ranedeer</ent><br/
<hw>Rane"deer`</hw> <pr>(r<amac/n"d<emac/r`)</pr>, <pos>n.</pos>
<def>See <er>Reindeer</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ranee</ent><br/
\'d8<hw>Ra"nee</hw> <pr>(r<aum/"n<emac/)</pr>, <pos>n.</pos> <def>Same
as <er>Rani</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ranforce</ent><br/
<hw>Ran"force`</hw> <pr>(r<acr/n"f<omac/rs`)</pr>, <pos>n.</pos>
<ety>[Cf. F. <ets>renforcer</ets>.]</ety> <def>See
<er>Re<eum/nforce</er>.</def> <mark>[Obs.]</mark>
<rj><au>Bailey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rang</ent><br/
<hw>Rang</hw> <pr>(r<acr/ng)</pr>, <def><pos>imp.</pos> of
<er>Ring</er>, <pos>v. t. & i.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Range</ent><br/
<hw>Range</hw> <pr>(r<amac/nj)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Ranged</conjf> <pr>(r<amac/njd)</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>Ranging</conjf>
<pr>(r<amac/n"j<icr/ng)</pr>.]</vmorph> <ety>[OE. <ets>rengen</ets>, OF.
<ets>rengier</ets>, F. <ets>ranger</ets>, OF. <ets>renc</ets> row, rank,
F. <ets>rang</ets>; of German origin. See <er>Rank</er>,
<pos>n.</pos>]</ety> <sn>1.</sn> <def>To set in a row, or in rows; to
place in a regular line or lines, or in ranks; to dispose in the proper
order; to rank; <as>as, to <ex>range</ex> soldiers in
line</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Maccabeus <qex>ranged</qex> his army by bands.</q> <rj><qau>2
Macc. xii. 20.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To place (as a single individual) among others in a
line, row, or order, as in the ranks of an army; -- usually, reflexively
and figuratively, (in the sense) to espouse a cause, to join a party,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It would be absurd in me to <qex>range</qex> myself on the side of
the Duke of Bedford and the corresponding society.</q>
<rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To separate into parts; to sift.</def>
<mark>[Obs.]</mark> <rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To dispose in a classified or in systematic order;
to arrange regularly; <as>as, to <ex>range</ex> plants and animals in
genera and species</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To rove over or through; <as>as, to <ex>range</ex>
the fields</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Teach him to <qex>range</qex> the ditch, and force the brake.</q>
<rj><qau>Gay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To sail or pass in a direction parallel to or near;
<as>as, to <ex>range</ex> the coast</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Compare the last two senses (5 and 6) with the French
<xex>ranger</xex> une c<ocir/te.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Biol.)</fld> <def>To be native to, or to live in;
to frequent.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Range</ent><br/
<hw>Range</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To rove at large; to
wander without restraint or direction; to roam.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Like a <qex>ranging</qex> spaniel that barks at every bird he
sees.</q> <rj><qau>Burton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To have range; to change or differ within limits; to
be capable of projecting, or to admit of being projected, especially as
to horizontal distance; <as>as, the temperature <ex>ranged</ex> through
seventy degrees Fahrenheit; the gun <ex>ranges</ex> three miles; the
shot <ex>ranged</ex> four miles.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To be placed in order; to be ranked; to admit of
arrangement or classification; to rank.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And <qex>range</qex> with humble livers in content.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To have a certain direction; to correspond in
direction; to be or keep in a corresponding line; to trend or run; --
often followed by <xex>with</xex>; <as>as, the front of a house
<ex>ranges</ex> with the street; to <ex>range</ex> along the
coast.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Which way the forests <qex>range</qex>.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Biol.)</fld> <def>To be native to, or live in, a
certain district or region; <as>as, the peba <ex>ranges</ex> from Texas
to Paraguay</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To rove; roam; ramble; wander; stroll.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Range</ent><br/
<hw>Range</hw>, <pos>n.</pos> <ety>[From <er>Range</er>, <pos>v.</pos>:
cf. F. <ets>rang<eacute/e</ets>.]</ety> <sn>1.</sn> <def>A series of
things in a line; a row; a rank; <as>as, a <ex>range</ex> of buildings;
a <ex>range</ex> of mountains.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An aggregate of individuals in one rank or degree;
an order; a class.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The next <qex>range</qex> of beings above him are the immaterial
intelligences.</q> <rj><qau>Sir M. Hale.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The step of a ladder; a rung.</def>
<rj><au>Clarendon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A kitchen grate.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He was bid at his first coming to take off the <qex>range</qex>,
and let down the cinders.</q> <rj><qau>L'Estrange.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>An extended cooking apparatus of cast iron, set in
brickwork, and affording conveniences for various ways of cooking; also,
a kind of cooking stove.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>A bolting sieve to sift meal.</def> <mark>[Obs. or
Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>A wandering or roving; a going to and fro; an
excursion; a ramble; an expedition.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He may take a <qex>range</qex> all the world over.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>That which may be ranged over; place or room for
excursion; especially, a region of country in which cattle or sheep may
wander and pasture.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>Extent or space taken in by anything excursive;
compass or extent of excursion; reach; scope; discursive power; <as>as,
the <ex>range</ex> of one's voice, or authority</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Far as creation's ample <qex>range</qex> extends.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>range</qex> and compass of Hammond's knowledge filled the
whole circle of the arts.</q> <rj><qau>Bp. Fell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A man has not enough <qex>range</qex> of thought.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <fld>(Biol.)</fld> <def>The region within which a plant
or animal naturally lives.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>11.</sn> <fld>(Gun.)</fld> <sd>(a)</sd> <def>The horizontal
distance to which a shot or other projectile is carried.</def>
<sd>(b)</sd> <def>Sometimes, less properly, the trajectory of a shot or
projectile.</def> <sd>(c)</sd> <def>A place where shooting, as with
cannons or rifles, is practiced.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>12.</sn> <def>In the public land system of the United States, a
row or line of townships lying between two successive meridian lines six
miles apart.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The meridians included in each great survey are numbered
in order east and west from the <ldquo/principal meridian<rdquo/ of that
survey, and the townships in the range are numbered north and south from
the <ldquo/base line,<rdquo/ which runs east and west; as, township No.
6, N., <xex>range</xex> 7, W., from the fifth principal
meridian.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>13.</sn> <fld>(Naut.)</fld> <def>See <cref>Range of cable</cref>,
below.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Range of accommodation</b></col> <fld>(Optics)</fld>,
<cd>the distance between the near point and the far point of distinct
vision, -- usually measured and designated by the strength of the lens
which if added to the refracting media of the eye would cause the rays
from the near point to appear as if they came from the far point.</cd>
-- <col><b>Range finder</b></col> <fld>(Gunnery)</fld>, <cd>an
instrument, or apparatus, variously constructed, for ascertaining the
distance of an inaccessible object, -- used to determine what elevation
must be given to a gun in order to hit the object; a position
finder.</cd> -- <col><b>Range of cable</b></col> <fld>(Naut.)</fld>,
<cd>a certain length of slack cable ranged along the deck preparatory to
letting go the anchor.</cd> -- <col><b>Range work</b></col>
<fld>(Masonry)</fld>, <cd>masonry of squared stones laid in courses each
of which is of even height throughout the length of the wall; --
distinguished from <xex>broken range work</xex>, which consists of
squared stones laid in courses not continuously of even height.</cd> --
<col><b>To get the range of</b></col> (an object) <fld>(Gun.)</fld>,
<cd>to find the angle at which the piece must be raised to reach (the
object) without carrying beyond.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rangement</ent><br/
<hw>Range"ment</hw> <pr>(r<amac/nj"m<eit/nt)</pr>, <pos>n.</pos>
<ety>[Cf. F. <ets>rangement</ets>.]</ety> <def>Arrangement.</def>
<mark>[Obs.]</mark> <rj><au>Waterland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ranger</ent><br/
<hw>Ran"ger</hw> <pr>(r<amac/n"j<etil/r)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>One who ranges; a rover; sometimes, one who ranges for plunder; a
roving robber.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which separates or arranges; specifically, a
sieve.</def> <mark>[Obs.]</mark> <ldquo/The tamis
<xex>ranger</xex>.<rdquo/ <rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A dog that beats the ground in search of
game.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>One of a body of mounted troops, formerly armed with
short muskets, who range over the country, and often fight on
foot.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>The keeper of a public park or forest; formerly, a
sworn officer of a forest, appointed by the king's letters patent, whose
business was to walk through the forest, recover beasts that had strayed
beyond its limits, watch the deer, present trespasses to the next court
held for the forest, etc.</def> <mark>[Eng.]</mark>
<note><ex>Rangers</ex> in U.S. national parks and national monuments
perform a similar function.</note><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Rangership</ent><br/
<hw>Ran"ger*ship</hw>, <pos>n.</pos> <def>The office of the keeper of a
forest or park.</def> <mark>[Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rangle</ent><br/
<hw>Ran"gle</hw> <pr>(r<acr/n"g'l)</pr>, <pos>v. i.</pos> <def>To range
about in an irregular manner.</def> <mark>[Obs. or Prov. Eng.]</mark>
<rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rangy</ent><br/
<hw>Ran"gy</hw> <pr>(r<amac/n"j<ycr/)</pr>, <pos>a.</pos> <ety>[From
<er>Range</er>, <pos>v. i.</pos>]</ety> <def>Inclined or able to range,
or rove about, for considerable distances; apt or suited for much
roving, -- chiefly used of cattle.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Rani</ent><br/
\'d8<hw>Ra"ni</hw> <pr>(r<aum/"n<emac/)</pr>, <pos>n.</pos> <ety>[Hind.
<ets>r<amac/n<imac/</ets>, Skr. <ets>r<amac/jn<imac/</ets>. See
<er>Rajah</er>.]</ety> <def>A queen or princess; the wife of a
rajah.</def> <altsp>[Written also <asp>ranee</asp>.]</altsp>
<mark>[India]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ranine</ent><br/
<hw>Ra"nine</hw> <pr>(r<amac/"n<imac/n)</pr>, <pos>a.</pos> <ety>[L.
<ets>rana</ets> a frog.]</ety> <sn>1.</sn> <fld>(Zool.)</fld> <def>Of or
pertaining to the frogs and toads.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Anat.)</fld> <def>Pertaining to, or designating, a
swelling under the tongue; also, pertaining to the region where the
swelling occurs; -- applied especially to branches of the lingual artery
and lingual vein.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rank</ent><br/
<hw>Rank</hw> <pr>(r<acr/<nsm/k)</pr>, <pos>a.</pos>
<amorph>[<pos>Compar.</pos> <adjf>Ranker</adjf>
<pr>(r<acr/<nsm/k"<etil/r)</pr>; <pos>superl.</pos>
<adjf>Rankest</adjf>.]</amorph> <ety>[AS. <ets>ranc</ets> strong, proud;
cf. D. <ets>rank</ets> slender, Dan. <ets>rank</ets> upright, erect,
Prov. G. <ets>rank</ets> slender, Icel. <ets>rakkr</ets> slender, bold.
The meaning seems to have been influenced by L. <ets>rancidus</ets>, E.
<ets>rancid</ets>.]</ety> <sn>1.</sn> <def>Luxuriant in growth; of
vigorous growth; exuberant; grown to immoderate height; <as>as,
<ex>rank</ex> grass; <ex>rank</ex> weeds.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>And, behold, seven ears of corn came up upon one stalk,
<qex>rank</qex> and good.</q> <rj><qau>Gen. xli. 5.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Raised to a high degree; violent; extreme; gross;
utter; <as>as, <ex>rank</ex> heresy</as>.</def> <ldquo/<xex>Rank</xex>
nonsense.<rdquo/ <au>Hare.</au> <ldquo/I do forgive thy
<xex>rankest</xex> fault.<rdquo/ <au>Shak.</au><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Causing vigorous growth; producing luxuriantly; very
rich and fertile; <as>as, <ex>rank</ex> land</as>.</def>
<rj><au>Mortimer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Strong-scented; rancid; musty; <as>as, oil of a
<ex>rank</ex> smell; <ex>rank</ex>-smelling rue.</as></def>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Strong to the taste.</def> <ldquo/Divers sea fowls
taste <xex>rank</xex> of the fish on which they feed.<rdquo/
<rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Inflamed with venereal appetite.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Rank modus</b></col> <fld>(Law)</fld>, <cd>an excessive
and unreasonable modus. See <er>Modus</er>, 3.</cd> -- <mcol><col><b>To
set</b></col> (the iron of a plane, etc.) <col><b>rank</b></col></mcol>,
<cd>to set so as to take off a thick shaving.</cd>
<au>Moxon.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rank</ent><br/
<hw>Rank</hw>, <pos>adv.</pos> <def>Rankly; stoutly; violently.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>That rides so <qex>rank</qex> and bends his lance so fell.</q>
<rj><qau>Fairfax.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rank</ent><br/
<hw>Rank</hw>, <pos>n.</pos> <ety>[OE. <ets>renk</ets>, <ets>reng</ets>,
OF. <ets>renc</ets>, F. <ets>rang</ets>, fr. OHG. <ets>hring</ets> a
circle, a circular row, G. <ets>ring</ets>. See <er>Ring</er>, and cf.
<er>Range</er>, <pos>n. & v.</pos>]</ety> <sn>1.</sn> <def>A row or
line; a range; an order; a tier; <as>as, a <ex>rank</ex> of
osiers</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Many a mountain nigh<br/
Rising in lofty <qex>ranks</qex>, and loftier still.</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mil.)</fld> <def>A line of soldiers ranged side by
side; -- opposed to <xex>file</xex>. See 1st <er>File</er>, 1
<sd>(a)</sd>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Fierce, fiery warriors fought upon the clouds,<br/
In <qex>ranks</qex> and squadrons and right form of war.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Grade of official standing, as in the army, navy, or
nobility; <as>as, the <ex>rank</ex> of general; the <ex>rank</ex> of
admiral.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>An aggregate of individuals classed together; a
permanent social class; an order; a division; <as>as, <ex>ranks</ex> and
orders of men; the highest and the lowest <ex>ranks</ex> of men, or of
other intelligent beings.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Degree of dignity, eminence, or excellence; position
in civil or social life; station; degree; grade; <as>as, a writer of the
first <ex>rank</ex>; a lawyer of high <ex>rank</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>These all are virtues of a meaner <qex>rank</qex>.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Elevated grade or standing; high degree; high social
position; distinction; eminence; <as>as, a man of
<ex>rank</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Rank and file</b></col>. <sd>(a)</sd> <fld>(Mil.)</fld>
<cd>The whole body of common soldiers, including also corporals. In a
more extended sense, it includes sergeants also, excepting the
noncommissioned staff.</cd><-- analogously, the lowest ranking members
of any organization --> <sd>(b)</sd> <cd>See under 1st
<er>File</er>.</cd> -- <col><b>The ranks</b></col>, <cd>the order or
grade of common soldiers; <as>as, to reduce a noncommissioned officer to
<ex>the ranks</ex></as>.</cd> -- <col><b>To fill the ranks</b></col>,
<cd>to supply the whole number, or a competent number.</cd> --
<col><b>To take rank of</b></col>, <cd>to have precedence over, or to
have the right of taking a higher place than.</cd></cs><-- <col><b>pull
rank</b></col>, to insist on one's own prerogative or plan of action, by
right of a higher rank than that of one suggesting a different plan
--><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rank</ent><br/
<hw>Rank</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Ranked</conjf> <pr>(r<acr/<nsm/kt)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Ranking</conjf>.]</vmorph> <sn>1.</sn> <def>To place
abreast, or in a line.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To range in a particular class, order, or division;
to class; also, to dispose methodically; to place in suitable classes or
order; to classify.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Ranking</qex> all things under general and special heads.</q>
<rj><qau>I. Watts.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Poets were <qex>ranked</qex> in the class of philosophers.</q>
<rj><qau>Broome.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Heresy is <qex>ranked</qex> with idolatry and witchcraft.</q>
<rj><qau>Dr. H. More.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To take rank of; to outrank.</def>
<mark>[U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rank</ent><br/
<hw>Rank</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To be ranged; to be set
or disposed, as in a particular degree, class, order, or
division.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Let that one article <qex>rank</qex> with the rest.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To have a certain grade or degree of elevation in
the orders of civil or military life; to have a certain degree of esteem
or consideration; <as>as, he <ex>ranks</ex> with the first class of
poets; he <ex>ranks</ex> high in public estimation.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ranker</ent><br/
<hw>Rank"er</hw> <pr>(r<acr/<nsm/k"<etil/r)</pr>, <pos>n.</pos> <def>One
who ranks, or disposes in ranks; one who arranges.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rankle</ent><br/
<hw>Ran"kle</hw> <pr>(r<acr/<nsm/"k'l)</pr>, <pos>v. i.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Rankled</conjf>
<pr>(-k'ld)</pr>; <pos>p. pr. & vb. n.</pos> <conjf>Rankling</conjf>
<pr>(-kl<icr/ng)</pr>.]</vmorph> <ety>[From <er>Rank</er>,
<pos>a.</pos>]</ety> <sn>1.</sn> <def>To become, or be, rank; to grow
rank or strong; to be inflamed; to fester; -- used literally and
figuratively.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A malady that burns and <qex>rankles</qex> inward.</q>
<rj><qau>Rowe.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>This would have left a <qex>rankling</qex> wound in the hearts of
the people.</q> <rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To produce a festering or inflamed effect; to cause
a sore; -- used literally and figuratively; <as>as, a splinter
<ex>rankles</ex> in the flesh; the words <ex>rankled</ex> in his
bosom.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rankle</ent><br/
<hw>Ran"kle</hw> <pr>(r<acr/<nsm/"k'l)</pr>, <pos>v. t.</pos> <def>To
cause to fester; to make sore; to inflame.</def> <mark>[R.]</mark>
<rj><au>Beau. & Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rankly</ent><br/
<hw>Rank"ly</hw> <pr>(r<acr/<nsm/k"l<ycr/)</pr>, <pos>adv.</pos>
<def>With rank or vigorous growth; luxuriantly; hence, coarsely;
grossly; <as>as, weeds grow <ex>rankly</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rankness</ent><br/
<hw>Rank"ness</hw>, <pos>n.</pos> <ety>[AS. <ets>rancness</ets>
pride.]</ety> <def>The condition or quality of being rank.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rannel</ent><br/
<hw>Ran"nel</hw> <pr>(r<acr/n"n<ecr/l)</pr>, <pos>n.</pos> <def>A
prostitute.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ranny</ent><br/
<hw>Ran"ny</hw> <pr>(r<acr/n"n<ycr/)</pr>, <pos>n.</pos> <ety>[L.
<ets>araneus mus</ets>, a kind of small mouse.]</ety> <fld>(Zool.)</fld>
<def>The erd shrew.</def> <mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ransack</ent><br/
<hw>Ran"sack</hw> <pr>(r<acr/n"s<acr/k)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Ransacked</conjf>
<pr>(-s<acr/kt)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Ransacking</conjf>.]</vmorph> <ety>[OE. <ets>ransaken</ets>,
Icel. <ets>rannsaka</ets> to explore, examine; <ets>rann</ets> a house
(akin to Goth. <ets>razn</ets> house, AS. <ets>r<ae/sn</ets> plank,
beam) + the root of <ets>s<ae/kja</ets> to seek, akin to E.
<ets>seek</ets>. See <er>Seek</er>, and cf. <er>Rest</er> repose.]</ety>
<sn>1.</sn> <def>To search thoroughly; to search every place or part of;
<as>as, to <ex>ransack</ex> a house</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>ransack</qex> every corner of their . . . hearts.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To plunder; to pillage completely.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Their vow is made<br/
To <qex>ransack</qex> Troy.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To violate; to ravish; to defiour.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Rich spoil of <qex>ransacked</qex> chastity.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ransack</ent><br/
<hw>Ran"sack</hw>, <pos>v. i.</pos> <def>To make a thorough
search.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>ransack</qex> in the tas [heap] of bodies dead.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ransack</ent><br/
<hw>Ran"sack</hw>, <pos>n.</pos> <def>The act of ransacking, or state of
being ransacked; pillage.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Even your father's house<br/
Shall not be free from <qex>ransack</qex>.</q> <rj><qau>J.
Webster.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ransom</ent><br/
<hw>Ran"som</hw> <pr>(r<acr/n"s<ucr/m)</pr>, <pos>n.</pos> <ety>[OE.
<ets>raunson</ets>, <ets>raunsoun</ets>, OF. <ets>ran<cced/on</ets>,
<ets>raen<cced/on</ets>, <ets>raan<cced/on</ets>, F.
<ets>ran<cced/on</ets>, fr. L. <ets>redemptio</ets>, fr.
<ets>redimere</ets> to redeem. See <er>Redeem</er>, and cf.
<er>Redemption</er>.]</ety> <sn>1.</sn> <def>The release of a captive,
or of captured property, by payment of a consideration; redemption;
<as>as, prisoners hopeless of <ex>ransom</ex></as>.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The money or price paid for the redemption of a
prisoner, or for goods captured by an enemy; payment for freedom from
restraint, penalty, or forfeit.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thy <qex>ransom</qex> paid, which man from death redeems.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>His captivity in Austria, and the heavy <qex>ransom</qex> he paid
for his liberty.</q> <rj><qau>Sir J. Davies.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(O. Eng. Law)</fld> <def>A sum paid for the pardon
of some great offense and the discharge of the offender; also, a fine
paid in lieu of corporal punishment.</def>
<rj><au>Blackstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Ransom bill</b></col> <fld>(Law)</fld>, <cd>a war
contract, valid by the law of nations, for the ransom of property
captured at sea and its safe conduct into port.</cd>
<rj><au>Kent.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ransom</ent><br/
<hw>Ran"som</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Ransomed</conjf> <pr>(-s<ucr/md)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Ransoming</conjf>.]</vmorph> <ety>[Cf. F.
<ets>ran<cced/onner</ets>. See <er>Ransom</er>, <pos>n.</pos>]</ety>
<sn>1.</sn> <def>To redeem from captivity, servitude, punishment, or
forfeit, by paying a price; to buy out of servitude or penalty; to
rescue; to deliver; <as>as, to <ex>ransom</ex> prisoners from an
enemy</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To exact a ransom for, or a payment on.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Such lands as he had rule of he <qex>ransomed</qex> them so
grievously, and would tax the men two or three times in a year.</q>
<rj><qau>Berners.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ransomable</ent><br/
<hw>Ran"som*a*ble</hw> <pr>(-<adot/*b'l)</pr>, <pos>a.</pos> <def>Such
as can be ransomed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ransomer</ent><br/
<hw>Ran"som*er</hw> <pr>(-<etil/r)</pr>, <pos>n.</pos> <def>One who
ransoms or redeems.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ransomless</ent><br/
<hw>Ran"som*less</hw>, <pos>a.</pos> <def>Incapable of being ransomed;
without ransom.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rant</ent><br/
<hw>Rant</hw> <pr>(r<acr/nt)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Ranted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Ranting</conjf>.]</vmorph> <ety>[OD. <ets>ranten</ets>,
<ets>randen</ets>, to dote, to be enraged.]</ety> <def>To rave in
violent, high-sounding, or extravagant language, without dignity of
thought; to be noisy, boisterous, and bombastic in talk or declamation;
<as>as, a <ex>ranting</ex> preacher</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Look where my <qex>ranting</qex> host of the Garter comes!</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rant</ent><br/
<hw>Rant</hw>, <pos>n.</pos> <def>High-sounding language, without
importance or dignity of thought; boisterous, empty declamation;
bombast; <as>as, the <ex>rant</ex> of fanatics</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This is a stoical <qex>rant</qex>, without any foundation in the
nature of man or reason of things.</q>
<rj><qau>Atterbury.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ranter</ent><br/
<hw>Rant"er</hw> <pr>(r<acr/nt"<etil/r)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>A noisy talker; a raving declaimer.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Eccl. Hist.)</fld> <sd>(a)</sd> <def>One of a
religious sect which sprung up in 1645; -- called also
<altname>Seekers</altname>. See <er>Seeker</er>.</def> <sd>(b)</sd>
<def>One of the Primitive Methodists, who seceded from the Wesleyan
Methodists on the ground of their deficiency in fervor and zeal; -- so
called in contempt.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ranterism</ent><br/
<hw>Rant"er*ism</hw> <pr>(r<acr/nt"<etil/r*<icr/z'm)</pr>, <pos>n.</pos>
<fld>(Eccl. Hist.)</fld> <def>The practice or tenets of the
Ranters.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rantingly</ent><br/
<hw>Rant"ing*ly</hw>, <pos>adv.</pos> <def>In a ranting
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rantipole</ent><br/
<hw>Rant"i*pole</hw> <pr>(r<acr/nt"<icr/*p<omac/l)</pr>, <pos>n.</pos>
<ety>[<ets>Ranty</ets> + <ets>pole</ets>, <ets>poll</ets>, head.]</ety>
<def>A wild, romping young person.</def> <mark>[Low]</mark>
<rj><au>Marryat.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rantipole</ent><br/
<hw>Rant"i*pole</hw>, <pos>a.</pos> <def>Wild; roving; rakish.</def>
<mark>[Low]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rantipole</ent><br/
<hw>Rant"i*pole</hw>, <pos>v. i.</pos> <def>To act like a
rantipole.</def> <mark>[Low]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>She used to <qex>rantipole</qex> about the house.</q>
<rj><qau>Arbuthnot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rantism</ent><br/
<hw>Rant"ism</hw> <pr>(r<acr/nt"<icr/z'm)</pr>, <pos>n.</pos>
<fld>(Eccl. Hist.)</fld> <def>Ranterism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ranty</ent><br/
<hw>Rant"y</hw> <pr>(r<acr/nt"<ycr/)</pr>, <pos>a.</pos> <def>Wild;
noisy; boisterous.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ranula</ent><br/
\'d8<hw>Ran"u*la</hw> <pr>(r<acr/n"<usl/*l<adot/)</pr>, <pos>n.</pos>
<ety>[L., a little frog, a little swelling on the tongue of cattle, dim.
of <ets>rana</ets> a frog.]</ety> <fld>(Med.)</fld> <def>A cyst formed
under the tongue by obstruction of the duct of the submaxillary
gland.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ranunculaceous</ent><br/
<hw>Ra*nun`cu*la"ceous</hw>
<pr>(r<adot/*n<ucr/<nsm/`k<usl/*l<amac/"sh<ucr/s)</pr>, <pos>a.</pos>
<ety>[See <er>Ranunculus</er>.]</ety> <fld>(Bot.)</fld> <def>Of or
pertaining to a natural order of plants (<spn>Ranunculaceae</spn>), of
which the buttercup is the type, and which includes also the virgin's
bower, the monkshood, larkspur, anemone, meadow rue, and
peony.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ranunculus</ent><br/
<hw>Ra*nun"cu*lus</hw> <pr>(r<adot/*n<ucr/<nsm/"k<usl/*l<ucr/s)</pr>,
<pos>n.</pos>; <plu><it>pl.</it> E. <plw>Ranunculuses</plw>
<pr>(r<adot/*n<ucr/<nsm/"k<usl/*l<ucr/s*<ecr/z)</pr>, L.
<plw>Ranunculi</plw> <pr>(-l<imac/)</pr>.</plu> <ety>[L., a little frog,
a medicinal plant, perhaps crowfoot, dim. of <ets>rana</ets> a frog; cf.
<ets>raccare</ets> to roar.]</ety> <fld>(Bot.)</fld> <def>A genus of
herbs, mostly with yellow flowers, including crowfoot, buttercups, and
the cultivated ranunculi (<spn>Ranunculus Asiaticus</spn>,
<spn>Ranunculus aconitifolius</spn>, etc.) in which the flowers are
double and of various colors.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1189 pr=vmg --></p>

<p><ent>Ranz des vaches</ent><br/
\'d8<hw>Ranz" des` vaches"</hw> <pr>(r<aum/Ns" d<asl/` v<adot/sh")</pr>.
<ety>[F., the ranks or rows of cows, the name being given from the fact
that the cattle, when answering the musical call of their keeper, move
towards him in a row, preceded by those wearing bells.]</ety> <def>The
name for numerous simple, but very irregular, melodies of the Swiss
mountaineers, blown on a long tube called the <xex>Alpine horn</xex>,
and sometimes sung.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rap</ent><br/
<hw>Rap</hw> <pr>(r<acr/p)</pr>, <pos>n.</pos> <ety>[Etymol.
uncertain.]</ety> <def>A lay or skein containing 120 yards of
yarn.</def> <rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rap</ent><br/
<hw>Rap</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Rapped</conjf> <pr>(r<acr/pt)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Rapping</conjf>.]</vmorph> <ety>[Akin to Sw. <ets>rappa</ets> to
strike, <ets>rapp</ets> stroke, Dan. <ets>rap</ets>, perhaps of
imitative origin.]</ety> <def>To strike with a quick, sharp blow; to
knock; <as>as, to <ex>rap</ex> on the door</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rap</ent><br/
<hw>Rap</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To strike with a quick
blow; to knock on.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With one great peal they <qex>rap</qex> the door.</q>
<rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Founding)</fld> <def>To free (a pattern) in a mold
by light blows on the pattern, so as to facilitate its
removal.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rap</ent><br/
<hw>Rap</hw>, <pos>n.</pos> <def>A quick, smart blow; a knock.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rap</ent><br/
<hw>Rap</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Rapped</conjf> <pr>(r<acr/pt)</pr>, usually written
<conjf>Rapt</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Rapping</conjf>.]</vmorph> <ety>[OE. <ets>rapen</ets>; akin to
LG. & D. <ets>rapen</ets> to snatch, G. <ets>raffen</ets>, Sw.
<ets>rappa</ets>; cf. Dan. <ets>rappe sig</ets> to make haste, and Icel.
<ets>hrapa</ets> to fall, to rush, hurry. The word has been confused
with L. <ets>rapere</ets> to seize. Cf. <er>Rape</er> robbery,
<er>Rapture</er>, <er>Raff</er>, <pos>v.</pos>, <er>Ramp</er>,
<pos>v.</pos>]</ety> <sn>1.</sn> <def>To snatch away; to seize and hurry
off.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And through the Greeks and Ilians they <qex>rapt</qex><br/
The whirring chariot.</q> <rj><qau>Chapman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>From Oxford I was <qex>rapt</qex> by my nephew, Sir Edmund Bacon,
to Redgrove.</q> <rj><qau>Sir H. Wotton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To hasten.</def> <mark>[Obs.]</mark> <rj><au>Piers
Plowman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To seize and bear away, as the mind or thoughts; to
transport out of one's self; to affect with ecstasy or rapture; <as>as,
<ex>rapt</ex> into admiration</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I'm <qex>rapt</qex> with joy to see my Marcia's tears.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Rapt</qex> into future times, the bard begun.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To exchange; to truck.</def> <mark>[Obs. &
Low]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To engage in a discussion, converse.</def><br/
[<source>PJC</source>]</p>

<p><sn>6.</sn> <fu>(ca. 1985)</fu> <def>to perform a type of rhythmic
talking, often with accompanying rhythm instruments. It is considered by
some as a type of music; see <er>rap music</er>.</def><br/
[<source>PJC</source>]</p>

<cs><p><mcol><col><b>To rap and ren</b></col>, <col><b>To rap and
rend</b></col></mcol>. <ety>[Perhaps fr. Icel. <ets>hrapa</ets> to hurry
and <ets>r<ae/na</ets> plunder, fr. <ets>r<amac/n</ets> plunder, E.
<ets>ran</ets>.]</ety> <cd>To seize and plunder; to snatch by
violence.</cd> <au>Dryden.</au> <ldquo/[Ye] waste all that ye may
<xex>rape and renne</xex>.<rdquo/ <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>All they could <qex>rap and rend</qex> and pilfer.</q>
<rj><qau>Hudibras.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <col><b>To rap out</b></col>, <cd>to utter with sudden violence,
as an oath.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>A judge who <qex>rapped out</qex> a great oath.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p></cs>

<p><ent>Rap</ent><br/
<hw>Rap</hw>, <pos>n.</pos> <ety>[Perhaps contr. fr.
<ets>raparee</ets>.]</ety> <def>A popular name for any of the tokens
that passed current for a half-penny in Ireland in the early part of the
eighteenth century; any coin of trifling value.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Many counterfeits passed about under the name of
<qex>raps</qex>.</q> <rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Tie it [her money] up so tight that you can't touch a
<qex>rap</qex>, save with her consent.</q> <rj><qau>Mrs.
Alexander.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Not to care a rap</b></col>, <cd>to care nothing.</cd> --
<col><b>Not worth a rap</b></col>, <cd>worth nothing.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rap</ent><br/
<hw>Rap</hw>, <pos>n.</pos> <sn>1.</sn> <def>conversation; also,
rapping.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <fu>(ca. 1985)</fu> <def>a type of rhythmic talking,
often with accompanying rhythm instruments; <altname>rap
music</altname>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Rapaces</ent><br/
\'d8<hw>Ra*pa"ces</hw> <pr>(r<adot/*p<amac/"s<emac/z)</pr>, <pos>n.
pl.</pos> <ety>[NL. See <er>Rapacious</er>.]</ety> <fld>(Zool.)</fld>
<def>Same as <er>Accipitres</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rapacious</ent><br/
<hw>Ra*pa"cious</hw> <pr>(r<adot/*p<amac/"sh<ucr/s)</pr>, <pos>a.</pos>
<ety>[L. <ets>rapax</ets>, <ets>-acis</ets>, from <ets>rapere</ets> to
seize and carry off, to snatch away. See <er>Rapid</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Given to plunder; disposed or accustomed to seize by
violence; seizing by force.</def> <ldquo/ The downfall of the
<xex>rapacious</xex> and licentious Knights Templar.<rdquo/
<rj><au>Motley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Accustomed to seize food; subsisting on prey, or
animals seized by violence; <as>as, a tiger is a <ex>rapacious</ex>
animal; a <ex>rapacious</ex> bird.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Avaricious; grasping; extortionate; also, greedy;
ravenous; voracious; <as>as, <ex>rapacious</ex> usurers; a
<ex>rapacious</ex> appetite.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>[Thy Lord] redeem thee quite from Death's <qex>rapacious</qex>
claim</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Greedy; grasping; ravenous; voracious.</syn><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Ra*pa"cious*ly</wf>, <pos>adv.</pos> --
<wf>Ra*pa"cious*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rapacity</ent><br/
<hw>Ra*pac"i*ty</hw> <pr>(r<adot/*p<acr/s"<icr/*t<ycr/)</pr>,
<pos>n.</pos> <ety>[L. <ets>rapacitas</ets>: cf. F.
<ets>rapacit<eacute/</ets>. See <er>Rapacious</er>.]</ety> <sn>1.</sn>
<def>The quality of being rapacious; rapaciousness; ravenousness;
<as>as, the <ex>rapacity</ex> of pirates; the <ex>rapacity</ex> of
wolves.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The act or practice of extorting or exacting by
oppressive injustice; exorbitant greediness of gain.</def> <ldquo/The
<xex>rapacity</xex> of some ages.<rdquo/ <rj><au>Sprat.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raparee</ent><br/
<hw>Rap`a*ree"</hw> <pr>(r<acr/p`<adot/*r<emac/")</pr>, <pos>n.</pos>
<def>See <er>Rapparee</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rape</ent><br/
<hw>Rape</hw> <pr>(r<amac/p)</pr>, <pos>n.</pos> <ety>[F.
<ets>r<acir/pe</ets> a grape stalk.]</ety> <sn>1.</sn> <def>Fruit, as
grapes, plucked from the cluster.</def> <rj><au>Ray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The refuse stems and skins of grapes or raisins from
which the must has been expressed in wine making.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A filter containing the above refuse, used in
clarifying and perfecting malt, vinegar, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Rape wine</b></col>, <cd>a poor, thin wine made from the
last dregs of pressed grapes.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rape</ent><br/
<hw>Rape</hw>, <pos>n.</pos> <ety>[Akin to <ets>rap</ets> to snatch, but
confused with L. <ets>rapere</ets>. See <er>Rap</er> to snatch.]</ety>
<sn>1.</sn> <def>The act of seizing and carrying away by force; violent
seizure; robbery.</def><-- [Rare] --><br/
[<source>1913 Webster</source>]</p>

<p><q>And ruined orphans of thy <qex>rapes</qex> complain.</q>
<rj><qau>Sandys.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>Sexual connection with a woman
without her consent. See <cref>Age of consent</cref>, under
<er>Consent</er>, <pos>n.</pos></def> <-- (b) Any sexual intercourse
forced on a person, whether male or female (also called forcible rape,
or sexual assault, and sometimes, as a euphemism, criminal assault); Any
sexual intercourse performed with a person who is under the age of
consent, whether male or female, is <cref>statutory rape</cref>. --><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which is snatched away.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Where now are all my hopes? O, never more<br/
Shall they revive! nor death her <qex>rapes</qex> restore.</q>
<rj><qau>Sandys.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Movement, as in snatching; haste; hurry.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <mark>(Fig., Colloq.)</mark> <def>An action causing
results harmful to a person or thing; as, the <ex>rape</ex> of the land
by mining companies.</def><br/
[<source>PJC</source>]</p>

<p><ent>Rape</ent><br/
<hw>Rape</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To commit rape upon; to
ravish.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <mark>(Fig., Colloq.)</mark> <def>To perform an action
causing results harmful or very unpleasant to a person or thing; <as>as,
women <ex>raped</ex> first by their assailants, and then by the Justice
system.</as> Corresponds to 2nd <er>rape</er>, <pos>n.</pos>
5.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>To rape and ren</b></col>. <cd>See under <er>Rap</er>,
<pos>v. t.</pos>, to snatch.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rape</ent><br/
<hw>Rape</hw>, <pos>v. i.</pos> <def>To rob; to pillage.</def>
<mark>[Obs.]</mark> <rj><au>Heywood.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rape</ent><br/
<hw>Rape</hw>, <pos>n.</pos> <ety>[Icel. <ets>hreppr</ets> village,
district; cf. Icel. <ets>hreppa</ets> to catch, obtain, AS.
<ets>hrepian</ets>, <ets>hreppan</ets>, to touch.]</ety> <def>One of six
divisions of the county of Sussex, England, intermediate between a
hundred and a shire.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rape</ent><br/
<hw>Rape</hw>, <pos>n.</pos> <ety>[L. <ets>rapa</ets>, <ets>rapum</ets>,
akin to Gr. <grk>"ra`pys</grk>, <grk>"ra`fys</grk>, G.
<ets>r<uum/be</ets>.]</ety> <fld>(Bot.)</fld> <def>A name given to a
variety or to varieties of a plant of the turnip kind, grown for seeds
and herbage. The seeds are used for the production of rape oil, and to a
limited extent for the food of cage birds.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ These plants, with the edible turnip, have been
variously named, but are all now believed to be derived from the
<spn>Brassica campestris</spn> of Europe, which by some is not
considered distinct from the wild stock (<spn>Brassica oleracea</spn>)
of the cabbage. See <er>Cole</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Broom rape</b></col>. <fld>(Bot.)</fld> <cd>See <er>Broom
rape</er>, in the Vocabulary.</cd> -- <col><b>Rape cake</b></col>,
<cd>the refuse remaining after the oil has been expressed from the rape
seed.</cd> -- <col><b>Rape root</b></col>. <cd>Same as
<er>Rape</er>.</cd> -- <col><b>Summer rape</b></col>. <fld>(Bot.)</fld>
<cd>See <er>Colza</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rapeful</ent><br/
<hw>Rape"ful</hw> <pr>(r<amac/p"f<usdot/l)</pr>, <pos>a.</pos>
<sn>1.</sn> <def>Violent.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Given to the commission of rape.</def>
<rj><au>Byron.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rapfully</ent><br/
<hw>Rap"ful*ly</hw> <pr>(r<acr/p"f<usdot/l*l<ycr/)</pr>, <pos>adv.</pos>
<def>Violently.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raphaelesque</ent><br/
<hw>Raph`a*el*esque"</hw> <pr>(r<acr/f`<adot/*<ecr/l*<ecr/sk")</pr>,
<pos>a.</pos> <def>Like Raphael's works; in Raphael's manner of
painting.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raphaelism</ent><br/
<hw>Raph"a*el*ism</hw> <pr>(r<acr/f"<adot/*<ecr/l*<icr/z'm)</pr>,
<pos>n.</pos> <def>The principles of painting introduced by Raphael, the
Italian painter.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raphaelite</ent><br/
<hw>Raph"a*el*ite</hw> <pr>(r<acr/f"<adot/*<ecr/l*<imac/t)</pr>,
<pos>n.</pos> <def>One who advocates or adopts the principles of
Raphaelism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raphany</ent><br/
<hw>Raph"a*ny</hw> <pr>(r<acr/f"<adot/*n<ycr/)</pr>, <pos>n.</pos>
<ety>[Cf. F. <ets>raphanie</ets>.]</ety> <fld>(Med.)</fld> <def>A
convulsive disease, attended with ravenous hunger, not uncommon in
Sweden and Germany. It was so called because supposed to be caused by
eating corn with which seeds of jointed charlock (<spn>Raphanus
raphanistrum</spn>) had been mixed, but the condition is now known to be
a form of ergotism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raphe</ent><br/
<hw>Ra"phe</hw> <pr>(r<amac/"f<esl/)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <grk>"rafh`</grk> a seam or suture, fr. <grk>"ra`ptein</grk> to sew
or stitch together.]</ety> <sn>1.</sn> <fld>(Anat.)</fld> <def>A line,
ridge, furrow, or band of fibers, especially in the median line; <as>as,
the <ex>raphe</ex> of the tongue</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>Same as <er>Rhaphe</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raphides</ent><br/
\'d8<hw>Raph"i*des</hw> <pr>(r<acr/f"<icr/*d<emac/z)</pr>, <pos>n.
pl.</pos> <ety>[F. <ets>raphide</ets>.]</ety> <fld>(Bot.)</fld> <def>See
<er>Rhaphides</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rapid</ent><br/
<hw>Rap"id</hw> <pr>(r<acr/p"<icr/d)</pr>, <pos>a.</pos> <ety>[L.
<ets>rapidus</ets>, fr. <ets>rapere</ets> to seize and carry off, to
snatch or hurry away; perhaps akin to Gr. <grk>'arpa`zein</grk>: cf. F.
<ets>rapide</ets>. Cf. <er>Harpy</er>, <er>Ravish</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Very swift or quick; moving with celerity; fast;
<as>as, a <ex>rapid</ex> stream; a <ex>rapid</ex> flight; a
<ex>rapid</ex> motion.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Ascend my chariot; guide the <qex>rapid</qex> wheels.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Advancing with haste or speed; speedy in
progression; in quick sequence; <as>as, <ex>rapid</ex> growth;
<ex>rapid</ex> improvement; <ex>rapid</ex> recurrence; <ex>rapid</ex>
succession.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Quick in execution; <as>as, a <ex>rapid</ex>
penman</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rapids</ent><br/
<ent>Rapid</ent><br/
<mhw><hw>Rap"id</hw>, <hw>Rap"ids</hw></mhw> <pr>(r<acr/p"<icr/dz)</pr>
, <pos>n.</pos> <ety>[Cf. F. <ets>rapide</ets>. See <er>Rapid</er>,
<pos>a.</pos>]</ety> <def>The part of a river where the current moves
with great swiftness, but without actual waterfall or cascade; sometimes
called <altname>whitewater</altname>; -- usually used in the plural;
<as>as, the Lachine <ex>rapids</ex> in the St. Lawrence</as>. For
boaters on the river, it is a place that can be hazardous, with danger
of capsizing or crashing into large rocks.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><q>Row, brothers, row, the stream runs fast,<br/
The <qex>rapids</qex> are near, and the daylight's past.</q>
<rj><qau>Moore.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rapid-firing</ent><br/
<ent>Rapid-fire</ent><br/
<mhw>{ <hw>Rap"id-fire`</hw>, <hw>Rap"id-fir`ing</hw> }</mhw>,
<pos>a.</pos> <sd>(a)</sd> <fld>(Gun.)</fld> <def>Firing shots in rapid
succession.</def> <sd>(b)</sd> <fld>(Ordnance)</fld> <def>Capable of
being fired rapidly; -- applied to single-barreled guns of greater
caliber than small arms, mounted so as to be quickly trained and
elevated, with a quick-acting breech mechanism operated by a single
motion of a crank or lever (abbr. <xex>R. F.</xex>);</def>
<specif>specif.:</specif> (1) <def>In the United States navy,
designating such a gun using fixed ammunition or metallic cartridge
cases; -- distinguished from <xex>breech-loading</xex> (abbr. <xex>B.
L.</xex>), applied to all guns loading with the charge in bags, and
formerly from <xex>quick-fire</xex>. <xex>Rapid-fire</xex> guns in the
navy also sometimes include automatic or semiautomatic rapid-fire guns;
the former being automatic guns of not less than one inch caliber,
firing a shell of not less than one pound weight, the explosion of each
cartridge operating the mechanism for ejecting the empty shell, loading,
and firing the next shot, the latter being guns that require one
operation of the hand at each discharge, to load the gun.</def> (2)
<def>In the United States army, designating such a gun, whether using
fixed or separate ammunition, designed chiefly for use in coast
batteries against torpedo vessels and the lightly armored batteries or
other war vessels and for the protection of defensive mine fields; --
not distinguished from <xex>quick-fire</xex>.</def> (3) <def>In Great
Britain and Europe used, rarely, as synonymous with
<altname>quick-fire</altname>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Rapid-fire</ent><br/
<hw>Rap"id-fire`</hw>, <pos>a.</pos> <def>Occurring in rapid succession
like the shots fired from a machine gun. See also
<er>machine-gun</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Rapid-fire mount</ent><br/
<hw>Rapid-fire mount</hw>. <fld>(Ordnance)</fld> <def>A mount permitting
easy and quick elevation or depression and training of the gun, and
fitted with a device for taking up the recoil.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Rapidity</ent><br/
<hw>Ra*pid"i*ty</hw> <pr>(r<adot/*p<icr/d"<icr/*t<ycr/)</pr>,
<pos>n.</pos> <ety>[L. <ets>rapiditas</ets>: cf. F.
<ets>rapidit<eacute/</ets>.]</ety> <def>The quality or state of being
rapid; swiftness; celerity; velocity; <as>as, the <ex>rapidity</ex> of a
current; <ex>rapidity</ex> of speech; <ex>rapidity</ex> of growth or
improvement</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Rapidness; haste; speed; celerity; velocity;
swiftness; fleetness; quickness; agility.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rapidly</ent><br/
<hw>Rap"id*ly</hw> <pr>(r<acr/p"<icr/d*l<ycr/)</pr>, <pos>adv.</pos>
<def>In a rapid manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rapidness</ent><br/
<hw>Rap"id*ness</hw>, <pos>n.</pos> <def>Quality of being rapid;
rapidity.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rapier</ent><br/
<hw>Ra"pi*er</hw> <pr>(r<amac/"p<icr/*<etil/r)</pr>, <pos>n.</pos>
<ety>[F. <ets>rapi<egrave/re</ets>, perhaps for
<ets>raspi<egrave/re</ets>, and ultimately of German origin, akin to E.
<ets>rasp</ets>, v.]</ety> <def>A straight sword, with a narrow and
finely pointed blade, used only for thrusting.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Rapier fish</b></col> <fld>(Zool.)</fld>, <cd>the
swordfish.</cd> <mark>[Obs.]</mark> <rj><au>Grew.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rapiered</ent><br/
<hw>Ra"pi*ered</hw> <pr>(-<etil/rd)</pr>, <pos>a.</pos> <def>Wearing a
rapier.</def> <ldquo/Scarletcoated, <xex>rapiered</xex> figures.<rdquo/
<rj><au>Lowell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rapilli</ent><br/
\'d8<hw>Ra*pil"li</hw> <pr>(r<adot/*p<icr/l"l<esl/)</pr>, <pos>n.
pl.</pos> <ety>[It.]</ety> <fld>(Min.)</fld> <def>Lapilli.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rapine</ent><br/
<hw>Rap"ine</hw> <pr>(r<acr/p"<icr/n)</pr>, <pos>n.</pos> <ety>[F.
<ets>rapine</ets>; cf. Pr. & It. <ets>rapina</ets>; all fr. L.
<ets>rapina</ets>, fr. <ets>rapere</ets> to seize and carry off by
force. See <er>Rapid</er>, and cf. <er>Raven</er> rapine.]</ety>
<sn>1.</sn> <def>The act of plundering; the seizing and carrying away of
things by force; spoliation; pillage; plunder.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Men who were impelled to war quite as much by the desire of
<qex>rapine</qex> as by the desire of glory.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Ravishment; rape.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rapine</ent><br/
<hw>Rap"ine</hw>, <pos>v. t.</pos> <def>To plunder.</def> <rj><au>Sir G.
Buck.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rapinous</ent><br/
<hw>Rap"i*nous</hw> <pr>(r<acr/p"<icr/*n<ucr/s)</pr>, <pos>a.</pos>
<def>Given to rapine.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>rap music</ent><br/
<hw>rap` mu"sic</hw> <pr>(r<acr/p` m<umac/"z<icr/k)</pr>, <pos>n.</pos>
<fu>(ca. 1985)</fu> <def>a type of rhythmic talking, often with
accompanying rhythm instruments; same as 7th <er>rap</er>,
<pos>n.</pos>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Rappage</ent><br/
<hw>Rap"page</hw> <pr>(r<acr/p"p<asl/j; 48)</pr>, <pos>n.</pos>
<fld>(Founding)</fld> <def>The enlargement of a mold caused by rapping
the pattern.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rapparee</ent><br/
<hw>Rap`pa*ree"</hw> <pr>(-p<adot/*r<emac/")</pr>, <pos>n.</pos> <def>A
wild Irish plunderer, esp. one of the 17th century; -- so called from
his carrying a half-pike, called a <xex>rapary</xex>.</def>
<altsp>[Written also <asp>raparee</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rapped</ent><br/
<hw>Rapped</hw> <pr>(r<acr/pt)</pr>, <def><pos>imp. & p. p.</pos> of
<er>Rap</er>, to strike.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rapped</ent><br/
<hw>Rapped</hw>, <def><pos>imp. & p. p.</pos> of <er>Rap</er>, to snatch
away.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rappee</ent><br/
<hw>Rap*pee"</hw> <pr>(r<acr/p*p<emac/")</pr>, <pos>n.</pos> <ety>[F.
<ets>r<acir/p<eacute/</ets>, fr. <ets>r<acir/per</ets> to grate, to
rasp. See <er>Rasp</er>, <pos>v.</pos>]</ety> <def>A pungent kind of
snuff made from the darker and ranker kinds of tobacco leaves.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rappel</ent><br/
<hw>Rap"pel</hw> <pr>(r<acr/p"p<ecr/l <or/ r<acr/p*p<ecr/l")</pr>,
<pos>n.</pos> <ety>[F. Cf. <er>Repeal</er>.]</ety> <fld>(Mil.)</fld>
<def>The beat of the drum to call soldiers to arms.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rapper</ent><br/
<hw>Rap"per</hw> <pr>(r<acr/p"p<etil/r)</pr>, <pos>n.</pos> <ety>[From
<er>Rap</er>.]</ety> <sn>1.</sn> <def>One who, or that which, raps or
knocks; specifically, the knocker of a door.</def>
<rj><au>Sterne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A forcible oath or lie.</def> <mark>[Slang]</mark>
<rj><au>Bp. Parker.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A musician specializing in <er>rap
music</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Rapport</ent><br/
<hw>Rap*port"</hw> <pr>(r<acr/p*p<omac/rt"; F. r<adot/`p<ocir/r")</pr>,
<pos>n.</pos> <ety>[F., fr. <ets>rapporter</ets> to bring again or back,
to refer; pref. <ets>re-</ets> re- + <ets>apporter</ets> to bring, L.
<ets>apportare</ets>. Cf. <er>Report</er>.]</ety> <def>Relation;
proportion; conformity; correspondence; accord.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>'T is obvious what <qex>rapport</qex> there is between the
conceptions and languages in every country.</q> <rj><qau>Sir W.
Temple.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs>\'d8<col><b>En` rap`port"</b></col> <pr>(<aum/N`
r<adot/`p<ocir/r")</pr> <ety>[F.]</ety>, <cd>in accord, harmony, or
sympathy; having a mutual, especially a private, understanding; in
hypnotism, in that relation of sympathy which permits influence or
communication.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rapprochement</ent><br/
\'d8<hw>Rap`proche`ment"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr.
<ets>rapprocher</ets> to cause to approach again. See <er>Re-</er>;
<er>Approach</er>.]</ety> <def>Act or fact of coming or being drawn near
or together; establishment or state of cordial relations.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><q>He had witnessed the gradual <qex>rapprochement</qex> between the
papacy and Austria.</q> <rj><qau>Wilfrid Ward.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Rapscallion</ent><br/
<hw>Rap*scal"lion</hw> <pr>(r<acr/p*sk<acr/l"y<ucr/n)</pr>,
<pos>n.</pos> <ety>[See <er>Rascallion</er>.]</ety> <def>A rascal; a
good-for-nothing fellow.</def> <mark>[Colloq.]</mark>
<rj><au>Howitt.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rapt</ent><br/
<hw>Rapt</hw> <pr>(r<acr/pt)</pr>, <def><pos>imp. & p. p.</pos> of
<er>Rap</er>, to snatch away.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rapt</ent><br/
<hw>Rapt</hw>, <pos>a.</pos> <sn>1.</sn> <def>Snatched away; hurried
away or along.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Waters <qex>rapt</qex> with whirling away.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Transported with love, admiration, delight, etc.;
enraptured.</def> <ldquo/The <xex>rapt</xex> musician.<rdquo/
<rj><au>Longfellow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Wholly absorbed or engrossed, as in work or
meditation.</def> <ldquo/<xex>Rapt</xex> in secret studies.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rapt</ent><br/
<hw>Rapt</hw>, <pos>n.</pos> <ety>[From F. <ets>rapt</ets> abduction,
rape, L. <ets>raptus</ets>, fr. <ets>rapere</ets> to seize and carry
off, to transport; or fr. E. <ets>rapt</ets>, a. See <er>Rapt</er>,
<pos>a.</pos>, and <er>Rapid</er>.]</ety> <sn>1.</sn> <def>An ecstasy; a
trance.</def> <mark>[Obs.]</mark> <rj><au>Bp. Morton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Rapidity.</def> <mark>[Obs.]</mark> <rj><au>Sir T.
Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rapt</ent><br/
<hw>Rapt</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To transport or
ravish.</def> <mark>[Obs.]</mark> <rj><au>Drayton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To carry away by force.</def> <mark>[Obs.]</mark>
<rj><au>Daniel.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rapter</ent><br/
<hw>Rap"ter</hw> <pr>(r<acr/p"t<etil/r)</pr>, <pos>n.</pos> <def>A
raptor.</def> <mark>[Obs.]</mark> <rj><au>Drayton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raptor</ent><br/
<hw>Rap"tor</hw> <pr>(r<acr/p"t<etil/r)</pr>, <pos>n.</pos> <ety>[L.
<ets>raptor</ets>, from <ets>rapere</ets> to ravish. See
<er>Rapid</er>.]</ety> <def>A ravisher; a plunderer.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raptores</ent><br/
\'d8<hw>Rap*to"res</hw> <pr>(r<acr/p*t<omac/"r<emac/z)</pr>, <pos>n.
pl.</pos> <ety>[NL. See <er>Raptor</er>.]</ety> <fld>(Zool.)</fld>
<def>An order of birds, same as <er>Accipitres</er>. Called also
<altname>Raptatores</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raptorial</ent><br/
<hw>Rap*to"ri*al</hw> <pr>(r<acr/p*t<omac/"r<icr/*<ait/l)</pr>,
<pos>a.</pos> <fld>(Zool.)</fld> <sd>(a)</sd> <def>Rapacious; living
upon prey; -- said especially of certain birds.</def> <sd>(b)</sd>
<def>Adapted for seizing prey; -- said of the legs, claws, etc., of
insects, birds, and other animals.</def> <sd>(c)</sd> <def>Of or
pertaining to the <ord>Raptores</ord>. See <xex>Illust.</xex>
<sd>(f)</sd> of <er>Aves</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raptorious</ent><br/
<hw>Rap*to"ri*ous</hw> <pr>(r<acr/p*t<omac/"r<icr/*<ucr/s)</pr>,
<pos>a.</pos> <ety>[L. <ets>raptorius</ets>.]</ety> <fld>(Zool.)</fld>
<def>Raptorial.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rapture</ent><br/
<hw>Rap"ture</hw> <pr>(r<acr/p"t<usl/r; 135)</pr>, <pos>n.</pos>
<ety>[L. <ets>rapere</ets>, <ets>raptum</ets>, to carry off by force.
See <er>Rapid</er>.]</ety> <sn>1.</sn> <def>A seizing by violence; a
hurrying along; rapidity with violence.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>That 'gainst a rock, or flat, her keel did dash<br/
With headlong <qex>rapture</qex>.</q> <rj><qau>Chapman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The state or condition of being rapt, or carried
away from one's self by agreeable excitement; violence of a pleasing
passion; extreme joy or pleasure; ecstasy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Music, when thus applied, raises in the mind of the hearer great
conceptions; it strengthens devotion, and advances praise into
<qex>rapture</qex>.</q> <rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>You grow correct that once with <qex>rapture</qex> writ.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A spasm; a fit; a syncope; delirium.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Bliss; ecstasy; transport; delight;
exultation.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rapture</ent><br/
<hw>Rap"ture</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Raptured</conjf> <pr>(-t<usl/rd; 135)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Rapturing</conjf>.]</vmorph> <def>To transport with
excitement; to enrapture.</def> <mark>[Poetic]</mark>
<rj><au>Thomson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rapturist</ent><br/
<hw>Rap"tur*ist</hw>, <pos>n.</pos> <def>An enthusiast.</def>
<mark>[Obs.]</mark> <rj><au>J. Spencer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rapturize</ent><br/
<hw>Rap"tur*ize</hw> <pr>(-<imac/z)</pr>, <pos>v. t. & i.</pos> <def>To
put, or be put, in a state of rapture.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rapturous</ent><br/
<hw>Rap"tur*ous</hw> <pr>(-<ucr/s)</pr>, <pos>a.</pos> <def>Ecstatic;
transporting; ravishing; feeling, expressing, or manifesting rapture;
<as>as, <ex>rapturous</ex> joy, pleasure, or delight; <ex>rapturous</ex>
applause.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rapturously</ent><br/
<hw>Rap"tur*ous*ly</hw>, <pos>adv.</pos> <def>In a rapturous
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rare</ent><br/
<hw>Rare</hw> <pr>(r<acir/r)</pr>, <pos>a.</pos> <ety>[Cf.
<er>Rather</er>, <er>Rath</er>.]</ety> <def>Early.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Rude mechanicals that <qex>rare</qex> and late<br/
Work in the market place.</q> <rj><qau>Chapman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rare</ent><br/
<hw>Rare</hw>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Rarer</adjf> <pr>(r<acir/r"<etil/r)</pr>; <pos>superl.</pos>
<adjf>Rarest</adjf>.]</amorph> <ety>[Cf. AS. <ets>hr<emac/r</ets>, or E.
<ets>rare</ets> early. <root/18.]</ety> <def>Nearly raw; partially
cooked; not thoroughly cooked; underdone; <as>as, <ex>rare</ex> beef or
mutton</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>New-laid eggs, which Baucis' busy care<br/
Turned by a gentle fire, and roasted <qex>rare</qex>.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ This word is in common use in the United States, but in
England its synonym <altname>underdone</altname> is
preferred.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rare</ent><br/
<hw>Rare</hw>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Rarer</adjf> <pr>(r<acir/r"<etil/r)</pr>; <pos>superl.</pos>
<adjf>Rarest</adjf>.]</amorph> <ety>[F., fr. L. <ets>rarus</ets> thin,
rare.]</ety> <sn>1.</sn> <def>Not frequent; seldom met with or
occurring; unusual; <as>as, a <ex>rare</ex> event</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of an uncommon nature; unusually excellent; valuable
to a degree seldom found.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Rare</qex> work, all filled with terror and delight.</q>
<rj><qau>Cowley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Above the rest I judge one beauty <qex>rare</qex>.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Thinly scattered; dispersed.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Those <qex>rare</qex> and solitary, these in flocks.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Characterized by wide separation of parts; of loose
texture; not thick or dense; thin; <as>as, a <ex>rare</ex> atmosphere at
high elevations</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Water is nineteen times lighter, and by consequence nineteen times
<qex>rarer</qex>, than gold.</q> <rj><qau>Sir I. Newton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Scarce; infrequent; unusual; uncommon; singular;
extraordinary; incomparable.</syn> <usage> -- <er>Rare</er>,
<er>Scarce</er>. We call a thing <xex>rare</xex> when but few examples,
specimens, or instances of it are ever to be met with; <as>as, a
<ex>rare</ex> plant</as>. We speak of a thing as <xex>scarce</xex>,
which, though usually abundant, is for the time being to be had only in
diminished quantities; <as>as, a bad harvest makes corn
<ex>scarce</ex></as>.</usage><br/
[<source>1913 Webster</source>]</p>

<p><q>A perfect union of wit and judgment is one of the
<qex>rarest</qex> things in the world.</q>
<rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>When any particular piece of money grew very <qex>scarce</qex>, it
was often recoined by a succeeding emperor.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rarebit</ent><br/
<hw>Rare"bit</hw> <pr>(r<acir/r"b<icr/t)</pr>, <pos>n.</pos> <def>A
dainty morsel; a Welsh rabbit. See <cref>Welsh rabbit</cref>, under
<er>Rabbit</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raree-show</ent><br/
<hw>Rar"ee-show`</hw> <pr>(r<acir/r"<esl/-sh<omac/`)</pr>, <pos>n.</pos>
<ety>[Contr. fr. <ets>rarity-show</ets>.]</ety> <def>A show carried
about in a box; a peep show.</def> <rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rarefaction</ent><br/
<hw>Rar`e*fac"tion</hw> <pr>(r<acr/r`<esl/*f<acr/k"sh<ucr/n)</pr>,
<pos>n.</pos> <ety>[Cf. F. <ets>rar<eacute/faction</ets>. See
<er>Rarefy</er>.]</ety> <def>The act or process of rarefying; the state
of being rarefied; -- opposed to <xex>condensation</xex>; <as>as, the
<ex>rarefaction</ex> of air</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rarefiable</ent><br/
<hw>Rar"e*fi`a*ble</hw> <pr>(r<acr/r"<esl/*f<imac/`<adot/*b'l)</pr>,
<pos>a.</pos> <ety>[Cf. F. <ets>rar<eacute/fiable</ets>.]</ety>
<def>Capable of being rarefied.</def> <rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rarefy</ent><br/
<hw>Rar"e*fy</hw> <pr>(r<acr/r"<esl/*f<imac/; 277)</pr>, <pos>v.
t.</pos> <vmorph>[<pos>imp. & p. p.</pos> <conjf>Rarefied</conjf>
<pr>(r<acr/r"<esl/*f<imac/d)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Rarefying</conjf>
<pr>(r<acr/r"<esl/*f<imac/`<icr/ng)</pr>.]</vmorph> <ety>[F.
<ets>rar<eacute/fier</ets>; L. <ets>rarus</ets> rare +
<ets>-ficare</ets> (in comp.) to make; cf. L. <ets>rarefacere</ets>. See
<er>-fy</er>.]</ety> <def>To make rare, thin, porous, or less dense; to
expand or enlarge without adding any new portion of matter to; --
opposed to <xex>condense</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rarefy</ent><br/
<hw>Rar"e*fy</hw>, <pos>v. i.</pos> <def>To become less dense; to become
thin and porous.</def> <ldquo/Earth <xex>rarefies</xex> to dew.<rdquo/
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rarely</ent><br/
<hw>Rare"ly</hw> <pr>(r<acir/r"l<ycr/)</pr>, <pos>adv.</pos> <sn>1.</sn>
<def>In a rare manner or degree; seldom; not often; <as>as, things
<ex>rarely</ex> seen</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Finely; excellently; with rare skill. See 3d
<er>Rare</er>, 2.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The person who played so <qex>rarely</qex> on the flageolet.</q>
<rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The rest of the apartments are <qex>rarely</qex> gilded.</q>
<rj><qau>Evelyn.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rareness</ent><br/
<hw>Rare"ness</hw>, <pos>n.</pos> <def>The state or quality of being
rare.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And let the <qex>rareness</qex> the small gift commend.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rareripe</ent><br/
<hw>Rare"ripe`</hw> <pr>(-r<imac/p`)</pr>, <pos>a.</pos>
<ety>[<ets>Rare</ets> early + <ets>ripe</ets>. Cf.
<er>Rathripe</er>.]</ety> <def>Early ripe; ripe before others, or before
the usual season.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rareripe</ent><br/
<hw>Rare"ripe`</hw>, <pos>n.</pos> <def>An early ripening fruit,
especially a kind of freestone peach.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rarification</ent><br/
<hw>Rar`i*fi*ca"tion</hw>
<pr>(r<acr/r`<icr/*f<icr/*k<amac/"sh<ucr/n)</pr>, <pos>n.</pos> <def>See
<er>Rarefaction</er>.</def> <mark>[R.]</mark> <rj><au>Am. Chem.
Journal.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rarity</ent><br/
<hw>Rar"i*ty</hw> <pr>(r<acr/r"<icr/*t<ycr/; 277)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Rarities</plw>
<pr>(r<acr/r"<icr/*t<icr/z)</pr>.</plu> <ety>[L. <ets>raritas</ets>: cf.
F. <ets>raret<eacute/</ets>. See <er>Rare</er>.]</ety> <sn>1.</sn>
<def>The quality or state of being rare; rareness; thinness; <as>as, the
<ex>rarity</ex> (contrasted with the <ex>density</ex>) of
gases</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1190 pr=vmg --></p>

<p><sn>2.</sn> <def>That which is rare; an uncommon thing; a thing
valued for its scarcity.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I saw three <qex>rarities</qex> of different kinds, which pleased
me more than any other shows in the place.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ras</ent><br/
<hw>Ras</hw> <pr>(r<aum/s)</pr>, <pos>n.</pos> <def>See 2d
<er>Reis</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>ras</ent><br/
<hw>ras</hw> <pr>(r<aum/s)</pr>, <pos>n.</pos> <ety>[from <ets>ra</ets>t
<ets>s</ets>arcoma.]</ety> <def>The name and genetic symbol for a mutant
gene that has been identified as one of those associated with certains
types of cancer; -- it is a form of <isa>oncogene</isa>. It was first
observed in rats, but analogues have been found in humans and other
animals.</def><br/
[<source>PJC</source>]</p>

<p><q> During the 1960s and 1970s, a great deal of research was done on
a class of viruses that affects rodents and birds and causes tumors in
those species. The motivation for a lot of this research was the idea
that similar viruses might cause tumors in humans, but in fact it's
turned out that there are very few viruses that cause tumors in humans.
Nevertheless, the study of these rodent viruses has been enormously
fruitful in helping us to understand human cancer, and that's the basis
of this story.<br/
<br/
One of the viruses that was studied in those years had two
peculiarities. One was that it had lost most of the genes that it needed
to reproduce itself. It could only reproduce if a helper virus was
present in the same cell to supply the missing functions. The second
peculiarity was that in place of the genes that were required for
reproduction of the virus was another gene that had actually been picked
up at some point in the history of this virus when it went through rats,
and it picked up a rat gene and incorporated it into its own genome.<br/
<br/
At the same time that a lot of work was going on on these viruses, other
scientists were studying other aspects of tumor formation, in
particular, the action of carcinogenic agents, chemicals and X-rays and
ultraviolet light. As you all know, human cells can turn into tumor
cells under the influence of such agents. The tumor-like properties of
those cells are inherited by all the daughter cells through many
generations and, moreover, almost all chemicals that turn out to be
carcinogens are also able to cause mutations.<br/
<br/
Another observation was that in tumor cells, many of the chromosomes
seemed to have altered structures. So, all of these observations and
others certainly suggested that changes in DNA might be involved in the
development of tumor cells. By about 1980, it became possible to test
that hypothesis directly.<br/
<br/
If you have human tumor cells produced in laboratory dishes or isolated
from the tumor itself, then perhaps they have a gene or genes in them
which is responsible for the fact that they're tumor cells. If you
isolate the DNA from the cells and cut it up into more or less
gene-sized pieces and then put it on top of mouse cells growing in a
dish, the mouse cells can take up pieces of this DNA, and any mouse cell
that picks up a piece of DNA that carries on it a gene that can cause a
tumor will begin to grow like tumor cells, and its progeny will grow
rapidly and form a tight little cluster on the cell.<br/
<br/
Now it's possible to pick such cells off and isolate the DNA from them
and also separate the human DNA sequence that might have caused the
tumor-like property from the bulk of the mouse sequences and to clone
that DNA. And when you do that and put that DNA, which is now pure
sequence, back in mouse cells, many of the cells become tumor-like
rather than just a rare few. And such a gene, such a DNA sequence, bears
the name of an oncogene.<br/
<br/
When such DNA segments are cloned, the DNA can also be used to probe, to
find out whether matching DNA sequences occur only in tumor cells or
whether there are similar DNA sequences in normal cells. And the answer
has been for a whole group of oncogenes, that very similar DNA sequences
are present in normal cells. To find out just how similar, the sequences
of the normal genes were compared with those from the genes that were
isolated from these tumor cells.<br/
<br/
The first such oncogene isolated was from a human bladder tumor, and
everyone was surprised by the results. First of all, the gene isolated
from the bladder tumor was almost identical to the normal human gene and
almost identical to the gene that was present in the tumor virus that
infected rodents that I told you about before. This gene has become
known as <ldquo/ras<rdquo/, because it was originally isolated from rats
with sarcoma, and it caused sarcomas and it's called that, and it's
protein is called that. And the only really significant difference
between the normal human gene, the bladder tumor gene, and the rodent
virus gene was a change in one codon, Codon XII, and therefore a change
in amino acids.<br/
<br/
So the normal human gene has a sequence GGC, encodes the amino acid
glycine, and does not cause tumors. But the bladder tumor gene has GTC;
it encodes valine. The rodent virus has AGA; it encodes arginine, and
both of these cause tumors. In fact, any change that leads to a loss of
the glycine at Codon XII can change this normal gene, <qex>ras</qex>,
into a gene that would cause tumors. So there were two different ways in
which the <qex>ras</qex> gene turned up. First, as a rat gene in a tumor
virus and second of all as the gene that could account for the
tumor-like properties of the bladder tumor.<br/
<br/
Well by now, many of the questions that occurred to the scientists
working on this have occurred to you. What is the <qex>ras</qex> protein
normally (if anything), and what does the altered ras protein do that
differently, and how can a change in one amino acid in a protein change
cells from normal to tumor cells?<br/
<br/
It turns out that the ras gene and the ras protein are important for a
lot of things, but more particularly for regulating the growth of cells.
Normal cells need to have a good <qex>ras</qex> gene in order to grow,
in order to make new DNA, to time it all right so they don't grow out of
control. Moreover, the ras gene occurs in virtually all living things.
For example, yeast cells also have two <qex>ras</qex> genes. If either
one of them is knocked out, the yeast cells can still grow very well and
multiply. But if both <qex>ras</qex> genes are knocked out, the yeast
cells cannot multiply, and they die. Astonishingly, if a human
<qex>ras</qex> gene is applied to these yeast cells, it completely takes
the place of the yeast's own ras genes. So we know from this that the
<qex>ras</qex> gene is very important to all living cells and that it's
probably been around for a couple billion years, ever since the very
first cells were formed on the planet.<br/
<br/
So ras does something important and the question is, what does it do?
<person>David Golde</person> told you before about receptors that span
cell membranes that bind molecules outside the cell and provide a signal
inside the cell, and it turns out that what the <qex>ras</qex> protein
does is to help convey that signal from the receptor at the surface down
into the cell and into the gene where it results in a change in gene
expression. The <qex>ras</qex> protein itself actually sits right under
the cell membrane, very well positioned to do this.<br/
<br/
Well, how can it do that? To tell you about that I need to tell you a
couple of things about the <qex>ras</qex> protein and what it does.
First of all, <qex>ras</qex> combines two small molecules called GDP and
GTP, and they differ only in the presence of one more phosphate, three
in GTP and two in GDP. This G is related; it's in fact the same kind of
molecule as the G that occurs in DNA. Moreover, <qex>ras</qex> protein
can catalyze the removal of one phosphate, so you go from <qex>ras</qex>
GTP to <qex>ras</qex> GDP and a phosphate is lost. Furthermore, the ras
GDP can lose the GDP and pick up the GTP, and there are extra proteins
in the cell that foster either this exchange, back to GTP or this loss
of the phosphate to GDP. And the whole trick is the ratio of the GTP to
the GDP. So if you have <qex>ras</qex> GTP, it's active and it
stimulates growth, but if you have <qex>ras</qex> GDP, then it's
inactive and you don't stimulate growth.<br/
<br/
In fact, the change in Codon XII from a glycine results in a change in
the amount of ras GTP, so that there's more ras GTP collecting in the
cell than the ras GDP, and therefore the cell is constantly under
pressure to make DNA and grow and divide. And this is the critical
reason for this change, this oncogenic change in those versions of ras
that cause tumors or are related to tumor formation as opposed to the
natural protein.<br/
<br/
How can that happen, a small change like that? You've heard a little bit
about the importance of shapes of proteins. If one looks closely at the
atoms in the proteins then you see that the whole shape of the protein
changes as you go from GTP to GDP.<br/
<br/
Now one ras gene and protein all by itself would be interesting, but it
turns out that there's a whole family of ras genes and ras proteins. Two
of them are specially similar to the type that I've been describing, and
mutations in those genes are associated with a whole variety of human
tumors including some that are believed to be the result of the reaction
to environmental agents.<br/
<br/
A mutant in one of those two related genes, which was also first
discovered in a tumor virus, is very frequently associated with human
tumors of the colon and rectum. And again, it's Codon XII in that
similar gene that is altered in the oncogenic form of this kind of ras.
Tumors of the colon and rectum are the third most common human
malignancy worldwide, and surgical removal of the tumors can actually
cure the disease in many cases, but only if the tumor is detected very,
very early. Recent work has shown that you can, in fact, detect the
change in the gene even by looking at the DNA in the stool of people who
are suspected of having the colon tumor.<br/
<br/
Even though the mutant DNA only occurs in a very small percentage of the
cells in the stool, namely the cells that come from the tumor, not from
all the normal cells or all the bacterial cells that are there, it is
possible to amplify the amount of a possible abnormal ras gene and test
directly for it. So, for example in this test, DNA from the stool of
patient #1 matched a probe for the normal ras gene, but DNA isolated
from the stool of patient #2 matched a probe not only from a normal ras
gene but also from a ras gene with a mutation at Codon XII, thereby
permitting a very early diagnosis of a colon tumor and thereby providing
real hope that such tumors can be detected early, when the tumor is
small enough to be removed surgically with a successful cure.</q>
<qau>Maxine Singer
(http://www.accessexcellence.org/AB/BA/Ras_Gene_and_Cancer.html)</qau><br/
[<source>PJC</source>]</p>

<p><ent>Rasante</ent><br/
\'d8<hw>Ra`sante"</hw> <pr>(r<adot/`z<aum/Nt")</pr>, <pos>a.</pos>
<ety>[F., p. pr. of <ets>raser</ets> to graze.]</ety> <fld>(Fort.)</fld>
<def>Sweeping; grazing; -- applied to a style of fortification in which
the command of the works over each other, and over the country, is kept
very low, in order that the shot may more effectually sweep or graze the
ground before them.</def> <rj><au>H. L. Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rascal</ent><br/
<hw>Ras"cal</hw> <pr>(r<acr/s"k<ait/l)</pr>, <pos>n.</pos> <ety>[OE.
<ets>rascaille</ets> rabble, probably from an OF. <ets>racaille</ets>,
F. <ets>racaille</ets> the rabble, rubbish, probably akin to F.
<ets>racler</ets> to scrape, (assumed) LL. <ets>rasiculare</ets>,
<ets>rasicare</ets>, fr. L. <ets>radere</ets>, <ets>rasum</ets>. See
<er>Rase</er>, <pos>v.</pos>]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>One of the rabble; a low, common sort of person or
creature; collectively, the rabble; the common herd; also, a lean,
ill-conditioned beast, esp. a deer.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He smote of the people seventy men, and fifty thousand of the
<qex>rascal</qex>.</q> <rj><qau>Wyclif (1 Kings [1 Samuel] vi.
19).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Poor men alone? No, no; the noblest deer hath them [horns] as huge
as the <qex>rascal</qex>.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A mean, trickish fellow; a base, dishonest person; a
rogue; a scoundrel; a trickster.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>For I have sense to serve my turn in store,<br/
And he's a <qex>rascal</qex> who pretends to more.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rascal</ent><br/
<hw>Ras"cal</hw>, <pos>a.</pos> <def>Of or pertaining to the common herd
or common people; low; mean; base.</def> <ldquo/The <xex>rascal</xex>
many.<rdquo/ <au>Spencer.</au> <ldquo/The <xex>rascal</xex>
people.<rdquo/ <au>Shak.</au><br/
[<source>1913 Webster</source>]</p>

<p><q>While she called me <qex>rascal</qex> fiddler.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rascaldom</ent><br/
<hw>Ras"cal*dom</hw> <pr>(-d<ucr/m)</pr>, <pos>n.</pos> <def>State of
being a rascal; rascality; domain of rascals; rascals,
collectively.</def> <rj><au>Emerson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rascaless</ent><br/
<hw>Ras"cal*ess</hw>, <pos>n.</pos> <def>A female rascal.</def>
<mark>[Humorous]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rascality</ent><br/
<hw>Ras*cal"i*ty</hw> <pr>(r<acr/s*k<acr/l"<icr/*t<ycr/)</pr>,
<pos>n.</pos>; <plu><it>pl.</it> <plw>Rascalities</plw>
<pr>(r<acr/s*k<acr/l"<icr/*t<icr/z)</pr></plu><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>The quality or state of being rascally, or a rascal;
mean trickishness or dishonesty; base fraud.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The poorer and lower classes of people.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The chief heads of their clans with their several
<qex>rascalities</qex></q> <rj><qau>T. Jackson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rascallion</ent><br/
<hw>Ras*cal"lion</hw> <pr>(r<acr/s*k<acr/l"y<ucr/n)</pr>, <pos>n.</pos>
<ety>[From <er>Rascal</er>]</ety> <def>A low, mean wretch; a rogue; same
as <er>rascal</er>, <pos>n.</pos>. 2; now disused, replaced by
<er>rapscalion</er>.</def> <mark>[archaic]</mark> <altsp>[Written also
<asp>rascalion</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rascally</ent><br/
<hw>Ras"cal*ly</hw> <pr>(r<acr/s"k<ait/l*l<ycr/)</pr>, <pos>a.</pos>
<def>Like a rascal; trickish or dishonest; base; worthless; -- often in
humorous disparagement, without implication of dishonesty.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Our <qex>rascally</qex> porter is fallen fast asleep.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rase</ent><br/
<hw>Rase</hw> <pr>(r<amac/z)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Rased</conjf> <pr>(r<amac/zd)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Rasing</conjf>.]</vmorph> <ety>[F. <ets>raser</ets>, LL.
<ets>rasare</ets> to scrape often, v. freq. fr. L. <ets>radere</ets>,
<ets>rasum</ets>, to scrape, shave; cf. Skr. <ets>rad</ets> to scratch,
gnaw, L. <ets>rodere</ets> to gnaw. Cf. <er>Raze</er>, <er>Razee</er>,
<er>Razor</er>, <er>Rodent</er>.]</ety> <sn>1.</sn> <def>To rub along
the surface of; to graze.</def> <mark>[Obsoles.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Was he not in the . . . neighborhood to death? and might not the
bullet which <qex>rased</qex> his cheek have gone into his head?</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Sometimes his feet <qex>rased</qex> the surface of the water, and
at others the skylight almost flattened his nose.</q>
<rj><qau>Beckford.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To rub or scratch out; to erase.</def>
<mark>[Obsoles.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Except we <qex>rase</qex> the faculty of memory, root and branch,
out of our mind.</q> <rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To level with the ground; to overthrow; to destroy;
to raze.</def> <altsp>[In this sense <asp>raze</asp> is generally
used.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><q>Till Troy were by their brave hands <qex>rased</qex>,<br/
They would not turn home.</q> <rj><qau>Chapman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ This word, <xex>rase</xex>, may be considered as nearly
obsolete; <xex>graze</xex>, <xex>erase</xex>, and <xex>raze</xex>,
having superseded it.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Rasing iron</b></col>, <cd>a tool for removing old oakum
and pitch from the seams of a vessel.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To erase; efface; obliterate; expunge; cancel;
level; prostrate; overthrow; subvert; destroy; demolish; ruin.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rase</ent><br/
<hw>Rase</hw>, <pos>v. i.</pos> <def>To be leveled with the ground; to
fall; to suffer overthrow.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rase</ent><br/
<hw>Rase</hw>, <pos>n.</pos> <sn>1.</sn> <def>A scratching out, or
erasure.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A slight wound; a scratch.</def> <mark>[Obs.]</mark>
<rj><au>Hooker.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(O. Eng. Law)</fld> <def>A way of measuring in which
the commodity measured was made even with the top of the measuring
vessel by rasing, or striking off, all that was above it.</def>
<rj><au>Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rash</ent><br/
<hw>Rash</hw> <pr>(r<acr/sh)</pr>, <pos>v. t.</pos> <ety>[For
<ets>arace</ets>.]</ety> <sn>1.</sn> <def>To pull off or pluck
violently.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To slash; to hack; to cut; to slice.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Rashing</qex> off helms and riving plates asunder.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rash</ent><br/
<hw>Rash</hw>, <pos>n.</pos> <ety>[OF. <ets>rasche</ets> an eruption,
scurf, F. <ets>rache</ets>; fr. (assumed) LL. <ets>rasicare</ets> to
scratch, fr. L. <ets>radere</ets>, <ets>rasum</ets>, to scrape, scratch,
shave. See <er>Rase</er>, and cf. <er>Rascal</er>.]</ety>
<fld>(Med.)</fld> <def>A fine eruption or efflorescence on the body,
with little or no elevation.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Canker rash</b></col>. <cd>See in the Vocabulary.</cd> --
<col><b>Nettle rash</b></col>. <cd>See <er>Urticaria</er>.</cd> --
<col><b>Rose rash</b></col>. <cd>See <er>Roseola</er>.</cd> --
<col><b>Tooth rash</b></col>. <cd>See <er>Red-gum</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rash</ent><br/
<hw>Rash</hw>, <pos>n.</pos> <ety>[Cf. F. <ets>ras</ets> short-nap
cloth, It. & Sp. <ets>raso</ets> satin (cf. <er>Rase</er>); or cf. It.
<ets>rascia</ets> serge, G. <ets>rasch</ets>, probably fr.
<ets>Arras</ets> in France (cf. <er>Arras</er>).]</ety> <def>An inferior
kind of silk, or mixture of silk and worsted.</def> <mark>[Obs.]</mark>
<rj><au>Donne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rash</ent><br/
<hw>Rash</hw>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Rasher</adjf> <pr>(-<etil/r)</pr>; <pos>superl.</pos>
<adjf>Rashest</adjf>.]</amorph> <ety>[Probably of Scand. origin; cf.
Dan. & Sw. <ets>rask</ets> quick, brisk, rash, Icel.
<ets>r<oum/skr</ets> vigorous, brave, akin to D. & G. <ets>rasch</ets>
quick, of uncertain origin.]</ety> <sn>1.</sn> <def>Sudden in action;
quick; hasty.</def> <mark>[Obs.]</mark> <ldquo/Strong as aconitum or
<xex>rash</xex> gunpowder.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Requiring sudden action; pressing; urgent.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I scarce have leisure to salute you,<br/
My matter is so <qex>rash</qex>.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Esp., overhasty in counsel or action; precipitate;
resolving or entering on a project or measure without due deliberation
and caution; opposed to <xex>prudent</xex>; said of persons; <as>as, a
<ex>rash</ex> statesman or commander</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Uttered or undertaken with too much haste or too
little reflection; <as>as, <ex>rash</ex> words; <ex>rash</ex>
measures.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>So dry as to fall out of the ear with handling, as
corn.</def> <mark>[Prov. Eng.]</mark> <rj><au>Grose.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Precipitate; headlong; headstrong; foolhardy;
hasty; indiscreet; heedless; thoughtless; incautious; careless;
inconsiderate; unwary.</syn> <usage> -- <er>Rash</er>,
<er>Adventurous</er>, <er>Foolhardy</er>. A man is
<xex>adventurous</xex> who incurs risk or hazard from a love of the
arduous and the bold. A man is <xex>rash</xex> who does it from the mere
impulse of his feelings, without counting the cost. A man is
<xex>foolhardy</xex> who throws himself into danger in disregard or
defiance of the consequences.</usage><br/
[<source>1913 Webster</source>]</p>

<p><q>Was never known a more <qex>adventurous</qex> knight.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Her <qex>rash</qex> hand in evil hour<br/
Forth reaching to the fruit, she plucked, she eat.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>If any yet be so <qex>foolhardy</qex><br/
To expose themselves to vain jeopardy;<br/
If they come wounded off, and lame,<br/
No honor's got by such a maim.</q> <rj><qau>Hudibras.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rash</ent><br/
<hw>Rash</hw> <pr>(r<acr/sh)</pr>, <pos>v. t.</pos> <def>To prepare with
haste.</def> <mark>[Obs.]</mark> <rj><au>Foxe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rasher</ent><br/
<hw>Rash"er</hw> <pr>(r<acr/sh"<etil/r)</pr>, <pos>n.</pos> <ety>[In
sense 1, probably fr. <ets>rash</ets>, a., as being hastily
cooked.]</ety> <sn>1.</sn> <def>A thin slice of bacon.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>A California rockfish
(<spn>Sebastichthys miniatus</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rashful</ent><br/
<hw>Rash"ful</hw> <pr>(r<acr/sh"f<usdot/l)</pr>, <pos>a.</pos>
<def>Rash; hasty; precipitate.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rashling</ent><br/
<hw>Rash"ling</hw> <pr>(r<acr/sh"l<icr/ng)</pr>, <pos>n.</pos> <def>A
rash person.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rashly</ent><br/
<hw>Rash"ly</hw>, <pos>adv.</pos> <def>In a rash manner; with
precipitation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He that doth anything <qex>rashly</qex>, must do it willingly; for
he was free to deliberate or not.</q>
<rj><qau>L'Estrange.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rashness</ent><br/
<hw>Rash"ness</hw>, <pos>n.</pos> <def>The quality or state of being
rash.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We offend . . . by <qex>rashness</qex>, which is an affirming or
denying, before we have sufficiently informed ourselves.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Temerity; foolhardiness; precipitancy;
precipitation; hastiness; indiscretion; heedlessness; inconsideration;
carelessness. See <er>Temerity</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raskolnik</ent><br/
\'d8<hw>Ras*kol"nik</hw> <pr>(r<acr/s*k<ocr/l"n<icr/k)</pr>,
<pos>n.</pos>; <plu>pl. <plw>Raskolniki</plw>
<pr>(r<acr/s*k<ocr/l"n<icr/k*<emac/)</pr> or <plw>Raskolniks</plw>
<pr>(#)</pr></plu>. <ety>[Russ. <ets>raskol'nik</ets> dissenter, fr.
<ets>raskol</ets> dissent.]</ety> <def>The name applied by the Russian
government to any subject of the Greek faith who dissents from the
established church. The <xex>Raskolniki</xex> embrace many sects, whose
common characteristic is a clinging to antique traditions, habits, and
customs. The schism originated in 1667 in an ecclesiastical dispute as
to the correctness of the translation of the religious books. The
dissenters, who have been continually persecuted, are believed to number
about 20,000,000, although the Holy Synod officially puts the number at
about 2,000,000. They are officially divided into three groups according
to the degree of their variance from orthodox beliefs and observances,
as follows: I. <ldquo/Most obnoxious.<rdquo/ the
<col><b>Judaizers</b></col>; the <col><b>Molokane</b></col>, who refuse
to recognize civil authority or to take oaths; the
<col><b>Dukhobortsy</b></col>, or <col><b>Dukhobors</b></col>, who are
communistic, marry without ceremony, and believe that Christ was human,
but that his soul reappears at intervals in living men; the
<col><b>Khlysty</b></col>, who countenance anthropolatory, are ascetics,
practice continual self-flagellation, and reject marriage; the
<col><b>Skoptsy</b></col>, who practice castration; and a section of the
<col><b>Bezpopovtsy</b></col>, or priestless sect, which disbelieve in
prayers for the Czar and in marriage. II. <ldquo/Obnoxious:<rdquo/ the
<col><b>Bezpopovtsy</b></col>, who pray for the Czar and recognize
marriage. III. <ldquo/Least obnoxious:<rdquo/ the
<col><b>Popovtsy</b></col>, who dissent from the orthodox church in
minor points only.</def> <altsp>[Written also
<asp>rascolnik</asp>.]</altsp><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Rasores</ent><br/
\'d8<hw>Ra*so"res</hw> <pr>(r<adot/*z<omac/"r<emac/z)</pr>, <pos>n.
pl.</pos> <ety>[NL., fr. L. <ets>radere</ets>, <ets>rasum</ets>, to
scratch. See <er>Rase</er>, <pos>v. t.</pos>]</ety> <fld>(Zool.)</fld>
<def>An order of birds; the Gallinae.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Formerly, the word <ord>Rasores</ord> was used in a
wider sense, so as to include other birds now widely separated in
classification.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rasorial</ent><br/
<hw>Ra*so"ri*al</hw> <pr>(r<adot/*z<omac/"r<icr/*<ait/l; 277)</pr>,
<pos>a.</pos> <fld>(Zool.)</fld> <def>Of or pertaining to the
<ord>Rasores</ord>, or gallinaceous birds, as the peacock, domestic
fowl, partridge, quail, and the like.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rasour</ent><br/
<hw>Ra"sour</hw> <pr>(r<aum/"s<oomac/r)</pr>, <pos>n.</pos>
<def>Razor.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rasp</ent><br/
<hw>Rasp</hw> <pr>(r<adot/sp)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Rasped</conjf> <pr>(r<adot/spt)</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>Rasping</conjf>.]</vmorph> <ety>[OF.
<ets>rasper</ets>, F. <ets>r<acir/per</ets>, to scrape, grate, rasp, fr.
OHG. <ets>rasp<omac/n</ets> to scrape together, to collect, probably
akin to E. <ets>rap</ets>. Cf. <er>Rap</er> to snatch.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>To rub or file with a rasp; to rub or grate with a
rough file; <as>as, to <ex>rasp</ex> wood to make it smooth; to
<ex>rasp</ex> bones to powder.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence, figuratively: To grate harshly upon; to
offend by coarse or rough treatment or language; <as>as, some sounds
<ex>rasp</ex> the ear; his insults <ex>rasped</ex> my
temper.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rasp</ent><br/
<hw>Rasp</hw>, <pos>n.</pos> <ety>[OE. <ets>raspe</ets>, OF.
<ets>raspe</ets>, F. <ets>r<acir/pe</ets>. See <er>Rasp</er>,
<pos>v.</pos>]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>A coarse file, on which the cutting prominences are
distinct points raised by the oblique stroke of a sharp punch, instead
of lines raised by a chisel, as on the true file.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The raspberry.</def> <mark>[Obs.]</mark> <ldquo/Set
sorrel amongst <xex>rasps</xex>, and the <xex>rasps</xex> will be the
smaller.<rdquo/ <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Rasp palm</b></col> <fld>(Bot.)</fld>, <cd>a Brazilian
palm tree (<spn>Iriartea exorhiza</spn>) which has strong aerial roots
like a screw pine. The roots have a hard, rough surface, and are used by
the natives for graters and rasps, whence the common name.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raspatorium</ent><br/
\'d8<hw>Ras`pa*to"ri*um</hw>
<pr>(r<acr/s`p<adot/*t<omac/"r<icr/*<ucr/m)</pr>, <pos>n.</pos>
<ety>[LL.]</ety> <def>See <er>Raspatory</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raspatory</ent><br/
<hw>Rasp"a*to*ry</hw> <pr>(r<adot/sp"<adot/*t<osl/*r<ycr/)</pr>,
<pos>n.</pos> <ety>[LL. <ets>raspatorium</ets>: cf. F.
<ets>raspatoir</ets>. See <er>Rasp</er>, <pos>v.</pos>]</ety> <def>A
surgeon's rasp.</def> <rj><au>Wiseman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raspberry</ent><br/
<hw>Rasp"ber*ry</hw> <pr>(r<acr/z"b<ecr/r*r<ycr/; 277)</pr>,
<pos>n.</pos> <ety>[From E. <ets>rasp</ets>, in allusion to the apparent
roughness of the fruit.]</ety> <fld>(Bot.)</fld> <sd>(a)</sd> <def>The
thimble-shaped fruit of the <spn>Rubus Idaeus</spn> and other similar
brambles; <as>as, the black, the red, and the white
<ex>raspberry</ex></as>.</def> <sd>(b)</sd> <def>The shrub bearing this
fruit.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Technically, raspberries are those brambles in which the
fruit separates readily from the core or receptacle, in this differing
from the blackberries, in which the fruit is firmly attached to the
receptacle.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rasper</ent><br/
<hw>Rasp"er</hw> <pr>(r<adot/sp"<etil/r)</pr>, <pos>n.</pos> <def>One
who, or that which, rasps; a scraper.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raspis</ent><br/
<hw>Ras"pis</hw> <pr>(r<acr/s"p<icr/s)</pr>, <pos>n.</pos> <def>The
raspberry.</def> <mark>[Obs.]</mark> <rj><au>Langham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raspy</ent><br/
<hw>Rasp"y</hw> <pr>(r<adot/sp"<ycr/)</pr>, <pos>a.</pos> <def>Like a
rasp, or the sound made by a rasp; grating.</def> <rj><au>R. D.
Blackmore.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rasse</ent><br/
<hw>Rasse</hw> <pr>(r<acr/s)</pr>, <pos>n.</pos> <ety>[Cf. Malay
<ets>r<amac/sa</ets> taste, sensation.]</ety> <fld>(Zool.)</fld> <def>A
carnivore (<spn>Viverricula Mallaccensis</spn>) allied to the civet but
smaller, native of China and the East Indies. It furnishes a perfume
resembling that of the civet, which is highly prized by the Javanese.
Called also <altname>Malacca weasel</altname>, and <altname>lesser
civet</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rasure</ent><br/
<hw>Ra"sure</hw> <pr>(r<amac/"zh<usl/r; 135)</pr>, <pos>n.</pos>
<ety>[L. <ets>rasura</ets>, fr. <ets>radere</ets>, <ets>rasum</ets>, to
scrape, to shave. See <er>Rase</er>, <pos>v.</pos>]</ety> <sn>1.</sn>
<def>The act of rasing, scraping, or erasing; erasure;
obliteration.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A mark by which a letter, word, or any part of a
writing or print, is erased, effaced, or obliterated; an erasure.</def>
<rj><au>Ayliffe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rat</ent><br/
<hw>Rat</hw> <pr>(r<acr/t)</pr>, <pos>n.</pos> <ety>[AS.
<ets>r<ae/t</ets>; akin to D. <ets>rat</ets>, OHG. <ets>rato</ets>,
<ets>ratta</ets>, G. <ets>ratte</ets>, <ets>ratze</ets>, OLG.
<ets>ratta</ets>, LG. & Dan. <ets>rotte</ets>, Sw.
<ets>r<aring/tta</ets>, F. <ets>rat</ets>, Ir. & Gael <ets>radan</ets>,
Armor. <ets>raz</ets>, of unknown origin. Cf. <er>Raccoon</er>.]</ety>
<sn>1.</sn> <fld>(Zool.)</fld> <def>One of several species of small
rodents of the genus <gen>Rattus</gen> (formerly included in
<gen>Mus</gen>) and allied genera, of the family <fam>Muridae</fam>,
distinguished from mice primarily by being larger. They infest houses,
stores, and ships, especially the <styp><ecol><b>Norway
rat</b></ecol></styp>, also called <stype>brown rat</stype>,
(<spn>Rattus norvegicus</spn> formerly <spn>Mus decumanus</spn>), the
<styp><ecol><b>black rat</b></ecol></styp> (<spn>Rattus rattus</spn>
formerly <spn>Mus rattus</spn>), and the <styp><ecol><b>roof
rat</b></ecol></styp> (formerly <spn>Mus Alexandrinus</spn>, now
included in <spn>Rattus rattus</spn>). These were introduced into
America from the Old World. The white rat used most commonly in
laboratories is primarily a strain derived from <spn>Rattus
rattus</spn>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>A round and tapering mass of hair, or similar
material, used by women to support the puffs and rolls of their natural
hair.</def> <mark>[Local, U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>One who deserts his party or associates; hence, in
the trades, one who works for lower wages than those prescribed by a
trades union.</def> <mark>[Cant]</mark><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <ldquo/It so chanced that, not long after the accession
of the house of Hanover, some of the brown, that is the German or
Norway, rats, were first brought over to this country (in some timber as
is said); and being much stronger than the black, or, till then, the
common, rats, they in many places quite extirpated the latter. The word
(both the noun and the verb to <xex>rat</xex>) was first, as we have
seen, leveled at the converts to the government of George the First, but
has by degrees obtained a wider meaning, and come to be applied to any
sudden and mercenary change in politics.<rdquo/ <rj><au>Lord
Mahon.</au></rj></note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Bamboo rat</b></col> <fld>(Zool.)</fld>, <cd>any Indian
rodent of the genus <gen>Rhizomys</gen>.</cd> -- <mcol><col><b>Beaver
rat</b></col>, <col><b>Coast rat</b></col></mcol>. <fld>(Zool.)</fld>
<cd>See under <er>Beaver</er> and <er>Coast</er>.</cd> -- <col><b>Blind
rat</b></col> <fld>(Zool.)</fld>, <cd>the mole rat.</cd> --
<col><b>Cotton rat</b></col> <fld>(Zool.)</fld>, <cd>a long-haired rat
(<spn>Sigmodon hispidus</spn>), native of the Southern United States and
Mexico. It makes its nest of cotton and is often injurious to the
crop.</cd> -- <col><b>Ground rat</b></col>. <cd>See <cref>Ground
Pig</cref>, under <er>Ground</er>.</cd> -- <col><b>Hedgehog
rat</b></col>. <cd>See under <er>Hedgehog</er>.</cd> -- <col><b>Kangaroo
rat</b></col> <fld>(Zool.)</fld>, <cd>the potoroo.</cd> --
<col><b>Norway rat</b></col> <fld>(Zool.)</fld>, <cd>the common brown
rat. See <er>Rat</er>.</cd> -- <col><b>Pouched rat</b></col>.
<fld>(Zool.)</fld> <sd>(a)</sd> <cd>See <cref>Pocket Gopher</cref>,
under <er>Pocket</er>.</cd> <sd>(b)</sd> <cd>Any African rodent of the
genus <gen>Cricetomys</gen>.</cd> <col><b>Rat Indians</b></col>
<fld>(Ethnol.)</fld>, <cd>a tribe of Indians dwelling near Fort Ukon,
<state>Alaska</state>. They belong to the Athabascan stock.</cd> --
<col><b>Rat mole</b></col>. <fld>(Zool.)</fld> <cd>See <cref>Mole
rat</cref>, under <er>Mole</er>.</cd> -- <col><b>Rat pit</b></col>,
<cd>an inclosed space into which rats are put to be killed by a dog for
sport.</cd> -- <col><b>Rat snake</b></col> <fld>(Zool.)</fld>, <cd>a
large colubrine snake (<spn>Ptyas mucosus</spn>) very common in
<country>India</country> and <geog>Ceylon</geog>. It enters dwellings,
and destroys rats, chickens, etc.</cd> -- <col><b>Spiny rat</b></col>
<fld>(Zool.)</fld>, <cd>any South American rodent of the genus
<gen>Echinomys</gen>.</cd> -- <col><b>To smell a rat</b></col>. <cd>See
under <er>Smell</er>.</cd> -- <col><b>Wood rat</b></col>
<fld>(Zool.)</fld>, <cd>any American rat of the genus
<gen>Neotoma</gen>, especially <spn>Neotoma Floridana</spn>, common in
the <geog>Southern United States</geog>. Its feet and belly are
white.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rat</ent><br/
<hw>Rat</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Ratted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Ratting</conjf>.]</vmorph> <sn>1.</sn> <def>In English politics,
to desert one's party from interested motives; to forsake one's
associates for one's own advantage; in the trades, to work for less
wages, or on other conditions, than those established by a trades
union.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Coleridge . . . incurred the reproach of having <qex>ratted</qex>,
solely by his inability to follow the friends of his early days.</q>
<rj><qau>De Quincey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To catch or kill rats.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To be an informer (against an associate); to inform
(on an associate); to squeal; -- used commonly in the phrase to rat
on.</def><br/
[<source>PJC</source>]</p>

<p><ent>Rata</ent><br/
<hw>Ra"ta</hw> <pr>(r<aum/"t<adot/)</pr>, <pos>n.</pos>
<ety>[Maori.]</ety> <fld>(Bot.)</fld> <def>A New Zealand forest tree
(<spn>Metrosideros robusta</spn>), also, its hard dark red wood, used by
the Maoris for paddles and war clubs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ratability</ent><br/
<hw>Rat`a*bil"i*ty</hw> <pr>(r<amac/t`<adot/*b<icr/l"<icr/*t<ycr/)</pr>,
<pos>n.</pos> <def>The quality or state of being ratable.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ratable</ent><br/
<hw>Rat"a*ble</hw> <pr>(r<amac/t"<adot/*b'l)</pr>, <pos>a.</pos>
<sn>1.</sn> <def>Capable of being rated, or set at a certain
value.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Twenty orae were <qex>ratable</qex> to [at] two marks of
silver.</q> <rj><qau>Camden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Liable to, or subjected by law to, taxation; <as>as,
<ex>ratable</ex> estate</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Made at a proportionate rate; <as>as,
<ex>ratable</ex> payments</as>.</def> --
<wordforms><wf>Rat"a*ble*ness</wf>, <pos>n.</pos> -- <wf>Rat"a*bly</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>ratable</ent><br/
<hw>rat"a*ble</hw> <pr>(r<amac/t"<adot/*b'l)</pr>, <pos>n.</pos> <def>a
structure which may be rated, or set at a certain value, for the purpose
of taxation, usually based on the value; <as>as, with the deterioration
of the center cities, the loss of <ex>ratables</ex> worsened the
situation by removing valuable sources of tax revenue</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Ratafia</ent><br/
<hw>Rat`a*fi"a</hw> <pr>(r<acr/t`<adot/*f<emac/"<adot/)</pr>,
<pos>n.</pos> <ety>[F., fr. Malay <ets>arak</ets> arrack +
<ets>t<amac/f<imac/a</ets> a spirit distilled from molasses.]</ety>
<def>A spirituous liquor flavored with the kernels of cherries,
apricots, peaches, or other fruit, spiced, and sweetened with sugar; --
a term applied to the liqueurs called <xex>noyau</xex>,
<xex>cura<cced/ao</xex>, etc.</def> <altsp>[Written also
<asp>ratifia</asp> and <asp>ratafee</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ratan</ent><br/
<hw>Ra*tan"</hw> <pr>(r<adot/*t<acr/n")</pr>, <pos>n.</pos> <def>See
<er>Rattan</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ratany</ent><br/
<hw>Rat"a*ny</hw> <pr>(r<acr/t"<adot/*n<ycr/)</pr>, <pos>n.</pos>
<fld>(Bot.)</fld> <def>Same as <er>Rhatany</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rataplan</ent><br/
\'d8<hw>Ra`ta`plan"</hw> <pr>(r<adot/`t<adot/`pl<aum/N")</pr>,
<pos>n.</pos> <ety>[F.]</ety> <def>The iterative sound of beating a
drum, or of a galloping horse.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ratch</ent><br/
<hw>Ratch</hw> <pr>(r<acr/ch)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>Same as <er>Rotche</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ratch</ent><br/
<hw>Ratch</hw> <pr>(r<acr/ch)</pr>, <pos>n.</pos> <ety>[See
<er>Rack</er> the instrument, <er>Ratchet</er>.]</ety> <def>A ratchet
wheel, or notched bar, with which a pawl or click works.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ratchel</ent><br/
<hw>Ratch"el</hw> <pr>(-<ecr/l)</pr>, <pos>n.</pos> <def>Gravelly
stone.</def> <mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ratchet</ent><br/
<hw>Ratch"et</hw> <pr>(-<ecr/t)</pr>, <pos>n.</pos> <ety>[Properly a
diminutive from the same word as <ets>rack</ets>: cf. F.
<ets>rochet</ets>. See 2d <er>Ratch</er>, <er>Rack</er> the
instrument.]</ety> <sn>1.</sn> <def>A pawl, click, or detent, for
holding or propelling a ratchet wheel, or ratch, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A mechanism composed of a ratchet wheel, or ratch,
and pawl. See <cref>Ratchet wheel</cref>, below, and 2d
<er>Ratch</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Ratchet brace</b></col> <fld>(Mech.)</fld>, <cd>a boring
brace, having a ratchet wheel and pawl for rotating the tool by back and
forth movements of the brace handle.</cd> -- <col><b>Ratchet
drill</b></col>, <cd>a portable machine for working a drill by hand,
consisting of a hand lever carrying at one end a drill holder which is
revolved by means of a ratchet wheel and pawl, by swinging the lever
back and forth.</cd> -- <col><b>Ratchet wheel</b></col>
<fld>(Mach.)</fld>, <cd>a circular wheel having teeth, usually angular,
with which a reciprocating pawl engages to turn the wheel forward, or a
stationary pawl to hold it from turning backward.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><-- illustr. Ratchet wheel and ilustr. of ratchet drill --><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In the cut, the moving pawl <xex>c</xex> slides over the
teeth in one direction, but in returning, draws the wheel with it, while
the pawl <xex>d</xex> prevents it from turning in the contrary
direction.</note><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1191 pr=vmg --></p>

<p><ent>Rate</ent><br/
<hw>Rate</hw> <pr>(r<amac/t)</pr>, <pos>v. t. & i.</pos> <ety>[Perh. fr.
E. <ets>rate</ets>, v. t., to value at a certain rate, to estimate, but
more prob. fr. Sw. <ets>rata</ets> to find fault, to blame, to despise,
to hold cheap; cf. Icel. <ets>hrat</ets> refuse, <ets>hrati</ets>
rubbish.]</ety> <def>To chide with vehemence; to scold; to censure
violently; to berate.</def> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><q>Go, <qex>rate</qex> thy minions, proud, insulting boy!</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Conscience is a check to beginners in sin, reclaiming them from
it, and <qex>rating</qex> them for it.</q>
<rj><qau>Barrow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rate</ent><br/
<hw>Rate</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF., fr. L.
<ets>rata</ets> (sc. <ets>pars</ets>), fr. <ets>ratus</ets> reckoned,
fixed by calculation, p. p. of <ets>reri</ets> to reckon, to calculate.
Cf. <er>Reason</er>.]</ety> <sn>1.</sn> <def>Established portion or
measure; fixed allowance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The one right feeble through the evil <qex>rate</qex><br/
Of food which in her duress she had found.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is established as a measure or criterion;
degree; standard; rank; proportion; ratio; <as>as, a slow <ex>rate</ex>
of movement; <ex>rate</ex> of interest is the ratio of the interest to
the principal, per annum.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Heretofore the <qex>rate</qex> and standard of wit was different
from what it is nowadays.</q> <rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>In this did his holiness and godliness appear above the
<qex>rate</qex> and pitch of other men's, in that he was so . . .
merciful.</q> <rj><qau>Calamy.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Many of the horse could not march at that <qex>rate</qex>, nor
come up soon enough.</q> <rj><qau>Clarendon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Valuation; price fixed with relation to a standard;
cost; charge; <as>as, high or low <ex>rates</ex> of
transportation</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They come at dear <qex>rates</qex> from Japan.</q>
<rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A tax or sum assessed by authority on property for
public use, according to its income or value; esp., in England, a local
tax; <as>as, parish <ex>rates</ex>; town <ex>rates</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Order; arrangement.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Thus sat they all around in seemly <qex>rate</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Ratification; approval.</def> <mark>[R.]</mark>
<rj><au>Chapman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Horol.)</fld> <def>The gain or loss of a timepiece
in a unit of time; <as>as, daily <ex>rate</ex>; hourly <ex>rate</ex>;
etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <fld>(Naut.)</fld> <sd>(a)</sd> <def>The order or class
to which a war vessel belongs, determined according to its size,
armament, etc.; <as>as, first <ex>rate</ex>, second <ex>rate</ex>,
etc.</as></def> <sd>(b)</sd> <def>The class of a merchant vessel for
marine insurance, determined by its relative safety as a risk, as A1,
A2, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rate</ent><br/
<hw>Rate</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Rated</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Rating</conjf>.]</vmorph> <sn>1.</sn> <def>To set a certain
estimate on; to value at a certain price or degree.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>rate</qex> a man by the nature of his companions is a rule
frequent indeed, but not infallible.</q> <rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>You seem not high enough your joys to <qex>rate</qex>.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To assess for the payment of a rate or
tax.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To settle the relative scale, rank, position,
amount, value, or quality of; <as>as, to <ex>rate</ex> a ship; to
<ex>rate</ex> a seaman; to <ex>rate</ex> a pension.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To ratify.</def> <mark>[Obs.]</mark> <ldquo/To
<xex>rate</xex> the truce.<rdquo/ <au>Chapman.</au><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To rate a chronometer</b></col>, <cd>to ascertain the
exact rate of its gain or loss as compared with true time, so as to make
an allowance or computation dependent thereon.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To value; appraise; estimate; reckon.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rate</ent><br/
<hw>Rate</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To be set or considered
in a class; to have rank; <as>as, the ship <ex>rates</ex> as a ship of
the line</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To make an estimate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rateable</ent><br/
<hw>Rate"a*ble</hw> <pr>(-<adot/*b'l)</pr>, <pos>a.</pos> <def>See
<er>Ratable</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ratel</ent><br/
<hw>Ra"tel</hw> <pr>(r<amac/"t<ecr/l)</pr>, <pos>n.</pos>
<ety>[F.]</ety> <fld>(Zool.)</fld> <def>Any carnivore of the genus
<gen>Mellivora</gen>, allied to the weasels and the skunks; -- called
also <altname>honey badger</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Several species are known in Africa and India. The Cape
ratel (<spn>Mellivora Capensis</spn>) and the Indian ratel
(<spn>Mellivora Indica</spn>) are the best known. The back is gray; the
lower parts, face, and tail are black. They are fond of honey, and rob
the nests of wild bees.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ratepayer</ent><br/
<hw>Rate"pay`er</hw> <pr>(-p<amac/`<etil/r)</pr>, <pos>n.</pos> <def>One
who pays rates or taxes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rater</ent><br/
<hw>Rat"er</hw> <pr>(r<amac/t"<etil/r)</pr>, <pos>n.</pos> <def>One who
rates or estimates.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rater</ent><br/
<hw>Rat"er</hw>, <pos>n.</pos> <def>One who rates or scolds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ratfish</ent><br/
<hw>Rat"fish`</hw> <pr>(r<acr/t"f<icr/sh`)</pr>, <pos>n.</pos>
<fld>(Zool.)</fld> <def>Same as <er>Rat-tail</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rath</ent><br/
<hw>Rath</hw> <pr>(r<acr/th)</pr>, <pos>n.</pos> <ety>[Ir.
<ets>rath</ets>.]</ety> <sn>1.</sn> <def>A hill or mound.</def>
<mark>[Ireland]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A kind of ancient fortification found in
Ireland.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rathe</ent><br/
<ent>Rath</ent><br/
<mhw>{ <hw>Rath</hw>, <hw>Rathe</hw> }</mhw> <pr>(r<acr/th)</pr>,
<pos>a.</pos> <ety>[AS. <ets>hr<ae/<edh/</ets>, <ets>hr<ae/d</ets>,
quick, akin to OHG. <ets>hrad</ets>, Icel. <ets>hra<edh/r</ets>.]</ety>
<def>Coming before others, or before the usual time; early.</def>
<mark>[Obs. or Poetic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Bring the <qex>rathe</qex> primrose that forsaken dies.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rathe</ent><br/
<ent>Rath</ent><br/
<mhw>{ <hw>Rath</hw>, <hw>Rathe</hw>, }</mhw> <pos>adv.</pos>
<def>Early; soon; betimes.</def> <mark>[Obs. or Poetic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Why rise ye up so <qex>rathe</qex>?</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Too <qex>rathe</qex> cut off by practice criminal.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rather</ent><br/
<hw>Rath"er</hw> <pr>(r<acr/<th/"<etil/r)</pr>, <pos>a.</pos>
<ety>[Compar. of <er>Rath</er>, <pos>a.</pos>]</ety> <def>Prior;
earlier; former.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Now no man dwelleth at the <qex>rather</qex> town.</q>
<rj><qau>Sir J. Mandeville.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rather</ent><br/
<hw>Rath"er</hw> <pr>(r<acr/<th/"<etil/r; 277)</pr>, <pos>adv.</pos>
<ety>[AS. <ets>hra<edh/or</ets>, compar. of <ets>hra<edh/e</ets>,
<ets>hr<ae/<edh/e</ets>, quickly, immediately. See <er>Rath</er>,
<pos>a.</pos>]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Earlier; sooner; before.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou shalt, quod he, be <qex>rather</qex> false than I.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A good mean to come the <qex>rather</qex> to grace.</q>
<rj><qau>Foxe.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>More readily or willingly; preferably.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>My soul chooseth . . . death <qex>rather</qex> than my life.</q>
<rj><qau>Job vii. 15.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>On the other hand; to the contrary of what was said
or suggested; instead.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Was nothing bettered, but <qex>rather</qex> grew worse.</q>
<rj><qau>Mark v. 26.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Of two alternatives conceived of, this by preference
to, or as more likely than, the other; somewhat.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He sought throughout the world, but sought in vain,<br/
And nowhere finding, <qex>rather</qex> feared her slain.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>More properly; more correctly speaking.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This is an art<br/
Which does mend nature, change it <qex>rather</qex>, but<br/
The art itself is nature.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>In some degree; somewhat; <as>as, the day is
<ex>rather</ex> warm; the house is <ex>rather</ex> damp.</as></def><br/
[<source>1913 Webster</source>]</p>

<cs><p><col><b>The rather</b></col>, <cd>the more so; especially; for
better reason; for particular cause.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>You are come to me in happy time,<br/
<qex>The rather</qex> for I have some sport in hand.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <mcol><col><b>Had rather</b></col>, <it>or</it> <col><b>Would
rather</b></col></mcol>, <cd>prefer to; prefers to; <as>as, he <ex>had
rather</ex>, or <ex>would rather</ex> go than stay</as>.</cd> <ldquo/I
<xex>had rather</xex> speak five words with my understanding than ten
thousand words in an unknown tongue.<rdquo/ <au>1 Cor. xiv. 19.</au> See
<cref>Had rather</cref>, under <er>Had</er>.<br/
[<source>1913 Webster</source>]</p></cs>

<p><ent>Rathripe</ent><br/
<hw>Rath"ripe`</hw> <pr>(r<acr/th"r<imac/p`)</pr>, <pos>a.</pos>
<def>Rareripe, or early ripe.</def> -- <def2><pos>n.</pos> <def>A
rareripe.</def> <mark>[Obs. or Prov. Eng.]</mark></def2><br/
[<source>1913 Webster</source>]</p>

<p><q>Such who delight in <qex>rathripe</qex> fruits.</q>
<rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rathskeller</ent><br/
\'d8<hw>Raths"kel`ler</hw> <pr>(r<aum/ts"k<ecr/l*l<etil/r)</pr>,
<pos>n.</pos> <ety>[G., also <asp>ratskeller</asp>, prop., town-hall
cellar.]</ety> <def>Orig., in Germany, the cellar or basement of the
city hall, usually rented for use as a restaurant where beer is sold;
hence, a beer saloon of the German type below the street level, where,
usually, drinks are served only at tables and simple food may also be
had; -- sometimes loosely used, in English, of what are essentially
basement restaurants where liquors are served.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Ratification</ent><br/
<hw>Rat`i*fi*ca"tion</hw>
<pr>(r<acr/t`<icr/*f<icr/*k<amac/"sh<ucr/n)</pr>, <pos>n.</pos>
<ety>[Cf. F. <ets>ratification</ets>.]</ety> <def>The act of ratifying;
the state of being ratified; confirmation; sanction; <as>as, the
<ex>ratification</ex> of a treaty</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ratifier</ent><br/
<hw>Rat"i*fi`er</hw> <pr>(r<acr/t"<icr/*f<imac/`<etil/r)</pr>,
<pos>n.</pos> <def>One who, or that which, ratifies; a confirmer.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ratify</ent><br/
<hw>Rat"i*fy</hw> <pr>(r<acr/t"<icr/*f<imac/)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Ratified</conjf>
<pr>(r<acr/t"<icr/*f<imac/d)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Ratifying</conjf>
<pr>(r<acr/t"<icr/*f<imac/`<icr/ng)</pr>.]</vmorph> <ety>[F.
<ets>ratifier</ets>, fr. L. <ets>ratus</ets> fixed by calculation, firm,
valid + <ets>-ficare</ets> (in comp.) to make. See <er>Rate</er>,
<pos>n.</pos>, and <er>-fy</er>.]</ety> <def>To approve and sanction; to
make valid; to confirm; to establish; to settle; especially, to give
sanction to, as something done by an agent or servant; <as>as, to
<ex>ratify</ex> an agreement, treaty, or contract; to <ex>ratify</ex> a
nomination.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>It is impossible for the divine power to set a seal to a lie by
<qex>ratifying</qex> an imposture with such a miracle.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ratihabition</ent><br/
<hw>Rat`i*ha*bi"tion</hw> <pr>(-h<adot/*b<icr/sh"<ucr/n)</pr>,
<pos>n.</pos> <ety>[L. <ets>ratihabitio</ets>; <ets>ratus</ets> fixed,
valid + <ets>habere</ets> to hold.]</ety> <def>Confirmation or
approbation, as of an act or contract.</def> <mark>[Obs.]</mark>
<rj><au>Jer. Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ratio</ent><br/
<hw>Ra"ti*o</hw> <pr>(r<amac/"sh<icr/*<osl/ <or/ r<amac/"sh<osl/)</pr>,
<pos>n.</pos> <ety>[L., fr. <ets>reri</ets>, <ets>ratus</ets>, to
reckon, believe, think, judge. See <er>Reason</er>.]</ety> <sn>1.</sn>
<fld>(Math.)</fld> <def>The relation which one quantity or magnitude has
to another of the same kind. It is expressed by the quotient of the
division of the first by the second; thus, the ratio of 3 to 6 is
expressed by <frac36/ or <frac12/; of <it>a</it> to <it>b</it> by
<fract>a/b</fract>; or (less commonly) the second term is made the
dividend; as, <mathex>a:b = <fract>b/a</fract></mathex>.</def><br/
[<source>1913 Webster</source>]</p>

<note><p><hand/ Some writers consider <xex>ratio</xex> as the quotient
itself, making ratio equivalent to a number.<br/
[<source>1913 Webster</source>]</p>

<p>The term <xex>ratio</xex> is also sometimes applied to the
<xex>difference</xex> of two quantities as well as to their
<xex>quotient</xex>, in which case the former is called
<xex>arithmetical ratio</xex>, the latter, <xex>geometrical ratio</xex>.
The name <xex>ratio</xex> is sometimes given to the <xex>rule of
three</xex> in arithmetic. See under <er>Rule</er>.<br/
[<source>1913 Webster</source>]</p></note>

<p><sn>2.</sn> <def>Hence, fixed relation of number, quantity, or
degree; rate; proportion; <as>as, the <ex>ratio</ex> of representation
in Congress</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Compound ratio</b></col>, <col><b>Duplicate
ratio</b></col>, <col><b>Inverse ratio</b></col>, etc.</mcol> <cd>See
under <er>Compound</er>, <er>Duplicate</er>, etc.</cd> -- <col><b>Ratio
of a geometrical progression</b></col>, <cd>the constant quantity by
which each term is multiplied to produce the succeeding
one.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ratiocinate</ent><br/
<hw>Ra`ti*oc"i*nate</hw>
<pr>(r<acr/sh`<icr/*<ocr/s"<icr/*n<amac/t)</pr>, <pos>v. i.</pos>
<ety>[L. <ets>ratiocinatus</ets>, p. p. of <ets>ratiocinari</ets>, fr.
<ets>ratio</ets> reason. See <er>Ratio</er>.]</ety> <def>To reason, esp.
deductively; to offer reason or argument.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ratiocination</ent><br/
<hw>Ra`ti*oc`i*na"tion</hw>
<pr>(r<acr/sh`<icr/*<ocr/s"<icr/*n<amac/"sh<ucr/n)</pr>, <pos>n.</pos>
<ety>[L. <ets>ratiocinatio</ets>: cf. F.
<ets>ratiocination</ets>.]</ety> <def>The process of reasoning, or
deducing conclusions from premises; deductive reasoning.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ratiocinative</ent><br/
<hw>Ra`ti*oc"i*na*tive</hw>
<pr>(r<acr/sh`<icr/*<ocr/s"<icr/*n<asl/*t<icr/v)</pr>, <pos>a.</pos>
<ety>[L. <ets>ratiocinativus</ets>.]</ety> <def>Characterized by, or
addicted to, ratiocination; consisting in the comparison of propositions
or facts, and the deduction of inferences from the comparison;
argumentative; <as>as, a <ex>ratiocinative</ex> process</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>ratiocinative</qex> meditativeness of his character.</q>
<rj><qau>Coleridge.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ratiocinatory</ent><br/
<hw>Ra`ti*oc"i*na*to*ry</hw>
<pr>(r<acr/sh`<icr/*<ocr/s"<icr/*n<adot/*t<osl/*r<ycr/)</pr>,
<pos>a.</pos> <def>Ratiocinative.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ration</ent><br/
<hw>Ra"tion</hw> <pr>(r<amac/"sh<ucr/n <it>or</it>
r<acr/sh"<ucr/n)</pr>, <pos>n.</pos> <ety>[F., fr. L. <ets>ratio</ets> a
reckoning, calculation, relation, reference, LL. <ets>ratio</ets>
ration. See <er>Ratio</er>.]</ety> <sn>1.</sn> <def>A fixed daily
allowance of provisions assigned to a soldier in the army, or a sailor
in the navy, for his subsistence.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Officers have several rations, the number varying
according to their rank or the number of their attendants.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence, a certain portion or fixed amount dealt out;
an allowance; an allotment.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ration</ent><br/
<hw>Ra"tion</hw>, <pos>v. t.</pos> <def>To supply with rations, as a
regiment.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rational</ent><br/
<hw>Ra"tion*al</hw> <pr>(r<acr/sh"<ucr/n*<ait/l)</pr>, <pos>a.</pos>
<ety>[L. <ets>rationalis</ets>: cf. F. <ets>rationnel</ets>. See
<er>Ratio</er>, <er>Reason</er>, and cf. <er>Rationale</er>.]</ety>
<sn>1.</sn> <def>Relating to the reason; not physical; mental.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Moral philosophy was his chiefest end; for the
<qex>rational</qex>, the natural, and mathematics . . . were but simple
pastimes in comparison of the other.</q> <rj><qau>Sir T.
North.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Having reason, or the faculty of reasoning; endowed
with reason or understanding; reasoning.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It is our glory and happiness to have a <qex>rational</qex>
nature.</q> <rj><qau>Law.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Agreeable to reason; not absurd, preposterous,
extravagant, foolish, fanciful, or the like; wise; judicious; <as>as,
<ex>rational</ex> conduct; a <ex>rational</ex> man.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Chem.)</fld> <def>Expressing the type, structure,
relations, and reactions of a compound; graphic; -- said of formulae.
See under <er>Formula</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Rational horizon</b></col>. <fld>(Astron.)</fld> <cd>See
<er>Horizon</er>, 2 <sd>(b)</sd>.</cd> -- <col><b>Rational
quantity</b></col> <fld>(Alg.)</fld>, <cd>one that can be expressed
without the use of a radical sign, or in exact parts of unity; --
opposed to <contr>irrational</contr> or <contr>radical
quantity</contr>.</cd> -- <col><b>Rational symptom</b></col>
<fld>(Med.)</fld>, <cd>one elicited by the statements of the patient
himself and not as the result of a physical examination.</cd></cs> <--
rational drug design. --><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Sane; sound; intelligent; reasonable; sensible;
wise; discreet; judicious.</syn> -- <usage><er>Rational</er>,
<er>reasonable</er>. <xex>Rational</xex> has reference to reason as a
faculty of the mind, and is opposed to <xex>ir</xex>rational; <as>as, a
<ex>rational</ex> being, a <ex>rational</ex> state of mind,
<ex>rational</ex> views, etc.</as> In these cases the speculative reason
is more particularly, referred to. <xex>Reasonable</xex> has reference
to the exercise of this faculty for practical purposes, and means,
governed or directed by reason; <as>as, <ex>reasonable</ex> desires or
plans; a <ex>reasonable</ex> charge; a <ex>reasonable</ex> prospect of
success</as>.</usage><br/
[<source>1913 Webster</source>]</p>

<p><q>What higher in her society thou find'st<br/
Attractive, human, <qex>rational</qex>, love still.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A law may be <qex>reasonable</qex> in itself, although a man does
not allow it, or does not know the reason of the lawgivers.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rational</ent><br/
<hw>Ra"tion*al</hw>, <pos>n.</pos> <def>A rational being.</def>
<rj><au>Young.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rationale</ent><br/
<hw>Ra`tion*a"le</hw> <pr>(r<acr/sh`<ucr/*n<acr/l" <it>or</it>
r<acr/sh`<ucr/n*<amac/"l<esl/)</pr>, <pos>n.</pos> <ety>[L.
<ets>rationalis</ets>, neut. <ets>rationale</ets>. See
<er>Rational</er>, <pos>a.</pos>]</ety> <def>An explanation or
exposition of the principles of some opinion, action, hypothesis,
phenomenon, or the like; also, the principles themselves.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rationalism</ent><br/
<hw>Ra"tion*al*ism</hw> <pr>(r<acr/sh"<ucr/n*<ait/l*<icr/z'm)</pr>,
<pos>n.</pos> <ety>[Cf. F. <ets>rationalisme</ets>.]</ety> <sn>1.</sn>
<fld>(Theol.)</fld> <def>The doctrine or system of those who deduce
their religious opinions from reason or the understanding, as distinct
from, or opposed to, revelation.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Philos.)</fld> <def>The system that makes rational
power the ultimate test of truth; -- opposed to <xex>sensualism</xex>,
or <xex>sensationalism</xex>, and <xex>empiricism</xex>.</def>
<rj><au>Fleming.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rationalist</ent><br/
<hw>Ra"tion*al*ist</hw>, <pos>n.</pos> <ety>[Cf. F.
<ets>rationaliste</ets>.]</ety> <def>One who accepts rationalism as a
theory or system; also, disparagingly, a false reasoner. See Citation
under <er>Reasonist</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rationalistical</ent><br/
<ent>Rationalistic</ent><br/
<mhw>{ <hw>Ra`tion*al*is"tic</hw>
<pr>(r<acr/sh"<ucr/n*<ait/l*<icr/s"t<icr/k)</pr>,
<hw>Ra`tion*al*is"tic*al</hw> <pr>(-t<icr/*k<ait/l)</pr>, }</mhw>
<pos>a.</pos> <def>Belonging to, or in accordance with, the principles
of rationalism.</def> -- <wordforms><wf>Ra`tion*al*is"tic*al*ly</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rationality</ent><br/
<hw>Ra`tion*al"i*ty</hw> <pr>(r<acr/sh"<ucr/n*<acr/l"<icr/*t<ycr/;
277)</pr>, <pos>n.</pos>; <plu><it>pl.</it> <plw>-ties</plw>
<pr>(-t<icr/z)</pr>.</plu> <ety>[F. <ets>rationalit<eacute/</ets>, or L.
<ets>rationalitas</ets>.]</ety> <def>The quality or state of being
rational; agreement with reason; possession of reason; due exercise of
reason; reasonableness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>When God has made <qex>rationality</qex> the common portion of
mankind, how came it to be thy inclosure?</q> <rj><qau>Gov. of
Tongue.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Well-directed intentions, whose <qex>rationalities</qex> will
never bear a rigid examination.</q> <rj><qau>Sir T.
Browne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rationalization</ent><br/
<hw>Ra`tion*al*i*za"tion</hw>
<pr>(r<acr/sh`<ucr/n*<ait/l*<icr/*z<amac/"sh<ucr/n)</pr>, <pos>n.</pos>
<def>The act or process of rationalizing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rationalize</ent><br/
<hw>Ra"tion*al*ize</hw> <pr>(r<acr/sh"<ucr/n*<ait/l*<imac/z)</pr>,
<pos>v. t.</pos> <sn>1.</sn> <def>To make rational; also, to convert to
rationalism.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To interpret in the manner of a
rationalist.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To form a rational conception of.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Alg.)</fld> <def>To render rational; to free from
radical signs or quantities.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rationalize</ent><br/
<hw>Ra"tion*al*ize</hw>, <pos>v. i.</pos> <def>To use, and rely on,
reason in forming a theory, belief, etc., especially in matters of
religion: to accord with the principles of rationalism.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Theodore . . . is justly considered the chief
<qex>rationalizing</qex> doctor of antiquity.</q> <rj><qau>J. H.
Newman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rationally</ent><br/
<hw>Ra"tion*al*ly</hw>, <pos>adv.</pos> <def>In a rational
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rationalness</ent><br/
<hw>Ra"tion*al*ness</hw>, <pos>n.</pos> <def>The quality or state of
being rational; rationality.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ratitae</ent><br/
\'d8<hw>Ra*ti"tae</hw> <pr>(r<adot/*t<imac/"t<esl/)</pr>, <pos>n.
pl.</pos> <ety>[NL., fr. L. <ets>ratis</ets> a raft; cf. L.
<ets>ratitus</ets> marked with the figure of a raft.]</ety>
<fld>(Zool.)</fld> <def>An order of birds in which the wings are small,
rudimentary, or absent, and the breastbone is destitute of a keel. The
ostrich, emu, moa, and apteryx are examples.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ratitate</ent><br/
<hw>Rat"i*tate</hw> <pr>(r<acr/t"<icr/*t<asl/t)</pr>, <pos>a.</pos>
<fld>(Zool.)</fld> <def>Of or pertaining to the Ratitae.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ratite</ent><br/
<hw>Rat"ite</hw> <pr>(r<acr/t"<imac/t)</pr>, <pos>a.</pos>
<fld>(Zool.)</fld> <def>Of or pertaining to the Ratitae.</def> --
<def2><pos>n.</pos> <def>One of the Ratitae.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ratlins</ent><br/
<ent>Ratlines</ent><br/
<mhw>{ <hw>Rat"lines</hw>, <hw>Rat"lins</hw> }</mhw>
<pr>(r<acr/t"l<icr/nz)</pr>, <pos>n. pl.</pos> <ety>[Of uncertain
origin.]</ety> <fld>(Naut.)</fld> <def>The small transverse ropes
attached to the shrouds and forming the steps of a rope ladder.</def>
<altsp>[Written also <asp>ratlings</asp>, and
<asp>rattlings</asp>.]</altsp> <rj><au>Totten.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raton</ent><br/
<hw>Rat"on</hw> <pr>(r<acr/t"<ocr/n)</pr>, <pos>n.</pos> <ety>[Cf.
<er>Raccoon</er>.]</ety> <def>A small rat.</def> <mark>[Obs.]</mark>
<rj><au>Piers Plowman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ratoon</ent><br/
<hw>Ra*toon"</hw> <pr>(r<adot/*t<oomac/n")</pr>, <pos>n.</pos>
<sn>1.</sn> <def>Same as <er>Rattoon</er>, <pos>n.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A rattan cane.</def> <mark>[Obs.]</mark>
<rj><au>Pepys.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ratoon</ent><br/
<hw>Ra*toon"</hw>, <pos>v. i.</pos> <def>Same as <er>Rattoon</er>,
<pos>v. i.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ratsbane</ent><br/
<hw>Rats"bane`</hw> <pr>(r<acr/ts"b<amac/n`)</pr>, <pos>n.</pos>
<ety>[<ets>Rat</ets> + <ets>bane</ets>.]</ety> <def>Rat poison; white
arsenic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ratsbaned</ent><br/
<hw>Rats"baned`</hw> <pr>(r<acr/ts"b<amac/nd`)</pr>, <pos>a.</pos>
<def>Poisoned by ratsbane.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rat-tail</ent><br/
<hw>Rat"-tail`</hw> <pr>(r<acr/t"t<amac/l`)</pr>, <pos>a.</pos>
<def>Like a rat's tail in form; <as>as, a <ex>rat-tail</ex> file, which
is round, slender, and tapering</as>. See <xex>Illust.</xex> of
<er>File</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rat-tail</ent><br/
<hw>Rat"-tail`</hw>, <pos>n.</pos> <sn>1.</sn> <fld>(Far.)</fld>
<pluf>pl.</pluf> <def>An excrescence growing from the pastern to the
middle of the shank of a horse.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <sd>(a)</sd> <def>The California
chimaera. See <er>Chimaera</er>.</def> <sd>(b)</sd> <def>Any fish of the
genus <gen>Macrurus</gen>. See <er>Grenadier</er>, 2.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rat-tailed</ent><br/
<hw>Rat"-tailed`</hw> <pr>(r<acr/t"t<amac/ld`)</pr>, <pos>a.</pos>
<fld>(Zool.)</fld> <def>Having a long, tapering tail like that of a
rat.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Rat-tailed larva</b></col> <fld>(Zool.)</fld>, <cd>the
larva of a fly of the genus Eristalis. See <er>Eristalis</er>.</cd> --
<col><b>Rat-tailed serpent</b></col> <fld>(Zool.)</fld>, <cd>the
fer-de-lance.</cd> -- <col><b>Rat-tailed shrew</b></col>
<fld>(Zool.)</fld>, <cd>the musk shrew.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rattan</ent><br/
<hw>Rat*tan"</hw> <pr>(r<acr/t*t<acr/n")</pr>, <pos>n.</pos> <ety>[Malay
<ets>r<omac/tan</ets>.]</ety> <altsp>[Written also
<asp>ratan</asp>.]</altsp> <fld>(Bot.)</fld> <def>One of the long
slender flexible stems of several species of palms of the genus
<gen>Calamus</gen>, mostly East Indian, though some are African and
Australian. They are exceedingly tough, and are used for walking sticks,
wickerwork, chairs and seats of chairs, cords and cordage, and many
other purposes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ratteen</ent><br/
<hw>Rat*teen"</hw> <pr>(r<acr/t*t<emac/n")</pr>, <pos>n.</pos> <ety>[F.
<ets>ratine</ets>.]</ety> <def>A thick woolen stuff quilled or
twilled.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ratten</ent><br/
<hw>Rat"ten</hw> <pr>(r<acr/t"t'n)</pr>, <pos>v. t.</pos> <ety>[Prov. E.
<ets>ratten</ets> a rat, hence the verb literally means, to do mischief
like a rat.]</ety> <def>To deprive feloniously of the tools used in
one's employment (as by breaking or stealing them), for the purpose of
annoying; <as>as, to <ex>ratten</ex> a mechanic who works during a
strike</as>.</def> <mark>[Trades-union Cant]</mark> <rj><au>J.
McCarthy.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ratter</ent><br/
<hw>Rat"ter</hw> <pr>(r<acr/t"t<etil/r)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>One who, or that which, rats, as one who deserts his
party.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Anything which catches rats; esp., a dog trained to
catch rats; a rat terrier. See <er>Terrier</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rattinet</ent><br/
<hw>Rat`ti*net"</hw> <pr>(-t<icr/*n<ecr/t")</pr>, <pos>n.</pos> <def>A
woolen stuff thinner than ratteen.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ratting</ent><br/
<hw>Rat"ting</hw> <pr>(r<acr/t"t<icr/ng)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>The conduct or practices of one who rats. See <er>Rat</er>, <pos>v.
i.</pos>, 1.</def> <rj><au>Sydney Smith.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The low sport of setting a dog upon rats confined in
a pit to see how many he will kill in a given time.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rattle</ent><br/
<hw>Rat"tle</hw> <pr>(r<acr/t"t'l)</pr>, <pos>v. i.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Rattled</conjf>
<pr>(-t'ld)</pr>; <pos>p. pr. & vb. n.</pos> <conjf>Rattling</conjf>
<pr>(-tl<icr/ng)</pr>.]</vmorph> <ety>[Akin to D. <ets>ratelen</ets>, G.
<ets>rasseln</ets>, AS. <ets>hr<ae/tele</ets> a rattle, in
<ets>hr<ae/tel</ets>wyrt rattlewort; cf. Gr. <grk>kradai`nein</grk> to
swing, wave. Cf. <er>Rail</er> a bird.]</ety> <sn>1.</sn> <def>To make a
quick succession of sharp, inharmonious noises, as by the collision of
hard and not very sonorous bodies shaken together; to clatter.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And the rude hail in <qex>rattling</qex> tempest forms.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>'T was but the wind,<br/
Or the car <qex>rattling</qex> o'er the stony street.</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1192 pr=vmg --></p>

<p><sn>2.</sn> <def>To drive or ride briskly, so as to make a
clattering; <as>as, we <ex>rattled</ex> along for a couple of
miles</as>.</def> <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To make a clatter with the voice; to talk rapidly
and idly; to clatter; -- with <xex>on</xex> or <xex>away</xex>; <as>as,
she <ex>rattled</ex> on for an hour</as>.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rattle</ent><br/
<hw>Rat"tle</hw> <pr>(r<acr/t"t'l)</pr>, <pos>v. t.</pos> <sn>1.</sn>
<def>To cause to make a rattling or clattering sound; <as>as, to
<ex>rattle</ex> a chain</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To assail, annoy, or stun with a rattling
noise.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Sound but another [drum], and another shall<br/
As loud as thine <qex>rattle</qex> the welkin's ear.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Hence, to disconcert; to confuse; <as>as, to
<ex>rattle</ex> one's judgment; to <ex>rattle</ex> a player in a
game.</as></def> <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To scold; to rail at.</def>
<rj><au>L'Estrange.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To rattle off</b></col>. <sd>(a)</sd> <cd>To tell glibly
or noisily; <as>as, <ex>to rattle off</ex> a story</as>.</cd>
<sd>(b)</sd> <cd>To rail at; to scold.</cd> <ldquo/She would sometimes
<xex>rattle off</xex> her servants sharply.<rdquo/
<au>Arbuthnot.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rattle</ent><br/
<hw>Rat"tle</hw>, <pos>n.</pos> <sn>1.</sn> <def>A rapid succession of
sharp, clattering sounds; <as>as, the <ex>rattle</ex> of a
drum</as>.</def> <rj><au>Prior.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Noisy, rapid talk.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>All this ado about the golden age is but an empty
<qex>rattle</qex> and frivolous conceit.</q>
<rj><qau>Hakewill.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>An instrument with which a rattling sound is made;
especially, a child's toy that rattles when shaken.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>rattles</qex> of Isis and the cymbals of Brasilea nearly
enough resemble each other.</q> <rj><qau>Sir W. Raleigh.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Pleased with a <qex>rattle</qex>, tickled with a straw.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A noisy, senseless talker; a jabberer.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It may seem strange that a man who wrote with so much perspicuity,
vivacity, and grace, should have been, whenever he took a part in
conversation, an empty, noisy, blundering <qex>rattle</qex>.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A scolding; a sharp rebuke.</def>
<mark>[Obs.]</mark> <rj><au>Heylin.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Zool.)</fld> <def>Any organ of an animal having a
structure adapted to produce a rattling sound.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The <xex>rattle</xex> of a rattlesnake is composed of
the hardened terminal scales, loosened in succession, but not cast off,
and so modified in form as to make a series of loose, hollow
joints.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>The noise in the throat produced by the air in
passing through mucus which the lungs are unable to expel; -- chiefly
observable at the approach of death, when it is called the <xex>death
rattle</xex>. See <er>R<acir/le</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To spring a rattle</b></col>, <cd>to cause it to
sound.</cd> -- <col><b>Yellow rattle</b></col> <fld>(Bot.)</fld>, <cd>a
yellow-flowered herb (<spn>Rhinanthus Crista-galli</spn>), the ripe
seeds of which rattle in the inflated calyx.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rattlebox</ent><br/
<hw>Rat"tle*box`</hw> <pr>(r<acr/t"t'l*b<ocr/ks`)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>A toy that makes a rattling sound; a rattle.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <sd>(a)</sd> <def>An American herb
(<spn>Crotalaria sagittalis</spn>), the seeds of which, when ripe,
rattle in the inflated pod.</def> <sd>(b)</sd> <def>Any species of
<spn>Crotalaria</spn>, a genus of yellow-flowered herbs, with inflated,
many-seeded pods.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rattle-brained</ent><br/
<hw>Rat"tle-brained`</hw> <pr>(r<acr/t"t'l*br<amac/nd`)</pr>,
<pos>a.</pos> <def>Giddy; rattle-headed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rattlehead</ent><br/
<hw>Rat"tle*head`</hw> <pr>(r<acr/t"t'l*h<ecr/d`)</pr>, <pos>n.</pos>
<def>An empty, noisy talker.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rattle-headed</ent><br/
<hw>Rat"tle-head`ed</hw>, <pos>a.</pos> <def>Noisy; giddy;
unsteady.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rattlemouse</ent><br/
<hw>Rat"tle*mouse`</hw> <pr>(r<acr/t"t'l*mous`)</pr>, <pos>n.</pos>
<def>A bat.</def> <mark>[Obs.]</mark> <rj><au>Puttenham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rattlepate</ent><br/
<hw>Rat"tle*pate`</hw> <pr>(r<acr/t"t'l*p<amac/t`)</pr>, <pos>n.</pos>
<def>A rattlehead.</def> <rj><au>C. Kingsley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rattle-pated</ent><br/
<hw>Rat"tle-pat`ed</hw>, <pos>a.</pos> <def>Rattle-headed.</def>
<ldquo/A noisy, <xex>rattle-pated</xex> fellow.<rdquo/ <rj><au>W.
Irving.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rattler</ent><br/
<hw>Rat"tler</hw> <pr>(r<acr/t"tl<etil/r)</pr>, <pos>n.</pos> <def>One
who, or that which, rattles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rattlesnake</ent><br/
<hw>Rat"tle*snake`</hw> <pr>(r<acr/t"t'l*sn<amac/k`)</pr>, <pos>n.</pos>
<fld>(Zool.)</fld> <def>Any one of several species of venomous American
snakes belonging to the genera <gen>Crotalus</gen> and
<gen>Caudisona</gen>, or <gen>Sistrurus</gen>; sometimes also called
<altname>rattler</altname>. They have a series of horny interlocking
joints at the end of the tail which make a sharp rattling sound when
shaken. The common rattlesnake of the Northern United States
(<spn>Crotalus horridus</spn>), and the <stype>diamondback
rattlesnake</stype> (also called <altname>diamondback rattler</altname>,
and <altname>diamondback</altname>) of the South and East (<spn>Crotalus
adamanteus</spn>) and West (<spn>Crotalus atrox</spn>), are the best
known. See <xex>Illust.</xex> of <er>Fang</er>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><cs><col><b>Ground rattlesnake</b></col> <fld>(Zool.)</fld>, <cd>a
small rattlesnake (<spn>Caudisona miliaria</spn> or <spn>Sistrurus
miliaria</spn>) of the Southern United States, having a small rattle. It
has nine large scales on its head.</cd> -- <col><b>Rattlesnake
fern</b></col> <fld>(Bot.)</fld>, <cd>a common American fern
(<spn>Botrychium Virginianum</spn>) having a triangular decompound frond
and a long-stalked panicle of spore cases rising from the middle of the
frond.</cd> -- <col><b>Rattlesnake grass</b></col> <fld>(Bot.)</fld>,
<cd>a handsome American grass (<spn>Glyceria Canadensis</spn>) with an
ample panicle of rather large ovate spikelets, each one composed of
imbricated parts and slightly resembling the rattle of the rattlesnake.
Sometimes called <altname>quaking grass</altname>.</cd> --
<col><b>Rattlesnake plantain</b></col> <fld>(Bot.)</fld>, <cd>See under
<er>Plantain</er>.</cd> -- <col><b>Rattlesnake root</b></col>
<fld>(Bot.)</fld>, <cd>a name given to certain American species of the
composite genus <gen>Prenanthes</gen> (<spn>Prenanthes alba</spn> and
<spn>Prenanthes serpentaria</spn>), formerly asserted to cure the bite
of the rattlesnake. Called also <altname>lion's foot</altname>,
<altname>gall of the earth</altname>, and <altname>white
lettuce</altname>.</cd> -- <col><b>Rattlesnake's master</b></col>
<fld>(Bot.)</fld> <sd>(a)</sd> <cd>A species of Agave (<spn>Agave
Virginica</spn>) growing in the Southern United States</cd>.
<sd>(b)</sd> <cd>An umbelliferous plant (<spn>Eryngium
yuccaefolium</spn>) with large bristly-fringed linear leaves</cd>.
<sd>(c)</sd> <cd>A composite plant, the blazing star (<spn>Liatris
squarrosa</spn>).</cd> -- <col><b>Rattlesnake weed</b></col>
<fld>(Bot.)</fld>, <cd>a plant of the composite genus
<gen>Hieracium</gen> (<spn>Hieracium venosum</spn>); -- probably so
named from its spotted leaves. See also
<er>Snakeroot</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rattletrap</ent><br/
<hw>Rat"tle*trap`</hw> <pr>(-tr<acr/p`)</pr>, <pos>n.</pos> <def>Any
machine or vehicle that does not run smoothly.</def>
<mark>[Colloq.]</mark> <rj><au>A. Trollope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rattleweed</ent><br/
<hw>Rat"tle*weed`</hw> <pr>(-w<emac/d`)</pr>, <pos>n.</pos>
<fld>(Bot.)</fld> <def>Any plant of the genus <gen>Astragalus</gen>. See
<er>Milk vetch</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rattlewings</ent><br/
<hw>Rat"tle*wings`</hw> <pr>(-w<icr/ngz`)</pr>, <pos>n.</pos>
<fld>(Zool.)</fld> <def>The golden-eye.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rattlewort</ent><br/
<hw>Rat"tle*wort`</hw> <pr>(-w<ucir/rt`)</pr>, <pos>n.</pos> <ety>[AS.
<ets>hr<ae/telwyrt</ets>.]</ety> <fld>(Bot.)</fld> <def>Same as
<er>Rattlebox</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rattlings</ent><br/
<hw>Rat"tlings</hw> <pr>(r<acr/t"tl<icr/ngz)</pr>, <pos>n. pl.</pos>
<fld>(Naut.)</fld> <def>Ratlines.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rattoon</ent><br/
<hw>Rat*toon"</hw> <pr>(r<acr/t*t<oomac/n")</pr>, <pos>n.</pos>
<ety>[Sp. <ets>reto<ntil/o</ets>.]</ety> <def>One of the stems or shoots
of sugar cane of the second year's growth from the root, or later. See
<er>Plant-cane</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rattoon</ent><br/
<hw>Rat*toon"</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Rattooned</conjf> <pr>(-t<oomac/nd")</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Rattooning</conjf>.]</vmorph> <ety>[Cf. Sp.
<ets>reto<ntil/ar</ets>.]</ety> <def>To sprout or spring up from the
root, as sugar cane from the root of the previous year's
planting.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raucid</ent><br/
<hw>Rau"cid</hw> <pr>(r<add/"s<icr/d)</pr>, <pos>a.</pos> <ety>[L.
<ets>raucus</ets> hoarse; cf. LL. <ets>raucidus</ets>.]</ety>
<def>Hoarse; raucous.</def> <mark>[R.]</mark>
<rj><au>Lamb.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raucity</ent><br/
<hw>Rau"ci*ty</hw> <pr>(r<add/"s<icr/*t<ycr/)</pr>, <pos>n.</pos>
<ety>[L. <ets>raucitas</ets>, from <ets>raucus</ets> hoarse: cf. F.
<ets>raucit<eacute/</ets>.]</ety> <def>Harshness of sound; rough
utterance; hoarseness; <as>as, the <ex>raucity</ex> of a trumpet, or of
the human voice</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raucous</ent><br/
<hw>Rau"cous</hw> <pr>(r<add/"k<ucr/s)</pr>, <pos>a.</pos> <ety>[L.
<ets>raucus</ets>.]</ety> <def>Hoarse; harsh; rough; <as>as, a
<ex>raucous</ex>, thick tone</as>.</def> <ldquo/His voice slightly
<xex>raucous</xex>.<rdquo/ <au>Aytoun.</au> --
<wordforms><wf>Rau"cous*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raught</ent><br/
<hw>Raught</hw> <pr>(r<add/t)</pr>, <mark>obs.</mark> <def><pos>imp. &
p. p.</pos> of <er>Reach</er>.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raught</ent><br/
<hw>Raught</hw>, <mark>obs.</mark> <def><pos>imp. & p. p.</pos> of
<er>Reck</er>.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raunch</ent><br/
<hw>Raunch</hw> <pr>(r<add/nch)</pr>, <pos>v. t.</pos> <def>See
<er>Ranch</er>.</def> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raunsoun</ent><br/
<hw>Raun*soun"</hw> <pr>(r<add/n*s<oomac/n")</pr>, <pos>n.</pos>
<def>Ransom.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ravage</ent><br/
<hw>Rav"age</hw> <pr>(r<acr/v"<asl/j; 48)</pr>, <pos>n.</pos> <ety>[F.,
fr. (assumed) L. <ets>rapagium</ets>, <ets>rapaticum</ets>, fr.
<ets>rapere</ets> to carry off by force, to ravish. See
<er>Rapacious</er>, <er>Ravish</er>.]</ety> <def>Desolation by violence;
violent ruin or destruction; devastation; havoc; waste; <as>as, the
<ex>ravage</ex> of a lion; the <ex>ravages</ex> of fire or tempest; the
<ex>ravages</ex> of an army, or of time.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Would one think 't were possible for love<br/
To make such <qex>ravage</qex> in a noble soul?</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Despoilment; devastation; desolation; pillage;
plunder; spoil; waste; ruin.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ravage</ent><br/
<hw>Rav"age</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Ravaged</conjf> <pr>(r<acr/v"<asl/jd)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Ravaging</conjf>
<pr>(r<acr/v"<asl/*j<icr/ng)</pr>.]</vmorph> <ety>[F.
<ets>ravager</ets>. See <er>Ravage</er>, <pos>n.</pos>]</ety> <def>To
lay waste by force; to desolate by violence; to commit havoc or
devastation upon; to spoil; to plunder; to consume.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Already Caesar<br/
Has <qex>ravaged</qex> more than half the globe.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>His lands were daily <qex>ravaged</qex>, his cattle driven
away.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To despoil; pillage; plunder; sack; spoil;
devastate; desolate; destroy; waste; ruin.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ravager</ent><br/
<hw>Rav"a*ger</hw> <pr>(-<asl/*j<etil/r)</pr>, <pos>n.</pos> <def>One
who, or that which, ravages or lays waste; spoiler.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rave</ent><br/
<hw>Rave</hw> <pr>(r<amac/v)</pr>, <mark>obs.</mark>
<def><pos>imp.</pos> of <er>Rive</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rave</ent><br/
<hw>Rave</hw>, <pos>n.</pos> <ety>[Prov. E. <ets>raves</ets>, or
<ets>rathes</ets>, a frame laid on a wagon, for carrying hay,
etc.]</ety> <def>One of the upper side pieces of the frame of a wagon
body or a sleigh.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rave</ent><br/
<hw>Rave</hw> <pr>(r<amac/v)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Raved</conjf> <pr>(r<amac/vd)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Raving</conjf>.]</vmorph> <ety>[F. <ets>r<ecir/ver</ets>
to rave, to be delirious, to dream; perhaps fr. L. <ets>rabere</ets> to
rave, rage, be mad or furious. Cf. <er>Rage</er>,
<er>Reverie</er>.]</ety> <sn>1.</sn> <def>To wander in mind or
intellect; to be delirious; to talk or act irrationally; to be wild,
furious, or raging, as a madman.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In our madness evermore we <qex>rave</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Have I not cause to <qex>rave</qex> and beat my breast?</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The mingled torrent of redcoats and tartans went <qex>raving</qex>
down the valley to the gorge of Killiecrankie.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To rush wildly or furiously.</def>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To talk with unreasonable enthusiasm or excessive
passion or excitement; -- followed by <xex>about</xex>, <xex>of</xex>,
or <xex>on</xex>; <as>as, he <ex>raved</ex> about her
beauty</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The hallowed scene<br/
Which others <qex>rave</qex> of, though they know it not.</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rave</ent><br/
<hw>Rave</hw>, <pos>v. t.</pos> <def>To utter in madness or frenzy; to
say wildly; <as>as, to <ex>rave</ex> nonsense</as>.</def>
<rj><au>Young.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rave</ent><br/
<hw>Rave</hw>, <pos>n.</pos> <sn>1.</sn> <def>An instance of
raving.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>A highly flattering or enthusiastic review of a
play, book, etc.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>A clamorous dance party, especially one featuring a
band or disc jockey playing loud modern rock music oriented toward young
people, held in a large room such as a warehouse, often organized by an
informal or ad hoc sponsor.</def> <mark>[originally British
slang]</mark><br/
[<source>PJC</source>]</p>

<p><ent>Ravehook</ent><br/
<hw>Rave"hook</hw> <pr>(r<amac/v"h<oocr/k)</pr>, <pos>n.</pos>
<fld>(Shipbuilding)</fld> <def>A tool, hooked at the end, for enlarging
or clearing seams for the reception of oakum.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ravel</ent><br/
<hw>Rav"el</hw> <pr>(r<acr/v"'l)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Raveled</conjf> <pr>(-'ld)</pr>
or <conjf>Ravelled</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Raveling</conjf> or <conjf>Ravelling</conjf>.]</vmorph> <ety>[OD.
<ets>ravelen</ets>, D. <ets>rafelen</ets>, akin to LG.
<ets>rebeln</ets>, <ets>rebbeln</ets>, <ets>reffeln</ets>.]</ety>
<sn>1.</sn> <def>To separate or undo the texture of; to unravel; to take
apart; to untwist; to unweave or unknit; -- often followed by
<xex>out</xex>; <as>as, to <ex>ravel</ex> a twist; to <ex>ravel</ex> out
a stocking.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Sleep, that knits up the <qex>raveled</qex> sleave of care.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To undo the intricacies of; to
disentangle.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To pull apart, as the threads of a texture, and let
them fall into a tangled mass; hence, to entangle; to make intricate; to
involve.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>What glory's due to him that could divide<br/
Such <qex>raveled</qex> interests? has the knot untied?</q>
<rj><qau>Waller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The faith of very many men seems a duty so weak and indifferent,
is so often untwisted by violence, or <qex>raveled</qex> and entangled
in weak discourses!</q> <rj><qau>Jer. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ravel</ent><br/
<hw>Rav"el</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To become untwisted
or unwoven; to be disentangled; to be relieved of intricacy.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To fall into perplexity and confusion.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Till, by their own perplexities involved,<br/
They <qex>ravel</qex> more, still less resolved.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To make investigation or search, as by picking out
the threads of a woven pattern.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The humor of <qex>raveling</qex> into all these mystical or
entangled matters.</q> <rj><qau>Sir W. Temple.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raveler</ent><br/
<hw>Rav"el*er</hw> <pr>(-<etil/r)</pr>, <pos>n.</pos> <ety>[Also
<ets>raveller</ets>.]</ety> <def>One who ravels.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ravelin</ent><br/
<hw>Rave"lin</hw> <pr>(r<acr/v"l<icr/n; 277)</pr>, <pos>n.</pos>
<ety>[F.; cf. Sp. <ets>rebellin</ets>, It. <ets>revellino</ets>,
<ets>rivellino</ets>; perhaps fr. L. <ets>re-</ets> again +
<ets>vallum</ets> wall.]</ety> <fld>(Fort.)</fld> <def>A detached work
with two embankments which make a salient angle. It is raised before the
curtain on the counterscarp of the place. Formerly called
<altname>demilune</altname> and <altname>half-moon</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raveling</ent><br/
<hw>Rav"el*ing</hw> <pr>(r<acr/v"'l*<icr/ng)</pr>, <pos>n.</pos>
<ety>[Also <ets>ravelling</ets>.]</ety> <sn>1.</sn> <def>The act of
untwisting or of disentangling.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is raveled out; esp., a thread detached
from a texture.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raven</ent><br/
<hw>Ra"ven</hw> <pr>(r<amac/"v'n)</pr>, <pos>n.</pos> <ety>[AS.
<ets>hr<ae/fn</ets>; akin to D. <ets>raaf</ets>, G. <ets>rabe</ets>,
OHG. <ets>hraban</ets>, Icel. <ets>hrafn</ets>, Dan. <ets>ravn</ets>,
and perhaps to L. <ets>corvus</ets>, Gr. <grk>ko`rax</grk>.
<root/19.]</ety> <fld>(Zool.)</fld> <def>A large black passerine bird
(<spn>Corvus corax</spn>), similar to the crow, but larger, and has a
harsh, loud call. It is native of the northern parts of Europe, Asia and
America, and is noted for its sagacity.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Sea raven</b></col> <fld>(Zool.)</fld>, <cd>the
cormorant.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raven</ent><br/
<hw>Ra"ven</hw>, <pos>a.</pos> <def>Of the color of the raven; jet
black; <as>as, <ex>raven</ex> curls; <ex>raven</ex>
darkness.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><-- raven-haired --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raven</ent><br/
<hw>Rav"en</hw> <pr>(r<acr/v"'n)</pr>, <pos>n.</pos> <ety>[OF.
<ets>ravine</ets> impetuosity, violence, F. <ets>ravine</ets> ravine.
See <er>Ravine</er>, <er>Rapine</er>.]</ety> <altsp>[Written also
<asp>ravin</asp>, and <asp>ravine</asp>.]</altsp> <sn>1.</sn>
<def>Rapine; rapacity.</def> <rj><au>Ray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Prey; plunder; food obtained by violence.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raven</ent><br/
<hw>Rav"en</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Ravened</conjf> <pr>(r<acr/v"'nd)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Ravening</conjf>.]</vmorph> <ety>[Written also
<ets>ravin</ets>, and <ets>ravine</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>To obtain or seize by violence.</def>
<rj><au>Hakewill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To devour with great eagerness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Like rats that <qex>ravin</qex> down their proper bane.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raven</ent><br/
<hw>Rav"en</hw>, <pos>v. i.</pos> <def>To prey with rapacity; to be
greedy; to show rapacity.</def> <altsp>[Written also <asp>ravin</asp>,
and <asp>ravine</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><q>Benjamin shall <qex>raven</qex> as a wolf.</q> <rj><qau>Gen. xlix.
27.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ravenala</ent><br/
\'d8<hw>Rav`e*na"la</hw> <pr>(r<acr/v`<esl/*n<aum/"l<adot/)</pr>,
<pos>n.</pos> <ety>[Malagasy.]</ety> <fld>(Bot.)</fld> <def>A genus of
plants related to the banana.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <spn>Ravenala Madagascariensis</spn>, the principal
species, is an unbranched tree with immense oarlike leaves growing
alternately from two sides of the stem. The sheathing bases of the
leafstalks collect and retain rain water, which flows freely when they
are pierced with a knife, whence the plant is called <altname>traveler's
tree</altname>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ravener</ent><br/
<hw>Rav"en*er</hw> <pr>(r<acr/v"'n*<etil/r)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>One who, or that which, ravens or plunders.</def>
<rj><au>Gower.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A bird of prey, as the owl or vulture.</def>
<mark>[Obs.]</mark> <rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ravening</ent><br/
<hw>Rav"en*ing</hw>, <pos>n.</pos> <def>Eagerness for plunder; rapacity;
extortion.</def> <rj><au>Luke xi. 39.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ravening</ent><br/
<hw>Rav"en*ing</hw>, <pos>a.</pos> <def>Greedily devouring; rapacious;
<as>as, <ex>ravening</ex> wolves</as>.</def> --
<wordforms><wf>Rav"en*ing*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ravenous</ent><br/
<hw>Rav"en*ous</hw> <pr>(r<acr/v"'n*<ucr/s)</pr>, <pos>a.</pos>
<ety>[From 2d <er>Raven</er>.]</ety> <sn>1.</sn> <def>Devouring with
rapacious eagerness; furiously voracious; hungry even to rage; <as>as, a
<ex>ravenous</ex> wolf or vulture</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Eager for prey or gratification; <as>as, a
<ex>ravenous</ex> appetite or desire</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Rav"en*ous*ly</wf>, <pos>adv.</pos> --
<wf>Rav"en*ous*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raven's-duck</ent><br/
<hw>Ra"ven's-duck`</hw> <pr>(r<amac/"v'nz-d<ucr/k`)</pr>, <pos>n.</pos>
<ety>[Cf. G. <ets>ravenstuch</ets>.]</ety> <def>A fine quality of
sailcloth.</def> <rj><au>Ham. Nav. Encyc.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raver</ent><br/
<hw>Rav"er</hw> <pr>(r<amac/v"<etil/r)</pr>, <pos>n.</pos> <def>One who
raves.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ravin</ent><br/
<hw>Rav"in</hw> <pr>(r<acr/v"'n)</pr>, <pos>a.</pos>
<def>Ravenous.</def> <mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ravine</ent><br/
<ent>Ravin</ent><br/
<mhw>{ <hw>Rav"in</hw>, <hw>Rav"ine</hw> }</mhw> <pr>(r<acr/v"'n)</pr>,
<pos>n.</pos> <ety>[See 2d <er>Raven</er>.]</ety> <def>Food obtained by
violence; plunder; prey; raven.</def> <ldquo/Fowls of
<xex>ravyne</xex>.<rdquo/ <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Though Nature, red in tooth and claw<br/
With <qex>ravine</qex>, shrieked against his creed.</q>
<rj><qau>Tennyson.</qau></rj> <-- famous quote from In memoriam, 56, st.
4 --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ravine</ent><br/
<ent>Ravin</ent><br/
<mhw>{ <hw>Rav"in</hw>, <hw>Rav"ine</hw>, }</mhw> <pos>v. t. & i.</pos>
<def>See <er>Raven</er>, <pos>v. t. & i.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ravine</ent><br/
<hw>Ra*vine"</hw> <pr>(r<adot/*v<emac/n")</pr>, <pos>n.</pos> <ety>[F.,
a place excavated by a torrent, a ravine, fr. <ets>ravir</ets> to snatch
or tear away, L. <ets>rapere</ets>; cf. L. <ets>rapina</ets> rapine. See
<er>Ravish</er>, and cf. <er>Rapine</er>, <er>Raven</er> prey.]</ety>
<sn>1.</sn> <def>A torrent of water.</def> <mark>[Obs.]</mark>
<rj><au>Cotgrave.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A deep and narrow hollow, usually worn by a stream
or torrent of water; a gorge; a mountain cleft.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raving</ent><br/
<hw>Rav"ing</hw> <pr>(r<amac/v"<icr/ng)</pr>, <pos>a.</pos> <def>Talking
irrationally and wildly; <as>as, a <ex>raving</ex> lunatic</as>.</def>
-- <wordforms><wf>Rav"ing*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ravish</ent><br/
<hw>Rav"ish</hw> <pr>(r<acr/v"<icr/sh)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Ravished</conjf>
<pr>(-<icr/sht)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Ravishing</conjf>.]</vmorph> <ety>[OE. <ets>ravissen</ets>, F.
<ets>ravir</ets>, fr. L. <ets>rapere</ets> to snatch or tear away, to
ravish. See <er>Rapacious</er>, <er>Rapid</er>, and
<er>-ish</er>.]</ety> <sn>1.</sn> <def>To seize and carry away by
violence; to snatch by force.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>These hairs which thou dost <qex>ravish</qex> from my chin<br/
Will quicken, and accuse thee.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>This hand shall <qex>ravish</qex> thy pretended right.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To transport with joy or delight; to delight to
ecstasy.</def> <ldquo/<xex>Ravished</xex> . . . for the joy.<rdquo/
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou hast <qex>ravished</qex> my heart.</q> <rj><qau>Cant. iv.
9.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To have carnal knowledge of (a woman) by force, and
against her consent; to rape.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To transport; entrance; enrapture; delight;
violate; deflower; force.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ravisher</ent><br/
<hw>Rav"ish*er</hw> <pr>(-<etil/r)</pr>, <pos>n.</pos> <def>One who
ravishes (in any sense).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ravishing</ent><br/
<hw>Rav"ish*ing</hw>, <pos>a.</pos> <def>Rapturous;
transporting.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ravishingly</ent><br/
<hw>Rav"ish*ing*ly</hw>, <pos>adv.</pos> <def>In a ravishing
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ravishment</ent><br/
<hw>Rav"ish*ment</hw> <pr>(-m<eit/nt)</pr>, <pos>n.</pos> <ety>[F.
<ets>ravissement</ets>. See <er>Ravish</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>The act of carrying away by force or against
consent; abduction; <as>as, the <ex>ravishment</ex> of children from
their parents, of a ward from his guardian, or of a wife from her
husband</as>.</def> <rj><au>Blackstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The state of being ravished; rapture; transport of
delight; ecstasy.</def> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>In whose sight all things joy, with <qex>ravishment</qex><br/
Attracted by thy beauty still to gaze.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The act of ravishing a woman; rape.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ravissant</ent><br/
<hw>Rav"is*sant</hw> <pr>(r<acr/v"<icr/s*s<acr/nt)</pr>, <pos>a.</pos>
<ety>[F.]</ety> <fld>(Her.)</fld> <def>In a half-raised position, as if
about to spring on prey.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1193 pr=vmg --></p>

<p><ent>Raw</ent><br/
<hw>Raw</hw> <pr>(r<add/)</pr>, <pos>a.</pos>
<amorph>[<pos>Compar.</pos> <adjf>Rawer</adjf>
<pr>(r<add/"<etil/r)</pr>; <pos>superl.</pos>
<adjf>Rawest</adjf>.]</amorph> <ety>[AS. <ets>hre<aacute/w</ets>; akin
to D. <ets>raauw</ets>, LG. <ets>rau</ets>, G. <ets>roh</ets>, OHG.
<ets>r<omac/</ets>, Icel. <ets>hr<amac/r</ets>, Dan. <ets>raa</ets>, Sw.
<ets>r<aring/</ets>, L. <ets>crudus</ets>, Gr. <grk>kre`as</grk> flesh,
Skr. <ets>kravis</ets> raw flesh. <root/18. Cf. <er>Crude</er>,
<er>Cruel</er>.]</ety> <sn>1.</sn> <def>Not altered from its natural
state; not prepared by the action of heat; <as>as, <ex>raw</ex>
sienna</as>;</def> <specif>specifically,</specif> <def>not cooked; not
changed by heat to a state suitable for eating; not done; <as>as,
<ex>raw</ex> meat</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence: Unprepared for use or enjoyment; immature;
unripe; unseasoned; inexperienced; unpracticed; untried; <as>as,
<ex>raw</ex> soldiers; a <ex>raw</ex> recruit.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Approved himself to the <qex>raw</qex> judgment of the
multitude.</q> <rj><qau>De Quincey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Not worked in due form; in the natural state;
untouched by art; unwrought.</def> Specifically: <sd>(a)</sd> <def>Not
distilled; <as>as, <ex>raw</ex> water</as>.</def> <mark>[Obs.]</mark>
<au>Bacon.</au> <sd>(b)</sd> <def>Not spun or twisted; <as>as,
<ex>raw</ex> silk or cotton</as>.</def> <sd>(c)</sd> <def>Not mixed or
diluted; <as>as, <ex>raw</ex> spirits</as>.</def> <sd>(d)</sd> <def>Not
tried; not melted and strained; <as>as, <ex>raw</ex> tallow</as>.</def>
<sd>(e)</sd> <def>Not tanned; <as>as, <ex>raw</ex> hides</as>.</def>
<sd>(f)</sd> <def>Not trimmed, covered, or folded under; <as>as, the
<ex>raw</ex> edge of a piece of metal or of cloth</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Not covered; bare.</def> Specifically: <sd>(a)</sd>
<def>Bald.</def> <mark>[Obs.]</mark> <ldquo/With skull all
<xex>raw</xex>.<rdquo/ <au>Spenser</au> <sd>(b)</sd> <def>Deprived of
skin; galled; <as>as, a <ex>raw</ex> sore</as>.</def> <sd>(c)</sd>
<def>Sore, as if by being galled.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And all his sinews waxen weak and <qex>raw</qex><br/
Through long imprisonment.</q> <rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Disagreeably damp or cold; chilly; bleak; <as>as, a
<ex>raw</ex> wind</as>.</def> <ldquo/A <xex>raw</xex> and gusty
day.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Raw material</b></col>, <cd>material that has not been
subjected to a (specified) process of manufacture; <as>as, ore is the
<ex>raw material</ex> used in smelting; leather is the <ex>raw
material</ex> of the shoe industry</as>.</cd> -- <col><b>Raw
pig</b></col>, <cd>cast iron as it comes from the smelting
furnace.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raw</ent><br/
<hw>Raw</hw>, <pos>n.</pos> <def>A raw, sore, or galled place; a
sensitive spot; <as>as, to touch one on the <ex>raw</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Like savage hackney coachmen, they know where there is a
<qex>raw</qex>.</q> <rj><qau>De Quincey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rawbone</ent><br/
<hw>Raw"bone`</hw> <pr>(r<add/"b<omac/n`)</pr>, <pos>a.</pos>
<def>Rawboned.</def> <mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rawboned</ent><br/
<hw>Raw"boned`</hw> <pr>(-b<omac/nd`)</pr>, <pos>a.</pos> <def>Having
little flesh on the bones; gaunt.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rawhead</ent><br/
<hw>Raw"head`</hw> <pr>(r<add/"h<ecr/d`)</pr>, <pos>n.</pos> <def>A
specter mentioned to frighten children; <as>as, <ex>rawhead</ex> and
bloodybones</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rawhide</ent><br/
<hw>Raw"hide`</hw> <pr>(r<add/"h<imac/d`)</pr>, <pos>n.</pos> <def>A
cowhide, or coarse riding whip, made of untanned (or raw) hide
twisted.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rawish</ent><br/
<hw>Raw"ish</hw>, <pos>a.</pos> <def>Somewhat raw.</def>
<mark>[R.]</mark> <rj><au>Marston.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rawly</ent><br/
<hw>Raw"ly</hw>, <pos>adv.</pos> <sn>1.</sn> <def>In a raw manner;
unskillfully; without experience.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Without proper preparation or provision.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rawness</ent><br/
<hw>Raw"ness</hw>, <pos>n.</pos> <def>The quality or state of being
raw.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ray</ent><br/
<hw>Ray</hw> <pr>(r<amac/)</pr>, <pos>v. t.</pos> <ety>[An aphetic form
of <ets>array</ets>; cf. <er>Beray</er>.]</ety> <sn>1.</sn> <def>To
array.</def> <mark>[Obs.]</mark> <rj><au>Sir T. More.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To mark, stain, or soil; to streak; to defile.</def>
<mark>[Obs.]</mark> <ldquo/The filth that did it <xex>ray</xex>.<rdquo/
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ray</ent><br/
<hw>Ray</hw>, <pos>n.</pos> <def>Array; order; arrangement; dress.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>And spoiling all her gears and goodly <qex>ray</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ray</ent><br/
<hw>Ray</hw>, <pos>n.</pos> <ety>[OF. <ets>rai</ets>, F.
<ets>rais</ets>, fr. L. <ets>radius</ets> a beam or ray, staff, rod,
spoke of a wheel. Cf. <er>Radius</er>.]</ety> <sn>1.</sn> <def>One of a
number of lines or parts diverging from a common point or center, like
the radii of a circle; <as>as, a star of six
<ex>rays</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>A radiating part of a flower or
plant; the marginal florets of a compound flower, as an aster or a
sunflower; one of the pedicels of an umbel or other circular flower
cluster; radius. See <er>Radius</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <sd>(a)</sd> <def>One of the radiating
spines, or cartilages, supporting the fins of fishes.</def> <sd>(b)</sd>
<def>One of the spheromeres of a radiate, especially one of the arms of
a starfish or an ophiuran.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Physics)</fld> <sd>(a)</sd> <def>A line of light or
heat proceeding from a radiant or reflecting point; a single element of
light or heat propagated continuously; <as>as, a solar <ex>ray</ex>; a
polarized <ex>ray</ex>.</as></def> <sd>(b)</sd> <def>One of the
component elements of the total radiation from a body; any definite or
limited portion of the spectrum; <as>as, the red <ex>ray</ex>; the
violet <ex>ray</ex>.</as> See <ex>Illust</ex>. under
<er>Light</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Sight; perception; vision; -- from an old theory of
vision, that sight was something which proceeded from the eye to the
object seen.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>All eyes direct their <qex>rays</qex><br/
On him, and crowds turn coxcombs as they gaze.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Geom.)</fld> <def>One of a system of diverging
lines passing through a point, and regarded as extending indefinitely in
both directions. See <er>Half-ray</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Bundle of rays</b></col>. <fld>(Geom.)</fld> <cd>See
<cref>Pencil of rays</cref>, below.</cd> -- <col><b>Extraordinary
ray</b></col> <fld>(Opt.)</fld>, <cd>that one of two parts of a ray
divided by double refraction which does not follow the ordinary law of
refraction.</cd> -- <col><b>Ordinary ray</b></col> <fld>(Opt.)</fld>
<cd>that one of the two parts of a ray divided by double refraction
which follows the usual or ordinary law of refraction.</cd> --
<col><b>Pencil of rays</b></col> <fld>(Geom.)</fld>, <cd>a definite
system of rays.</cd> -- <mcol><col><b>Ray flower</b></col>, <it>or</it>
<col><b>Ray floret</b></col></mcol> <fld>(Bot.)</fld>, <cd>one of the
marginal flowers of the capitulum in such composite plants as the aster,
goldenrod, daisy, and sunflower. They have an elongated, strap-shaped
corolla, while the corollas of the disk flowers are tubular and
five-lobed.</cd> -- <col><b>Ray point</b></col> <fld>(Geom.)</fld>,
<cd>the common point of a pencil of rays.</cd> -- <mcol><col><b>Roentgen
ray</b></col>, <col><b>R<oum/ntgen ray</b></col></mcol>
<pr>(r<etil/nt"g<ecr/n r<amac/`)</pr> <fld>(Phys.)</fld>, <cd>a form of
electromagnetic radiation generated in a very highly exhausted vacuum
tube by an electrical discharge; now more commonly called
<altname>X-ray</altname>. It is composed of electromagnetic radiation of
wavelength shorter than that of ultraviolet light but longer than that
of gamma rays. It is capable of passing through many bodies opaque to
light, and producing photographic and fluorescent effects by which means
pictures showing the internal structure of opaque objects are made,
called <xex>X-rays</xex>, <xex>radiographs</xex>, <xex>sciagraphs</xex>,
<xex>X-ray photographs</xex>, <xex>radiograms</xex>. So called from the
discoverer, <person>W. C. <etsep>R<oum/ntgen</etsep></person>.</cd> --
<col><b>X ray</b></col>, <cd>the R<oum/ntgen ray; -- so called by its
discoverer because of its enigmatical character, <it>x</it> being an
algebraic symbol for an unknown quantity.</cd></cs><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Ray</ent><br/
<hw>Ray</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Rayed</conjf> <pr>(r<amac/d)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Raying</conjf>.]</vmorph> <ety>[Cf. OF. <ets>raier</ets>,
<ets>raiier</ets>, <ets>rayer</ets>, L. <ets>radiare</ets> to irradiate.
See <er>Ray</er>, <pos>n.</pos>, and cf. <er>Radiate</er>.]</ety>
<sn>1.</sn> <def>To mark with long lines; to streak.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <ety>[From <er>Ray</er>, <pos>n.</pos>]</ety> <def>To
send forth or shoot out; to cause to shine out; <as>as, to <ex>ray</ex>
smiles</as>.</def> <mark>[R.]</mark> <rj><au>Thomson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ray</ent><br/
<hw>Ray</hw>, <pos>v. i.</pos> <def>To shine, as with rays.</def>
<rj><au>Mrs. Browning.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ray</ent><br/
<hw>Ray</hw>, <pos>n.</pos> <ety>[F. <ets>raie</ets>, L.
<ets>raia</ets>. Cf. <er>Roach</er>.]</ety> <fld>(Zool.)</fld>
<sd>(a)</sd> <def>Any one of numerous elasmobranch fishes of the order
Raiae, including the skates, torpedoes, sawfishes, etc.</def>
<sd>(b)</sd> <def>In a restricted sense, any of the broad, flat,
narrow-tailed species, as the skates and sting rays. See
<er>Skate</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Bishop ray</b></col>, <cd>a yellow-spotted, long-tailed
eagle ray (<spn>Aetobatus narinari</spn> syn. <spn>Stoasodon
narinari</spn>) of the Southern United States and the West Indies; also
called the <altname>spotted eagle ray</altname> and
<altname>white-spotted eagle ray</altname>. </cd> -- <col><b>Butterfly
ray</b></col>, <cd>a short-tailed American sting ray (<spn>Pteroplatea
Maclura</spn>), having very broad pectoral fins.</cd> -- <col><b>Devil
ray</b></col>. <cd>See <er>Sea Devil</er>.</cd> -- <col><b>Eagle
ray</b></col>, <cd>any large ray of the family <fam>Myliobatidae</fam>,
or <fam>Aetobatidae</fam>. The common European species (<spn>Myliobatis
aquila</spn>) is called also <altname>whip ray</altname>, and
<altname>miller</altname>.</cd> -- <mcol><col><b>Electric ray</b></col>,
or <col><b>Cramp ray</b></col></mcol>, <cd>a torpedo.</cd> --
<col><b>Starry ray</b></col>, <cd>a common European skate (<spn>Raia
radiata</spn>).</cd> -- <col><b>Sting ray</b></col>, <cd>any one of
numerous species of rays of the family <fam>Trygonidae</fam> having one
or more large, sharp, barbed dorsal spines on the whiplike tail. Called
also <altname>stingaree</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rayah</ent><br/
\'d8<hw>Ra"yah</hw> <pr>(r<amac/"y<adot/ <or/ r<aum/"y<adot/)</pr>,
<pos>n.</pos> <ety>[Ar. <ets>ra'iyah</ets> a herd, a subject, fr.
<ets>ra'a</ets> to pasture, guard.]</ety> <def>A person not a
Mohammedan, who pays the capitation tax.</def>
<mark>[Turkey.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ray grass</ent><br/
<hw>Ray" grass`</hw> <pr>(r<amac/" gr<adot/s`)</pr>. <ety>[Etymol. of
<ets>ray</ets> is uncertain.]</ety> <fld>(Bot.)</fld> <def>A perennial
European grass (<spn>Lolium perenne</spn>); -- called also <altname>rye
grass</altname>, and <altname>red darnel</altname>. See <er>Darnel</er>,
and <er>Grass</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Italian ray grass</b></col> or <col><b>Italian rye
grass</b></col></mcol>. <cd>See <er>Darnel</er>, and
<er>Grass</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rayless</ent><br/
<hw>Ray"less</hw> <pr>(r<amac/"l<ecr/s)</pr>, <pos>a.</pos>
<def>Destitute of rays; hence, dark; not illuminated; blind; <as>as, a
<ex>rayless</ex> sky; <ex>rayless</ex> eyes.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rayon</ent><br/
<hw>Ray"on</hw> <pr>(r<amac/"<ocr/n)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<def>Ray; beam.</def> <mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rayon</ent><br/
<hw>Ray"on</hw> <pr>(r<amac/"<ocr/n)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>A synthetic fiber, made of thin filaments of regenerated cellulose,
extruded from a solution of <er>viscose</er>. Called also
<altname>viscose fiber</altname> and <altname>viscose rayon
fiber</altname>.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>a textile fabric made from rayon{1}.</def><br/
[<source>PJC</source>]</p>

<p><ent>Rayonnant</ent><br/
<hw>Ray"on*nant</hw> <pr>(r<amac/"<ocr/n*n<acr/nt)</pr>, <pos>a.</pos>
<ety>[F.]</ety> <fld>(Her.)</fld> <def>Darting forth rays, as the sun
when it shines out.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raze</ent><br/
<hw>Raze</hw> <pr>(r<amac/z)</pr>, <pos>n.</pos> <ety>[See
<er>Race</er>.]</ety> <def>A Shakespearean word (used once) supposed to
mean the same as <xex>race</xex>, a root.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Raze</ent><br/
<hw>Raze</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Razed</conjf> <pr>(r<amac/zd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Razing</conjf>.]</vmorph> <ety>[F. <ets>raser</ets>. See
<er>Rase</er>, <pos>v. t.</pos>]</ety> <altsp>[Written also
<asp>rase</asp>.]</altsp> <sn>1.</sn> <def>To erase; to efface; to
obliterate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Razing</qex> the characters of your renown.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To subvert from the foundation; to lay level with
the ground; to overthrow; to destroy; to demolish.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The royal hand that <qex>razed</qex> unhappy Troy.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To demolish; level; prostrate; overthrow;
subvert; destroy; ruin. See <er>Demolish</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Razed</ent><br/
<hw>Razed</hw> <pr>(r<amac/zd)</pr>, <pos>a.</pos> <def>Slashed or
striped in patterns.</def> <mark>[Obs.]</mark> <ldquo/Two Provincial
roses on my <xex>razed</xex> shoes.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Razee</ent><br/
<hw>Ra*zee"</hw> <pr>(r<adot/*z<emac/")</pr>, <pos>n.</pos> <ety>[F.
vaisseau <ets>ras<eacute/</ets>, fr. <ets>raser</ets> to raze, to cut
down ships. See <er>Raze</er>, <pos>v. t.</pos>, <er>Rase</er>, <pos>v.
t.</pos>]</ety> <fld>(Naut.)</fld> <def>An armed ship having her upper
deck cut away, and thus reduced to the next inferior rate, as a
seventy-four cut down to a frigate.</def> <rj><au>Totten.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Razee</ent><br/
<hw>Ra*zee"</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Razeed</conjf> <pr>(r<adot/*z<emac/d")</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Razeeing</conjf>.]</vmorph> <def>To cut down to a less
number of decks, and thus to an inferior rate or class, as a ship;
hence, to prune or abridge by cutting off or retrenching parts; <as>as,
to <ex>razee</ex> a book, or an article</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Razor</ent><br/
<hw>Ra"zor</hw> <pr>(r<amac/"z<etil/r)</pr>, <pos>n.</pos> <ety>[OE.
<ets>rasour</ets>, OF. <ets>rasur</ets>, LL. <ets>rasor</ets>: cf. F.
<ets>rasoir</ets>, LL. <ets>rasorium</ets>. See <er>Raze</er>, <pos>v.
t.</pos>, <er>Rase</er>, <pos>v. t.</pos>]</ety> <sn>1.</sn> <def>A
keen-edged knife of peculiar shape, used in shaving the hair from the
face or the head; also called a <altname>straight razor</altname>.</def>
<ldquo/Take thee a barber's <xex>razor</xex>.<rdquo/ <rj><au>Ezek. v.
1.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>a device used for shaving, having a replaceable
blade with a very sharp edge; also called <altname>safety
razor</altname>. Also a similar device, made of plastic, in which the
blade is neither replaceable nor can be sharpened, intended to be
discarded after the blade dulls -- called a <altname>disposable
razor</altname>.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <def>A tusk of a wild boar.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Razor fish</b></col>. <fld>(Zool.)</fld> <sd>(a)</sd>
<cd>A small Mediterranean fish (<spn>Coryphaena novacula</spn>), prized
for the table</cd>. <sd>(b)</sd> <cd>The razor shell.</cd> --
<col><b>Razor grass</b></col> <fld>(Bot.)</fld>, <cd>a West Indian plant
(<spn>Scleria scindens</spn>), the triangular stem and the leaves of
which are edged with minute sharp teeth.</cd> -- <col><b>Razor
grinder</b></col> <fld>(Zool.)</fld>, <cd>the European goat-sucker.</cd>
-- <col><b>Razor shell</b></col> <fld>(Zool.)</fld>, <cd>any marine
bivalve shell belonging to <gen>Solen</gen> and allied genera,
especially <spn>Solen ensis</spn> (or <spn>Ensatella ensis</spn>), and
<spn>Solen Americana</spn>, which have a long, narrow, somewhat curved
shell, resembling a razor handle in shape. Called also <altname>razor
clam</altname>, <altname>razor fish</altname>, <altname>knife
handle</altname>.</cd> -- <col><b>Razor stone</b></col>. <cd>Same as
<er>Novaculite</er>.</cd> -- <mcol><col><b>Razor strap</b></col>, or
<col><b>razor strop</b></col></mcol>, <cd>a strap or strop used in
sharpening razors.</cd></cs><-- ##?? safety razor; disposable razor;
electric razor --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Razorable</ent><br/
<hw>Ra"zor*a*ble</hw> <pr>(r<amac/"z<etil/r*<adot/*b'l)</pr>,
<pos>a.</pos> <def>Ready for the razor; fit to be shaved.</def>
<mark>[R.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Razorback</ent><br/
<hw>Ra"zor*back`</hw> <pr>(r<amac/"z<etil/r*b<acr/k`)</pr>,
<pos>n.</pos> <fld>(Zool.)</fld> <def>The rorqual.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Razor-backed</ent><br/
<hw>Ra"zor-backed"</hw> <pr>(-b<acr/kt`)</pr>, <pos>a.</pos>
<fld>(Zool.)</fld> <def>Having a sharp, lean, or thin back; <as>as, a
<ex>razor-backed</ex> hog, perch, etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Razorbill</ent><br/
<hw>Ra"zor*bill`</hw> <pr>(-b<icr/l`)</pr>, <pos>n.</pos>
<fld>(Zool.)</fld> <sd>(a)</sd> <def>A species of auk (<spn>Alca
torda</spn>) common in the Arctic seas. See <er>Auk</er>, and
<xex>Illust.</xex> in Appendix.</def> <sd>(b)</sd> <def>See
<er>Cutwater</er>, 3.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>razor-edged</ent><br/
<hw>ra"zor-edged</hw> <pos>a.</pos> <def>having an edge as sharp as that
of a razor; very sharp.</def><br/
[<source>PJC</source>]</p>

<p><ent>razor-thin</ent><br/
<hw>ra"zor-thin</hw> <pos>a.</pos> <def>as thin as a razor blade; very
thin.</def><br/
[<source>PJC</source>]</p>

<p><ent>Razure</ent><br/
<hw>Ra"zure</hw> <pr>(r<amac/"zh<usl/r; 135)</pr>, <pos>n.</pos>
<ety>[See <er>Rasure</er>.]</ety> <sn>1.</sn> <def>The act of erasing or
effacing, or the state of being effaced; obliteration. See
<er>Rasure</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An erasure; a change made by erasing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Razzia</ent><br/
\'d8<hw>Raz"zi*a</hw> <pr>(r<aum/"z<esl/*<aum/)</pr>, <pos>n.</pos>
<ety>[F., fr. Ar. <ets>gh<amac/z<imac/a</ets> (pron. <ets>razia</ets> in
Algeria).]</ety> <def>A plundering and destructive incursion; a foray; a
raid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Re-</ent><br/
<hw>Re-</hw> <pr>(r<emac/-)</pr>. <ety>[L. <ets>re-</ets>, older form
(retained before vowels) <ets>red-</ets>: cf. F. <ets>re-</ets>,
<ets>r<eacute/-</ets>.]</ety> <def>A prefix signifying <xex>back</xex>,
<xex>against</xex>, <xex>again</xex>, <xex>anew</xex>; <as>as,
<ex>re</ex>cline, to lean back; <ex>re</ex>call, to call back;
<ex>re</ex>cede; <ex>re</ex>move; <ex>re</ex>claim, to call out against;
<ex>re</ex>pugn, to fight against; <ex>re</ex>cognition, a knowing
again; <ex>re</ex>join, to join again; <ex>re</ex>iterate;
<ex>re</ex>assure</as>. Combinations containing the prefix <ex>re-</ex>
are readily formed, and are for the most part of obvious
signification.</def><br/
[<source>1913 Webster</source>]</p>

<p><note> With the increase of electronic connunications, in which the
vowels with a diaeresis (e.g. <eum/) are seldom used in contrast with
printed materials, some words with <ex>re</ex> followed by a vowel are
now spelled with a hyphen to indicate that the two vowels are to be
pronounced as two syllables rather than as one syllable, as in
<i>re-emerge</i> rather than <i>re<eum/merge</i>. The unbroken forms
(e.g. <i>reemerge</i>) are, however, usually more commonly used, and the
pronunciation with two syllables for the two vowels is taken as
understood.</note><br/
[<source>PJC</source>]</p>

<p><ent>Re</ent><br/
<hw>Re</hw> <pr>(r<amac/)</pr>. <ety>[It.]</ety> <fld>(Mus.)</fld>
<def>A syllable applied in solmization to the second tone of the
diatonic scale of C; in the American system, to the second tone of any
diatonic scale.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reabsorb</ent><br/
<hw>Re`ab*sorb"</hw> <pr>(r<emac/`<acr/b*s<ocir/rb")</pr>, <pos>v.
t.</pos> <def>To absorb again; to draw in, or imbibe, again what has
been effused, extravasated, or thrown off; to swallow up again; <as>as,
to <ex>reabsorb</ex> chyle, lymph, etc.</as>; -- used esp. of
fluids.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reabsorption</ent><br/
<hw>Re`ab*sorp"tion</hw> <pr>(r<emac/`<acr/b*s<ocir/rp"sh<ucr/n)</pr>,
<pos>n.</pos> <def>The act or process of reabsorbing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reaccess</ent><br/
<hw>Re`ac*cess"</hw> <pr>(r<emac/`<acr/k*s<ecr/s" <or/
r<esl/*<acr/k"s<ecr/s)</pr>, <pos>n.</pos> <def>A second access or
approach; a return.</def> <rj><au>Hakewill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reaccuse</ent><br/
<hw>Re`ac*cuse"</hw> <pr>(r<emac/`<acr/k*k<umac/z")</pr>, <pos>v.
t.</pos> <def>To accuse again.</def> <rj><au>Cheyne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reach</ent><br/
<hw>Reach</hw> <pr>(r<emac/ch)</pr>, <pos>v. i.</pos> <def>To
retch.</def> <rj><au>Cheyne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reach</ent><br/
<hw>Reach</hw>, <pos>n.</pos> <def>An effort to vomit.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reach</ent><br/
<hw>Reach</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Reached</conjf> <pr>(r<emac/cht)</pr> (<conjf>Raught</conjf>, the
old preterit, is obsolete); <pos>p. pr. & vb. n.</pos>
<conjf>Reaching</conjf>.]</vmorph> <ety>[OE. <ets>rechen</ets>, AS.
<ets>r<aemac/can</ets>, <ets>r<aemac/cean</ets>, to extend, stretch out;
akin to D. <ets>reiken</ets>, G. <ets>reichen</ets>, and possibly to AS.
<ets>r<imac/ce</ets> powerful, rich, E. <ets>rich</ets>.
<root/115.]</ety> <sn>1.</sn> <def>To extend; to stretch; to thrust out;
to put forth, as a limb, a member, something held, or the
like.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Her tresses yellow, and long straughten,<br/
Unto her heeles down they <qex>raughten</qex>.</q> <rj><qau>Rom. of
R.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Reach</qex> hither thy hand and thrust it into my side.</q>
<rj><qau>John xx. 27.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Fruit trees, over woody, <qex>reached</qex> too far<br/
Their pampered boughs.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence, to deliver by stretching out a member,
especially the hand; to give with the hand; to pass to another; to hand
over; <as>as, to <ex>reach</ex> one a book</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He <qex>reached</qex> me a full cup.</q> <rj><qau>2 Esd. xiv.
39.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To attain or obtain by stretching forth the hand; to
extend some part of the body, or something held by one, so as to touch,
strike, grasp, or the like; <as>as, to <ex>reach</ex> an object with the
hand, or with a spear</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>O patron power, . . . thy present aid afford,<br/
Than I may <qex>reach</qex> the beast.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To strike, hit, or touch with a missile; <as>as, to
<ex>reach</ex> an object with an arrow, a bullet, or a
shell</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Hence, to extend an action, effort, or influence to;
to penetrate to; to pierce, or cut, as far as.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If these examples of grown men <qex>reach</qex> not the case of
children, let them examine.</q> <rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To extend to; to stretch out as far as; to touch by
virtue of extent; <as>as, his land <ex>reaches</ex> the
river</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thy desire . . . leads to no excess<br/
That <qex>reaches</qex> blame.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>To arrive at; to come to; to get as far
as.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Before this letter <qex>reaches</qex> your hands.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>To arrive at by effort of any kind; to attain to; to
gain; to be advanced to.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The best account of the appearances of nature which human
penetration can <qex>reach</qex>, comes short of its reality.</q>
<rj><qau>Cheyne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>To understand; to comprehend.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Do what, sir? I <qex>reach</qex> you not.</q> <rj><qau>Beau. &
Fl.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <def>To overreach; to deceive.</def> <mark>[Obs.]</mark>
<rj><au>South.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reach</ent><br/
<hw>Reach</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To stretch out the
hand.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Goddess humane, <qex>reach</qex>, then, and freely taste!</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To strain after something; to make
efforts.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Reaching</qex> above our nature does no good.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To extend in dimension, time, amount, action,
influence, etc., so as to touch, attain to, or be equal to,
something.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And behold, a ladder set upon the earth, and the top of it
<qex>reached</qex> to heaven.</q> <rj><qau>Gen. xxviii.
12.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The new world <qex>reaches</qex> quite across the torrid zone.</q>
<rj><qau>Boyle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Naut.)</fld> <def>To sail on the wind, as from one
point of tacking to another, or with the wind nearly abeam.</def><br/
[<source>1913 Webster</source>]</p>

<cs><p><mcol><col><b>To reach after</b></col> <it>or</it> <col><b>To
reach for</b></col> <it>or</it> <col><b>To reach at</b></col></mcol>,
<cd>to make efforts to attain to or obtain.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>He would be in the posture of the mind <qex>reaching after</qex> a
positive idea of infinity.</q> <rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p></cs>

<p><ent>Reach</ent><br/
<hw>Reach</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act of stretching or
extending; extension; power of reaching or touching with the person, or
a limb, or something held or thrown; <as>as, the fruit is beyond my
<ex>reach</ex>; to be within <ex>reach</ex> of cannon
shot.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The power of stretching out or extending action,
influence, or the like; power of attainment or management; extent of
force or capacity.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Drawn by others who had deeper <qex>reaches</qex> than themselves
to matters which they least intended.</q>
<rj><qau>Hayward.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Be sure yourself and your own <qex>reach</qex> to know.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Extent; stretch; expanse; hence, application;
influence; result; scope.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And on the left hand, hell,<br/
With long <qex>reach</qex>, interposed.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I am to pray you not to strain my speech<br/
To grosser issues, nor to larger <qex>reach</qex><br/
Than to suspicion.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>An extended portion of land or water; a stretch; a
straight portion of a stream or river, as from one turn to another; a
level stretch, as between locks in a canal; an arm of the sea extending
up into the land.</def> <ldquo/The river's wooded
<xex>reach</xex>.<rdquo/ <rj><au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The coast . . . is very full of creeks and <qex>reaches</qex>.</q>
<rj><qau>Holland.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>An artifice to obtain an advantage.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The Duke of Parma had particular <qex>reaches</qex> and ends of
his own underhand to cross the design.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>The pole or rod which connects the hind axle with
the forward bolster of a wagon.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reachable</ent><br/
<hw>Reach"a*ble</hw> <pr>(-<adot/*b'l)</pr>, <pos>a.</pos> <def>Being
within reach.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reacher</ent><br/
<hw>Reach"er</hw> <pr>(-<etil/r)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>One who reaches.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An exaggeration.</def> <mark>[Obs.]</mark>
<rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reachless</ent><br/
<hw>Reach"less</hw>, <pos>a.</pos> <def>Being beyond reach;
lofty.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Unto a <qex>reachless</qex> pitch of praises hight.</q>
<rj><qau>Bp. Hall.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>React</ent><br/
<hw>Re*act"</hw> <pr>(r<emac/*<acr/kt")</pr>, <pos>v. t.</pos> <def>To
act or perform a second time; to do over again; to reenact; <as>as, to
<ex>react</ex> a play; the same scenes were <ex>reacted</ex> at
Rome.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>React</ent><br/
<hw>Re*act"</hw> <pr>(r<esl/*<acr/kt")</pr>, <pos>v. i.</pos>
<sn>1.</sn> <def>To return an impulse or impression; to resist the
action of another body by an opposite force; <as>as, every body
<ex>reacts</ex> on the body that impels it from its natural
state</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1194 pr=vmg --></p>

<p><sn>2.</sn> <def>To act upon each other; to exercise a reciprocal or
a reverse effect, as two or more chemical agents; to act in
opposition.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reactance</ent><br/
<hw>Re*act"ance</hw> <pr>(r<esl/*<acr/k"t<ait/ns)</pr>, <pos>n.</pos>
<ety>[<ets>React</ets> + <ets>-ance</ets>.]</ety> <fld>(Elec.)</fld>
<def>The influence of a coil of wire upon an alternating current passing
through it, tending to choke or diminish the current, or the similar
influence of a condenser; inductive resistance. Reactance is measured in
ohms. The reactance of a circuit is equal to the component of the
impressed electro-motive force at right angles to the current divided by
the current, that is, the component of the impedance due to the
self-inductance or capacity of the circuit.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Reactance coil</ent><br/
<hw>Reactance coil</hw> <fld>(Elec.)</fld> <def>A choking
coil.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Reaction</ent><br/
<hw>Re*ac"tion</hw> <pr>(r<esl/*<acr/k"sh<ucr/n)</pr>, <pos>n.</pos>
<ety>[Cf. F. <ets>r<eacute/action</ets>.]</ety> <sn>1.</sn> <def>Any
action in resisting other action or force; counter tendency; movement in
a contrary direction; reverse action.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Chem.)</fld> <def>The mutual or reciprocal action
of chemical agents upon each other, or the action upon such chemical
agents of some form of energy, as heat, light, or electricity, resulting
in a chemical change in one or more of these agents, with the production
of new compounds or the manifestation of distinctive characters. See
<cref>Blowpipe reaction</cref>, <cref>Flame reaction</cref>, under
<er>Blowpipe</er>, and <er>Flame</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Med.)</fld> <def>An action induced by vital
resistance to some other action; depression or exhaustion of vital force
consequent on overexertion or overstimulation; heightened activity and
overaction succeeding depression or shock.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Mech.)</fld> <def>The force which a body subjected
to the action of a force from another body exerts upon the latter body
in the opposite direction.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Reaction</qex> is always equal and opposite to action, that
is to say, the actions of two bodies upon each other are always equal
and in opposite directions.</q> <rj><qau>Sir I. Newton (3d Law of
Motion).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Politics)</fld> <def>Backward tendency or movement
after revolution, reform, or great progress in any direction.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The new king had, at the very moment at which his fame and fortune
reached the highest point, predicted the coming <qex>reaction</qex>.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Psycophysics)</fld> <def>A regular or
characteristic response to a stimulation of the nerves.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>7.</sn> <def>An action by a person or people in response to an
event. The <ex>reaction</ex> may be primarily mental (<ldquo/ a
<ex>reaction</ex> of surprise<rdquo/) but is usually manifested by some
activity.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Reaction time</b></col> <fld>(Physiol.)</fld>, <cd>in
nerve physiology, the interval between the application of a stimulus to
an end organ of sense and the reaction or resulting movement; -- called
also <altname>physiological time</altname>.</cd> -- <col><b>Reaction
wheel</b></col> <fld>(Mech.)</fld>, <cd>a water wheel driven by the
reaction of water, usually one in which the water, entering it
centrally, escapes at its periphery in a direction opposed to that of
its motion by orifices at right angles, or inclined, to its
radii.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reactionary</ent><br/
<hw>Re*ac"tion*a*ry</hw> <pr>(-<asl/*r<ycr/)</pr>, <pos>a.</pos>
<def>Being, causing, or favoring reaction; <as>as, <ex>reactionary</ex>
movements</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reactionary</ent><br/
<hw>Re*ac"tion*a*ry</hw>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Reactionaries</plw> <pr>(-r<icr/z)</pr>.</plu> <def>One who favors
reaction, or seeks to undo political progress or revolution.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reactionist</ent><br/
<hw>Re*ac"tion*ist</hw>, <pos>n.</pos> <def>A reactionary.</def>
<rj><au>C. Kingsley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reactive</ent><br/
<hw>Re*act"ive</hw> <pr>(r<esl/*<acr/kt"<icr/v)</pr>, <pos>a.</pos>
<ety>[Cf. F. <ets>r<eacute/actif</ets>.]</ety> <def>Having power to
react; tending to reaction; of the nature of reaction.</def> --
<wordforms><wf>Re*act"ive*ly</wf>, <pos>adv.</pos> --
<wf>Re*act"ive*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reactor</ent><br/
<hw>Re*act"or</hw>, <pos>n.</pos> <sn>1.</sn> <fld>(Elec.)</fld> <def>A
choking coil.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>A <er>nuclear reactor</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Read</ent><br/
<hw>Read</hw> <pr>(r<emac/d)</pr>, <pos>n.</pos> <def>Rennet. See 3d
<er>Reed</er>.</def> <mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Read</ent><br/
<hw>Read</hw> <pr>(r<emac/d)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Read</conjf> <pr>(r<ecr/d)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Reading</conjf>.]</vmorph> <ety>[OE. <ets>reden</ets>,
<ets>r<ae/den</ets>, AS. <ets>r<aemac/dan</ets> to read, advise,
counsel, fr. <ets>r<aemac/d</ets> advice, counsel,
<ets>r<aemac/dan</ets> (imperf. <ets>reord</ets>) to advise, counsel,
guess; akin to D. <ets>raden</ets> to advise, G. <ets>raten</ets>,
<ets>rathen</ets>, Icel. <ets>r<amac/<edh/a</ets>, Goth.
<ets>r<emac/dan</ets> (in comp.), and perh. also to Skr.
<ets>r<amac/dh</ets> to succeed. <root/116. Cf. <er>Riddle</er>.]</ety>
<sn>1.</sn> <def>To advise; to counsel.</def> <mark>[Obs.]</mark>
<see>See <er>Rede</er>.</see><br/
[<source>1913 Webster</source>]</p>

<p><q>Therefore, I <qex>read</qex> thee, get thee to God's word, and
thereby try all doctrine.</q> <rj><qau>Tyndale.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To interpret; to explain; <as>as, to <ex>read</ex> a
riddle</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To tell; to declare; to recite.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>But <qex>read</qex> how art thou named, and of what kin.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To go over, as characters or words, and utter aloud,
or recite to one's self inaudibly; to take in the sense of, as of
language, by interpreting the characters with which it is expressed; to
peruse; <as>as, to <ex>read</ex> a discourse; to <ex>read</ex> the
letters of an alphabet; to <ex>read</ex> figures; to <ex>read</ex> the
notes of music, or to <ex>read</ex> music; to <ex>read</ex> a
book.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Redeth</qex> [read ye] the great poet of Itaille.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Well could he <qex>rede</qex> a lesson or a story.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Hence, to know fully; to comprehend.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Who is't can <qex>read</qex> a woman?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To discover or understand by characters, marks,
features, etc.; to learn by observation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>An armed corse did lie,<br/
In whose dead face he <qex>read</qex> great magnanimity.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Those about her<br/
From her shall <qex>read</qex> the perfect ways of honor.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>To make a special study of, as by perusing
textbooks; <as>as, to <ex>read</ex> theology or law</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To read one's self in</b></col>, <cd>to read aloud the
Thirty-nine Articles and the Declaration of Assent, -- required of a
clergyman of the Church of England when he first officiates in a new
benefice.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Read</ent><br/
<hw>Read</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To give advice or
counsel.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To tell; to declare.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To perform the act of reading; to peruse, or to go
over and utter aloud, the words of a book or other like
document.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>So they <qex>read</qex> in the book of the law of God distinctly,
and gave the sense.</q> <rj><qau>Neh. viii. 8.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To study by reading; <as>as, he <ex>read</ex> for
the bar</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To learn by reading.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I have <qex>read</qex> of an Eastern king who put a judge to death
for an iniquitous sentence.</q> <rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To appear in writing or print; to be expressed by,
or consist of, certain words or characters; <as>as, the passage
<ex>reads</ex> thus in the early manuscripts</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>To produce a certain effect when read; <as>as, that
sentence <ex>reads</ex> queerly</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To read between the lines</b></col>, <cd>to infer
something different from what is plainly indicated; to detect the real
meaning as distinguished from the apparent meaning.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Read</ent><br/
<hw>Read</hw>, <pos>n.</pos> <ety>[AS. <ets>r<aemac/d</ets> counsel, fr.
<ets>r<aemac/dan</ets> to counsel. See <er>Read</er>, <pos>v.
t.</pos>]</ety> <sn>1.</sn> <def>Saying; sentence; maxim; hence, word;
advice; counsel. See <er>Rede</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <ety>[<er>Read</er>, <pos>v.</pos>]</ety>
<def>Reading.</def> <mark>[Colloq.]</mark> <rj><au>Hume.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>One newswoman here lets magazines for a penny a
<qex>read</qex>.</q> <rj><qau>Furnivall.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Read</ent><br/
<hw>Read</hw> <pr>(r<ecr/d)</pr>, <def><pos>imp. & p. p.</pos> of
<er>Read</er>, <pos>v. t. & i.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Read</ent><br/
<hw>Read</hw> <pr>(r<ecr/d)</pr>, <pos>a.</pos> <def>Instructed or
knowing by reading; versed in books; learned.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A poet . . . well <qex>read</qex> in Longinus.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Readability</ent><br/
<hw>Read`a*bil"i*ty</hw>
<pr>(r<emac/d`<adot/*b<icr/l"<icr/*t<ycr/)</pr>, <pos>n.</pos> <def>The
state of being readable; readableness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Readable</ent><br/
<hw>Read"a*ble</hw> <pr>(r<emac/d"<adot/*b'l)</pr>, <pos>a.</pos>
<def>Such as can be read; legible; fit or suitable to be read; worth
reading; interesting.</def> -- <wordforms><wf>Read"a*ble*ness</wf>,
<pos>n.</pos> -- <wf>Read"a*bly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Readdress</ent><br/
<hw>Re`ad*dress"</hw> <pr>(r<emac/`<acr/d*dr<ecr/s")</pr>, <pos>v.
t.</pos> <def>To address a second time; -- often used
reflexively.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He <qex>readdressed</qex> himself to her.</q>
<rj><qau>Boyle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Readept</ent><br/
<hw>Re`a*dept"</hw> <pr>(-<adot/*d<ecr/pt")</pr>, <pos>v. t.</pos>
<ety>[Pref. <ets>re-</ets> + L. <ets>adeptus</ets>, p. p. of
<ets>adipisci</ets> to obtain.]</ety> <def>To regain; to recover.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Readeption</ent><br/
<hw>Re`a*dep"tion</hw> <pr>(-d<ecr/p"sh<ucr/n)</pr>, <pos>n.</pos>
<def>A regaining; recovery of something lost.</def> <mark>[Obs.]</mark>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reader</ent><br/
<hw>Read"er</hw> <pr>(r<emac/d"<etil/r)</pr>, <pos>n.</pos> <ety>[AS.
<ets>r<aemac/dere</ets>.]</ety> <sn>1.</sn> <def>One who reads.</def>
<specif>Specifically:</specif> <sd>(a)</sd> <def>One whose distinctive
office is to read prayers in a church.</def> <sd>(b)</sd>
<fld>(University of Oxford, Eng.)</fld> <def>One who reads lectures on
scientific subjects.</def> <au>Lyell.</au> <sd>(c)</sd> <def>A proof
reader.</def> <sd>(d)</sd> <def>One who reads manuscripts offered for
publication and advises regarding their merit.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who reads much; one who is studious.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A book containing a selection of extracts for
exercises in reading; an elementary book for practice in a language; a
reading book.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Readership</ent><br/
<hw>Read"er*ship</hw>, <pos>n.</pos> <def>The office of reader.</def>
<rj><au>Lyell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Readily</ent><br/
<hw>Read"i*ly</hw> <pr>(r<ecr/d"<icr/*l<ycr/)</pr>, <pos>adv.</pos>
<sn>1.</sn> <def>In a ready manner; quickly; promptly.</def>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Without delay or objection; without reluctance;
willingly; cheerfully.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>How <qex>readily</qex> we wish time spent revoked!</q>
<rj><qau>Cowper.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Readiness</ent><br/
<hw>Read"i*ness</hw>, <pos>n.</pos> <def>The state or quality of being
ready; preparation; promptness; aptitude; willingness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They received the word with all <qex>readiness</qex> of mind.</q>
<rj><qau>Acts xvii. 11.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Facility; quickness; expedition; promptitude;
promptness; aptitude; aptness; knack; skill; expertness; dexterity;
ease; cheerfulness. See <er>Facility</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reading</ent><br/
<hw>Read"ing</hw> <pr>(r<emac/d"<icr/ng)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>The act of one who reads; perusal; also, printed or written matter
to be read.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Study of books; literary scholarship; <as>as, a man
of extensive <ex>reading</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A lecture or prelection; public recital.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The Jews had their weekly <qex>readings</qex> of the law.</q>
<rj><qau>Hooker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The way in which anything reads; force of a word or
passage presented by a documentary authority; lection;
version.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Manner of reciting, or acting a part, on the stage;
way of rendering.</def> <mark>[Cant]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>An observation read from the scale of a graduated
instrument; <as>as, the <ex>reading</ex> of a barometer</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Reading of a bill</b></col> <fld>(Legislation)</fld>,
<cd>its formal recital, by the proper officer, before the House which is
to consider it.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reading</ent><br/
<hw>Read"ing</hw>, <pos>a.</pos> <sn>1.</sn> <def>Of or pertaining to
the act of reading; used in reading.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Addicted to reading; <as>as, a <ex>reading</ex>
community</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Reading book</b></col>, <cd>a book for teaching reading;
a reader.</cd> -- <col><b>Reading desk</b></col>, <cd>a desk to support
a book while reading; esp., a desk used while reading the service in a
church.</cd> -- <col><b>Reading glass</b></col>, <cd>a large lens with
more or less magnifying power, attached to a handle, and used in
reading, etc.</cd> -- <col><b>Reading man</b></col>, <cd>one who reads
much; hence, in the English universities, a close, industrious
student.</cd> -- <col><b>Reading room</b></col>, <cd>a room appropriated
to reading; a room provided with papers, periodicals, and the like, to
which persons resort.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Readjourn</ent><br/
<hw>Re`ad*journ"</hw> <pr>(r<emac/`<acr/d*j<ucir/rn")</pr>, <pos>v.
t.</pos> <def>To adjourn a second time; to adjourn again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Readjournment</ent><br/
<hw>Re`ad*journ"ment</hw> <pr>(r<emac/`<acr/d*j<ucir/rn"m<eit/nt)</pr>,
<pos>n.</pos> <def>The act of readjourning; a second or repeated
adjournment.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Readjust</ent><br/
<hw>Re`ad*just"</hw> <pr>(r<emac/`<acr/d*j<ucr/st")</pr>, <pos>v.
t.</pos> <def>To adjust or settle again; to put in a different order or
relation; to rearrange.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Readjuster</ent><br/
<hw>Re`ad*just"er</hw> <pr>(r<emac/`<acr/d*j<ucr/st"<etil/r)</pr>,
<pos>n.</pos> <def>One who, or that which, readjusts; in some of the
States of the United States, one who advocates a refunding, and
sometimes a partial repudiation, of the State debt without the consent
of the State's creditors.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Readjustment</ent><br/
<hw>Re`ad*just"ment</hw> <pr>(r<emac/`<acr/d*j<ucr/st"m<eit/nt)</pr>,
<pos>n.</pos> <def>A second adjustment; a new or different
adjustment.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Readmission</ent><br/
<hw>Re`ad*mis"sion</hw> <pr>(r<emac/`<acr/d*m<icr/sh"<ucr/n)</pr>,
<pos>n.</pos> <def>The act of admitting again, or the state of being
readmitted; <as>as, the <ex>readmission</ex> of fresh air into an
exhausted receiver; the <ex>readmission</ex> of a student into a
seminary.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Readmit</ent><br/
<hw>Re`ad*mit"</hw> <pr>(-m<icr/t")</pr>, <pos>v. t.</pos> <def>To admit
again; to give entrance or access to again.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Whose ear is ever open, and his eye<br/
Gracious to <qex>readmit</qex> the suppliant.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Readmittance</ent><br/
<hw>Re`ad*mit"tance</hw> <pr>(-t<ait/ns)</pr>, <pos>n.</pos>
<def>Allowance to enter again; a second admission.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Readopt</ent><br/
<hw>Re`a*dopt"</hw> <pr>(r<emac/`<adot/*d<ocr/pt")</pr>, <pos>v.
t.</pos> <def>To adopt again.</def> <rj><au>Young.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Readorn</ent><br/
<hw>Re`a*dorn"</hw> <pr>(-d<ocir/rn")</pr>, <pos>v. t.</pos> <def>To
adorn again or anew.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Readvance</ent><br/
<hw>Re`ad*vance"</hw> <pr>(r<emac/`<acr/d*v<adot/ns")</pr>, <pos>v.
i.</pos> <def>To advance again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Readvertency</ent><br/
<hw>Re`ad*vert"en*cy</hw>
<pr>(r<emac/`<acr/d*v<etil/rt"<eit/n*s<ycr/)</pr>, <pos>n.</pos>
<def>The act of adverting to again, or of reviewing.</def>
<mark>[R.]</mark> <rj><au>Norris.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ready</ent><br/
<hw>Read"y</hw> <pr>(r<ecr/d"<ycr/)</pr>, <pos>a.</pos>
<amorph>[<pos>Compar.</pos> <adjf>Readier</adjf>
<pr>(r<ecr/d"<icr/*<etil/r)</pr>; <pos>superl.</pos>
<adjf>Readiest</adjf>.]</amorph> <ety>[AS. <ets>r<aemac/de</ets>; akin
to D. ge<ets>reed</ets>, be<ets>reid</ets>, G. be<ets>reit</ets>, Goth.
ga<ets>r<aacute/ids</ets> fixed, arranged, and possibly to E.
<ets>ride</ets>, as meaning originally, prepared for riding. Cf.
<er>Array</er>, 1st <er>Curry</er>.]</ety> <sn>1.</sn> <def>Prepared for
what one is about to do or experience; equipped or supplied with what is
needed for some act or event; prepared for immediate movement or action;
<as>as, the troops are <ex>ready</ex> to march; <ex>ready</ex> for the
journey.</as></def> <ldquo/When she <xex>redy</xex> was.<rdquo/
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Fitted or arranged for immediate use; causing no
delay for lack of being prepared or furnished.</def> <ldquo/Dinner was
<xex>ready</xex>.<rdquo/ <rj><au>Fielding.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>My oxen and my fatlings are killed, and all things are
<qex>ready</qex>: come unto the marriage.</q> <rj><qau>Matt. xxii.
4.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Prepared in mind or disposition; not reluctant;
willing; free; inclined; disposed.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I am <qex>ready</qex> not to be bound only, but also to die at
Jerusalem, for the name of the Lord Jesus.</q> <rj><qau>Acts xxi.
13.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>If need be, I am <qex>ready</qex> to forego<br/
And quit.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Not slow or hesitating; quick in action or
perception of any kind; dexterous; prompt; easy; expert; <as>as, a
<ex>ready</ex> apprehension; <ex>ready</ex> wit; a <ex>ready</ex> writer
or workman.</as></def> <ldquo/<xex>Ready</xex> in devising
expedients.<rdquo/ <rj><au>Macaulay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Gurth, whose temper was <qex>ready</qex>, though surly.</q>
<rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Offering itself at once; at hand; opportune;
convenient; near; easy.</def> <ldquo/The <xex>readiest</xex> way.<rdquo/
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A sapling pine he wrenched from out the ground,<br/
The <qex>readiest</qex> weapon that his fury found.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>On the point; about; on the brink; near; -- with a
following infinitive.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>My heart is <qex>ready</qex> to crack.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Mil.)</fld> <def>A word of command, or a position,
in the manual of arms, at which the piece is cocked and held in position
to execute promptly the next command, which is,
<xex>aim</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>All ready</b></col>, <cd>ready in every particular;
wholly equipped or prepared.</cd> <ldquo/[I] am <xex>all redy</xex> at
your hest.<rdquo/ <au>Chaucer.</au> -- <col><b>Ready money</b></col>,
<cd>means of immediate payment; cash.</cd> <ldquo/'T is all the
<xex>ready money</xex> fate can give.<rdquo/ <au>Cowley.</au> --
<col><b>Ready reckoner</b></col>, <cd>a book of tables for facilitating
computations, as of interest, prices, etc.</cd> -- <col><b>To make
ready</b></col>, <cd>to make preparation; to get in
readiness.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Prompt; expeditious; speedy; unhesitating;
dexterous; apt; skillful; handy; expert; facile; easy; opportune;
fitted; prepared; disposed; willing; free; cheerful. See
<er>Prompt</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ready</ent><br/
<hw>Read"y</hw> <pr>(r<ecr/d"<ycr/)</pr>, <pos>adv.</pos> <def>In a
state of preparation for immediate action; so as to need no
delay.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We ourselves will go <qex>ready</qex> armed.</q> <rj><qau>Num.
xxxii. 17.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ready</ent><br/
<hw>Read"y</hw>, <pos>n.</pos> <def>Ready money; cash; -- commonly with
<xex>the</xex>; <as>as, he was well supplied with the
<ex>ready</ex></as>.</def> <mark>[Slang]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Lord Strut was not flush in <qex>ready</qex>, either to go to law,
or to clear old debts.</q> <rj><qau>Arbuthnot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ready</ent><br/
<hw>Read"y</hw>, <pos>v. t.</pos> <def>To dispose in order.</def>
<mark>[Obs.]</mark> <rj><au>Heywood.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ready-made</ent><br/
<hw>Read"y-made`</hw> <pr>(r<ecr/d"<ycr/-m<amac/d`)</pr>, <pos>a.</pos>
<def>Made already, or beforehand, in anticipation of need; not made to
order; <as>as, <ex>ready-made</ex> clothing; <ex>ready-made</ex>
jokes.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ready-witted</ent><br/
<hw>Read"y-wit`ted</hw> <pr>(r<ecr/d"<ycr/-w<icr/t`t<ecr/d)</pr>,
<pos>a.</pos> <def>Having ready wit.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reaffirm</ent><br/
<hw>Re`af*firm"</hw> <pr>(r<emac/`<acr/f*f<etil/rm")</pr>, <pos>v.
t.</pos> <def>To affirm again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reaffirmation</ent><br/
<ent>Reaffirmance</ent><br/
<mhw>{ <hw>Re`af*firm"ance</hw>
<pr>(r<emac/`<acr/f*f<etil/rm"<ait/ns)</pr>, <hw>Re*af`fir*ma"tion</hw>
<pr>(r<emac/*<acr/f`f<etil/r*m<amac/"sh<ucr/n)</pr>, }</mhw>
<pos>n.</pos> <def>A second affirmation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>reafforest</ent><br/
<ent>re-afforest</ent><br/
<hw>re`af*for"est</hw> <pr>(r<emac/`<acr/f*f<ocr/r"<ecr/st)</pr>,
<pos>v. t.</pos> <def>To convert again into a forest, as a region of
country; to re-establish a forest after clear-cutting or fire, etc.; --
used more often without the hyphen.</def><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><ent>Reafforestation</ent><br/
<hw>Re`af*for`es*ta"tion</hw> <pr>(-<ecr/s*t<amac/"sh<ucr/n)</pr>,
<pos>n.</pos> <def>The act or process of converting again into a
forest.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reagent</ent><br/
<hw>Re*a"gent</hw> <pr>(r<esl/*<amac/"j<eit/nt)</pr>, <pos>n.</pos>
<fld>(Chem.)</fld> <def>A substance capable of producing with another a
reaction, especially when employed to detect the presence of other
bodies; a test.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reaggravation</ent><br/
<hw>Re*ag`gra*va"tion</hw>
<pr>(r<esl/*<acr/g`gr<adot/*v<amac/"sh<ucr/n)</pr>, <pos>n.</pos>
<fld>(R. C. Ch.)</fld> <def>The last monitory, published after three
admonitions and before the last excommunication.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reagree</ent><br/
<hw>Re`a*gree"</hw> <pr>(r<emac/`<adot/*gr<emac/")</pr>, <pos>v.
i.</pos> <def>To agree again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reak</ent><br/
<hw>Reak</hw> <pr>(r<emac/k)</pr>, <pos>n.</pos> <ety>[<root/115. Cf.
<er>Wrack</er> seaweed.]</ety> <def>A rush.</def> <mark>[Obs.]</mark>
<ldquo/Feeds on <xex>reaks</xex> and reeds.<rdquo/
<rj><au>Drant.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reak</ent><br/
<hw>Reak</hw>, <pos>n.</pos> <ety>[Cf. Icel. <ets>hrekkr</ets>, or E.
<ets>wreak</ets> vengeance.]</ety> <def>A prank.</def>
<mark>[Obs.]</mark> <ldquo/They play such <xex>reaks</xex>.<rdquo/
<rj><au>Beau. & Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Real</ent><br/
<hw>Re"al</hw> <pr>(r<emac/"<ait/l)</pr>, <pos>n.</pos> <ety>[Sp., fr.
<ets>real</ets> royal, L. <ets>regalis</ets>. See <er>Regal</er>, and
cf. <er>Ree</er> a coin.]</ety> <def>A former small Spanish silver coin;
also, a denomination of money of account, formerly the unit of the
Spanish monetary system.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ A <col>real of plate</col> (coin) varied in value
according to the time of its coinage, from 12<frac12/ down to 10 cents,
or from 6<frac12/ to 5 pence sterling. The <col>real vellon</col>, or
money of account, was nearly equal to five cents, or 2<frac12/ pence
sterling. In 1871 the coinage of Spain was assimilated to that of the
Latin Union, of which the franc is the unit. The peseta was introduced
in 1868, and continued as the official currency of Spain (splitting
temporarily into Nationalist and Republican pesetas during the civil war
of the 1930's) until 2002. In 2002, the euro became the official
currency of Spain and most other nations of the European
Union.</note><br/
[<source>1913 Webster</source> + <source>PJC</source>]</p>

<p><ent>Real</ent><br/
<hw>Re*al"</hw> <pr>(r<asl/*<aum/l")</pr>, <pos>a.</pos> <def>Royal;
regal; kingly.</def> <mark>[Obs.]</mark> <ldquo/The blood
<xex>real</xex> of Thebes.<rdquo/ <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Real</ent><br/
<hw>Re"al</hw> <pr>(r<emac/"<ait/l)</pr>, <pos>a.</pos> <ety>[LL.
<ets>realis</ets>, fr. L. <ets>res</ets>, <ets>rei</ets>, a thing: cf.
F. <ets>r<eacute/el</ets>. Cf. <er>Rebus</er>.]</ety> <sn>1.</sn>
<def>Actually being or existing; not fictitious or imaginary; <as>as, a
description of <ex>real</ex> life</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Whereat I waked, and found<br/
Before mine eyes all <qex>real</qex>, as the dream<br/
Had lively shadowed.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>True; genuine; not artificial, counterfeit, or
factitious; often opposed to <contr>ostensible</contr>; <as>as, the
<ex>real</ex> reason; <ex>real</ex> Madeira wine; <ex>real</ex>
ginger.</as></def><-- split reason from objects. --><br/
[<source>1913 Webster</source>]</p>

<p><q>Whose perfection far excelled<br/
Hers in all <qex>real</qex> dignity.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Relating to things, not to persons.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Many are perfect in men's humors that are not greatly capable of
the <qex>real</qex> part of business.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Alg.)</fld> <def>Having an assignable arithmetical
or numerical value or meaning; not imaginary.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Law)</fld> <def>Pertaining to things fixed,
permanent, or immovable, as to lands and tenements; <as>as,
<ex>real</ex> property, in distinction from <ex>personal</ex> or
<ex>movable</ex> property</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Chattels real</b></col> <fld>(Law)</fld>, <cd>such
chattels as are annexed to, or savor of, the realty, as terms for years
of land. See <er>Chattel</er>.</cd> -- <col><b>Real action</b></col>
<fld>(Law)</fld>, <cd>an action for the recovery of real property.</cd>
-- <col><b>Real assets</b></col> <fld>(Law)</fld>, <cd>lands or real
estate in the hands of the heir, chargeable with the debts of the
ancestor.</cd> -- <col><b>Real composition</b></col> <fld>(Eccl.
Law)</fld>, <cd>an agreement made between the owner of lands and the
parson or vicar, with consent of the ordinary, that such lands shall be
discharged from payment of tithes, in consequence of other land or
recompense given to the parson in lieu and satisfaction thereof.</cd>
<au>Blackstone.</au> -- <mcol><col><b>Real estate</b></col> <it>or</it>
<col><b>Real property</b></col></mcol>, <cd>lands, tenements, and
hereditaments; freehold interests in landed property; property in houses
and land.</cd> <au>Kent.</au> <au>Burrill.</au> -- <col><b>Real
presence</b></col> <fld>(R. C. Ch.)</fld>, <cd>the actual presence of
the body and blood of Christ in the eucharist, or the conversion of the
substance of the bread and wine into the real body and blood of Christ;
transubstantiation. In other churches there is a belief in a form of
real presence, not however in the sense of
<xex>transubstantiation</xex>.</cd> -- <mcol><col><b>Real
servitude</b></col>, <it>called also</it> <col><b>Predial
servitude</b></col></mcol> <fld>(Civil Law)</fld>, <cd>a burden imposed
upon one estate in favor of another estate of another proprietor.</cd>
<au>Erskine.</au> <au>Bouvier.</au></cs><br/
[<source>1913 Webster</source>]</p>

<usage>
<p><syn><b>Syn.</b> -- Actual; true; genuine; authentic.</syn>
-- <er>Real</er>, <er>Actual</er>. <xex>Real</xex> represents a thing to
be a substantive existence; <as>as, a <ex>real</ex>, not imaginary,
occurrence</as>. <xex>Actual</xex> refers to it as acted or performed;
and, hence, when we wish to prove a thing <xex>real</xex>, we often say,
<ldquo/It <xex>actually</xex> exists,<rdquo/ <ldquo/It has
<xex>actually</xex> been done.<rdquo/ Thus its <xex>reality</xex> is
shown by its <xex>actuality</xex>. <xex>Actual</xex>, from this
reference to being <xex>acted</xex>, has recently received a new
signification, namely, <xex>present</xex>; as, the <xex>actual</xex>
posture of affairs; since what is now in <xex>action</xex>, or going on,
has, of course, a <xex>present</xex> existence. An <xex>actual</xex>
fact; a <xex>real</xex> sentiment.<br/
[<source>1913 Webster</source>]</p>

<p><q>For he that but conceives a crime in thought,<br/
Contracts the danger of an <qex>actual</qex> fault.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Our simple ideas are all <qex>real</qex>; all agree to the
<qex>reality</qex> of things.</q> <rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>
</usage>

<p><-- p. 1195 pr=vmg --></p>

<p><ent>Real</ent><br/
<hw>Re"al</hw> <pr>(r<emac/"<ait/l)</pr>, <pos>n.</pos> <def>A
realist.</def> <mark>[Obs.]</mark> <rj><au>Burton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Realgar</ent><br/
<hw>Re*al"gar</hw> <pr>(r<esl/*<acr/l"g<etil/r)</pr>, <pos>n.</pos>
<ety>[F. <ets>r<eacute/algar</ets>, Sp. <ets>rejalgar</ets>, Ar.
<ets>rahj al gh<amac/r</ets> powder of the mine.]</ety>
<fld>(Min.)</fld> <def>Arsenic sulphide, a mineral of a brilliant red
color; red orpiment. It is also an artificial product.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>realign</ent><br/
<ent>re-align</ent><br/
<mhw><hw>realign</hw>, <hw>re-align</hw></mhw> <pos>v. t.</pos> <def>To
align anew or better; <as>as, <ex>realign</ex> the wheels of my car;
<ex>realign</ex> my jaw</as>. Usually used without the hyphen.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Realism</ent><br/
<hw>Re"al*ism</hw> <pr>(r<emac/"<ait/l*<icr/z'm)</pr>, <pos>n.</pos>
<ety>[Cf. F. <ets>r<eacute/alisme</ets>.]</ety> <sn>1.</sn>
<fld>(Philos.)</fld> <sd>(a)</sd> <def>As opposed to
<xex>nominalism</xex>, the doctrine that genera and species are real
things or entities, existing independently of our conceptions. According
to realism the Universal exists <xex>ante rem</xex> (<xex>Plato</xex>),
or <xex>in re</xex> (<xex>Aristotle</xex>).</def> <sd>(b)</sd> <def>As
opposed to <xex>idealism</xex>, the doctrine that in sense perception
there is an immediate cognition of the external object, and our
knowledge of it is not mediate and representative.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Art & Lit.)</fld> <def>Fidelity to nature or to
real life; representation without idealization, and making no appeal to
the imagination; adherence to the actual fact.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>the practise of assessing facts and the
probabilities of the consequences of actions in an objective manner;
avoidance of unrealistic or impractical beliefs or efforts. Contrasted
to <contr>idealism</contr>, <contr>self-deception</contr>,
<contr>overoptimism</contr>, <contr>overimaginativeness</contr>, or
<contr>visionariness</contr>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Realist</ent><br/
<hw>Re"al*ist</hw>, <pos>n.</pos> <ety>[Cf. F.
<ets>r<eacute/aliste</ets>.]</ety> <sn>1.</sn> <fld>(Philos.)</fld>
<def>One who believes in realism; esp., one who maintains that
<xex>generals</xex>, or the terms used to denote the genera and species
of things, represent real existences, and are not mere names, as
maintained by the <xex>nominalists</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Art. & Lit.)</fld> <def>An artist or writer who
aims at realism in his work. See <er>Realism</er>, 2.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>a person who avoids unrealistic or impractical
beliefs or efforts. Contrasted to <contr>idealist</contr> or
<contr>visionary</contr>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Realistic</ent><br/
<hw>Re`al*is"tic</hw> <pr>(-<icr/s"t<icr/k)</pr>, <pos>a.</pos> <def>Of
or pertaining to the realists; in the manner of the realists;
characterized by realism rather than by imagination.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Realistically</ent><br/
<hw>Re`al*is"tic*al*ly</hw>, <pos>adv.</pos> <def>In a realistic
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reality</ent><br/
<hw>Re*al"i*ty</hw> <pr>(r<esl/*<acr/l"<icr/*t<ycr/)</pr>,
<pos>n.</pos>; <plu><it>pl.</it> <plw>Realities</plw>
<pr>(-t<icr/z)</pr>.</plu> <ety>[Cf. F.
<ets>r<eacute/alit<eacute/</ets>, LL. <ets>realitas</ets>. See 3d
<er>Real</er>, and cf. 2d <er>Realty</er>.]</ety> <sn>1.</sn> <def>The
state or quality of being real; actual being or existence of anything,
in distinction from mere appearance; fact.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A man fancies that he understands a critic, when in
<qex>reality</qex> he does not comprehend his meaning.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is real; an actual existence; that which
is not imagination, fiction, or pretense; that which has objective
existence, and is not merely an idea.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And to <qex>realities</qex> yield all her shows.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>My neck may be an idea to you, but it is a <qex>reality</qex> to
me.</q> <rj><qau>Beattie.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <ety>[See 1st <er>Realty</er>, 2.]</ety> <def>Loyalty;
devotion.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>To express our <qex>reality</qex> to the emperor.</q>
<rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Law)</fld> <def>See 2d <er>Realty</er>,
2.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Realizable</ent><br/
<hw>Re"al*i`za*ble</hw> <pr>(r<emac/"<ait/l*<imac/`z<adot/*b'l)</pr>,
<pos>a.</pos> <def>Capable of being realized.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Realization</ent><br/
<hw>Re`al*i*za"tion</hw>
<pr>(r<emac/`<ait/l*<icr/*z<amac/"sh<ucr/n)</pr>, <pos>n.</pos>
<ety>[Cf. F. <ets>r<eacute/alisation</ets>.]</ety> <def>The act of
realizing, or the state of being realized.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Realize</ent><br/
<hw>Re"al*ize</hw> <pr>(r<emac/"<ait/l*<imac/z)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Realized</conjf>
<pr>(-<imac/zd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Realizing</conjf> <pr>(-<imac/`z<icr/ng)</pr>.]</vmorph>
<ety>[Cf. F. <ets>r<eacute/aliser</ets>.]</ety> <sn>1.</sn> <def>To make
real; to convert from the imaginary or fictitious into the actual; to
bring into concrete existence; to effectuate; to accomplish; <as>as, to
<ex>realize</ex> a scheme or project</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We <qex>realize</qex> what Archimedes had only in hypothesis,
weighing a single grain against the globe of earth.</q>
<rj><qau>Glanvill.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To cause to seem real; to impress upon the mind as
actual; to feel vividly or strongly; to make one's own in apprehension
or experience.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Many coincidences . . . soon begin to appear in them [Greek
inscriptions] which <qex>realize</qex> ancient history to us.</q>
<rj><qau>Jowett.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>We can not <qex>realize</qex> it in thought, that the object . . .
had really no being at any past moment.</q> <rj><qau>Sir W.
Hamilton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To convert into real property; to make real estate
of; <as>as, to <ex>realize</ex> his fortune</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To acquire as an actual possession; to obtain as the
result of plans and efforts; to gain; to get; <as>as, to
<ex>realize</ex> large profits from a speculation</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Knighthood was not beyond the reach of any man who could by
diligent thrift <qex>realize</qex> a good estate.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To convert into actual money; <as>as, to
<ex>realize</ex> assets</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Realize</ent><br/
<hw>Re"al*ize</hw>, <pos>v. i.</pos> <def>To convert any kind of
property into money, especially property representing investments, as
shares in stock companies, bonds, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Wary men took the alarm, and began to <qex>realize</qex>, a word
now first brought into use to express the conversion of ideal property
into something real.</q> <rj><qau>W. Irving.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Realizer</ent><br/
<hw>Re"al*i`zer</hw> <pr>(-<imac/`z<etil/r)</pr>, <pos>n.</pos> <def>One
who realizes.</def> <rj><au>Coleridge.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Realizing</ent><br/
<hw>Re"al*i`zing</hw> <pr>(-z<icr/ng)</pr>, <pos>a.</pos> <def>Serving
to make real, or to impress on the mind as a reality; <as>as, a
<ex>realizing</ex> view of the danger incurred</as>.</def> --
<wordforms><wf>Re"al*i`zing*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reallege</ent><br/
<hw>Re`al*lege"</hw> <pr>(-<acr/l*l<ecr/j")</pr>, <pos>v. t.</pos>
<def>To allege again.</def> <rj><au>Cotgrave.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Realliance</ent><br/
<hw>Re`al*li"ance</hw> <pr>(-l<imac/"<ait/ns)</pr>, <pos>n.</pos> <def>A
renewed alliance.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Re-ally</ent><br/
<hw>Re"-al*ly"</hw> <pr>(-l<imac/")</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>re-</ets> + <ets>ally</ets>, v. t.]</ety> <def>To bring together
again; to compose or form anew.</def> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Really</ent><br/
<hw>Re"al*ly`</hw> <pr>(r<amac/"<aum/l*l<emac/`)</pr>, <pos>adv.</pos>
<def>Royally.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Really</ent><br/
<hw>Re"al*ly</hw> <pr>(r<emac/"<ait/l*l<ycr/)</pr>, <pos>adv.</pos>
<def>In a real manner; with or in reality; actually; in truth.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Whose anger is <qex>really</qex> but a short fit of madness.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Really</xex> is often used familiarly as a slight
corroboration of an opinion or a declaration.</note><br/
[<source>1913 Webster</source>]</p>

<p><q>Why, <qex>really</qex>, sixty-five is somewhat old.</q>
<rj><qau>Young.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Realm</ent><br/
<hw>Realm</hw> <pr>(r<ecr/lm)</pr>, <pos>n.</pos> <ety>[OE.
<ets>realme</ets>, <ets>ream</ets>, <ets>reaume</ets>, OF.
<ets>reialme</ets>, <ets>roialme</ets>, F. <ets>royaume</ets>, fr.
(assumed) LL. <ets>regalimen</ets>, from L. <ets>regalis</ets> royal.
See <er>Regal</er>.]</ety> <sn>1.</sn> <def>A royal jurisdiction or
domain; a region which is under the dominion of a king; a
kingdom.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The absolute master of <qex>realms</qex> on which the sun
perpetually shone.</q> <rj><qau>Motley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence, in general, province; region; country;
domain; department; division; <as>as, the <ex>realm</ex> of
fancy</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Realmless</ent><br/
<hw>Realm"less</hw>, <pos>a.</pos> <def>Destitute of a realm.</def>
<rj><au>Keats.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Realness</ent><br/
<hw>Re"al*ness</hw> <pr>(r<emac/"<ait/l*n<ecr/s)</pr>, <pos>n.</pos>
<def>The quality or condition of being real; reality.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Realty</ent><br/
<hw>Re"al*ty</hw> <pr>(-t<ycr/)</pr>, <pos>n.</pos> <ety>[OF.
<ets>r<eacute/alt<eacute/</ets>, LL. <ets>regalitas</ets>, fr. L.
<ets>regalis</ets>. See <er>Regal</er>.]</ety> <sn>1.</sn>
<def>Royalty.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Loyalty; faithfulness.</def> <mark>[R.]</mark>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Realty</ent><br/
<hw>Re"al*ty</hw>, <pos>n.</pos> <ety>[Contr. from 1st
<er>Reality</er>.]</ety> <sn>1.</sn> <def>Reality.</def>
<mark>[Obs.]</mark> <rj><au>Dr. H. More.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <sd>(a)</sd> <def>Immobility, or the
fixed, permanent nature of real property; <as>as, chattels which savor
of the <ex>realty</ex></as>; -- so written in legal language for
<xex>reality</xex>.</def> <sd>(b)</sd> <def>Real estate; a piece of real
property.</def> <rj><au>Blackstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ream</ent><br/
<hw>Ream</hw> <pr>(r<emac/m)</pr>, <pos>n.</pos> <ety>[AS.
<ets>re<aacute/m</ets>, akin to G. <ets>rahm</ets>.]</ety> <def>Cream;
also, the cream or froth on ale.</def> <mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ream</ent><br/
<hw>Ream</hw>, <pos>v. i.</pos> <def>To cream; to mantle.</def>
<mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>A huge pewter measuring pot which, in the language of the hostess,
<qex>reamed</qex> with excellent claret.</q> <rj><qau>Sir W.
Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ream</ent><br/
<hw>Ream</hw>, <pos>v. t.</pos> <ety>[Cf. <er>Reim</er>.]</ety> <def>To
stretch out; to draw out into thongs, threads, or filaments.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ream</ent><br/
<hw>Ream</hw>, <pos>n.</pos> <ety>[OE. <ets>reme</ets>, OF.
<ets>rayme</ets>, F. <ets>rame</ets> (cf. Sp. <ets>resma</ets>), fr. Ar.
<ets>rizma</ets> a bundle, especially of paper.]</ety> <def>A bundle,
package, or quantity of paper, usually consisting of twenty quires or
480 sheets.</def><-- now 500 --><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Printer's ream</b></col>, <cd>twenty-one and a half
quires. <mark>[Eng.]</mark> A common practice is now to count five
hundred sheets to the <xex>ream</xex>.</cd> <au>Knight.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ream</ent><br/
<hw>Ream</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Reamed</conjf> <pr>(r<emac/md)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Reaming</conjf>.]</vmorph> <ety>[Cf. G. <ets>r<aum/umen</ets> to
remove, to clear away, fr. <ets>raum</ets> room. See
<er>Room</er>.]</ety> <def>To bevel out, as the mouth of a hole in wood
or metal; in modern usage, to enlarge or dress out, as a hole, with a
reamer.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reame</ent><br/
<hw>Reame</hw> <pr>(r<emac/m)</pr>, <pos>n.</pos> <def>Realm.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reamer</ent><br/
<hw>Ream"er</hw> <pr>(-<etil/r)</pr>, <pos>n.</pos> <def>One who, or
that which, reams; specifically, an instrument with cutting or scraping
edges, used, with a twisting motion, for enlarging a round hole, as the
bore of a cannon, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reamputation</ent><br/
<hw>Re*am`pu*ta"tion</hw>
<pr>(r<emac/*<acr/m`p<usl/*t<amac/"sh<ucr/n)</pr>, <pos>n.</pos>
<fld>(Surg.)</fld> <def>The second of two amputations performed upon the
same member.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reanimate</ent><br/
<hw>Re*an"i*mate</hw> <pr>(r<esl/*<acr/n"<icr/*m<amac/t)</pr>, <pos>v.
t.</pos> <def>To animate anew; to restore to animation or life; to
infuse new life, vigor, spirit, or courage into; to revive; to
reinvigorate; <as>as, to <ex>reanimate</ex> a drowned person; to
<ex>reanimate</ex> disheartened troops; to <ex>reanimate</ex> languid
spirits.</as></def> <rj><au>Glanvill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reanimation</ent><br/
<hw>Re*an`i*ma"tion</hw>
<pr>(r<esl/*<acr/n"<icr/*m<amac/"sh<ucr/n)</pr>, <pos>n.</pos> <def>The
act or operation of reanimating, or the state of being reanimated;
reinvigoration; revival.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reannex</ent><br/
<hw>Re`an*nex"</hw> <pr>(r<emac/`<acr/n*n<ecr/ks")</pr>, <pos>v.
t.</pos> <def>To annex again or anew; to reunite.</def> <ldquo/To
<xex>reannex</xex> that duchy.<rdquo/ <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reannexation</ent><br/
<hw>Re*an`nex*a"tion</hw> <pr>(-<amac/"sh<ucr/n)</pr>, <pos>n.</pos>
<def>Act of reannexing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reanswer</ent><br/
<hw>Re*an"swer</hw> <pr>(r<esl/*<acr/n"s<etil/r)</pr>, <pos>v. t. &
i.</pos> <def>To answer in return; to repay; to compensate; to make
amends for.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Which in weight to <qex>reanswer</qex>, his pettiness would bow
under.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reap</ent><br/
<hw>Reap</hw> <pr>(r<emac/p)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Reaped</conjf> <pr>(r<emac/pt)</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>Reaping</conjf>.]</vmorph> <ety>[OE.
<ets>repen</ets>, AS. <ets>r<imac/pan</ets> to seize, reap; cf. D.
<ets>rapen</ets> to glean, reap, G. <ets>raufen</ets> to pluck, Goth.
<ets>raupjan</ets>, or E. <ets>ripe</ets>.]</ety> <sn>1.</sn> <def>To
cut with a sickle, scythe, or reaping machine, as grain; to gather, as a
harvest, by cutting.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>When ye <qex>reap</qex> the harvest of your land, thou shalt not
wholly reap the corners of thy field.</q> <rj><qau>Lev. xix.
9.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To gather; to obtain; to receive as a reward or
harvest, or as the fruit of labor or of works; -- in a good or a bad
sense; <as>as, to <ex>reap</ex> a benefit from exertions</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Why do I humble thus myself, and, suing<br/
For peace, <qex>reap</qex> nothing but repulse and hate?</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To clear of a crop by reaping; <as>as, to
<ex>reap</ex> a field</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To deprive of the beard; to shave.</def>
<mark>[R.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Reaping hook</b></col>, <cd>an implement having a
hook-shaped blade, used in reaping; a sickle; -- in a specific sense,
distinguished from a sickle by a blade keen instead of
serrated.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reap</ent><br/
<hw>Reap</hw>, <pos>v. i.</pos> <def>To perform the act or operation of
reaping; to gather a harvest.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They that sow in tears shall <qex>reap</qex> in joy.</q>
<rj><qau>Ps. cxxvi. 5.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reap</ent><br/
<hw>Reap</hw>, <pos>n.</pos> <ety>[Cf. AS. <ets>r<imac/p</ets> harvest.
See <er>Reap</er>, <pos>v.</pos>]</ety> <def>A bundle of grain; a
handful of grain laid down by the reaper as it is cut.</def> <mark>[Obs.
or Prov. Eng.]</mark> <rj><au>Wright.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reaper</ent><br/
<hw>Reap"er</hw> <pr>(r<emac/p"<etil/r)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>One who reaps.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The sun-burned <qex>reapers</qex> wiping their foreheads.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A reaping machine.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reapparel</ent><br/
<hw>Re`ap*par"el</hw> <pr>(r<emac/`<acr/p*p<acr/r"<ecr/l)</pr>, <pos>v.
t.</pos> <def>To clothe again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reappear</ent><br/
<hw>Re`ap*pear"</hw> <pr>(r<emac/`<acr/p*p<emac/r")</pr>, <pos>v.
i.</pos> <def>To appear again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reappearance</ent><br/
<hw>Re`ap*pear"ance</hw> <pr>(-<ait/ns)</pr>, <pos>n.</pos> <def>A
second or new appearance; the act or state of appearing again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reapplication</ent><br/
<hw>Re*ap`pli*ca"tion</hw>
<pr>(r<emac/*<acr/p`pl<icr/*k<amac/"sh<ucr/n)</pr>, <pos>n.</pos>
<def>The act of reapplying, or the state of being reapplied.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reapply</ent><br/
<hw>Re`ap*ply"</hw> <pr>(r<emac/`<acr/p*pl<imac/")</pr>, <pos>v. t. &
i.</pos> <def>To apply again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reappoint</ent><br/
<hw>Re`ap*point"</hw> <pr>(-point")</pr>, <pos>v. t.</pos> <def>To
appoint again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reappointment</ent><br/
<hw>Re`ap*point"ment</hw> <pr>(-m<eit/nt)</pr>, <pos>n.</pos> <def>The
act of reappointing, or the state of being reappointed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reapportion</ent><br/
<hw>Re`ap*por"tion</hw> <pr>(-p<omac/r"sh<ucr/n)</pr>, <pos>v. t.</pos>
<def>To apportion again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reapportionment</ent><br/
<hw>Re`ap*por"tion*ment</hw> <pr>(-m<eit/nt)</pr>, <pos>n.</pos> <def>A
second or a new apportionment.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reapproach</ent><br/
<hw>Re`ap*proach"</hw> <pr>(r<emac/`<acr/p*pr<omac/ch")</pr>, <pos>v. i.
& t.</pos> <def>To approach again or anew.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rear</ent><br/
<hw>Rear</hw> <pr>(r<emac/r)</pr>, <pos>adv.</pos> <def>Early;
soon.</def> <mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Then why does Cuddy leave his cot so <qex>rear</qex>?</q>
<rj><qau>Gay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rear</ent><br/
<hw>Rear</hw>, <pos>n.</pos> <ety>[OF. <ets>riere</ets> behind,
backward, fr. L. <ets>retro</ets>. Cf. <er>Arrear</er>.]</ety>
<sn>1.</sn> <def>The back or hindmost part; that which is behind, or
last in order; -- opposed to <ant>front</ant>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Nipped with the lagging <qex>rear</qex> of winter's frost.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Specifically, the part of an army or fleet which
comes last, or is stationed behind the rest.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>When the fierce foe hung on our broken <qex>rear</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rear</ent><br/
<hw>Rear</hw>, <pos>a.</pos> <def>Being behind, or in the hindmost part;
hindmost; <as>as, the <ex>rear</ex> rank of a company</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Rear admiral</b></col>, <cd>an officer in the navy, next
in rank below a vice admiral and above a commodore. See
<er>Admiral</er>.</cd> -- <col><b>Rear front</b></col>
<fld>(Mil.)</fld>, <cd>the rear rank of a body of troops when faced
about and standing in that position.</cd> -- <col><b>Rear
guard</b></col> <fld>(Mil.)</fld>, <cd>the division of an army that
marches in the rear of the main body to protect it; -- used also
figuratively.</cd> -- <col><b>Rear line</b></col> <fld>(Mil.)</fld>,
<cd>the line in the rear of an army.</cd> -- <col><b>Rear rank</b></col>
<fld>(Mil.)</fld>, <cd>the rank or line of a body of troops which is in
the rear, or last in order.</cd> -- <col><b>Rear sight</b></col>
<fld>(Firearms)</fld>, <cd>the sight nearest the breech.</cd> --
<col><b>To bring up the rear</b></col>, <cd>to come last or
behind.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rear</ent><br/
<hw>Rear</hw> <pr>(r<emac/r)</pr>, <pos>v. t.</pos> <def>To place in the
rear; to secure the rear of.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rear</ent><br/
<hw>Rear</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Reared</conjf> <pr>(r<emac/rd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Rearing</conjf>.]</vmorph> <ety>[AS. <ets>r<aemac/ran</ets> to
raise, rear, elevate, for <ets>r<aemac/san</ets>, causative of
<ets>r<imac/san</ets> to rise. See <er>Rise</er>, and cf.
<er>Raise</er>.]</ety> <sn>1.</sn> <def>To raise; to lift up; to cause
to rise, become erect, etc.; to elevate; <as>as, to <ex>rear</ex> a
monolith</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In adoration at his feet I fell<br/
Submiss; he <qex>reared</qex> me.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>It <qex>reareth</qex> our hearts from vain thoughts.</q>
<rj><qau>Barrow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Mine [shall be] the first hand to <qex>rear</qex> her banner.</q>
<rj><qau>Ld. Lytton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To erect by building; to set up; to construct;
<as>as, to <ex>rear</ex> defenses or houses; to <ex>rear</ex> one
government on the ruins of another.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>One <qex>reared</qex> a font of stone.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To lift and take up.</def> <mark>[Obs. or
R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>And having her from Trompart lightly <qex>reared</qex>,<br/
Upon his courser set the lovely load.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To bring up to maturity, as young; to educate; to
instruct; to foster; <as>as, to <ex>rear</ex> offspring</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He wants a father to protect his youth,<br/
And <qex>rear</qex> him up to virtue.</q>
<rj><qau>Southern.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To breed and raise; <as>as, to <ex>rear</ex>
cattle</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To rouse; to stir up.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>And seeks the tusky boar to <qex>rear</qex>.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To lift; elevate; erect; raise; build; establish.
See the Note under <er>Raise</er>, 3 <sd>(c)</sd>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rear</ent><br/
<hw>Rear</hw>, <pos>v. i.</pos> <def>To rise up on the hind legs, as a
horse; to become erect.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Rearing bit</b></col>, <cd>a bit designed to prevent a
horse from lifting his head when rearing.</cd> <au>Knight.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reardoss</ent><br/
<ent>Reardorse</ent><br/
<mhw>{ <hw>Rear"dorse</hw> <pr>(-d<ocir/rs)</pr>, <hw>Rear"doss</hw>
<pr>(-d<ocr/s)</pr> }</mhw>, <pos>n.</pos> <def>A reredos.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rearer</ent><br/
<hw>Rear"er</hw> <pr>(r<emac/r"<etil/r)</pr>, <pos>n.</pos> <def>One
who, or that which, rears.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reargue</ent><br/
<ent>re-argue</ent><br/
<mhw><hw>Re*ar"gue</hw>, <hw>Re-ar"gue</hw></mhw>
<pr>(r<emac/*<aum/r"g<umac/)</pr>, <pos>v. t.</pos> <def>To argue anew
or again; <as>as, This politician will be forced into
<ex>re-arguing</ex> an old national campaign</as>. Usually used without
the hyphen.</def><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><ent>Reargument</ent><br/
<hw>Re*ar"gu*ment</hw> <pr>(-g<usl/*m<eit/nt)</pr>, <pos>n.</pos>
<def>An arguing over again, as of a motion made in court.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rear-horse</ent><br/
<hw>Rear"-horse`</hw> <pr>(r<emac/r"h<ocir/rs`)</pr>, <pos>n.</pos>
<ety>[So called because it <ets>rears</ets> up when disturbed.]</ety>
<fld>(Zool.)</fld> <def>A mantis.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rearly</ent><br/
<hw>Rear"ly</hw>, <pos>adv.</pos> <def>Early.</def> <mark>[Obs.]</mark>
<rj><au>Beau. & Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>rearm</ent><br/
<ent>re-arm</ent><br/
<mhw><hw>re-arm</hw>, <hw>re-arm</hw></mhw> <pos>v. t.</pos> <def>To arm
(a person, group, or country) again; <as>as, After the war, the defeated
country was not <ex>rearmed</ex> by the victors</as>. Usually used
without the hyphen.</def><br/
<syn><b>Syn. --</b> rearm.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>rearm</ent><br/
<ent>re-arm</ent><br/
<mhw><hw>re-arm</hw>, <hw>re-arm</hw></mhw> <pos>v. i.</pos> <def>To
become armed again; <as>as, after the war, the defeated country rapidly
<ex>rearmed</ex></as>. Usually used without the hyphen.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Rearmost</ent><br/
<hw>Rear"most`</hw> <pr>(-m<omac/st`)</pr>, <pos>a.</pos> <def>Farthest
in the rear; last.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rearmouse</ent><br/
<ent>Reremouse</ent><br/
<mhw>{ <hw>Rear"mouse`</hw>, <hw>Rere"mouse`</hw> <pr>(-mous`)</pr>
}</mhw>, <pos>n.</pos> <ety>[AS. <ets>hr<emac/rem<umac/s</ets>; probably
fr. <ets>hr<emac/ran</ets> to agitate, stir (akin to G.
<ets>r<uum/hren</ets>, Icel. <ets>hr<ae/ra</ets>) + <ets>m<umac/s</ets>
mouse.]</ety> <fld>(Zool.)</fld> <def>The leather-winged bat
(<spn>Vespertilio murinus</spn>).</def> <altsp>[Written also
<asp>reermouse</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rearrange</ent><br/
<ent>re-arrange</ent><br/
<mhw><hw>re`-ar*range"</hw>, <hw>Re`ar*range"</hw></mhw>
<pr>(r<emac/`<acr/r*r<amac/nj")</pr>, <pos>v. t.</pos> <def>To arrange
again; to put into a different order; to arrange in a different way;
<as>as, Please <ex>re-arrange</ex> these files in alphabetical
order</as>. Usually used without the hyphen.</def><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><ent>Rearrangement</ent><br/
<hw>Re`ar*range"ment</hw> <pr>(-m<eit/nt)</pr>, <pos>n.</pos> <def>The
act of rearranging, or the state of being rearranged.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rearward</ent><br/
<hw>Rear"ward`</hw> <pr>(r<emac/r"w<add/rd`-w<etil/rd)</pr>,
<pos>n.</pos> <ety>[<ets>Rear</ets> + <ets>ward</ets>.]</ety> <def>The
last troop; the rear of an army; a rear guard. Also used
figuratively.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rearward</ent><br/
<hw>Rear"ward</hw> <pr>(-w<etil/rd)</pr>, <pos>a. & adv.</pos> <def>At
or toward the rear.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reascend</ent><br/
<hw>Re`as*cend"</hw> <pr>(r<emac/`<acr/s*s<ecr/nd")</pr>, <pos>v.
i.</pos> <def>To rise, mount, or climb again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reascend</ent><br/
<hw>Re`as*cend"</hw>, <pos>v. t.</pos> <def>To ascend or mount again; to
reach by ascending again.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He mounts aloft, and <qex>reascends</qex> the skies.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reascension</ent><br/
<hw>Re`as*cen"sion</hw> <pr>(-s<ecr/n"sh<ucr/n)</pr>, <pos>n.</pos>
<def>The act of reascending; a remounting.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reascent</ent><br/
<hw>Re`as*cent"</hw> <pr>(-s<ecr/nt")</pr>, <pos>n.</pos> <def>A
returning ascent or ascension; acclivity.</def>
<rj><au>Cowper.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reason</ent><br/
<hw>Rea"son</hw> <pr>(r<emac/"z'n)</pr>, <pos>n.</pos> <ety>[OE.
<ets>resoun</ets>, F. <ets>raison</ets>, fr. L. <ets>ratio</ets> (akin
to Goth. <ets>ra<thorn/j<omac/</ets> number, account,
ga<ets>ra<thorn/jan</ets> to count, G. <ets>rede</ets> speech,
<ets>reden</ets> to speak), fr. <ets>reri</ets>, <ets>ratus</ets>, to
reckon, believe, think. Cf. <er>Arraign</er>, <er>Rate</er>,
<er>Ratio</er>, <er>Ration</er>.]</ety> <sn>1.</sn> <def>A thought or a
consideration offered in support of a determination or an opinion; a
just ground for a conclusion or an action; that which is offered or
accepted as an explanation; the efficient cause of an occurrence or a
phenomenon; a motive for an action or a determination; proof, more or
less decisive, for an opinion or a conclusion; principle; efficient
cause; final cause; ground of argument.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I'll give him <qex>reasons</qex> for it.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>reason</qex> of the motion of the balance in a wheel
watch is by the motion of the next wheel.</q> <rj><qau>Sir M.
Hale.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>This <qex>reason</qex> did the ancient fathers render, why the
church was called <ldquo/catholic.<rdquo/</q> <rj><qau>Bp.
Pearson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Virtue and vice are not arbitrary things; but there is a natural
and eternal <qex>reason</qex> for that goodness and virtue, and against
vice and wickedness.</q> <rj><qau>Tillotson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The faculty or capacity of the human mind by which
it is distinguished from the intelligence of the inferior animals; the
higher as distinguished from the lower cognitive faculties, sense,
imagination, and memory, and in contrast to the feelings and desires.
<xex>Reason</xex> comprises conception, judgment, reasoning, and the
intuitional faculty. Specifically, it is the intuitional faculty, or the
faculty of first truths, as distinguished from the understanding, which
is called the <xex>discursive</xex> or <xex>ratiocinative</xex>
faculty.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We have no other faculties of perceiving or knowing anything
divine or human, but by our five senses and our <qex>reason</qex>.</q>
<rj><qau>P. Browne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>In common and popular discourse, <qex>reason</qex> denotes that
power by which we distinguish truth from falsehood, and right from
wrong, and by which we are enabled to combine means for the attainment
of particular ends.</q> <rj><qau>Stewart.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Reason</qex> is used sometimes to express the whole of those
powers which elevate man above the brutes, and constitute his rational
nature, more especially, perhaps, his intellectual powers; sometimes to
express the power of deduction or argumentation.</q>
<rj><qau>Stewart.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>By the pure <qex>reason</qex> I mean the power by which we become
possessed of principles.</q> <rj><qau>Coleridge.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The sense perceives; the understanding, in its own peculiar
operation, conceives; the <qex>reason</qex>, or rationalized
understanding, comprehends.</q> <rj><qau>Coleridge.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1196 pr=vmg --></p>

<p><sn>3.</sn> <def>Due exercise of the reasoning faculty; accordance
with, or that which is accordant with and ratified by, the mind rightly
exercised; right intellectual judgment; clear and fair deductions from
true principles; that which is dictated or supported by the common sense
of mankind; right conduct; right; propriety; justice.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I was promised, on a time,<br/
To have <qex>reason</qex> for my rhyme.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>But law in a free nation hath been ever public <qex>reason</qex>;
the enacted <qex>reason</qex> of a parliament, which he denying to
enact, denies to govern us by that which ought to be our law;
interposing his own private <qex>reason</qex>, which to us is no
law.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The most probable way of bringing France to <qex>reason</qex>
would be by the making an attempt on the Spanish West Indies.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Math.)</fld> <def>Ratio; proportion.</def>
<mark>[Obs.]</mark> <rj><au>Barrow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<cs><p><col><b>By reason of</b></col>, <cd>by means of; on account of;
because of.</cd> <ldquo/Spain is thin sown of people, partly <xex>by
reason of</xex> the sterility of the soil.<rdquo/ <au>Bacon.</au> --
<col><b>In reason</b></col>, <col><b>In all reason</b></col>, <cd>in
justice; with rational ground; in a right view.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>When anything is proved by as good arguments as a thing of that
kind is capable of, we ought not, <qex>in reason</qex>, to doubt of its
existence.</q> <rj><qau>Tillotson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <col><b>It is reason</b></col>, <cd>it is reasonable; it is
right.</cd> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Yet <xex>it were</xex> great <qex>reason</qex>, that those that
have children should have greatest care of future times.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p></cs>

<p><syn><b>Syn.</b> -- Motive; argument; ground; consideration;
principle; sake; account; object; purpose; design. See <er>Motive</er>,
<er>Sense</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reason</ent><br/
<hw>Rea"son</hw> <pr>(r<emac/"z'n)</pr>, <pos>v. i.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Reasoned</conjf>
<pr>(r<emac/"z'nd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Reasoning</conjf>.]</vmorph> <ety>[Cf. F. <ets>raisonner</ets>.
See <er>Reason</er>, <pos>n.</pos>]</ety> <sn>1.</sn> <def>To exercise
the rational faculty; to deduce inferences from premises; to perform the
process of deduction or of induction; to ratiocinate; to reach
conclusions by a systematic comparison of facts.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence: To carry on a process of deduction or of
induction, in order to convince or to confute; to formulate and set
forth propositions and the inferences from them; to argue.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Stand still, that I may <qex>reason</qex> with you, before the
Lord, of all the righteous acts of the Lord.</q> <rj><qau>1 Sam. xii.
7.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To converse; to compare opinions.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reason</ent><br/
<hw>Rea"son</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To arrange and
present the reasons for or against; to examine or discuss by arguments;
to debate or discuss; <as>as, I <ex>reasoned</ex> the matter with my
friend</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>When they are clearly discovered, well digested, and well
<qex>reasoned</qex> in every part, there is beauty in such a theory.</q>
<rj><qau>T. Burnet.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To support with reasons, as a request.</def>
<mark>[R.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To persuade by reasoning or argument; <as>as, to
<ex>reason</ex> one into a belief; to <ex>reason</ex> one out of his
plan.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Men that will not be <qex>reasoned</qex> into their senses.</q>
<rj><qau>L'Estrange.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To overcome or conquer by adducing reasons; -- with
<xex>down</xex>; <as>as, to <ex>reason</ex> down a
passion</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To find by logical processes; to explain or justify
by reason or argument; -- usually with <ptcl>out</ptcl>; <as>as, to
<ex>reason</ex> out the causes of the librations of the
moon</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reasonable</ent><br/
<hw>Rea"son*a*ble</hw> <pr>(r<emac/"z'n*<adot/*b'l)</pr>, <pos>a.</pos>
<ety>[OE. <ets>resonable</ets>, F. <ets>raisonnable</ets>, fr. L.
<ets>rationabilis</ets>. See <er>Reason</er>, <pos>n.</pos>]</ety>
<sn>1.</sn> <def>Having the faculty of reason; endued with reason;
rational; <as>as, a <ex>reasonable</ex> being</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Governed by reason; being under the influence of
reason; thinking, speaking or acting rationally, or according to the
dictates of reason; agreeable to reason; just; rational; <as>as, the
measure must satisfy all <ex>reasonable</ex> men</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>By indubitable certainty, I mean that which doth not admit of any
<qex>reasonable</qex> cause of doubting.</q> <rj><qau>Bp.
Wilkins.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Men have no right to what is not <qex>reasonable</qex>.</q>
<rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Not excessive or immoderate; within due limits;
proper; <as>as, a <ex>reasonable</ex> demand, amount,
price</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Let . . . all things be thought upon<br/
That may, with <qex>reasonable</qex> swiftness, add<br/
More feathers to our wings.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Rational; just; honest; equitable; fair;
suitable; moderate; tolerable. See <er>Rational</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reasonable</ent><br/
<hw>Rea"son*a*ble</hw>, <pos>adv.</pos> <def>Reasonably;
tolerably.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I have a <qex>reasonable</qex> good ear in music.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reasonableness</ent><br/
<hw>Rea"son*a*ble*ness</hw>, <pos>n.</pos> <def>Quality of being
reasonable.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reasonably</ent><br/
<hw>Rea"son*a*bly</hw>, <pos>adv.</pos> <sn>1.</sn> <def>In a reasonable
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Moderately; tolerably.</def>
<ldquo/<xex>Reasonably</xex> perfect in the language.<rdquo/
<rj><au>Holder.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reasoner</ent><br/
<hw>Rea"son*er</hw> <pr>(r<emac/"z'n*<etil/r)</pr>, <pos>n.</pos>
<def>One who reasons or argues; <as>as, a fair <ex>reasoner</ex>; a
close <ex>reasoner</ex>; a logical <ex>reasoner</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reasoning</ent><br/
<hw>Rea"son*ing</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act or process
of adducing a reason or reasons; manner of presenting one's
reasons.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is offered in argument; proofs or reasons
when arranged and developed; course of argument.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His <qex>reasoning</qex> was sufficiently profound.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Argumentation; argument.</syn> <usage> --
<er>Reasoning</er>, <er>Argumentation</er>. Few words are more
interchanged than these; and yet, technically, there is a difference
between them. <xex>Reasoning</xex> is the broader term, including both
deduction and induction. <xex>Argumentation</xex> denotes simply the
former, and descends from the whole to some included part; while
<xex>reasoning</xex> embraces also the latter, and ascends from the
parts to a whole. See <er>Induction</er>. <xex>Reasoning</xex> is
occupied with ideas and their relations; <xex>argumentation</xex> has to
do with the forms of logic. A thesis is set down: you attack, I defend
it; you insist, I reply; you deny, I prove; you distinguish, I destroy
your distinctions; my replies balance or overturn your objections. Such
is <xex>argumentation</xex>. It supposes that there are two sides, and
that both agree to the same rules. <xex>Reasoning</xex>, on the other
hand, is often a natural process, by which we form, from the general
analogy of nature, or special presumptions in the case, conclusions
which have greater or less degrees of force, and which may be
strengthened or weakened by subsequent experience.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reasonist</ent><br/
<hw>Rea"son*ist</hw>, <pos>n.</pos> <def>A rationalist.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Such persons are now commonly called
<ldquo/<qex>reasonists</qex><rdquo/ and <ldquo/rationalists,<rdquo/ to
distinguish them from true reasoners and rational inquirers.</q>
<rj><qau>Waterland.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reasonless</ent><br/
<hw>Rea"son*less</hw>, <pos>a.</pos> <sn>1.</sn> <def>Destitute of
reason; <as>as, a <ex>reasonless</ex> man or mind</as>.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Void of reason; not warranted or supported by
reason; unreasonable.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This proffer is absurd and <qex>reasonless</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>reassail</ent><br/
<ent>re-assail</ent><br/
<mhw><hw>re`as*sail"</hw>, <hw>re`-as*sail"</hw></mhw> <pos>v. t.</pos>
<def>To assail again; <as>as, Her old fears <ex>reassailed</ex>
her</as>. Usually used without the hyphen.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Reassemblage</ent><br/
<hw>Re`as*sem"blage</hw> <pr>(r<emac/`<acr/s*s<ecr/m"bl<asl/j)</pr>,
<pos>n.</pos> <def>Assemblage a second time or again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reassemble</ent><br/
<ent>re-assemble</ent><br/
<mhw><hw>Re`as*sem"ble</hw>, <hw>Re`-as*sem"ble</hw></mhw>
<pr>(r<emac/`<acr/s*s<ecr/m"b'l)</pr>, <pos>v. t. & i.</pos> <def>To
assemble again; -- usually after having taking something apart. Usually
used without the hyphen.</def><br/
[<source>1913 Webster</source>  <source>WordNet 1.5</source>]</p>

<p><ent>Reassert</ent><br/
<hw>Re`as*sert"</hw> <pr>(r<emac/`<acr/s*s<etil/rt")</pr>, <pos>v.
t.</pos> <def>To assert again or anew; to maintain after an omission to
do so.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Let us hope . . . we may have a body of authors who will
<qex>reassert</qex> our claim to respectability in literature.</q>
<rj><qau>Walsh.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reassertion</ent><br/
<hw>Re`as*ser"tion</hw> <pr>(r<emac/`<acr/s*s<etil/r"sh<ucr/n)</pr>,
<pos>n.</pos> <def>A second or renewed assertion of the same
thing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>re-assess</ent><br/
<ent>re-assess</ent><br/
<mhw><hw>re`as*sess"</hw>, <hw>re`-as*sess"</hw></mhw> <pos>v. t.</pos>
<def>To revise or renew one's assessment of; <as>as, we need to
<ex>reassess</ex> our position to include the new information</as>.
Usually used without the hyphen.</def><br/
<syn><b>Syn. --</b> re-evaluate, reevaluate.</syn><br/
[<source>WordNet 1.5</source> +<source>PJC</source>]</p>

<p><ent>Reassessment</ent><br/
<hw>Re`as*sess"ment</hw> <pr>(r<emac/`<acr/s*s<ecr/s"m<eit/nt</pr>,
<pos>n.</pos> <def>A renewed or second assessment.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reassign</ent><br/
<hw>Re`as*sign"</hw> <pr>(r<emac/`<acr/s*s<imac/n")</pr>, <pos>v.
t.</pos> <def>To assign back or again; to transfer back what has been
assigned.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reassignment</ent><br/
<hw>Re`as*sign"ment</hw> <pr>(r<emac/`<acr/s*s<imac/n"m<eit/nt)</pr>,
<pos>n.</pos> <def>The act of reassigning.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reassimilate</ent><br/
<hw>Re`as*sim"i*late</hw>
<pr>(r<emac/`<acr/s*s<icr/m"<icr/*l<amac/t)</pr>, <pos>v. t. & i.</pos>
<def>To assimilate again.</def> --
<wordforms><wf>Re`as*sim`i*la"tion</wf>
<pr>(r<emac/`<acr/s*s<icr/m"<icr/*l<amac/"sh<ucr/n)</pr>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reassociate</ent><br/
<hw>Re`as*so"ci*ate</hw>
<pr>(r<emac/`<acr/s*s<omac/"sh<icr/*<amac/t)</pr>, <pos>v. t. & i.</pos>
<def>To associate again; to bring again into close relations.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reassume</ent><br/
<hw>Re`as*sume"</hw> <pr>(r<emac/`<acr/s*s<umac/m")</pr>, <pos>v.
t.</pos> <def>To assume again or anew; to resume.</def> --
<wordforms><wf>Re`as*sump"tion</wf>
<pr>(r<emac/`<acr/s*s<ucr/mp"sh<ucr/n)</pr>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reassurance</ent><br/
<hw>Re`as*sur"ance</hw> <pr>(r<emac/`<adot/*sh<udd/r"<ait/ns)</pr>,
<pos>n.</pos> <sn>1.</sn> <def>Assurance or confirmation renewed or
repeated.</def> <rj><au>Prynne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>Same as
<er>Reinsurance</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reassure</ent><br/
<hw>Re`as*sure"</hw> <pr>(r<emac/`<adot/*sh<udd/r")</pr>, <pos>v.
t.</pos> <sn>1.</sn> <def>To assure anew; to restore confidence to; to
free from fear or terror.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They rose with fear, . . . <br/
Till dauntless Pallas <qex>reassured</qex> the rest.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To reinsure.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reassurer</ent><br/
<hw>Re`as*sur"er</hw> <pr>(r<emac/`<adot/*sh<udd/r"<etil/r)</pr>,
<pos>n.</pos> <def>One who reassures.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reasty</ent><br/
<hw>Reas"ty</hw> <pr>(r<emac/s"t<ycr/)</pr>, <pos>a.</pos> <ety>[Etymol.
uncertain.]</ety> <def>Rusty and rancid; -- applied to salt meat.</def>
<mark>[Obs. or Prov. Eng.]</mark> <au>Tusser.</au> --
<wordforms><wf>Reas"ti*ness</wf> <pr>(r<emac/s"t<icr/*n<ecr/s)</pr>,
<pos>n.</pos> <mark>[Obs. or Prov. Eng.]</mark></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reata</ent><br/
\'d8<hw>Re*a"ta</hw> <pr>(r<asl/*<aum/"t<adot/)</pr>, <pos>n.</pos>
<ety>[Sp.]</ety> <def>A lariat.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reattach</ent><br/
<hw>Re`at*tach"</hw> <pr>(r<emac/`<acr/t*t<acr/ch")</pr>, <pos>v.
t.</pos> <def>To attach again.</def> <note>The object reattached may
have been an integral part which had never been "attached" (trans),
e.g., to reattach a severed finger.</note><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Reattachment</ent><br/
<hw>Re`at*tach"ment</hw> <pr>(r<emac/`<acr/t*t<acr/ch"m<eit/nt)</pr>,
<pos>n.</pos> <def>The act of reattaching; a second
attachment.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reattain</ent><br/
<hw>Re`at*tain"</hw> <pr>(r<emac/`<acr/t*t<amac/n")</pr>, <pos>v.
t.</pos> <def>To attain again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reattainment</ent><br/
<hw>Re`at*tain"ment</hw> <pr>(r<emac/`<acr/t*t<amac/n"m<eit/nt)</pr>,
<pos>n.</pos> <def>The act of reattaining.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reattempt</ent><br/
<hw>Re`at*tempt"</hw> <pr>(r<emac/`<acr/t*t<ecr/mt"; 215)</pr>, <pos>v.
t.</pos> <def>To attempt again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>reattribute</ent><br/
<ent>re-attribute</ent><br/
<mhw><hw>reattribute</hw>, <hw>re-attribute</hw></mhw> <pos>v. t.</pos>
<def>To attribute to another source or cause. Usually used without the
hyphen.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Reaume</ent><br/
<hw>Re"aume</hw> <pr>(r<emac/"<add/m)</pr>, <pos>n.</pos>
<def>Realm.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reaumur</ent><br/
<hw>R<eacute/`au`mur"</hw> <pr>(r<asl/`<omac/`m<usdot/r")</pr>,
<pos>a.</pos> <def>Of or pertaining to <person>Ren<eacute/ Antoine
Ferchault de <etsep>R<eacute/aumur</etsep></person>; conformed to the
scale adopted by <person>R<eacute/aumur</person> in graduating the
thermometer he invented.</def> -- <def2><pos>n.</pos> <def>A
R<eacute/aumur thermometer or scale.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The <xex>R<eacute/aumur thermometer</xex> is so
graduated that 0<deg/ marks the freezing point and 80<deg/ the boiling
point of water. Frequently indicated by R. Cf. <er>Centigrade</er>, and
<er>Fahrenheit</er>. See <xex>Illust.</xex> of
<er>Thermometer</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reave</ent><br/
<hw>Reave</hw> <pr>(r<emac/v)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Reaved</conjf> <pr>(r<emac/vd)</pr>,
<conjf>Reft</conjf> <pr>(r<ecr/ft)</pr>, or <conjf>Raft</conjf>
<pr>(r<adot/ft)</pr> (<mark>obs.</mark>); <pos>p. pr. & vb. n.</pos>
<conjf>Reaving</conjf>.]</vmorph> <ety>[AS. <ets>re<aacute/fian</ets>,
from <ets>re<aacute/f</ets> spoil, plunder, clothing,
<ets>re<oacute/fan</ets> to break (cf. <ets>bire<oacute/fan</ets> to
deprive of); akin to G. <ets>rauben</ets> to rob, Icel. <ets>raufa</ets>
to rob, <ets>rj<umac/fa</ets> to break, violate, Goth.
<ets>bir<aacute/ub<omac/n</ets> to despoil, L. <ets>rumpere</ets> to
break; cf. Skr. <ets>lup</ets> to break. <root/114. Cf.
<er>Bereave</er>, <er>Rob</er>, <pos>v. t.</pos>, <er>Robe</er>,
<er>Rove</er>, <pos>v. i.</pos>, <er>Rupture</er>.]</ety> <def>To take
away by violence or by stealth; to snatch away; to rob; to despoil; to
bereave. <mark>[Archaic]</mark>.</def> <ldquo/To <xex>reave</xex> his
life.<rdquo/ <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He golden apples <qex>raft</qex> of the dragon.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>If the wooers <qex>reave</qex><br/
By privy stratagem my life at home.</q> <rj><qau>Chapman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>reave</qex> the orphan of his patrimony.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The heathen caught and <qex>reft</qex> him of his tongue.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reaver</ent><br/
<hw>Reav"er</hw> <pr>(r<emac/v"<etil/r)</pr>, <pos>n.</pos> <def>One who
reaves.</def> <mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reawake</ent><br/
<hw>Re`a*wake"</hw> <pr>(r<emac/`<adot/*w<amac/k")</pr>, <pos>v.
i.</pos> <def>To awake again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>reawaken</ent><br/
<ent>re-awaken</ent><br/
<mhw><hw>reawaken</hw>, <hw>re-awaken</hw></mhw> <pos>v. t. & i.</pos>
<def>To awaken once again. Usually used without the hyphen.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Rebanish</ent><br/
<hw>Re*ban"ish</hw> <pr>(r<emac/*b<acr/n"<icr/sh)</pr>, <pos>v. t.</pos>
<def>To banish again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rebaptism</ent><br/
<hw>Re*bap"tism</hw> <pr>(r<emac/*b<acr/p"t<icr/z'm)</pr>, <pos>n.</pos>
<def>A second baptism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rebaptization</ent><br/
<hw>Re*bap`ti*za"tion</hw>
<pr>(r<emac/*b<acr/p`t<icr/*z<amac/"sh<ucr/n)</pr>, <pos>n.</pos>
<ety>[Cf. F. <ets>rebaptisation</ets>.]</ety> <def>A second
baptism.</def> <mark>[Obs.]</mark> <rj><au>Hooker.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rebaptize</ent><br/
<hw>Re`bap*tize"</hw> <pr>(r<emac/`b<acr/p*t<imac/z")</pr>, <pos>v.
t.</pos> <ety>[Pref. <ets>re-</ets> + <ets>baptize</ets>: cf. F.
<ets>rebaptiser</ets>, L. <ets>rebaptizare</ets>.]</ety> <def>To baptize
again or a second time.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rebaptizer</ent><br/
<hw>Re`bap*tiz"er</hw> <pr>(r<emac/`b<acr/p*t<imac/z"<etil/r)</pr>,
<pos>n.</pos> <def>One who rebaptizes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rebarbarize</ent><br/
<hw>Re*bar"ba*rize</hw> <pr>(r<emac/*b<aum/r"b<adot/*r<imac/z)</pr>,
<pos>v. t.</pos> <def>To reduce again to barbarism.</def> --
<wordforms><wf>Re*bar`ba*ri*za"tion</wf>
<pr>(r<emac/*b<aum/r"b<adot/*r<icr/*z<amac/"sh<ucr/n)</pr>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><q>Germany . . . <qex>rebarbarized</qex> by polemical theology and
religious wars.</q> <rj><qau>Sir W. Hamilton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rebate</ent><br/
<hw>Re*bate"</hw> <pr>(r<esl/*b<amac/t")</pr>, <pos>v. t.</pos> <ety>[F.
<ets>rebattre</ets> to beat again; pref. <ets>re-</ets> re- +
<ets>battre</ets> to beat, L. <ets>batuere</ets> to beat, strike. See
<er>Abate</er>.]</ety> <sn>1.</sn> <def>To beat to obtuseness; to
deprive of keenness; to blunt; to turn back the point of, as a lance
used for exercise.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>But doth <qex>rebate</qex> and blunt his natural edge.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To deduct from; to make a discount from, as interest
due, or customs duties.</def> <rj><au>Blount.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To return a portion of a sum paid, as a method of
discounting of prices.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Rebated cross</b></col>, <cd>a cross which has the
extremities of the arms bent back at right angles, as in the
fylfot.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rebate</ent><br/
<hw>Re*bate"</hw>, <pos>v. i.</pos> <def>To abate; to withdraw.</def>
<mark>[Obs.]</mark> <rj><au>Foxe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rebate</ent><br/
<hw>Re*bate"</hw>, <pos>n.</pos> <sn>1.</sn> <def>Diminution.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Com.)</fld> <def>Deduction; abatement; <as>as, a
<ex>rebate</ex> of interest for immediate payment; a <ex>rebate</ex> of
importation duties.</as></def> <rj><au>Bouvier.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A portion of a sum paid, returned to the purchaser,
as a method of discounting. The rebate is sometimes returned by the
manufacturer, after the full price is paid to the retailer by the
purchaser.</def><br/
[<source>PJC</source>]</p>

<p><ent>Rebate</ent><br/
<hw>Re*bate"</hw>, <pos>n.</pos> <ety>[See <er>Rabbet</er>.]</ety>
<sn>1.</sn> <fld>(Arch.)</fld> <def>A rectangular longitudinal recess or
groove, cut in the corner or edge of any body; a rabbet. See
<er>Rabbet</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A piece of wood hafted into a long stick, and
serving to beat out mortar.</def> <rj><au>Elmes.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>An iron tool sharpened something like a chisel, and
used for dressing and polishing wood.</def> <rj><au>Elmes.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <ety>[Perhaps a different word.]</ety> <def>A kind of
hard freestone used in making pavements.</def> <mark>[R.]</mark>
<rj><au>Elmes.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rebate</ent><br/
<hw>Re*bate"</hw>, <pos>v. t.</pos> <def>To cut a rebate in. See
<er>Rabbet</er>, <pos>v.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rebatement</ent><br/
<hw>Re*bate"ment</hw> <pr>(r<esl/*b<amac/t"m<eit/nt)</pr>, <pos>n.</pos>
<ety>[Cf. OF. <ets>rabatement</ets>, fr. <ets>rabatre</ets> to diminish,
F. <ets>rabattre</ets>.]</ety> <def>Same as 3d <er>Rebate</er>,
<pos>v.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rebato</ent><br/
<hw>Re*ba"to</hw> <pr>(r<esl/*b<amac/"t<osl/)</pr>, <pos>n.</pos>
<def>Same as <er>Rabato</er>.</def> <rj><au>Burton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rebec</ent><br/
<hw>Re"bec</hw> <pr>(r<emac/"b<ecr/k)</pr>, <pos>n.</pos> <ety>[F., fr.
It. <ets>ribeca</ets>, <ets>ribeba</ets>, fr. Ar. <ets>rab<amac/b</ets>
a musical instrument of a round form.]</ety> <sn>1.</sn>
<fld>(Mus.)</fld> <def>An instrument formerly used which somewhat
resembled the violin, having three strings, and being played with a
bow.</def> <altsp>[Written also <asp>rebeck</asp>.]</altsp>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He turn'd his <qex>rebec</qex> to a mournful note.</q>
<rj><qau>Drayton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A contemptuous term applied to an old woman.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rebel</ent><br/
<hw>Reb"el</hw> <pr>(r<ecr/b"<ecr/l)</pr>, <pos>a.</pos> <ety>[F.
<ets>rebelle</ets>, fr. L. <ets>rebellis</ets>. See <er>Rebel</er>,
<pos>v. i.</pos>]</ety> <def>Pertaining to rebels or rebellion; acting
in revolt; rebellious; <as>as, <ex>rebel</ex> troops</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Whoso be <qex>rebel</qex> to my judgment.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Convict by flight, and <qex>rebel</qex> to all law.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rebel</ent><br/
<hw>Reb"el</hw>, <pos>n.</pos> <ety>[F. <ets>rebelle</ets>.]</ety>
<def>One who rebels.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Revolter; insurgent.</syn> <usage> --
<er>Rebel</er>, <er>Insurgent</er>. <xex>Insurgent</xex> marks an early,
and <xex>rebel</xex> a more advanced, stage of opposition to government.
The former rises up against his rulers, the latter makes war upon
them.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rebel</ent><br/
<hw>Re*bel"</hw> <pr>(r<esl/*b<ecr/l")</pr>, <pos>v. i.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Rebelled</conjf>
<pr>(r<esl/*b<ecr/ld)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Rebelling</conjf>.]</vmorph> <ety>[F. <ets>rebeller</ets>, fr. L.
<ets>rebellare</ets> to make war again; pref. <ets>re-</ets> again +
<ets>bellare</ets> to make war, fr. <ets>bellum</ets> war. See
<er>Bellicose</er>, and cf. <er>Revel</er> to carouse.]</ety>
<sn>1.</sn> <def>To renounce, and resist by force, the authority of the
ruler or government to which one owes obedience. See
<er>Rebellion</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The murmur and the churls' <qex>rebelling</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Ye have builded you an altar, that ye might <qex>rebel</qex> this
day against the Lord.</q> <rj><qau>Josh. xxii. 16.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To be disobedient to authority; to assume a hostile
or insubordinate attitude; to revolt.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>How could my hand <qex>rebel</qex> against my heart?<br/
How could your heart <qex>rebel</qex> against your reason?</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rebeldom</ent><br/
<hw>Reb"el*dom</hw> <pr>(r<ecr/b"<ecr/l*d<ucr/m)</pr>, <pos>n.</pos>
<def>A region infested by rebels; rebels, considered collectively; also,
conduct or quality characteristic of rebels.</def>
<rj><au>Thackeray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rebeller</ent><br/
<hw>Re*bel"ler</hw> <pr>(r<esl/*b<ecr/l"l<etil/r)</pr>, <pos>n.</pos>
<def>One who rebels; a rebel.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rebellion</ent><br/
<hw>Re*bel"lion</hw> <pr>(r<esl/*b<ecr/l"y<ucr/n)</pr>, <pos>n.</pos>
<ety>[F. <ets>r<eacute/bellion</ets>, L. <ets>rebellio</ets>. See
<er>Rebel</er>, <pos>v. i.</pos> Among the Romans rebellion was
originally a revolt or open resistance to their government by nations
that had been subdued in war. It was a renewed war.]</ety> <sn>1.</sn>
<def>The act of rebelling; open and avowed renunciation of the authority
of the government to which one owes obedience, and resistance to its
officers and laws, either by levying war, or by aiding others to do so;
an organized uprising of subjects for the purpose of coercing or
overthrowing their lawful ruler or government by force; revolt;
insurrection.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>No sooner is the standard of <qex>rebellion</qex> displayed than
men of desperate principles resort to it.</q>
<rj><qau>Ames.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Open resistance to, or defiance of, lawful
authority.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Commission of rebellion</b></col> <fld>(Eng. Law)</fld>,
<cd>a process of contempt issued on the nonappearance of a defendant, --
now abolished.</cd> <au>Wharton.</au> <au>Burrill.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Insurrection; sedition; revolt; mutiny;
resistance; contumacy. See <er>Insurrection</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rebellious</ent><br/
<hw>Re*bel"lious</hw> <pr>(r<esl/*b<ecr/l"y<ucr/s)</pr>, <pos>a.</pos>
<def>Engaged in rebellion; disposed to rebel; of the nature of rebels or
of rebellion; resisting government or lawful authority by force.</def>
<ldquo/Thy <xex>rebellious</xex> crew.<rdquo/ <ldquo/Proud
<xex>rebellious</xex> arms.<rdquo/ <au>Milton.</au> --
<wordforms><wf>Re*bel"lious*ly</wf>, <pos>adv.</pos> --
<wf>Re*bel"lious*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rebellow</ent><br/
<hw>Re*bel"low</hw> <pr>(r<emac/*b<ecr/l"l<osl/)</pr>, <pos>v. i.</pos>
<def>To bellow again; to repeat or echo a bellow.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The cave <qex>rebellowed</qex>, and the temple shook.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>rebind</ent><br/
<ent>re-bind</ent><br/
<mhw><hw>rebind</hw>, <hw>re-bind</hw></mhw> <pos>v. t.</pos> <def>To
provide with a new binding, as of books. Usually used without the
hyphen.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Rebiting</ent><br/
<hw>Re*bit"ing</hw> <pr>(r<emac/*b<imac/t"<icr/ng)</pr>, <pos>n.</pos>
<fld>(Etching)</fld> <def>The act or process of deepening worn lines in
an etched plate by submitting it again to the action of acid.</def>
<rj><au>Fairholt.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rebloom</ent><br/
<hw>Re*bloom"</hw> <pr>(r<emac/*bl<oomac/m")</pr>, <pos>v. i.</pos>
<def>To bloom again.</def> <rj><au>Crabbe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reblossom</ent><br/
<hw>Re*blos"som</hw> <pr>(r<emac/*bl<ocr/s"s<ucr/m)</pr>, <pos>v.
i.</pos> <def>To blossom again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reboant</ent><br/
<hw>Re*bo"ant</hw> <pr>(r<esl/*b<omac/"<ait/nt)</pr>, <pos>a.</pos>
<ety>[L. <ets>reboans</ets>, p. pr. of <ets>reboare</ets>; pref.
<ets>re-</ets> re- + <ets>boare</ets> to cry aloud.]</ety>
<def>Rebellowing; resounding loudly.</def> <mark>[R.]</mark>
<rj><au>Mrs. Browning.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reboation</ent><br/
<hw>Re`bo*a"tion</hw> <pr>(r<emac/`b<osl/*<amac/"sh<ucr/n)</pr>,
<pos>n.</pos> <def>Repetition of a bellow.</def> <mark>[R.]</mark>
<rj><au>Bp. Patrick.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reboil</ent><br/
<hw>Re*boil"</hw> <pr>(r<emac/*boil")</pr>, <pos>v. t. & i.</pos>
<ety>[Pref. <ets>re-</ets> + <ets>boil</ets>: cf. F.
<ets>rebouillir</ets>.]</ety> <sn>1.</sn> <def>To boil, or to cause to
boil, again.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Fig.: To make or to become hot.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Some of his companions thereat <qex>reboyleth</qex>.</q>
<rj><qau>Sir T. Elyot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reborn</ent><br/
<hw>Re*born"</hw> <pr>(r<emac/*b<ocir/rn")</pr>, <pos>p. p.</pos>
<def>Born again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rebound</ent><br/
<hw>Re*bound"</hw> <pr>(r<esl/*bound")</pr>, <pos>v. i.</pos>
<ety>[Pref. <ets>re-</ets> + <ets>bound</ets>: cf. F.
<ets>rebondir</ets>.]</ety> <sn>1.</sn> <def>To spring back; to start
back; to be sent back or reverberated by elastic force on collision with
another body; <as>as, a <ex>rebounding</ex> echo</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Bodies which are absolutely hard, or so soft as to be void of
elasticity, will not <qex>rebound</qex> from one another.</q>
<rj><qau>Sir I. Newton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To give back an echo.</def> <mark>[R.]</mark>
<rj><au>T. Warton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To bound again or repeatedly, as a horse.</def>
<rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>to recover, as from sickness, psychological shock,
or disappointment.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Rebounding lock</b></col> <fld>(Firearms)</fld>, <cd>one
in which the hammer rebounds to half cock after striking the cap or
primer.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rebound</ent><br/
<hw>Re*bound"</hw>, <pos>v. t.</pos> <def>To send back; to
reverberate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Silenus sung; the vales his voice <qex>rebound</qex>.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rebound</ent><br/
<hw>Re*bound"</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act of
rebounding; resilience.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Flew . . . back, as from a rock, with swift
<qex>rebound</qex>.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>recovery, as from sickness, psychological shock, or
disappointment.</def><br/
[<source>PJC</source>]</p>

<p><ent>Rebozo</ent><br/
\'d8<hw>Re*bo"zo</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sp.
<ets>rebozo</ets>.]</ety> <def>A kind of mantilla worn by women over the
head and shoulders, and sometimes over part of the face.</def>
<mark>[Mexico & Sp. Amer.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Rebrace</ent><br/
<hw>Re*brace"</hw> <pr>(r<emac/*br<amac/s")</pr>, <pos>v. t.</pos>
<def>To brace again.</def> <rj><au>Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rebreathe</ent><br/
<hw>Re*breathe"</hw> <pr>(r<emac/*br<emac/th")</pr>, <pos>v. t.</pos>
<def>To breathe again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rebucous</ent><br/
<hw>Re*bu"cous</hw> <pr>(r<esl/*b<umac/"k<ucr/s)</pr>, <pos>a.</pos>
<def>Rebuking.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>She gave unto him many <qex>rebucous</qex> words.</q>
<rj><qau>Fabyan.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rebuff</ent><br/
<hw>Re*buff"</hw> <pr>(r<esl/*b<ucr/f")</pr>, <pos>n.</pos> <ety>[It.
<ets>ribuffo</ets>, akin to <ets>ribuffare</ets> to repulse; pref.
<ets>ri-</ets> (L. <ets>re-</ets>) + <ets>buffo</ets> puff. Cf.
<er>Buff</er> to strike, <er>Buffet</er> a blow.]</ety> <sn>1.</sn>
<def>Repercussion, or beating back; a quick and sudden
resistance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The strong <qex>rebuff</qex> of some tumultuous cloud.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Sudden check; unexpected repulse; defeat; refusal;
repellence; rejection of solicitation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rebuff</ent><br/
<hw>Re*buff"</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Rebuffed</conjf> <pr>(r<esl/*b<ucr/ft")</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Rebuffing</conjf>.]</vmorph> <def>To beat back; to offer
sudden resistance to; to check; to repel or repulse violently, harshly,
or uncourteously.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rebuild</ent><br/
<ent>re-build</ent><br/
<mhw><hw>Re*build"</hw>, <hw>Re-build"</hw></mhw>
<pr>(r<emac/*b<icr/ld")</pr>, <pos>v. t.</pos> <def>To build again, as
something which has been demolished; to construct anew; <as>as, to
<ex>rebuild</ex> a house, a wall, a wharf, or a city</as>. Usually used
without the hyphen.</def><br/
<syn><b>Syn. --</b> build anew, build again, reconstruct,
reerect.</syn><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><ent>Rebuilder</ent><br/
<hw>Re*build"er</hw> <pr>(r<emac/*b<icr/ld"<etil/r)</pr>, <pos>n.</pos>
<def>One who rebuilds.</def> <rj><au>Bp. Bull.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rebukable</ent><br/
<hw>Re*buk"a*ble</hw> <pr>(r<esl/*b<umac/k"<adot/*b'l)</pr>,
<pos>a.</pos> <def>Worthy of rebuke or reprehension;
reprehensible.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rebuke</ent><br/
<hw>Re*buke"</hw> <pr>(r<esl/*b<umac/k")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Rebuked</conjf>
<pr>(r<esl/*b<umac/kt")</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Rebuking</conjf>.]</vmorph> <ety>[OF. <ets>rebouquier</ets> to
dull, blunt, F. <ets>reboucher</ets>; perhaps fr. pref. <ets>re-</ets>
re- + <ets>bouche</ets> mouth, OF. also <ets>bouque</ets>, L.
<ets>bucca</ets> cheek; if so, the original sense was, to stop the mouth
of; hence, to stop, obstruct.]</ety> <def>To check, silence, or put
down, with reproof; to restrain by expression of disapprobation; to
reprehend sharply and summarily; to chide; to reprove; to
admonish.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The proud he tamed, the penitent he cheered,<br/
Nor to <qex>rebuke</qex> the rich offender feared.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To reprove; chide; check; chasten; restrain;
silence. See <er>Reprove</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1197 pr=vmg --></p>

<p><ent>Rebuke</ent><br/
<hw>Re*buke"</hw> <pr>(r<esl/*b<umac/k")</pr>, <pos>n.</pos> <sn>1.</sn>
<def>A direct and pointed reproof; a reprimand; also, chastisement;
punishment.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>For thy sake I have suffered <qex>rebuke</qex>.</q> <rj><qau>Jer.
xv. 15.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Why bear you these <qex>rebukes</qex> and answer not?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Check; rebuff.</def> <mark>[Obs.]</mark>
<rj><au>L'Estrange.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To be without rebuke</b></col>, <cd>to live without
giving cause of reproof or censure; to be blameless.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rebukeful</ent><br/
<hw>Re*buke"ful</hw> <pr>(r<esl/*b<umac/k"f<usdot/l)</pr>, <pos>a.</pos>
<def>Containing rebuke; of the nature of rebuke.</def>
<mark>[Obs.]</mark> -- <wordforms><wf>Re*buke"ful*ly</wf>,
<pos>adv.</pos> <mark>[Obs.]</mark></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rebuker</ent><br/
<hw>Re*buk"er</hw> <pr>(r<esl/*b<umac/k"<etil/r)</pr>, <pos>n.</pos>
<def>One who rebukes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rebukingly</ent><br/
<hw>Re*buk"ing*ly</hw>, <pos>adv.</pos> <def>By way of rebuke.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rebullition</ent><br/
<hw>Re`bul*li"tion</hw> <pr>(r<emac/`b<ucr/l*l<icr/sh"<ucr/n)</pr>,
<pos>n.</pos> <def>The act of boiling up or effervescing.</def>
<mark>[R.]</mark> <rj><au>Sir H. Wotton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rebury</ent><br/
<hw>Re*bur"y</hw> <pr>(r<emac/*b<ecr/r"r<ycr/)</pr>, <pos>v. t.</pos>
<def>To bury again.</def> <rj><au>Ashmole.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rebus</ent><br/
<hw>Re"bus</hw> <pr>(r<emac/"b<ucr/s)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Rebuses</plw>
<pr>(r<emac/"b<ucr/s*<ecr/z)</pr>.</plu> <ety>[L. <ets>rebus</ets> by
things, abl. pl. of <ets>res</ets> a thing: cf. F.
<ets>r<eacute/bus</ets>. Cf. 3d <er>Real</er>.]</ety> <sn>1.</sn> <def>A
mode of expressing words and phrases by pictures of objects whose names
resemble those words, or the syllables of which they are composed;
enigmatical representation of words by figures; hence, a peculiar form
of riddle made up of such representations.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ A gallant, in love with a woman named <xex>Rose
Hill</xex>, had, embroidered on his gown, a rose, a hill, an eye, a
loaf, and a well, signifying, <xex>Rose Hill I love
well</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Her.)</fld> <def>A pictorial suggestion on a coat
of arms of the name of the person to whom it belongs. See <cref>Canting
arms</cref>, under <er>Canting</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rebus</ent><br/
<hw>Re"bus</hw>, <pos>v. t.</pos> <def>To mark or indicate by a
rebus.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He [John Morton] had a fair library <qex>rebused</qex> with More
in text and Tun under it.</q> <rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rebut</ent><br/
<hw>Re*but"</hw> <pr>(r<esl/*b<ucr/t")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Rebutted</conjf>; <pos>p. pr. &
vb. n.</pos> <conjf>Rebutting</conjf>.]</vmorph> <ety>[OF.
<ets>rebouter</ets> to repulse, drive back; pref. <ets>re-</ets> +
<ets>bouter</ets> to push, thrust. See 1st <er>Butt</er>,
<er>Boutade</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>To drive or beat back; to repulse.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Who him, rencount'ring fierce, as hawk in flight,<br/
Perforce <qex>rebutted</qex> back.</q> <rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>To contradict, meet, or oppose by
argument, plea, or countervailing proof.</def>
<rj><au>Abbott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rebut</ent><br/
<hw>Re*but"</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To retire; to
recoil.</def> <mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>To make, or put in, an answer, as
to a plaintiff's surrejoinder.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The plaintiff may answer the rejoinder by a surrejoinder; on which
the defendant may <qex>rebut</qex>.</q>
<rj><qau>Blackstone.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rebuttable</ent><br/
<hw>Re*but"ta*ble</hw> <pr>(r<esl/*b<ucr/t"t<adot/*b'l)</pr>,
<pos>a.</pos> <def>Capable of being rebutted.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rebuttal</ent><br/
<hw>Re*but"tal</hw> <pr>(r<esl/*b<ucr/t"t<ait/l)</pr>, <pos>n.</pos>
<fld>(Law)</fld> <def>The giving of evidence on the part of a plaintiff
to destroy the effect of evidence introduced by the defendant in the
same suit.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rebutter</ent><br/
<hw>Re*but"ter</hw> <pr>(r<esl/*b<ucr/t"t<etil/r)</pr>, <pos>n.</pos>
<fld>(Law)</fld> <def>The answer of a defendant in matter of fact to a
plaintiff's surrejoinder.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recadency</ent><br/
<hw>Re*ca"den*cy</hw> <pr>(r<emac/*k<amac/"d<eit/n*s<ycr/)</pr>,
<pos>n.</pos> <def>A falling back or descending a second time; a
relapse.</def> <rj><au>W. Montagu.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recalcitrant</ent><br/
<hw>Re*cal"ci*trant</hw> <pr>(r<esl/*k<acr/l"s<icr/*tr<ait/nt)</pr>,
<pos>a.</pos> <ety>[L. <ets>recalcitrans</ets>, p. pr. of
<ets>recalcitrare</ets> to kick back; pref. <ets>re-</ets> re- +
<ets>calcitrare</ets> to kick, fr. <ets>calx</ets> heel. Cf.
<er>Inculcate</er>.]</ety> <def>Kicking back; recalcitrating; hence,
showing repugnance or opposition; refractory.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recalcitrate</ent><br/
<hw>Re*cal"ci*trate</hw> <pr>(r<esl/*k<acr/l"s<icr/*tr<amac/t)</pr>,
<pos>v. t.</pos> <def>To kick against; to show repugnance to; to
rebuff.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The more heartily did one disdain his disdain, and
<qex>recalcitrate</qex> his tricks.</q> <rj><qau>De
Quincey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recalcitrate</ent><br/
<hw>Re*cal"ci*trate</hw>, <pos>v. i.</pos> <def>To kick back; to kick
against anything; hence, to express repugnance or opposition.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recalcitration</ent><br/
<hw>Re*cal`ci*tra"tion</hw>
<pr>(r<esl/*k<acr/l"s<icr/*tr<amac/"sh<ucr/n)</pr>, <pos>n.</pos> <def>A
kicking back again; opposition; repugnance; refractoriness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recall</ent><br/
<hw>Re*call"</hw> <pr>(r<esl/*k<add/l")</pr>, <pos>v. t.</pos>
<sn>1.</sn> <def>To call back; to summon to return; <as>as, to
<ex>recall</ex> troops; to <ex>recall</ex> an ambassador.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>If Henry were <qex>recalled</qex> to life again.</q>
<rj><qau>Shak.</qau></rj></p>

<p><sn>2.</sn> <def>To revoke; to annul by a subsequent act; to take
back; to withdraw; <as>as, to <ex>recall</ex> words, or a
decree</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Passed sentence may not be <qex>recall'd</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To call back to mind; to revive in memory; to
recollect; to remember; <as>as, to <ex>recall</ex> bygone
days</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recall</ent><br/
<hw>Re*call"</hw>, <pos>n.</pos> <sn>1.</sn> <def>A calling back; a
revocation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>'T is done, and since 't is done, 't is past
<qex>recall</qex>.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mil.)</fld> <def>A call on the trumpet, bugle, or
drum, by which soldiers are recalled from duty, labor, etc.</def>
<rj><au>Wilhelm.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Political Science)</fld> <sd>(a)</sd> <def>The
right or procedure by which a public official, commonly a legislative or
executive official, may be removed from office, before the end of his
term of office, by a vote of the people to be taken on the filing of a
petition signed by a required number or percentage of qualified
voters.</def> <sd>(b)</sd> <def>Short for <col><b>recall of judicial
decisions</b></col>, the right or procedure by which the decision of a
court may be directly reversed or annulled by popular vote, as was
advocated, in 1912, in the platform of the Progressive party for certain
cases involving the police power of the state.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Recallable</ent><br/
<hw>Re*call"a*ble</hw> <pr>(r<esl/*k<add/l"<adot/*b'l)</pr>,
<pos>a.</pos> <def>Capable of being recalled.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recallment</ent><br/
<hw>Re*call"ment</hw> <pr>(r<esl/*k<add/l"m<eit/nt)</pr>, <pos>n.</pos>
<def>Recall.</def> <mark>[R.]</mark> <rj><au>R. Browning.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recant</ent><br/
<hw>Re*cant"</hw> <pr>(r<esl/*k<acr/nt")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Recanted</conjf>; <pos>p. pr. &
vb. n.</pos> <conjf>Recanting</conjf>.]</vmorph> <ety>[L.
<ets>recantare</ets>, <ets>recantatum</ets>, to recall, recant; pref.
<ets>re-</ets> re- + <ets>cantare</ets> to sing, to sound. See 3d
<er>Cant</er>, <er>Chant</er>.]</ety> <def>To withdraw or repudiate
formally and publicly (opinions formerly expressed); to contradict, as a
former declaration; to take back openly; to retract; to
recall.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>How soon . . . ease would <qex>recant</qex><br/
Vows made in pain, as violent and void!</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To retract; recall; revoke; abjure; disown;
disavow. See <er>Renounce</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recant</ent><br/
<hw>Re*cant"</hw>, <pos>v. i.</pos> <def>To revoke a declaration or
proposition; to unsay what has been said; to retract; <as>as, convince
me that I am wrong, and I will <ex>recant</ex></as>.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recantation</ent><br/
<hw>Re`can*ta"tion</hw> <pr>(r<emac/`k<acr/n*t<amac/"sh<ucr/n)</pr>,
<pos>n.</pos> <def>The act of recanting; a declaration that contradicts
a former one; that which is thus asserted in contradiction;
retraction.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The poor man was imprisoned for this discovery, and forced to make
a public <qex>recantation</qex>.</q> <rj><qau>Bp.
Stillingfleet.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recanter</ent><br/
<hw>Re*cant"er</hw> <pr>(r<esl/*k<acr/nt"<etil/r)</pr>, <pos>n.</pos>
<def>One who recants.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recapacitate</ent><br/
<hw>Re`ca*pac"i*tate</hw>
<pr>(r<emac/`k<adot/*p<acr/s"<icr/*t<amac/t)</pr>, <pos>v. t.</pos>
<def>To qualify again; to confer capacity on again.</def>
<rj><au>Atterbury.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recapitulate</ent><br/
<hw>Re*ca*pit"u*late</hw>
<pr>(r<emac/`k<adot/*p<icr/t"<usl/*l<amac/t)</pr>, <pos>v. t.</pos>
<ety>[L. <ets>recapitulare</ets>, <ets>recapitulatum</ets>; pref.
<ets>re-</ets> re- + <ets>capitulum</ets> a small head, chapter,
section. See <er>Capitulate</er>.]</ety> <def>To repeat, as the
principal points in a discourse, argument, or essay; to give a summary
of the principal facts, points, or arguments of; to relate in brief; to
summarize.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recapitulate</ent><br/
<hw>Re`ca*pit"u*late</hw>
<pr>(r<emac/`k<adot/*p<icr/t"<usl/*l<amac/t)</pr>, <pos>v. i.</pos>
<def>To sum up, or enumerate by heads or topics, what has been
previously said; to repeat briefly the substance.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recapitulation</ent><br/
<hw>Re`ca*pit`u*la"tion</hw>
<pr>(r<emac/`k<adot/*p<icr/t"<usl/*l<amac/"sh<ucr/n)</pr>, <pos>n.</pos>
<ety>[LL. <ets>recapitulatio</ets>: cf. F.
<ets>recapitulation</ets>.]</ety> <sn>1.</sn> <def>The act of
recapitulating; a summary, or concise statement or enumeration, of the
principal points, facts, or statements, in a preceding discourse,
argument, or essay.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>That process of development of
the individual organism from the embryonic stage onward, which displays
a parallel between the development of an individual animal (ontogeny)
and the historical evolution of the species (phylogeny). Some authors
recognize two types of recapitulation, <stype>palingenesis</stype>, in
which the truly ancestral characters conserved by heredity are
reproduced during development; and <stype>cenogenesis</stype>
(<contr>kenogenesis</contr> or <contr>coenogenesis</contr>), the mode of
individual development in which alterations in the development process
have changed the original process of recapitulation and obscured the
evolutionary pathway.</def><br/
[<source>PJC</source>]</p>

<p><q>This parallel is explained by the theory of evolution, according
to which, in the words of Sidgwick, "the developmental history of the
individual appears to be a short and simplified repetition, or in a
certain sense a recapitulation, of the course of development of the
species." Examples of <ex>recapitulation</ex> may be found in the
embryological development of all vertebrates. Thus the frog develops
through stages in which the embryo just before hatching is very
fish-like, after hatching becomes a tadpole which exhibits many
newt-like characters; and finally reaches the permanent frog stage. This
accords with the comparative rank of the fish, newt and frog groups in
classification; and also with the succession appearance of these groups.
Man, as the highest animal, exhibits most completely these phenomena. In
the earliest stages the human embryo is indistinguishable from that of
any other creature. A little later the cephalic region shows gill-slits,
like those which in a shark are a permanent feature, and the heart is
two-chambered or fish-like. Further development closes the gill-slits,
and the heart changes to the reptilian type. Here the reptiles stop,
while birds and mammals advance further; but the human embryo in its
progress to the higher type recapitulates and leaves features
characteristic of lower mammalian forms -- for instance, a distinct and
comparatively long tail exists. Most of these changes are completed
before the embryo is six weeks old, but some traces of primitive and
obsolete structures persist throughout life as "vestiges" or
"rudimentary organs," and others appear after birth in infancy, as the
well-known tendency of babies to turn their feet sideways and inward,
and to use their toes and feet as grasping organs, after the manner of
monkeys. This recapitulation of ancestral characters in ontogeny is not
complete, however, for not all the stages are reproduced in every case,
so far as can be perceived; and it is irregular and complicated in
various ways among others by the inheritance of acquired characters. The
most special students of it, as Haeckel, Fritz M<uum/tter, Hyatt,
Balfour, etc., distinguish two sorts of recapitulation
<stype>palingenesis</stype>, exemplified in amphibian larvae and
<stype>coenogenesis</stype>, the last manifested most completely in the
metamorphoses of insects. Palingenesis is recapitulation without any
fundamental changes due to the later modification of the primitive
method of development, while in coenogenesis, the mode of development
has suffered alterations which obscure the original process of
recapitulation, or support it entirely.</q> <qau>Encyclopedia Americana,
1961.</qau><br/
[<source>PJC</source>]</p>

<p><ent>Recapitulator</ent><br/
<hw>Re`ca*pit"u*la`tor</hw>
<pr>(r<emac/`k<adot/*p<icr/t"<usl/*l<amac/`t<etil/r)</pr>, <pos>n.</pos>
<def>One who recapitulates.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recapitulatory</ent><br/
<hw>Re`ca*pit"u*la*to*ry</hw>
<pr>(r<emac/`k<adot/*p<icr/t"<usl/*l<adot/*t<osl/*r<ycr/)</pr>,
<pos>a.</pos> <def>Of the nature of a recapitulation; containing
recapitulation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recapper</ent><br/
<hw>Re*cap"per</hw> <pr>(r<esl/*k<acr/p"p<etil/r)</pr>, <pos>n.</pos>
<fld>(Firearms)</fld> <def>A tool used for applying a fresh percussion
cap or primer to a cartridge shell in reloading it.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recaption</ent><br/
<hw>Re*cap"tion</hw> <pr>(r<esl/*k<acr/p"sh<ucr/n)</pr>, <pos>n.</pos>
<fld>(Law)</fld> <def>The act of retaking, as of one who has escaped
after arrest; reprisal; the retaking of one's own goods, chattels, wife,
or children, without force or violence, from one who has taken them and
who wrongfully detains them.</def> <rj><au>Blackstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Writ of recaption</b></col> <fld>(Law)</fld>, <cd>a writ
to recover damages for him whose goods, being distrained for rent or
service, are distrained again for the same cause.</cd>
<rj><au>Wharton.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recaptor</ent><br/
<hw>Re*cap"tor</hw> <pr>(r<esl/*k<acr/p"t<etil/r)</pr>, <pos>n.</pos>
<def>One who recaptures; one who takes a prize which had been previously
taken.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recapture</ent><br/
<hw>Re*cap"ture</hw> <pr>(r<esl/*k<acr/p"t<usl/r; 135)</pr>,
<pos>n.</pos> <sn>1.</sn> <def>The act of retaking or recovering by
capture; especially, the retaking of a prize or goods from a
captor.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is captured back; a prize
retaken.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recapture</ent><br/
<hw>Re*cap"ture</hw>, <pos>v. t.</pos> <def>To capture again; to
retake.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recarbonize</ent><br/
<hw>Re*car"bon*ize</hw> <pr>(r<esl/*k<aum/r"b<ocr/n*<imac/z)</pr>,
<pos>v. t.</pos> <fld>(Metal.)</fld> <def>To restore carbon to; <as>as,
to <ex>recarbonize</ex> iron in converting it into steel</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recarnify</ent><br/
<hw>Re*car"ni*fy</hw> <pr>(r<esl/*k<aum/r"n<icr/*f<imac/)</pr>, <pos>v.
t.</pos> <def>To convert again into flesh.</def> <mark>[Obs.]</mark>
<rj><au>Howell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recarriage</ent><br/
<hw>Re*car"riage</hw> <pr>(r<esl/*k<acr/r"r<icr/j)</pr>, <pos>n.</pos>
<def>Act of carrying back.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recarry</ent><br/
<hw>Re*car"ry</hw> <pr>(r<esl/*k<acr/r"r<ycr/)</pr>, <pos>v. t.</pos>
<def>To carry back.</def> <rj><au>Walton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recast</ent><br/
<hw>Re*cast"</hw> <pr>(r<emac/*k<adot/st")</pr>, <pos>v. t.</pos>
<sn>1.</sn> <def>To throw again.</def> <rj><au>Florio.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To mold anew; to cast anew; to throw into a new form
or shape; to reconstruct; <as>as, to <ex>recast</ex> cannon; to
<ex>recast</ex> an argument or a play.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To compute, or cast up, a second time.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recche</ent><br/
<hw>Rec"che</hw> <pr>(r<ecr/k"k<eit/)</pr>, <pos>v. i.</pos> <def>To
reck.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reccheles</ent><br/
<hw>Rec"che*les</hw> <pr>(r<ecr/k"l<ecr/s)</pr>, <pos>a.</pos>
<def>Reckless.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recede</ent><br/
<hw>Re*cede"</hw> <pr>(r<esl/*s<emac/d")</pr>, <pos>v. i.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Receded</conjf>; <pos>p. pr. &
vb. n.</pos> <conjf>Receding</conjf>.]</vmorph> <ety>[L.
<ets>recedere</ets>, <ets>recessum</ets>; pref. <ets>re-</ets> re- +
<ets>cedere</ets> to go, to go along: cf. F. <ets>rec<eacute/der</ets>.
See <er>Cede</er>.]</ety> <sn>1.</sn> <def>To move back; to retreat; to
withdraw.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Like the hollow roar<br/
Of tides <qex>receding</qex> from the insulted shore.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>All bodies moved circularly endeavor to <qex>recede</qex> from the
center.</q> <rj><qau>Bentley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To withdraw a claim or pretension; to desist; to
relinquish what had been proposed or asserted; <as>as, to
<ex>recede</ex> from a demand or proposition</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To retire; retreat; return; retrograde; withdraw;
desist.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recede</ent><br/
<hw>Re*cede"</hw> <pr>(r<emac/*s<emac/d")</pr>, <pos>v. t.</pos>
<ety>[Pref. <ets>re-</ets> + <ets>cede</ets>. Cf. <er>Recede</er>,
<pos>v. i.</pos>]</ety> <def>To cede back; to grant or yield again to a
former possessor; <as>as, to <ex>recede</ex> conquered
territory</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Receipt</ent><br/
<hw>Re*ceipt"</hw> <pr>(r<esl/*s<emac/t")</pr>, <pos>n.</pos> <ety>[OE.
<ets>receite</ets>, OF. <ets>recete</ets>, <ets>recepte</ets>, F.
<ets>recette</ets>, fr. L. <ets>recipere</ets>, <ets>receptum</ets>, to
receive. See <er>Receive</er>.]</ety> <sn>1.</sn> <def>The act of
receiving; reception.</def> <ldquo/At the <xex>receipt</xex> of your
letter.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Reception, as an act of hospitality.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Thy kind <qex>receipt</qex> of me.</q>
<rj><qau>Chapman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Capability of receiving; capacity.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>It has become a place of great <qex>receipt</qex>.</q>
<rj><qau>Evelyn.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Place of receiving.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He saw a man, named Matthew, sitting at the <qex>receipt</qex> of
custom.</q> <rj><qau>Matt. ix. 9.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Hence, a recess; a retired place.</def>
<mark>[Obs.]</mark> <ldquo/In a retired <xex>receipt</xex> together
lay.<rdquo/ <rj><au>Chapman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>A formulary according to the directions of which
things are to be taken or combined; a recipe; <as>as, a <ex>receipt</ex>
for making sponge cake</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>She had a <qex>receipt</qex> to make white hair black.</q>
<rj><qau>Sir T. Browne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>A writing acknowledging the taking or receiving of
goods delivered; an acknowledgment of money paid.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>That which is received; that which comes in, in
distinction from what is expended, paid out, sent away, and the like; --
usually in the plural; <as>as, the <ex>receipts</ex> amounted to a
thousand dollars</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Gross receipts</b></col>. <cd>See under <er>Gross</er>,
<pos>a.</pos></cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Receipt</ent><br/
<hw>Re*ceipt"</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Receipted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Receipting</conjf>.]</vmorph> <sn>1.</sn> <def>To give a receipt
for; <as>as, to <ex>receipt</ex> goods delivered by a
sheriff</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To put a receipt on, as by writing or stamping;
<as>as, to <ex>receipt</ex> a bill</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Receipt</ent><br/
<hw>Re*ceipt"</hw>, <pos>v. i.</pos> <def>To give a receipt, as for
money paid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Receiptment</ent><br/
<hw>Re*ceipt"ment</hw> <pr>(r<esl/*s<emac/t"m<eit/nt)</pr>,
<pos>n.</pos> <fld>(O. Eng. Law)</fld> <def>The receiving or harboring a
felon knowingly, after the commission of a felony.</def>
<rj><au>Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Receiptor</ent><br/
<hw>Re*ceipt"or</hw> <pr>(r<esl/*s<emac/t"<etil/r)</pr>, <pos>n.</pos>
<def>One who receipts; specifically <fld>(Law)</fld>, one who receipts
for property which has been taken by the sheriff.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Receit</ent><br/
<hw>Re*ceit"</hw> <pr>(r<esl/*s<emac/t")</pr>, <pos>n.</pos>
<def>Receipt.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Receivability</ent><br/
<hw>Re*ceiv`a*bil"i*ty</hw>
<pr>(r<esl/*s<emac/v`<adot/*b<icr/l"<icr/*t<ycr/)</pr>, <pos>n.</pos>
<def>The quality of being receivable; receivableness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Receivable</ent><br/
<hw>Re*ceiv"a*ble</hw> <pr>(r<esl/*s<emac/v"<adot/*b'l)</pr>,
<pos>a.</pos> <ety>[Cf. F. <ets>recevable</ets>.]</ety> <def>Capable of
being received.</def> -- <wordforms><wf>Re*ceiv"a*ble*ness</wf>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Bills receivable</b></col>. <cd>See under 6th
<er>Bill</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Receive</ent><br/
<hw>Re*ceive"</hw> <pr>(r<esl/*s<emac/v")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Received</conjf>
<pr>(r<esl/*s<emac/vd")</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Receiving</conjf>.]</vmorph> <ety>[OF. <ets>receveir</ets>,
<ets>recevoir</ets>, F. <ets>recevoir</ets>, fr. L. <ets>recipere</ets>;
pref. <ets>re-</ets> re- + <ets>capere</ets> to take, seize. See
<er>Capable</er>, <er>Heave</er>, and cf. <er>Receipt</er>,
<er>Reception</er>, <er>Recipe</er>.]</ety> <sn>1.</sn> <def>To take, as
something that is offered, given, committed, sent, paid, or the like; to
accept; <as>as, to <ex>receive</ex> money offered in payment of a debt;
to <ex>receive</ex> a gift, a message, or a letter.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Receyven</qex> all in gree that God us sent.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence: To gain the knowledge of; to take into the
mind by assent to; to give admission to; to accept, as an opinion,
notion, etc.; to embrace.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Our hearts <qex>receive</qex> your warnings.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The idea of solidity we <qex>receive</qex> by our touch.</q>
<rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To allow, as a custom, tradition, or the like; to
give credence or acceptance to.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Many other things there be which they have <qex>received</qex> to
hold, as the washing of cups, and pots.</q> <rj><qau>Mark vii.
4.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To give admittance to; to permit to enter, as into
one's house, presence, company, and the like; <as>as, to
<ex>receive</ex> a lodger, visitor, ambassador, messenger,
etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>They kindled a fire, and <qex>received</qex> us every one.</q>
<rj><qau>Acts xxviii. 2.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To admit; to take in; to hold; to contain; to have
capacity for; to be able to take in.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The brazen altar that was before the Lord was too little to
<qex>receive</qex> the burnt offerings.</q> <rj><qau>1 Kings viii.
64.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To be affected by something; to suffer; to be
subjected to; <as>as, to <ex>receive</ex> pleasure or pain; to
<ex>receive</ex> a wound or a blow; to <ex>receive</ex>
damage.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Against his will he can <qex>receive</qex> no harm.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>To take from a thief, as goods known to be
stolen.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <fld>(Lawn Tennis)</fld> <def>To bat back (the ball) when
served.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Receiving ship</b></col>, <cd>one on board of which newly
recruited sailors are received, and kept till drafted for
service.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To accept; take; allow; hold; retain;
admit.</syn> <usage> -- <er>Receive</er>, <er>Accept</er>. To
<xex>receive</xex> describes simply the act of taking. To
<xex>accept</xex> denotes the taking with approval, or for the purposes
for which a thing is offered. Thus, we <xex>receive</xex> a letter when
it comes to hand; we <xex>receive</xex> news when it reaches us; we
<xex>accept</xex> a present when it is offered; we <xex>accept</xex> an
invitation to dine with a friend.</usage><br/
[<source>1913 Webster</source>]</p>

<p><q>Who, if we knew<br/
What we <qex>receive</qex>, would either not <qex>accept</qex><br/
Life offered, or soon beg to lay it down.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Receive</ent><br/
<hw>Re*ceive"</hw> <pr>(r<esl/*s<emac/v")</pr>, <pos>v. i.</pos>
<sn>1.</sn> <def>To receive visitors; to be at home to receive calls;
<as>as, she <ex>receives</ex> on Tuesdays</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Lawn Tennis)</fld> <def>To return, or bat back, the
ball when served; <as>as, it is your turn to
<ex>receive</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Receivedness</ent><br/
<hw>Re*ceiv"ed*ness</hw>, <pos>n.</pos> <def>The state or quality of
being received, accepted, or current; <as>as, the <ex>receivedness</ex>
of an opinion</as>.</def> <rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Receiver</ent><br/
<hw>Re*ceiv"er</hw> <pr>(r<esl/*s<emac/v"<etil/r)</pr>, <pos>n.</pos>
<ety>[Cf. F. <ets>receveur</ets>.]</ety> <sn>1.</sn> <def>One who takes
or receives in any manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>A person appointed, ordinarily by a
court, to receive, and hold in trust, money or other property which is
the subject of litigation, pending the suit; a person appointed to take
charge of the estate and effects of a corporation, and to do other acts
necessary to winding up its affairs, in certain cases.</def>
<rj><au>Bouvier.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>One who takes or buys stolen goods from a thief,
knowing them to be stolen.</def> <rj><au>Blackstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Chem.)</fld> <sd>(a)</sd> <def>A vessel connected
with an alembic, a retort, or the like, for receiving and condensing the
product of distillation.</def> <sd>(b)</sd> <def>A vessel for receiving
and containing gases.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Pneumatics)</fld> <def>The glass vessel in which
the vacuum is produced, and the objects of experiment are put, in
experiments with an air pump. Cf. <er>Bell jar</er>, and see
<xex>Illust.</xex> of <er>Air pump</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Steam Engine)</fld> <sd>(a)</sd> <def>A vessel for
receiving the exhaust steam from the high-pressure cylinder before it
enters the low-pressure cylinder, in a compound engine.</def>
<sd>(b)</sd> <def>A capacious vessel for receiving steam from a distant
boiler, and supplying it dry to an engine.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>That portion of a telephonic apparatus, or similar
system, at which the message is received and made audible; -- opposed to
<contr>transmitter</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <fld>(Firearms)</fld> <def>In portable breech-loading
firearms, the steel frame screwed to the breech end of the barrel, which
receives the bolt or block, gives means of securing for firing,
facilitates loading, and holds the ejector, cut-off, etc.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><cs><col><b>Exhausted receiver</b></col> <fld>(Physics)</fld>, <cd>a
receiver, as that used with the air pump, from which the air has been
withdrawn; a vessel the interior of which is a more or less complete
vacuum.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Receiver's certificate</ent><br/
<hw>Re*ceiv"er's cer*tif"i*cate</hw> <pr>(?)</pr>. <def>An
acknowledgment of indebtedness made by a receiver under order of court
to obtain funds for the preservation of the assets held by him, as for
operating a railroad. Receivers' certificates are ordinarily a first
lien on the assets, prior to that of bonds or other
securities.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Receivership</ent><br/
<hw>Re*ceiv"er*ship</hw>, <pos>n.</pos> <def>The state or office of a
receiver.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recelebrate</ent><br/
<hw>Re*cel"e*brate</hw> <pr>(r<emac/*s<ecr/l"<esl/*br<amac/t)</pr>,
<pos>v. t.</pos> <def>To celebrate again, or anew.</def> --
<wordforms><wf>Re*cel`e*bra"tion</wf>
<pr>(r<emac/*s<ecr/l"<esl/*br<amac/"sh<ucr/n)</pr>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recency</ent><br/
<hw>Re"cen*cy</hw> <pr>(r<emac/"s<eit/n*s<ycr/)</pr>, <pos>n.</pos>
<ety>[LL. <ets>recentia</ets>, fr. L. <ets>recens</ets>. See
<er>Recent</er>.]</ety> <def>The state or quality of being recent;
newness; new state; late origin; lateness in time; freshness; <as>as,
the <ex>recency</ex> of a transaction, of a wound, etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recense</ent><br/
<hw>Re*cense"</hw> <pr>(r<esl/*s<ecr/ns")</pr>, <pos>v. t.</pos>
<ety>[L. <ets>recensere</ets>; pref. <ets>re-</ets> again +
<ets>censere</ets> to value, estimate: cf. F.
<ets>recenser</ets>.]</ety> <def>To review; to revise.</def>
<mark>[R.]</mark> <rj><au>Bentley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recension</ent><br/
<hw>Re*cen"sion</hw> <pr>(r<esl/*s<ecr/n"sh<ucr/n)</pr>, <pos>n.</pos>
<ety>[L. <ets>recensio</ets>: cf. F. <ets>recension</ets>.]</ety>
<sn>1.</sn> <def>The act of reviewing or revising; review; examination;
enumeration.</def> <rj><au>Barrow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Specifically, the review of a text (as of an ancient
author) by an editor; critical revisal and establishment.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The result of such a work; a text established by
critical revision; an edited version.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recensionist</ent><br/
<hw>Re*cen"sion*ist</hw>, <pos>n.</pos> <def>One who makes recensions;
specifically, a critical editor.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recent</ent><br/
<hw>Re"cent</hw> <pr>(r<emac/"s<eit/nt)</pr>, <pos>a.</pos> <ety>[L.
<ets>recens</ets>, <ets>-entis</ets>: cf. F.
<ets>r<eacute/cent</ets>.]</ety> <sn>1.</sn> <def>Of late origin,
existence, or occurrence; lately come; not of remote date, antiquated
style, or the like; not already known, familiar, worn out, trite, etc.;
fresh; novel; new; modern; <as>as, <ex>recent</ex> news</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The ancients were of opinion, that a considerable portion of that
country [Egypt] was <qex>recent</qex>, and formed out of the mud
discharged into the neighboring sea by the Nile.</q>
<rj><qau>Woodward.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Geol.)</fld> <def>Of or pertaining to the present
or existing epoch; <as>as, <ex>recent</ex> shells</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recenter</ent><br/
<hw>Re*cen"ter</hw> <pr>(r<emac/*s<ecr/n"t<etil/r)</pr>, <pos>v.
t.</pos> <ety>[Pref. <ets>re-</ets> + <ets>center</ets>.]</ety> <def>To
center again; to restore to the center.</def>
<rj><au>Coleridge.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recently</ent><br/
<hw>Re"cent*ly</hw> <pr>(r<emac/"s<eit/nt*l<ycr/)</pr>, <pos>adv.</pos>
<def>Newly; lately; freshly; not long since; <as>as, advices
<ex>recently</ex> received</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recentness</ent><br/
<hw>Re"cent*ness</hw>, <pos>n.</pos> <def>Quality or state of being
recent.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Receptacle</ent><br/
<hw>Re*cep"ta*cle</hw> <pr>(r<esl/*s<ecr/p"t<adot/*k'l)</pr>,
<pos>n.</pos> <ety>[F. <ets>r<eacute/ceptacle</ets>, L.
<ets>receptaculum</ets>, fr. <ets>receptare</ets>, v. intens. fr.
<ets>recipere</ets> to receive. See <er>Receive</er>.]</ety> <sn>1.</sn>
<def>That which serves, or is used, for receiving and containing
something, as for example, a <stype>basket</stype>, a
<stype>vase</stype>, a <stype>bag</stype>, a <stype>reservoir</stype>; a
<stype>repository</stype>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>O sacred <qex>receptacle</qex> of my joys!</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <sd>(a)</sd> <def>The apex of the
flower stalk, from which the organs of the flower grow, or into which
they are inserted. See <xex>Illust.</xex> of <er>Flower</er>, and
<er>Ovary</er>.</def> <sd>(b)</sd> <def>The dilated apex of a pedicel
which serves as a common support to a head of flowers.</def>
<sd>(c)</sd> <def>An intercellular cavity containing oil or resin or
other matters.</def> <sd>(d)</sd> <def>A special branch which bears the
fructification in many cryptogamous plants.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1198 pr=vmg --></p>

<p><ent>Receptacular</ent><br/
<hw>Rec`ep*tac"u*lar</hw>
<pr>(r<ecr/s`<ecr/p*t<acr/k"<usl/*l<etil/r)</pr>, <pos>a.</pos>
<ety>[Cf. F. <ets>r<eacute/ceptaculaire</ets>.]</ety> <fld>(Bot.)</fld>
<def>Pertaining to the receptacle, or growing on it; <as>as, the
<ex>receptacular</ex> chaff or scales in the sunflower</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Receptaculum</ent><br/
\'d8<hw>Rec`ep*tac"u*lum</hw>
<pr>(r<ecr/s`<ecr/p*t<acr/k"<usl/*l<ucr/m)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Receptacula</plw>
<pr>(r<ecr/s`<ecr/p*t<acr/k"<usl/*l<adot/)</pr>.</plu> <ety>[L.]</ety>
<fld>(Anat.)</fld> <def>A receptacle; <as>as, the <ex>receptaculum</ex>
of the chyle</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Receptary</ent><br/
<hw>Rec"ep*ta*ry</hw> <pr>(r<ecr/s"<ecr/p*t<asl/*r<ycr/)</pr>,
<pos>a.</pos> <def>Generally or popularly admitted or received.</def>
<mark>[Obs.]</mark> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Receptary</ent><br/
<hw>Rec"ep*ta*ry</hw>, <pos>n.</pos> <def>That which is received.</def>
<mark>[Obs.]</mark> <ldquo/<xex>Receptaries</xex> of philosophy.<rdquo/
<rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Receptibility</ent><br/
<hw>Re*cep`ti*bil"i*ty</hw>
<pr>(r<esl/*s<ecr/p`t<icr/*b<icr/l"<icr/*t<ycr/)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>The quality or state of being receptible;
receivableness.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A receptible thing.</def> <mark>[R.]</mark>
<rj><au>Glanvill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Receptible</ent><br/
<hw>Re*cep"ti*ble</hw> <pr>(r<esl/*s<ecr/p"t<icr/*b'l)</pr>,
<pos>a.</pos> <ety>[L. <ets>receptibilis</ets>.]</ety> <def>Such as may
be received; receivable.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reception</ent><br/
<hw>Re*cep"tion</hw> <pr>(r<esl/*s<ecr/p"sh<ucr/n)</pr>, <pos>n.</pos>
<ety>[F. <ets>r<eacute/ception</ets>, L. <ets>receptio</ets>, fr.
<ets>recipere</ets>, <ets>receptum</ets>. See <er>Receive</er>.]</ety>
<sn>1.</sn> <def>The act of receiving; receipt; admission; <as>as, the
<ex>reception</ex> of food into the stomach; the <ex>reception</ex> of a
letter; the <ex>reception</ex> of sensation or ideas; <ex>reception</ex>
of evidence.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The state of being received.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The act or manner of receiving, especially of
receiving visitors; entertainment; hence, an occasion or ceremony of
receiving guests; <as>as, a hearty <ex>reception</ex>; an elaborate
<ex>reception</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>What <qex>reception</qex> a poem may find.</q>
<rj><qau>Goldsmith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Acceptance, as of an opinion or doctrine.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Philosophers who have quitted the popular doctrines of their
countries have fallen into as extravagant opinions as even common
<qex>reception</qex> countenanced.</q> <rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A retaking; a recovery.</def> <mark>[Obs.]</mark>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Receptive</ent><br/
<hw>Re*cep"tive</hw> <pr>(r<esl/*s<ecr/p"t<icr/v)</pr>, <pos>a.</pos>
<ety>[Cf. F. <ets>r<eacute/ceptif</ets>. See <er>Receive</er>.]</ety>
<def>Having the quality of receiving; able or inclined to take in,
absorb, hold, or contain; receiving or containing; <as>as, a
<ex>receptive</ex> mind</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Imaginary space is <qex>receptive</qex> of all bodies.</q>
<rj><qau>Glanvill.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Receptiveness</ent><br/
<hw>Re*cep"tive*ness</hw>, <pos>n.</pos> <def>The quality of being
receptive.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Receptivity</ent><br/
<hw>Rec`ep*tiv"i*ty</hw> <pr>(r<ecr/s`<ecr/p*t<icr/v"<icr/*t<ycr/ <or/
r<emac/`s<ecr/p*t<icr/v"<icr/*t<ycr/)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>r<eacute/ceptivit<eacute/</ets>.]</ety> <sn>1.</sn> <def>The state
or quality of being receptive.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Kantian Philos.)</fld> <def>The power or capacity
of receiving impressions, as those of the external senses.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Receptory</ent><br/
<hw>Re*cep"to*ry</hw> <pr>(r<esl/*s<ecr/p"t<osl/*r<ycr/; 277)</pr>,
<pos>n.</pos> <ety>[Cf. L. <ets>receptorium</ets> a place of
shelter.]</ety> <def>Receptacle.</def> <mark>[Obs.]</mark>
<rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recess</ent><br/
<hw>Re*cess"</hw> <pr>(r<esl/*s<ecr/s")</pr>, <pos>n.</pos> <ety>[L.
<ets>recessus</ets>, fr. <ets>recedere</ets>, <ets>recessum</ets>. See
<er>Recede</er>.]</ety> <sn>1.</sn> <def>A withdrawing or retiring; a
moving back; retreat; <as>as, the <ex>recess</ex> of the
tides</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Every degree of ignorance being so far a <qex>recess</qex> and
degradation from rationality.</q> <rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>My <qex>recess</qex> hath given them confidence that I may be
conquered.</q> <rj><qau>Eikon Basilike.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The state of being withdrawn; seclusion;
privacy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In the <qex>recess</qex> of the jury they are to consider the
evidence.</q> <rj><qau>Sir M. Hale.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Good verse <qex>recess</qex> and solitude requires.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Remission or suspension of business or procedure;
intermission, as of a legislative body, court, or school; <as>as, the
children were allowed to play in the school yard during
<ex>recess</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>recess</qex> of . . . Parliament lasted six weeks.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Part of a room formed by the receding of the wall,
as an alcove, niche, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A bed which stood in a deep <qex>recess</qex>.</q> <rj><qau>W.
Irving.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A place of retirement, retreat, secrecy, or
seclusion.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Departure from this happy place, our sweet<br/
<qex>Recess</qex>, and only consolation left.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Secret or abstruse part; <as>as, the difficulties
and <ex>recesses</ex> of science; the deepest <ex>recesses</ex> of the
mind</as>.</def> <rj><au>I. Watts.</au></rj><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>7.</sn> <fld>(Bot. & Zool.)</fld> <def>A sinus.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recess</ent><br/
<hw>Re*cess"</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Recessed</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Recessing</conjf>.]</vmorph> <def>To make a recess in; <as>as, to
<ex>recess</ex> a wall</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recess</ent><br/
<hw>Re*cess"</hw>, <pos>n.</pos> <ety>[G.]</ety> <def>A decree of the
imperial diet of the old German empire.</def> <rj><au>Brande &
C.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recessed</ent><br/
<hw>Re*cessed"</hw> <pr>(r<esl/*s<ecr/st")</pr>, <pos>a.</pos>
<sn>1.</sn> <def>Having a recess or recesses; <as>as, a
<ex>recessed</ex> arch or wall</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Withdrawn; secluded.</def> <mark>[R.]</mark>
<ldquo/Comfortably <xex>recessed</xex> from curious impertinents.<rdquo/
<rj><au>Miss Edgeworth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Recessed arch</b></col> <fld>(Arch.)</fld>, <cd>one of a
series of arches constructed one within another so as to correspond with
splayed jambs of a doorway, or the like.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recession</ent><br/
<hw>Re*ces"sion</hw> <pr>(r<esl/*s<ecr/sh"<ucr/n)</pr>, <pos>n.</pos>
<ety>[L. <ets>recessio</ets>, fr. <ets>recedere</ets>,
<ets>recessum</ets>. See <er>Recede</er>.]</ety> <sn>1.</sn> <def>The
act of receding or withdrawing, as from a place, a claim, or a
demand.</def> <rj><au>South.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Mercy may rejoice upon the <qex>recessions</qex> of justice.</q>
<rj><qau>Jer. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Economics)</fld> <def>A period during which
economic activity, as measured by gross domestic product, declines for
at least two quarters in a row in a specific country. If the decline is
severe and long, such as greater than ten percent, it may be termed a
<contr>depression</contr>.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>A procession in which people leave a ceremony, such
as at a religious service.</def><br/
[<source>PJC</source>]</p>

<p><ent>Recession</ent><br/
<hw>Re*ces"sion</hw>, <pos>n.</pos> <ety>[Pref. <ets>re-</ets> +
<ets>cession</ets>.]</ety> <def>The act of ceding back; restoration;
repeated cession; <as>as, the <ex>recession</ex> of conquered territory
to its former sovereign</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recessional</ent><br/
<hw>Re*ces"sion*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or
pertaining to recession or withdrawal.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Recessional hymn</b></col>, <cd>a hymn sung in a
procession returning from the choir to the robing room; a
<er>recessional</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>recessional</ent><br/
<hw>re*ces"sion*al</hw> <pr>(r<esl/*s<ecr/sh"<ucr/n*<ait/l)</pr>,
<pos>n.</pos> <def>a hymn or other piece of music sung or played while a
church congregation is leaving a service, or a choir is returning to the
cloak room; a <cref>recessional hymn</cref>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Recessive</ent><br/
<hw>Re*ces"sive</hw> <pr>(r<esl/*s<ecr/s"s<icr/v)</pr>, <pos>a.</pos>
<sn>1.</sn> <def>Going back; receding.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Genetics)</fld> <def>Not appearing in the phenotype
unless both alleles of the organism have the same trait; -- of genetic
characteristics, or of the genes coding for such characteristics, in
diploid organisms. Opposite of <ant>dominant</ant>; <as>hemophilia is a
<ex>recessive</ex> trait</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Recessive</ent><br/
<hw>Re*ces"sive</hw> <pr>(r<esl/*s<ecr/s"s<icr/v)</pr>, <pos>n.</pos>
<fld>(Genetics)</fld> <def>A genetic trait determined by a recessive{2}
allele; a trait not appearing in the phenotype unless both chromosomes
of the organism have the same allele; also, an allele which is
recessive{2}.</def><br/
[<source>PJC</source>]</p>

<p><ent>Rechabite</ent><br/
<hw>Re"chab*ite</hw> <pr>(r<emac/"k<acr/b*<imac/t)</pr>, <pos>n.</pos>
<fld>(Jewish Hist.)</fld> <def>One of the descendants of Jonadab, the
son of Rechab, all of whom by his injunction abstained from the use of
intoxicating drinks and even from planting the vine. <xex>Jer</xex>.
<xex>xxxv</xex>. 2-19. Also, in modern times, a member of a certain
society of abstainers from alcoholic liquors.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rechange</ent><br/
<hw>Re*change"</hw> <pr>(r<emac/*ch<amac/nj")</pr>, <pos>v. t. &
i.</pos> <def>To change again, or change back.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recharge</ent><br/
<hw>Re*charge"</hw> <pr>(r<emac/*ch<aum/rj")</pr>, <pos>v. t. & i.</pos>
<ety>[Pref. <ets>re-</ets> + <ets>charge</ets>: cf. F.
<ets>recharger</ets>.]</ety> <sn>1.</sn> <def>To charge or accuse in
return.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To attack again; to attack anew.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recharter</ent><br/
<hw>Re*char"ter</hw> <pr>(r<emac/*ch<aum/r"t<etil/r)</pr>, <pos>n.</pos>
<def>A second charter; a renewal of a charter.</def> <rj><au>D.
Webster.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recharter</ent><br/
<hw>Re*char"ter</hw>, <pos>v. t.</pos> <def>To charter again or anew; to
grant a second or another charter to.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rechase</ent><br/
<hw>Re*chase"</hw> <pr>(r<emac/*ch<amac/s")</pr>, <pos>v. t.</pos>
<ety>[Pref. <ets>re-</ets> + <ets>chase</ets>: cf. F.
<ets>rechasser</ets>.]</ety> <def>To chase again; to chase or drive
back.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rechauff<eacute/</ent><br/
\'d8<hw>R<eacute/`chauf`f<eacute/"</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[F., orig. p.p. of <ets>r<eacute/chauffer</ets> 8warm over. See
<er>Chafe</er>, <pos>v. t.</pos>]</ety> <def>A dish of food that has
been warmed again, hence, fig., something made up from old material; a
rehash.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><q>It is merely a <qex>r<eacute/chauff<eacute/</qex> of ancient
philosophies.</q> <rj><qau>F. W. H. Myers.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Recheat</ent><br/
<hw>Re*cheat"</hw> <pr>(r<esl/*ch<emac/t")</pr>, <pos>n.</pos> <ety>[F.
<ets>requ<ecir/t<eacute/</ets>, fr. <ets>requ<ecir/ter</ets> to hunt
anew. See <er>Request</er>.]</ety> <fld>(Sporting)</fld> <def>A strain
given on the horn to call back the hounds when they have lost track of
the game.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recheat</ent><br/
<hw>Re*cheat"</hw>, <pos>v. i.</pos> <def>To blow the recheat.</def>
<rj><au>Drayton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recherche</ent><br/
\'d8<hw>Re*cher`ch<eacute/"</hw> <pr>(r<eit/*sh<acir/r`sh<asl/")</pr>,
<pos>a.</pos> <ety>[F.]</ety> <def>Sought out with care; choice.</def>
<specif>Hence:</specif> <def>of rare quality, elegance, or
attractiveness; peculiar and refined in kind.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rechless</ent><br/
<hw>Rech"less</hw> <pr>(r<ecr/k"l<ecr/s)</pr>, <pos>a.</pos>
<def>Reckless.</def> <mark>[Obs.]</mark> <rj><au>P.
Plowman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rechoose</ent><br/
<hw>Re*choose"</hw> <pr>(r<emac/*ch<oomac/z")</pr>, <pos>v. t.</pos>
<def>To choose again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recidivate</ent><br/
<hw>Re*cid"i*vate</hw> <pr>(r<esl/*s<icr/d"<icr/*v<amac/t)</pr>, <pos>v.
i.</pos> <ety>[LL. <ets>recidivare</ets>. See
<er>Recidivous</er>.]</ety> <def>To backslide; to fall again.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recidivation</ent><br/
<hw>Re*cid`i*va"tion</hw>
<pr>(r<esl/*s<icr/d"<icr/*v<amac/"sh<ucr/n)</pr>, <pos>n.</pos>
<ety>[LL. <ets>recidivatio</ets>.]</ety> <def>A falling back; a
backsliding.</def> <rj><au>Hammond.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recidivism</ent><br/
<hw>Re*cid"i*vism</hw> <pr>(r<esl/*s<icr/d"<icr/*v<icr/z'm)</pr>,
<pos>n.</pos> <def>The state or quality of being recidivous;
relapse,</def> <specif>specif.</specif> <fld>(Criminology)</fld>, <def>a
falling back or relapse into prior criminal habits, esp. after
conviction and punishment.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><q>The old English system of recognizances, in which the guilty party
deposits a sum of money, is an excellent guarantee to society against
<qex>recidivism</qex>.</q> <rj><qau>Havelock Ellis.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Recidivist</ent><br/
<hw>Re*cid"i*vist</hw> <pr>(r<esl/*s<icr/d"<icr/*v<icr/st)</pr>,
<pos>n.</pos> <def>One who is recidivous or is characterized by
recidivism; an incorrigible criminal.</def> --
<wordforms><wf>Re*cid`i*vis"tic</wf>
<pr>(r<esl/*s<icr/d`<icr/*v<icr/s"t<icr/k)</pr>,
<pos>a.</pos></wordforms><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><q>The criminal by passion never becomes a <qex>recidivist</qex>, it
is the social, not the antisocial, instincts that are strong within him,
his crime is a solitary event in his life.</q> <rj><qau>Havelock
Ellis.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Recidivous</ent><br/
<hw>Re*cid"i*vous</hw> <pr>(r<esl/*s<icr/d"<icr/*v<ucr/s)</pr>,
<pos>a.</pos> <ety>[L. <ets>recidivus</ets>, fr. <ets>recidere</ets> to
fall back.]</ety> <def>Tending or liable to backslide or relapse to a
former condition or habit.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recipe</ent><br/
<hw>Rec"i*pe</hw> <pr>(r<ecr/s"<icr/*p<esl/)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Recipes</plw>
<pr>(r<ecr/s"<icr/*p<emac/z)</pr>.</plu> <ety>[L., imperative of
<ets>recipere</ets> to take back, take in, receive. See
<er>Receive</er>.]</ety> <def>A formulary or prescription for making
some combination, mixture, or preparation of materials; a
receipt.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>a prescription for medicine.</def>
<mark>[archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>a prescription for medicine.</def>
<mark>[archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>a set of directions for preparing food from its
ingredients.</def><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <def>a method or procedure for accomplishing a goal by
defined steps; -- implying a high probability of achieving the goal;
<as>as, a <ex>recipe</ex> for success</as>. Also used in a negative
sense, <as>as, a <ex>recipe</ex> for disaster</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Recipiangle</ent><br/
<hw>Re*cip"i*an`gle</hw> <pr>(r<esl/*s<icr/p"<icr/*<acr/<nsm/`g'l)</pr>,
<pos>n.</pos> <ety>[L. <ets>recipere</ets> to take + <ets>angulus</ets>
angle.]</ety> <def>An instrument with two arms that are pivoted together
at one end, and a graduated arc, -- used by military engineers for
measuring and laying off angles of fortifications.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recipiency</ent><br/
<ent>Recipience</ent><br/
<mhw>{ <hw>Re*cip"i*ence</hw> <pr>(r<esl/*s<icr/p"<icr/*<eit/ns)</pr>,
<hw>Re*cip"i*en*cy</hw> <pr>(r<esl/*s<icr/p"<icr/*<eit/n*s<ycr/)</pr>,
}</mhw> <pos>n.</pos> <def>The quality or state of being recipient; a
receiving; reception; receptiveness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recipient</ent><br/
<hw>Re*cip"i*ent</hw> <pr>(r<esl/*s<icr/p"<icr/*<eit/nt)</pr>,
<pos>n.</pos> <ety>[L. <ets>recipiens</ets>, <ets>-entis</ets>,
receiving, p. pr. of <ets>recipere</ets> to receive: cf. F.
<ets>r<eacute/cipient</ets>. See <er>Receive</er>.]</ety> <def>A
receiver; the person or thing that receives; one to whom, or that to
which, anything is given or communicated; specifically, the receiver of
a still.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recipient</ent><br/
<hw>Re*cip"i*ent</hw>, <pos>a.</pos> <def>Receiving;
receptive.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reciprocal</ent><br/
<hw>Re*cip"ro*cal</hw> <pr>(r<esl/*s<icr/p"r<osl/*k<ait/l)</pr>,
<pos>a.</pos> <ety>[L. <ets>reciprocus</ets>; of unknown origin.]</ety>
<sn>1.</sn> <def>Recurring in vicissitude; alternate.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Done by each to the other; interchanging or
interchanged; given and received; due from each to each; mutual; <as>as,
<ex>reciprocal</ex> love; <ex>reciprocal</ex> duties.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Let our <qex>reciprocal</qex> vows be remembered.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Mutually interchangeable.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>These two rules will render a definition <qex>reciprocal</qex>
with the thing defined.</q> <rj><qau>I. Watts.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Gram.)</fld> <def>Reflexive; -- applied to pronouns
and verbs, but sometimes limited to such pronouns as express mutual
action.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Math.)</fld> <def>Used to denote different kinds of
mutual relation; often with reference to the substitution of reciprocals
for given quantities. See the Phrases below.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Reciprocal equation</b></col> <fld>(Math.)</fld>, <cd>one
which remains unchanged in form when the reciprocal of the unknown
quantity is substituted for that quantity.</cd> -- <col><b>Reciprocal
figures</b></col> <fld>(Geom.)</fld>, <cd>two figures of the same kind
(as triangles, parallelograms, prisms, etc.), so related that two sides
of the one form the extremes of a proportion of which the means are the
two corresponding sides of the other; in general, two figures so related
that the first corresponds in some special way to the second, and the
second corresponds in the same way to the first.</cd> --
<col><b>Reciprocal proportion</b></col> <fld>(Math.)</fld>, <cd>a
proportion such that, of four terms taken in order, the first has to the
second the same ratio which the fourth has to the third, or the first
has to the second the same ratio which the reciprocal of the third has
to the reciprocal of the fourth. Thus, 2:5: :20:8 form a <xex>reciprocal
proportion</xex>, because 2:5: :<frac1x20/:<frac18/.</cd> --
<col><b>Reciprocal quantities</b></col> <fld>(Math.)</fld>, <cd>any two
quantities which produce unity when multiplied together.</cd> --
<col><b>Reciprocal ratio</b></col> <fld>(Math.)</fld>, <cd>the ratio
between the reciprocals of two quantities; as, the <xex>reciprocal
ratio</xex> of 4 to 9 is that of <frac14/ to <frac19/.</cd> --
<col><b>Reciprocal terms</b></col> <fld>(Logic)</fld>, <cd>those terms
which have the same signification, and, consequently, are convertible,
and may be used for each other.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Mutual; alternate.</syn> <usage> --
<er>Reciprocal</er>, <er>Mutual</er>. The distinctive idea of
<xex>mutual</xex> is, that the parties unite by interchange in the same
act; <as>as, a <ex>mutual</ex> covenant; <ex>mutual</ex> affection,
etc.</as> The distinctive idea of <xex>reciprocal</xex> is, that one
party acts by way of return or response to something previously done by
the other party; <as>as, a <ex>reciprocal</ex> kindness;
<ex>reciprocal</ex> reproaches, etc.</as> Love is <xex>reciprocal</xex>
when the previous affection of one party has drawn forth the attachment
of the other. To make it <xex>mutual</xex> in the strictest sense, the
two parties should have fallen in love at the same time; but as the
result is the same, the two words are here used interchangeably. The
ebbing and flowing of the tide is a case where the action is
<xex>reciprocal</xex>, but not <xex>mutual</xex>.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reciprocal</ent><br/
<hw>Re*cip"ro*cal</hw>, <pos>n.</pos> <sn>1.</sn> <def>That which is
reciprocal to another thing.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Corruption is a <qex>reciprocal</qex> to generation.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Arith. & Alg.)</fld> <def>The quotient arising from
dividing unity by any quantity; thus <frac14/ is the
<xex>reciprocal</xex> of 4; <fract>1/(a + b)</fract> is the
<xex>reciprocal</xex> of <mathex>a + b</mathex>. The
<xex>reciprocal</xex> of a fraction is the fraction inverted, or the
denominator divided by the numerator.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reciprocality</ent><br/
<hw>Re*cip`ro*cal"i*ty</hw>
<pr>(r<esl/*s<icr/p`r<osl/*k<acr/l"<icr/*t<ycr/)</pr>, <pos>n.</pos>
<def>The quality or condition of being reciprocal; reciprocalness.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reciprocally</ent><br/
<hw>Re*cip"ro*cal*ly</hw>
<pr>(r<esl/*s<icr/p"r<osl/*k<ait/l*l<ycr/)</pr>, <pos>adv.</pos>
<sn>1.</sn> <def>In a reciprocal manner; so that each affects the other,
and is equally affected by it; interchangeably; mutually.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>These two particles do <qex>reciprocally</qex> affect each other
with the same force.</q> <rj><qau>Bentley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Math.)</fld> <def>In the manner of
reciprocals.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Reciprocally proportional</b></col> <fld>(Arith. &
Alg.)</fld>, <cd>proportional, as two variable quantities, so that the
one shall have a constant ratio to the reciprocal of the
other.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reciprocalness</ent><br/
<hw>Re*cip"ro*cal*ness</hw>
<pr>(r<esl/*s<icr/p"r<osl/*k<ait/l*n<ecr/s)</pr>, <pos>n.</pos> <def>The
quality or condition of being reciprocal; mutual return;
alternateness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reciprocate</ent><br/
<hw>Re*cip"ro*cate</hw> <pr>(r<esl/*s<icr/p"r<osl/*k<amac/t)</pr>,
<pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Reciprocated</conjf>
<pr>(r<esl/*s<icr/p"r<osl/*k<amac/`t<ecr/d)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Reciprocating</conjf>.]</vmorph> <ety>[L.
<ets>reciprocatus</ets>, p. p. of <ets>reciprocare</ets>. See
<er>Reciprocal</er>.]</ety> <def>To move forward and backward
alternately; to recur in vicissitude; to act interchangeably; to
alternate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>One brawny smith the puffing bellows plies,<br/
And draws and blows <qex>reciprocating</qex> air.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Reciprocating engine</b></col>, <cd>a steam, air, or gas
engine, etc., in which the piston moves back and forth; -- in
distinction from a <xex>rotary engine</xex>, in which the piston travels
continuously in one direction in a circular path.</cd> --
<col><b>Reciprocating motion</b></col> <fld>(Mech.)</fld>, <cd>motion
alternately backward and forward, or up and down, as of a piston
rod.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reciprocate</ent><br/
<hw>Re*cip"ro*cate</hw>, <pos>v. t.</pos> <def>To give and return
mutually; to make return for; to give in return; to interchange; to
alternate; <as>as, to <ex>reciprocate</ex> favors</as>.</def>
<rj><au>Cowper.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reciprocation</ent><br/
<hw>Re*cip`ro*ca"tion</hw>
<pr>(r<esl/*s<icr/p"r<osl/*k<amac/"sh<ucr/n)</pr>, <pos>n.</pos>
<ety>[L. <ets>reciprocatio</ets>: cf. F.
<ets>r<eacute/ciprocation</ets>.]</ety> <sn>1.</sn> <def>The act of
reciprocating; interchange of acts; a mutual giving and returning;
<as>as, the <ex>reciprocation</ex> of kindness</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Alternate recurrence or action; <as>as, the
<ex>reciprocation</ex> of the sea in the flow and ebb of
tides</as>.</def> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reciprocity</ent><br/
<hw>Rec`i*proc"i*ty</hw> <pr>(r<ecr/s`<icr/*pr<ocr/s"<icr/*t<ycr/)</pr>,
<pos>n.</pos> <ety>[Cf. F. <ets>r<eacute/ciprocit<eacute/</ets>. See
<er>Reciprocal</er>.]</ety> <sn>1.</sn> <def>Mutual action and
reaction.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Reciprocal advantages, obligations, or rights;
reciprocation.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Reciprocity treaty</b></col>, <or/ <col><b>Treaty
of reciprocity</b></col></mcol>, <cd>a treaty concluded between two
countries, conferring equal privileges as regards customs or charges on
imports, or in other respects.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Reciprocation; interchange; mutuality.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reciprocornous</ent><br/
<hw>Re*cip`ro*cor"nous</hw>
<pr>(r<esl/*s<icr/p`r<osl/*k<ocir/r"n<ucr/s)</pr>, <pos>a.</pos>
<ety>[L. <ets>reciprocus</ets> returning, reciprocal + <ets>cornu</ets>
horn.]</ety> <fld>(Zool.)</fld> <def>Having horns turning backward and
then forward, like those of a ram.</def> <mark>[R.]</mark>
<rj><au>Ash.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reciprocous</ent><br/
<hw>Re*cip"ro*cous</hw> <pr>(r<esl/*s<icr/p"r<osl/*k<ucr/s)</pr>,
<pos>a.</pos> <def>Reciprocal.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reciprok</ent><br/
<hw>Rec"i*prok</hw> <pr>(r<ecr/s"<icr/*pr<ocr/k)</pr>, <pos>a.</pos>
<ety>[F. <ets>r<eacute/ciproque</ets>, L. <ets>reciprocus</ets>.]</ety>
<def>Reciprocal.</def> <mark>[Obs.]</mark> <rj><au>B.
Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reciproque</ent><br/
<hw>Rec"i*proque</hw> <pr>(r<ecr/s"<icr/*pr<omac/k)</pr>, <pos>a. &
n.</pos> <ety>[F. <ets>r<eacute/ciproque</ets>.]</ety>
<def>Reciprocal.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recision</ent><br/
<hw>Re*ci"sion</hw> <pr>(r<esl/*s<icr/zh"<ucr/n)</pr>, <pos>n.</pos>
<ety>[L. <ets>recisio</ets>, fr. <ets>recidere</ets>,
<ets>recisum</ets>, to cut off; pref. <ets>re-</ets> re- +
<ets>caedere</ets> to cut.]</ety> <def>The act of cutting off.</def>
<rj><au>Sherwood.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recital</ent><br/
<hw>Re*cit"al</hw> <pr>(r<esl/*s<imac/t"<ait/l)</pr>, <pos>n.</pos>
<ety>[From <er>Recite</er>.]</ety> <sn>1.</sn> <def>The act of reciting;
the repetition of the words of another, or of a document; rehearsal;
<as>as, the <ex>recital</ex> of testimony</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A telling in detail and due order of the particulars
of anything, as of a law, an adventure, or a series of events;
narration.</def> <rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which is recited; a story; a
narration.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Mus.)</fld> <def>A vocal or instrumental
performance by one person; -- distinguished from <xex>concert</xex>;
<as>as, a song <ex>recital</ex>; an organ, piano, or violin
<ex>recital</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Law)</fld> <def>The formal statement, or setting
forth, of some matter of fact in any deed or writing in order to explain
the reasons on which the transaction is founded; the statement of matter
in pleading introductory to some positive allegation.</def>
<rj><au>Burn.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Account; rehearsal; recitation; narration;
description; explanation; enumeration; detail; narrative. See
<er>Account</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recitation</ent><br/
<hw>Rec`i*ta"tion</hw> <pr>(r<ecr/s`<icr/*t<amac/"sh<ucr/n)</pr>,
<pos>n.</pos> <ety>[L. <ets>recitatio</ets>: cf. F.
<ets>r<eacute/citation</ets>. See <er>Recite</er>.]</ety> <sn>1.</sn>
<def>The act of reciting; rehearsal; repetition of words or
sentences.</def> <rj><au>Hammond.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The delivery before an audience of something
committed to memory, especially as an elocutionary exhibition; also,
that which is so delivered.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Colleges and Schools)</fld> <def>The rehearsal of a
lesson by pupils before their instructor.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recitative</ent><br/
<hw>Rec`i*ta*tive"</hw> <pr>(r<ecr/s`<icr/*t<adot/*t<emac/v")</pr>,
<pos>n.</pos> <ety>[It. <ets>recitativo</ets>, or F.
<ets>r<eacute/citatif</ets>. See <er>Recite</er>.]</ety>
<fld>(Mus.)</fld> <def>A species of musical recitation in which the
words are delivered in a manner resembling that of ordinary declamation;
also, a piece of music intended for such recitation; -- opposed to
<contr>melisma</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recitative</ent><br/
<hw>Rec`i*ta*tive"</hw>, <pos>a.</pos> <def>Of or pertaining to
recitation; intended for musical recitation or declamation; in the style
or manner of recitative.</def> -- <wordforms><wf>Rec`i*ta*tive"ly</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recitativo</ent><br/
\'d8<hw>Rec`i*ta*ti"vo</hw>
<pr>(r<ecr/s`<icr/*t<adot/*t<emac/"v<osl/)</pr>, <pos>n.</pos>
<ety>[It.]</ety> <fld>(Mus.)</fld> <def>Recitative.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recite</ent><br/
<hw>Re*cite"</hw> <pr>(r<esl/*s<imac/t")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Recited</conjf>; <pos>p. pr. &
vb. n.</pos> <conjf>Reciting</conjf>.]</vmorph> <ety>[F.
<ets>r<eacute/citer</ets>, fr. L. <ets>recitare</ets>,
<ets>recitatum</ets>; pref. <ets>re-</ets> re- + <ets>citare</ets> to
call or name, to cite. See <er>Cite</er>.]</ety> <sn>1.</sn> <def>To
repeat, as something already prepared, written down, committed to
memory, or the like; to deliver from a written or printed document, or
from recollection; to rehearse; <as>as, to <ex>recite</ex> the words of
an author, or of a deed or covenant</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To tell over; to go over in particulars; to relate;
to narrate; <as>as, to <ex>recite</ex> past events; to <ex>recite</ex>
the particulars of a voyage.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To rehearse, as a lesson to an instructor.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Law)</fld> <def>To state in or as a recital. See
<er>Recital</er>, 5.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To rehearse; narrate; relate; recount; describe;
recapitulate; detail; number; count.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recite</ent><br/
<hw>Re*cite"</hw>, <pos>v. i.</pos> <def>To repeat, pronounce, or
rehearse, as before an audience, something prepared or committed to
memory; to rehearse a lesson learned.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recite</ent><br/
<hw>Re*cite"</hw>, <pos>n.</pos> <def>A recital.</def>
<mark>[Obs.]</mark> <rj><au>Sir W. Temple.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reciter</ent><br/
<hw>Re*cit"er</hw> <pr>(r<esl/*s<imac/t"<etil/r)</pr>, <pos>n.</pos>
<def>One who recites; also, a book of extracts for recitation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reck</ent><br/
<hw>Reck</hw> <pr>(r<ecr/k)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Recked</conjf> <pr>(r<ecr/kt)</pr> (<ets>obs.
imp.</ets> <conjf>Roughte</conjf>); <pos>p. pr. & vb. n.</pos>
<conjf>Recking</conjf>.]</vmorph> <ety>[AS. <ets>reccan</ets>,
<ets>r<emac/can</ets>, to care for; akin to OS. <ets>r<omac/kian</ets>,
OHG. <ets>ruochan</ets>, G. <ets>geruhen</ets>, Icel.
<ets>r<ae/kja</ets>, also to E. <ets>reckon</ets>, <ets>rake</ets> an
implement. See <er>Rake</er>, and cf. <er>Reckon</er>.]</ety>
<sn>1.</sn> <def>To make account of; to care for; to heed; to
regard.</def> <mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>This son of mine not <qex>recking</qex> danger.</q> <rj><qau>Sir
P. Sidney.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And may you better <qex>reck</qex> the rede<br/
Than ever did the adviser.</q> <rj><qau>Burns.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To concern; -- used impersonally.</def>
<mark>[Poetic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>What <qex>recks</qex> it them?</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1199 pr=vmg --></p>

<p><ent>Reck</ent><br/
<hw>Reck</hw> <pr>(r<ecr/k)</pr>, <pos>v. i.</pos> <def>To make account;
to take heed; to care; to mind; -- often followed by
<xex>of</xex>.</def> <mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Then <qex>reck</qex> I not, when I have lost my life.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I <qex>reck</qex> not though I end my life to-day.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Of me she <qex>recks</qex> not, nor my vain desire.</q>
<rj><qau>M. Arnold.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reckless</ent><br/
<hw>Reck"less</hw>, <pos>a.</pos> <ety>[AS. <ets>reccele<aacute/s</ets>,
<ets>r<emac/cele<aacute/s</ets>.]</ety> <sn>1.</sn> <def>Inattentive to
duty; careless; neglectful; indifferent.</def>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Rashly negligent; utterly careless or
heedless.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It made the king as <qex>reckless</qex> as them diligent.</q>
<rj><qau>Sir P. Sidney.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Heedless; careless; mindless; thoughtless;
negligent; indifferent; regardless; unconcerned; inattentive; remiss;
rash.</syn><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Reck"less*ly</wf>, <pos>adv.</pos> --
<wf>Reck"less*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reckling</ent><br/
<hw>Reck"ling</hw> <pr>(r<ecr/k"l<icr/ng)</pr>, <pos>a.</pos>
<def>Needing care; weak; feeble; <as>as, a <ex>reckling</ex>
child</as>.</def> <au>H. Taylor.</au> -- <def2><pos>n.</pos> <def>A weak
child or animal.</def></def2> <rj><au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reckon</ent><br/
<hw>Reck"on</hw> <pr>(r<ecr/k"'n)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Reckoned</conjf>
<pr>(r<ecr/k"'nd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Reckoning</conjf>.]</vmorph> <ety>[OE. <ets>rekenen</ets>, AS.
<ets>gerecenian</ets> to explain; akin to D. <ets>rekenen</ets> to
reckon, G. <ets>rechnen</ets>, OHG. <ets>rehhan<omac/n</ets> (cf. Goth.
<ets>rahnjan</ets>), and to E. <ets>reck</ets>, <ets>rake</ets> an
implement; the original sense probably being, to bring together, count
together. See <er>Reck</er>, <pos>v. t.</pos>]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>To count; to enumerate; to number; also, to compute;
to calculate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The priest shall <qex>reckon</qex> to him the money according to
the years that remain.</q> <rj><qau>Lev. xxvii. 18.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I <qex>reckoned</qex> above two hundred and fifty on the outside
of the church.</q> <rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To count as in a number, rank, or series; to
estimate by rank or quality; to place by estimation; to account; to
esteem; to repute.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He was <qex>reckoned</qex> among the transgressors.</q>
<rj><qau>Luke xxii. 37.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>For him I <qex>reckon</qex> not in high estate.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To charge, attribute, or adjudge to one, as having a
certain quality or value.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Faith was <qex>reckoned</qex> to Abraham for righteousness.</q>
<rj><qau>Rom. iv. 9.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Without her eccentricities being <qex>reckoned</qex> to her for a
crime.</q> <rj><qau>Hawthorne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To conclude, as by an enumeration and balancing of
chances; hence, to think; to suppose; -- followed by an objective
clause; <as>as, I <ex>reckon</ex> he won't try that again</as>.</def>
<mark>[Prov. Eng. & Colloq. U. S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To number; enumerate; compute; calculate;
estimate; value; esteem; account; repute. See <er>Calculate</er>,
<er>Guess</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reckon</ent><br/
<hw>Reck"on</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To make an
enumeration or computation; to engage in numbering or computing.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To come to an accounting; to make up accounts; to
settle; to examine and strike the balance of debt and credit; to adjust
relations of desert or penalty.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><ldquo/Parfay,<rdquo/ sayst thou, <ldquo/sometime he
<qex>reckon</qex> shall.<rdquo/</q> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<cs><p><col><b>To reckon for</b></col>, <cd>to answer for; to pay the
account for.</cd> <ldquo/If they fail in their bounden duty, they shall
<xex>reckon for</xex> it one day.<rdquo/ <au>Bp. Sanderson.</au> --
<mcol><col><b>To reckon on</b></col> <col><b>To reckon
upon</b></col></mcol>, <cd>to count or depend on; to include as a factor
within one's considerations.</cd> -- <col><b>To reckon with</b></col>,
<sd>(a)</sd> <cd>to settle accounts or claims with; -- used literally or
figuratively.</cd> <sd>(b)</sd> <cd>to include as a factor in one's
plans or calculations; to anticipate.</cd> <sd>(c)</sd> <cd>to deal
with; to handle; <as>as, I have to <ex>reckon with</ex> raising three
children as well as doing my job</as>.</cd> <br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><q>After a long time the lord of those servants cometh, and
<qex>reckoneth with</qex> them.</q> <rj><qau>Matt. xxv.
19.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <col><b>To reckon without one's host</b></col>, <cd>to ignore in a
calculation or arrangement the person whose assent is essential; hence,
to reckon erroneously.</cd><br/
[<source>1913 Webster</source>]</p></cs>

<p><ent>Reckoner</ent><br/
<hw>Reck"on*er</hw> <pr>(r<ecr/k"'n*<etil/r)</pr>, <pos>n.</pos>
<def>One who reckons or computes; also, a book of calculations, tables,
etc., to assist in reckoning.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Reckoners</qex> without their host must reckon twice.</q>
<rj><qau>Camden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reckoning</ent><br/
<hw>Reck"on*ing</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act of one who
reckons, counts, or computes; the result of reckoning or counting;
calculation.</def> Specifically: <sd>(a)</sd> <def>An account of
time.</def> <au>Sandys.</au> <sd>(b)</sd> <def>Adjustment of claims and
accounts; settlement of obligations, liabilities, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Even <qex>reckoning</qex> makes lasting friends, and the way to
make <qex>reckonings</qex> even is to make them often.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He quitted London, never to return till the day of a terrible and
memorable <qex>reckoning</qex> had arrived.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The charge or account made by a host at an
inn.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A coin would have a nobler use than to pay a
<qex>reckoning</qex>.</q> <rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Esteem; account; estimation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>You make no further <qex>reckoning</qex> of it [beauty] than of an
outward fading benefit nature bestowed.</q> <rj><qau>Sir P.
Sidney.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Navigation)</fld> <sd>(a)</sd> <def>The calculation
of a ship's position, either from astronomical observations, or from the
record of the courses steered and distances sailed as shown by compass
and log, -- in the latter case called <stype>dead reckoning</stype> (see
under <er>Dead</er>); -- also used for <xex>dead reckoning</xex> in
contradistinction to <contr>observation</contr>.</def> <sd>(b)</sd>
<def>The position of a ship as determined by calculation.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To be out of her reckoning</b></col>, <cd>to be at a
distance from the place indicated by the reckoning; -- said of a
ship.</cd> -- <col><b>day of reckoning</b></col> <cd>the day or time
when one must pay one's debts, fulfill one's obligations, or be punished
for one's transgressions.</cd></cs><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Reclaim</ent><br/
<hw>Re*claim"</hw> <pr>(r<emac/*kl<amac/m")</pr>, <pos>v. t.</pos>
<def>To claim back; to demand the return of as a right; to attempt to
recover possession of.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A tract of land [Holland] snatched from an element perpetually
<qex>reclaiming</qex> its prior occupancy.</q> <rj><qau>W.
Coxe.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reclaim</ent><br/
<hw>Re*claim"</hw> <pr>(r<esl/*kl<amac/m")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Reclaimed</conjf>
<pr>(r<esl/*kl<amac/md")</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Reclaiming</conjf>.]</vmorph> <ety>[F.
<ets>r<eacute/clamer</ets>, L. <ets>reclamare</ets>,
<ets>reclamatum</ets>, to cry out against; pref. <ets>re-</ets> re- +
<ets>clamare</ets> to call or cry aloud. See <er>Claim</er>.]</ety>
<sn>1.</sn> <def>To call back, as a hawk to the wrist in falconry, by a
certain customary call.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To call back from flight or disorderly action; to
call to, for the purpose of subduing or quieting.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The headstrong horses hurried Octavius . . . along, and were deaf
to his <qex>reclaiming</qex> them.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To reduce from a wild to a tamed state; to bring
under discipline; -- said especially of birds trained for the chase, but
also of other animals.</def> <ldquo/An eagle well
<xex>reclaimed</xex>.<rdquo/ <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Hence: To reduce to a desired state by discipline,
labor, cultivation, or the like; to rescue from being wild, desert,
waste, submerged, or the like; <as>as, to <ex>reclaim</ex> wild land,
overflowed land, etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To call back to rectitude from moral wandering or
transgression; to draw back to correct deportment or course of life; to
reform.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It is the intention of Providence, in all the various expressions
of his goodness, to <qex>reclaim</qex> mankind.</q>
<rj><qau>Rogers.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To correct; to reform; -- said of things.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Your error, in time <qex>reclaimed</qex>, will be venial.</q>
<rj><qau>Sir E. Hoby.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>To exclaim against; to gainsay.</def>
<mark>[Obs.]</mark> <rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To reform; recover; restore; amend;
correct.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reclaim</ent><br/
<hw>Re*claim"</hw> <pr>(r<esl/*kl<amac/m")</pr>, <pos>v. i.</pos>
<sn>1.</sn> <def>To cry out in opposition or contradiction; to exclaim
against anything; to contradict; to take exceptions.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Scripture <qex>reclaims</qex>, and the whole Catholic church
<qex>reclaims</qex>, and Christian ears would not hear it.</q>
<rj><qau>Waterland.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>At a later period Grote <qex>reclaimed</qex> strongly against
Mill's setting Whately above Hamilton.</q> <rj><qau>Bain.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To bring anyone back from evil courses; to
reform.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They, hardened more by what might most <qex>reclaim</qex>,<br/
Grieving to see his glory, . . . took envy.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To draw back; to give way.</def> <mark>[R. &
Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reclaim</ent><br/
<hw>Re*claim"</hw>, <pos>n.</pos> <def>The act of reclaiming, or the
state of being reclaimed; reclamation; recovery.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reclaimable</ent><br/
<hw>Re*claim"a*ble</hw> <pr>(r<esl/*kl<amac/m"<adot/*b'l)</pr>,
<pos>a.</pos> <def>That may be reclaimed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reclaimant</ent><br/
<hw>Re*claim"ant</hw> <pr>(r<esl/*kl<amac/m"<ait/nt)</pr>, <pos>n.</pos>
<ety>[Cf. F. <ets>r<eacute/clamant</ets>, p. pr.]</ety> <def>One who
reclaims; one who cries out against or contradicts.</def>
<rj><au>Waterland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reclaimer</ent><br/
<hw>Re*claim"er</hw> <pr>(r<esl/*kl<amac/m"<etil/r)</pr>, <pos>n.</pos>
<def>One who reclaims.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reclaimless</ent><br/
<hw>Re*claim"less</hw>, <pos>a.</pos> <def>That can not be
reclaimed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reclamation</ent><br/
<hw>Rec`la*ma"tion</hw> <pr>(r<ecr/k`l<adot/*m<amac/"sh<ucr/n)</pr>,
<pos>n.</pos> <ety>[F. <ets>r<eacute/clamation</ets>, L.
<ets>reclamatio</ets>. See <er>Reclaim</er>.]</ety> <sn>1.</sn> <def>The
act or process of reclaiming.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Representation made in opposition;
remonstrance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I would now, on the <qex>reclamation</qex> both of generosity and
of justice, try clemency.</q> <rj><qau>Landor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reclasp</ent><br/
<hw>Re*clasp"</hw> <pr>(r<emac/*kl<adot/sp")</pr>, <pos>v. i.</pos>
<def>To clasp or unite again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reclinant</ent><br/
<hw>Re*clin"ant</hw> <pr>(r<esl/*kl<imac/n"<ait/nt)</pr>, <pos>a.</pos>
<ety>[L. <ets>reclinans</ets>, p. pr. See <er>Recline</er>.]</ety>
<def>Bending or leaning backward.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reclinate</ent><br/
<hw>Rec"li*nate</hw> <pr>(r<ecr/k"l<icr/*n<asl/t)</pr>, <pos>a.</pos>
<ety>[L. <ets>reclinatus</ets>, p. p.]</ety> <fld>(Bot.)</fld>
<def>Reclined, as a leaf; bent downward, so that the point, as of a stem
or leaf, is lower than the base.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reclination</ent><br/
<hw>Rec`li*na"tion</hw> <pr>(r<ecr/k`l<icr/*n<amac/"sh<ucr/n)</pr>,
<pos>n.</pos> <ety>[Cf. F. <ets>r<eacute/clinaison</ets>.]</ety>
<sn>1.</sn> <def>The act of leaning or reclining, or the state of being
reclined.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Dialing)</fld> <def>The angle which the plane of
the dial makes with a vertical plane which it intersects in a horizontal
line.</def> <rj><au>Brande & C.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Surg.)</fld> <def>The act or process of removing a
cataract, by applying the needle to its anterior surface, and depressing
it into the vitreous humor in such a way that the front surface of the
cataract becomes the upper one and its back surface the lower one.</def>
<rj><au>Dunglison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recline</ent><br/
<hw>Re*cline"</hw> <pr>(r<esl/*kl<imac/n")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Reclined</conjf>
<pr>(r<esl/*kl<imac/nd")</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Reclining</conjf>.]</vmorph> <ety>[L. <ets>reclinare</ets>; pref.
<ets>re-</ets> re- + <ets>clinare</ets> to lean, incline. See
<er>Incline</er>, <er>Lean</er> to incline.]</ety> <def>To cause or
permit to lean, incline, rest, etc.; to place in a recumbent position;
<as>as, to <ex>recline</ex> the head on the hand</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The mother<br/
<qex>Reclined</qex> her dying head upon his breast.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recline</ent><br/
<hw>Re*cline"</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To lean or
incline; <as>as, to <ex>recline</ex> against a wall</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To assume, or to be in, a recumbent position;
<as>as, to <ex>recline</ex> on a couch</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recline</ent><br/
<hw>Re*cline"</hw>, <pos>a.</pos> <ety>[L. <ets>reclinis</ets>. See
<er>Recline</er>, <pos>v. t.</pos>]</ety> <def>Having a reclining
posture; leaning; reclining.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>They sat, <qex>recline</qex><br/
On the soft downy bank, damasked with flowers.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reclined</ent><br/
<hw>Re*clined"</hw> <pr>(r<esl/*kl<imac/nd")</pr>, <pos>a.</pos>
<fld>(Bot.)</fld> <def>Falling or turned downward; reclinate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recliner</ent><br/
<hw>Re*clin"er</hw> <pr>(r<esl/*kl<imac/n"<etil/r)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>One who, or that which, reclines.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <specif>Specifically:</specif> <def>An armchair with a
back that can be adjusted to lean backward, and a footrest that can be
moved up to support the legs, or folded under the chair when the person
is sitting up; the back and footrest are often geared so that they move
together, allowing the chair to be conveniently adjusted either for
sitting up or for lying back; also called a <altname>reclining
chair</altname>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Reclining</ent><br/
<hw>Re*clin"ing</hw>, <pos>a.</pos> <fld>(Bot.)</fld> <sd>(a)</sd>
<def>Bending or curving gradually back from the perpendicular.</def>
<sd>(b)</sd> <def>Recumbent.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Reclining dial</b></col>, <cd>a dial whose plane is
inclined to the vertical line through its center. <au>Davies & Peck</au>
<fld>(Math. Dict.)</fld>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reclose</ent><br/
<hw>Re*close"</hw> <pr>(r<emac/*kl<omac/z")</pr>, <pos>v. t.</pos>
<def>To close again.</def> <rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reclothe</ent><br/
<hw>Re*clothe"</hw> <pr>(r<emac/*kl<omac/th")</pr>, <pos>v. t.</pos>
<def>To clothe again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reclude</ent><br/
<hw>Re*clude"</hw> <pr>(r<esl/*kl<umac/d")</pr>, <pos>v. t.</pos>
<ety>[L. <ets>recludere</ets> to unclose, open; pref. <ets>re-</ets>
again, back, un- + <ets>claudere</ets> to shut.]</ety> <def>To open; to
unclose.</def> <mark>[R.]</mark> <rj><au>Harvey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recluse</ent><br/
<hw>Re*cluse"</hw> <pr>(r<esl/*kl<umac/s")</pr>, <pos>a.</pos> <ety>[F.
<ets>reclus</ets>, L. <ets>reclusus</ets>, from <ets>recludere</ets>,
<ets>reclusum</ets>, to unclose, open, in LL., to shut up. See
<er>Close</er>.]</ety> <def>Shut up, sequestered; retired from the world
or from public notice; solitary; living apart; <as>as, a
<ex>recluse</ex> monk or hermit; a <ex>recluse</ex> life</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>In meditation deep, <qex>recluse</qex><br/
From human converse.</q> <rj><qau>J. Philips.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recluse</ent><br/
<hw>Re*cluse"</hw>, <pos>n.</pos> <ety>[F. <ets>reclus</ets>, LL.
<ets>reclusus</ets>. See <er>Recluse</er>, <pos>a.</pos>]</ety>
<sn>1.</sn> <def>A person who lives in seclusion from intercourse with
the world, as a hermit or monk; specifically, one of a class of secluded
devotees who live in single cells, usually attached to
monasteries.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The place where a recluse dwells.</def>
<mark>[Obs.]</mark> <rj><au>Foxe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recluse</ent><br/
<hw>Re*cluse"</hw>, <pos>v. t.</pos> <def>To shut up; to seclude.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reclusely</ent><br/
<hw>Re*cluse"ly</hw>, <pos>adv.</pos> <def>In a recluse or solitary
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recluseness</ent><br/
<hw>Re*cluse"ness</hw>, <pos>n.</pos> <def>Quality or state of being
recluse.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reclusion</ent><br/
<hw>Re*clu"sion</hw> <pr>(r<esl/*kl<umac/"zh<ucr/n)</pr>, <pos>n.</pos>
<ety>[LL. <ets>reclusio</ets>: cf. F. <ets>reclusion</ets>.]</ety>
<def>A state of retirement from the world; seclusion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reclusive</ent><br/
<hw>Re*clu"sive</hw> <pr>(r<esl/*kl<umac/"s<icr/v)</pr>, <pos>a.</pos>
<sn>1.</sn> <def>Affording retirement from society.</def> <ldquo/Some
<xex>reclusive</xex> and religious life.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Disposed to avoid the company of other people;
living like a recluse{1}; not sociable; -- of people.</def><br/
[<source>PJC</source>]</p>

<p><ent>Reclusory</ent><br/
<hw>Re*clu"so*ry</hw> <pr>(r<esl/*kl<umac/"s<osl/*r<ycr/)</pr>,
<pos>n.</pos> <ety>[LL. <ets>reclusorium</ets>.]</ety> <def>The
habitation of a recluse; a hermitage.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recoct</ent><br/
<hw>Re*coct"</hw> <pr>(r<esl/*k<ocr/kt")</pr>, <pos>v. t.</pos> <ety>[L.
<ets>recoctus</ets>, p. p. of <ets>recoquere</ets> to cook or boil over
again. See <er>Re-</er>, and 4th <er>Cook</er>.]</ety> <def>To boil or
cook again; hence, to make over; to vamp up; to reconstruct.</def>
<mark>[Obs.]</mark> <rj><au>Jer. Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recoction</ent><br/
<hw>Re*coc"tion</hw> <pr>(r<esl/*k<ocr/k"sh<ucr/n)</pr>, <pos>n.</pos>
<def>A second coction or preparation; a vamping up.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recognition</ent><br/
<hw>Rec`og*ni"tion</hw> <pr>(r<ecr/k`<ocr/g*n<icr/sh"<ucr/n)</pr>,
<pos>n.</pos> <ety>[L. <ets>recognitio</ets>: cf. F.
<ets>recognition</ets>. See <er>Recognizance</er>.]</ety> <def>The act
of recognizing, or the state of being recognized; acknowledgment; formal
avowal; knowledge confessed or avowed; notice.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The lives of such saints had, at the time of their yearly
memorials, solemn <qex>recognition</qex> in the church of God.</q>
<rj><qau>Hooker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recognitor</ent><br/
<hw>Re*cog"ni*tor</hw> <pr>(r<esl/*k<ocr/g"n<icr/*t<etil/r)</pr>,
<pos>n.</pos> <ety>[LL.]</ety> <fld>(Law)</fld> <def>One of a jury
impaneled on an assize.</def> <rj><au>Blackstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recognitory</ent><br/
<hw>Re*cog"ni*to*ry</hw> <pr>(r<esl/*k<ocr/g"n<icr/*t<osl/*r<ycr/)</pr>,
<pos>a.</pos> <def>Pertaining to, or connected with, recognition.</def>
<rj><au>Lamb.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recognizability</ent><br/
<hw>Rec`og*ni`za*bil"i*ty</hw>
<pr>(r<ecr/k`<ocr/g*n<imac/`z<adot/*b<icr/l"<icr/*t<ycr/)</pr>,
<pos>n.</pos> <def>The quality or condition of being
recognizable.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recognizable</ent><br/
<hw>Rec"og*ni`za*ble</hw> <pr>(r<ecr/k"<ocr/g*n<imac/`z<adot/*b'l <or/
r<esl/*k<ocr/g"n<icr/*z<adot/*b'l; 277)</pr>, <pos>a.</pos> <def>Capable
of being recognized.</def> <altsp>[Written also
<asp>recognisable</asp>.]</altsp> --
<wordforms><wf>Rec"og*ni`za*bly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recognizance</ent><br/
<hw>Re*cog"ni*zance</hw> <pr>(r<esl/*k<ocr/g"n<icr/*z<ait/ns <or/
r<esl/*k<ocr/n"<icr/-)</pr>, <pos>n.</pos> <ety>[F.
<ets>reconnaissance</ets>, OF. <ets>recognoissance</ets>, fr.
<ets>recognoissant</ets>, p. pr. of <ets>recognoistre</ets> to
recognize, F. <ets>reconna<icir/tre</ets>, fr. L.
<ets>recognoscere</ets>; pref. <ets>re-</ets> re- +
<ets>cognoscere</ets> to know. See <er>Cognizance</er>, <er>Know</er>,
and cf. <er>Recognize</er>, <er>Reconnoissance</er>.]</ety>
<altsp>[Written also <asp>recognisance</asp>.]</altsp> <sn>1.</sn>
<fld>(Law)</fld> <sd>(a)</sd> <def>An obligation of record entered into
before some court of record or magistrate duly authorized, with
condition to do some particular act, as to appear at the same or some
other court, to keep the peace, or pay a debt. A <ex>recognizance</ex>
differs from a <xex>bond</xex>, being witnessed by the record only, and
not by the party's seal.</def> <sd>(b)</sd> <def>The verdict of a jury
impaneled upon assize.</def> <rj><au>Cowell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Among lawyers the <xex>g</xex> in this and the related
words (except <xex>recognize</xex>) is usually silent.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A token; a symbol; a pledge; a badge.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That <qex>recognizance</qex> and pledge of love<br/
Which I first gave her.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Acknowledgment of a person or thing; avowal;
profession; recognition.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recognization</ent><br/
<hw>Re*cog`ni*za"tion</hw>
<pr>(r<esl/*k<ocr/g"n<icr/*z<amac/"sh<ucr/n)</pr>, <pos>n.</pos>
<def>Recognition.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recognize</ent><br/
<hw>Rec"og*nize</hw> <pr>(r<ecr/k"<ocr/g*n<imac/z)</pr>, <pos>v.
t.</pos> <vmorph>[<pos>imp. & p. p.</pos> <conjf>Recognized</conjf>
<pr>(r<ecr/k"<ocr/g*n<imac/zd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Recognizing</conjf>
<pr>(r<ecr/k"<ocr/g*n<imac/`z<icr/ng)</pr>.]</vmorph> <ety>[From
<er>Recognizance</er>; see <er>Cognition</er>, and cf.
<er>Reconnoiter</er>.]</ety> <altsp>[Written also
<asp>recognise</asp>.]</altsp> <sn>1.</sn> <def>To know again; to
perceive the identity of, with a person or thing previously known; to
recover or recall knowledge of.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Speak, vassal; <qex>recognize</qex> thy sovereign queen.</q>
<rj><qau>Harte.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To avow knowledge of; to allow that one knows; to
consent to admit, hold, or the like; to admit with a formal
acknowledgment; <as>as, to <ex>recognize</ex> an obligation; to
<ex>recognize</ex> a consul.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To acknowledge acquaintance with, as by salutation,
bowing, or the like.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To show appreciation of; <as>as, to
<ex>recognize</ex> services by a testimonial</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To review; to reexamine.</def> <mark>[Obs.]</mark>
<rj><au>South.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To reconnoiter.</def> <mark>[Obs.]</mark> <rj><au>R.
Monro.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To acknowledge; avow; confess; own; allow;
concede. See <er>Acknowledge</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recognize</ent><br/
<hw>Rec"og*nize</hw>, <pos>v. i.</pos> <fld>(Law)</fld> <def>To enter an
obligation of record before a proper tribunal; <as>as, A B
<ex>recognized</ex> in the sum of twenty dollars</as>.</def>
<altsp>[Written also <asp>recognise</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In legal usage in the United States the second syllable
is often accented.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recognizee</ent><br/
<hw>Re*cog`ni*zee"</hw> <pr>(r<esl/*k<ocr/g`n<icr/*z<emac/" <or/
r<esl/*k<ocr/n`<icr/*z<emac/")</pr>, <pos>n.</pos> <fld>(Law)</fld>
<def>The person in whose favor a recognizance is made.</def>
<altsp>[Written also <asp>recognisee</asp>.]</altsp>
<rj><au>Blackstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recognizer</ent><br/
<hw>Rec"og*ni`zer</hw> <pr>(r<ecr/k"<ocr/g*n<imac/`z<etil/r)</pr>,
<pos>n.</pos> <def>One who recognizes; a recognizor.</def>
<altsp>[Written also <asp>recogniser</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recognizor</ent><br/
<hw>Re*cog`ni*zor"</hw> <pr>(r<esl/*k<ocr/g`n<icr/*z<ocir/r" <or/
r<esl/*k<ocr/n`<icr/*z<ocir/r")</pr>, <pos>n.</pos> <fld>(Law)</fld>
<def>One who enters into a recognizance.</def> <altsp>[Written also
<asp>recognisor</asp>.]</altsp> <rj><au>Blackstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recognosce</ent><br/
<hw>Rec"og*nosce</hw> <pr>(r<ecr/k"<ocr/g*n<ocr/s)</pr>, <pos>v.
t.</pos> <ety>[L. <ets>recognoscere</ets>. See
<er>Recognizance</er>.]</ety> <def>To recognize.</def> <mark>[R. &
Obs.]</mark> <rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recoil</ent><br/
<hw>Re*coil"</hw> <pr>(r<esl/*koil")</pr>, <pos>v. i.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Recoiled</conjf>
<pr>(r<esl/*koild")</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Recoiling</conjf>.]</vmorph> <ety>[OE. <ets>recoilen</ets>, F.
<ets>reculer</ets>, fr. L. pref. <ets>re-</ets> re- + <ets>culus</ets>
the fundament. The English word was perhaps influenced in form by
<ets>accoil</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>To start, roll, bound, spring, or fall back; to take
a reverse motion; to be driven or forced backward; to return.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Evil on itself shall back <qex>recoil</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The solemnity of her demeanor made it impossible . . . that we
should <qex>recoil</qex> into our ordinary spirits.</q> <rj><qau>De
Quincey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To draw back, as from anything repugnant,
distressing, alarming, or the like; to shrink.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To turn or go back; to withdraw one's self; to
retire.</def> <mark>[Obs.]</mark> <ldquo/To your bowers
<xex>recoil</xex>.<rdquo/ <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recoil</ent><br/
<hw>Re*coil"</hw> <pr>(r<esl/*koil")</pr>, <pos>v. t.</pos> <def>To draw
or go back.</def> <mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recoil</ent><br/
<hw>Re*coil"</hw>, <pos>n.</pos> <sn>1.</sn> <def>A starting or falling
back; a rebound; a shrinking; <as>as, the <ex>recoil</ex> of nature, or
of the blood</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The state or condition of having recoiled.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>recoil</qex> from formalism is skepticism.</q>
<rj><qau>F. W. Robertson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Specifically, the reaction or rebounding of a
firearm when discharged.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Recoil dynamometer</b></col> <fld>(Gunnery)</fld>, <cd>an
instrument for measuring the force of the recoil of a firearm.</cd> --
<col><b>Recoil escapement</b></col>. <cd>See the Note under
<er>Escapement</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recoiler</ent><br/
<hw>Re*coil"er</hw> <pr>(r<esl/*koil"<etil/r)</pr>, <pos>n.</pos>
<def>One who, or that which, recoils.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recoilingly</ent><br/
<hw>Re*coil"ing*ly</hw>, <pos>adv.</pos> <def>In the manner of a
recoil.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recoilment</ent><br/
<hw>Re*coil"ment</hw>, <pos>n.</pos> <ety>[Cf. F.
<ets>reculement</ets>.]</ety> <def>Recoil.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recoin</ent><br/
<hw>Re*coin"</hw> <pr>(r<emac/*koin")</pr>, <pos>v. t.</pos> <def>To
coin anew or again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recoinage</ent><br/
<hw>Re*coin"age</hw> <pr>(r<emac/*koin"<asl/j)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>The act of coining anew.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is coined anew.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Re-collect</ent><br/
<hw>Re`-col*lect"</hw> <pr>(r<emac/`k<ocr/l*l<ecr/kt")</pr>, <pos>v.
t.</pos> <ety>[Pref. <ets>re-</ets> + <ets>collect</ets>.]</ety> <def>To
collect again; to gather what has been scattered; <as>as, to
<ex>re-collect</ex> routed troops</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>God will one day raise the dead, <qex>re-collecting</qex> our
scattered dust.</q> <rj><qau>Barrow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recollect</ent><br/
<hw>Rec`ol*lect"</hw> <pr>(r<ecr/k`<ocr/l*l<ecr/kt")</pr>, <pos>v.
t.</pos> <vmorph>[<pos>imp. & p. p.</pos> <conjf>Recollected</conjf>;
<pos>p. pr. & vb. n.</pos> <conjf>Recollecting</conjf>.]</vmorph>
<ety>[Pref. <ets>re-</ets> + <ets>collect</ets>: cf. L.
<ets>recolligere</ets>, <ets>recollectum</ets>, to collect. Cf.
<er>Recollet</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>To recover or recall the knowledge of; to bring back
to the mind or memory; to remember.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Reflexively, to compose one's self; to recover
self-command; <as>as, to <ex>recollect</ex> one's self after a burst of
anger</as>; -- sometimes, formerly, in the perfect participle.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The Tyrian queen . . . <br/
Admired his fortunes, more admired the man;<br/
Then <qex>recollected</qex> stood.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recollect</ent><br/
<hw>Rec"ol*lect</hw> <pr>(r<ecr/k"<ocr/l*l<ecr/kt)</pr>, <pos>n.</pos>
<ety>[See <er>Recollet</er>.]</ety> <fld>(Eccl.)</fld> <def>A friar of
the Strict Observance, -- an order of Franciscans.</def> <altsp>[Written
also <asp>Recollet</asp>.]</altsp> <rj><au>Addis & Arnold.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1200 --></p>

<p><ent>Recollection</ent><br/
<hw>Rec`ol*lec"tion</hw> <pr>(r?k`?l*l?k"sh?n)</pr>, <pos>n.</pos>
<ety>[Cf. F. <ets>r<eacute/collection</ets>.]</ety> <sn>1.</sn> <def>The
act of recollecting, or recalling to the memory; the operation by which
objects are recalled to the memory, or ideas revived in the mind;
reminiscence; remembrance.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The power of recalling ideas to the mind, or the
period within which things can be recollected; remembrance; memory;
<as>as, an event within my <ex>recollection</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which is recollected; something called to mind;
reminiscence.</def> <ldquo/One of his earliest
<xex>recollections</xex>.<rdquo/ <rj><au>Macaulay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The act or practice of collecting or concentrating
the mind; concentration; self-control.</def> <mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>From such an education Charles contracted habits of gravity and
<qex>recollection</qex>.</q> <rj><qau>Robertson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Reminiscence; remembrance. See
<er>Memory</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recollective</ent><br/
<hw>Rec`ol*lect"ive</hw> <pr>(-l?k"t?v)</pr>, <pos>a.</pos> <def>Having
the power of recollecting.</def> <rj><au>J. Foster.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recollet</ent><br/
<hw>Rec"ol*let</hw> <pr>(r?k"?l*l?t; F. r?`k?`l?")</pr>, <pos>n.</pos>
<ety>[F. <ets>r<eacute/collet</ets>, fr. L. <ets>recollectus</ets>, p.
p. of <ets>recolligere</ets> to gather again, to gather up; NL., to
collect one's self, esp. for religious contemplation.]</ety>
<fld>(Eccl.)</fld> <def>Same as <er>Recollect</er>,
<pos>n.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recolonization</ent><br/
<hw>Re*col`o*ni*za"tion</hw> <pr>(r?*k?l`?*n?*z?"sh?n)</pr>,
<pos>n.</pos> <def>A second or renewed colonization.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recolonize</ent><br/
<hw>Re*col"o*nize</hw> <pr>(r?*k?l"?*n?z)</pr>, <pos>v. t.</pos> <def>To
colonize again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recombination</ent><br/
<hw>Re*com`bi*na"tion</hw> <pr>(r?*k?m`b?*n?"sh?n)</pr>, <pos>n.</pos>
<def>Combination a second or additional time.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recombine</ent><br/
<hw>Re`com*bine"</hw> <pr>(r?`k?m*b?n")</pr>, <pos>v. t.</pos> <def>To
combine again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recomfort</ent><br/
<hw>Re*com"fort</hw> <pr>(r?*k?m"f?rt)</pr>, <pos>v. t.</pos>
<ety>[Pref. <ets>re-</ets> + <ets>comfort</ets>: cf. F.
<ets>r<eacute/conforter</ets>.]</ety> <def>To comfort again; to console
anew; to give new strength to.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Gan her <qex>recomfort</qex> from so sad affright.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recomfortless</ent><br/
<hw>Re*com"fort*less</hw>, <pos>a.</pos> <def>Without comfort.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recomforture</ent><br/
<hw>Re*com"for*ture</hw> <pr>(-f?r*t?r;135)</pr>, <pos>n.</pos> <def>The
act of recomforting; restoration of comfort.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recommence</ent><br/
<hw>Re`com*mence"</hw> <pr>(r?`k?m*m?ns")</pr>, <pos>v. i.</pos>
<sn>1.</sn> <def>To commence or begin again.</def>
<rj><au>Howell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To begin anew to be; to act again as.</def>
<mark>[Archaic.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He seems desirous enough of <qex>recommencing</qex> courtier.</q>
<rj><qau>Johnson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recommence</ent><br/
<hw>Re`com*mence"</hw>, <pos>v. t.</pos> <ety>[Pref. <ets>re-</ets> +
<ets>commence</ets>: cf. F. <ets>recommencer</ets>.]</ety> <def>To
commence again or anew.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recommencement</ent><br/
<hw>Re`com*mence"ment</hw> <pr>(-m<eit/nt)</pr>, <pos>n.</pos> <def>A
commencement made anew.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recommend</ent><br/
<hw>Rec`om*mend"</hw> <pr>(r?k`?m*m?nd")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Recommended</conjf>; <pos>p. pr.
& vb. n.</pos> <conjf>Recommending</conjf>.]</vmorph> <ety>[Pref.
<ets>re-</ets> + <ets>commend</ets>: cf. F.
<ets>recommander</ets>.]</ety> <sn>1.</sn> <def>To commend to the
favorable notice of another; to commit to another's care, confidence, or
acceptance, with favoring representations; to put in a favorable light
before any one; to bestow commendation on; <as>as, he
<ex>recommended</ex> resting the mind and exercising the
body</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Maecenas <qex>recommended</qex> Virgil and Horace to Augustus,
whose praises . . . have made him precious to posterity.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To make acceptable; to attract favor to.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A decent boldness ever meets with friends,<br/
Succeeds, and e'en a stranger <qex>recommends</qex>.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To commit; to give in charge; to commend.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Paul chose Silas and departed, being <qex>recommended</qex> by the
brethren unto the grace of God.</q> <rj><qau>Acts xv. 40.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recommendable</ent><br/
<hw>Rec`om*mend"a*ble</hw> <pr>(-?*b'l)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>recommandable</ets>.]</ety> <def>Suitable to be recommended; worthy
of praise; commendable.</def> <au>Glanvill.</au> --
<wordforms><wf>Rec`om*mend"a*ble*ness</wf>, <pos>n.</pos> --
<wf>Rec`om*mend"a*bly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recommendation</ent><br/
<hw>Rec`om*men*da"tion</hw> <pr>(r?k`?m*m?n*d?"sh?n)</pr>, <pos>n.</pos>
<ety>[Cf. F. <ets>recommandation</ets>.]</ety> <sn>1.</sn> <def>The act
of recommending.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which recommends, or commends to favor;
anything procuring, or tending to procure, a favorable reception, or to
secure acceptance and adoption; <as>as, he brought excellent
<ex>recommendations</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The state of being recommended; esteem.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The burying of the dead . . . hath always been had in an
extraordinary <qex>recommendation</qex> amongst the ancient.</q>
<rj><qau>Sir T. North.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recommendative</ent><br/
<hw>Rec`om*mend"a*tive</hw> <pr>(-m?nd"?*t?v)</pr>, <pos>n.</pos>
<def>That which recommends; a recommendation.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recommendatory</ent><br/
<hw>Rec`om*mend"a*to*ry</hw> <pr>(-?*t?*r?)</pr>, <pos>a.</pos>
<def>Serving to recommend; recommending; commendatory.</def>
<rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recommender</ent><br/
<hw>Rec`om*mend"er</hw> <pr>(-?r)</pr>, <pos>n.</pos> <def>One who
recommends.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recommission</ent><br/
<hw>Re`com*mis"sion</hw> <pr>(r?`k?m*m?sh?n)</pr>, <pos>v. t.</pos>
<def>To commission again; to give a new commission to.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Officers whose time of service had expired were to be
<qex>recommissioned</qex>.</q> <rj><qau>Marshall.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recommit</ent><br/
<hw>Re`com*mit"</hw> <pr>(-m?t")</pr>, <pos>v. t.</pos> <def>To commit
again; to give back into keeping; specifically, to refer again to a
committee; <as>as, to <ex>recommit</ex> a bill to the same
committee</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recommittal</ent><br/
<ent>Recommitment</ent><br/
<mhw>{ <hw>Re`com*mit"ment</hw> <pr>(-m<eit/nt)</pr>,
<hw>Re`com*mit"tal</hw> <pr>(-?l)</pr>, }</mhw> <pos>n.</pos> <def>A
second or renewed commitment; a renewed reference to a
committee.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recompact</ent><br/
<hw>Re`com*pact"</hw> <pr>(-p?kt")</pr>, <pos>v. t.</pos> <def>To
compact or join anew.</def> <ldquo/<xex>Recompact</xex> my scattered
body.<rdquo/ <rj><au>Donne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recompensation</ent><br/
<hw>Re*com`pen*sa"tion</hw> <pr>(r?*k?m`p?n*s?"sh?n)</pr>, <pos>n.</pos>
<ety>[Cf. LL. <ets>recompensatio</ets>.]</ety> <sn>1.</sn>
<def>Recompense.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Scots Law)</fld> <def>Used to denote a case where a
set-off pleaded by the defendant is met by a set-off pleaded by the
plaintiff.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recompense</ent><br/
<hw>Rec"om*pense</hw> <pr>(r<ecr/k"<ocr/m*p<ecr/ns)</pr>, <pos>v.
t.</pos> <vmorph>[<pos>imp. & p. p.</pos> <conjf>Recompensed</conjf>
<pr>(-p?nst)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Recompensing</conjf> <pr>(-p?n`s?ng)</pr>.]</vmorph> <ety>[F.
<ets>r<eacute/compenser</ets>, LL. <ets>recompensare</ets>, fr.L. pref.
<ets>re-</ets> re- + <ets>compensare</ets> to compensate. See
<er>Compensate</er>.]</ety> <sn>1.</sn> <def>To render an equivalent to,
for service, loss, etc.; to requite; to remunerate; to
compensate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He can not <qex>recompense</qex> me better.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To return an equivalent for; to give compensation
for; to atone for; to pay for.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>God <qex>recompenseth</qex> the gift.</q> <rj><qau>Robynson
(More's Utopia).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>recompense</qex><br/
My rash, but more unfortunate, misdeed.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To give in return; to pay back; to pay, as something
earned or deserved.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Recompense</qex> to no man evil for evil.</q> <rj><qau>Rom.
xii. 17.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To repay; requite; compensate; reward;
remunerate.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recompense</ent><br/
<hw>Rec"om*pense</hw> <pr>(r?k"?m*p?ns)</pr>, <pos>v. i.</pos> <def>To
give recompense; to make amends or requital.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recompense</ent><br/
<hw>Rec"om*pense</hw>, <pos>n.</pos> <ety>[Cf. F.
<ets>r<eacute/compense</ets>.]</ety> <def>An equivalent returned for
anything done, suffered, or given; compensation; requital; suitable
return.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To me belongeth vengeance, and <qex>recompense</qex>.</q>
<rj><qau>Deut. xxii. 35.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And every transgression and disobedience received a just
<qex>recompense</qex> of reward.</q> <rj><qau>Heb. ii. 2.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Repayment; compensation; remuneration; amends;
satisfaction; reward; requital.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recompensement</ent><br/
<hw>Rec"om*pense`ment</hw> <pr>(-p?ns`m?nt)</pr>, <pos>n.</pos>
<def>Recompense; requital.</def> <mark>[Obs.]</mark>
<rj><au>Fabyan.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recompenser</ent><br/
<hw>Rec"om*pen`ser</hw> <pr>(-p?n`s?r)</pr>, <pos>n.</pos> <def>One who
recompenses.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A thankful <qex>recompenser</qex> of the benefits received.</q>
<rj><qau>Foxe.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recompensive</ent><br/
<hw>Rec"om*pen`sive</hw> <pr>(-s?v)</pr>, <pos>a.</pos> <def>Of the
nature of recompense; serving to recompense.</def> <rj><au>Sir T.
Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recompilation</ent><br/
<hw>Re*com`pi*la"tion</hw> <pr>(r?*k?m`p?*l?"tion)</pr>, <pos>n.</pos>
<def>A new compilation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recompile</ent><br/
<hw>Re`com*pile"</hw> <pr>(r<emac/`k<ocr/m*p<imac/l")</pr>, <pos>v.
t.</pos> <def>To compile anew.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recompilement</ent><br/
<hw>Re`com*pile"ment</hw> <pr>(-m<eit/nt)</pr>, <pos>n.</pos> <def>The
act of recompiling; new compilation or digest; <as>as, a
<ex>recompilement</ex> of the laws</as>.</def>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recompose</ent><br/
<hw>Re`com*pose"</hw> <pr>(-p?z")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Recomposed</conjf>
<pr>(-p?zd")</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Recomposing</conjf>.]</vmorph> <ety>[Pref. <ets>re-</ets> +
<ets>compose</ets>: cf. F. <ets>recomposer</ets>.]</ety> <sn>1.</sn>
<def>To compose again; to form anew; to put together again or
repeatedly.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The far greater number of the objects presented to our observation
can only be decomposed, but not actually <qex>recomposed</qex>.</q>
<rj><qau>Sir W. Hamilton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To restore to composure; to quiet anew; to
tranquilize; <as>as, to <ex>recompose</ex> the mind</as>.</def>
<rj><au>Jer. Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recomposer</ent><br/
<hw>Re`com*pos"er</hw> <pr>(-p?z"?r)</pr>, <pos>n.</pos> <def>One who
recomposes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recomposition</ent><br/
<hw>Re*com`po*si"tion</hw> <pr>(r?*k?m`p?z?sh?n)</pr>, <pos>n.</pos>
<ety>[Cf. F. <ets>recomposition</ets>.]</ety> <def>The act of
recomposing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reconcentrado</ent><br/
\'d8<hw>Re*con`cen*tra"do</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sp.,
p.p. of <ets>reconcentrar</ets> to inclose, to reconcentrate.]</ety>
<def>Lit., one who has been reconcentrated; specif., in Cuba, the
Philippines, etc., during the revolution of 1895-98, one of the rural
noncombatants who were concentrated by the military authorities in areas
surrounding the fortified towns, and later were reconcentrated in the
smaller limits of the towns themselves.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Reconcentrate</ent><br/
<hw>Re`con*cen"trate</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <def>To
concentrate again; to concentrate thoroughly.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Reconcentration</ent><br/
<hw>Re*con`cen*tra"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
reconcentrating or the state of being reconcentrated; esp., the act or
policy of concentrating the rural population in or about towns and
villages for convenience in political or military administration, as in
Cuba during the revolution of 1895-98.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Reconcilable</ent><br/
<hw>Rec"on*ci`la*ble</hw> <pr>(r?k"?n*s?`l?*b'l)</pr>, <pos>a.</pos>
<ety>[Cf. F. <ets>r<eacute/conciliable</ets>.]</ety> <def>Capable of
being reconciled; <as>as, <ex>reconcilable</ex> adversaries; an act
<ex>reconciable</ex> with previous acts.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>The different accounts of the numbers of ships are
<qex>reconcilable</qex>.</q> <rj><qau>Arbuthnot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Rec"on*ci`la*ble*ness</wf>, <pos>n.</pos> --
<wf>Rec"on*ci`la*bly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reconcile</ent><br/
<hw>Rec"on*cile`</hw> <pr>(-s?l`)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Reconciled</conjf>
<pr>(-s?ld`)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Reconciling</conjf>.]</vmorph> <ety>[F.
<ets>r<eacute/concilier</ets>, L. <ets>reconciliare</ets>; pref.
<ets>re-</ets> re- + <ets>conciliare</ets> to bring together, to unite.
See <er>Conciliate</er>.]</ety> <sn>1.</sn> <def>To cause to be friendly
again; to conciliate anew; to restore to friendship; to bring back to
harmony; to cause to be no longer at variance; <as>as, to
<ex>reconcile</ex> persons who have quarreled</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Propitious now and <qex>reconciled</qex> by prayer.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The church [if defiled] is interdicted till it be
<qex>reconciled</qex> [i.e., restored to sanctity] by the bishop.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>We pray you . . . be ye <qex>reconciled</qex> to God.</q>
<rj><qau>2 Cor. v. 20.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To bring to acquiescence, content, or quiet
submission; <as>as, to <ex>reconcile</ex> one's self to
afflictions</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To make consistent or congruous; to bring to
agreement or suitableness; -- followed by <xex>with</xex> or
<xex>to</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The great men among the ancients understood how to
<qex>reconcile</qex> manual labor with affairs of state.</q>
<rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Some figures monstrous and misshaped appear,<br/
Considered singly, or beheld too near;<br/
Which, but proportioned to their light or place,<br/
Due distance <qex>reconciles</qex> to form and grace.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To adjust; to settle; <as>as, to <ex>reconcile</ex>
differences</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To reunite; conciliate; placate; propitiate;
pacify; appease.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reconcile</ent><br/
<hw>Rec"on*cile`</hw>, <pos>v. i.</pos> <def>To become reconciled.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reconcilement</ent><br/
<hw>Rec"on*cile`ment</hw> <pr>(-m<eit/nt)</pr>, <pos>n.</pos>
<def>Reconciliation.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reconciler</ent><br/
<hw>Rec"on*ci`ler</hw> <pr>(-s?`l?r)</pr>, <pos>n.</pos> <def>One who
reconciles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reconciliation</ent><br/
<hw>Rec`on*cil`i*a"tion</hw> <pr>(-s?l`?*?"sh?n)</pr>, <pos>n.</pos>
<ety>[F. <ets>r<eacute/conciliation</ets>, L.
<ets>reconciliatio</ets>.]</ety> <sn>1.</sn> <def>The act of
reconciling, or the state of being reconciled; reconcilement;
restoration to harmony; renewal of friendship.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Reconciliation</qex> and friendship with God really form the
basis of all rational and true enjoyment.</q> <rj><qau>S.
Miller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Reduction to congruence or consistency; removal of
inconsistency; harmony.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A clear and easy <qex>reconciliation</qex> of those seeming
inconsistencies of Scripture.</q> <rj><qau>D. Rogers.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Reconcilement; reunion; pacification;
appeasement; propitiation; atonement; expiation.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reconciliatory</ent><br/
<hw>Rec`on*cil"i*a*to*ry</hw> <pr>(-s?l"?*?*t?*r?)</pr>, <pos>a.</pos>
<def>Serving or tending to reconcile.</def> <rj><au>Bp.
Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recondensation</ent><br/
<hw>Re*con`den*sa"tion</hw> <pr>(r?*k?n`d?n*s?"sh?n)</pr>, <pos>n.</pos>
<def>The act or process of recondensing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recondense</ent><br/
<hw>Re`con*dense"</hw> <pr>(r<emac/`k<ocr/n*d<ecr/ns")</pr>, <pos>v.
t.</pos> <def>To condense again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recondite</ent><br/
<hw>Rec"on*dite</hw> <pr>(r<ecr/k"<ocr/n*d<imac/t <or/
r<esl/k<ocr/n"d<icr/t; 277)</pr>, <pos>a.</pos> <ety>[L.
<ets>reconditus</ets>, p. p. of <ets>recondere</ets> to put up again, to
lay up, to conceal; pref. <ets>re-</ets> re- + <ets>condere</ets> to
bring or lay together. See <er>Abscond</er>.]</ety> <sn>1.</sn>
<def>Hidden from the mental or intellectual view; secret; abstruse;
<as>as, <ex>recondite</ex> causes of things</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Dealing in things abstruse; profound; searching;
<as>as, <ex>recondite</ex> studies</as>.</def>
<ldquo/<xex>Recondite</xex> learning.<rdquo/ <rj><au>Bp.
Horsley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reconditory</ent><br/
<hw>Re*con"di*to*ry</hw> <pr>(r<esl/k<ocr/n"d<icr/*t<osl/*r<ycr/)</pr>,
<pos>n.</pos> <ety>[LL. <ets>reconditorium</ets>.]</ety> <def>A
repository; a storehouse.</def> <mark>[Obs.]</mark>
<rj><au>Ash.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reconduct</ent><br/
<hw>Re`con*duct"</hw> <pr>(r<emac/`k<ocr/n*d<ucr/kt")</pr>, <pos>v.
t.</pos> <def>To conduct back or again.</def> <ldquo/A guide to
<xex>reconduct</xex> thy steps.<rdquo/ <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reconfirm</ent><br/
<hw>Re`con*firm"</hw> <pr>(r<emac/`k<ocr/n*f<etil/rm")</pr>, <pos>v.
t.</pos> <ety>[Pref. <ets>re-</ets> + <ets>confirm</ets>: cf. F.
<ets>reconfirmer</ets>.]</ety> <def>To confirm anew.</def>
<rj><au>Clarendon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reconfort</ent><br/
<hw>Re`con*fort"</hw> <pr>(-f?rt")</pr>, <pos>v. t.</pos> <ety>[F.
<ets>r<eacute/conforter</ets>.]</ety> <def>To recomfort; to
comfort.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reconjoin</ent><br/
<hw>Re`con*join"</hw> <pr>(r?`k?n*join")</pr>, <pos>v. t.</pos> <def>To
join or conjoin anew.</def> <rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reconnoissance</ent><br/
<ent>Reconnaissance</ent><br/
<mhw>{ <hw>Re*con"nais*sance</hw>, <hw>Re*con"nois*sance</hw> }</mhw>
<pr>(r?-k?n"n?s-s?ns)</pr>, <pos>n.</pos> <ety>[F. See
<er>Recognizance</er>.]</ety> <def>The act of reconnoitering;
preliminary examination or survey.</def> Specifically: <sd>(a)</sd>
<fld>(Geol.)</fld> <def>An examination or survey of a region in
reference to its general geological character.</def> <sd>(b)</sd>
<fld>(Engin.)</fld> <def>An examination of a region as to its general
natural features, preparatory to a more particular survey for the
purposes of triangulation, or of determining the location of a public
work.</def> <sd>(c)</sd> <fld>(Mil.)</fld> <def>An examination of a
territory, or of an enemy's position, for the purpose of obtaining
information necessary for directing military operations; a preparatory
expedition.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Reconnoissance in force</b></col> <fld>(Mil.)</fld>,
<cd>a demonstration or attack by a large force of troops for the purpose
of discovering the position and strength of an enemy.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reconnoitre</ent><br/
<ent>Reconnoiter</ent><br/
<mhw>{ <hw>Rec`on*noi"ter</hw>, <hw>Rec`on*noi"tre</hw> }</mhw>
<pr>(r?k`?n*noi"t?r)</pr>, <pos>v. t.</pos> <ety>[F.
<ets>reconnoitre</ets>, a former spelling of
<ets>reconna<icir/tre</ets>. See <er>Recognize</er>.]</ety> <sn>1.</sn>
<def>To examine with the eye to make a preliminary examination or survey
of; esp., to survey with a view to military or engineering
operations.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To recognize.</def> <mark>[Obs.]</mark> <rj><au>Sir
H. Walpole.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reconquer</ent><br/
<hw>Re*con"quer</hw> <pr>(r?*k?n"k?r)</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>re-</ets> + <ets>conquer</ets>: cf. F.
<ets>reconqu<eacute/rir</ets>.]</ety> <def>To conquer again; to recover
by conquest; <as>as, to <ex>reconquer</ex> a revolted
province</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reconquest</ent><br/
<hw>Re*con"quest</hw> <pr>(-kw?st)</pr>, <pos>n.</pos> <def>A second
conquest.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reconsecrate</ent><br/
<hw>Re*con"se*crate</hw> <pr>(-k?n"s?*kr?t)</pr>, <pos>v. t.</pos>
<def>To consecrate anew or again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reconsecration</ent><br/
<hw>Re*con`se*cra"tion</hw>, <pos>n.</pos> <def>Renewed
consecration.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reconsider</ent><br/
<hw>Re`con*sid"er</hw> <pr>(r?`k?n*s?d"?r)</pr>, <pos>v. t.</pos>
<sn>1.</sn> <def>To consider again; <as>as, to <ex>reconsider</ex> a
subject</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Parliamentary Practice)</fld> <def>To take up for
renewed consideration, as a motion or a vote which has been previously
acted upon.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reconsideration</ent><br/
<hw>Re`con*sid`er*a"tion</hw> <pr>(-?"sh?n)</pr>, <pos>n.</pos> <def>The
act of reconsidering, or the state of being reconsidered; <as>as, the
<ex>reconsideration</ex> of a vote in a legislative body</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reconsolate</ent><br/
<hw>Re*con"so*late</hw> <pr>(r?*k?n"s?*l?t)</pr>, <pos>v. t.</pos>
<def>To console or comfort again.</def> <mark>[Obs.]</mark> <rj><au>Sir
H. Wotton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reconsolidate</ent><br/
<hw>Re`con*sol"i*date</hw> <pr>(r?`k?n*s?l"?*d?t)</pr>, <pos>v. t.</pos>
<def>To consolidate anew or again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reconsolidation</ent><br/
<hw>Re`con*sol`i*da"tion</hw> <pr>(-d?"sh?n)</pr>, <pos>n.</pos>
<def>The act or process of reconsolidating; the state of being
reconsolidated.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reconstruct</ent><br/
<hw>Re`con*struct"</hw> <pr>(-str?kt")</pr>, <pos>v. t.</pos> <def>To
construct again; to rebuild; to remodel; to form again or
anew.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Regiments had been dissolved and <qex>reconstructed</qex>.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reconstruction</ent><br/
<hw>Re`con*struc"tion</hw> <pr>(-str?k"sh?n)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>The act of constructing again; the state of being
reconstructed.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(U.S. Politics)</fld> <def>The act or process of
reorganizing the governments of the States which had passed ordinances
of secession, and of reestablishing their constitutional relations to
the national government, after the close of the Civil War.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reconstructive</ent><br/
<hw>Re`con*struct"ive</hw> <pr>(-str?k"t?v)</pr>, <pos>a.</pos>
<def>Reconstructing; tending to reconstruct; <as>as, a
<ex>reconstructive</ex> policy</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recontinuance</ent><br/
<hw>Re`con*tin"u*ance</hw> <pr>(-t?n"?*?ns)</pr>, <pos>n.</pos> <def>The
act or state of recontinuing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recontinue</ent><br/
<hw>Re`con*tin"ue</hw> <pr>(-?)</pr>, <pos>v. t. & i.</pos> <def>To
continue anew.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reconvene</ent><br/
<hw>Re`con*vene"</hw> <pr>(r?`k?n*v?n")</pr>, <pos>v. t. & i.</pos>
<def>To convene or assemble again; to call or come together
again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reconvention</ent><br/
<hw>Re`con*ven"tion</hw> <pr>(-v?n"sh?n)</pr>, <pos>n.</pos> <fld>(Civil
Law)</fld> <def>A cross demand; an action brought by the defendant
against the plaintiff before the same judge.</def> <rj><au>Burrill.
Bouvier.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reconversion</ent><br/
<hw>Re`con*ver"sion</hw> <pr>(-v?r"sh?n)</pr>, <pos>n.</pos> <def>A
second conversion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reconvert</ent><br/
<hw>Re`con*vert"</hw> <pr>(-v?rt")</pr>, <pos>v. t.</pos> <def>To
convert again.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reconvert</ent><br/
<hw>Re*con"vert</hw> <pr>(r?*k?n"v?rt)</pr>, <pos>n.</pos> <def>A person
who has been reconverted.</def> <rj><au>Gladstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reconvertible</ent><br/
<hw>Re`con*vert"i*ble</hw> <pr>(r?`k?n*v?rt"?*b'l)</pr>, <pos>a.</pos>
<fld>(Chem.)</fld> <def>Capable of being reconverted; convertible again
to the original form or condition.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reconvey</ent><br/
<hw>Re`con*vey"</hw> <pr>(-v?")</pr>, <pos>v. t.</pos> <sn>1.</sn>
<def>To convey back or to the former place; <as>as, to <ex>reconvey</ex>
goods</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To transfer back to a former owner; <as>as, to
<ex>reconvey</ex> an estate</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reconveyance</ent><br/
<hw>Re`con*vey"ance</hw> <pr>(-v?"?ns)</pr>, <pos>n.</pos> <def>Act of
reconveying.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recopy</ent><br/
<hw>Re*cop"y</hw> <pr>(r?*k?p"?)</pr>, <pos>v. t.</pos> <def>To copy
again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Record</ent><br/
<hw>Re*cord"</hw> <pr>(r?*k?rd")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Recorded</conjf>; <pos>p. pr. &
vb. n.</pos> <conjf>Recording</conjf>.]</vmorph> <ety>[OE.
<ets>recorden</ets> to repeat, remind, F. <ets>recorder</ets>, fr. L.
<ets>recordari</ets> to remember; pref. <ets>re-</ets> re- +
<ets>cor</ets>, <ets>cordis</ets>, the heart or mind. See
<er>Cordial</er>, <er>Heart</er>.]</ety> <sn>1.</sn> <def>To recall to
mind; to recollect; to remember; to meditate.</def> <mark>[Obs.]</mark>
<ldquo/I it you <xex>record</xex>.<rdquo/ <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To repeat; to recite; to sing or play.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>They longed to see the day, to hear the lark<br/
<qex>Record</qex> her hymns, and chant her carols blest.</q>
<rj><qau>Fairfax.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To preserve the memory of, by committing to writing,
to printing, to inscription, or the like; to make note of; to write or
enter in a book or on parchment, for the purpose of preserving authentic
evidence of; to register; to enroll; <as>as, to <ex>record</ex> the
proceedings of a court; to <ex>record</ex> historical
events.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Those things that are <qex>recorded</qex> of him . . . are written
in the chronicles of the kings.</q> <rj><qau>1 Esd. i.
42.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>To record a deed</b></col>,
<col><b>mortgage</b></col>, <col><b>lease</b></col></mcol>, <cd>etc., to
have a copy of the same entered in the records of the office designated
by law, for the information of the public.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Record</ent><br/
<hw>Re*cord"</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To reflect; to
ponder.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Praying all the way, and <qex>recording</qex> upon the words which
he before had read.</q> <rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To sing or repeat a tune.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Whether the birds or she <qex>recorded</qex> best.</q> <rj><qau>W.
Browne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Record</ent><br/
<hw>Rec"ord</hw> <pr>(r<ecr/k"<etil/rd)</pr>, <pos>n.</pos> <ety>[OF.
<ets>recort</ets>, <ets>record</ets>, remembrance, attestation, record.
See <er>Record</er>, <pos>v. t.</pos>]</ety> <sn>1.</sn> <def>A writing
by which some act or event, or a number of acts or events, is recorded;
a register; <as>as, a <ex>record</ex> of the acts of the Hebrew kings; a
<ex>record</ex> of the variations of temperature during a certain time;
a family <ex>record</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> Especially: <sd>(a)</sd> <def>An official contemporaneous
writing by which the acts of some public body, or public officer, are
recorded; <as>as, a <ex>record</ex> of city ordinances; the
<ex>records</ex> of the receiver of taxes</as>.</def> <sd>(b)</sd>
<def>An authentic official copy of a document which has been entered in
a book, or deposited in the keeping of some officer designated by
law.</def> <sd>(c)</sd> <def>An official contemporaneous memorandum
stating the proceedings of a court of justice; a judicial record.</def>
<sd>(d)</sd> <def>The various legal papers used in a case, together with
memoranda of the proceedings of the court; <as>as, it is not permissible
to allege facts not in the <ex>record</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Testimony; witness; attestation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>John bare <qex>record</qex>, saying.</q> <rj><qau>John i.
32.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>That which serves to perpetuate a knowledge of acts
or events; a monument; a memorial.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>That which has been, or might be, recorded; the
known facts in the course, progress, or duration of anything, as in the
life of a public man; <as>as, a politician with a good or a bad
<ex>record</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1201 --></p>

<p><sn>6.</sn> <def>That which has been publicly achieved in any kind of
competitive sport as recorded in some authoritative manner, as the time
made by a winning horse in a race.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Court of record</b></col> <pr>(<it>pron.</it>
r<?/*k<?/rd" <it>in Eng.</it>)</pr>, <cd>a court whose acts and judicial
proceedings are written on parchment or in books for a perpetual
memorial.</cd> -- <col><b>Debt of record</b></col>, <cd>a debt which
appears to be due by the evidence of a court of record, as upon a
judgment or a cognizance.</cd> -- <col><b>Trial by record</b></col>,
<cd>a trial which is had when a matter of record is pleaded, and the
opposite party pleads that there is no such record. In this case the
trial is by inspection of the record itself, no other evidence being
admissible.</cd> <au>Blackstone.</au> -- <mcol><col><b>To beat the
record</b></col>, <it>or</it> <col><b>To break the
record</b></col></mcol> <fld>(Sporting)</fld>, <cd>to surpass any
performance of like kind as authoritatively recorded; <as>as, <ex>to
break the record</ex> in a walking match</as>.</cd> <note>Records in
many fields of endeavor are listed in the <a
href="https://www.guinnessworldrecords.com/">Guiness Book of World
Records</a></note>.</cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recordance</ent><br/
<hw>Re*cord"ance</hw> <pr>(r?*k?rd"?ns)</pr>, <pos>n.</pos>
<def>Remembrance.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recordation</ent><br/
<hw>Rec`or*da"tion</hw> <pr>(r?k`?r*d?"sh?n)</pr>, <pos>n.</pos>
<ety>[L. <ets>recordatio</ets>: cf. F. <ets>recordation</ets>. See
<er>Record</er>, <pos>v. t.</pos>]</ety> <def>Remembrance; recollection;
also, a record.</def> <mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recorder</ent><br/
<hw>Re*cord"er</hw> <pr>(r?*k?rd"?r)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>One who records; specifically, a person whose official duty it is
to make a record of writings or transactions.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The title of the chief judicial officer of some
cities and boroughs; also, of the chief justice of an East Indian
settlement. The Recorder of London is judge of the Lord Mayor's Court,
and one of the commissioners of the Central Criminal Court.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Mus.)</fld> <def>A kind of wind instrument
resembling the flageolet.</def> <mark>[Obs.]</mark> <ldquo/Flutes and
soft <xex>recorders</xex>.<rdquo/ <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recordership</ent><br/
<hw>Re*cord"er*ship</hw>, <pos>n.</pos> <def>The office of a
recorder.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recording</ent><br/
<hw>Re*cord"ing</hw>, <pos>a.</pos> <def>Keeping a record or a register;
<as>as, a <ex>recording</ex> secretary</as>; -- applied to numerous
instruments with an automatic appliance which makes a record of their
action; <as>as, a <ex>recording</ex> gauge or telegraph</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recorporification</ent><br/
<hw>Re`cor*por`i*fi*ca"tion</hw> <pr>(r?`k?r*p?r`?*f?*k?"sh?n)</pr>,
<pos>n.</pos> <def>The act of investing again with a body; the state of
being furnished anew with a body.</def> <mark>[R.]</mark>
<rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recouch</ent><br/
<hw>Re*couch"</hw> <pr>(r?*kouch")</pr>, <pos>v. i.</pos> <ety>[Pref.
<ets>re-</ets> + <ets>couch</ets>: cf. F. <ets>recoucher</ets>.]</ety>
<def>To retire again to a couch; to lie down again.</def>
<mark>[Obs.]</mark> <rj><au>Sir H. Wotton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recount</ent><br/
<hw>Re*count"</hw> <pr>(r<emac/*kount")</pr>, <pos>v. t.</pos>
<ety>[Pref. <ets>re-</ets> + <ets>count</ets>.]</ety> <def>To count or
reckon again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recount</ent><br/
<hw>Re*count"</hw>, <pos>n.</pos> <def>A counting again, as of
votes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recount</ent><br/
<hw>Re*count"</hw> <pr>(r<esl/*kount")</pr>, <pos>v. t.</pos> <ety>[F.
<ets>raconter</ets> to relate, to recount; pref. <ets>re-</ets> again +
<?/ (L. <ets>ad</ets>.) + <ets>conter</ets> to relate. See
<er>Count</er>, <pos>v.</pos>]</ety> <def>To tell over; to relate in
detail; to recite; to tell or narrate the particulars of; to rehearse;
to enumerate; <as>as, to <ex>recount</ex> one's blessings</as>.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To all his angels, who, with true applause,<br/
<qex>Recount</qex> his praises.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recountment</ent><br/
<hw>Re*count`ment</hw> <pr>(-m<eit/nt)</pr>, <pos>n.</pos>
<def>Recital.</def> <mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recoupe</ent><br/
<ent>Recoup</ent><br/
<mhw>{ <hw>Re*coup"</hw>, <hw>Re*coupe"</hw> }</mhw> <pr>(-k??p")</pr>,
<pos>v. t.</pos> <ety>[F. <ets>recouper</ets>; pref. <ets>re-</ets> re-
+ <ets>couper</ets> to cut.]</ety> <sn>1.</sn> <fld>(Law)</fld> <def>To
keep back rightfully (a part), as if by cutting off, so as to diminish a
sum due; to take off (a part) from damages; to deduct; <as>as, where a
landlord <ex>recouped</ex> the rent of premises from damages awarded to
the plaintiff for eviction</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To get an equivalent or compensation for; <as>as, to
<ex>recoup</ex> money lost at the gaming table; to <ex>recoup</ex> one's
losses in the share market</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To reimburse; to indemnify; -- often used
reflexively and in the passive.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Elizabeth had lost her venture; but if she was bold, she might
<qex>recoup</qex> herself at Philip's cost.</q>
<rj><qau>Froude.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Industry is sometimes <qex>recouped</qex> for a small price by
extensive custom.</q> <rj><qau>Duke of Argyll.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recouper</ent><br/
<hw>Re*coup"er</hw> <pr>(r?*k??p"?r)</pr>, <pos>n.</pos> <def>One who
recoups.</def> <rj><au>Story.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recoupment</ent><br/
<hw>Re*coup"ment</hw> <pr>(-m<eit/nt)</pr>, <pos>n.</pos> <def>The act
of recouping.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Recoupment</xex> applies to equities growing out of
the very affair from which thw principal demand arises,
<xex>set-off</xex> to cross-demands which may be independent in
origin.</note> <rj><au>Abbott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recourse</ent><br/
<hw>Re*course"</hw> <pr>(r?*k?rs")</pr>, <pos>n.</pos> <ety>[F.
<ets>recours</ets>, L. <ets>recursus</ets> a running back, return, fr.
<ets>recurrere</ets>, <ets>recursum</ets>, to run back. See
<er>Recur</er>.]</ety> <sn>1.</sn> <def>A coursing back, or coursing
again, along the line of a previous coursing; renewed course; return;
retreat; recurrence.</def> <mark>[Obs.]</mark> <ldquo/Swift
<xex>recourse</xex> of flushing blood.<rdquo/
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Unto my first I will have my <qex>recourse</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Preventive physic . . . preventeth sickness in the healthy, or the
<qex>recourse thereof in the valetudinary</qex>.</q> <rj><qau>Sir T.
Browne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Recurrence in difficulty, perplexity, need, or the
like; access or application for aid; resort.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thus died this great peer, in a time of great <qex>recourse</qex>
unto him and dependence upon him.</q> <rj><qau>Sir H.
Wotton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Our last <qex>recourse</qex> is therefore to our art.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Access; admittance.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Give me <qex>recourse</qex> to him.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Without recourse</b></col> <fld>(Commerce)</fld>,
<cd>words sometimes added to the indorsement of a negotiable instrument
to protect the indorser from liability to the indorsee and subsequent
holders. It is a restricted indorsement.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recourse</ent><br/
<hw>Re*course"</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To return; to
recur.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The flame departing and <qex>recoursing</qex>.</q>
<rj><qau>Foxe.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To have recourse; to resort.</def>
<mark>[Obs.]</mark> <rj><au>Bp. Hacket.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recourseful</ent><br/
<hw>Re*course"ful</hw> <pr>(-f?l)</pr>, <pos>a.</pos> <def>Having
recurring flow and ebb; moving alternately.</def> <mark>[Obs.]</mark>
<rj><au>Drayton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recover</ent><br/
<hw>Re*cov"er</hw> <pr>(r?*k?v"?r)</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>re-</ets> + <ets>cover</ets>: cf. F. <ets>recouvrir</ets>.]</ety>
<def>To cover again.</def> <rj><au>Sir W. Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recover</ent><br/
<hw>Re*cov"er</hw> <pr>(r?*k?v"?r)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Recovered</conjf>
<pr>(-?rd)</pr>; <pos>p. pr. & vb. n.</pos> <conjf>Recovering</conjf>.
]</vmorph> <ety>[OE. <ets>recoveren</ets>, OF. <ets>recovrer</ets>, F.
<ets>recouvrer</ets>, from L. <ets>recuperare</ets>; pref.
<ets>re-</ets> re + a word of unknown origin.
Cf.<er>Recuperate</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>To get or obtain again; to get renewed possession
of; to win back; to regain.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>David <qex>recovered</qex> all that the Amalekites had carried
away.</q> <rj><qau>1. Sam. xxx. 18.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To make good by reparation; to make up for; to
retrieve; to repair the loss or injury of; <as>as, to <ex>recover</ex>
lost time</as>.</def> <ldquo/Loss of catel may <xex>recovered</xex>
be.<rdquo/ <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Even good men have many failings and lapses to lament and
<qex>recover</qex>.</q> <rj><qau>Rogers.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To restore from sickness, faintness, or the like; to
bring back to life or health; to cure; to heal.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The wine in my bottle will <qex>recover</qex> him.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To overcome; to get the better of, -- as a state of
mind or body.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I do hope to <qex>recover</qex> my late hurt.</q>
<rj><qau>Cowley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>When I had <qex>recovered</qex> a little my first surprise.</q>
<rj><qau>De Foe.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To rescue; to deliver.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That they may <qex>recover</qex> themselves out of the snare of
the devil, who are taken captive by him.</q> <rj><qau>2. Tim. ii.
26.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To gain by motion or effort; to obtain; to reach; to
come to.</def> <mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The forest is not three leagues off;<br/
If we <qex>recover</qex> that, we're sure enough.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Except he could <qex>recover</qex> one of the Cities of Refuge he
was to die.</q> <rj><qau>Hales.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Law)</fld> <def>To gain as a compensation; to
obtain in return for injury or debt; <as>as, to <ex>recover</ex> damages
in trespass; to <ex>recover</ex> debt and costs in a suit at law</as>;
to obtain title to by judgement in a court of law; <as>as, to
<ex>recover</ex> lands in ejectment or common recovery</as>; to gain by
legal process; <as>as, to <ex>recover</ex> judgement against a
defendant</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Recover arms</b></col> <fld>(Mil. Drill)</fld>, <cd>a
command whereby the piece is brought from the position of
<ldquo/aim<rdquo/ to that of <ldquo/ready.<rdquo/</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To regain; repossess; resume; retrieve; recruit;
heal; cure.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recover</ent><br/
<hw>Re*cov"er</hw> <pr>(r?*k?v"?r)</pr>, <pos>v. i.</pos> <sn>1.</sn>
<def>To regain health after sickness; to grow well; to be restored or
cured; hence, to regain a former state or condition after misfortune,
alarm, etc.; -- often followed by <xex>of</xex> or <xex>from</xex>;
<as>as, to <ex>recover</ex> from a state of poverty; to <ex>recover</ex>
from fright.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Go, inquire of Baal-zebub, the god of Ekron, whether I shall
<qex>recover</qex> of this disease.</q> <rj><qau>2 Kings i.
2.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To make one's way; to come; to arrive.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>With much ado the Christians <qex>recovered</qex> to Antioch.</q>
<rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Law)</fld> <def>To obtain a judgement; to succeed
in a lawsuit; <as>as, the plaintiff has <ex>recovered</ex> in his
suit</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recover</ent><br/
<hw>Re*cov"er</hw>, <pos>n.</pos> <def>Recovery.</def> <rj><au>Sir T.
Malory.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recoverable</ent><br/
<hw>Re*cov"er*a*ble</hw> <pr>(-?*b'l)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>recouvrable</ets>.]</ety> <def>Capable of being recovered or
regained; capable of being brought back to a former condition, as from
sickness, misfortune, etc.; obtainable from a debtor or possessor;
<as>as, the debt is <ex>recoverable</ex>; goods lost or sunk in the
ocean are not <ex>recoverable</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>A prodigal course<br/
Is like the sun's; but not, like his, <qex>recoverable</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>If I am <qex>recoverable</qex>, why am I thus?</q>
<rj><qau>Cowper.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Re*cov"er*a*ble*ness</wf>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Re coverance</ent><br/
<hw>Re cov"er*ance</hw> <pr>(-<ait/ns)</pr>, <pos>n.</pos>
<def>Recovery.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recoveree</ent><br/
<hw>Re*cov`er*ee"</hw> <pr>(-<emac/")</pr>, <pos>n.</pos>
<fld>(Law)</fld> <def>The person against whom a judgment is obtained in
common recovery.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recoverer</ent><br/
<hw>Re*cov"er*er</hw> <pr>(r?*k?v"?r*?r)</pr>, <pos>n.</pos> <def>One
who recovers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recoveror</ent><br/
<hw>Re*cov`er*or"</hw> <pr>(-?r)</pr>, <pos>n.</pos> <fld>(Law)</fld>
<def>The demandant in a common recovery after judgment.</def>
<rj><au>Wharton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recovery</ent><br/
<hw>Re*cov"er*y</hw> <pr>(r?*k?v"?r*?)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>The act of recovering, regaining, or retaking possession.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Restoration from sickness, weakness, faintness, or
the like; restoration from a condition of mistortune, of fright,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Law)</fld> <def>The obtaining in a suit at law of a
right to something by a verdict and judgment of court.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The getting, or gaining, of something not previously
had.</def> <mark>[Obs.]</mark> <ldquo/Help be past
<xex>recovery</xex>.<rdquo/ <rj><au>Tusser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>In rowing, the act of regaining the proper position
for making a new stroke.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Act of regaining the natural position after
curtseying.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>7.</sn> <fld>(Fencing, Sparring, etc.)</fld> <def>Act of
regaining the position of guard after making an attack.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><cs><col><b>Common recovery</b></col> <fld>(Law)</fld>, <cd>a species
of common assurance or mode of conveying lands by matter of record,
through the forms of an action at law, formerly in frequent use, but now
abolished or obsolete, both in England and America.</cd>
<rj><au>Burrill. Warren.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recreance</ent><br/
<hw>Rec"re*ance</hw> <pr>(r?k"r?*?ns)</pr>, <pos>n.</pos>
<def>Recreancy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recreancy</ent><br/
<hw>Rec"re*an*cy</hw> <pr>(-<it>a</it>n*s?)</pr>, <pos>n.</pos> <def>The
quality or state of being recreant.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recreant</ent><br/
<hw>Rec"re*ant</hw> <pr>(-<it>a</it>nt)</pr>, <pos>a.</pos> <ety>[OF.,
cowardly, fr. <ets>recroire</ets>, <ets>recreire</ets>, to forsake,
leave, tire, discourage, regard as conquered, LL. <ets>recredere
se</ets> to declare one's self conquered in combat; hence, those are
called <ets>recrediti</ets> or <ets>recreanti</ets> who are considered
infamous; L. pref. <ets>re-</ets> again, back + <ets>credere</ets> to
believe, to be of opinion; hence, originally, to disavow one's opinion.
See <er>Creed</er>.]</ety> <sn>1.</sn> <def>Crying for mercy, as a
combatant in the trial by battle; yielding; cowardly; mean-spirited;
craven.</def> <ldquo/This <xex>recreant</xex> knight.<rdquo/
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Apostate; false; unfaithful.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Who, for so many benefits received,<br/
Turned <qex>recreant</qex> to God, ingrate and false.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recreant</ent><br/
<hw>Rec"re*ant</hw>, <pos>n.</pos> <def>One who yields in combat, and
begs for mercy; a mean-spirited, cowardly wretch.</def>
<rj><au>Blackstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>You are all <qex>recreants</qex> and dastards!</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Re-create</ent><br/
<hw>Re`-cre*ate"</hw> <pr>(r?`kr?*?t")</pr>, <pos>v. t.</pos>
<ety>[Pref. <ets>re-</ets> + <ets>create</ets>.]</ety> <def>To create or
form anew.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>On opening the campaign of 1776, instead of reenforcing, it was
necessary to <qex>re-create</qex>, the army.</q>
<rj><qau>Marshall.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recreate</ent><br/
<hw>Rec"re*ate</hw> <pr>(rk"r*t)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Recreated</conjf>
<pr>(-`td)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Recreating</conjf>.]</vmorph> <ety>[L. <ets>recreatus</ets>, p.
p. of <ets>recreate</ets> to create anew, to refresh; pref.
<ets>re-</ets> re- + <ets>creare</ets> to create. See
<er>Create</er>.]</ety> <def>To give fresh life to; to reanimate; to
revive; especially, to refresh after wearying toil or anxiety; to
relieve; to cheer; to divert; to amuse; to gratify.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Painters, when they work on white grounds, place before them
colors mixed with blue and green, to <qex>recreate</qex> their eyes,
white wearying . . . the sight more than any.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>St. John, who <qex>recreated</qex> himself with sporting with a
tame partridge.</q> <rj><qau>Jer. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>These ripe fruits <qex>recreate</qex> the nostrils with their
aromatic scent.</q> <rj><qau>Dr. H. More.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recreate</ent><br/
<hw>Rec"re*ate</hw>, <pos>v. i.</pos> <def>To take recreation.</def>
<rj><au>L. Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recreation</ent><br/
<hw>Rec"re*a"tion</hw> <pr>(-?"sh?n)</pr>, <pos>n.</pos> <ety>[F.
<ets>r<eacute/cr<eacute/ation</ets>, L. <ets>recreatio</ets>.]</ety>
<def>The act of recreating, or the state of being recreated; refreshment
of the strength and spirits after toil; amusement; diversion; sport;
pastime.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Re-creation</ent><br/
<hw>Re`-cre*a"tion</hw> <pr>(r?`kr?*?sh?n)</pr>, <pos>n.</pos> <ety>[See
<er>Re-create</er>.]</ety> <def>A forming anew; a new creation or
formation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Re-creative</ent><br/
<hw>Re`-cre*a"tive</hw> <pr>(-?`t?v)</pr>, <pos>a.</pos> <def>Creating
anew; <as>as, <ex>re-creative</ex> power</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recreative</ent><br/
<hw>Rec"re*a`tive</hw> <pr>(r?k"r?*?`t?v)</pr>, <pos>a.</pos> <ety>[Cf.
F. <ets>r<eacute/cr<eacute/atif</ets>. See <er>Recreate</er>.]</ety>
<def>Tending to recreate or refresh; recreating; giving new vigor or
animation; reinvigorating; giving relief after labor or pain; amusing;
diverting.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Let the music of them be <qex>recreative</qex>.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p>--- <wordforms><wf>Rec"re*a`tive*ly</wf>, <pos>adv.</pos> --
<wf>Rec"re*a`tive*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recrement</ent><br/
<hw>Rec"re*ment</hw> <pr>(r?k"r?*m<it>e</it>nt)</pr>, <pos>n.</pos>
<ety>[L. <ets>recrementum</ets>; pref. <ets>re-</ets> re- +
<ets>cernere</ets>, <ets>cretum</ets>, to separate, sift: cf. F.
<ets>r<eacute/cr<eacute/ment</ets>.]</ety> <sn>1.</sn> <def>Superfluous
matter separated from that which is useful; dross; scoria; <as>as, the
<ex>recrement</ex> of ore</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Med.)</fld> <sd>(a)</sd> <def>Excrement.</def>
<mark>[Obs.]</mark> <sd>(a)</sd> <def>A substance secreted from the
blood and again absorbed by it.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recremental</ent><br/
<hw>Rec`re*men"tal</hw> <pr>(-m?n"t<it>a</it>l)</pr>, <pos>a.</pos>
<def>Recrementitious.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recrementitial</ent><br/
<hw>Rec`re*men*ti"tial</hw> <pr>(-m?n*t?sh"<it>a</it>l)</pr>,
<pos>a.</pos> <ety>[Cf. F.
<ets>r<eacute/cr<eacute/mentitiel</ets>.]</ety> <fld>(Med.)</fld>
<def>Of the nature of a recrement. See <er>Recrement</er>, 2
<sd>(b)</sd>.</def> <ldquo/<xex>Recrementitial</xex> fluids.<rdquo/
<rj><au>Dunglison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recrementitious</ent><br/
<hw>Rec`re*men*ti"tious</hw> <pr>(-t?sh"?s)</pr>, <pos>a.</pos> <def>Of
or pertaining to recrement; consisting of recrement or dross.</def>
<rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recriminate</ent><br/
<hw>Re*crim"i*nate</hw> <pr>(r?*kr?m"?*n?t)</pr>, <pos>v. i.</pos>
<ety>[Pref. <ets>re-</ets> + <ets>criminate</ets>: cf. F.
<ets>r<eacute/criminer</ets>, LL. <ets>recriminare</ets>.]</ety> <def>To
return one charge or accusation with another; to charge back fault or
crime upon an accuser.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It is not my business to <qex>recriminate</qex>, hoping
sufficiently to clear myself in this matter.</q> <rj><qau>Bp.
Stillingfleet.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recriminate</ent><br/
<hw>Re*crim"i*nate</hw>, <pos>v. t.</pos> <def>To accuse in
return.</def> <rj><au>South.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recrimination</ent><br/
<hw>Re*crim`i*na"tion</hw> <pr>(-n?"sh?n)</pr>, <pos>n.</pos> <ety>[F.
<ets>r<eacute/crimination</ets>, LL. <ets>recriminatio</ets>.]</ety>
<def>The act of recriminating; an accusation brought by the accused
against the accuser; a counter accusation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Accusations and <qex>recriminations</qex> passed backward and
forward between the contending parties.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recriminative</ent><br/
<hw>Re*crim"i*na*tive</hw> <pr>(-n?*t?v)</pr>, <pos>a.</pos>
<def>Recriminatory.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recriminator</ent><br/
<hw>Re*crim"i*na`tor</hw> <pr>(-n?`t?r)</pr>, <pos>n.</pos> <def>One who
recriminates.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recriminatory</ent><br/
<hw>Re*crim"i*na*to*ry</hw> <pr>(-n?*t?*r?)</pr>, <pos>a.</pos>
<ety>[Cf. F. <ets>r<eacute/criminatoire</ets>.]</ety> <def>Having the
quality of recrimination; retorting accusation; recriminating.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recross</ent><br/
<hw>Re*cross"</hw> <pr>(r?*kr?s";115)</pr>, <pos>v. t.</pos> <def>To
cross a second time.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recrudency</ent><br/
<hw>Re*cru"den*cy</hw> <pr>(r<esl/*kr<udd/"d<eit/n*s<ycr/)</pr>,
<pos>n.</pos> <def>Recrudescence.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recrudesce</ent><br/
<hw>Re`cru*desce"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[See
<er>Recrudescent</er>.]</ety> <def>To be in a state of recrudescence;
esp., to come into renewed freshness, vigor, or activity; to
revive.</def></p>

<p><q>The general influence . . . which is liable every now and then to
<qex>recrudesce</qex> in his absence.</q> <rj><qau>Edmund
Gurney.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Recrudescency</ent><br/
<ent>Recrudescence</ent><br/
<mhw>{ <hw>Re`cru*des"cence</hw> <pr>(r?`kr?*d?s"s<it>e</it>ns)</pr>,
<hw>Re`cru*des`cen*cy</hw> <pr>(-d?s"s<it>e</it>n*s?)</pr>, }</mhw>
<pos>n.</pos> <ety>[Cf. F. <ets>recrudescence</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>The state or condition of being
recrudescent.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>A recrudescence</qex> of barbarism may condemn it [land] to
chronic poverty and waste.</q> <rj><qau>Duke of Argyll.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Med.)</fld> <def>Increased severity of a disease
after temporary remission.</def> <rj><au>Dunglison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recrudescent</ent><br/
<hw>Re`cru*des"cent</hw> <pr>(-s<it>e</it>nt)</pr>, <pos>a.</pos>
<ety>[L. <ets>recrudescens</ets>, <ets>-entis</ets>, p. pr. of
<ets>recrudescere</ets> to become raw again; pref. <ets>re-</ets> re- +
<ets>crudescere</ets> to become hard or raw: cf. F.
<ets>recrudescent</ets>.]</ety> <sn>1.</sn> <def>Growing raw, sore, or
painful again.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Breaking out again after temporary abatement or
suppression; <as>as, a <ex>recrudescent</ex> epidemic</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recruit</ent><br/
<hw>Re*cruit"</hw> <pr>(r?*kr?t")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Recruited</conjf>; <pos>p. pr. &
vb. n.</pos> <conjf>Recruiting</conjf>.]</vmorph> <ety>[F.
<ets>recruter</ets>, corrupted (under influence of <ets>recrue</ets>
recruiting, recruit, from <ets>recro<icir//tre</ets>, p. p.
<ets>recr<ucir/</ets>, to grow again) from an older <ets>recluter</ets>,
properly, to patch, to mend (a garment); pref. <ets>re-</ets> + OF.
<ets>clut</ets> piece, piece of cloth; cf. Icel. <ets>kl<umac/tr</ets>
kerchief, E. <ets>clout</ets>.]</ety> <sn>1.</sn> <def>To repair by
fresh supplies, as anything wasted; to remedy lack or deficiency in;
<as>as, food <ex>recruits</ex> the flesh; fresh air and exercise
<ex>recruit</ex> the spirits.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Her cheeks glow the brighter, <qex>recruiting</qex> their
color.</q> <rj><qau>Glanvill.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence, to restore the wasted vigor of; to renew in
strength or health; to reinvigorate.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To supply with new men, as an army; to fill up or
make up by enlistment; <as>as, he <ex>recruited</ex> two regiments; the
army was <ex>recruited</ex> for a campaign</as>; also, to muster; to
enlist; <as>as, he <ex>recruited</ex> fifty men</as>.</def> <rj><au>M.
Arnold.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recruit</ent><br/
<hw>Re*cruit"</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To gain new
supplies of anything wasted; to gain health, flesh, spirits, or the
like; to recuperate; <as>as, lean cattle <ex>recruit</ex> in fresh
pastures</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To gain new supplies of men for military or other
service; to raise or enlist new soldiers; to enlist troops.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recruit</ent><br/
<hw>Re*cruit"</hw>, <pos>n.</pos> <sn>1.</sn> <def>A supply of anything
wasted or exhausted; a reenforcement.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The state is to have <qex>recruits</qex> to its strength, and
remedies to its distempers.</q> <rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Specifically, a man enlisted for service in the
army; a newly enlisted soldier.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recruiter</ent><br/
<hw>Re*cruit"er</hw>, <pos>n.</pos> <def>One who, or that which,
recruits.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recruitment</ent><br/
<hw>Re*cruit"ment</hw> <pr>(-m<eit/nt)</pr>, <pos>n.</pos> <def>The act
or process of recruiting; especially, the enlistment of men for an
army.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recrystallization</ent><br/
<hw>Re*crys`tal*li*za"tion</hw>
<pr>(r<emac/*kr<icr/s`t<ait/l*l<icr/*z<amac/"sh<ucr/n)</pr>,
<pos>n.</pos> <fld>(Chem. & Min.)</fld> <def>The process or
recrystallizing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recrystallize</ent><br/
<hw>Re*crys"tal*lize</hw> <pr>(r<emac/*kr<icr/s"t<ait/l*l<imac/z)</pr>,
<pos>v. i. & t.</pos> <fld>(Chem. & Min.)</fld> <def>To crystallize
again.</def> <rj><au>Henry.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rectal</ent><br/
<hw>Rec"tal</hw> <pr>(r?k"t<it>a</it>l)</pr>, <pos>a.</pos>
<fld>(Anat.)</fld> <def>Of or pertaining to the rectum; in the region of
the rectum.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rectangle</ent><br/
<hw>Rec"tan`gle</hw> <pr>(r?k"t??`g'l)</pr>, <pos>n.</pos> <ety>[F., fr.
L. <ets>rectus</ets> right + <ets>angulus</ets> angle. See
<er>Right</er>, and <er>Angle</er>.]</ety> <fld>(Geom.)</fld> <def>A
four-sided figure having only right angles; a right-angled
parallelogram.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ As the area of a <xex>rectangle</xex> is expressed by
the product of its two dimensions, the term <xex>rectangle</xex> is
sometimes used for <xex>product</xex>; as, the <xex>rectangle</xex> of
<xex>a</xex> and <xex>b</xex>, that is, <xex>ab</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rectangle</ent><br/
<hw>Rec"tan`gle</hw>, <pos>a.</pos> <def>Rectangular.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rectangled</ent><br/
<hw>Rec"tan`gled</hw> <pr>(-g'ld)</pr>, <pos>a.</pos>
<def>Rectangular.</def> <rj><au>Hutton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rectangular</ent><br/
<hw>Rec*tan"gu*lar</hw> <pr>(r?k*t?n"g?*l?r)</pr>, <pos>a.</pos>
<ety>[CF. F. <ets>rectangulaire</ets>.]</ety> <def>Right-angled; having
one or more angles of ninety degrees.</def> --
<wordforms><wf>Rec*tan"gu*lar*ly</wf>
<pr>(r<?/k*t<?/n"g<?/*l<?/r*l<?/)</pr>, <pos>adv.</pos> --
<wf>Rec*tan"gu*lar*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rectangularity</ent><br/
<hw>Rec*tan`gu*lar"i*ty</hw> <pr>(-l?r"?*t?)</pr>, <pos>n.</pos>
<def>The quality or condition of being rectangular, or
right-angled.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recti-</ent><br/
<hw>Rec"ti-</hw> <pr>(r?k"t?*)</pr>. <ety>[L. <ets>rectus</ets>
straight.]</ety> <def>A combining form signifying <xex>straight</xex>;
<as>as, <ex>recti</ex>lineal, having straight lines;
<ex>recti</ex>nerved</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rectifiable</ent><br/
<hw>Rec"ti*fi`a*ble</hw> <pr>(r?k"t?*f?`?*b'l)</pr>, <pos>a.</pos>
<sn>1.</sn> <def>Capable of being rectified; <as>as, a
<ex>rectifiable</ex> mistake</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1202 --></p>

<p><sn>2.</sn> <fld>(Math.)</fld> <def>Admitting, as a curve, of the
construction of a straight line equal in length to any definite portion
of the curve.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rectification</ent><br/
<hw>Rec`ti*fi*ca"tion</hw> <pr>(r?k`t?*f?*k?1sh?n)</pr>, <pos>n.</pos>
<ety>[Cf. F. <ets>rectification</ets>.]</ety> <sn>1.</sn> <def>The act
or operation of rectifying; <as>as, the <ex>rectification</ex> of an
error; the <ex>rectification</ex> of spirits.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>After the <qex>rectification</qex> of his views, he was incapable
of compromise with profounder shapes of error.</q> <rj><qau>De
Quincey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Geom.)</fld> <def>The determination of a straight
line whose length is equal a portion of a curve.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Rectification of a globe</b></col> <fld>(Astron.)</fld>,
<cd>its adjustment preparatory to the solution of a proposed
problem.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rectificator</ent><br/
<hw>Rec"ti*fi*ca`tor</hw> <pr>(r?k"t?*f?*k?`t?r)</pr>, <pos>n.</pos>
<fld>(Chem.)</fld> <def>That which rectifies or refines; esp., a part of
a distilling apparatus in which the more volatile portions are separated
from the less volatile by the process of evaporation and condensation; a
rectifier.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rectifier</ent><br/
<hw>Rec"ti*fi`er</hw> <pr>(r?k"t?*f?`?r)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>One who, or that which, rectifies.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Specifically: <sd>(a)</sd> <fld>(Naut.)</fld> An
instrument used for determining and rectifying the variations of the
compass on board ship. <sd>(b)</sd> <fld>(Chem.)</fld> A
rectificator.</def><-- (Elec.) A device to convert alternating current
to direct current. --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rectify</ent><br/
<hw>Rec"ti*fy</hw> <pr>(-f?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Rectified</conjf> <pr>(-f?d)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Rectifying</conjf> <pr>(-f?`?ng)</pr>.]</vmorph>
<ety>[F. <ets>rectifier</ets>, LL. <ets>rectificare</ets>; L.
<ets>rectus</ets> right + <ets>-ficare</ets> (in comp.) to make. See
<er>Right</er>, and <er>-fy</er>.]</ety> <sn>1.</sn> <def>To make or set
right; to correct from a wrong, erroneous, or false state; to amend;
<as>as, to <ex>rectify</ex> errors, mistakes, or abuses; to
<ex>rectify</ex> the will, the judgment, opinions; to <ex>rectify</ex>
disorders.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>I meant to <qex>rectify</qex> my conscience.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>This was an error of opinion which a conflicting opinion would
have <qex>rectified</qex>.</q> <rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Chem.)</fld> <def>To refine or purify by repeated
distillation or sublimation, by which the fine parts of a substance are
separated from the grosser; <as>as, to <ex>rectify</ex> spirit of
wine</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Com.)</fld> <def>To produce ( as factitious gin or
brandy) by redistilling low wines or ardent spirits (whisky, rum, etc.),
flavoring substances, etc., being added.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- (Elec.) To convert (alternating current) to direct current.
--><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To rectify a globe</b></col>, <cd>to adjust it in order
to prepare for the solution of a proposed problem.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To amend; emend; correct; better; mend; reform;
redress; adjust; regulate; improve. See <er>Amend</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rectilinear</ent><br/
<ent>Rectilineal</ent><br/
<mhw>{ <hw>Rec`ti*lin"e*al</hw> <pr>(-l?n"?*<it>a</it>l)</pr>,
<hw>Rec`ti*lin"e*ar</hw> <pr>(-l?n"?*?r)</pr>, }</mhw> <pos>a.</pos>
<ety>[<ets>Recti-</ets> + <ets>lineal</ets>, <ets>linear</ets>.]</ety>
<def>Straight; consisting of a straight line or lines; bounded by
straight lines; <as>as, a <ex>rectilineal</ex> angle; a
<ex>rectilinear</ex> figure or course.</as></def> --
<wordforms><wf>Rec`ti*lin"e*al*ly</wf>, <pos>adv.</pos> --
<wf>Rec`ti*lin"e*ar*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rectilinearity</ent><br/
<hw>Rec`ti*lin`e*ar"i*ty</hw> <pr>(-?r"?*t?)</pr>, <pos>n.</pos>
<def>The quality or state of being rectilinear.</def>
<rj><au>Coleridge.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rectilineous</ent><br/
<hw>Rec`ti*lin"e*ous</hw> <pr>(-?s)</pr>, <pos>a.</pos>
<def>Rectilinear.</def> <mark>[Obs.]</mark> <rj><au>Ray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rectinerved</ent><br/
<hw>Rec"ti*nerved`</hw> <pr>(r?k"t?*n?rrvd`)</pr>, <pos>a.</pos>
<ety>[<ets>Recti-</ets> + <ets>nerve</ets>.]</ety> <fld>(Bot.)</fld>
<def>Having the veins or nerves straight; -- said of leaves.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rection</ent><br/
<hw>Rec"tion</hw> <pr>(r?k"sh?n)</pr>, <pos>n.</pos> <ety>[L.
<ets>rectio</ets>, fr. <ets>regere</ets> to rule or govern.]</ety>
<fld>(Gram.)</fld> <def>See <er>Government</er>, <pos>n.</pos>, 7.</def>
<rj><au>Gibbs.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rectirostral</ent><br/
<hw>Rec`ti*ros"tral</hw> <pr>(r?k`t?*r?s"tr<it>a</it>l)</pr>,
<pos>a.</pos> <ety>[<ets>Recti-</ets> + <ets>rostral</ets>.]</ety>
<fld>(Zool.)</fld> <def>Having a straight beak.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rectiserial</ent><br/
<hw>Rec`ti*se"ri*al</hw> <pr>(-s?"r?*<it>a</it>l)</pr>, <pos>a.</pos>
<ety>[<ets>Recti-</ets> + <ets>serial</ets>.]</ety> <fld>(Bot.)</fld>
<def>Arranged in exactly vertical ranks, as the leaves on stems of many
kinds; -- opposed to <xex>curviserial</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rectitis</ent><br/
\'d8<hw>Rec*ti"tis</hw> <pr>(r?k*t?"t?s)</pr>, <pos>n.</pos> <ety>[NL.
See <er>Rectum</er>, and <er>-itis</er>.]</ety> <fld>(Med.)</fld>
<def>Proctitis.</def> <rj><au>Dunglison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rectitude</ent><br/
<hw>Rec"ti*tude</hw> <pr>(r?k"t?*t?d)</pr>, <pos>n.</pos> <ety>[L.
<ets>rectitudo</ets>, fr. <ets>rectus</ets> right, straight: cf. F.
<ets>rectitude</ets>. See <er>Right</er>.]</ety> <sn>1.</sn>
<def>Straightness.</def> <mark>[R.]</mark>
<rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Rightness of principle or practice; exact conformity
to truth, or to the rules prescribed for moral conduct, either by divine
or human laws; uprightness of mind; uprightness; integrity; honesty;
justice.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Right judgment.</def> <mark>[R.]</mark> <rj><au>Sir
G. C. Lewis.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- See <er>Justice</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recto-</ent><br/
<hw>Rec"to-</hw> <pr>(r?k"t?*)</pr>. <def>A combining form indicating
<xex>connection with</xex>, or <xex>relation to</xex>, <xex>the
rectum</xex>; <as>as, <ex>recto</ex>-vesical</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recto</ent><br/
<hw>Rec"to</hw>, <pos>n.</pos> <ety>[Abbrev. fr. LL. breve de
<ets>recto</ets>. See <er>Right</er>.]</ety> <fld>(Law)</fld> <def>A
writ of right.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recto</ent><br/
<hw>Rec"to</hw>, <pos>n.</pos> <ety>[Cf. F. <ets>recto</ets>.]</ety>
<fld>(Print.)</fld> <def>The right-hand page; -- opposed to
<xex>verso</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rector</ent><br/
<hw>Rec"tor</hw> <pr>(r?k"t?r)</pr>, <pos>n.</pos> <ety>[L., fr.
<ets>regere</ets>, <ets>rectum</ets>, to lead straight, to rule: cf. F.
<ets>recteur</ets>. See <er>Regiment</er>, <er>Right</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>A ruler or governor.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>God is the supreme <qex>rector</qex> of the world.</q>
<rj><qau>Sir M. Hale.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <sd>(a)</sd> <fld>(Ch. of Eng.)</fld> <def>A clergyman
who has the charge and cure of a parish, and has the tithes, etc.; the
clergyman of a parish where the tithes are not impropriate. See the Note
under Vicar.</def> <au>Blackstone.</au> <sd>(b)</sd> <fld>(Prot. Epis.
Ch.)</fld> <def>A clergyman in charge of a parish.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The head master of a public school.</def>
<mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The chief elective officer of some universities, as
in France and Scotland; sometimes, the head of a college; <as>as, the
<ex>Rector</ex> of Exeter College, or of Lincoln College, at
Oxford</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(R. C. Ch.)</fld> <def>The superior officer or chief
of a convent or religious house; and among the Jesuits the superior of a
house that is a seminary or college.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rectoral</ent><br/
<hw>Rec"tor*al</hw> <pr>(-<it>a</it>l)</pr>, <pos>a.</pos> <ety>[CF. F.
<ets>rectoral</ets>.]</ety> <def>Pertaining to a rector or
governor.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rectorate</ent><br/
<hw>Rec"tor*ate</hw> <pr>(-?t)</pr>, <pos>n.</pos> <ety>[LL.
<ets>rectoratus</ets>: cf. F. <ets>rectorat</ets>.]</ety> <def>The
office, rank, or station of a rector; rectorship.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rectoress</ent><br/
<hw>Rec"tor*ess</hw>, <pos>n.</pos> <sn>1.</sn> <def>A governess; a
rectrix.</def> <rj><au>Drayton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The wife of a rector.</def>
<rj><au>Thackeray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rectorial</ent><br/
<hw>Rec*to"ri*al</hw> <pr>(r?k*t?"r?*<it>a</it>l)</pr>, <pos>a.</pos>
<def>Pertaining to a rector or a rectory; rectoral.</def>
<rj><au>Shipley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rectorship</ent><br/
<hw>Rec"tor*ship</hw> <pr>(r?k"t?r*sh?p)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>Government; guidance.</def> <mark>[Obs.]</mark> <ldquo/The
<xex>rectorship</xex> of judgment.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The office or rank of a rector; rectorate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rectory</ent><br/
<hw>Rec"to*ry</hw> <pr>(-t?*r?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Rectories</plw> <pr>(-r<?/z)</pr>.</plu> <ety>[Cf. OF.
<ets>rectorie</ets> or <ets>rectorerie</ets>, LL.
<ets>rectoria</ets>.]</ety> <sn>1.</sn> <def>The province of a rector; a
parish church, parsonage, or spiritual living, with all its rights,
tithes, and glebes.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A rector's mansion; a parsonage house.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recto-uterine</ent><br/
<hw>Rec`to-u"ter*ine</hw> <pr>(-?"t?r*?n or *?n)</pr>, <pos>a.</pos>
<fld>(Anat.)</fld> <def>Of or pertaining to both the rectum and the
uterus.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rectovaginal</ent><br/
<hw>Rec`to*vag"i*nal</hw> <pr>(r?k`t?*v?j"?*n<it>a</it>l)</pr>,
<pos>a.</pos> <fld>(Anat.)</fld> <def>Of or pertaining to both the
rectum and the vagina.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recto-vesical</ent><br/
<hw>Rec`to-ves"i*cal</hw> <pr>(-v?s"?*k<it>a</it>l)</pr>, <pos>a.</pos>
<fld>(Anat.)</fld> <def>Of or pertaining to both the rectum and the
bladder.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rectress</ent><br/
<hw>Rec"tress</hw> <pr>(r?k"tr?s)</pr>, <pos>n.</pos> <def>A
rectoress.</def> <rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rectrix</ent><br/
\'d8<hw>Rec"trix</hw> <pr>(-tr?ks)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Rectrices</plw> <pr>(-tr<?/"s<?/z)</pr>.</plu>
<ety>[L., fem. of <ets>rector</ets>.]</ety> <sn>1.</sn> <def>A
governess; a rectoress.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>One of the quill feathers of the
tail of a bird.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rectum</ent><br/
<hw>Rec"tum</hw> <pr>(-t?m)</pr>, <pos>n.</pos> <ety>[NL. (sc.
<ets>intestinum</ets>), fr. L. <ets>rectus</ets> straight. See
<er>Right</er>.]</ety> <fld>(Anat.)</fld> <def>The terminal part of the
large intestine; -- so named because supposed by the old anatomists to
be straight. See <xex>Illust.</xex> under <er>Digestive</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rectus</ent><br/
\'d8<hw>Rec"tus</hw> <pr>(-t?s)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Recti</plw> <pr>(-t<?/)</pr>.</plu> <ety>[NL., fr. L.
<ets>regere</ets> to keep straight.]</ety> <fld>(Anat.)</fld> <def>A
straight muscle; <as>as, the <ex>recti</ex> of the eye</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recubation</ent><br/
<hw>Rec`u*ba"tion</hw> <pr>(r?k`?*b?"sh?n)</pr>, <pos>n.</pos> <ety>[L.
<ets>recubare</ets> to lie upon the back.]</ety> <def>Recumbence.</def>
<mark>[Obs.]</mark> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recule</ent><br/
<hw>Re*cule"</hw> <pr>(r?*k?l")</pr>, <pos>v. i.</pos> <def>To
recoil.</def> <mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reculement</ent><br/
<ent>Recule</ent><br/
<mhw>{ <hw>Re*cule"</hw> <pr>(r?*k?l")</pr>, <hw>Re*cule"ment</hw>
<pr>(-m<it>e</it>nt)</pr>, }</mhw> <pos>n.</pos> <ety>[F.
<ets>reculement</ets>.]</ety> <def>Recoil.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recumb</ent><br/
<hw>Re*cumb"</hw> <pr>(-k?m")</pr>, <pos>v. i.</pos> <ety>[L.
<ets>recumbere</ets>; pref. <ets>re-</ets> back + <ets>cumbere</ets> (in
comp.), akin to <ets>cubare</ets> to lie down.]</ety> <def>To lean; to
recline; to repose.</def> <mark>[Obs.]</mark> <rj><au>J. Allen
(1761).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recumbence</ent><br/
<hw>Re*cum"bence</hw> <pr>(r?*k?m"b<it>e</it>ns)</pr>, <pos>n.</pos>
<def>The act of leaning, resting, or reclining; the state of being
recumbent.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recumbency</ent><br/
<hw>Re*cum"ben*cy</hw> <pr>(-b<it>e</it>n*s?)</pr>, <pos>n.</pos>
<def>Recumbence.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recumbent</ent><br/
<hw>Re*cum"bent</hw> <pr>(-b<it>e</it>t)</pr>, <pos>a.</pos> <ety>[L.
<ets>recumbens</ets>, <ets>-entis</ets>, p. pr. of <ets>recumbere</ets>.
See <er>Recumb</er>, <er>Incumbent</er>.]</ety> <def>Leaning; reclining;
lying; <as>as, the <ex>recumbent</ex> posture of the Romans at their
meals</as>. Hence, figuratively; Resting; inactive; idle.</def> --
<wordforms><wf>Re*cum"bent*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recuperable</ent><br/
<hw>Re*cu"per*a*ble</hw> <pr>(r<esl/*k<umac/`p<etil/r*<adot/*b'l)</pr>,
<pos>a.</pos> <ety>[Cf.F. <ets>r<eacute/cup<eacute/rable</ets>. See
<er>Recover</er>.]</ety> <def>Recoverable.</def> <rj><au>Sir T.
Elyot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recuperate</ent><br/
<hw>Re*cu"per*ate</hw> <pr>(-?t)</pr>, <pos>v. i.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Recuperated</conjf>
<pr>(-?`t?d)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Recuperating</conjf>.]</vmorph> <ety>[L. <ets>recuperatus</ets>,
p. p. of <ets>recuperare</ets>. See <er>Recover</er> to get
again.]</ety> <def>To recover health; to regain strength; to
convalesce.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recuperate</ent><br/
<hw>Re*cu"per*ate</hw>, <pos>v. t.</pos> <def>To recover; to regain;
<as>as, to <ex>recuperate</ex> the health or strength</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recuperation</ent><br/
<hw>Re*cu`per*a"tion</hw>
<pr>(r<esl/*k<umac/`p<etil/r*<amac/"sh<ucr/n)</pr>, <pos>n.</pos>
<ety>[L. <ets>recuperatio</ets>: cf. F.
<ets>r<eacute/cup<eacute/ration</ets>.]</ety> <def>Recovery, as of
anything lost, especially of the health or strength.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recuperatory</ent><br/
<ent>Recuperative</ent><br/
<mhw>{ <hw>Re*cu"per*a*tive</hw> <pr>(-?*t?v)</pr>,
<hw>Re*cu"per*a*to*ry</hw> <pr>(-?*t?*r?)</pr>, }</mhw> <pos>a.</pos>
<ety>[L. <ets>recuperativus</ets>, <ets>recuperatorius</ets>.]</ety>
<def>Of or pertaining to recuperation; tending to recovery.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recuperator</ent><br/
<hw>Re*cu"per*a`tor</hw> <pr>(r?*k?"pp?r*?`t?r)</pr>, <pos>n.</pos>
<ety>[Cf. L. <ets>recuperator</ets> a recoverer.]</ety> <fld>(Steel
Manuf.)</fld> <def>Same as <er>Regenerator</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recur</ent><br/
<hw>Re*cur"</hw> <pr>(r?*k?r")</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Recurred</conjf> <pr>(-k?rd")</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>Recurring</conjf>.]</vmorph> <ety>[L.
<ets>recurrere</ets>; pref. <ets>re-</ets> re- + <ets>currere</ets> to
run. See <er>Current</er>.]</ety> <sn>1.</sn> <def>To come back; to
return again or repeatedly; to come again to mind.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>When any word has been used to signify an idea, the old idea will
<qex>recur</qex> in the mind when the word is heard.</q> <rj><qau>I.
Watts.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To occur at a stated interval, or according to some
regular rule; <as>as, the fever will <ex>recur</ex>
to-night</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To resort; to have recourse; to go for
help.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If, to avoid succession in eternal existence, they
<qex>recur</qex> to the <ldquo/punctum stans<rdquo/ of the schools, they
will thereby very little help us to a more positive idea of infinite
duration.</q> <rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Recurring decimal</b></col> <fld>(Math.)</fld>, <cd>a
circulating decimal. See under <er>Decimal</er>.</cd> --
<col><b>Recurring series</b></col> <fld>(Math.)</fld>, <cd>an algebraic
series in which the coefficients of the several terms can be expressed
by means of certain preceding coefficients and constants in one uniform
manner.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recure</ent><br/
<hw>Re*cure"</hw> <pr>(r?*k?r")</pr>, <pos>v. t.</pos> <ety>[Cf.
<er>Recover</er>.]</ety> <sn>1.</sn> <def>To arrive at; to reach; to
attain.</def> <mark>[Obs.]</mark> <rj><au>Lydgate.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To recover; to regain; to repossess.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>When their powers, impaired through labor long,<br/
With due repast, they had <qex>recured</qex> well.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To restore, as from weariness, sickness; or the
like; to repair.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In western waves his weary wagon did <qex>recure</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To be a cure for; to remedy.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>No medicine<br/
Might avail his sickness to <qex>recure</qex>.</q>
<rj><qau>Lydgate.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recure</ent><br/
<hw>Re*cure"</hw>, <pos>n.</pos> <def>Cure; remedy; recovery.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>But whom he hite, without <qex>recure</qex> he dies.</q>
<rj><qau>Fairfax.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recureless</ent><br/
<hw>Re*cure"less</hw>, <pos>a.</pos> <def>Incapable of cure.</def>
<mark>[Obs.]</mark> <rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recurrency</ent><br/
<ent>Recurrence</ent><br/
<mhw>{ <hw>Re*cur"rence</hw> <pr>(r?*k?r"r<it>e</it>ns)</pr>,
<hw>Re*cur"ren*cy</hw> <pr>(-r<it>e</it>n*s?)</pr>, }</mhw>
<pos>n.</pos> <ety>[Cf. F. <ets>r<eacute/currence</ets>.]</ety> <def>The
act of recurring, or state of being recurrent; return; resort;
recourse.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I shall insensibly go on from a rare to a frequent
<qex>recurrence</qex> to the dangerous preparations.</q> <rj><qau>I.
Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recurrent</ent><br/
<hw>Re*cur"rent</hw> <pr>(-r<it>e</it>nt)</pr>, <pos>a.</pos> <ety>[L.
<ets>recurrens</ets>, <ets>-entis</ets>, p. pr. of <ets>recurrere</ets>:
cf.F. <ets>r<eacute/current</ets>. See <er>Recur</er>.]</ety>
<sn>1.</sn> <def>Returning from time to time; recurring; <as>as,
<ex>recurrent</ex> pains</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Anat.)</fld> <def>Running back toward its origin;
<as>as, a <ex>recurrent</ex> nerve or artery</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Recurrent fever</b></col>. <fld>(Med.)</fld> <cd>See
<cref>Relapsing fever</cref>, under <er>Relapsing</er>.</cd> --
<col><b>Recurrent pulse</b></col> <fld>(Physiol.)</fld>, <cd>the pulse
beat which appears (when the radial artery is compressed at the wrist)
on the distal side of the point of pressure through the arteries of the
palm of the hand.</cd> -- <col><b>Recurrent sensibility</b></col>
<fld>(Physiol.)</fld>, <cd>the sensibility manifested by the anterior,
or motor, roots of the spinal cord (their stimulation causing pain)
owing to the presence of sensory fibers from the corresponding sensory
or posterior roots.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recursant</ent><br/
<hw>Re*cur"sant</hw> <pr>(r?*k?r"s<it>a</it>nt)</pr>, <pos>a.</pos>
<ety>[L. <ets>recursans</ets>, <ets>-antis</ets>, p. pr. of
<ets>recursare</ets> to run back, v. freq. of <ets>recurrere</ets>. See
<er>Recure</er>.]</ety> <fld>(Her.)</fld> <def>Displayed with the back
toward the spectator; -- said especially of an eagle.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recursion</ent><br/
<hw>Re*cur"sion</hw> <pr>(-sh?n)</pr>, <pos>n.</pos> <ety>[L.
<ets>recursio</ets>. See <er>Recur</er>.]</ety> <def>The act of
recurring; return.</def> <mark>[Obs.]</mark>
<rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- (Math.) The calculation of a mathematical expression (or a
quantity) by repeating an operation on another expression which was
derived by application of the same operation, on an expression which
itself was the result of similar repeated applications of that same
operation on prior results. The series of operations is terminated by
specifying an initial or terminal condition.<br/
[<source>1913 Webster</source>]</p>

<p> (Computers) A programming technique in which a function calls itself
as a subfunction. Such calls may be repeated in series to arbitrary
depth, provided that a terminating condition is given so that the final
(deepest) call will return a value (rather than continue to recurse),
which then permits the next higher call to return a value, and so forth,
until the original call returns a value to the calling program. --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recurvate</ent><br/
<hw>Re*cur"vate</hw> <pr>(r?*k?r"v?t)</pr>, <pos>a.</pos> <ety>[L.
<ets>recurvatus</ets>, p. p. of <ets>recurvare</ets>. See <er>Re-</er>,
and <er>Curvate</er>.]</ety> <fld>(Bot.)</fld> <def>Recurved.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recurvate</ent><br/
<hw>Re*cur"vate</hw> <pr>(-v?t)</pr>, <pos>v. t.</pos> <def>To bend or
curve back; to recurve.</def> <rj><au>Pennant.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recurvation</ent><br/
<hw>Re`cur*va"tion</hw> <pr>(r?`k?r*v?"sh?n)</pr>, <pos>n.</pos>
<def>The act of recurving, or the state of being recurved; a bending or
flexure backward.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recurve</ent><br/
<hw>Re*curve"</hw> <pr>(r?*k?rv")</pr>, <pos>v. t.</pos> <def>To curve
in an opposite or unusual direction; to bend back or down.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recurved</ent><br/
<hw>Re*curved"</hw> <pr>(r?*k?rvd")</pr>, <pos>a.</pos> <def>Curved in
an opposite or uncommon direction; bent back; <as>as, a bird with a
<ex>recurved</ex> bill; flowers with <ex>recurved</ex>
petals.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recurviroster</ent><br/
<hw>Re*cur`vi*ros"ter</hw> <pr>(r?*k?r`v?*r?s"t?r)</pr>, <pos>n.</pos>
<ety>[L. <ets>recurvus</ets> bent back + <ets>rostrum</ets> beack; cf.
F. <ets>r<eacute/curvirostre</ets>.]</ety> <fld>(Zool.)</fld> <def>A
bird whose beak bends upward, as the avocet.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recurvirostral</ent><br/
<hw>Re*cur`vi*ros"tral</hw> <pr>(-tr<it>a</it>l)</pr>, <pos>a.</pos>
<ety>[See <er>Recurviroster</er>.]</ety> <fld>(Zool.)</fld> <def>Having
the beak bent upwards.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recurvity</ent><br/
<hw>Re*cur"vi*ty</hw> <pr>(r?*k?r"v?*t?)</pr>, <pos>n.</pos>
<def>Recurvation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recurvous</ent><br/
<hw>Re*cur"vous</hw> <pr>(-v?s)</pr>, <pos>a.</pos> <ety>[L.
<ets>recurvus</ets>; pref. <ets>re-</ets> re + <ets>curvus</ets>
curved.]</ety> <def>Recurved.</def> <rj><au>Derham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recusancy</ent><br/
<hw>Re*cu"san*cy</hw> <pr>(r?*k?"z<it>a</it>n*s? <or/ r?k"?-)</pr>,
<pos>n.</pos> <def>The state of being recusant; nonconformity.</def>
<rj><au>Coke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recusant</ent><br/
<hw>Re*cu"sant</hw> <pr>(-z<it>a</it>t; 277)</pr>, <pos>a.</pos><ety>[L.
<ets>recusans</ets>, <ets>-antis</ets>, p. pr. of <ets>recure</ets> to
refuse, to oject to; pref. <ets>re-</ets> re + <ets>causa</ets> a cause,
pretext: cf. F. <ets>r<eacute/cusant</ets>. See <er>Cause</er>, and cf.
<er>Ruse</er>.]</ety> <def>Obstinate in refusal; specifically, in
English history, refusing to acknowledge the supremacy of the king in
the church, or to conform to the established rites of the church;
<as>as, a <ex>recusant</ex> lord</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It stated him to have placed his son in the household of the
Countess of Derby, a <qex>recusant</qex> papist.</q> <rj><qau>Sir W.
Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recusant</ent><br/
<hw>Re*cu"sant</hw>, <pos>n.</pos> <sn>1.</sn> <def>One who is obstinate
in refusal; one standing out stubbornly against general practice or
opinion.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The last rebellious <qex>recusants</qex> among the European family
of nations.</q> <rj><qau>De Quincey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Eng. Hist.)</fld> <def>A person who refuses to
acknowledge the supremacy of the king in matters of religion; <as>as, a
Roman Catholic <ex>recusant</ex>, who acknowledges the supremacy of the
pope</as>.</def> <rj><au>Brande & C.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>One who refuses communion with the Church of
England; a nonconformist.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>All that are <qex>recusants</qex> of holy rites.</q>
<rj><qau>Holyday.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recusation</ent><br/
<hw>Rec`u*sa"tion</hw> <pr>(r?k`?*z?"sh?n)</pr>, <pos>n.</pos> <ety>[L.
<ets>recusatio</ets>: cf. F. <ets>r<eacute/cusation</ets>.]</ety>
<sn>1.</sn> <def>Refusal.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Old Law)</fld> <def>The act of refusing a judge or
challenging that he shall not try the cause, on account of his supposed
partiality.</def> <rj><au>Blackstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Recusative</ent><br/
<hw>Re*cu"sa*tive</hw> <pr>(r?*k?"z?*t?v)</pr>, <pos>a.</pos>
<def>Refusing; denying; negative.</def> <mark>[R.]</mark> <rj><au>Jer.
Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>recuse</ent><br/
<hw>re*cuse"</hw> <pr>(r?*k?z")</pr>, <pos>v. t.</pos> <ety>[F.
<ets>r<eacute/cuser</ets>, or L. <ets>recusare</ets>. See
<er>Recusant</er>.]</ety> <fld>(Law)</fld> <def>To refuse or reject, as
a judge; to challenge that the judge shall not try the cause.</def>
<mark>[Obs.]</mark> <rj><au>Sir K. Digby.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>recuse</ent><br/
<hw>re*cuse"</hw> <pr>(r?*k?z")</pr>, <pos>v. i.</pos> <def>To withdraw
oneself from serving as a judge or other decision-maker in order to
avoid a real or apparent conflict of interest; -- often used with the
reflexive; <as>as, the judge <ex>recused</ex> himself due to a financial
interest in the matter</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Recussion</ent><br/
<hw>Re*cus"sion</hw> <pr>(r?*k?sh"?n)</pr>, <pos>n.</pos> <ety>[L.
<ets>recutire</ets>, <ets>recussum</ets>, to beat back; pref.
<ets>re-</ets> re- + <ets>quatere</ets> to shake.]</ety> <def>The act of
beating or striking back.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Red</ent><br/
<hw>Red</hw> <pr>(r<ecr/d)</pr>, <mark>obs.</mark> <def><pos>imp. & p.
p.</pos> of <er>Read</er>.</def> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Red</ent><br/
<hw>Red</hw>, <pos>v. t.</pos> <def>To put on order; to make tidy; also,
to free from entanglement or embarrassment; -- generally with
<ptcl>up</ptcl>; <as>as, to <ex>red</ex> up a house</as>.</def>
<mark>[Prov. Eng. & Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Red</ent><br/
<hw>Red</hw>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Redder</adjf> <pr>(-d?r)</pr>; <pos>superl.</pos>
<adjf>Reddest</adjf>.]</amorph> <ety>[OE. <ets>red</ets>,
<ets>reed</ets>, AS. <ets>re<aacute/d</ets>, <ets>re<oacute/d</ets>;
akin to OS. <ets>r<omac/d</ets>, OFries. <ets>r<amac/d</ets>, D.
<ets>rood</ets>, G. <ets>roht</ets>, <ets>rot</ets>, OHG.
<ets>r<omac/t</ets>, Dan. & Sw. <ets>r<oum/d</ets>, Icel.
<ets>rau<edh/r</ets>, <ets>rj<omac/<edh/r</ets>, Goth.
<ets>r<aacute/uds</ets>, W. <ets>rhudd</ets>, Armor. <ets>ruz</ets>, Ir.
& Gael. <ets>ruadh</ets>, L. <ets>ruber</ets>, <ets>rufus</ets>, Gr.
<grk>'eryqro`s</grk>, Skr. <ets>rudhira</ets>, <ets>rohita</ets>; cf. L.
<ets>rutilus</ets>. <root/113. Cf. <er>Erysipelas</er>, <er>Rouge</er>,
<er>Rubric</er>, <er>Ruby</er>, <er>Ruddy</er>, <er>Russet</er>,
<er>Rust</er>.]</ety> <def>Of the color of blood, or of a tint
resembling that color; of the hue of that part of the rainbow, or of the
solar spectrum, which is furthest from the violet part.</def>
<ldquo/Fresh flowers, white and <xex>reede</xex>.<rdquo/
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Your color, I warrant you, is as <qex>red</qex> as any rose.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Red</xex> is a general term, including many
different shades or hues, as scarlet, crimson, vermilion, orange red,
and the like.</note><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Red</xex> is often used in the formation of
self-explaining compounds; as, <xex>red</xex>-breasted,
<xex>red</xex>-cheeked, <xex>red</xex>-faced, <xex>red</xex>-haired,
<xex>red</xex>-headed, <xex>red-</xex>skinned, <xex>red</xex>-tailed,
<xex>red-</xex>topped, <xex>red-</xex>whiskered,
<xex>red</xex>-coasted.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Red admiral</b></col> <fld>(Zool.)</fld>, <cd>a beautiful
butterfly (<spn>Vanessa Atalanta</spn>) common in both Europe and
America. The front wings are crossed by a broad orange red band. The
larva feeds on nettles. Called also <altname>Atalanta
butterfly</altname>, and <altname>nettle butterfly</altname>.</cd> --
<col><b>Red ant</b></col>. <fld>(Zool.)</fld> <sd>(a)</sd> <cd>A very
small ant (<spn>Myrmica molesta</spn>) which often infests houses</cd>.
<sd>(b)</sd> <cd>A larger reddish ant (<spn>Formica sanguinea</spn>),
native of Europe and America. It is one of the slave-making
species.</cd> -- <col><b>Red antimony</b></col> <fld>(Min.)</fld>,
<cd>kermesite. See <cref>Kermes mineral</cref> <sd>(b)</sd>, under
<er>Kermes</er>.</cd> -- <col><b>Red ash</b></col> <fld>(Bot.)</fld>,
<cd>an American tree (<spn>Fraxinus pubescens</spn>), smaller than the
white ash, and less valuable for timber.</cd> <au>Cray.</au> --
<col><b>Red bass</b></col>. <fld>(Zool.)</fld> <cd>See <er>Redfish</er>
<sd>(d)</sd>.</cd> -- <col><b>Red bay</b></col> <fld>(Bot.)</fld>, <cd>a
tree (<spn>Persea Caroliniensis</spn>) having the heartwood red, found
in swamps in the Southern United States.</cd> -- <col><b>Red
beard</b></col> <fld>(Zool.)</fld>, <cd>a bright red sponge
(<spn>Microciona prolifera</spn>), common on oyster shells and
stones.</cd> <mark>[Local, U.S.]</mark> -- <col><b>Red birch</b></col>
<fld>(Bot.)</fld>, <cd>a species of birch (<spn>Betula nigra</spn>)
having reddish brown bark, and compact, light-colored wood.</cd>
<au>Gray.</au> -- <col><b>Red blindness</b></col>. <fld>(Med.)</fld>
<cd>See <er>Daltonism</er>.</cd> -- <col><b>Red book</b></col>, <cd>a
book containing the names of all the persons in the service of the
state.</cd> <mark>[Eng.]</mark> -- <col><b>Red book of the
Exchequer</b></col>, <cd>an ancient record in which are registered the
names of all that held lands <xex>per baroniam</xex> in the time of
Henry II.</cd> <au>Brande & C.</au> -- <col><b>Red brass</b></col>,
<cd>an alloy containing eight parts of copper and three of zinc.</cd> --
<col><b>Red bug</b></col>. <fld>(Zool.)</fld> <sd>(a)</sd> <cd>A very
small mite which in Florida attacks man, and produces great irritation
by its bites</cd>. <sd>(b)</sd> <cd>A red hemipterous insect of the
genus <gen>Pyrrhocoris</gen>, especially the European species
(<spn>Pyrrhocoris apterus</spn>), which is bright scarlet and lives in
clusters on tree trunks.</cd> <sd>(c)</sd> <cd>See <cref>Cotton
stainder</cref>, under <er>Cotton</er>.</cd> -- <col><b>Red
cedar</b></col>. <fld>(Bot.)</fld> <cd>An evergreen North American tree
(<spn>Juniperus Virginiana</spn>) having a fragrant red-colored
heartwood.</cd> <sd>(b)</sd> <cd>A tree of India and Australia
(<spn>Cedrela Toona</spn>) having fragrant reddish wood; -- called also
<altname>toon tree</altname> in India.</cd> <-- p. 1203 --> --
<col><b>Red chalk</b></col>. <cd>See under <er>Chalk</er>.</cd> --
<col><b>Red copper</b></col> <fld>(Min.)</fld>, <cd>red oxide of copper;
cuprite.</cd> -- <col><b>Red coral</b></col> <fld>(Zool.)</fld>, <cd>the
precious coral (<spn>Corallium rubrum</spn>). See <xex>Illusts.</xex> of
<er>Coral</er> and <er>Gorgonlacea</er>.</cd> -- <col><b>Red
cross</b></col>. <cd>The cross of St. George, the national emblem of the
English.</cd> <sd>(b)</sd> <cd>The Geneva cross. See <cref>Geneva
convention</cref>, and <cref>Geneva cross</cref>, under
<er>Geneva</er>.</cd> -- <col><b>Red currant</b></col>.
<fld>(Bot.)</fld> <cd>See <er>Currant</er>.</cd> -- <col><b>Red
deer</b></col>. <fld>(Zool.)</fld> <sd>(a)</sd> <cd>The common stag
(<spn>Cervus elaphus</spn>), native of the forests of the temperate
parts of Europe and Asia. It is very similar to the American elk, or
wapiti.</cd> <sd>(b)</sd> <cd>The Virginia deer. See <er>Deer</er>.</cd>
-- <col><b>Red duck</b></col> <fld>(Zool.)</fld>, <cd>a European reddish
brown duck (<spn>Fuligula nyroca</spn>); -- called also
<altname>ferruginous duck</altname>.</cd> -- <col><b>Red
ebony</b></col>. <fld>(Bot.)</fld> <cd>See <er>Grenadillo</er>.</cd> --
<col><b>Red empress</b></col> <fld>(Zool.)</fld>, <cd>a butterfly. See
<er>Tortoise shell</er>.</cd> -- <col><b>Red fir</b></col>
<fld>(Bot.)</fld>, <cd>a coniferous tree (<spn>Pseudotsuga
Douglasii</spn>) found from British Columbia to Texas, and highly valued
for its durable timber. The name is sometimes given to other coniferous
trees, as the Norway spruce and the American <spn>Abies magnifica</spn>
and <spn>Abies nobilis</spn>.</cd> -- <col><b>Red fire</b></col>.
<fld>(Pyrotech.)</fld> <cd>See <cref>Blue fire</cref>, under
<er>Fire</er>.</cd> -- <col><b>Red flag</b></col>. <cd>See under
<er>Flag</er>.</cd> -- <col><b>Red fox</b></col> <fld>(Zool.)</fld>,
<cd>the common American fox (<spn>Vulpes fulvus</spn>), which is usually
reddish in color.</cd> -- <col><b>Red grouse</b></col>
<fld>(Zool.)</fld>, <cd>the Scotch grouse, or ptarmigan. See under
<er>Ptarmigan</er>.</cd> -- <mcol><col><b>Red gum</b></col>, <it>or</it>
<col><b>Red gum-tree</b></col></mcol> <fld>(Bot.)</fld>, <cd>a name
given to eight Australian species of <spn>Eucalyptus</spn>
(<spn>Eucalyptus amygdalina</spn>, <spn>resinifera</spn>, etc.) which
yield a reddish gum resin. See <er>Eucalyptus</er>.</cd> -- <col><b>Red
hand</b></col> <fld>(Her.)</fld>, <cd>a left hand appaum<eacute/,
fingers erect, borne on an escutcheon, being the mark of a baronet of
the United Kingdom of Great Britain and Ireland; -- called also
<cref>Badge of Ulster</cref>.</cd> -- <col><b>Red herring</b></col>,
<cd>the common herring dried and smoked.</cd><-- Fig. something that
merely distracts attention from the basic issue; esp. something
irrelevant to the issue at hand, or something which is not true or does
not exist. --> -- <col><b>Red horse</b></col>. <fld>(Zool.)</fld>
<sd>(a)</sd> <cd>Any large American red fresh-water sucker, especially
<spn>Moxostoma macrolepidotum</spn> and allied species</cd>.
<sd>(b)</sd> <cd>See the Note under <er>Drumfish</er>. -- <col><b>Red
lead</b></col>. <sd>(Chem)</sd> See under <er>Lead</er>, and
<er>Minium</er>.</cd> -- <col><b>Red-lead ore</b></col>.
<fld>(Min.)</fld> <cd>Same as <er>Crocoite</er>.</cd> -- <col><b>Red
liquor</b></col> <fld>(Dyeing)</fld>, <cd>a solution consisting
essentially of aluminium acetate, used as a mordant in the fixation of
dyestuffs on vegetable fiber; -- so called because used originally for
red dyestuffs. Called also <altname>red mordant</altname>.</cd> --
<col><b>Red maggot</b></col> <fld>(Zool.)</fld>, <cd>the larva of the
wheat midge.</cd> -- <col><b>Red manganese</b></col>. <fld>(Min.)</fld>
<cd>Same as <er>Rhodochrosite</er>.</cd> -- <col><b>Red man</b></col>,
<cd>one of the American Indians; -- so called from his color.</cd> --
<col><b>Red maple</b></col> <fld>(Bot.)</fld>, <cd>a species of maple
(<spn>Acer rubrum</spn>). See <er>Maple</er>.</cd> -- <col><b>Red
mite</b></col>. <fld>(Zool.)</fld> <cd>See <cref>Red spider</cref>,
below.</cd> -- <col><b>Red mulberry</b></col> <fld>(Bot.)</fld>, <cd>an
American mulberry of a dark purple color (<spn>Morus rubra</spn>).</cd>
-- <col><b>Red mullet</b></col> <fld>(Zool.)</fld>, <cd>the surmullet.
See <er>Mullet</er>.</cd> -- <col><b>Red ocher</b></col>
<fld>(Min.)</fld>, <cd>a soft earthy variety of hematite, of a reddish
color.</cd> -- <col><b>Red perch</b></col> <fld>(Zool.)</fld>, <cd>the
rosefish.</cd> -- <col><b>Red phosphorus</b></col>. <fld>(Chem.)</fld>
<cd>See under <er>Phosphorus</er>.</cd> -- <col><b>Red pine</b></col>
<fld>(Bot.)</fld>, <cd>an American species of pine (<spn>Pinus
resinosa</spn>); -- so named from its reddish bark.</cd> -- <col><b>Red
precipitate</b></col>. <cd>See under <er>Precipitate</er>.</cd> --
<col><b>Red Republican</b></col> <fld>(European Politics)</fld>,
<cd>originally, one who maintained extreme republican doctrines in
<country>France</country>, -- because a red liberty cap was the badge of
the party; an extreme radical in social reform.</cd> <mark>[Cant]</mark>
-- <col><b>Red ribbon</b></col>, <cd>the ribbon of the Order of the Bath
in England.</cd> -- <col><b>Red sanders</b></col>. <fld>(Bot.)</fld>
<cd>See <er>Sanders</er>.</cd> -- <col><b>Red sandstone</b></col>.
<fld>(Geol.)</fld> <cd>See under <er>Sandstone</er>.</cd> -- <col><b>Red
scale</b></col> <fld>(Zool.)</fld>, <cd>a scale insect (<spn>Aspidiotus
aurantii</spn>) very injurious to the orange tree in
<state>California</state> and <country>Australia</country>.</cd> --
<col><b>Red silver</b></col> <fld>(Min.)</fld>, <cd>an ore of silver, of
a ruby-red or reddish black color. It includes <stype>proustite</stype>,
or light red silver, and <stype>pyrargyrite</stype>, or dark red
silver.</cd> -- <col><b>Red snapper</b></col> <fld>(Zool.)</fld>, <cd>a
large fish (<spn>Lutjanus aya</spn> syn. <spn>Lutjanus
Blackfordii</spn>) abundant in the <geog>Gulf of Mexico</geog> and about
the <state>Florida</state> reefs.</cd> -- <col><b>Red snow</b></col>,
<cd>snow colored by a mocroscopic unicellular alga (<spn>Protococcus
nivalis</spn>) which produces large patches of scarlet on the snows of
arctic or mountainous regions.</cd> -- <col><b>Red softening</b></col>
<fld>(Med.)</fld> <cd>a form of cerebral softening in which the affected
parts are red, -- a condition due either to infarction or
inflammation.</cd> -- <col><b>Red spider</b></col> <fld>(Zool.)</fld>,
<cd>a very small web-spinning mite (<spn>Tetranychus telarius</spn>)
which infests, and often destroys, plants of various kinds, especially
those cultivated in houses and conservatories. It feeds mostly on the
under side of the leaves, and causes them to turn yellow and die. The
adult insects are usually pale red. Called also <altname>red
mite</altname>.</cd> -- <col><b>Red squirrel</b></col>
<fld>(Zool.)</fld>, <cd>the chickaree.</cd> -- <col><b>Red
tape</b></col>, <sd>(a)</sd> <cd>the tape used in public offices for
tying up documents, etc.</cd> <specif>Hence,</specif> <sd>(b)</sd>
<cd>official formality and delay; excessive bureaucratic paperwork.</cd>
-- <col><b>Red underwing</b></col> <fld>(Zool.)</fld>, <cd>any species
of noctuid moths belonging to <gen>Catacola</gen> and allied genera. The
numerous species are mostly large and handsomely colored. The under
wings are commonly banded with bright red or orange.</cd> -- <col><b>Red
water</b></col>, <cd>a disease in cattle, so called from an appearance
like blood in the urine.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Red</ent><br/
<hw>Red</hw> <pr>(r?d)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The color of
blood, or of that part of the spectrum farthest from violet, or a tint
resembling these.</def> <ldquo/Celestial rosy <xex>red</xex>, love's
proper hue.<rdquo/ <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A red pigment.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(European Politics)</fld> <def>An abbreviation for
<xex>Red Republican</xex>. See under Red, <pos>a.</pos></def>
<mark>[Cant]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <pluf>pl.</pluf> <fld>(Med.)</fld> <def>The menses.</def>
<rj><au>Dunglison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- 5. Informal name for a Communist. --><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>English red</b></col>, <cd>a pigment prepared by the
Dutch, similar to Indian red.</cd> -- <col><b>Hypericum red</b></col>,
<cd>a red resinous dyestuff extracted from Hypericum.</cd> --
<col><b>Indian red</b></col>. <cd>See under <er>Indian</er>, and
<er>Almagra</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redact</ent><br/
<hw>Re*dact"</hw> <pr>(r?*d?kt")</pr>, <pos>v. t.</pos> <ety>[L.
<ets>redactus</ets>, p. p. of <ets>redigere</ets>; pref.
<ets>red-</ets>, <ets>re-</ets>, again, back + <ets>agere</ets> to put
in motion, to drive.]</ety> <def>To reduce to form, as literary matter;
to digest and put in shape (matter for publication); to edit.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redacteur</ent><br/
\'d8<hw>R<eacute/`dac`teur"</hw> <pr>(r<asl/`d<adot/k`t<etil/r")</pr>,
<pos>n.</pos> <ety>[F.]</ety> <def>See <er>Redactor</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redaction</ent><br/
<hw>Re*dac"tion</hw> <pr>(r?*d?k"sh?n)</pr>, <pos>n.</pos> <ety>[F.
<ets>r<eacute/daction</ets>.]</ety> <def>The act of redacting; work
produced by redacting; a digest.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redactor</ent><br/
<hw>Re*dac"tor</hw> <pr>(-t?r)</pr>, <pos>n.</pos> <def>One who redacts;
one who prepares matter for publication; an editor.</def>
<rj><au>Carlyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redan</ent><br/
<hw>Re*dan"</hw> <pr>(r?*d?n")</pr>, <pos>n.</pos> <ety>[F., for OF.
<ets>redent</ets> a double notching or jagging, as in the teeth of a
saw, fr. L. pref. <ets>re-</ets> re- + <ets>dens</ets>,
<ets>dentis</ets>, a tooth. Cf. <er>Redented</er>.]</ety>
<altsp>[Written sometimes <asp>redent</asp> and
<asp>redens</asp>.]</altsp> <sn>1.</sn> <fld>(Fort.)</fld> <def>A work
having two parapets whose faces unite so as to form a salient angle
toward the enemy.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A step or vertical offset in a wall on uneven
ground, to keep the parts level.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redargue</ent><br/
<hw>Red*ar"gue</hw> <pr>(r?d*?r"g?)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Redargued</conjf>
<pr>(-g?d)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Redarguing</conjf>.]</vmorph> <ety>[L. <ets>redarguere</ets>;
pref. <ets>red-</ets>, <ets>re-</ets> re- + <ets>arguere</ets> to
accuse, charge with: cf. F. <ets>r<eacute/darguer</ets>.]</ety> <def>To
disprove; to refute; to confute; to reprove; to convict.</def>
<mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>How shall I . . . suffer that God should <qex>redargue</qex> me at
doomsday, and the angels reproach my lukewarmness?</q> <rj><qau>Jer.
Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Now this objection to the immediate cognition of external objects
has, as far as I know, been <qex>redargued</qex> in three different
ways.</q> <rj><qau>Sir W. Hamilton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redargution</ent><br/
<hw>Red`ar*gu"tion</hw> <pr>(r?d`?r*g?"sh?n)</pr>, <pos>n.</pos>
<ety>[L. <ets>redargutio</ets>.]</ety> <def>The act of redarguing;
refutation.</def> <mark>[Obs. or R.]</mark> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redargutory</ent><br/
<hw>Red`ar*gu"to*ry</hw> <pr>(-t?*r?)</pr>, <pos>a.</pos>
<def>Pertaining to, or containing, redargution; refutatory.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redback</ent><br/
<hw>Red"back`</hw> <pr>(r?d"b?k`)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>The dunlin.</def> <mark>[U. S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redbelly</ent><br/
<hw>Red"bel`ly</hw> <pr>(-b?l`l?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>The char.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redbird</ent><br/
<hw>Red"bird`</hw> <pr>(-b?rd`)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<sd>(a)</sd> <def>The cardinal bird.</def> <sd>(b)</sd> <def>The summer
redbird (<spn>Piranga rubra</spn>).</def> <sd>(c)</sd> <def>The scarlet
tanager. See <er>Tanager</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redbreast</ent><br/
<hw>Red"breast`</hw> <pr>(-br?st`)</pr>, <pos>n.</pos> <sn>1.</sn>
<fld>(Zool.)</fld> <sd>(a)</sd> <def>The European robin.</def>
<sd>(b)</sd> <def>The American robin. See <er>Robin</er>.</def>
<sd>(c)</sd> <def>The knot, or red-breasted snipe; -- called also
<altname>robin breast</altname>, and <altname>robin snipe</altname>. See
<er>Knot</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>The long-eared pondfish. See
<er>Pondfish</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redbud</ent><br/
<hw>Red"bud`</hw> <pr>(-b?d`)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>A small ornamental leguminous tree of the American species of the
genus <gen>Cercis</gen>. See <cref>Judas tree</cref>, under
<er>Judas</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redcap</ent><br/
<hw>Red"cap`</hw>, <pos>n.</pos> <sn>1.</sn> <fld>(Zool.)</fld> <def>The
European goldfinch.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A specter having long teeth, popularly supposed to
haunt old castles in Scotland.</def> <mark>[Scot.]</mark>
<rj><au>Jamieson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redcoat</ent><br/
<hw>Red"coat`</hw> <pr>(-k<omac/t`)</pr>, <pos>n.</pos> <def>One who
wears a red coat; specifically, a red-coated British soldier.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Red Cross</ent><br/
<hw>Red Cross</hw>. <sn>1.</sn> <def>The crusaders or the cause they
represented.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>A hospital or ambulance service established as a
result of, though not provided for by, the Geneva convention of 1864;
any of the national societies for alleviating the sufferings of the sick
and wounded war, also giving aid and relief during great calamities;
also, a member or worker of such a society; -- so called from the badge
of neutrality; the Geneva cross.</def> <note>In islamic countries, a
similarly motivated affiliated organization is called the <contr>Red
Crescent</contr>. The American Red Cross was founded in 1881, largely
due to the initiative of Clara Barton. The <a
href="http://www.redcross.org">American Red Cross</a> maintains a web
page on the internet, where additional information can be
found.</note><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><ent>Redde</ent><br/
<hw>Red"de</hw> <pr>(-de)</pr>, <def><pos>obs. imp.</pos> of
<er>Read</er>, or <er>Rede</er>.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redden</ent><br/
<hw>Red"den</hw> <pr>(r?d"d'n)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Reddened</conjf> <pr>(-d'nd)</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>Reddening</conjf>.]</vmorph> <ety>[From
<er>Red</er>, <pos>a.</pos>]</ety> <def>To make red or somewhat red; to
give a red color to.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redden</ent><br/
<hw>Red"den</hw>, <pos>v. i.</pos> <def>To grow or become red; to
blush.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Appius <qex>reddens</qex> at each word you speak.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He no sooner saw that her eye glistened and her cheek
<qex>reddened</qex> than his obstinacy was at once subbued.</q>
<rj><qau>Sir W. SCott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reddendum</ent><br/
\'d8<hw>Red*den"dum</hw> <pr>(r?d*d?n"d?m)</pr>, <pos>n.</pos>
<ety>[Neut. of L. <ets>reddendus</ets> that must be given back or
yielded, gerundive of <ets>reddere</ets>. See <er>Reddition</er>.]</ety>
<fld>(Law)</fld> <def>A clause in a deed by which some new thing is
reserved out of what had been granted before; the clause by which rent
is reserved in a lease.</def> <rj><au>Cruise.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reddish</ent><br/
<hw>Red"dish</hw> <pr>(r?d"d?sh)</pr>, <pos>a.</pos> <def>Somewhat red;
moderately <er>red</er>.</def> -- <wordforms><wf>Red"dish*ness</wf>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reddition</ent><br/
<hw>Red*di"tion</hw> <pr>(r?d*d?sh"?n)</pr>, <pos>n.</pos><ety>[L.
<ets>redditio</ets>, fr. <ets>reddere</ets> to give back, to return: cf.
F. <ets>reddition</ets>. See <er>Render</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Restoration: restitution: surrender.</def>
<rj><au>Howell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Explanation; representation.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>reddition</qex> or application of the comparison.</q>
<rj><qau>Chapman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redditive</ent><br/
<hw>Red"di**tive</hw> <pr>(r?d"d?*t?v)</pr>, <pos>a.</pos> <ety>[L.
<ets>redditivus</ets>.]</ety> <fld>(Gram.)</fld> <def>Answering to an
interrogative or inquiry; conveying a reply; <as>as, <ex>redditive</ex>
words</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reddle</ent><br/
<hw>Red"dle</hw> <pr>(r?d"d'l)</pr>, <pos>n.</pos> <ety>[From
<er>Red</er>; cf. G. <ets>r<oum/thel</ets>. Cf. <er>Ruddle</er>.]</ety>
<fld>(Min.)</fld> <def>Red chalk. See under <er>Chalk</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Red-dog flour</ent><br/
<ent>Red dog</ent><br/
<mhw>{ <hw>Red dog</hw>, <it>or</it> <hw>Red`-dog" flour</hw> }</mhw>.
<def>The lowest grade of flour in milling. It is dark and of little
expansive power, is secured largely from the germ or embryo and adjacent
parts, and contains a relatively high percentage of protein. It is
chiefly useful as feed for farm animals.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Reddour</ent><br/
<hw>Red"dour</hw> <pr>(r?d"d?r)</pr>, <pos>n.</pos> <ety>[F.
<ets>raideur</ets>, fr. <ets>raide</ets> stiff.]</ety> <def>Rigor;
violence.</def> <mark>[Obs.]</mark> <rj><au>Gower.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rede</ent><br/
<hw>Rede</hw> <pr>(r?d)</pr>, <pos>v. t.</pos> <ety>[See <er>Read</er>,
<pos>v. t.</pos>]</ety> <sn>1.</sn> <def>To advise or counsel.</def>
<mark>[Obs. or Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I <qex>rede</qex> that our host here shall begin.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To interpret; to explain.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>My sweven [dream] <qex>rede</qex> aright.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rede</ent><br/
<hw>Rede</hw>, <pos>n.</pos> <ety>[See <er>Read</er>,
<pos>n.</pos>]</ety> <sn>1.</sn> <def>Advice; counsel; suggestion.</def>
<mark>[Obs. or Scot.]</mark> <rj><au>Burns.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>There was none other remedy ne <qex>reed</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A word or phrase; a motto; a proverb; a wise
saw.</def> <mark>[Obs.]</mark> <ldquo/This <xex>rede</xex> is
rife.<rdquo/ <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redeem</ent><br/
<hw>Re*deem"</hw> <pr>(r?*d?m")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Redeemed</conjf>. (-d<?/md");
<pos>p. pr. & vb. n.</pos> <conjf>Redeeming</conjf>.]</vmorph> <ety>[F.
<ets>r<eacute/dimer</ets>, L. <ets>redimere</ets>; pref.
<ets>red-</ets>, <ets>re-</ets> re- + <ets>emere</ets>,
<ets>emptum</ets>, to buy, originally, to take, cf. OIr. <ets>em</ets>
(in comp.), Lith. <ets>imti</ets>. Cf. <er>Assume</er>,
<er>Consume</er>, <er>Exempt</er>, <er>Premium</er>, <er>Prompt</er>,
<er>Ransom</er>.]</ety> <sn>1.</sn> <def>To purchase back; to regain
possession of by payment of a stipulated price; to repurchase.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If a man sell a dwelling house in a walled city, then he may
<qex>redeem</qex> it within a whole year after it is sold.</q>
<rj><qau>Lev. xxv. 29.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> Hence, specifically: <sd>(a)</sd> <fld>(Law)</fld>
<def>To recall, as an estate, or to regain, as mortgaged property, by
paying what may be due by force of the mortgage.</def> <sd>(b)</sd>
<fld>(Com.)</fld> <def>To regain by performing the obligation or
condition stated; to discharge the obligation mentioned in, as a
promissory note, bond, or other evidence of debt; <as>as, to
<ex>redeem</ex> bank notes with coin</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To ransom, liberate, or rescue from captivity or
bondage, or from any obligation or liability to suffer or to be
forfeited, by paying a price or ransom; to ransom; to rescue; to
recover; <as>as, to <ex>redeem</ex> a captive, a pledge, and the
like</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Redeem</qex> Israel, O God, out of all his troubles.</q>
<rj><qau>Ps. xxv. 22.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The Almighty from the grave<br/
Hath me <qex>redeemed</qex>.</q> <rj><qau>Sandys.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Theol.)</fld> <def>Hence, to rescue and deliver
from the bondage of sin and the penalties of God's violated
law.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Christ hath <qex>redeemed</qex> us from the curse of the law,
being made a curse for us.</q> <rj><qau>Gal. iii. 13.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To make good by performing fully; to fulfill;
<as>as, to <ex>redeem</ex> one's promises.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>I will <qex>redeem</qex> all this on Percy's head.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To pay the penalty of; to make amends for; to serve
as an equivalent or offset for; to atone for; to compensate; <as>as, to
<ex>redeem</ex> an error</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Which of ye will be mortal, to <qex>redeem</qex><br/
Man's mortal crime?</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>It is a chance which does <qex>redeem</qex> all sorrows.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To redeem the time</b></col>, <cd>to make the best use of
it.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redeemability</ent><br/
<hw>Re*deem`a*bil"i*ty</hw> <pr>(-?*b?l"?*t?)</pr>, <pos>n.</pos>
<def>Redeemableness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redeemable</ent><br/
<hw>Re*deem"a*ble</hw> <pr>(-?*b;l)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Capable of being redeemed; subject to repurchase; held under
conditions permitting redemption; <as>as, a pledge securing the payment
of money is <ex>redeemable</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Subject to an obligation of redemption; conditioned
upon a promise of redemption; payable; due; <as>as, bonds, promissory
notes, etc.</as> , <xex>redeemable</xex> in gold, or in current money,
or four months after date.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redeemableness</ent><br/
<hw>Re*deem"a*ble*ness</hw> <pr>(r?*d?m"?*b'l*n?s)</pr>, <pos>n.</pos>
<def>The quality or state of being redeemable; redeem ability.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redeemer</ent><br/
<hw>Re*deem"er</hw> <pr>(r?*d?m"?r)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>One who redeems.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Specifically, the Savior of the world, Jesus
Christ.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redeless</ent><br/
<hw>Rede"less</hw> <pr>(r?d"l?s)</pr>, <pos>a.</pos> <def>Without rede
or counsel.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redeliberate</ent><br/
<hw>Re`de*lib"er*ate</hw> <pr>(r?`d?*l?b"?r*?t)</pr>, <pos>v. t. &
i.</pos> <def>To deliberate again; to reconsider.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redeliver</ent><br/
<hw>Re`de*liv"er</hw> <pr>(r?`d?*l?v"?r)</pr>, <pos>v. t.</pos>
<sn>1.</sn> <def>To deliver or give back; to return.</def>
<rj><au>Ay<?/iffe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To deliver or liberate a second time or
again.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To report; to deliver the answer of.</def>
<mark>[R.]</mark> <ldquo/Shall I <xex>redeliver</xex> you e'en
so?<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redeliverance</ent><br/
<hw>Re`de*liv"er*ance</hw> <pr>(-<it>a</it>ns)</pr>, <pos>n.</pos>
<def>A second deliverance.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redelivery</ent><br/
<hw>Re`de*liv"er*y</hw> <pr>(-?)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>Act of delivering back.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A second or new delivery or liberation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redemand</ent><br/
<hw>Re`de*mand"</hw> <pr>(r<emac/`d<esl/*m<acr/nd" <i>or</i>
r<emac/`d<esl/*m<adot/nd")</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>re-</ets> back, again + <ets>demand</ets>: cf. F.
<ets>redemander</ets>.]</ety> <def>To demand back; to demand
again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redemand</ent><br/
<hw>Re`de*mand"</hw>, <pos>n.</pos> <def>A demanding back; a second or
renewed demand.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redemise</ent><br/
<hw>Re`de*mise"</hw> <pr>(r<emac/`d<esl/*m<imac/z")</pr>, <pos>v.
t.</pos> <def>To demise back; to convey or transfer back, as an
estate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redemise</ent><br/
<hw>Re`de*mise"</hw>, <pos>n.</pos> <fld>(Law)</fld> <def>The transfer
of an estate back to the person who demised it; reconveyance; <as>as,
the demise and <ex>redemise</ex> of an estate</as>. See under
<er>Demise</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redemonstrate</ent><br/
<hw>Re*dem"on*strate</hw> <pr>(r?*d?m"?n*str?t <or/
r?`d?*m?n"-str?t)</pr>, <pos>v. t.</pos> <def>To demonstrate again, or
anew.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Every truth of morals must be <qex>redemonstrated</qex> in the
experience of the individual man before he is capable of utilizing it as
a constituent of character or a guide in action.</q>
<rj><qau>Lowell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redemptible</ent><br/
<hw>Re*demp"ti*ble</hw> <pr>(r<esl/*d<ecr/mp"t<icr/*b'l)</pr>,
<pos>a.</pos> <def>Redeemable.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>redemption</ent><br/
<hw>re*demp"tion</hw> <pr>(r<esl/*d<ecr/mp"sh<ucr/n)</pr>, <pos>n.</pos>
<ety>[F. <ets>r<eacute/demption</ets>, L. <ets>redemptio</ets>. See
<er>redeem</er>, and cf. <er>ransom</er>.]</ety> <def>The act of
redeeming, or the state of being redeemed; repurchase; ransom; release;
rescue; deliverance; <as>as, the <ex>redemption</ex> of prisoners taken
in war; the <ex>redemption</ex> of a ship and cargo</as>.</def>
Specifically: <sd>(a)</sd> <fld>(Law)</fld> <def>The liberation of an
estate from a mortgage, or the taking back of property mortgaged, upon
performance of the terms or conditions on which it was conveyed; also,
the right of redeeming and reentering upon an estate mortgaged. See
<cref>Equity of redemption</cref>, under <er>Equity</er>.</def>
<sd>(b)</sd> <fld>(Com.)</fld> <def>Performance of the obligation stated
in a note, bill, bond, or other evidence of debt, by making payment to
the holder.</def> <sd>(c)</sd> <fld>(Theol.)</fld> <def>The procuring of
God's favor by the sufferings and death of Christ; the ransom or
deliverance of sinners from the bondage of sin and the penalties of
God's violated law.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In whom we have <qex>redemption</qex> through his blood.</q>
<rj><qau>Eph. i. 7.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redemptionary</ent><br/
<hw>Re*demp"tion*a*ry</hw> <pr>(-?*r?)</pr>, <pos>n.</pos> <def>One who
is, or may be, redeemed.</def> <mark>[R.]</mark>
<rj><au>Hakluyt.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redemptioner</ent><br/
<hw>Re*demp"tion*er</hw> <pr>(-?r)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>One who redeems himself, as from debt or servitude.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Formerly, one who, wishing to emigrate from Europe
to America, sold his services for a stipulated time to pay the expenses
of his passage.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redemptionist</ent><br/
<hw>Re*demp"tion*ist</hw>, <pos>n.</pos> <fld>(R.C.Ch.)</fld> <def>A
monk of an order founded in 1197; -- so called because the order was
especially devoted to the redemption of Christians held in captivity by
the Mohammedans. Called also <altname>Trinitarian</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redemptive</ent><br/
<hw>Re*demp"tive</hw> <pr>(-t?v)</pr>, <pos>a.</pos> <def>Serving or
tending to redeem; redeeming; <as>as, the <ex>redemptive</ex> work of
Christ</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redemptorist</ent><br/
<hw>Re*demp"tor*ist</hw> <pr>(-t?r*?st)</pr>, <pos>n.</pos> <ety>[F.
<ets>r<eacute/demptoriste</ets>, fr. L. <ets>redemptor</ets> redeemer,
from <ets>redinere</ets>. See <er>Redeem</er>.]</ety>
<fld>(R.C.Ch.)</fld> <def>One of the Congregation of the Most Holy
Redeemer, founded in Naples in 1732 by St. Alphonsus Maria de Liquori.
It was introduced onto the United States in 1832 at Detroit. The Fathers
of the Congregation devote themselves to preaching to the neglected,
esp. in missions and retreats, and are forbidden by their rule to engage
in the instruction of youth.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redemptory</ent><br/
<hw>Re*demp"to*ry</hw> <pr>(-t?*r?)</pr>, <pos>a.</pos> <def>Paid for
ransom; serving to redeem.</def> <ldquo/Hector's <xex>redemptory</xex>
price.<rdquo/ <rj><au>Chapman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redempture</ent><br/
<hw>Re*demp"ture</hw> <pr>(-t?r; 135)</pr>, <pos>n.</pos>
<def>Redemption.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redented</ent><br/
<hw>Re*dent"ed</hw> <pr>(r?*d?nt"?d)</pr>, <pos>a.</pos> <ety>[From OF.
<ets>redent</ets>. See <er>Redan</er>.]</ety> <def>Formed like the teeth
of a saw; indented.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redeposit</ent><br/
<hw>Re`de*pos"it</hw> <pr>(r?`d?*p?z"?t)</pr>, <pos>v. t.</pos> <def>To
deposit again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redescend</ent><br/
<hw>Re`de*scend"</hw> <pr>(-s?nd")</pr>, <pos>v. i.</pos> <ety>[Pref.
<ets>re-</ets> + <ets>descend</ets>: cf. F.
<ets>redescendre</ets>.]</ety> <def>To descend again.</def>
<rj><au>Howell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redevelop</ent><br/
<hw>Re`de*vel"op</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <sn>1.</sn>
<def>To develop again;</def> <specif>specif.</specif>
<fld>(Photog.)</fld>, <def>to intensify (a developed image), as by
bleaching with mercuric chloride and subsequently subjecting anew to a
developing agent.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>to rebuild an urban area, usually commercial but
sometimes residential; -- typically involving some portion of government
involvement and expenditure.</def><br/
[<source>PJC</source>]</p>

<p> -- <wordforms><wf>Re`de*vel"op*er</wf> <pr>(#)</pr>, <pos>n.</pos>
-- <wf>Re`de*vel"op*ment</wf> <pr>(#)</pr>,
<pos>n.</pos></wordforms><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Redevelopment</ent><br/
<hw>Re`de*vel"op*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>the
rebuilding of an urban area, usually a commercial district but sometimes
residential or industrial, and typically involving some portion of
government involvement and expenditure; <as>to organize a municipal
<ex>redevelopment</ex> agency</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Redeye</ent><br/
<hw>Red"eye`</hw> <pr>(r<ecr/d"<imac/`)</pr>, <pos>n.</pos> <sn>1.</sn>
<fld>(Zool.)</fld> <sd>(a)</sd> <def>The rudd.</def> <sd>(b)</sd>
<def>Same as <er>Redfish</er> <sd>(d)</sd>.</def> <sd>(c)</sd> <def>The
goggle-eye, or fresh-water rock bass.</def> <mark>[Local,
U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A scheduled public conveyance, such as a train or
airplane, which travels late at night or overnight.</def>
<mark>[Colloq.]</mark> <br/
[<source>PJC</source>]</p>

<p><ent>Redfin</ent><br/
<hw>Red"fin`</hw> <pr>(-f?n`)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>A small North American dace (<spn>Minnilus cornutus</spn>, or
<spn>Notropis megalops</spn>). The male, in the breeding season, has
bright red fins. Called also <altname>red dace</altname>, and
<altname>shiner</altname>. Applied also to <spn>Notropis ardens</spn>,
of the Mississippi valley.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redfinch</ent><br/
<hw>Red"finch`</hw> <pr>(-f<icr/nch`)</pr>, <pos>n.</pos>
<fld>(Zool.)</fld> <def>The European linnet.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redfish</ent><br/
<hw>Red"fish`</hw> <pr>(r<ecr/d"f<icr/sh`)</pr>, <pos>n.</pos>
<fld>(Zool.)</fld> <sd>(a)</sd> <def>The blueback salmon of the North
Pacific; -- called also <altname>nerka</altname>. See <er>Blueback</er>
<sd>(b)</sd>.</def> <sd>(b)</sd> <def>The rosefish.</def> <sd>(c)</sd>
<def>A large California labroid food fish (<spn>Trochocopus
pulcher</spn>); -- called also <altname>fathead</altname>.</def>
<sd>(d)</sd> <def>The red bass, red drum, or drumfish. See the Note
under <er>Drumfish</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Red-gum</ent><br/
<hw>Red"-gum`</hw> <pr>(-g?m`)</pr>, <pos>n.</pos> <ety>[OE. <ets>reed
gounde</ets>; AS. <ets>re<aacute/d</ets> red + <ets>gund</ets> matter,
pus.]</ety> <sn>1.</sn> <fld>(Med.)</fld> <def>An eruption of red
pimples upon the face, neck, and arms, in early infancy; tooth rash;
strophulus.</def> <rj><au>Good.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A name of rust on grain. See
<er>Rust</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1204 --></p>

<p><ent>Red-handed</ent><br/
<ent>Red-hand</ent><br/
<mhw>{ <hw>Red"-hand`</hw> <pr>(r?d"h?nd`)</pr>, <hw>Red"-hand`ed</hw>
<pr>(-h?nd`?d)</pr>, }</mhw> <pos>a. <or/ adv.</pos> <def>Having hands
red with blood; in the very act, as if with red or bloody hands; -- said
of a person taken in the act of homicide; hence, fresh from the
commission of crime; <as>as, he was taken <ex>red-hand</ex> or
<ex>red-handed</ex></as>.</def> <-- usu. caught red-handed --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redhead</ent><br/
<hw>Red"head`</hw> <pr>(-h?d`)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A
person having red hair.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <sd>(a)</sd> <def>An American duck
(<spn>Aythya Americana</spn>) highly esteemed as a game bird. It is
closely allied to the canvasback, but is smaller and its head brighter
red. Called also <altname>red-headed duck</altname>. <altname>American
poachard</altname>, <altname>grayback</altname>, and <altname>fall
duck</altname>. See <xex>Illust.</xex> under <er>Poachard</er>.</def>
<sd>(b)</sd> <def>The red-headed woodpecker. See
<er>Woodpecker</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Bot.)</fld> <def>A kind of milkweed (<spn>Asclepias
Curassavica</spn>) with red flowers. It is used in medicine.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redhibition</ent><br/
<hw>Red`hi*bi"tion</hw> <pr>(r?d`h?*b?sh"?n)</pr>, <pos>n.</pos>
<ety>[L. <ets>redhibitio</ets> a taking back.]</ety> <fld>(Civil
Law)</fld> <def>The annulling of a sale, and the return by the buyer of
the article sold, on account of some defect.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redhibitory</ent><br/
<hw>Red*hib"i*to*ry</hw> <pr>(r?d*h?b"?*t?*r?)</pr>, <pos>a.</pos>
<ety>[L. <ets>redhibitorius</ets>.]</ety> <fld>(Civil Law)</fld> <def>Of
or pertaining to redhibition; <as>as, a <ex>redhibitory</ex> action or
fault</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redhoop</ent><br/
<hw>Red"hoop`</hw> <pr>(r?d"h??p`)</pr>, <pos>n.</pos>
<fld>(Zool.)</fld> <def>The male of the European bullfinch.</def>
<mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redhorn</ent><br/
<hw>Red"horn`</hw> <pr>(-h?rn`)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>Any species of a tribe of butterflies (<spn>Fugacia</spn>)
including the common yellow species and the cabbage butterflies. The
antennae are usually red.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Red-hot</ent><br/
<hw>Red"-hot`</hw> <pr>(-h?t`)</pr>, <pos>a.</pos> <def>Red with heat;
heated to redness; <as>as, <ex>red-hot</ex> iron; <ex>red-hot</ex>
balls</as>. Hence, figuratively, excited; violent; <as>as, a
<ex>red-hot</ex> radical</as>.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redia</ent><br/
\'d8<hw>Re"di*a</hw> <pr>(r?"d?*?)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> L. <plw>Rediae</plw> (-<emac/), E. <plw>Redias</plw>
<pr>(-<?/z)</pr>.</plu> <ety>[NL.; of uncertain origin.]</ety>
<fld>(Zool.)</fld> <def>A kind of larva, or nurse, which is prroduced
within the sporocyst of certain trematodes by asexual generation. It in
turn produces, in the same way, either another generation of rediae, or
else cercariae within its own body. Called also
<altname>proscolex</altname>, and <altname>nurse</altname>. See
<xex>Illustration</xex> in Appendix.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redient</ent><br/
<hw>Re"di*ent</hw> <pr>(r?"d?-<it>e</it>nt)</pr>, <pos>a.</pos> <ety>[L.
<ets>rediens</ets>, p. pr. of <ets>redire</ets> to return; pref.
<ets>red-</ets> + <ets>ire</ets> to go.]</ety> <def>Returning.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redif</ent><br/
\'d8<hw>Re*dif"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Turk.
<ets>red<imac/f</ets>, fr. <ets>rad<imac/f</ets>, orig., he who rides
behind another on the same beast, fr. <ets>radaf</ets> to follow.]</ety>
<def>A reserve force in the Turkish army, or a soldier of the reserve.
See <er>Army organization</er>, above.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Redigest</ent><br/
<hw>Re`di*gest"</hw> <pr>(r?`d?*j?st")</pr>, <pos>v. t.</pos> <def>To
digest, or reduce to form, a second time.</def>
<rj><au>Kent.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rediminish</ent><br/
<hw>Re`di*min"ish</hw> <pr>(-m?n"?sh)</pr>, <pos>v. t.</pos> <def>To
diminish again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redingote</ent><br/
<hw>Red"in*gote</hw> <pr>(r<ecr/d"<icr/n*g<omac/t)</pr>, <pos>n.</pos>
<ety>[F., corrupted from E. <ets>riding coat</ets>.]</ety> <def>A long
plain double-breasted outside coat for women.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redintegrate</ent><br/
<hw>Re*din"te*grate</hw> <pr>(r?*d?n"t?*gr?t)</pr>, <pos>a.</pos>
<ety>[L. <ets>redintegratus</ets>, p. p. of <ets>redintegrare</ets> to
restore; pref. <ets>red-</ets>, <ets>re-</ets>, re- +
<ets>integrare</ets> to make whole, to renew, fr. <ets>integer</ets>
whole. See <er>Integer</er>.]</ety> <def>Restored to wholeness or a
perfect state; renewed.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redintegrate</ent><br/
<hw>Re*din"te*grate</hw> <pr>(-gr?t)</pr>, <pos>v. t.</pos> <def>To make
whole again; a renew; to restore to integrity or soundness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The English nation seems obliterated. What could
<qex>redintegrate</qex> us again?</q> <rj><qau>Coleridge.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redintegration</ent><br/
<hw>Re*din`te*gra"tion</hw> <pr>(-gr?"sh?n)</pr>, <pos>n.</pos> <ety>[L.
<ets>redintegratio</ets>.]</ety> <sn>1.</sn> <def>Restoration to a whole
or sound state; renewal; renovation.</def> <rj><au>Dr. H.
More.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Chem.)</fld> <def>Restoration of a mixed body or
matter to its former nature and state.</def> <mark>[Achaic.]</mark>
<rj><au>Coxe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Psychology)</fld> <def>The law that objects which
have been previously combined as part of a single mental state tend to
recall or suggest one another; -- adopted by many philosophers to
explain the phenomena of the association of ideas.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redirect</ent><br/
<hw>Re`di*rect"</hw> <pr>(r?`d?*r?kt")</pr>, <pos>a.</pos>
<fld>(Law)</fld> <def>Applied to the examination of a witness, by the
party calling him, after the cross-examination.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redisburse</ent><br/
<hw>Re`dis*burse"</hw> <pr>(r?`d?s*b?rs")</pr>, <pos>v. t.</pos> <def>To
disburse anew; to give, or pay, back.</def>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rediscover</ent><br/
<hw>Re`dis*cov"er</hw> <pr>(-k?v"?r)</pr>, <pos>v. t.</pos> <def>To
discover again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redispose</ent><br/
<hw>Re`dis*pose"</hw> <pr>(-p?z")</pr>, <pos>v. t.</pos> <def>To dispose
anew or again; to readjust; to rearrange.</def> <rj><au>A.
Baxter.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redisseize</ent><br/
<hw>Re`dis*seize"</hw> <pr>(-s?z")</pr>, <pos>v. t.</pos>
<fld>(Law)</fld> <def>To disseize anew, or a second time.</def>
<altsp>[Written also <asp>redisseise</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redisseizin</ent><br/
<hw>Re`dis*sei"zin</hw> <pr>(-s?"z?n)</pr>, <pos>n.</pos>
<fld>(Law)</fld> <def>A disseizin by one who once before was adjudged to
have dassezed the same person of the same lands, etc.; also, a writ
which lay in such a case.</def> <rj><au>Blackstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redisseizor</ent><br/
<hw>Re`dis*sei"zor</hw> <pr>(-z?r)</pr>, <pos>n.</pos> <fld>(Law)</fld>
<def>One who redisseizes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redissolve</ent><br/
<hw>Re`dis*solve"</hw> <pr>(r?`d?z*z?lv")</pr>, <pos>v. t.</pos> <def>To
dissolve again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redistill</ent><br/
<hw>Re`dis*till"</hw> <pr>(r?`d?s*t?l")</pr>, <pos>v. t.</pos> <def>To
distill again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redistrainer</ent><br/
<hw>Re`dis*train"er</hw> <pr>(-tr?n"?r)</pr>, <pos>n.</pos> <def>One who
distrains again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redistribute</ent><br/
<hw>Re`dis*trib"ute</hw> <pr>(-tr?b"?t)</pr>, <pos>v. t.</pos> <def>To
distribute again.</def><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Re*dis`tri*bu"tion</wf>
<pr>(-tr<?/*b<?/"sh<?/n)</pr>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redistrict</ent><br/
<hw>Re*dis"trict</hw> <pr>(-tr?kt)</pr>, <pos>v. t.</pos> <def>To divide
into new districts.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redition</ent><br/
<hw>Re*di"tion</hw> <pr>(r?*d?sh"?n)</pr>, <pos>n.</pos> <ety>[L.
<ets>reditio</ets>, fr. <ets>redire</ets>. See <er>Redient</er>.]</ety>
<def>Act of returning; return.</def> <mark>[Obs.]</mark>
<rj><au>Chapman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redivide</ent><br/
<hw>Re`di*vide"</hw> <pr>(r?`d?*v?d")</pr>, <pos>v. t.</pos> <def>To
divide anew.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redivivus</ent><br/
\'d8<hw>Red`i*vi"vus</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L., fr.
pref. <ets>red-</ets>, <ets>re-</ets>, re- + <ets>vivus</ets>
alive.]</ety> <def>Living again; revived; restored.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Redlegs</ent><br/
<ent>Redleg</ent><br/
<mhw>{ <hw>Red"leg`</hw> <pr>(r?d"l?g`)</pr>, <hw>Red`legs`</hw>
<pr>(-l?gz`)</pr>, }</mhw> <pos>n.</pos> <fld>(Zool.)</fld> <sd>(a)</sd>
<def>The redshank.</def> <sd>(b)</sd> <def>The turnstone.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Red-letter</ent><br/
<hw>Red"-let`ter</hw> <pr>(-l?t`t?r)</pr>, <pos>a.</pos> <def>Of or
pertaining to a red letter; marked by red letters.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Red-letter day</b></col>, <cd>a day that is fortunate or
auspicious; -- so called in allusion to the custom of marking holy days,
or saints' days, in the old calendars with red letters.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Red-light district</ent><br/
<hw>Red-light district</hw>. <def>A district or neighborhood in which
houses of prostitution are located; -- so called in allusion to the red
light kept in front of many such resorts at night.</def> <mark>[Colloq.
or Cant]</mark><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><ent>Red light</ent><br/
<hw>Red light</hw>. <sn>1.</sn> <def>an electrically operated set of
lights at a road intersection which has different lights visible to
traffic from different directions, designed to control vehicle traffic
through the intersection. Each set of lights typically has a colored red
light and also green and amber lights; the color of the light which is
lighted at any one time changes automatically to control the flow of
traffic through the intersection, allowing flow from different
directions in alternating succession. Also called <altname><er>traffic
light</er></altname>, <altname>traffic signal</altname> or
<altname><er>stop light</er></altname>. When the red light is
illuminated the signal means to stop; green means to go; and amber means
to stop or procede through the intersection with caution. In simple
intersections of two roads, a red light visible to traffic on one road
will usually be accompanied by a green light visible to traffic on the
intersecting road. In some locations the lights may be set to be
illuminated in other sequences or combinations; a blinking red light is
typically equivalent to a <ldquo/stop<rdquo/ sign, and a blinking amber
light typically means <ldquo/procede with caution<rdquo/.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>the condition of a traffic light when the signal
visible to the driver of a vehicle is red, signalling that the vehicle
must stop and not enter the intersection; <as>I got seven <ex>red
lights</ex> on the way to work</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>figuratively, a sign or signal that one must stop
doing what one is presently doing; <as>as, a fatal side effect is often
a <ex>red light</ex> to continuation of a clinical trial</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Redly</ent><br/
<hw>Red"ly</hw>, <pos>adv.</pos> <def>In a red manner; with
redness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redmouth</ent><br/
<hw>Red"mouth`</hw> <pr>(-mouth`)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>Any one of several species of marine food fishes of the genus
<gen>Diabasis</gen>, or <gen>Haemulon</gen>, of the Southern United
States, having the inside of the mouth bright red. Called also
<altname>flannelmouth</altname>, and <altname>grunt</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redness</ent><br/
<hw>Red"ness</hw>, <pos>n.</pos> <ety>[AS. <ets>re<aacute/dness</ets>.
See <er>Red</er>.]</ety> <def>The quality or state of being red; red
color.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redolency</ent><br/
<ent>Redolence</ent><br/
<mhw>{ <hw>Red"o*lence</hw> <pr>(r?d"?*l<it>e</it>ns)</pr>,
<hw>Red"o*len*cy</hw> <pr>(-l<it>e</it>n*s?)</pr>, }</mhw> <pos>n.</pos>
<def>The quality of being redolent; sweetness of scent; pleasant odor;
fragrance.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redolent</ent><br/
<hw>Red"o*lent</hw> <pr>(-l<it>e</it>nt)</pr>, <pos>a.</pos> <ety>[L.
<ets>redolens</ets>, <ets>-entis</ets>, p. pr. of <ets>redolere</ets> to
emit a scent, diffuse an odor; pref. <ets>red-</ets>, <ets>re-</ets>,
re- + <ets>olere</ets> to emit a smell. See <er>Odor</er>.]</ety>
<def>Diffusing odor or fragrance; spreading sweet scent; scented;
odorous; smelling; -- usually followed by <xex>of</xex>.</def>
<ldquo/Honey <xex>redolent</xex> of spring.<rdquo/ <au>Dryden.</au> --
<wordforms><wf>Red"o*lent*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><q>Gales . . . <qex>redolent</qex> of joy and youth.</q>
<rj><qau>Gray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redouble</ent><br/
<hw>Re*dou"ble</hw> <pr>(r?*d?b"'l)</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>re-</ets> + <ets>double</ets>: cf. F. <ets>redoubler</ets>. Cf.
<er>Reduplicate</er>.]</ety> <def>To double again or repeatedly; to
increase by continued or repeated additions; to augment greatly; to
multiply.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>So they<br/
Doubly <qex>redoubled</qex> strokes upon the foe.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- v. t. 2. (Contract bridge) To bid a redouble.<br/
[<source>1913 Webster</source>]</p>

<p> <pos>n.</pos> An optional bid made by the side currently holding the
highest bid for the contract, after the opposing side has doubled. This
bid increases the score for successfully making the contract, and
increases the penalties for failing. The score or penalty depends on the
number of tricks over or under the contract, according to a defined
schedule, and depending on the vulnerability of the side attempting the
contract. --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redouble</ent><br/
<hw>Re*dou"ble</hw>, <pos>v. i.</pos> <def>To become greatly or
repeatedly increased; to be multiplied; to be greatly augmented; <as>as,
the noise <ex>redoubles</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redoubt</ent><br/
<hw>Re*doubt"</hw> <pr>(r?*dout")</pr>, <pos>n.</pos> <ety>[F.
<ets>redoute</ets>, fem., It. <ets>ridotto</ets>, LL.
<ets>reductus</ets>, literally, a retreat, from L. <ets>reductus</ets>
drawn back, retired, p. p. of <ets>reducere</ets> to lead or draw back;
cf. F. <ets>r<eacute/duit</ets>, also fr. LL. <ets>reductus</ets>. See
<er>Reduce</er>, and cf. <er>Reduct</er>, <er>R<eacute/duit</er>,
<er>Ridotto</er>.]</ety> <fld>(Fort.)</fld> <sd>(a)</sd> <def>A small,
and usually a roughly constructed, fort or outwork of varying shape,
commonly erected for a temporary purpose, and without flanking defenses,
-- used esp. in fortifying tops of hills and passes, and positions in
hostile territory.</def> <sd>(b)</sd> <def>In permanent works, an
outwork placed within another outwork. See <xex>F</xex> and <xex>i</xex>
in <xex>Illust.</xex> of <er>Ravelin</er>.</def> <altsp>[Written also
<asp>redout</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redoubt</ent><br/
<hw>Re*doubt"</hw>, <pos>v. t.</pos> <ety>[F. <ets>redouter</ets>,
formerly also spelt <ets>redoubter</ets>; fr. L. pref. <ets>re-</ets>
re- + <ets>dubitare</ets> to doubt, in LL., to fear. See
<er>Doubt</er>.]</ety> <def>To stand in dread of; to regard with fear;
to dread.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redoubtable</ent><br/
<hw>Re*doubt"a*ble</hw> <pr>(-?*b'l)</pr>, <pos>a.</pos> <ety>[F.
<ets>redoutable</ets>, formerly also spelt
<ets>redoubtable</ets>.]</ety> <def>Formidable; dread; terrible to foes;
<as>as, a <ex>redoubtable</ex> hero</as>; hence, valiant; -- often in
contempt or burlesque.</def> <altsp>[Written also
<asp>redoutable</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redoubted</ent><br/
<hw>Re*doubt"ed</hw>, <pos>a.</pos> <def>Formidable; dread.</def>
<ldquo/Some <xex>redoubted</xex> knight.<rdquo/
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Lord regent, and <qex>redoubted</qex> Burgandy.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redoubting</ent><br/
<hw>Re*doubt"ing</hw>, <pos>n.</pos> <def>Reverence; honor.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>In <qex>redoutyng</qex> of Mars and of his glory.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redound</ent><br/
<hw>Re*dound"</hw> <pr>(r?*dound")</pr>, <pos>v. i.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Redounded</conjf>; <pos>p. pr. &
vb. n.</pos> <conjf>Redounding</conjf>.]</vmorph> <ety>[F.
<ets>redonder</ets>, L. <ets>redundare</ets>; pref. <ets>red</ets>-,
<ets>re-</ets>, re- + <ets>undare</ets> to rise in waves or surges, fr.
<ets>unda</ets> a wave. See <er>Undulate</er>, and cf.
<er>Redundant</er>.]</ety> <sn>1.</sn> <def>To roll back, as a wave or
flood; to be sent or driven back; to flow back, as a consequence or
effect; to conduce; to contribute; to result.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The evil, soon<br/
Driven back, <qex>redounded</qex> as a flood on those<br/
From whom it sprung.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The honor done to our religion ultimately <qex>redounds</qex> to
God, the author of it.</q> <rj><qau>Rogers.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q> both . . . will devour great quantities of paper, there will no
small use <qex>redound</qex> from them to that manufacture.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To be in excess; to remain over and above; to be
redundant; to overflow.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>For every dram of honey therein found,<br/
A pound of gall doth over it <qex>redound</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redound</ent><br/
<hw>Re*dound"</hw>, <pos>n.</pos> <sn>1.</sn> <def>The coming back, as
of consequence or effect; result; return; requital.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We give you welcome; not without <qex>redound</qex><br/
Of use and glory to yourselves ye come.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Rebound; reverberation.</def> <mark>[R.]</mark>
<rj><au>Codrington.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redowa</ent><br/
<hw>Red"ow*a</hw> <pr>(r?d"?*?)</pr>, <pos>n.</pos> <ety>[F., fr.
Bohemian.]</ety> <def>A Bohemian dance of two kinds, one in triple time,
like a waltz, the other in two-four time, like a polka. The former is
most in use.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redpole</ent><br/
<hw>Red"pole`</hw> <pr>(r?d"p?l`)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>Same as <er>Redpoll</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redpoll</ent><br/
<hw>Red"poll`</hw> <pr>(-p?l`)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<sd>(a)</sd> <def>Any one of several species of small northern finches
of the genus <gen>Acanthis</gen> (formerly <gen>Aegiothus</gen>), native
of Europe and America. The adults have the crown red or rosy. The male
of the most common species (<spn>Acanthis linarius</spn>) has also the
breast and rump rosy. Called also <altname>redpoll linnet</altname>. See
<xex>Illust.</xex> under <er>Linnet</er>.</def> <sd>(b)</sd> <def>The
common European linnet.</def> <sd>(c)</sd> <def>The American redpoll
warbler (<spn>Dendroica palmarum</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redraft</ent><br/
<hw>Re*draft"</hw> <pr>(r<emac/*dr<adot/ft")</pr>, <pos>v. t.</pos>
<def>To draft or draw anew.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redraft</ent><br/
<hw>Re*draft"</hw>, <pos>n.</pos> <sn>1.</sn> <def>A second draft or
copy.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Com.)</fld> <def>A new bill of exchange which the
holder of a protected bill draws on the drawer or indorsers, in order to
recover the amount of the protested bill with costs and
charges.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redraw</ent><br/
<hw>Re*draw"</hw> <pr>(r<emac/*dr<add/")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp.</pos> <conjf>Redrew</conjf>
<pr>(r<emac/*dr<udd/")</pr>;<pos>p. p.</pos> <conjf>Redrawn</conjf>
<pr>(r<emac/*dr<add/n")</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Redrawing</conjf>.]</vmorph> <def>To draw again; to make a second
draft or copy of; to redraft.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redraw</ent><br/
<hw>Re*draw"</hw>, <pos>v. i.</pos> <fld>(Com.)</fld> <def>To draw a new
bill of exchange, as the holder of a protested bill, on the drawer or
indorsers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redress</ent><br/
<hw>Re*dress"</hw> <pr>(r<emac/*dr<ecr/s")</pr>, <pos>v. t.</pos>
<ety>[Pref. <ets>re-</ets> + <ets>dress</ets>.]</ety> <def>To dress
again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redress</ent><br/
<hw>Re*dress"</hw> <pr>(r<esl/*dr<ecr/s")</pr>, <pos>v. t.</pos>
<ety>[F. <ets>redresser</ets> to straighten; pref. <ets>re-</ets> re- +
<ets>dresser</ets> to raise, arrange. See <er>Dress.</er>]</ety>
<sn>1.</sn> <def>To put in order again; to set right; to emend; to
revise.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The common profit could she <qex>redress</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>In yonder spring of roses intermixed<br/
With myrtle, find what to <qex>redress</qex> till noon.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Your wish that I should <qex>redress</qex> a certain paper which
you had prepared.</q> <rj><qau>A. Hamilton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To set right, as a wrong; to repair, as an injury;
to make amends for; to remedy; to relieve from.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Those wrongs, those bitter injuries, . . . <br/
I doubt not but with honor to <qex>redress</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To make amends or compensation to; to relieve of
anything unjust or oppressive; to bestow relief upon.</def> <ldquo/'T is
thine, O king! the afflicted to <xex>redress</xex>.<rdquo/
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Will Gaul or Muscovite <qex>redress ye</qex>?</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redress</ent><br/
<hw>Re*dress"</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act of
redressing; a making right; reformation; correction; amendment.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Reformation of evil laws is commendable, but for us the more
necessary is a speedy <qex>redress</qex> of ourselves.</q>
<rj><qau>Hooker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A setting right, as of wrong, injury, or opression;
<as>as, the <ex>redress</ex> of grievances</as>; hence, relief; remedy;
reparation; indemnification.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A few may complain without reason; but there is occasion for
<qex>redress</qex> when the cry is universal.</q>
<rj><qau>Davenant.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>One who, or that which, gives relief; a
redresser.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Fair majesty, the refuge and <qex>redress</qex><br/
Of those whom fate pursues and wants oppress.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redressal</ent><br/
<hw>Re*dress"al</hw> <pr>(r?*dr?s"<it>a</it>l)</pr>, <pos>n.</pos>
<def>Redress.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redresser</ent><br/
<hw>Re*dress"er</hw> <pr>(-?r)</pr>, <pos>n.</pos> <def>One who
redresses.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redressible</ent><br/
<hw>Re*dress"i*ble</hw> <pr>(-?*b'l)</pr>, <pos>a.</pos> <def>Such as
may be redressed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redressive</ent><br/
<hw>Re*dress"ive</hw> <pr>(-?v)</pr>, <pos>a.</pos> <def>Tending to
redress.</def> <rj><au>Thomson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redressless</ent><br/
<hw>Re*dress"less</hw>, <pos>a.</pos> <def>Not having redress; such as
can not be redressed; irremediable.</def>
<rj><au>Sherwood.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redressment</ent><br/
<hw>Re*dress"ment</hw> <pr>(-m<it>e</it>nt)</pr>, <pos>n.</pos>
<ety>[Cf. F. <ets>redressement</ets>.]</ety> <def>The act of redressing;
redress.</def> <rj><au>Jefferson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Red-riband</ent><br/
<hw>Red"-rib`and</hw> <pr>(r?d"r?b`<it>a</it>nd)</pr>, <pos>n.</pos>
<fld>(Zool.)</fld> <def>The European red band fish, or fireflame. See
<er>Rend fish</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redroot</ent><br/
<hw>Red"root`</hw> <pr>(r?d"r?t`)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>A name of several plants having red roots, as the New Jersey tea
(see under <er>Tea</er>), the gromwell, the bloodroot, and the
<xex>Lachnanthes tinctoria</xex>, an endogenous plant found in sandy
swamps from Rhode Island to Florida.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redsear</ent><br/
<hw>Red`sear"</hw> <pr>(r?d`s?r")</pr>, <pos>v. i.</pos> <def>To be
brittle when red-hot; to be red-short.</def>
<rj><au>Moxon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redshank</ent><br/
<hw>Red"shank`</hw> <pr>(r?d"sh?nk`)</pr>, <pos>n.</pos> <sn>1.</sn>
<fld>(Zool.)</fld> <sd>(a)</sd> <def>A common Old World limicoline bird
(<spn>Totanus calidris</spn>), having the legs and feet pale red. The
spotted redshank (<spn>Totanus fuscus</spn>) is larger, and has
orange-red legs. Called also <altname>redshanks</altname>,
<altname>redleg</altname>, and <altname>clee</altname>.</def>
<sd>(b)</sd> <def>The fieldfare.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A bare-legged person; -- a contemptuous appellation
formerly given to the Scotch Highlanders, in allusion to their bare
legs.</def> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Red-short</ent><br/
<hw>Red"-short`</hw> <pr>(-sh?rt`)</pr>, <pos>a.</pos>
<fld>(Metal.)</fld> <def>Hot-short; brittle when red-hot; -- said of
certain kinds of iron.</def> -- <wordforms><wf>Red"-short`ness</wf>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redskin</ent><br/
<hw>Red"skin`</hw> <pr>(-sk?n`)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A
common appellation for a North American Indian; -- so called from the
color of the skin. It is now considered pejorative by some persons of
North American Indian heritage.</def> <rj><au>Cooper.</au></rj><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <fld>(Football)</fld> <def>A member of the
<memberof><org>Washington Redskins</org></memberof>, a football
team.</def><br/
[<source>PJC</source>]</p>

<p><ent>Redstart</ent><br/
<hw>Red"start`</hw> <pr>(-st?rt`)</pr>, <pos>n.</pos>
<ety>[<ets>Red</ets> + <ets>start</ets> tail.]</ety> <fld>(Zool.)</fld>
<sd>(a)</sd> <def>A small, handsome European singing bird
(<spn>Phoenicurus phoenicurus</spn>, formerly <spn>Ruticilla
phoenicurus</spn>), allied to the nightingale; -- called also
<altname>redtail</altname>, <altname>brantail</altname>,
<altname>fireflirt</altname>, <altname>firetail</altname>. The black
redstart is <spn>Phoenicurus ochruros</spn> (formerly <spn>Phoenicurus
tithys</spn>), and is now rare and protected by law in England. The name
is also applied to several other species of <spn>Ruticilla</spn> and
allied genera, native of India.</def> <sd>(b)</sd> <def>An American
fly-catching warbler (<spn>Setophaga ruticilla</spn>). The male is
black, with large patches of orange-red on the sides, wings, and tail.
The female is olive, with yellow patches.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Redstreak</ent><br/
<hw>Red"streak`</hw> <pr>(-str?k`)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>A kind of apple having the skin streaked with red and yellow, -- a
favorite English cider apple.</def> <rj><au>Mortimer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Cider pressed from redstreak apples.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redtail</ent><br/
<hw>Red"tail`</hw> <pr>(-t?l`)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<sd>(a)</sd> <def>The red-tailed hawk.</def> <sd>(b)</sd> <def>The
European redstart.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Red-tailed</ent><br/
<hw>Red"-tailed`</hw> <pr>(-t?ld`)</pr>, <pos>a.</pos> <def>Having a red
tail.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Red-tailed hawk</b></col> <fld>(Zool.)</fld>, <cd>a large
North American hawk (<spn>Buteo borealis</spn>). When adult its tail is
chestnut red. Called also <altname>hen hawck</altname>, and
<altname>red-tailed buzzard</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Red-tape</ent><br/
<hw>Red"-tape`</hw> <pr>(-t?p`)</pr>, <pos>a.</pos> <def>Pertaining to,
or characterized by, official formality. See <cref>Red tape</cref>,
under <er>Red</er>, <pos>a.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Red-tapism</ent><br/
<hw>Red`-tap"ism</hw> <pr>(r?d`t?p"?z'm)</pr>, <pos>n.</pos> <def>Strict
adherence to official formalities.</def> <rj><au>J. C.
Shairp.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Red-tapist</ent><br/
<hw>Red`-tap"ist</hw>, <pos>n.</pos> <def>One who is tenacious of a
strict adherence to official formalities.</def> <rj><au>Ld.
Lytton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redthroat</ent><br/
<hw>Red"throat`</hw> <pr>(r?d"thr?t`)</pr>, <pos>n.</pos>
<fld>(Zool.)</fld> <def>A small Australian singing bird
(<spn>Phyrrholaemus brunneus</spn>). The upper parts are brown, the
center of the throat red.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redtop</ent><br/
<hw>Red"top`</hw> <pr>(-t?p`)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>A kind of grass (<spn>Agrostis vulgaris</spn>) highly valued in the
United States for pasturage and hay for cattle; -- called also
<altname>English grass</altname>, and in some localities <altname>herd's
grass</altname>. See <xex>Illustration</xex> in Appendix. The tall
redtop is <spn>Triodia seslerioides</spn>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redub</ent><br/
<hw>Re*dub"</hw> <pr>(r<esl/*d<ucr/b")</pr>, <pos>v. t.</pos> <ety>[F.
<ets>radouber</ets> to refit or repair.]</ety> <sn>1.</sn> <def>To
refit; to repair, or make reparation for; hence, to repay or
requite.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>It shall be good that you <qex>redub</qex> that negligence.</q>
<rj><qau>Wyatt.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>God shall give power to <qex>redub</qex> it with some like
requital to the French.</q> <rj><qau>Grafton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To dub again.</def><br/
[<source>PJC</source>]</p>

<p><ent>Reduce</ent><br/
<hw>Re*duce"</hw> <pr>(r<esl/*d<umac/s")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Reduced</conjf>
<pr>(-d<umac/st")</pr>,; <pos>p. pr. & vb. n.</pos>
<conjf>Reducing</conjf> <pr>(-d<umac/"s<icr/ng)</pr>.]</vmorph> <ety>[L.
<ets>reducere</ets>, <ets>reductum</ets>; pref. <ets>red-</ets>.
<ets>re-</ets>, re- + <ets>ducere</ets> to lead. See <er>Duke</er>, and
cf. <er>Redoubt</er>, <pos>n.</pos>]</ety> <sn>1.</sn> <def>To bring or
lead back to any former place or condition.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>And to his brother's house <qex>reduced</qex> his wife.</q>
<rj><qau>Chapman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The sheep must of necessity be scattered, unless the great
Shephered of souls oppose, or some of his delegates <qex>reduce</qex>
and direct us.</q> <rj><qau>Evelyn.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To bring to any inferior state, with respect to
rank, size, quantity, quality, value, etc.; to diminish; to lower; to
degrade; to impair; <as>as, to <ex>reduce</ex> a sergeant to the ranks;
to <ex>reduce</ex> a drawing; to <ex>reduce</ex> expenses; to
<ex>reduce</ex> the intensity of heat</as>.</def> <ldquo/An ancient but
<xex>reduced</xex> family.<rdquo/ <rj><au>Sir W. Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Nothing so excellent but a man may fasten upon something belonging
to it, to <qex>reduce</qex> it.</q> <rj><qau>Tillotson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Having <qex>reduced</qex><br/
Their foe to misery beneath their fears.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Hester Prynne was shocked at the condition to which she found the
clergyman <qex>reduced</qex>.</q> <rj><qau>Hawthorne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To bring to terms; to humble; to conquer; to subdue;
to capture; <as>as, to <ex>reduce</ex> a province or a
fort</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1205 --></p>

<p><sn>4.</sn> <def>To bring to a certain state or condition by
grinding, pounding, kneading, rubbing, etc.; <as>as, to <ex>reduce</ex>
a substance to powder, or to a pasty mass; to <ex>reduce</ex> fruit,
wood, or paper rags, to pulp.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>It were but right<br/
And equal to <qex>reduce</qex> me to my dust.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To bring into a certain order, arrangement,
classification, etc.; to bring under rules or within certain limits of
descriptions and terms adapted to use in computation; <as>as, to
<ex>reduce</ex> animals or vegetables to a class or classes; to
<ex>reduce</ex> a series of observations in astronomy; to
<ex>reduce</ex> language to rules.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Arith.)</fld> <sd>(a)</sd> <def>To change, as
numbers, from one denomination into another without altering their
value, or from one denomination into others of the same value; <as>as,
to <ex>reduce</ex> pounds, shillings, and pence to pence, or to
<ex>reduce</ex> pence to pounds; to <ex>reduce</ex> days and hours to
minutes, or minutes to days and hours.</as></def> <sd>(b)</sd> <def>To
change the form of a quantity or expression without altering its value;
<as>as, to <ex>reduce</ex> fractions to their lowest terms, to a common
denominator, etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Chem.)</fld> <def>To add an electron to an atom or
ion.</def> <specif>Specifically:</specif> <def>To remove oxygen from; to
deoxidize.</def> <fld>(Metallurgy)</fld> <def>To bring to the metallic
state by separating from combined oxygen and impurities; <as>as, metals
are <ex>reduced</ex> from their ores</as>.</def> <fld>(Chem.)</fld>
<def>To combine with, or to subject to the action of, hydrogen or any
other reducing agent; <as>as, ferric iron is <ex>reduced</ex> to ferrous
iron; aldehydes can be <ex>reduced</ex> to alcohols by lithium
hydride;</as> -- opposed to <ant>oxidize</ant>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>8.</sn> <fld>(Med.)</fld> <def>To restore to its proper place or
condition, as a displaced organ or part; <as>as, to <ex>reduce</ex> a
dislocation, a fracture, or a hernia</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Reduced iron</b></col> <fld>(Chem.)</fld>, <cd>metallic
iron obtained through deoxidation of an oxide of iron by exposure to a
current of hydrogen or other reducing agent. When hydrogen is used the
product is called also <stype>iron by hydrogen</stype>.</cd> --
<col><b>To reduce an equation</b></col> <fld>(Alg.)</fld>, <cd>to bring
the unknown quantity by itself on one side, and all the known quantities
on the other side, without destroying the equation.</cd> -- <col><b>To
reduce an expression</b></col> <fld>(Alg.)</fld>, <cd>to obtain an
equivalent expression of simpler form.</cd> -- <col><b>To reduce a
square</b></col> <fld>(Mil.)</fld>, <cd>to reform the line or column
from the square.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To diminish; lessen; decrease; abate; shorten;
curtail; impair; lower; subject; subdue; subjugate; conquer.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reducement</ent><br/
<hw>Re*duce"ment</hw> <pr>(r?*d?s"m<it>e</it>nt)</pr>, <pos>n.</pos>
<def>Reduction.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reducent</ent><br/
<hw>Re*du"cent</hw> <pr>(r?*d?"s<it>e</it>nt)</pr>, <pos>a.</pos>
<ety>[L. <ets>reducens</ets>, p. pr. of <ets>reducere</ets>.]</ety>
<def>Tending to reduce.</def> -- <def2><pos>n.</pos> <def>A reducent
agent.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reducer</ent><br/
<hw>Re*du"cer</hw> <pr>(-s?r)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One
who, or that which, reduces.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mach.)</fld> <sd>(a)</sd> <def>A contrivance for
reducing the dimensions of one part so as to fit it to another, as a
reducing coupling, or a device for holding a drilling a chuck.</def>
<sd>(b)</sd> <def>A reducing motion.</def> <sd>(c)</sd> <def>A reducing
valve.</def> <sd>(d)</sd> <def>A hydraulic device for reducing pressure
and hence increasing movement, used to transmit the load from the
hydraulic support of the lower shackle to the lever weighing apparatus
in some kinds of heavy testing machines.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>3.</sn> <fld>(Photog.)</fld> <def>A reducing agent, either a
developer or an agent for reducing density.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>4.</sn> <fld>(Chem.)</fld> <def>a reducing agent.</def><br/
[<source>PJC</source>]</p>

<p><ent>Reducible</ent><br/
<hw>Re*du"ci*ble</hw> <pr>(-s?*b'll)</pr>, <pos>a.</pos> <def>Capable of
being reduced.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reducibleness</ent><br/
<hw>Re*du"ci*ble*ness</hw>, <pos>n.</pos> <def>Quality of being
reducible.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reducing</ent><br/
<hw>Re*du"cing</hw> <pr>(r?*d?"s?ng)</pr>, <def><pos>a & n.</pos> from
<er>Reduce</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Reducing furnace</b></col> <fld>(Metal.)</fld>, <cd>a
furnace for reducing ores.</cd> -- <col><b>Reducing pipe
fitting</b></col>, <cd>a pipe fitting, as a coupling, an elbow, a tee,
etc., for connecting a large pipe with a smaller one.</cd> --
<col><b>Reducing valve</b></col>, <cd>a device for automatically
maintaining a diminished pressure of steam, air, gas, etc., in a pipe,
or other receiver, which is fed from a boiler or pipe in which the
pressure is higher than is desired in the receiver.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reducing agent</ent><br/
<hw>Re*du"cing a`gent</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Chem.)</fld> <def>a substance that causes reduction of another
substance in a chemical reaction, as by donating electrons or adding
hydrogen atoms; <as>as, lithium hydride is a powerful <ex>reducing
agent</ex></as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Reduct</ent><br/
<hw>Re*duct"</hw> <pr>(r<esl/*d<ucr/kt")</pr>, <pos>v. t.</pos> <ety>[L.
<ets>reductus</ets>, p. p. of <ets>reducere</ets>. See
<er>Reduce</er>.]</ety> <def>To reduce.</def> <mark>[Obs.]</mark>
<rj><au>W. Warde.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reductibility</ent><br/
<hw>Re*duc`ti*bil"i*ty</hw> <pr>(r?*d?k`t?*b?l"?*t?)</pr>, <pos>n.</pos>
<def>The quality of being reducible; reducibleness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reduction</ent><br/
<hw>Re*duc"tion</hw> <pr>(r<esl/*d<ucr/k"sh<ucr/n)</pr>, <pos>n.</pos>
<ety>[F. <ets>r<eacute/duction</ets>, L. <ets>reductio</ets>. See
<er>Reduce</er>.]</ety> <sn>1.</sn> <def>The act of reducing, or state
of being reduced; conversion to a given state or condition; diminution;
conquest; <as>as, the <ex>reduction</ex> of a body to powder; the
<ex>reduction</ex> of things to order; the <ex>reduction</ex> of the
expenses of government; the <ex>reduction</ex> of a rebellious
province.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Arith. & Alg.)</fld> <def>The act or process of
reducing. See <er>Reduce</er>, <pos>v. t.</pos>, 6. and <cref>To reduce
an equation</cref>, <cref>To reduce an expression</cref>, under
<er>Reduce</er>, <pos>v. t.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Astron.)</fld> <sd>(a)</sd> <def>The correction of
observations for known errors of instruments, etc.</def> <sd>(b)</sd>
<def>The preparation of the facts and measurements of observations in
order to deduce a general result.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The process of making a copy of something, as a
figure, design, or draught, on a smaller scale, preserving the proper
proportions.</def> <rj><au>Fairholt.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Logic)</fld> <def>The bringing of a syllogism in
one of the so-called imperfect modes into a mode in the first
figure.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Chem. & Metal.)</fld> <def>The act, process, or
result of reducing{7}; <as>as, the <ex>reduction</ex> of iron from its
ores; the <ex>reduction</ex> of an aldehyde into an
alcohol</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Med.)</fld> <def>The operation of restoring a
dislocated or fractured part to its former place.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Reduction ascending</b></col> <fld>(Arith.)</fld>,
<cd>the operation of changing numbers of a lower into others of a higher
denomination, as cents to dollars.</cd> -- <col><b>Reduction
descending</b></col> <fld>(Arith.)</fld>, <cd>the operation of changing
numbers of a higher into others of a lower denomination, as dollars to
cents.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Diminution; decrease; abatement; curtailment;
subjugation; conquest; subjection.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reductive</ent><br/
<hw>Re*duc"tive</hw> <pr>(-t?v)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>r<eacute/ductif</ets>.]</ety> <def>Tending to reduce; having the
power or effect of reducing.</def> -- <def2><pos>n.</pos> <def>A
reductive agent.</def> <au>Sir M. Hale.</au></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reductively</ent><br/
<hw>Re*duc"tive*ly</hw>, <pos>adv.</pos> <def>By reduction; by
consequence.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reduit</ent><br/
\'d8<hw>R<eacute/`duit"</hw> <pr>(r?`dw?")</pr>, <pos>n.</pos> <ety>[F.
See <er>Redoubt</er>, <pos>n.</pos> ]</ety> <fld>(Fort.)</fld> <def>A
central or retired work within any other work.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redundancy</ent><br/
<ent>Redundance</ent><br/
<mhw>{ <hw>Re*dun"dance</hw> <pr>(r?*d?n"d<it>a</it>ns)</pr>,
<hw>Re*dun"dan*cy</hw> <pr>(-d<it>a</it>n*s?)</pr>, }</mhw>
<pos>n.</pos> <ety>[L. <ets>redundantia</ets>: cf. F.
<ets>redondance</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>The quality or state of being redundant;
superfluity; superabundance; excess.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is redundant or in excess; anything
superfluous or superabundant.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Labor . . . throws off <qex>redundacies</qex>.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Law)</fld> <def>Surplusage inserted in a pleading
which may be rejected by the court without impairing the validity of
what remains.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redundant</ent><br/
<hw>Re*dun"dant</hw> <pr>(-d<it>a</it>nt)</pr>, <pos>a.</pos> <ety>[L.
<ets>redundans</ets>, <ets>-antis</ets>, p. pr. of <ets>redundare</ets>:
cf. F. <ets>redondant</ets>. See <er>Redound</er>.]</ety> <sn>1.</sn>
<def>Exceeding what is natural or necessary; superabundant; exuberant;
<as>as, a <ex>redundant</ex> quantity of bile or food</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Notwithstanding the <qex>redundant</qex> oil in fishes, they do
not increase fat so much as flesh.</q>
<rj><qau>Arbuthnot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Using more worrds or images than are necessary or
useful; pleonastic.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Where an suthor is <qex>redundant</qex>, mark those paragraphs to
be retrenched.</q> <rj><qau>I. Watts.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Superfluous; superabundant; excessive; exuberant;
overflowing; plentiful; copious.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redundantly</ent><br/
<hw>Re*dun"dant*ly</hw> <pr>(r?*d?n"d<it>a</it>nt*l?)</pr>,
<pos>adv.</pos> <def>In a refundant manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reduplicate</ent><br/
<hw>Re*du"pli*cate</hw> <pr>(r?*d?"pl?*k?t)</pr>, <pos>a.</pos>
<ety>[Pref. <ets>re-</ets> + <ets>duplicate</ets>: cf. L.
<ets>reduplicatus</ets>. Cf. <er>Redouble</er>.]</ety> <sn>1.</sn>
<def>Double; doubled; reduplicative; repeated.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>Valvate with the margins curved
outwardly; -- said of the estivation of certain flowers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reduplicate</ent><br/
<hw>Re*du"pli*cate</hw> <pr>(-k?t)</pr>, <pos>v. t.</pos> <ety>[Cf. LL.
<ets>reduplicare</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>To redouble; to multiply; to repeat.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Gram.)</fld> <def>To repeat the first letter or
letters of (a word). See <er>Reduplication</er>, 3.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reduplication</ent><br/
<hw>Re*du`pli*ca"tion</hw> <pr>(-k?sh?n)</pr>, <pos>n.</pos> <ety>[Cf.
F. <ets>r<eacute/duplication</ets>, L. <ets>reduplicatio</ets>
repetition.]</ety> <sn>1.</sn> <def>The act of doubling, or the state of
being doubled.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Pros.)</fld> <def>A figure in which the first word
of a verse is the same as the last word of the preceding
verse.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Philol.)</fld> <def>The doubling of a stem or
syllable (more or less modified), with the effect of changing the time
expressed, intensifying the meaning, or making the word more imitative;
also, the syllable thus added; <as>as, L. <xex>te</xex>tuli;
<xex>po</xex>posci</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reduplicative</ent><br/
<hw>Re*du"pli*ca*tive</hw> <pr>(-k?*t?v)</pr>, <pos>a.</pos> <ety>[Cf.
F. <ets>r<eacute/duplicatif</ets>.]</ety> <def>Double; formed by
reduplication; reduplicate.</def> <rj><au>I. Watts.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reduvid</ent><br/
<hw>Red"u*vid</hw> <pr>(r?d"?*v?d)</pr>, <pos>n.</pos> <ety>[L.
<ets>reduvia</ets> a hangnail.]</ety> <fld>(Zool.)</fld> <def>Any
hemipterous insect of the genus <gen>Redivius</gen>, or family
<fam>Reduvidae</fam>. They live by sucking the blood of other insects,
and some species also attack man.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redweed</ent><br/
<hw>Red"weed`</hw> <pr>(r<ecr/d"w<emac/d`)</pr>, <pos>n.</pos>
<fld>(Bot.)</fld> <def>The red poppy (<spn>Papaver Rhoeas</spn>).</def>
<rj><au>Dr. Prior.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redwing</ent><br/
<hw>Red"wing`</hw> <pr>(-w?ng`)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>A European thrush (<spn>Turdus iliacus</spn>). Its under wing
coverts are orange red. Called also <altname>redwinged thrush</altname>.
<sd>(b)</sd> A North American passerine bird (<spn>Agelarius
ph<oe/niceus</spn>) of the family <fam>Icteridae</fam>. The male is
black, with a conspicuous patch of bright red, bordered with orange, on
each wing. Called also <altname>redwinged blackbird</altname>,
<altname>red-winged troupial</altname>, <altname>marsh
blackbird</altname>, and <altname>swamp blackbird</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redwithe</ent><br/
<hw>Red"withe`</hw> <pr>(r?d"w?th`)</pr>, <pos>n.</pos>
<fld>(Bot.)</fld> <def>A west Indian climbing shrub (<spn>Combretum
Jacquini</spn>) with slender reddish branchlets.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Redwood</ent><br/
<hw>Red"wood`</hw> <pr>(-w<oocr/d`)</pr>, <pos>n.</pos>
<fld>(Bot.)</fld> <sd>(a)</sd> <def>A gigantic coniferous tree
(<spn>Sequoia sempervirens</spn>) of California, and its light and
durable reddish timber. See <er>Sequoia</er>.</def> <sd>(b)</sd> <def>An
East Indian dyewood, obtained from <spn>Pterocarpus santalinus</spn>,
<spn>Caesalpinia Sappan</spn>, and several other trees.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The redwood of Andaman is <spn>Pterocarpus
dalbergioides</spn>; that of some parts of tropical America, several
species of <spn>Erythoxylum</spn>; that of Brazil, the species of
<spn>Humirium</spn>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ree</ent><br/
<hw>Ree</hw> <pr>(r<emac/)</pr>, <pos>n.</pos> <ety>[Pg.
<ets>real</ets>, pl. <ets>reis</ets>. See <er>Real</er> the
money.]</ety> <def>See <er>Rei</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ree</ent><br/
<hw>Ree</hw>, <pos>v. t.</pos> <ety>[Cf. Prov. G. <ets>r<aum/den</ets>,
<ets>raden</ets>, <ets>raiten</ets>. Cf. <er>Riddle</er> a sieve.]</ety>
<def>To riddle; to sift; to separate or throw off.</def> <mark>[Obs. or
Prov. Eng.]</mark> <rj><au>Mortimer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reebok</ent><br/
<hw>Ree"bok`</hw> <pr>(r?"b?k`)</pr>, <pos>n.</pos> <ety>[D., literally,
roebuck.]</ety> <fld>(Zool.)</fld> <def>The peele.</def> <altsp>[Written
also <asp>rehboc</asp> and <asp>rheeboc</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reecho</ent><br/
<ent>re-echo</ent><br/
<mhw><hw>Re*ech"o</hw>, <hw>Re-ech"o</hw></mhw>
<pr>(r<emac/*<ecr/k"<osl/)</pr>, <pos>v. t.</pos> <def>To echo back; to
reverberate again; <as>as, the hills <ex>reecho</ex> the roar of
cannon</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To repeat back.</def><br/
<syn><b>Syn. --</b> echo back.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Reecho</ent><br/
<ent>Re-echo</ent><br/
<mhw><hw>Re*ech"o</hw>, <hw>Re-ech"o</hw></mhw>, <pos>v. i.</pos>
<def>To give echoes; to return back, or be reverberated, as an echo; to
resound; to be resonant; to echo repeatedly, again and again.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And a loud groan <qex>reechoes</qex> from the main.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reecho</ent><br/
<hw>Re*ech"o</hw>, <pos>n.</pos> <def>The echo of an echo; a repeated or
second echo.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reechy</ent><br/
<hw>Reech"y</hw> <pr>(r<emac/ch"<ycr/)</pr>, <pos>a.</pos> <ety>[See
<er>Reeky</er>.]</ety> <def>Smoky; reeky; hence, begrimed with
dirt.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reed</ent><br/
<hw>Reed</hw> <pr>(r<emac/d)</pr>, <pos>a.</pos> <def>Red.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reed</ent><br/
<hw>Reed</hw>, <pos>v. & n.</pos> <def>Same as <er>Rede</er>.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reed</ent><br/
<hw>Reed</hw>, <pos>n.</pos> <def>The fourth stomach of a ruminant;
rennet.</def> <mark>[Prov. Eng. or Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reed</ent><br/
<hw>Reed</hw>, <pos>n.</pos> <ety>[AS. <ets>hre<oacute/d</ets>; akin to
D. <ets>riet</ets>, G. <ets>riet</ets>, <ets>ried</ets>, OHG.
<ets>kriot</ets>, <ets>riot</ets>.]</ety> <sn>1.</sn> <fld>(Bot.)</fld>
<def>A name given to many tall and coarse grasses or grasslike plants,
and their slender, often jointed, stems, such as the various kinds of
bamboo, and especially the common reed of Europe and North America
(<spn>Phragmites communis</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A musical instrument made of the hollow joint of
some plant; a rustic or pastoral pipe.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Arcadian pipe, the pastoral <qex>reed</qex><br/
Of Hermes.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>An arrow, as made of a reed.</def>
<rj><au>Prior.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Straw prepared for thatching a roof.</def>
<mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Mus.)</fld> <sd>(a)</sd> <def>A small piece of cane
or wood attached to the mouthpiece of certain instruments, and set in
vibration by the breath. In the clarinet it is a single fiat reed; in
the oboe and bassoon it is double, forming a compressed tube.</def>
<sd>(b)</sd> <def>One of the thin pieces of metal, the vibration of
which produce the tones of a melodeon, accordeon, harmonium, or
seraphine; also attached to certain sets or registers of pipes in an
organ.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Weaving)</fld> <def>A frame having parallel flat
stripe of metal or reed, between which the warp threads pass, set in the
swinging lathe or batten of a loom for beating up the weft; a sley. See
<er>Batten</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Mining)</fld> <def>A tube containing the train of
powder for igniting the charge in blasting.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <fld>(Arch.)</fld> <def>Same as
<er>Reeding</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Egyptian reed</b></col> <fld>(Bot.)</fld>, <cd>the
papyrus.</cd> -- <col><b>Free reed</b></col> <fld>(Mus.)</fld>, <cd>a
reed whose edges do not overlap the wind passage, -- used in the
harmonium, concertina, etc. It is distinguished from the
<xex>beating</xex> or <xex>striking reed</xex> of the organ and
clarinet.</cd> -- <col><b>Meadow reed grass</b></col> <fld>(Bot.)</fld>,
<cd>the <spn>Glyceria aquatica</spn>, a tall grass found in wet
places.</cd> -- <col><b>Reed babbler</b></col>. <cd>See
<er>Reedbird</er>.</cd> -- <col><b>Reed bunting</b></col>
<fld>(Zool.)</fld> <cd>A European sparrow (<spn>Emberiza
sch<oe/niclus</spn>) which frequents marshy places; -- called also
<altname>reed sparrow</altname>, <altname>ring bunting</altname>.</cd>
<sd>(b)</sd> <cd>Reedling.</cd> -- <col><b>Reed canary grass</b></col>
<fld>(Bot.)</fld>, <cd>a tall wild grass (<spn>Phalaris
arundinacea</spn>).</cd> -- <col><b>Reed grass</b></col>.
<fld>(Bot.)</fld> <sd>(a)</sd> <cd>The common reed</cd>. See
<er>Reed</er>, 1. <sd>(b)</sd> <cd>A plant of the genus
<gen>Sparganium</gen>; bur reed. See under <er>Bur</er>.</cd> --
<col><b>Reed organ</b></col> <fld>(Mus.)</fld>, <cd>an organ in which
the wind acts on a set of free reeds, as the harmonium, melodeon,
concertina, etc.</cd> -- <col><b>Reed pipe</b></col> <fld>(Mus.)</fld>,
<cd>a pipe of an organ furnished with a reed.</cd> -- <col><b>Reed
sparrow</b></col>. <fld>(Zool.)</fld> <cd>See <cref>Reed bunting</cref>,
above.</cd> -- <col><b>Reed stop</b></col> <fld>(Mus.)</fld>, <cd>a set
of pipes in an organ furnished with reeds.</cd> -- <col><b>Reed
warbler</b></col>. <fld>(Zool.)</fld> <sd>(a)</sd> <cd>A small European
warbler (<spn>Acrocephalus streperus</spn>); -- called also
<altname>reed wren</altname>.</cd> <sd>(b)</sd> <cd>Any one of several
species of Indian and Australian warblers of the genera
<gen>Acrocephalus</gen>, <gen>Calamoherpe</gen>, and
<gen>Arundinax</gen>. They are excellent singers.</cd> --
<col><b>Sea-sand reed</b></col> <fld>(Bot.)</fld>, <cd>a kind of coarse
grass (<spn>Ammophila arundinacea</spn>). See <cref>Beach grass</cref>,
under <er>Beach</er>.</cd> -- <col><b>Wood reed grass</b></col>
<fld>(Bot.)</fld>, <cd>a tall, elegant grass (<spn>Cinna
arundinacea</spn>), common in moist woods.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reedbuck</ent><br/
<ent>Reedbird</ent><br/
<hw>Reed"bird`</hw> <pr>(r?d"b?rd`)</pr>, <pos>n.</pos>
<fld>(Zool.)</fld> <sd>(a)</sd> <def>The bobolink.</def> <sd>(b)</sd>
<def>One of several small Asiatic singing birds of the genera
<gen>Sch<oe/nicola</gen> and <gen>Eurycercus</gen>; -- called also
<altname>reed babbler</altname>.</def> <hw>Reed"buck"</hw>
<pr>(-b?k`)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>See
<er>Rietboc</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reeded</ent><br/
<hw>Reed"ed</hw>, <pos>a.</pos> <sn>1.</sn> <def>Civered with reeds;
reedy.</def> <rj><au>Tusser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Formed with channels and ridges like
reeds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reeden</ent><br/
<hw>Reed"en</hw> <pr>(r?d"'n)</pr>, <pos>a.</pos> <def>Consisting of a
reed or reeds.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Through <qex>reeden</qex> pipes convey the golden flood.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reedification</ent><br/
<hw>Re*ed`i*fi*ca"tion</hw> <pr>(r?*?d`?*f?*k?"sh?n)</pr>, <pos>n.</pos>
<ety>[Cf. F. <ets>r<eacute/<eacute/dification</ets>. See
<er>Reedify</er>.]</ety> <def>The act reedifying; the state of being
reedified.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reedify</ent><br/
<hw>Re*ed"i*fy</hw> <pr>(r?*?d"?*ff?)</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>re-</ets> + <ets>edify</ets>: cf. F.
<ets>r<eacute/<eacute/difier</ets>, L. <ets>reaedificare</ets>.]</ety>
<def>To edify anew; to build again after destruction.</def>
<mark>[R.]</mark> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reeding</ent><br/
<hw>Reed"ing</hw> <pr>(r<emac/d"<icr/ng)</pr>, <pos>n.</pos> <ety>[From
4th <er>Reed</er>.]</ety> <sn>1.</sn> <fld>(Arch.)</fld> <def>A small
convex molding; a reed (see <xex>Illust.</xex> <sd>(i)</sd> of
<er>Molding</er>); one of several set close together to decorate a
surface; also, decoration by means of reedings; -- the reverse of
<contr>fluting</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Several <ex>reedings</ex> are often placed together,
parallel to each other, either projecting from, or inserted into, the
adjoining surface. The decoration so produced is then called, in
general, <ex>reeding</ex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The nurling on the edge of a coin; -- commonly
called <xex>milling</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reedless</ent><br/
<hw>Reed"less</hw>, <pos>a.</pos> <def>Destitute of reeds; <as>as,
<ex>reedless</ex> banks</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reedling</ent><br/
<hw>Reed"ling</hw> <pr>(r<emac/d"l<icr/ng)</pr>, <pos>n.</pos>
<fld>(Zool.)</fld> <def>The European bearded titmouse (<spn>Panurus
biarmicus</spn>); -- called also <altname>reed bunting</altname>,
<altname>bearded pinnock</altname>, and <altname>lesser butcher
bird</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ It is orange brown, marked with black, white, and yellow
on the wings. The male has a tuft of black feathers on each side of the
face.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reed-mace</ent><br/
<hw>Reed"-mace`</hw> <pr>(r<emac/d"m<amac/s`)</pr>, <pos>n.</pos>
<fld>(Bot.)</fld> <def>The cat-tail.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reedwork</ent><br/
<hw>Reed"work`</hw> <pr>(r<emac/d"w<ucir/rk`)</pr>, <pos>n.</pos>
<fld>(Mus.)</fld> <def>A collective name for the reed stops of an
organ.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reedy</ent><br/
<hw>Reed"y</hw> <pr>(r<emac/d"<ycr/)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Abounding with reeds; covered with reeds.</def> <ldquo/A
<xex>reedy</xex> pool.<rdquo/ <rj><au>Thomson .</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Having the quality of a reed in tone, that is, harsh
and thin, as some voices.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reef</ent><br/
<hw>Reef</hw> <pr>(r<emac/f)</pr>, <pos>n.</pos> <ety>[Akin to D.
<ets>rif</ets>, G. <ets>riff</ets>, Icel. <ets>rif</ets>, Dan.
<ets>rev</ets>; cf. Icel. <ets>rifa</ets> rift, rent, fissure,
<ets>rifa</ets> to rive, bear. Cf. <er>Rift</er>, <er>Rive</er>.]</ety>
<sn>1.</sn> <def>A chain or range of rocks lying at or near the surface
of the water. See <cref>Coral reefs</cref>, under
<er>Coral</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mining.)</fld> <def>A large vein of auriferous
quartz; -- so called in Australia. Hence, any body of rock yielding
valuable ore.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Reef builder</b></col> <fld>(Zool.)</fld>, <cd>any stony
coral which contributes material to the formation of coral reefs.</cd>
-- <col><b>Reef heron</b></col> <fld>(Zool.)</fld>, <cd>any heron of the
genus <gen>Demigretta</gen>; <as>as, the blue <ex>reef heron</ex>
(<spn>Demigretta jugularis</spn>) of Australia</as>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reef</ent><br/
<hw>Reef</hw>, <pos>n.</pos> <ety>[Akin to D. <ets>reef</ets>, G.
<ets>reff</ets>, Sw. <ets>ref</ets>; cf. Icel. <ets>rif</ets> reef,
<ets>rifa</ets> to basten together. Cf. <er>Reeve</er>, <pos>v.
t.</pos>, <er>River</er>.]</ety> <fld>(Naut.)</fld> <def>That part of a
sail which is taken in or let out by means of the reef points, in order
to adapt the size of the sail to the force of the wind.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ From the head to the first reef-band, in square sails,
is termed the <xex>first reef</xex>; from this to the next is the
<xex>second reef</xex>; and so on. In fore-and-aft sails, which reef on
the foot, the first reef is the lowest part.</note>
<rj><au>Totten.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Close reef</b></col>, <cd>the last reef that can be put
in.</cd> -- <col><b>Reef band</b></col>. <cd>See <er>Reef-band</er> in
the Vocabulary.</cd> -- <col><b>Reef knot</b></col>, <cd>the knot which
is used in tying reef pointss. See <xex>Illust.</xex> under
<er>Knot</er>.</cd> -- <col><b>Reef line</b></col>, <cd>a small rope
formerly used to reef the courses by being passed spirally round the
yard and through the holes of the reef.</cd> <au>Totten.</au> --
<col><b>Reef points</b></col>, <cd>pieces of small rope passing through
the eyelet holes of a reef-band, and used reefing the sail.</cd> --
<col><b>Reef tackle</b></col>, <cd>a tackle by which the reef cringles,
or rings, of a sail are hauled up to the yard for reefing.</cd>
<au>Totten.</au> -- <col><b>To take a reef in</b></col>, <cd>to reduce
the size of (a sail) by folding or rolling up a reef, and lashing it to
the spar.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reef</ent><br/
<hw>Reef</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Reefed</conjf> <pr>(r<emac/ft)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Reefing</conjf>.]</vmorph> <fld>(Naut.)</fld> <def>To reduce the
extent of (as a sail) by rolling or folding a certain portion of it and
making it fast to the yard or spar.</def> <rj><au>Totten.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To reef the paddles</b></col>, <cd>to move the floats of
a paddle wheel toward its center so that they will not dip so
deeply.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1206 --></p>

<p><ent>Reef-band</ent><br/
<hw>Reef"-band`</hw> <pr>(r<emac/f"b<acr/nd`)</pr>, <pos>n.</pos>
<fld>(Naut.)</fld> <def>A piece of canvas sewed across a sail to
strengthen it in the part where the eyelet holes for reefing are
made.</def> <rj><au>Totten.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reefer</ent><br/
<hw>Reef"er</hw> <pr>(r<emac/f"<etil/r)</pr>, <pos>n.</pos> <sn>1.</sn>
<fld>(Naut.)</fld> <def>One who reefs; -- a name often given to
midshipmen.</def> <rj><au>Marryat.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A close-fitting jacket or short coat of thick
cloth.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A marijuana cigarette.</def>
<mark>[Slang]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reefing</ent><br/
<hw>Reef"ing</hw>, <pos>n.</pos> <fld>(Naut.)</fld> <def>The process of
taking in a reef.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Reefing bowsprit</b></col>, <cd>a bowsprit so rigged that
it can easily be run in or shortened by sliding inboard, as in
cutters.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reefy</ent><br/
<hw>Reef"y</hw> <pr>(r<emac/f"<ycr/)</pr>, <pos>a.</pos> <def>Full of
reefs or rocks.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reek</ent><br/
<hw>Reek</hw> <pr>(r<emac/k)</pr>, <pos>n.</pos> <def>A rick.</def>
<mark>[Obs.]</mark> <rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reek</ent><br/
<hw>Reek</hw>, <pos>n.</pos> <ety>[AS. <ets>r<emac/c</ets>; akin to
OFries. <ets>r<emac/k</ets>, LG. & D. <ets>rook</ets>, G.
<ets>rauch</ets>, OHG. <ets>rouh</ets>, Dan. <ets>r<oum/g</ets>, Sw.
<ets>r<oum/k</ets>, Icel. <ets>reykr</ets>, and to AS.
<ets>re<oacute/can</ets> to reek, smoke, Icel. <ets>rj<umac/ka</ets>, G.
<ets>riechen</ets> to smell.]</ety> <def>Vapor; steam; smoke;
fume.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>As hateful to me as the <qex>reek</qex> of a limekiln.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reek</ent><br/
<hw>Reek</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Reeked</conjf> <pr>(r<emac/kt)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Reeking</conjf>.]</vmorph> <ety>[As. <ets>r<emac/can</ets>. See
<er>Reek</er> vapor.]</ety> <def>To emit vapor, usually that which is
warm and moist; to be full of fumes; to steam; to smoke; to
exhale.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Few chimneys <qex>reeking</qex> you shall espy.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I found me laid<br/
In balmy sweat, which with his beams the sun<br/
Soon dried, and on the <qex>reeking</qex> moisture fed.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The coffee rooms <qex>reeked</qex> with tobacco.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reeky</ent><br/
<hw>Reek"y</hw> <pr>(-?)</pr>, <pos>a.</pos> <ety>[From 2d
<er>Reek</er>; cf. <er>Reechy</er>.]</ety> <sn>1.</sn> <def>Soiled with
smoke or steam; smoky; foul.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Emitting reek.</def> <ldquo/<xex>Reeky</xex>
fen.<rdquo/ <rj><au>Sir W. Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reel</ent><br/
<hw>Reel</hw> <pr>(r<emac/l)</pr>, <pos>n.</pos> <ety>[Gael.
<ets>righil</ets>.]</ety> <def>A lively dance of the Highlanders of
Scotland; also, the music to the dance; -- often called <altname>Scotch
reel</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Virginia reel</b></col>, <cd>the common name throughout
the United States for the old English <ldquo/country dance,<rdquo/ or
contradance (<xex>contredanse</xex>).</cd> <au>Bartlett.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reel</ent><br/
<hw>Reel</hw> <pr>(r<emac/l)</pr>, <pos>n.</pos> <ety>[AS.
<ets>hre<oacute/l</ets>: cf. Icel. <ets>hr<ae/ll</ets> a weaver's reed
or sley.]</ety> <sn>1.</sn> <def>A frame with radial arms, or a kind of
spool, turning on an axis, on which yarn, threads, lines, or the like,
are wound; <as>as, a log <ex>reel</ex>, used by seamen; an angler's
<ex>reel</ex>; a garden <ex>reel</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A machine on which yarn is wound and measured into
lays and hanks, -- for cotton or linen it is fifty-four inches in
circuit; for worsted, thirty inches.</def>
<rj><au>McElrath.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Agric.)</fld> <def>A device consisting of radial
arms with horizontal stats, connected with a harvesting machine, for
holding the stalks of grain in position to be cut by the
knives.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Reel oven</b></col>, <cd>a baker's oven in which bread
pans hang suspended from the arms of a kind of reel revolving on a
horizontal axis.</cd> <rj><au>Knight.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reel</ent><br/
<hw>Reel</hw> <pr>(r<emac/l)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Reeled</conjf> <pr>(r?ld)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Reeling</conjf>. ]</vmorph> <sn>1.</sn> <def>To
roll.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>And Sisyphus an huge round stone did <qex>reel</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To wind upon a reel, as yarn or thread.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reel</ent><br/
<hw>Reel</hw> <pr>(r<emac/l)</pr>, <pos>v. i.</pos> <ety>[Cf. Sw.
<ets>ragla</ets>. See <er>2d Reel</er>.]</ety> <sn>1.</sn> <def>To
incline, in walking, from one side to the other; to stagger.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They <qex>reel</qex> to and fro, and stagger like a drunken
man.</q> <rj><qau>Ps. cvii. 27.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He, with heavy fumes oppressed,<br/
<qex>Reeled</qex> from the palace, and retired to rest.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The wagons <qex>reeling</qex> under the yellow sheaves.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To have a whirling sensation; to be giddy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In these lengthened vigils his brain often <qex>reeled</qex>.</q>
<rj><qau>Hawthorne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reel</ent><br/
<hw>Reel</hw> <pr>(r<emac/l)</pr>, <pos>n.</pos> <def>The act or motion
of reeling or staggering; <as>as, a drunken <ex>reel</ex></as>.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reelect</ent><br/
<hw>Re`e*lect"</hw> <pr>(r?`?*l?kt")</pr>, <pos>v. t.</pos> <def>To
elect again; <as>as, to <ex>reelect</ex> the former
governor</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reelection</ent><br/
<hw>Re`e*lec"tion</hw> <pr>(-l?k"sh?n)</pr>, <pos>n.</pos> <def>Election
a second time, or anew; <as>as, the <ex>reelection</ex> of a former
chief</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reeler</ent><br/
<hw>Reel"er</hw> <pr>(r?l"?r)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One
who reels.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>The grasshopper warbler; -- so
called from its note.</def> <mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reeligible</ent><br/
<hw>Re*el"i*gi*ble</hw> <pr>(r<emac/*<ecr/l"<icr/*j<icr/*b'l)</pr>,
<pos>a.</pos> <def>Eligible again; capable of reelection; <as>as,
<ex>reeligible</ex> to the same office</as>.</def> --
<wordforms><wf>Re*el`i*gi*bil"i*ty</wf>
<pr>(r<emac/*<ecr/l`<icr/*j<icr/*b<icr/l"<icr/*t<ycr/)</pr>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reem</ent><br/
<hw>Reem</hw> <pr>(r?m)</pr>, <pos>n.</pos> <ety>[Heb.]</ety>
<fld>(Zool.)</fld> <def>The Hebrew name of a horned wild animal,
probably the Urus.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In King James's Version it is called <xex>unicorn</xex>;
in the Revised Version,<xex>wild ox</xex>. <au>Job xxxix.
9.</au></note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reem</ent><br/
<hw>Reem</hw>, <pos>v. t.</pos> <ety>[Cf. <er>Ream</er> to make a hole
in.]</ety> <fld>(Naut.)</fld> <def>To open (the seams of a vessel's
planking) for the purpose of calking them.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Reeming iron</b></col> <fld>(Naut.)</fld>, <cd>an iron
chisel for reeming the seams of planks in calking ships.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reembark</ent><br/
<hw>Re`em*bark"</hw> <pr>(r?`?m*b?rk")</pr>, <pos>v. t. & i.</pos>
<def>To put, or go, on board a vessel again; to embark again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reembarkation</ent><br/
<hw>Re*em`bar*ka"tion</hw> <pr>(r?*?m`b?r*k?"sh?n)</pr>, <pos>n.</pos>
<def>A putting, or going, on board a vessel again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reembody</ent><br/
<hw>Re`em*bod"y</hw> <pr>(r?`?m*b?d"?)</pr>, <pos>v. t.</pos> <def>To
embody again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reembrace</ent><br/
<hw>Re`em*brace"</hw> <pr>(-br?s")</pr>, <pos>v. i.</pos> <def>To
embrace again.</def><br/
[<source>1913 Webster</source>]</p>

<p><hw>re-emerge</hw> <pos>v.</pos> <sn>1.</sn> <def>to appear once
more.</def><br/
<syn><b>Syn. --</b> reappear, appear again.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Reemerge</ent><br/
<ent>re-emerge</ent><br/
<mhw><hw>Re`e*merge"</hw>, <hw>Re`-e*merge"</hw></mhw>
<pr>(r?`?*m?rj")</pr>, <pos>v. i.</pos> <def>To emerge again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reemergence</ent><br/
<hw>Re`e*mer"gence</hw> <pr>(-m?r"j<it>e</it>ns)</pr>, <pos>n.</pos>
<def>Act of reemerging.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>re-emphasise</ent><br/
<ent>re-emphasise</ent><br/
<mhw><hw>reemphasise</hw>, <hw>re-emphasise</hw></mhw> <pos>v. t.</pos>
<def>Same as <er>reemphasize</er>.</def> <mark>[mostly Brit.]</mark>
<br/
<syn><b>Syn. --</b> re-emphasize.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>reemphasize</ent><br/
<ent>re-emphasize</ent><br/
<mhw><hw>reemphasize</hw>, <hw>re-emphasize</hw></mhw> <pos>v. t.</pos>
<def>To emphasize again.</def><br/
<syn><b>Syn. --</b> re-emphasise.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Reenact</ent><br/
<ent>Re-enact</ent><br/
<mhw><hw>Re`en*act"</hw>, <hw>Re`-en*act"</hw></mhw>
<pr>(r?`?n*?kt")</pr>, <pos>v. t.</pos> <sn>1.</sn> <def>To enact
again.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <specif>Specifically:</specif> <def>To enact into law,
again; <as>as, Congress <ex>reenacted</ex> the environmental law, which
had expired</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>3.</sn> <def>To perform (an action) as a simulation of a prior
event; <as>as, She <ex>re-enacted</ex> what had happened earlier that
day; the historical society <ex>reenacted</ex> the signing of the
Declaration of Independence; the militia <ex>reenacted</ex> the battle
of Trenton</as>.</def><br/
<syn><b>Syn. --</b> model, reenact, simulate, act out.</syn><br/
[<source>WordNet 1.5</source> + <source>PJC</source>]</p>

<p><ent>Reenaction</ent><br/
<hw>Re`en*ac"tion</hw> <pr>(-?k"sh?n)</pr>, <pos>n.</pos> <def>The act
of reenacting; the state of being reenacted.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reenactment</ent><br/
<hw>Re`en*act"ment</hw> <pr>(-?kt"m<it>e</it>nt)</pr>, <pos>n.</pos>
<def>The enacting or passing of a law a second time; the renewal of a
law.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reencourage</ent><br/
<hw>Re`en*cour"age</hw> <pr>(-k?r"?j;)</pr>, <pos>v. t.</pos> <def>To
encourage again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reendow</ent><br/
<hw>Re`en*dow"</hw> <pr>(-dou")</pr>, <pos>v. t.</pos> <def>To endow
again.</def><br/
[<source>1913 Webster</source>]</p>

<p><hw>re-enforce</hw> <pos>v.</pos> <sn>1.</sn> <def>to make stronger;
"reinforced concrete".</def><br/
<syn><b>Syn. --</b> reinforce, reenforce.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Reenforce</ent><br/
<ent>re-enforce</ent><br/
<mhw><hw>Re`en*force"</hw>, <hw>Re`-en*force"</hw></mhw>
<pr>(r<emac/`<ecr/n*f<omac/rs")</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>re-</ets> + <ets>enforce</ets>: cf. F. <ets>renforcer</ets>.]</ety>
<sn>1.</sn> <def>To strengthen with new force, assistance, material, or
support; <as>as, to <ex>reenforce</ex> an argument; to
<ex>reenforce</ex> a garment</as>;</def> <specif>especially,</specif>
<def>to strengthen with additional troops, as an army or a fort, or with
additional ships, as a fleet.</def> <altsp>[Written also
<asp>reinforce</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Psychology)</fld> <def>To increase the likelihood
that (a specific behavior) will be repeated by giving a reward or
punishment to a person or animal; <as>as, to <ex>reenforce</ex> the
students' willingness to study by giving awards for good
grades</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Reenforce</ent><br/
<hw>Re`en*force"</hw>, <pos>n.</pos> <ety>[See <er>Reenforce</er>,
<pos>v.</pos>, and cf. <er>Ranforce</er>, <er>Reinforce</er>.]</ety>
<def>Something which reenforces or strengthens.</def>
<specif>Specifically:</specif> <sd>(a)</sd> <def>That part of a cannon
near the breech which is thicker than the rest of the piece, so as
better to resist the force of the exploding powder. See
<xex>Illust.</xex> of <er>Cannon</er>.</def> <sd>(b)</sd> <def>An
additional thickness of canvas, cloth, or the like, around an eyelet,
buttonhole, etc.</def> <altsp>[Written also
<asp>reinforce</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reenforced concrete</ent><br/
<hw>Reenforced concrete</hw>. <def>Concrete having within its mass a
system of iron or steel supports, such as bars, rods, or a heavy mesh,
to provide increased tensile strength and shear resistance. Same as
<er>Ferro-concrete</er>.</def><br/
<syn><b>Syn. --</b> reinforced concrete.</syn>
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><ent>Reenforcement</ent><br/
<hw>Re`en*force"ment</hw> <pr>(r?`?n*f?rs"m<it>e</it>nt)</pr>,
<pos>n.</pos> <sn>1.</sn> <def>The act of reenforcing, or the state of
being reenforced.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which reenforces; additional force; especially,
additional troops or force to augment the strength of any army, or ships
to strengthen a navy or fleet.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Psychology)</fld> <def>A reward or punishment which
is given to a person or animal in order to increase the likelihood that
a specific behavior will be repeated.</def><br/
[<source>PJC</source>]</p>

<p><ent>Reengage</ent><br/
<hw>Re`en*gage"</hw> <pr>(-g?j)</pr>, <pos>v. t. & i.</pos> <def>To
engage a second time or again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reengagement</ent><br/
<hw>Re`en*gage"ment</hw> <pr>(-m<it>e</it>nt)</pr>, <pos>n.</pos> <def>A
renewed or repeated engagement.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reengrave</ent><br/
<hw>Re`en*grave"</hw> <pr>(-gr?v")</pr>, <pos>v. t.</pos> <def>To
engrave anew.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reenjoy</ent><br/
<hw>Re`en*joy"</hw> <pr>(-joi")</pr>, <pos>v. i.</pos> <def>To enjoy
anew.</def> <rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reenjoyment</ent><br/
<hw>Re`en*joy"ment</hw> <pr>(-m<it>e</it>nt)</pr>, <pos>n.</pos>
<def>Renewed enjoyment.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reenkindle</ent><br/
<hw>Re`en*kin"dle</hw> <pr>(-k?n"d'l)</pr>, <pos>v. t.</pos> <def>To
enkindle again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reenlist</ent><br/
<hw>Re`en*list"</hw> <pr>(-l?st")</pr>, <pos>v. t. & i.</pos> <def>To
enlist again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reenlistment</ent><br/
<hw>Re`en*list"ment</hw> <pr>(-m<it>e</it>nt)</pr>, <pos>n.</pos> <def>A
renewed enlistment.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reenslave</ent><br/
<hw>Re`en*slave"</hw> <pr>(-sl?v")</pr>, <pos>v. t.</pos> <def>To
enslave again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reenter</ent><br/
<ent>re-enter</ent><br/
<mhw><hw>Re*en"ter</hw>, <hw>Re-en"ter</hw></mhw> <pr>(r?*?n"t?r)</pr>,
<pos>v. t.</pos> <sn>1.</sn> <def>To enter again; <as>as, You cannot
<ex>re-enter</ex> the country with this visa</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Engraving)</fld> <def>To cut deeper, as engraved
lines on a plate of metal, when the engraving has not been deep enough,
or the plate has become worn in printing.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Computers)</fld> <def>To put (data) into a document
or form on a computer again; -- usually to correct an erroneous entry;
<as>as, the password was incorrect, and had to be
<ex>reentered</ex></as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Reenter</ent><br/
<hw>Re*en"ter</hw>, <pos>v. i.</pos> <def>To enter anew or
again.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Reentering angle</b></col>, <cd>an angle of a polygon
pointing inward, as <xex>a</xex>, in the cut.</cd> -- <col><b>Reentering
polygon</b></col>, <cd>a polygon having one or more reentering
angles.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reentering</ent><br/
<hw>Re*en"ter*ing</hw>, <pos>n.</pos> <fld>(Calico Printing.)</fld>
<def>The process of applying additional colors, by applications of
printing blocks, to patterns already partly colored.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reenthrone</ent><br/
<hw>Re`en*throne"</hw> <pr>(-thr?n")</pr>, <pos>v. t.</pos> <def>To
enthrone again; to replace on a throne.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reenthronement</ent><br/
<hw>Re`en*throne"ment</hw> <pr>(-m<it>e</it>nt)</pr>, <pos>n.</pos>
<def>A second enthroning.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reentrance</ent><br/
<hw>Re*en"trance</hw> <pr>(r<emac/`<ecr/n"tr<ait/ns)</pr>, <pos>n.</pos>
<def>The act entering again; reentry.</def>
<rj><au>Hooker.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reentrant</ent><br/
<hw>Re*en"trant</hw> <pr>(r<emac/`<ecr/n"tr<ait/nt)</pr>, <pos>a.</pos>
<def>Reentering; pointing or directed inwards; <as>as, a
<ex>reentrant</ex> angle</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reentry</ent><br/
<hw>Re*en"try</hw> <pr>(r<emac/`<ecr/n"tr<ycr/)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>A second or new entry; <as>as, a <ex>reentry</ex> into
public life</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>A resuming or retaking possession
of what one has lately foregone; -- applied especially to land; the
entry by a lessor upon the premises leased, on failure of the tenant to
pay rent or perform the covenants in the lease.</def>
<rj><au>Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Astronautics)</fld> <def>To enter (the Earth's
atmosphere) after having passed beyond the atmosphere, as when in orbit
or returning from another planet.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Card of reentry</b></col>, <fld>(Whist)</fld>, <cd>a card
that by winning a trick will bring one the lead at an advanced period of
the hand.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>reequip</ent><br/
<ent>re-equip</ent><br/
<mhw><hw>reequip</hw>, <hw>re-equip</hw></mhw> <pos>v. t.</pos>
<sn>1.</sn> <fr>1</fr> <def>to furnish with new equipment. Forms with
and without the hyphen are common.</def><br/
<syn><b>Syn. --</b> rejig.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Reerect</ent><br/
<hw>Re`e*rect"</hw> <pr>(r?`?*r?kt")</pr>, <pos>v. t.</pos> <def>To
erect again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reermouse</ent><br/
<hw>Reer"mouse`</hw> <pr>(r?r"mous`)</pr>, <pos>n.</pos>
<fld>(Zool.)</fld> <def>See <er>Rearmouse</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reestablish</ent><br/
<hw>Re`es*tab"lish</hw> <pr>(r?`?s*t?b"l?sh)</pr>, <pos>v. t.</pos>
<def>To establish anew; to fix or confirm again; to restore; <as>as, to
<ex>reestablish</ex> a covenant; to <ex>reestablish</ex>
health.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reestablisher</ent><br/
<hw>Re`es*tab"lish*er</hw> <pr>(-?r)</pr>, <pos>n.</pos> <def>One who
establishes again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reestablishment</ent><br/
<hw>Re`es*tab"lish*ment</hw> <pr>(-mnt)</pr>, <pos>n.</pos> <def>The act
reestablishing; the state of being reestablished.</def>
<rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reestate</ent><br/
<hw>Re`es*tate"</hw> <pr>(-t?t)</pr>, <pos>v. t.</pos> <def>To
reestablish.</def> <mark>[Obs.]</mark> <rj><au>Walis.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>reevaluate</ent><br/
<ent>re-evaluate</ent><br/
<mhw><hw>reevaluate</hw>, <hw>re-evaluate</hw></mhw> <pos>v. t.</pos>
<def>To revise or renew one's assessment; to evaluate again.</def><br/
<syn><b>Syn. --</b> re-assess, reassess.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Reeve</ent><br/
<hw>Reeve</hw> <pr>(r<emac/v)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>The female of the ruff.</def><br/
[<source>1913 Webster</source>]</p>

<p><hw>Reeve</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Rove</conjf> <pr>(r<omac/v)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Reeving</conjf>.]</vmorph> <ety>[Cf. D. <ets>reven</ets>. See
<er>Reef</er>, <pos>n.</pos> & <pos>v. t.</pos>]</ety>
<fld>(Naut.)</fld> <def>To pass, as the end of a rope, through any hole
in a block, thimble, cleat, ringbolt, cringle, or the like.</def><br/
[<source>1913 Webster</source>]</p>

<p><hw>Reeve</hw>, <pos>n.</pos> <ety>[OE. <ets>reve</ets>, AS.
<ets>ger<emac/fa</ets>. Cf. <er>Sheriff</er>.]</ety> <def>An officer,
steward, bailiff, or governor; -- used chiefly in compounds; <as>as,
shire<ex>reeve</ex>, now written <xex>sheriff</xex>; port<ex>reeve</ex>,
etc.</as></def> <rj><au>Chaucer.</au> <au>Piers Plowman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><hw>Re`<eum/x*am"i*na*ble</hw>
<pr>(r<emac/`<ecr/gz*<acr/m"<icr/*n<adot/*b'l)</pr>, <pos>a.</pos>
<def>Admitting of being reexamined or reconsidered.</def>
<rj><au>Story.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reexamination</ent><br/
<hw>Re`ex*am`i*na"tion</hw> <pr>(-?*n?"sh?n)</pr>, <pos>n.</pos> <def>A
repeated examination. See under <er>Examination</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reexamine</ent><br/
<hw>Re`ex*am"ine</hw> <pr>(--?n)</pr>, <pos>v. t.</pos> <def>To examine
anew.</def> <rj><au>Hooker.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reexchange</ent><br/
<hw>Re`ex*change"</hw> <pr>(r?`?ks*ch?nj")</pr>, <pos>v. t.</pos>
<def>To exchange anew; to reverse (a previous exchange).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reexchange</ent><br/
<hw>Re`ex*change"</hw> <pos>n.</pos> <sn>1.</sn> <def>A renewed
exchange; a reversal of an exchange.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Com.)</fld> <def>The expense chargeable on a bill
of exchange or draft which has been dishonored in a foreign country, and
returned to the country in which it was made or indorsed, and then taken
up.</def> <rj><au>Bouvier.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The rate of <qex>reexchange</qex> is regulated with respect to the
drawer, at the course of exchange between the place where the bill of
exchange was payable, and the place where it was drawn.
<qex>Reexchange</qex> can not be cumulated.</q>
<rj><qau>Walsh.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reexhibit</ent><br/
<hw>Re`ex*hib"it</hw> <pr>(r?`?gz*?b"?t <or/ -?ks*h?b"?t)</pr>, <pos>v.
t.</pos> <def>To exhibit again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reexpel</ent><br/
<hw>Re`ex*pel"</hw> <pr>(r?`?ks*p?l")</pr>, <pos>v. t.</pos> <def>To
expel again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reexperience</ent><br/
<hw>Re`ex*pe"ri*ence</hw> <pr>(-p?`r?-<it>e</it>ns)</pr>, <pos>n.</pos>
<def>A renewed or repeated experience.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>reexplain</ent><br/
<ent>re-explain</ent><br/
<mhw><hw>reexplain</hw>, <hw>re-explain</hw></mhw> <pos>v. t.</pos>
<sn>1.</sn> <def>To explain or interpret from a different viewpoint. The
form without the hyphen is more common.</def><br/
<syn><b>Syn. --</b> reinterpret.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>reexplore</ent><br/
<ent>re-explore</ent><br/
<mhw><hw>reexplore</hw>, <hw>re-explore</hw></mhw> <pos>v. t.</pos>
<def>to explore again; <as>as, We need to <ex>re-explore</ex>
Colonialism</as>.</def><br/
<syn><b>Syn. --</b> explore again.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Reexport</ent><br/
<hw>Re`ex*port"</hw> <pr>(-p?rt")</pr>, <pos>v. t.</pos> <def>To export
again, as what has been imported.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reexport</ent><br/
<hw>Re*ex"port</hw> <pr>(r?*?ks"p?rt)</pr>, <pos>n.</pos> <def>Any
commodity reexported; -- chiefly in the plural.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reexportation</ent><br/
<hw>Re*ex`por*ta"tion</hw> <pr>(-p?r*t?"sh?n)</pr>, <pos>n.</pos>
<def>The act of reexporting, or of exporting an import.</def> <rj><au>A.
Smith.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reexpulsion</ent><br/
<hw>Re`ex*pul"sion</hw> <pr>(r?`?ks*p?l"sh?n)</pr>, <pos>n.</pos>
<def>Renewed or repeated expulsion.</def> <rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reezed</ent><br/
<hw>Reezed</hw> <pr>(r<emac/zd)</pr>, <pos>a.</pos> <def>Grown rank;
rancid; rusty.</def> <mark>[Obs.]</mark> <ldquo/<xex>Reezed</xex>
bacon.<rdquo/ <rj><au>Marston.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refaction</ent><br/
<hw>Re*fac"tion</hw> <pr>(r?*f?k"sh?n)</pr>, <pos>n.</pos> <ety>[See
<er>Refection</er>.]</ety> <def>Recompense; atonement;
retribution.</def> <mark>[Obs.]</mark> <rj><au>Howell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refait</ent><br/
\'d8<hw>Re*fait"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<fld>(Card Playing)</fld> <def>A drawn game;</def>
<specif>specif.</specif> <fld>(Trente et quarante)</fld>, <def>A state
of the game in which the aggregate pip value of cards dealt to red
equals that of those dealt to black. All bets are then off; unless the
value is 31, in which case the banker wins half the stakes.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Refar</ent><br/
<hw>Re*far"</hw> <pr>(r?*f?r")</pr>, <pos>v. t.</pos> <ety>[Cf. F.
<ets>refaire</ets> to do over again.]</ety> <def>To go over again; to
repeat.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>To him therefore this wonder done <qex>refar</qex>.</q>
<rj><qau>Fairfax.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refashion</ent><br/
<hw>Re*fash"ion</hw> <pr>(r?*f?sh"?n)</pr>, <pos>v. t.</pos> <def>To
fashion anew; to form or mold into shape a second time.</def>
<rj><au>MacKnight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refashionment</ent><br/
<hw>Re*fash"ion*ment</hw> <pr>(-m<it>e</it>nt)</pr>, <pos>n.</pos>
<def>The act of refashioning, or the state of being refashioned.</def>
<mark>[R.]</mark> <rj><au>Leigh Hunt.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refasten</ent><br/
<hw>Re*fas"ten</hw> <pr>(r?*f?s"'n)</pr>, <pos>v. t.</pos> <def>To
fasten again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refect</ent><br/
<hw>Re*fect"</hw> <pr>(r?*f?kt)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>refectus</ets>, p. p. of <ets>reficere</ets>; pref. <ets>re-</ets>
re- + <ets>facere</ets> to make.]</ety> <def>To restore after hunger or
fatigue; to refresh.</def> <mark>[Archaic]</mark> <rj><au>Sir T.
Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refection</ent><br/
<hw>Re*fec"tion</hw> <pr>(r?*f?k"sh?n)</pr>, <pos>n.</pos> <ety>[L.
<ets>refectio</ets>: cf. F. <ets>r<eacute/fection</ets>. See
<er>Refect</er>, <er>Fact</er>.]</ety> <def>Refreshment after hunger or
fatigue; a repast; a lunch.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>[His] feeble spirit inly felt <qex>refection</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Those Attic nights, and those <qex>refections</qex> of the
gods.</q> <rj><qau>Curran.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refective</ent><br/
<hw>Re*fec"tive</hw> <pr>(r?*f?k"t?v)</pr>, <pos>a.</pos>
<def>Refreshing; restoring.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refective</ent><br/
<hw>Re*fec"tive</hw>, <pos>n.</pos> <def>That which refreshes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refectory</ent><br/
<hw>Re*fec"to*ry</hw> <pr>(-<osl/*r<ycr/)</pr>, <pos>n.</pos>;
<plu><it>pl.</it>; <plw>Refectories</plw> <pr>(-r<?/z)</pr>.</plu>
<ety>[<er>LL</er>. <ets>refectorium</ets>: cf. F.
<ets>r<eacute/fectoire</ets>. See <er>Refection</er>.]</ety> <def>A room
for refreshment; originally, a dining hall in monasteries or
convents.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Sometimes pronounced
<pr>r<ecr/f"<ecr/k*t<osl/*r<ycr/</pr>, especially when signifying the
eating room in monasteries.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refel</ent><br/
<hw>Re*fel"</hw> <pr>(r?*f?l")</pr>, <pos>v. t.</pos> <ety>[L.
<ets>refellere</ets>; pref. <ets>re-</ets> re- + <ets>fallere</ets> to
deceive.]</ety> <def>To refute; to disprove; <as>as, to <ex>refel</ex>
the tricks of a sophister</as>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>How he <qex>refelled</qex> me, and how I replied.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refer</ent><br/
<hw>Re*fer"</hw> <pr>(r<esl/*f<etil/r")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Referred</conjf>
<pr>(r<esl/*f<etil/rd")</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Referring</conjf>.]</vmorph> <ety>[F.
<ets>r<eacute/f<eacute/rer</ets>, L. <ets>referre</ets>; pref.
<ets>re-</ets> re- + <ets>ferre</ets> to bear. See <er>Bear</er> to
carry.]</ety> <sn>1.</sn> <def>To carry or send back.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence: To send or direct away; to send or direct
elsewhere, as for treatment, aid, information, decision, etc.; to make
over, or pass over, to another; <as>as, to <ex>refer</ex> a student to
an author; to <ex>refer</ex> a beggar to an officer; to <ex>refer</ex> a
bill to a committee; a court <ex>refers</ex> a matter of fact to a
commissioner for investigation, or <ex>refers</ex> a question of law to
a superior tribunal.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To place in or under by a mental or rational
process; to assign to, as a class, a cause, source, a motive, reason, or
ground of explanation; <as>as, he <ex>referred</ex> the phenomena to
electrical disturbances</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To refer one's self</b></col>, <cd>to have recourse; to
betake one's self; to make application; to appeal.</cd>
<mark>[Obs.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><q>I'll <qex>refer</qex> me to all things sense.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refer</ent><br/
<hw>Re*fer"</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To have recourse; to
apply; to appeal; to betake one's self; <as>as, to <ex>refer</ex> to a
dictionary</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In suits . . . it is to <qex>refer</qex> to some friend of
trust.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To have relation or reference; to relate; to point;
<as>as, the figure <ex>refers</ex> to a footnote</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Of those places that <qex>refer</qex> to the shutting and opening
the abyss, I take notice of that in Job.</q> <rj><qau>Bp.
Burnet.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To carry the mind or thought; to direct attention;
<as>as, the preacher <ex>referred</ex> to the late
election</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To direct inquiry for information or a guarantee of
any kind, as in respect to one's integrity, capacity, pecuniary ability,
and the like; <as>as, I <ex>referred</ex> to his employer for the truth
of his story</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To allude; advert; suggest; appeal.</syn> <usage>
<er>Refer</er>, <er>Allude</er>, <er>Advert</er>. We <xex>refer</xex> to
a thing by specifically and distinctly introducing it into our
discourse. We <xex>allude</xex> to it by introducing it indirectly or
indefinitely, as by something collaterally allied to it. We
<xex>advert</xex> to it by turning off somewhat abruptly to consider it
more at large. Thus, Macaulay <xex>refers</xex> to the early condition
of England at the opening of his history; he <xex>alludes</xex> to these
statements from time to time; and <xex>adverts</xex>, in the progress of
his work, to various circumstances of peculiar interest, on which for a
time he dwells. <ldquo/But to do good is . . . that that Solomon chiefly
<xex>refers</xex> to in the text.<rdquo/ <au>Sharp.</au> <ldquo/This, I
doubt not, was that artificial structure here <xex>alluded</xex>
to.<rdquo/ <au>T. Burnet.</au></usage><br/
[<source>1913 Webster</source>]</p>

<p><q>Now to the universal whole <qex>advert</qex>:<br/
The earth regard as of that whole a part.</q>
<rj><qau>Blackmore.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Referable</ent><br/
<hw>Ref"er*a*ble</hw> <pr>(r?f"?r*?*b'l)</pr>, <pos>a.</pos>
<def>Capable of being referred, or considered in relation to something
else; assignable; ascribable.</def> <altsp>[Written also
<asp>referrible</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><q>It is a question among philosophers, whether all the attractions
which obtain between bodies are <qex>referable</qex> to one general
cause.</q> <rj><qau>W. Nicholson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Referee</ent><br/
<hw>Ref`er*ee"</hw> <pr>(-<?/)</pr>, <pos>n.</pos> <def>One to whom a
thing is referred; a person to whom a matter in dispute has been
referred, in order that he may settle it.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Judge; arbitrator; umpire. See
<er>Judge</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reference</ent><br/
<hw>Ref"er*ence</hw> <pr>(r?f"?r-<it>e</it>ns)</pr>, <pos>n.</pos>
<ety>[See <er>Refer</er>.]</ety> <sn>1.</sn> <def>The act of referring,
or the state of being referred; <as>as, <ex>reference</ex> to a chart
for guidance</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which refers to something; a specific direction
of the attention; <as>as, a <ex>reference</ex> in a
text-book</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Relation; regard; respect.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Something that hath a <qex>reference</qex> to my state.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>One who, or that which, is referred to.</def>
<specif>Specifically;</specif> <sd>(a)</sd> <def>One of whom inquires
can be made as to the integrity, capacity, and the like, of
another.</def> <sd>(b)</sd> <def>A work, or a passage in a work, to
which one is referred.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Law)</fld> <sd>(a)</sd> <def>The act of submitting
a matter in dispute to the judgment of one or more persons for
decision.</def> <sd>(b)</sd> <fld>(Equity)</fld> <def>The process of
sending any matter, for inquiry in a cause, to a master or other
officer, in order that he may ascertain facts and report to the
court.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Appeal.</def> <mark>[R.]</mark> <ldquo/Make your
full <xex>reference</xex>.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Reference Bible</b></col>, <cd>a Bible in which brief
explanations, and references to parallel passages, are printed in the
margin of the text.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Referendary</ent><br/
<hw>Ref`er*en"da*ry</hw> <pr>(r?f`?r*?n"d?*r?)</pr>, <pos>n.</pos>
<ety>[LL. <ets>referendarius</ets>, fr. L. <ets>referendus</ets> to be
referred, gerundive of <ets>referre</ets>: cf. F.
<ets>r<eacute/f<eacute/rendaire</ets>. See <er>Refer</er>.]</ety>
<sn>1.</sn> <def>One to whose decision a cause is referred; a
referee.</def> <mark>[Obs.]</mark> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An officer who delivered the royal answer to
petitions.</def> <ldquo/<xex>Referendaries</xex>, or masters of
request.<rdquo/ <rj><au>Harmar.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Formerly, an officer of state charged with the duty
of procuring and dispatching diplomas and decrees.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Referendum</ent><br/
\'d8<hw>Ref`er*en"dum</hw> <pr>(r?f`?r*?n"d?m)</pr>, <pos>n.</pos>;
<plu>pl. <plw>-da</plw> <pr>(#)</pr></plu> <ety>[Gerundive fr. L.
<ets>referre</ets>. See <er>Refer</er>.]</ety> <sn>1.</sn> <def>A
diplomatic agent's note asking for instructions from his government
concerning a particular matter or point.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The right to approve or reject by popular vote a
meassure passed upon by a legislature.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The principle or practice of referring measures
passed upon by the legislative body to the body of voters, or
electorate, for approval or rejection, as in the Swiss cantons (except
Freiburg) and in various local governments in the United States, and
also in the local option laws, etc.; also, the right to so approve or
reject laws, or the vote by which this is done. <xex>Referendum</xex> is
distinguished from the <xex>mandate</xex>, or instruction of
representatives by the people, from <xex>direct government</xex> by the
people, in which they initiate and make the laws by direct action
without representation, and from a <xex>plebiscite</xex>, or popular
vote taken on any measure proposed by a person or body having the
initiative but not constituting a representative or constituent
body.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Referential</ent><br/
<hw>Ref`er*en"tial</hw> <pr>(-sh<it>a</it>l)</pr>, <pos>a.</pos>
<def>Containing a reference; pointing to something out of itself;
<as>as, notes for <ex>referential</ex> use</as>.</def> --
<wordforms><wf>Ref`er*en"tial*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Referment</ent><br/
<hw>Re*fer"ment</hw> <pr>(r?*f?r"m<it>e</it>nt)</pr>, <pos>n.</pos>
<def>The act of referring; reference.</def> <rj><au>Laud.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1207 --></p>

<p><ent>Re-ferment</ent><br/
<hw>Re`-fer*ment"</hw> <pr>(r<?/`f<?/r*m<?/nt")</pr>, <pos>v. t. &
i.</pos> <def>To ferment, or cause to ferment, again.</def>
<rj><au>Blackmore.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Referrer</ent><br/
<hw>Re*fer"rer</hw> <pr>(r?*f?r"r?r)</pr>, <pos>n.</pos> <def>One who
refers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Referrible</ent><br/
<hw>Re*fer"ri*ble</hw> <pr>(-r?*b'l)</pr>, <pos>a.</pos>
<def>Referable.</def> <rj><au>Hallam.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refigure</ent><br/
<hw>Re*fig"ure</hw> <pr>(r?*f?g"?r)</pr>, <pos>v. t.</pos> <def>To
figure again.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refill</ent><br/
<hw>Re*fill"</hw> <pr>(r?*f?l")</pr>, <pos>v. t. & i.</pos> <def>To
fill, or become full, again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refind</ent><br/
<hw>Re*find"</hw> <pr>(r?*f?nd)</pr>, <pos>v. t.</pos> <def>To find
again; to get or experience again.</def> <rj><au>Sandys.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refine</ent><br/
<hw>Re*fine"</hw> <pr>(r?*f?n")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Refined</conjf>
<pr>(-find")</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Refining</conjf>.]</vmorph> <ety>[Pref. <ets>re-</ets> +
<ets>fine</ets> to make fine: cf. F. <ets>raffiner</ets>.]</ety>
<sn>1.</sn> <def>To reduce to a fine, unmixed, or pure state; to free
from impurities; to free from dross or alloy; to separate from
extraneous matter; to purify; to defecate; <as>as, to <ex>refine</ex>
gold or silver; to <ex>refine</ex> iron; to <ex>refine</ex> wine or
sugar.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>I will bring the third part through the fire, and will
<qex>refine</qex> them as silver is <qex>refined</qex>.</q>
<rj><qau>Zech. xiii. 9.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To purify from what is gross, coarse, vulgar,
inelegant, low, and the like; to make elegant or exellent; to polish;
<as>as, to <ex>refine</ex> the manners, the language, the style, the
taste, the intellect, or the moral feelings</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Love <qex>refines</qex><br/
The thoughts, and heart enlarges.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To purify; clarify; polish; ennoble.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refine</ent><br/
<hw>Re*fine"</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To become pure; to
be cleared of feculent matter.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>So the pure, limpid stream, when foul with stains,<br/
Works itself clear, and, as it runs, <qex>refines</qex>.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To improve in accuracy, delicacy, or
excellence.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Chaucer <qex>refined</qex> on Boccace, and mended his stories.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>But let a lord once own the happy lines,<br/
How the wit brightens! How the style <qex>refines</qex>!</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To affect nicety or subtilty in thought or
language.</def> <ldquo/He makes another paragraph about our
<xex>refining</xex> in controversy.<rdquo/
<rj><au>Atterbury.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refined</ent><br/
<hw>Re*fined"</hw> <pr>(-f?nd")</pr>, <pos>a.</pos> <def>Freed from
impurities or alloy; purifed; polished; cultured; delicate; as;
<xex>refined</xex> gold; <xex>refined</xex> language; <xex>refined</xex>
sentiments.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Refined</qex> wits who honored poesy with their pens.</q>
<rj><qau>Peacham.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Re*fin"ed*ly</wf> <pr>(r<?/*f<?/n"<?/d*l<?/)</pr>,
<pos>adv.</pos> -- <wf>Re*fin"ed*ness</wf>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refinement</ent><br/
<hw>Re*fine"ment</hw> <pr>(r?*f?n"m<it>e</it>nt)</pr>, <pos>n.</pos>
<ety>[Cf. F. <ets>raffinement</ets>.]</ety> <sn>1.</sn> <def>The act of
refining, or the state of being refined; <as>as, the <ex>refinement</ex>
or metals; <ex>refinement</ex> of ideas.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>The more bodies are of kin to spirit in subtilty and
<qex>refinement</qex>, the more diffusive are they.</q>
<rj><qau>Norris.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>From the civil war to this time, I doubt whether the corruptions
in our language have not equaled its <qex>refinements</qex>.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is refined, elaborated, or polished to
excess; an affected subtilty; <as>as, <ex>refinements</ex> of
logic</as>.</def> <ldquo/The <xex>refinements</xex> of irregular
cunning.<rdquo/ <rj><au>Rogers.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Purification; polish; politeness; gentility;
elegance; cultivation; civilization.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refiner</ent><br/
<hw>Re*fin"er</hw> <pr>(-f?n"?r)</pr>, <pos>n.</pos> <def>One who, or
that which, refines.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refinery</ent><br/
<hw>Re*fin"er*y</hw> <pr>(-?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Refineries</plw> <pr>(-<?/z)</pr>.</plu> <ety>[Cf. F.
<ets>raffinerie</ets>.]</ety> <sn>1.</sn> <def>The building and
apparatus for refining or purifying, esp. metals and sugar.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A furnace in which cast iron is refined by the
action of a blast on the molten metal.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refit</ent><br/
<hw>Re*fit"</hw> <pr>(r?*f?t")</pr>, <pos>v. t.</pos> <sn>1.</sn>
<def>To fit or prepare for use again; to repair; to restore after damage
or decay; <as>as, to <ex>refit</ex> a garment; to <ex>refit</ex> ships
of war.</as></def> <rj><au>Macaulay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To fit out or supply a second time.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refit</ent><br/
<hw>Re*fit"</hw>, <pos>v. i.</pos> <def>To obtain repairs or supplies;
<as>as, the fleet returned to <ex>refit</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refitment</ent><br/
<hw>Re*fit"ment</hw> <pr>(-m<it>e</it>nt)</pr>, <pos>n.</pos> <def>The
act of refitting, or the state of being refitted.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refix</ent><br/
<hw>Re*fix"</hw> <pr>(r?*f?ks")</pr>, <pos>v. t.</pos> <def>To fix again
or anew; to establish anew.</def> <rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reflame</ent><br/
<hw>Re*flame"</hw> <pr>(r?*fl?m")</pr>, <pos>v. i.</pos> <def>To kindle
again into flame.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reflect</ent><br/
<hw>Re*flect"</hw> <pr>(r?*fl?kt")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Reflected</conjf>; <pos>p. pr. &
vb. n.</pos> <conjf>Reflecting</conjf>.]</vmorph> <ety>[L.
<ets>reflectere</ets>, <ets>reflexum</ets>; pref. <ets>re-</ets> re- +
<ets>flectere</ets> to bend or turn. See <er>Flexible</er>, and cf.
<er>Reflex</er>, <pos>v.</pos>]</ety> <sn>1.</sn> <def>To bend back; to
give a backward turn to; to throw back; especially, to cause to return
after striking upon any surface; <as>as, a mirror <ex>reflects</ex> rays
of light; polished metals <ex>reflect</ex> heat.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Let me mind the reader to <qex>reflect</qex> his eye on our
quotations.</q> <rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Bodies close together <qex>reflect</qex> their own color.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To give back an image or likeness of; to
mirror.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Nature is the glass <qex>reflecting</qex> God,<br/
As by the sea <qex>reflected</qex> is the sun.</q>
<rj><qau>Young.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reflect</ent><br/
<hw>Re*flect"</hw> <pos>v. i.</pos> <sn>1.</sn> <def>To throw back
light, heat, or the like; to return rays or beams.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To be sent back; to rebound as from a surface; to
revert; to return.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Whose virtues will, I hope,<br/
<qex>Reflect</qex> on Rome, as Titan's rays on earth.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To throw or turn back the thoughts upon anything; to
contemplate. Specifically: To attend earnestly to what passes within the
mind; to attend to the facts or phenomena of consciousness; to use
attention or earnest thought; to meditate; especially, to think in
relation to moral truth or rules.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We can not be said to <qex>reflect</qex> upon any external object,
except so far as that object has been previously perceived, and its
image become part and parcel of our intellectual furniture.</q>
<rj><qau>Sir W. Hamilton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>All men are concious of the operations of their own minds, at all
times, while they are awake, but there few who <qex>reflect</qex> upon
them, or make them objects of thought.</q> <rj><qau>Reid.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>As I much <qex>reflected</qex>, much I mourned.</q>
<rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To cast reproach; to cause censure or
dishonor.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Errors of wives <qex>reflect</qex> on husbands still.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Neither do I <qex>reflect</qex> in the least upon the memory of
his late majesty.</q> <rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To consider; think; cogitate; mediate;
contemplate; ponder; muse; ruminate.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reflected</ent><br/
<hw>Re*flect"ed</hw>, <pos>a.</pos> <sn>1.</sn> <def>Thrown back after
striking a surface; <as>as, <ex>reflected</ex> light, heat, sound,
etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence: Not one's own; received from another; <as>as,
his glory was <ex>reflected</ex> glory</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Bent backward or outward; reflexed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reflectent</ent><br/
<hw>Re*flect"ent</hw> <pr>(r?*fl?kt"<it>e</it>nt)</pr>, <pos>a.</pos>
<ety>[L. <ets>reflectens</ets>, p. pr. of <ets>reflectere</ets>. See
<er>Reflect</er>.]</ety> <sn>1.</sn> <def>Bending or flying back;
reflected.</def> <ldquo/The ray descendent, and the ray
<xex>reflectent</xex> flying with so great a speed.<rdquo/ <rj><au>Sir
K. Digby.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Reflecting; <as>as, a <ex>reflectent</ex>
body</as>.</def> <rj><au>Sir K. Digby.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reflectible</ent><br/
<hw>Re*flect"i*ble</hw> <pr>(-?*b'l)</pr>, <pos>a.</pos> <def>Capable of
being reflected, or thrown back; reflexible.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reflecting</ent><br/
<hw>Re*flect"ing</hw>, <pos>a.</pos> <sn>1.</sn> <def>Throwing back
light, heat, etc., as a mirror or other surface.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Given to reflection or serious consideration;
reflective; contemplative; <as>as, a <ex>reflecting</ex>
mind</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Reflecting circle</b></col>, <cd>an astronomical
instrument for measuring angless, like the sextant or Hadley's quadrant,
by the reflection of light from two plane mirrors which it carries, and
differing from the sextant chiefly in having an entire circle.</cd> --
<col><b>Reflecting galvanometer</b></col>, <cd>a galvanometer in which
the deflections of the needle are read by means of a mirror attached to
it, which reflects a ray of light or the image of a scale; -- called
also <altname>mirror galvanometer</altname>.</cd> -- <col><b>Reflecting
goniometer</b></col>. <cd>See under <er>Goniometer</er>.</cd> --
<col><b>Reflecting telescope</b></col>. <cd>See under
<er>Telescope</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reflectingly</ent><br/
<hw>Re*flect"ing*ly</hw>, <pos>adv.</pos> <def>With reflection; also,
with censure; reproachfully.</def> <rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reflection</ent><br/
<hw>Re*flec"tion</hw> <pr>(r?*fl?k"sh?n)</pr>, <pos>n.</pos> <ety>[L.
<ets>reflexio</ets>: cf. F. <ets>r<eacute/flexion</ets>. See
<er>Riflect</er>.]</ety> <altsp>[Written also
<asp>reflexion</asp>.]</altsp> <sn>1.</sn> <def>The act of reflecting,
or turning or sending back, or the state of being reflected.</def>
Specifically: <sd>(a)</sd> <def>The return of rays, beams, sound, or the
like, from a surface. See <cref>Angle of reflection</cref>,
below.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The eye sees not itself,<br/
But by <qex>reflection</qex>, by some other things.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(b)</sd> <def>The reverting of the mind to that which has already
occupied it; continued consideration; meditation; contemplation; hence,
also, that operation or power of the mind by which it is conscious of
its own acts or states; the capacity for judging rationally, especially
in view of a moral rule or standard.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>By <qex>reflection</qex>, . . . I would be understood to mean,
that notice which the mind takes of its own operations, and the manner
of them, by reason whereof there come to be ideas of these operations in
the understanding.</q> <rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>This delight grows and improves under thought and
<qex>reflection</qex>.</q> <rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Shining; brightness, as of the sun.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which is produced by reflection.</def>
Specifically: <sd>(a)</sd> <def>An image given back from a reflecting
surface; a reflected counterpart.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>As the sun water we can bear,<br/
Yet not the sun, but his <qex>reflection</qex>, there.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(b)</sd> <def>A part reflected, or turned back, at an angle; as,
the <xex>reflection</xex> of a membrane.</def> <sd>(c)</sd> <def>Result
of meditation; thought or opinion after attentive consideration or
contemplation; especially, thoughts suggested by truth.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Job's <qex>reflections</qex> on his once flourishing estate did at
the same time afflict and encourage him.</q>
<rj><qau>Atterbury.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Censure; reproach cast.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He died; and oh! may no <qex>reflection</qex> shed<br/
Its poisonous venom on the royal dead.</q>
<rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Physiol.)</fld> <def>The transference of an
excitement from one nerve fiber to another by means of the nerve cells,
as in reflex action. See <cref>Reflex action</cref>, under
<er>Reflex</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Angle of reflection</b></col>, <cd>the angle which
anything, as a ray of light, on leaving a reflecting surface, makes with
the perpendicular to the surface.</cd> -- <col><b>Angle of total
reflection</b></col>. <fld>(Opt.)</fld> <cd>Same as <cref>Critical
angle</cref>, under <er>Critical</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Meditation; contemplation; rumination;
cogitation; consideration; musing; thinking.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reflective</ent><br/
<hw>Re*flect"ive</hw> <pr>(r?*fl?kt"?v)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>r<eacute/flectif</ets>. Cf. <er>Reflexive</er>.]</ety> <sn>1.</sn>
<def>Throwing back images; <as>as, a <ex>reflective</ex>
mirror</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In the <qex>reflective</qex> stream the sighing bride, viewing her
charms.</q> <rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Capable of exercising thought or judgment; <as>as,
<ex>reflective</ex> reason</as>.</def> <rj><au>Prior.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>His perceptive and <qex>reflective</qex> faculties . . . thus
acquired a precocious and extraordinary development.</q>
<rj><qau>Motley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Addicted to introspective or meditative habits;
<as>as, a <ex>reflective</ex> person</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Gram.)</fld> <def>Reflexive; reciprocal.</def><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Re*flect"ive*ly</wf>, <pos>adv.</pos> --
<wf>Re*flect"ive*ness</wf>, <pos>n.</pos></wordforms>
<ldquo/<xex>Reflectiveness</xex> of manner.<rdquo/ <rj><au>J. C.
Shairp.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reflector</ent><br/
<hw>Re*flect"or</hw> <pr>(-<etil/r)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>r<eacute/flecteur</ets>.]</ety> <sn>1.</sn> <def>One who, or that
which, reflects.</def> <rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Physics)</fld> <sd>(a)</sd> <def>Something having a
polished surface for reflecting light or heat, as a mirror, a speculum,
etc.</def> <sd>(b)</sd> <def>A reflecting telescope.</def> <sd>(c)</sd>
<def>A device for reflecting sound.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reflet</ent><br/
\'d8<hw>Re*flet"</hw> <pr>(r<eit/*fl<ecr/")</pr>, <pos>n.</pos>
<ety>[F., reflection. See <er>Reflect</er>.]</ety> <def>Luster; special
brilliancy of surface; -- used esp. in ceramics to denote the peculiar
metallic brilliancy seen in lustered pottery such as majolica; <as>as,
silver <ex>reflet</ex>; gold <ex>reflet</ex></as>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Reflex</ent><br/
<hw>Re"flex</hw> <pr>(r?"fl?ks)</pr>, <pos>a.</pos> <ety>[L.
<ets>reflexus</ets>, p. p. of <ets>reflectere</ets>: cf. F.
<ets>r<eacute/flexe</ets>. See <er>Reflect</er>.]</ety> <sn>1.</sn>
<def>Directed back; attended by reflection; retroactive;
introspective.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>reflex</qex> act of the soul, or the turning of the
intellectual eye inward upon its own actions.</q> <rj><qau>Sir M.
Hale.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Produced in reaction, in resistance, or in
return.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Physiol.)</fld> <def>Of, pertaining to, or produced
by, stimulus or excitation without the necessary intervention of
consciousness.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Reflex action</b></col> <fld>(Physiol.)</fld>, <cd>any
action performed involuntarily in consequence of an impulse or
impression transmitted along afferent nerves to a nerve center, from
which it is reflected to an efferent nerve, and so calls into action
certain muscles, organs, or cells.</cd> -- <col><b>Reflex
nerve</b></col> <fld>(Physiol.)</fld>, <cd>an excito-motory nerve. See
<er>Exito-motory</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reflex</ent><br/
<hw>Re"flex</hw> <pr>(r?"fl?ks; <it>formerly</it> r?*fl?ks")</pr>,
<pos>n.</pos> <ety>[L. <ets>reflexus</ets> a bending back. See
<er>Reflect</er>.]</ety> <sn>1.</sn> <def>Reflection; the light
reflected from an illuminated surface to one in shade.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Yon gray is not the morning's eye,<br/
'Tis but the pale <qex>reflex</qex> of Cynthia's brow.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>On the depths of death there swims<br/
The <qex>reflex</qex> of a human face.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Physiol.)</fld> <def>An involuntary movement
produced by reflex action.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Patellar reflex</b></col>. <cd>See <cref>Knee
jerk</cref>, under <er>Knee</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reflex</ent><br/
<hw>Re*flex"</hw> <pr>(r?*fl?ks")</pr>, <pos>v. t.</pos> <ety>[L.
<ets>reflexus</ets>, p. p. of <ets>reflectere</ets>. See
<er>Reflect</er>.]</ety> <sn>1.</sn> <def>To reflect.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To bend back; to turn back.</def> <rj><au>J.
Gregory.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reflexed</ent><br/
<hw>Re*flexed"</hw> <pr>(r?*fl?kst")</pr>, <pos>a.</pos> <def>Bent
backward or outward.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reflexibility</ent><br/
<hw>Re*flex`i*bil"i*ty</hw> <pr>(r?*fl?ks`?*b?l"?*t?)</pr>,
<pos>n.</pos> <ety>[Cf. F.
<ets>r<eacute/flexibilit<eacute/</ets>.]</ety> <def>The quality or
capability of being reflexible; <as>as, the <ex>reflexibility</ex> of
the rays of light</as>.</def> <rj><au>Sir I. Newton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reflexible</ent><br/
<hw>Re*flex"i*ble</hw> <pr>(r?*fl?ks"?*b'l)</pr>, <pos>a.</pos>
<ety>[CF. F. <ets>r<eacute/flexible</ets>.]</ety> <def>Capable of being
reflected, or thrown back.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The light of the sun consists of rays differently refrangible and
<qex>reflexible</qex>.</q> <rj><qau>Cheyne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reflexion</ent><br/
<hw>Re*flex"ion</hw> <pr>(-fl?k"sh?n)</pr>, <pos>n.</pos> <def>See
<er>Reflection</er>.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reflexity</ent><br/
<hw>Re*flex"i*ty</hw> <pr>(r?*fl?ks"?*t?)</pr>, <pos>n.</pos> <def>The
state or condition of being reflected.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reflexive</ent><br/
<hw>Re*flex"ive</hw> <pr>(-?v)</pr>, <pos>a.</pos> <sn>1.</sn> <ety>[Cf.
F. <ets>r<eacute/flexif</ets>.]</ety> <def>Bending or turned backward;
reflective; having respect to something past.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Assurance <qex>reflexive</qex> can not be a divine faith.</q>
<rj><qau>Hammond.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Implying censure.</def> <mark>[Obs.]</mark>
<ldquo/What man does not resent an ugly <xex>reflexive</xex>
word?<rdquo/ <rj><au>South.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Gram.)</fld> <def>Having for its direct object a
pronoun which refers to the agent or subject as its antecedent; -- said
of certain verbs; <as>as, the witness <xex>perjured</xex> himself; I
<xex>bethought</xex> myself. Applied also to pronouns of this class;
reciprocal; reflective.</as></def><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Re*flex"ive*ly</wf>, <pos>adv.</pos> --
<wf>Re*flex"ive*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reflexly</ent><br/
<hw>Re*flex"ly</hw>, <pos>adv.</pos> <def>In a reflex manner;
reflectively.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refloat</ent><br/
<hw>Re"float</hw> <pr>(r?"fl?t)</pr>, <pos>n.</pos> <def>Reflux;
ebb.</def> <mark>[Obs.]</mark> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reflorescence</ent><br/
<hw>Re`flo*res"cence</hw> <pr>(r?`fl?*r?s"s<it>e</it>ns)</pr>,
<pos>n.</pos> <fld>(Bot.)</fld> <def>A blossoming anew of a plant after
it has apparently ceased blossoming for the season.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reflourish</ent><br/
<hw>Re*flour"ish</hw> <pr>(r?*fl?r"?sh)</pr>, <pos>v. t. & i.</pos>
<def>To flourish again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reflow</ent><br/
<hw>Re*flow"</hw> <pr>(r?*fl?")</pr>, <pos>v. i.</pos> <def>To flow
back; to ebb.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reflower</ent><br/
<hw>Re*flow"er</hw> <pr>(r<emac/*flou"<etil/r)</pr>, <pos>v. i. &
t.</pos> <def>To flower, or cause to flower, again.</def>
<rj><au>Sylvester.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refluctuation</ent><br/
<hw>Re*fluc`tu*a"tion</hw> <pr>(r?*fl?k`t?*?"sh?n; 135)</pr>,
<pos>n.</pos> <def>A flowing back; refluence.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refluency</ent><br/
<ent>Refluence</ent><br/
<mhw>{ <hw>Ref"lu*ence</hw> <pr>(r?f"l?-<it>e</it>ns)</pr>,
<hw>Ref"lu*en*cy</hw> <pr>(-<it>e</it>n*s?)</pr>, }</mhw> <pos>n.</pos>
<def>The quality of being refluent; a flowing back.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refluent</ent><br/
<hw>Ref"lu*ent</hw> <pr>(-<it>e</it>nt)</pr>, <pos>a.</pos> <ety>[L.
<ets>refluens</ets>, p. pr. of <ets>refluere</ets> to flow back; pref.
<ets>re-</ets> re- + <ets>fluere</ets> to flow. See
<er>Flurent</er>.]</ety> <def>Flowing back; returning; ebbing.</def>
<rj><au>Cowper.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And <qex>refluent</qex> through the pass of fear<br/
The battle's tide was poured.</q> <rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reflueus</ent><br/
<hw>Ref"lu*eus</hw> <pr>(-?s)</pr>, <pos>a.</pos> <ety>[L.
<ets>refluus</ets>.]</ety> <def>Refluent.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reflux</ent><br/
<hw>Re"flux`</hw> <pr>(r?"fl?ks`)</pr>, <pos>a.</pos> <def>Returning, or
flowing back; reflex; <as>as, <ex>reflux</ex> action</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reflux</ent><br/
<hw>Re"flux`</hw>, <pos>n.</pos> <ety>[F. <ets>reflux</ets>. See
<er>Refluent</er>, <er>Flux</er>.]</ety> <def>A flowing back, as the
return of a fluid; ebb; reaction; <as>as, the flux and <ex>reflux</ex>
of the tides</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>All from me<br/
Shall with a fierce <qex>reflux</qex> on me redound.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refocillate</ent><br/
<hw>Re*foc"il*late</hw> <pr>(r?*f?s"?l*l?t)</pr>, <pos>v. t.</pos>
<ety>[L. <ets>refocillatus</ets>, p. p. of <ets>refocillare</ets>; pref.
<ets>re-</ets> re- + <ets>focillare</ets> to revive by warmth.]</ety>
<def>To refresh; to revive.</def> <mark>[Obs.]</mark>
<rj><au>Aubrey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refocillation</ent><br/
<hw>Re*foc`il*la"tion</hw> <pr>(-l?"sh?n)</pr>, <pos>n.</pos>
<def>Restoration of strength by refreshment.</def> <mark>[Obs.]</mark>
<rj><au>Middleton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refold</ent><br/
<hw>Re*fold"</hw> <pr>(r?*f?ld")</pr>, <pos>v. t.</pos> <def>To fold
again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refoment</ent><br/
<hw>Re`fo*ment"</hw> <pr>(r?`f?*m<it>?</it>nt")</pr>, <pos>v. t.</pos>
<def>To foment anew.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reforest</ent><br/
<hw>Re*for"est</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Reforested</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Reforesting</conjf>.]</vmorph> <def>To replant with
trees; to reafforest; to reforestize.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Reforestation</ent><br/
<hw>Re`for*est*a"tion</hw> <pr>(?)</pr>, <pos>n</pos> <def>replanting
with trees; reconversion into a forest; the act of
reforesting.</def><br/
[<source>PJC</source>]</p>

<p><ent>Reforestization</ent><br/
<hw>Re*for`est*i*za`tion</hw> <pr>(r?*f?r`?st*?*z?"sh?n)</pr>,
<pos>n.</pos> <def>The act or process of reforestizing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reforestize</ent><br/
<hw>Re*for"est*ize</hw> <pr>(r?*f?r"?st*?z)</pr>, <pos>v. t.</pos>
<def>To convert again into a forest; to plant again with
trees.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reforge</ent><br/
<hw>Re*forge"</hw> <pr>(r?*f?rj")</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>re-</ets> + <ets>forge</ets>: cf. F. <ets>reforger</ets>.]</ety>
<def>To forge again or anew; hence, to fashion or fabricate anew; to
make over.</def> <rj><au>Udall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reforger</ent><br/
<hw>Re*for"ger</hw> <pr>(r?*f?r"j?r)</pr>, <pos>n.</pos> <def>One who
reforges.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reform</ent><br/
<hw>Re*form"</hw> <pr>(r?*f?rm")</pr>, <pos>v. t.</pos> <ety>[F.
<ets>r<eacute/former</ets>, L. <ets>reformare</ets>; pref.
<ets>re-</ets> re- + <ets>formare</ets> to form, from <ets>forma</ets>
form. See <er>Form</er>.]</ety> <def>To put into a new and improved form
or condition; to restore to a former good state, or bring from bad to
good; to change from worse to better; to amend; to correct; <as>as, to
<ex>reform</ex> a profligate man; to <ex>reform</ex> corrupt manners or
morals.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>The example alone of a vicious prince will corrupt an age; but
that of a good one will not <qex>reform</qex> it.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To amend; correct; emend; rectify; mend; repair;
better; improve; restore; reclaim.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reform</ent><br/
<hw>Re*form"</hw>, <pos>v. i.</pos> <def>To return to a good state; to
amend or correct one's own character or habits; <as>as, a man of settled
habits of vice will seldom <ex>reform</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reform</ent><br/
<hw>Re*form"</hw>, <pos>n.</pos> <ety>[F.
<ets>r<eacute/forme</ets>.]</ety> <def>Amendment of what is defective,
vicious, corrupt, or depraved; reformation; <as>as, <ex>reform</ex> of
elections; <ex>reform</ex> of government.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Civil service reform</b></col>. <cd>See under
<er>Civil</er>.</cd> -- <col><b>Reform acts</b></col> <fld>(Eng.
Politics)</fld>, <cd>acts of Parliament passed in 1832, 1867, 1884,
1885, extending and equalizing popular representation in
Parliament.</cd> -- <col><b>Reform school</b></col>, <cd>a school
established by a state or city government, for the confinement,
instruction, and reformation of juvenile offenders, and of young persons
of idle, vicious, and vagrant habits.</cd> <mark>[U. S.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Reformation; amendment; rectification;
correction. See <er>Reformation</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Re-form</ent><br/
<hw>Re-form"</hw> <pr>(r?*f?rm")</pr>, <pos>v. t. & i.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Re-formed</conjf>
<pr>(-f?rmd")</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Re-forming</conjf>.]</vmorph> <def>To give a new form to; to form
anew; to take form again, or to take a new form; <as>as, to
<ex>re-form</ex> the line after a charge</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reformable</ent><br/
<hw>Re*form"a*ble</hw> <pr>(r?*f?rm"?*b'l)</pr>, <pos>a.</pos>
<def>Capable of being reformed.</def> <rj><au>Foxe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reformade</ent><br/
<hw>Ref`or*made"</hw> <pr>(r?f`?r*m?d")</pr>, <pos>n.</pos> <def>A
reformado.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reformado</ent><br/
<hw>Ref`or*ma"do</hw> <pr>(-m?"d?)</pr>, <pos>n.</pos> <ety>[Sp., fr.
<ets>reformar</ets>, L. <ets>reformare</ets>. SEe <er>Reform</er>,
<pos>v. t.</pos>]</ety> <sn>1.</sn> <def>A monk of a reformed
order.</def> <mark>[Obs.]</mark> <rj><au>Weever.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An officer who, in disgrace, is deprived of his
command, but retains his rank, and sometimes his pay.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reformalize</ent><br/
<hw>Re*form"al*ize</hw> <pr>(r?*f?rm"<it>a</it>l*?z)</pr>, <pos>v.
i.</pos> <def>To affect reformation; to pretend to correctness.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reformation</ent><br/
<hw>Ref`or*ma"tion</hw> <pr>(r?f`?r*m?"sh?n)</pr>, <pos>n.</pos>
<ety>[F. <ets>r<eacute/formation</ets>, L. <ets>reformatio</ets>.]</ety>
<sn>1.</sn> <def>The act of reforming, or the state of being reformed;
change from worse to better; correction or amendment of life, manners,
or of anything vicious or corrupt; <as>as, the <ex>reformation</ex> of
manners; <ex>reformation</ex> of the age; <ex>reformation</ex> of
abuses</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Satire lashes vice into <qex>reformation</qex>.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1208 --></p>

<p><sn>2.</sn> <def>Specifically <fld>(Eccl. Hist.)</fld>, the important
religious movement commenced by Luther early in the sixteenth century,
which resulted in the formation of the various Protestant
churches.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Reform; amendment; correction;
rectification.</syn> <usage> -- <er>Reformation</er>, <er>Reform</er>.
<xex>Reformation</xex> is a more thorough and comprehensive change than
<xex>reform</xex>. It is applied to subjects that are more important,
and results in changes which are more lasting. A <xex>reformation</xex>
involves, and is followed by, many particular <xex>reforms</xex>.
<ldquo/The pagan converts mention this great <xex>reformation</xex> of
those who had been the greatest sinners, with that sudden and surprising
change which the Christian religion made in the lives of the most
profligate.<rdquo/ <au>Addison.</au> <ldquo/A variety of schemes,
founded in visionary and impracticable ideas of <xex>reform</xex>, were
suddenly produced.<rdquo/ <au>Pitt.</au></usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Re-formation</ent><br/
<hw>Re`-for*ma"tion</hw> <pr>(r?`f?r*m?"sh?n)</pr>, <pos>n.</pos>
<def>The act of forming anew; a second forming in order; <as>as, the
<ex>reformation</ex> of a column of troops into a hollow
square</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reformative</ent><br/
<hw>Re*form"a*tive</hw> <pr>(r?*f?rm"?*t?v)</pr>, <pos>a.</pos>
<def>Forming again; having the quality of renewing form;
reformatory.</def> <rj><au>Good.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reformatory</ent><br/
<hw>Re*form"a*to*ry</hw> <pr>(-t?*r?)</pr>, <pos>a.</pos> <def>Tending
to produce reformation; reformative.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reformatory</ent><br/
<hw>Re*form"a*to*ry</hw>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>-ries</plw> <pr>(-r<?/z)</pr>.</plu> <def>An institution for
promoting the reformation of offenders.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Magistrates may send juvenile offenders to
<qex>reformatories</qex> instead of to prisons.</q> <rj><qau>Eng.
Cyc.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reformed</ent><br/
<hw>Re*formed"</hw> <pr>(r?*f?rmd")</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Corrected; amended; restored to purity or excellence; said,
specifically, of the whole body of Protestant churches originating in
the Reformation. Also, in a more restricted sense, of those who
separated from Luther on the doctrine of consubstantiation, etc., and
carried the Reformation, as they claimed, to a higher point. The
Protestant churches founded by them in Switzerland, France, Holland, and
part of Germany, were called the <xex>Reformed churches</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The town was one of the strongholds of the <qex>Reformed</qex>
faith.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Amended in character and life; <as>as, a
<ex>reformed</ex> gambler or drunkard</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Mil.)</fld> <def>Retained in service on half or
full pay after the disbandment of the company or troop; -- said of an
officer.</def> <mark>[Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reformer</ent><br/
<hw>Re*form"er</hw> <pr>(r?*f?rm"?r)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>One who effects a reformation or amendment; one who labors for, or
urges, reform; <as>as, a <ex>reformer</ex> of manners, or of
abuses</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Eccl.Hist.)</fld> <def>One of those who commenced
the reformation of religion in the sixteenth century, as Luther,
Melanchthon, Zwingli, and Calvin.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reformist</ent><br/
<hw>Re*form"ist</hw>, <pos>n.</pos> <ety>[Cf. F.
<ets>r<eacute/formiste</ets>.]</ety> <def>A reformer.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reformly</ent><br/
<hw>Re*form"ly</hw>, <pos>adv.</pos> <def>In the manner of a reform; for
the purpose of reform.</def> <mark>[Obs.]</mark>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refortification</ent><br/
<hw>Re*for`ti*fi*ca"tion</hw> <pr>(r?*f?r`t?*f?*k?"sh?n)</pr>,
<pos>n.</pos> <def>A fortifying anew, or a second time.</def>
<rj><au>Mitford.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refortify</ent><br/
<hw>Re*for"ti*fy</hw> <pr>(r?*f?r"t?*f?)</pr>, <pos>v. t.</pos> <def>To
fortify anew.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refossion</ent><br/
<hw>Re*fos"sion</hw> <pr>(r?*f?sh"?n)</pr>, <pos>n.</pos> <ety>[L.
<ets>refodere</ets>, <ets>refossum</ets>, to dig up again. See
<er>Fosse</er>.]</ety> <def>The act of digging up again.</def>
<mark>[Obs.]</mark> <rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refound</ent><br/
<hw>Re*found"</hw> <pr>(r?*found")</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>re-</ets> + <ets>found</ets> to cast; cf. F. <ets>refondare</ets>.
Cf. <er>Refund</er>.]</ety> <sn>1.</sn> <def>To found or cast
anew.</def> <ldquo/Ancient bells <xex>refounded</xex>.<rdquo/ <rj><au>T.
Warton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To found or establish again; to
reestablish.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refound</ent><br/
<hw>Re*found"</hw>, <def><pos>imp. & p. p.</pos> of <er>Refind</er>,
<pos>v. t.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refounder</ent><br/
<hw>Re*found"er</hw> <pr>(-?r)</pr>, <pos>n.</pos> <def>One who
refounds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refract</ent><br/
<hw>Re*fract"</hw> <pr>(r?*fr$kt")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Refracted</conjf>; <pos>p. pr. &
vb. n.</pos> <conjf>Refracting</conjf>.]</vmorph> <ety>[L.
<ets>refractus</ets>, p. p. of <ets>refringere</ets>; pref.
<ets>re-</ets> re- + <ets>frangere</ets> to break: cf. F.
<ets>r<eacute/fracter</ets>. SEe <er>FRacture</er>, and cf.
<er>Refrain</er>, <pos>n.</pos>]</ety> <sn>1.</sn> <def>To bend sharply
and abruptly back; to break off.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To break the natural course of, as rays of light orr
heat, when passing from one transparent medium to another of different
density; to cause to deviate from a direct course by an action distinct
from reflection; <as>as, a dense medium <ex>refrcts</ex> the rays of
light as they pass into it from a rare medium</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refractable</ent><br/
<hw>Re*fract"a*ble</hw> <pr>(-?*b'l)</pr>, <pos>a.</pos> <def>Capable of
being refracted.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refracted</ent><br/
<hw>Re*fract"ed</hw>, <pos>a.</pos> <sn>1.</sn> <fld>(Bot. &
Zool.)</fld> <def>Bent backward angularly, as if half-broken; <as>as, a
<ex>refracted</ex> stem or leaf</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Turned from a direct course by refraction; <as>as,
<ex>refracted</ex> rays of light</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refracting</ent><br/
<hw>Re*fract"ing</hw>, <pos>a.</pos> <def>Serving or tending to refract;
<as>as, a <ex>refracting</ex> medium</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Refracting angle of a prism</b></col> <fld>(Opt.)</fld>,
<cd>the angle of a triangular prism included between the two sides
through which the refracted beam passes in the decomposition of
light.</cd> -- <col><b>Refracting telescope</b></col>. <fld>(Opt.)</fld>
<cd>See under <er>Telescope</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refraction</ent><br/
<hw>Re*frac"tion</hw> <pr>(r?*fr?k"sh?n)</pr>, <pos>n.</pos> <ety>[F.
<ets>r<eacute/fraction</ets>.]</ety> <sn>1.</sn> <def>The act of
refracting, or the state of being refracted.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The change in the direction of ray of light, heat,
or the like, when it enters obliquely a medium of a different density
from that through which it has previously moved.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Refraction</qex> out of the rarer medium into the denser, is
made towards the perpendicular.</q> <rj><qau>Sir I.
Newton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Astron.)</fld> <sd>(a)</sd> <def>The change in the
direction of a ray of light, and, consequently, in the apparent position
of a heavenly body from which it emanates, arising from its passage
through the earth's atmosphere; -- hence distinguished as atmospheric
refraction, or astronomical refraction.</def> <sd>(b)</sd> <def>The
correction which is to be deducted from the apparent altitude of a
heavenly body on account of atmospheric refraction, in order to obtain
the true altitude.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Angle of refraction</b></col> <fld>(Opt.)</fld>, <cd>the
angle which a refracted ray makes with the perpendicular to the surface
separating the two media traversed by the ray.</cd> -- <col><b>Conical
refraction</b></col> <fld>(Opt.)</fld>, <cd>the refraction of a ray of
light into an infinite number of rays, forming a hollow cone. This
occurs when a ray of light is passed through crystals of some
substances, under certain circumstances. Conical refraction is of two
kinds; <xex>external conical refraction</xex>, in which the ray issues
from the crystal in the form of a cone, the vertex of which is at the
point of emergence; and <xex>internal conical refraction</xex>, in which
the ray is changed into the form of a cone on entering the crystal, from
which it issues in the form of a hollow cylinder. This singular
phenomenon was first discovered by Sir W. R. Hamilton by mathematical
reasoning alone, unaided by experiment.</cd> -- <col><b>Differential
refraction</b></col> <fld>(Astron.)</fld>, <cd>the change of the
apparent place of one object relative to a second object near it, due to
refraction; also, the correction required to be made to the observed
relative places of the two bodies.</cd> -- <col><b>Double
refraction</b></col> <fld>(Opt.)</fld>, <cd>the refraction of light in
two directions, which produces two distinct images. The power of double
refraction is possessed by all crystals except those of the isometric
system. A uniaxial crystal is said to be <xex>optically positive</xex>
(like quartz), or <xex>optically negative</xex> (like calcite), or to
have <xex>positive</xex>, or <xex>negative</xex>, <xex>double
refraction</xex>, according as the optic axis is the axis of least or
greatest elasticity for light; a biaxial crystal is similarly designated
when the same relation holds for the acute bisectrix.</cd> --
<col><b>Index of refraction</b></col>. <cd>See under
<er>Index</er>.</cd> -- <col><b>Refraction circle</b></col>
<fld>(Opt.)</fld>, <cd>an instrument provided with a graduated circle
for the measurement of refraction.</cd> -- <mcol><col><b>Refraction of
latitude</b></col>, <col><b>longitude</b></col>,
<col><b>declination</b></col>, <col><b>right ascension</b></col></mcol>,
<cd>etc., the change in the apparent latitude, longitude, etc., of a
heavenly body, due to the effect of atmospheric refraction.</cd> --
<col><b>Terrestrial refraction</b></col>, <cd>the change in the apparent
altitude of a distant point on or near the earth's surface, as the top
of a mountain, arising from the passage of light from it to the eye
through atmospheric strata of varying density.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refractive</ent><br/
<hw>Re*fract"ive</hw> <pr>(r?*fr?kt"?v)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>r<eacute/fractif</ets>. See <er>Refract</er>.]</ety> <def>Serving
or having power to refract, or turn from a direct course; pertaining to
refraction; <as>as, <ex>refractive</ex> surfaces; <ex>refractive</ex>
powers.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Refractive index</b></col>. <fld>(Opt.)</fld> <cd>See
<cref>Index of refraction</cref>, under <er>Index</er>.</cd> --
<col><b>Absolute refractive index</b></col> <fld>(Opt.)</fld>, <cd>the
index of refraction of a substances when the ray passes into it from a
vacuum.</cd> -- <col><b>Relative refractive index</b></col> (of two
media) <fld>(Opt.)</fld>, <cd>the ratio of the sine of the angle of
incidence to the sine of the angle of refraction for a ray passing out
of one of the media into the other.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refractiveness</ent><br/
<hw>Re*fract"ive*ness</hw>, <pos>n.</pos> <def>The quality or condition
of being refractive.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refractometer</ent><br/
<hw>Re`frac*tom"e*ter</hw> <pr>(r?`fr?k*t?m"?*t?r)</pr>, <pos>n.</pos>
<ety>[<ets>Refraction</ets> + <ets>-meter</ets>.]</ety>
<fld>(Opt.)</fld> <def>A contrivance for exhibiting and measuring the
refraction of light.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refractor</ent><br/
<hw>Re*fract"or</hw> <pr>(r<?/-fr<?/kt"<?/r)</pr>, <pos>n.</pos>
<def>Anything that refracts</def>; specifically: <fld>(Opt.)</fld>
<def>A refracting telescope, in which the image to be viewed is formed
by the refraction of light in passing through a convex lens.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refractorily</ent><br/
<hw>Re*frac"to*ri*ly</hw> <pr>(r?*fr?k"t?*r?*l?)</pr>, <pos>adv.</pos>
<def>In a refractory manner; perversely; obstinately.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refractoriness</ent><br/
<hw>Re*frac"to*ri*ness</hw>, <pos>n.</pos> <def>The quality or condition
of being refractory.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refractory</ent><br/
<hw>Re*frac"to*ry</hw> <pr>(-r?)</pr>, <pos>a.</pos> <ety>[L.
<ets>refractorius</ets>, fr. <ets>refringere</ets>: cf. F.
<ets>refractaire</ets>. See <er>Refract</er>.]</ety> <sn>1.</sn>
<def>Obstinate in disobedience; contumacious; stubborn; unmanageable;
<as>as, a <ex>refractory</ex> child; a <ex>refractory</ex>
beast</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Raging appetites that are<br/
Most disobedient and <qex>refractory</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Resisting ordinary treatment; difficult of fusion,
reduction, or the like; -- said especially of metals and the like, which
do not readily yield to heat, or to the hammer; <as>as, a
<ex>refractory</ex> ore</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Perverse; contumacious; unruly; stubborn;
obstinate; unyielding; ungovernable; unmanageable.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refractory</ent><br/
<hw>Re*frac"to*ry</hw>, <pos>n.</pos> <sn>1.</sn> <def>A refractory
person.</def> <rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Refractoriness.</def> <mark>[Obs.]</mark>
<rj><au>Jer. TAylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>O<xex>Pottery</xex>) A piece of ware covered with a
vaporable flux and placed in a kiln, to communicate a glaze to the other
articles.</def> <rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refracture</ent><br/
<hw>Re*frac"ture</hw> <pr>(r?*fr?k"t?r;135)</pr>, <pos>n.</pos>
<fld>(Surg.)</fld> <def>A second breaking (as of a badly set bone) by
the surgeon.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refracture</ent><br/
<hw>Re*frac"ture</hw>, <pos>v. t.</pos> <fld>(Surg.)</fld> <def>To break
again, as a bone.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refragable</ent><br/
<hw>Ref"ra*ga*ble</hw> <pr>(r?f"r?*g?*b'l)</pr>, <pos>a.</pos> <ety>[LL.
<ets>refragabilis</ets>, fr. L. <ets>refragari</ets> to oppose.]</ety>
<def>Capable of being refuted; refutable.</def> <mark>[R.]</mark> --
<wordforms><wf>Ref"ra*ga*ble*ness</wf>, <pos>n.</pos> <mark>[R.]</mark>
-- <wf>Ref`ra*ga*bil"i*ty</wf> <pr>(-b<?/l`<?/*t<?/)</pr>, <pos>n.</pos>
<mark>[R.]</mark></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refragate</ent><br/
<hw>Ref"ra*gate</hw> <pr>(-g?t)</pr>, <pos>v. i.</pos> <ety>[L.
<ets>refragatus</ets>, p. p. of <ets>refragor</ets>.]</ety> <def>To
oppose.</def> <mark>[R.]</mark> <rj><au>Glanvill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refrain</ent><br/
<hw>Re*frain"</hw> <pr>(r<esl/*fr<amac/n")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Refrained</conjf>
<pr>(-fr<amac/nd")</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Refraining</conjf>.]</vmorph> <ety>[OE. <ets>refreinen</ets>, OF.
<ets>refrener</ets>, F. <ets>refr<eacute/ner</ets>, fr. L.
<ets>refrenare</ets>; influenced by OF. <ets>refraindre</ets> to
restrain, moderate, fr. LL. <ets>refrangere</ets>, for L.
<ets>refringere</ets> to break up, break (see <er>Refract</er>). L.
<ets>refrenare</ets> is fr. pref. <ets>re-</ets> back +
<ets>frenum</ets> bridle; cf. Skr. <ets>dh<rsdot/</ets> to hold.]</ety>
<sn>1.</sn> <def>To hold back; to restrain; to keep within prescribed
bounds; to curb; to govern.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His reason <qex>refraineth</qex> not his foul delight or
talent.</q> <rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Refrain</qex> thy foot from their path.</q> <rj><qau>Prov. i.
15.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To abstain from.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Who, requiring a remedy for his gout, received no other counsel
than to <qex>refrain</qex> cold drink.</q> <rj><qau>Sir T.
Browne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refrain</ent><br/
<hw>Re*frain"</hw>, <pos>v. i.</pos> <def>To keep one's self from action
or interference; to hold aloof; to forbear; to abstain.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Refrain</qex> from these men, and let them alone.</q>
<rj><qau>Acts v. 38.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>They <qex>refrained</qex> therefrom [eating flesh] some time
after.</q> <rj><qau>Sir T. Browne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To hold back; forbear; abstain;
withhold.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refrain</ent><br/
<hw>Re*frain"</hw>, <pos>n.</pos> <ety>[F. <ets>refrain</ets>, fr. OF.
<ets>refraindre</ets>; cf. Pr. <ets>refranhs</ets> a refrain,
<ets>refranher</ets> to repeat. See <er>Refract</er>,<er>Refrain</er>,
<pos>v.</pos>]</ety> <def>The burden of a song; a phrase or verse which
recurs at the end of each of the separate stanzas or divisions of a
poetic composition.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We hear the wild <qex>refrain</qex>.</q>
<rj><qau>Whittier.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refrainer</ent><br/
<hw>Re*frain"er</hw> <pr>(r<esl/*fr<amac/n"<etil/r)</pr>, <pos>n.</pos>
<def>One who refrains.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refrainment</ent><br/
<hw>Re*frain"ment</hw> <pr>(-m<it>e</it>nt)</pr>, <pos>n.</pos> <def>Act
of refraining.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reframe</ent><br/
<hw>Re*frame"</hw> <pr>(r<esl/*fr<amac/m)</pr>, <pos>v. t.</pos> <def>To
frame again or anew.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refrangibility</ent><br/
<hw>Re*fran`gi*bil"i*ty</hw> <pr>(r?*fr?n`j?*b?l"?*t?)</pr>,
<pos>n.</pos> <ety>[Cf. F.
<ets>r<eacute/frangibilit<eacute/</ets>.]</ety> <def>The quality of
being refrangible.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refrangible</ent><br/
<hw>Re*fran"gi*ble</hw> <pr>(-fr?n"j?*b'l)</pr>, <pos>a.</pos> <ety>[Cf.
F. <ets>r<eacute/frangible</ets>. See <er>Refract</er>.]</ety>
<def>Capable of being refracted, or turned out of a direct course, in
passing from one medium to another, as rays of light.</def> --
<wordforms><wf>Re*fran"gi*ble*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refrenation</ent><br/
<hw>Ref`re*na"tion</hw> <pr>(r?f`r?*n?"sh?n)</pr>, <pos>n.</pos>
<ety>[L. <ets>refrenatio</ets>. See <er>Refrain</er>, <pos>v.
t.</pos>]</ety> <def>The act of refraining.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refresh</ent><br/
<hw>Re*fresh"</hw> <pr>(r?*fr?sh")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Refreshed</conjf>
<pr>(-fr?sht")</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Refreshing</conjf>.]</vmorph> <ety>[OE. <ets>refreshen</ets>,
<ets>refreschen</ets>, OF. <ets>refreschir</ets> (cf. OF.
<ets>rafraischir</ets>, <ets>rafreschir</ets>, F.
<ets>rafra<?/chir</ets>); pref. <ets>re-</ets> re- + <ets>fres</ets>
fresh. F. <ets>frais</ets>. See <er>Fresh</er>, <pos>a.</pos>]</ety>
<sn>1.</sn> <def>To make fresh again; to restore strength, spirit,
animation, or the like, to; to relieve from fatigue or depression; to
reinvigorate; to enliven anew; to reanimate; <as>as, sleep
<ex>refreshes</ex> the body and the mind</as>.</def>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Foer they have <qex>refreshed</qex> my spirit and yours.</q>
<rj><qau>1 Cor. xvi. 18.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And labor shall <qex>refresh</qex> itself with hope.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To make as if new; to repair; to restore.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The rest <qex>refresh</qex> the scaly snakes that fol<?/<br/
The shield of Pallas, and renew their gold.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To refresh the memory</b></col>, <cd>to quicken or
strengthen it, as by a reference, review, memorandum, or
suggestion.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To cool; refrigerate; invigorate; revive;
reanimate; renovate; renew; restore; recreate; enliven; cheer.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refresh</ent><br/
<hw>Re*fresh"</hw>, <pos>n.</pos> <def>The act of refreshing.</def>
<mark>[Obs.]</mark> <rj><au>Daniel.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refresher</ent><br/
<hw>Re*fresh"er</hw> <pr>(-?r)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One
who, or that which, refreshes.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>An extra fee paid to counsel in a
case that has been adjourned from one term to another, or that is
unusually protracted.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Ten guineas a day is the highest <qex>refresher</qex> which a
counsel can charge.</q> <rj><qau>London Truth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refreshful</ent><br/
<hw>Re*fresh"ful</hw> <pr>(-f?l)</pr>, <pos>a.</pos> <def>Full of power
to refresh; refreshing.</def> -- <wordforms><wf>Re*fresh"ful*ly</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refreshing</ent><br/
<hw>Re*fresh"ing</hw>, <pos>a.</pos> <def>Reviving; reanimating.</def>
-- <wordforms><wf>Re*fresh"ing*ly</wf>, <pos>adv.</pos> --
<wf>Re*fresh"ing*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refreshment</ent><br/
<hw>Re*fresh"ment</hw> <pr>(-m<it>e</it>nt)</pr>, <pos>n.</pos>
<ety>[CF. OF. <ets>refreschissement</ets>, F.
<ets>rafra<icir/chissement</ets>.]</ety> <sn>1.</sn> <def>The act of
refreshing, or the state of being refreshed; restoration of strength,
spirit, vigor, or liveliness; relief after suffering; new life or
animation after depression.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which refreshes; means of restoration or
reanimation; especially, an article of food or drink.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refret</ent><br/
<hw>Re*fret"</hw> <pr>(r?*fr?t")</pr>, <pos>n.</pos> <ety>[OF.
<ets>refret</ets>, L. <ets>refractus</ets>, p. p. See <er>Refrain</er>,
<pos>n.</pos>, <er>Refract</er>.]</ety> <def>Refrain.</def>
<mark>[Obs.]</mark> <rj><au>Bailey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refreyd</ent><br/
<hw>Re*freyd"</hw> <pr>(r?*fr?d")</pr>, <pos>v. t.</pos> <ety>[OF.
<ets>refreidier</ets>.]</ety> <def>To chill; to cool.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Refreyded</qex> by sickness . . . or by cold drinks.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refrication</ent><br/
<hw>Ref`ri*ca"tion</hw> <pr>(r?f`r?*k?"sh?n)</pr>, <pos>n.</pos>
<ety>[L. <ets>refricare</ets> to rub again.]</ety> <def>A rubbing up
afresh; a brightening.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>A continual <qex>refrication</qex> of the memory.</q> <rj><qau>Bp.
Hall.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refrigerant</ent><br/
<hw>Re*frig"er*ant</hw> <pr>(r?*fr?j"?r-<it>a</it>nt)</pr>,
<pos>a.</pos> <ety>[L. <ets>refrigerans</ets>, p. pr. of
<ets>refrigerare</ets>: cf. F. <ets>r<eacute/frig<eacute/rant</ets>. See
<er>Refrigerate</er>.]</ety> <def>Cooling; allaying heat or fever.</def>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refrigerant</ent><br/
<hw>Re*frig"er*ant</hw>, <pos>n.</pos> <def>That which makes to be cool
or cold; specifically, a medicine or an application for allaying fever,
or the symptoms of fever; -- used also figuratively.</def>
<au>Holland.</au> <ldquo/A <xex>refrigerant</xex> to passion.<rdquo/
<rj><au>Blair.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refrigerate</ent><br/
<hw>Re*frig"er*ate</hw> <pr>(-<amac/t)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Refrigerated</conjf>
<pr>(-<amac/`t<ecr/d)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Refrigerating</conjf>.]</vmorph> <ety>[L.
<ets>refrigeratus</ets>, p. p. of <ets>refrigerare</ets>; pref.
<ets>re-</ets> re- + <ets>frigerare</ets> to make cool, fr.
<ets>frigus</ets>, <ets>frigoris</ets>, coolness. See
<er>Frigid</er>.]</ety> <def>To cause to become cool; to make or keep
cold or cool.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refrigeration</ent><br/
<hw>Re*frig`er*a"tion</hw> <pr>(-?"sh?n)</pr>, <pos>n.</pos> <ety>[Cf.
F. <ets>r<eacute/frig<eacute/ration</ets>, L.
<ets>refrigeratio</ets>.]</ety> <def>The act or process of refrigerating
or cooling, or the state of being cooled.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refrigerative</ent><br/
<hw>Re*frig"er*a*tive</hw> <pr>(r?*fr?j"?r*?*t?v)</pr>, <pos>a.</pos>
<ety>[Cf. F. <ets>r<eacute/frig<eacute/ratif</ets>.]</ety> <def>Cooling;
allaying heat.</def> -- <def2><pos>n.</pos> <def>A
refrigerant.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><q>Crazed brains should come under a <qex>refrigerative</qex>
treatment.</q> <rj><qau>I. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refrigerator</ent><br/
<hw>Re*frig"er*a`tor</hw> <pr>(-?`t?r)</pr>, <pos>n.</pos> <def>That
which refrigerates or makes cold; that which keeps cool.</def>
Specifically: <sd>(a)</sd> <def>A box or room for keeping food or other
articles cool, usually by means of ice.</def><-- now by a mechanical
cooling mechanism. --> <sd>(b)</sd> <def>An apparatus for rapidly
cooling heated liquids or vapors, connected with a still, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Refrigerator car</b></col> <fld>(Railroad)</fld>, <cd>a
freight car constructed as a refrigerator, for the transportation of
fresh meats, fish, etc., in a temperature kept cool by ice.</cd></cs><--
or by mechanical refrigeration --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refrigeratory</ent><br/
<hw>Re*frig"er*a*to*ry</hw> <pr>(-?*t?*r?)</pr>, <pos>a.</pos> <ety>[L.
<ets>refrigeratorius</ets>.]</ety> <def>Mitigating heat;
cooling.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refrigeratory</ent><br/
<hw>Re*frig"er*a*to*ry</hw>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>-ries</plw> <pr>(-fr<?/z)</pr>.</plu> <ety>[CF. F.
<ets>r<eacute/frig<eacute/ratoire</ets>.]</ety> <def>That which
refrigerates or cools.</def> Specifically: <sd>(a)</sd> <def>In
distillation, a vessel filled with cold water, surrounding the worm, the
vapor in which is thereby condensed.</def> <sd>(b)</sd> <def>The
chamber, or tank, in which ice is formed, in an ice machine.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refrigerium</ent><br/
\'d8<hw>Ref`ri*ge"ri*um</hw> <pr>(r?f`r?*j?"r?*?m)</pr>, <pos>n.</pos>
<ety>[L.]</ety> <def>Cooling refreshment; refrigeration.</def>
<mark>[Obs.]</mark> <rj><au>South.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refringency</ent><br/
<hw>Re*frin"gen*cy</hw> <pr>(r?*fr?n"j<it>e</it>n*s?)</pr>,
<pos>n.</pos> <def>The power possessed by a substance to refract a ray;
<as>as, different substances have different
<ex>refringencies</ex></as>.</def> <rj><au>Nichol.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refringent</ent><br/
<hw>Re*frin"gent</hw> <pr>(-j<it>e</it>nt)</pr>, <pos>a.</pos> <ety>[L.
<ets>refringens</ets>, p. pr. of <ets>refringere</ets>. See
<er>Refract</er>.]</ety> <def>Pertaining to, or possessing, refringency;
refractive; refracting; <as>as, a <ex>refringent</ex> prism of
spar</as>.</def> <rj><au>Nichol.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reft</ent><br/
<hw>Reft</hw> <pr>(r?ft)</pr>, <pos>imp. & p. p.</pos> <mord>of
<er>Reave</er></mord>. <def>Bereft.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Reft</qex> of thy sons, amid thy foes forlorn.</q>
<rj><qau>Heber.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reft</ent><br/
<hw>Reft</hw>, <pos>n.</pos> <def>A chink; a rift. See
<er>Rift</er>.</def> <rj><au>Rom. of R.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refuge</ent><br/
<hw>Ref"uge</hw> <pr>(r?f"?j)</pr>, <pos>n.</pos> <ety>[F.
<ets>r<eacute/fuge</ets>, L. <ets>refugium</ets>, fr.
<ets>refugere</ets> to flee back; pref. <ets>re-</ets> +
<ets>figere</ets>. SEe <er>Fugitive</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Shelter or protection from danger or
distress.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Rocks, dens, and caves! But I in none of these<br/
Find place or <qex>refuge</qex>.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>We might have a strong consolation, who have fled for
<qex>refuge</qex> to lay hold upon the hope set before us.</q>
<rj><qau>Heb. vi. 18.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which shelters or protects from danger, or from
distress or calamity; a stronghold which protects by its strength, or a
sanctuary which secures safety by its sacredness; a place inaccessible
to an enemy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The high hills are a <qex>refuge</qex>r the wild goats.</q>
<rj><qau>Ps. civ. 18.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The Lord also will be a <qex>refuge</qex> for the oppressed.</q>
<rj><qau>Ps. ix. 9.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1209 --></p>

<p><sn>3.</sn> <def>An expedient to secure protection or defense; a
device or contrivance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Their latest <qex>refuge</qex><br/
Was to send him.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Light must be supplied, among graceful<qex>refuges</qex>, by
terracing <?/<?/<?/ story in danger of darkness.</q> <rj><qau>Sir H.
Wotton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Cities of refuge</b></col> <fld>(Jewish Antiq.)</fld>,
<cd>certain cities appointed as places of safe refuge for persons who
had committed homicide without design. Of these there were three on each
side of Jordan.</cd> <au>Josh. xx.</au> -- <col><b>House of
refuge</b></col>, <cd>a charitable institution for giving shelter and
protection to the homeless, destitute, or tempted.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Shelter; asylum; retreat; covert.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refuge</ent><br/
<hw>Ref"uge</hw> <pr>(r?f"?j)</pr>, <pos>v. t.</pos> <def>To shelter; to
protect.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refugee</ent><br/
<hw>Ref`u*gee"</hw> <pr>(r?f`?*j?")</pr>, <pos>n.</pos> <ety>[F.
<ets>r<eacute/fugi<eacute/</ets>, fr. <ets>se r<eacute/fugier</ets> to
take refuge. See <er>Refuge</er>, <pos>n.</pos>]</ety> <sn>1.</sn>
<def>One who flees to a shelter, or place of safety.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Especially, one who, in times of persecution or
political commotion, flees to a foreign power or country for safety;
<as>as, the French <ex>refugees</ex> who left France after the
revocation of the edict of Nantes</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refulgency</ent><br/
<ent>Refulgence</ent><br/
<mhw>{ <hw>Re*ful"gence</hw> <pr>(r?*f?l"j<it>e</it>ns)</pr>,
<hw>Re*ful"gen*cy</hw> <pr>(-j<it>e</it>n*s?)</pr>, }</mhw>
<pos>n.</pos> <ety>[L. <ets>refulgentia</ets>. See
<er>Refulgent</er>.]</ety> <def>The quality of being refulgent;
brilliancy; splender; radiance.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refulgent</ent><br/
<hw>Re*ful"gent</hw> <pr>(r?*f?l"j<eit/nt)</pr>, <pos>a.</pos> <ety>[L.
<ets>refulgens</ets>, p. pr. of <ets>refulgere</ets> to flash back, to
shine bright; pref. <ets>re-</ets> re- + <ets>fulgere</ets> to shine.
See <er>Fulgent</er>.]</ety> <def>Casting a bright light; radiant;
brilliant; resplendent; shining; splendid; <as>as, <ex>refulgent</ex>
beams</as>.</def> -- <wordforms><wf>Re*ful"gent*ly</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><q>So conspicuous and <qex>refulgent</qex> a truth.</q>
<rj><qau>Boyle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refund</ent><br/
<hw>Re*fund"</hw> <pr>(r?*f?nd")</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>re-</ets> + <ets>fund</ets>.]</ety> <def>To fund again or anew; to
replace (a fund or loan) by a new fund; <as>as, to <ex>refund</ex> a
railroad loan</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refund</ent><br/
<hw>Re*fund"</hw> <pr>(r?*f?nd")</pr>, <pos>v. t.</pos> <ety>[L.
<ets>refundere</ets>; pref. <ets>re-</ets> re- + <ets>fundere</ets> to
pour: cf. F. <ets>refondre</ets>, <ets>refonder</ets>. See <er>Fuse</er>
to melt, and cf. <er>Refound</er> to cast again, 1st
<er>Refuse</er>.]</ety> <sn>1.</sn> <def>To pour back.</def> <mark>[R. &
Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Were the humors of the eye tinctured with any color, they would
<qex>refund</qex> that color upon the object.</q>
<rj><qau>Ray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To give back; to repay; to restore.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A governor, that had pillaged the people, was . . . sentenced to
<qex>refund</qex> what he had wrongfully taken.</q>
<rj><qau>L'Estrange.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To supply again with funds; to reimburse.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refunder</ent><br/
<hw>Re*fund"er</hw> <pr>(-?r)</pr>, <pos>n.</pos> <def>One who
refunds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refundment</ent><br/
<hw>Re*fund"ment</hw> <pr>(-m<it>e</it>nt)</pr>, <pos>n.</pos> <def>The
act of refunding; also, that which is refunded.</def> <mark>[R.]</mark>
<rj><au>Lamb.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refurbish</ent><br/
<hw>Re*fur"bish</hw> <pr>(r?*f?r"b?sh)</pr>, <pos>v. t.</pos> <def>To
furbish anew.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refurnish</ent><br/
<hw>Re*fur"nish</hw> <pr>(-n?sh)</pr>, <pos>v. t.</pos> <def>To furnish
again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refurnishment</ent><br/
<hw>Re*fur"nish*ment</hw> <pr>(-m<it>e</it>nt)</pr>, <pos>n.</pos>
<def>The act of refurnishing, or state of being refurnished.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>refurnishment</qex> was in a style richer than
before.</q> <rj><qau>L. Wallace.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refusable</ent><br/
<hw>Re*fus"a*ble</hw> <pr>(r?*f?z"?*b'l)</pr>, <pos>a.</pos> <ety>[Cf.
F. <ets>refusable</ets>. See <er>Refuse</er>.]</ety> <def>Capable of
being refused; admitting of refusal.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refusal</ent><br/
<hw>Re*fus"al</hw> <pr>(-<it>a</it>l)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>The act of refusing; denial of anything demanded, solicited, or
offered for acceptance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Do they not seek occasion of new quarrels,<br/
On my <qex>refusal</qex>, to distress me more?</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The right of taking in preference to others; the
choice of taking or refusing; option; <as>as, to give one the
<ex>refusal</ex> of a farm; to have the <ex>refusal</ex> of an
employment</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refuse</ent><br/
<hw>Re*fuse"</hw> <pr>(r?*f?z")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Refused</conjf>
<pr>(-f?zd")</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Refusing</conjf>.]</vmorph> <ety>[F. <ets>refuser</ets>, either
from (assumed) LL. <ets>refusare</ets> to refuse, v. freq. of L.
<ets>refundere</ets> to pour back, give back, restore (see
<er>Refund</er> to repay), or. fr. L. <ets>recusare</ets> to decline,
refuse cf. <er>Accuse</er>, <er>Ruse</er>), influenced by L.
<ets>refutare</ets> to drive back, repel, refute. Cf.
<er>Refute</er>.]</ety> <sn>1.</sn> <def>To deny, as a request, demand,
invitation, or command; to decline to do or grant.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That never yet <qex>refused</qex> your hest.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mil.)</fld> <def>To throw back, or cause to keep
back (as the center, a wing, or a flank), out of the regular aligment
when troops ar<?/ about to engage the enemy; <as>as, to <ex>refuse</ex>
the right wing while the left wing attacks</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To decline to accept; to reject; to deny the request
or petition of; <as>as, to <ex>refuse</ex> a suitor</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The cunning workman never doth <qex>refuse</qex><br/
The meanest tool that he may chance to use.</q>
<rj><qau>Herbert.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To disown.</def> <mark>[Obs.]</mark>
<ldquo/<xex>Refuse</xex> thy name.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refuse</ent><br/
<hw>Re*fuse"</hw>, <pos>v. i.</pos> <def>To deny compliance; not to
comply.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Too proud to ask, too humble to <qex>refuse</qex>.</q>
<rj><qau>Garth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>If ye <qex>refuse</qex> . . . ye shall be devoured with the
sword.</q> <rj><qau>Isa. i. 20.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refuse</ent><br/
<hw>Re*fuse"</hw>, <pos>n.</pos> <def>Refusal.</def> <mark>[Obs.]</mark>
<rj><au>Fairfax.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refuse</ent><br/
<hw>Ref`use</hw> <pr>(r?f"?s;277)</pr>, <pos>n.</pos> <ety>[F.
<ets>refus</ets> refusal, also, that which is refused. See
<er>Refuse</er> to deny.]</ety> <def>That which is refused or rejected
as useless; waste or worthless matter.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Dregs; sediment; scum; recrement;
dross.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refuse</ent><br/
<hw>Ref"use</hw>, <pos>a.</pos> <def>Refused; rejected; hence; left as
unworthy of acceptance; of no value; worthless.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Everything that was vile and <qex>refuse</qex>, that they
destroyed utterly.</q> <rj><qau>1. Sam. xv. 9.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refuser</ent><br/
<hw>Re*fus"er</hw> <pr>(r?*f?z"?r)</pr>, <pos>n.</pos> <def>One who
refuses or rejects.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refusion</ent><br/
<hw>Re*fu"sion</hw> <pr>(r?*f?"zh?n)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>re-</ets> + <ets>fusion</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>New or repeated melting, as of metals.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Restoration.</def> <ldquo/This doctrine of the
<xex>refusion</xex> of the soul.<rdquo/ <rj><au>Bp.
Warbuton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refut</ent><br/
<hw>Ref"ut</hw> <pr>(r<ecr/f"<usdot/t)</pr>, <pos>n.</pos> <ety>[OF.
<ets>refuite</ets>.]</ety> <def>Refuge.</def> <ldquo/Thou haven of
<xex>refut</xex>.<rdquo/ <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refutability</ent><br/
<hw>Re*fut`a*bil"i*ty</hw> <pr>(r?*f?t`?*b?l"?*t?)</pr>, <pos>n.</pos>
<def>The quality of being refutable.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refutable</ent><br/
<hw>Re*fut"a*ble</hw> <pr>(r?*f?t"?*b'l;277)</pr>, <pos>a.</pos>
<ety>[Cf. F. <ets>r<eacute/futable</ets>.]</ety> <def>Admitting of being
refuted or disproved; capable of being proved false or
erroneous.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refutal</ent><br/
<hw>Re*fut"al</hw> <pr>(r?*f?t"<it>a</it>l)</pr>, <pos>n.</pos> <def>Act
of refuting; refutation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refutation</ent><br/
<hw>Ref`u*ta"tion</hw> <pr>(r?f`?*t?"sh?n)</pr>, <pos>n.</pos> <ety>[L.
<ets>refutatio</ets>: cf. F. <ets>r<eacute/futation</ets>.]</ety>
<def>The act or process of refuting or disproving, or the state of being
refuted; proof of falsehood or error; the overthrowing of an argument,
opinion, testimony, doctrine, or theory, by argument or countervailing
proof.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Same of his blunders seem rather to deserve a flogging than a
<qex>refutation</qex>.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refutatory</ent><br/
<hw>Re*fut"a*to*ry</hw> <pr>(r<esl/*f<umac/t"<adot/*t<osl/*r<ycr/)</pr>,
<pos>a.</pos> <ety>[L. <ets>refutatorius</ets>: cf. F.
<ets>r<eacute/futatoire</ets>.]</ety> <def>Tending to refute;
refuting.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>refute</ent><br/
<hw>re*fute"</hw> <pr>(r<esl/*f<umac/t")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Refuted</conjf>; <pos>p. pr. &
vb. n.</pos> <conjf>Refuting</conjf>.]</vmorph> <ety>[F.
<ets>r<eacute/futer</ets>, L. <ets>refuteare</ets> to repel, refute. Cf.
<er>Confute</er>, <er>Refuse</er> to deny.]</ety> <def>To disprove and
overthrow by argument, evidence, or countervailing proof; to prove to be
false or erroneous; to confute; <as>as, to <ex>refute</ex> arguments; to
<ex>refute</ex> testimony; to <ex>refute</ex> opinions or theories; to
<ex>refute</ex> a disputant.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>There were so many witnesses in these two miracles that it is
impossible to <qex>refute</qex> such multitudes.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To confute; disprove. See
<er>Confute</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Refuter</ent><br/
<hw>Re*fut"er</hw> <pr>(r<esl/*f<umac/t"<etil/r)</pr>, <pos>n.</pos>
<def>One who, or that which, refutes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regain</ent><br/
<hw>Re*gain"</hw> <pr>(r?*g?n")</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>re-</ets> + <ets>gain</ets>: cf. F. <ets>regagner</ets>.]</ety>
<def>To gain anew; to get again; to recover, as what has escaped or been
lost; to reach again.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To recover; reobtain; repossess;
retrieve.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regal</ent><br/
<hw>Re"gal</hw> <pr>(r<emac/"g<ait/l)</pr>, <pos>a.</pos> <ety>[L.
<ets>regalis</ets>, fr. <ets>rex</ets>, <ets>regis</ets>, a king. See
<er>Royal</er>, and cf. <er>Rajah</er>, <er>Realm</er>,
<er>Regalia</er>.]</ety> <def>Of or pertaining to a king; kingly; royal;
<as>as, <ex>regal</ex> authority, pomp, or sway</as>.</def> <ldquo/The
<xex>regal</xex> title.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He made a scorn of his <qex>regal</qex> oath.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Kingly; royal. See <er>Kingly</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regal</ent><br/
<hw>Re"gal</hw>, <pos>n.</pos> <ety>[F. <ets>r<eacute/gale</ets>, It.
<ets>regale</ets>. CF. <er>Rigoll</er>.]</ety> <fld>(Mus.)</fld> <def>A
small portable organ, played with one hand, the bellows being worked
with the other, -- used in the sixteenth and seventeenth
centuries.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regale</ent><br/
\'d8<hw>Re*ga"le</hw> <pr>(r<esl/*g<amac/"l<esl/)</pr>, <pos>n.</pos>
<ety>[LL. <ets>regale</ets>, pl. <ets>regalia</ets>, fr. L.
<ets>regalis</ets>: cf. F. <ets>r<eacute/gale</ets>. See
<er>Regal</er>.]</ety> <def>A prerogative of royalty.</def>
<mark>[R.]</mark> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regale</ent><br/
<hw>Re*gale"</hw> <pr>(r<esl/*g<amac/l")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Regaled</conjf>
<pr>(r<esl/*g<amac/ld")</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Regaling</conjf>.]</vmorph> <ety>[F. <ets>r<eacute/galer</ets>,
Sp. <ets>regalar</ets> to regale, to caress, to melt, perhaps fr. L.
<ets>regalare</ets> to thaw (cff. <er>Gelatin</er>), or cf. Sp.
<ets>gala</ets> graceful, pleasing address, choicest part of a thing
(cf. <er>Gala</er>), or most likely from OF. <ets>galer</ets> to
rejoice, <ets>gale</ets> pleasure.]</ety> <def>To entertain in a regal
or sumptuous manner; to entertain with something that delights; to
gratify; to refresh; <as>as, to <ex>regale</ex> the taste, the eye, or
the ear</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regale</ent><br/
<hw>Re*gale"</hw>, <pos>v. i.</pos> <def>To feast; to fare
sumtuously.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regale</ent><br/
<hw>Re*gale"</hw>, <pos>n.</pos> <ety>[F. <ets>r<eacute/gal</ets>. See
<er>Regale</er>, <pos>v. t.</pos>]</ety> <def>A sumptuous repast; a
banquet.</def> <rj><au>Johnson. Cowper.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Two baked custards were produced as additions to the
<qex>regale</qex>.</q> <rj><qau>E. E. Hale.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regalement</ent><br/
<hw>Re*gale"ment</hw> <pr>(r<esl/*g<amac/l"m<eit/nt)</pr>, <pos>n.</pos>
<def>The act of regaling; anything which regales; refreshment;
entertainment.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regaler</ent><br/
<hw>Re*gal"er</hw> <pr>(-g?l"?r)</pr>, <pos>n.</pos> <def>One who
regales.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regalia</ent><br/
<hw>Re*ga"li*a</hw> <pr>(r<esl/*g<amac/"l<icr/*<adot/)</pr>, <pos>n.
pl.</pos> <ety>[LL., from L. <ets>regalis</ets>regal. See
<er>Regal</er>.]</ety> <sn>1.</sn> <def>That which belongs to
royalty.</def> <specif>Specifically:</specif> <sd>(a)</sd> <def>The
rights and prerogatives of a king.</def> <sd>(b)</sd> <def>Royal estates
and revenues.</def> <sd>(c)</sd> <def>Ensigns, symbols, or paraphernalia
of royalty.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence, decorations or insignia of an office or
order, as of Freemasons, Odd Fellows,etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Sumptuous food; delicacies.</def>
<mark>[Obs.]</mark> <rj><au>Cotton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Regalia of a church</b></col>, <cd>the privileges granted
to it by kings; sometimes, its patrimony.</cd> <rj><au>Brande &
C.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regalia</ent><br/
<hw>Re*ga"li*a</hw>, <pos>n.</pos> <def>A kind of cigar of large size
and superior quality; also, the size in which such cigars are
classed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regalian</ent><br/
<hw>Re*ga"li*an</hw> <pr>(-<it>a</it>n)</pr>, <pos>a.</pos>
<def>Pertaining to regalia; pertaining to the royal insignia or
prerogatives.</def> <rj><au>Hallam.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regalism</ent><br/
<hw>Re"gal*ism</hw> <pr>(r?"g<it>a</it>l*?z'm)</pr>, <pos>n.</pos>
<def>The doctrine of royal prerogative or supremacy.</def>
<mark>[R.]</mark> <rj><au>Cardinal Manning.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regality</ent><br/
<hw>Re*gal"i*ty</hw> <pr>(r?*g?l"?*t?)</pr>, <pos>n.</pos> <ety>[LL.
<ets>regalitas</ets>, from L. <ets>regalis</ets> regal, royal. See
<er>Regal</er>, and cf. <er>Royality</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Royalty; sovereignty; sovereign
jurisdiction.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>[Passion] robs reason of her due <qex>regalitie</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He came partly in by the sword, and had high courage in all points
of <qex>regality</qex>.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An ensign or badge of royalty.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regally</ent><br/
<hw>Re"gal*ly</hw> <pr>(r?"g<it>a</it>l*l?)</pr>, <pos>adv.</pos>
<def>In a regal or royal manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regard</ent><br/
<hw>Re*gard"</hw> <pr>(r?*g?rd")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Regarded</conjf>; <pos>p. pr. &
vb. n.</pos> <conjf>Regarding</conjf>.]</vmorph> <ety>[F.
<ets>regarder</ets>; pref. <ets>re-</ets> re + <ets>garder</ets> to
guard, heed, keep. See <er>Guard</er>, and cf. <er>Reward</er>.]</ety>
<sn>1.</sn> <def>To keep in view; to behold; to look at; to view; to
gaze upon.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Your niece <qex>regards</qex> me with an eye of favor.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence, to look or front toward; to face.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>It is peninsula which <qex>regardeth</qex> the mainland.</q>
<rj><qau>Sandys.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>That exceedingly beatiful seat, on the ascent of a hill, flanked
with wood and <qex>regarding</qex> the river.</q>
<rj><qau>Evelyn.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To look closely at; to observe attentively; to pay
attention to; to notice or remark particularly.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If much you note him,<br/
You offened him; . . . feed, and <qex>regard</qex> him not.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To look upon, as in a certain relation; to hold as
an popinion; to consider; <as>as, to <ex>regard</ex> abstinence from
wine as a duty; to <ex>regard</ex> another as a friend or
enemy.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To consider and treat; to have a certain feeling
toward; <as>as, to <ex>regard</ex> one with favor or
dislike</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His associates seem to have <qex>regarded</qex> him with
kindness.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To pay respect to; to treat as something of peculiar
value, sanctity, or the like; to care for; to esteem.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He that <qex>regardeth</qex> thae day, <qex>regardeth</qex> it
into the LOrd.</q> <rj><qau>Rom. xiv. 6.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Here's Beaufort, that <qex>regards</qex> nor God nor king.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>To take into consideration; to take account of, as a
fact or condition.</def> <ldquo/Nether <xex>regarding</xex> that she is
my child, nor fearing me as if II were her father.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>To have relation to, as bearing upon; to respect; to
relate to; to touch; <as>as, an argument does not <ex>regard</ex> the
question</as>; -- often used impersonally; <as>as, I agree with you as
<ex>regards</ex> this or that</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To consider; observe; remark; heed; mind;
respect; esteem; estimate; value. See <er>Attend</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regard</ent><br/
<hw>Re*gard"</hw> <pr>(r?*g?rd")</pr>, <pos>v. i.</pos> <def>To look
attentively; to consider; to notice.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regard</ent><br/
<hw>Re*gard"</hw>, <pos>n.</pos> <ety>[F. <ets>regard</ets> See
<er>Regard</er>, <pos>v. t.</pos>]</ety> <sn>1.</sn> <def>A look; aspect
directed to another; view; gaze.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>But her, with stern <qex>regard</qex>, he thus repelled.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Attention of the mind with a feeling of interest;
observation; heed; notice.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Full many a lady<br/
I have eyed with best <qex>regard</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That view of the mind which springs from perception
of value, estimable qualities, or anything that excites admiration;
respect; esteem; reverence; affection; <as>as, to have a high
<ex>regard</ex> for a person</as>; -- often in the plural.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He has rendered himself worthy of their most favorable
<qex>regards</qex>.</q> <rj><qau>A. Smith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Save the long-sought <qex>regards</qex> of woman, nothing is
sweeter than those marks of childish preference.</q>
<rj><qau>Hawthorne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>State of being regarded, whether favorably or
otherwise; estimation; repute; note; account.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A man of meanest <qex>regard</qex> amongst them, neither having
wealth or power.</q> <rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Consideration; thought; reflection; heed.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Sad pause and deep <qex>regard</qex> become the sage.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Matter for consideration; account; condition.</def>
<mark>[Obs.]</mark> <ldquo/Reason full of good <xex>regard</xex>.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>Respect; relation; reference.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Persuade them to pursue and persevere in virtue, with
<qex>regard</qex> to themselves; in justice and goodness with
<qex>regard</qex> to their neighbors; and piefy toward God.</q>
<rj><qau>I. Watts.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The phrase <xex>in regard of</xex> was formerly used as
equivalent in meaning to <xex>on account of</xex>, but in modern usage
is often improperly substituted for <xex>in respect to</xex>, or <xex>in
regard to</xex>.</note> <rj><au>G. P. Marsh.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Change was thought necessary <qex>in regard of</qex> the injury
the church did receive by a number of things then in use.</q>
<rj><qau>Hooker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>In regard of</qex> its security, it had a great advantage
over the bandboxes.</q> <rj><qau>Dickens.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>Object of sight; scene; view; aspect.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Throw out our eyes for brave Othello,<br/
Even till we make the main and the aerial blue<br/
An indistinct <qex>regard</qex>.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <fld>(O.Eng.Law)</fld> <def>Supervision;
inspection.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>At regard of</b></col>, <cd>in consideration of; in
comparison with.</cd> <mark>[Obs.]</mark> <ldquo/Bodily penance is but
short and little <xex>at regard of</xex> the pains of hell.<rdquo/
<au>Chaucer.</au> -- <col><b>Court of regard</b></col>, <cd>a forest
court formerly held in England every third year for the lawing, or
expeditation, of dogs, to prevent them from running after deer; --
called also <altname>survey of dogs</altname>.</cd>
<au>Blackstone.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Respect; consideration; notice; observance; heed;
care; concern; estimation; esteem; attachment; reverence.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regardable</ent><br/
<hw>Re*gard"a*ble</hw> <pr>(-?*b'l)</pr>, <pos>a.</pos> <def>Worthy of
regard or notice; to be regarded; observable.</def> <mark>[R.]</mark>
<rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regardant</ent><br/
<hw>Re*gard"ant</hw> <pr>(-<it>a</it>nt)</pr>, <pos>a.</pos> <ety>[F.
<ets>regardant</ets>, fr. <ets>regarder</ets>. See <er>Regard</er>,
<pos>v. t.</pos>]</ety> <altsp>[Written also
<asp>regardant</asp>.]</altsp> <sn>1.</sn> <def>Looking behind; looking
backward watchfully.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>[He] turns thither his <qex>regardant</qex> eye.</q>
<rj><qau>Southey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Her.)</fld> <def>Looking behind or backward;
<as>as, a lion <ex>regardant</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(O.Eng.Law)</fld> <def>Annexed to the land or manor;
<as>as, a villain <ex>regardant</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regarder</ent><br/
<hw>Re*gard"er</hw> <pr>(r?*g?rd"?r)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>One who regards.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Eng. Forest law)</fld> <def>An officer appointed to
supervise the forest.</def> <rj><au>Cowell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regardful</ent><br/
<hw>Re*gard"ful</hw> <pr>(-f?l)</pr>, <pos>a.</pos> <def>Heedful;
attentive; observant.</def> -- <wordforms><wf>Re*gard"ful*ly</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><q>Let a man be very tender and <qex>regardful</qex> of every pious
motion made by the Spirit of God to his heart.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Mindful; heedful; attentive; observant.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regarding</ent><br/
<hw>Re*gard"ing</hw>, <pos>prep.</pos> <def>Concerning;
respecting.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regardless</ent><br/
<hw>Re*gard"less</hw>, <pos>a.</pos> <sn>1.</sn> <def>Having no regard;
heedless; careless; <as>as, <ex>regardless</ex> of life, consequences,
dignity</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Regardless</qex> of the bliss wherein he sat.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Not regarded; slighted.</def> <mark>[R.]</mark>
<rj><au>Spectator.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Heedless; negligent; careless; indifferent;
unconcerned; inattentive; unobservant; neglectful.</syn><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Re*gard"less*ly</wf>, <pos>adv.</pos> --
<wf>Re*gard"less*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regather</ent><br/
<hw>Re*gath"er</hw> <pr>(r?*g?th"?r)</pr>, <pos>v. t.</pos> <def>To
gather again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regatta</ent><br/
<hw>Re*gat"ta</hw> <pr>(r?*g?t"t?)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Regattas</plw> <pr>(-t<?/z)</pr>.</plu> <ety>[It.
<ets>regatta</ets>, <ets>regata</ets>.]</ety> <def>Originally, a gondola
race in Venice; now, a rowing or sailing race, or a series of such
races.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regel</ent><br/
<hw>Re"gel</hw> <pr>(r?"g?l)</pr>, <pos>n.</pos> <fld>(Astron.)</fld>
<def>See <er>Rigel</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regelate</ent><br/
<hw>Re"ge*late</hw> <pr>(r?"j?*l?t <or/ r?j"?-)</pr>, <pos>v. i.</pos>
<fld>(Physics)</fld> <def>To freeze together again; to undergo
regelation, as ice.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regelation</ent><br/
<hw>Re`ge*la"tion</hw> <pr>(-l?"sh?n)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>re-</ets> + L. <ets>gelatio</ets> a freezing.]</ety>
<fld>(Physics)</fld> <def>The act or process of freezing anew, or
together,as two pieces of ice.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Two pieces of ice at (or even) 32<?/ Fahrenheit, with
moist surfaces, placed in contact, freeze together to a rigid mass. This
is called <xex>regelation</xex>.</note> <rj><au>Faraday.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regence</ent><br/
<hw>Re"gence</hw> <pr>(r?"j<it>e</it>ns)</pr>, <pos>n.</pos>
<def>Rule.</def> <mark>[Obs.]</mark> <rj><au>Hudibras.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regency</ent><br/
<hw>Re"gen*cy</hw> <pr>(r?*j<it>e</it>n*s?)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Regencies</plw> <pr>(-s<?/z)</pr>.</plu>
<ety>[CF. F. <ets>r<eacute/gence</ets>, LL. <ets>regentia</ets>. See
<er>Regent</er>, <pos>a.</pos>]</ety> <sn>1.</sn> <def>The office of
ruler; rule; authority; government.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Especially, the office, jurisdiction, or dominion of
a regent or vicarious ruler, or of a body of regents; deputed or
vicarious government.</def> <rj><au>Sir W. Temple.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A body of men intrusted with vicarious government;
<as>as, a <ex>regency</ex> constituted during a king's minority, absence
from the kingdom, or other disability</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A council or <qex>regency</qex> consisting of twelve persons.</q>
<rj><qau>Lowth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regeneracy</ent><br/
<hw>Re*gen"er*a*cy</hw> <pr>(r?*j?n"?r*?*s?)</pr>, <pos>n.</pos>
<ety>[See <er>Regenerate</er>.]</ety> <def>The state of being
regenerated.</def> <rj><au>Hammond.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regenerate</ent><br/
<hw>Re*gen"er*ate</hw> <pr>(-?t)</pr>, <pos>a.</pos> <ety>[L.
<ets>regeneratus</ets>, p. p. of <ets>regenerare</ets> to regenerate;
pref. <ets>re-</ets> re- + <ets>generare</ets> to beget. See
<er>Generate</er>.]</ety> <sn>1.</sn> <def>Reproduced.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The earthly author of my blood,<br/
Whose youthful spirit, in me <qex>regenerate</qex>,<br/
Doth with a twofold vigor lift me up.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Theol.)</fld> <def>Born anew; become Christian;
renovated in heart; changed from a natural to a spiritual
state.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1210 --></p>

<p><ent>Regenerate</ent><br/
<hw>Re*gen"er*ate</hw> <pr>(r?*j?n"?r*?t)</pr>, <pos>v. t.</pos>
<sn>1.</sn> <def>To generate or produce anew; to reproduce; to give new
life, strength, or vigor to.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Through all the soil a genial fferment spreads.<br/
<qex>Regenerates</qex> the plauts, and new adorns the meads.</q>
<rj><qau>Blackmore.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Theol.)</fld> <def>To cause to be spiritually born
anew; to cause to become a Christian; to convert from sin to holiness;
to implant holy affections in the heart of.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Hence, to make a radical change for the better in
the character or condition of; <as>as, to <ex>regenerate</ex>
society</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regenerateness</ent><br/
<hw>Re*gen"er*ate*ness</hw> <pr>(-?t*n?s)</pr>, <pos>n.</pos> <def>The
quality or state of being rgenerate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regeneration</ent><br/
<hw>Re*gen`er*a"tion</hw> <pr>(-?"sh?n)</pr>, <pos>n.</pos> <ety>[L.
<ets>regeneratio</ets>: cf. F.
<ets>r<eacute/g<eacute/neration</ets>.]</ety> <sn>1.</sn> <def>The act
of regenerating, or the state of being regenerated.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Theol.)</fld> <def>The entering into a new
spiritual life; the act of becoming, or of being made, Christian; that
change by which holy affectations and purposes are substituted for the
opposite motives in the heart.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He saved us by the washing of <qex>regeneration</qex>, and
renewing of the Holy Chost.</q> <rj><qau>Tit. iii. 5.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Biol.)</fld> <def>The reproduction of a part which
has been removed or destroyed; re-formation; -- a process especially
characteristic of a many of the lower animals; <as>as, the
<ex>regeneration</ex> of lost feelers, limbs, and claws by spiders and
crabs</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Physiol.)</fld> <sd>(a)</sd> <def>The reproduction
or renewal of tissues, cells, etc., which have been used up and
destroyed by the ordinary processes of life; <as>as, the continual
<ex>regeneration</ex> of the epithelial cells of the body, or the
<ex>regeneration</ex> of the contractile substance of muscle</as>.</def>
<sd>(b)</sd> <def>The union of parts which have been severed, so that
they become anatomically perfect; <as>as, the <ex>regeneration</ex> of a
nerve</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regenerative</ent><br/
<hw>Re*gen"er*a*tive</hw> <pr>(r?*j?n"?r*?*t?v)</pr>, <pos>a.</pos>
<def>Of or pertaining to regeneration; tending to regenerate; <as>as,
<ex>regenerative</ex> influences</as>.</def> <rj><au>H.
Bushnell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Regenerative furnace</b></col> <fld>(Metal.)</fld>, <cd>a
furnace having a regenerator in which gas used for fuel, and air for
supporting combustion, are heated; a Siemens furnace.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regeneratively</ent><br/
<hw>Re*gen"er*a*tive*ly</hw>, <pos>adv.</pos> <def>So as to
regenerate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regenerator</ent><br/
<hw>Re*gen"er*a`tor</hw> <pr>(-?`t?r)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>One who, or that which, regenerates.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mech.)</fld> <def>A device used in connection with
hot-air engines, gas-burning furnaces, etc., in which the incoming air
or gas is heated by being brought into contact with masses of iron,
brick, etc., which have been previously heated by the outgoing, or
escaping, hot air or gas.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regeneratory</ent><br/
<hw>Re*gen"er*a*to*ry</hw> <pr>(-?*t?*r?)</pr>, <pos>a.</pos>
<def>Having power to renew; tending to reproduce; regenerating.</def>
<rj><au>G. S. Faber.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regenesis</ent><br/
<hw>Re*gen"e*sis</hw> <pr>(-?*s?s)</pr>, <pos>n.</pos> <def>New birth;
renewal.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A continued <qex>regenesis</qex> of dissenting sects.</q>
<rj><qau>H. Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regent</ent><br/
<hw>Re"gent</hw> <pr>(r?"j<it>e</it>nt)</pr>, <pos>a.</pos> <ety>[L.
<ets>regens</ets>, <ets>-entis</ets>, p. pr. of <ets>regere</ets> to
rule: cf. F. <ets>r<eacute/gent</ets>. See <er>Regiment</er>.]</ety>
<sn>1.</sn> <def>Ruling; governing; regnant.</def> <ldquo/Some other
active <xex>regent</xex> principle . . . which we call the soul.<rdquo/
<rj><au>Sir M. Hale.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Exercising vicarious authority.</def>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Queen regent</b></col>. <cd>See under <er>Queen</er>,
<pos>n.</pos></cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regent</ent><br/
<hw>Re"gent</hw>, <pos>n.</pos> <ety>[F. <ets>r<eacute/gent</ets>. See
<er>Regent</er>, <pos>a.</pos>]</ety> <sn>1.</sn> <def>One who rules or
reigns; a governor; a ruler.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Especially, one invested with vicarious authority;
one who governs a kingdom in the minority, absence, or disability of the
sovereign.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>One of a governing board; a trustee or overseer; a
superintendent; a curator; <as>as, the <ex>regents</ex> of the
Smithsonian Institution</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Eng.Univ.)</fld> <def>A resident master of arts of
less than five years' standing, or a doctor of less than twwo. They were
formerly privileged to lecture in the schools.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Regent bird</b></col> <fld>(Zool.)</fld>, <cd>a beautiful
Australian bower bird (<spn>Sericulus melinus</spn>). The male has the
head, neck, and large patches on the wings, bright golden yellow, and
the rest of the plumage deep velvety black; -- so called in honor of the
Prince of Wales (afterward George IV.), who was Prince Regent in the
reign of George III.</cd> -- <col><b>The Regents of the University of
the State of New York</b></col>, <cd>the members of a corporate body
called the University of New York. They have a certain supervisory power
over the incorporated institution for Academic and higher education in
the State.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regent diamond</ent><br/
<hw>Re"gent di"a*mond</hw>. <def>A famous diamond of fine quality, which
weighs about 137 carats and is among the state jewels of France. It is
so called from the Duke of Orleans, Regent of France, to whom it was
sold in 1717 by Pitt the English Governor of Madras (whence also called
the <altname>Pitt diamond</altname>), who bought it of an Indian
merchant in 1701.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Regentess</ent><br/
<hw>Re"gent*ess</hw>, <pos>n.</pos> <def>A female regent.</def>
<mark>[R.]</mark> <rj><au>Cotgrave.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regentship</ent><br/
<hw>Re"gent*ship</hw>, <pos>n.</pos> <def>The office of a regent;
regency.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regerminate</ent><br/
<hw>Re*ger"mi*nate</hw> <pr>(r?*j?r"m?*n?t)</pr>, <pos>v. i.</pos>
<ety>[Pref. <ets>re-</ets> + <ets>germinate</ets>: cf. L.
<ets>regerminare</ets>.]</ety> <def>To germinate again.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Perennial plants <qex>regerminate</qex> several years
successively.</q> <rj><qau>J. Lee.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regermination</ent><br/
<hw>Re*ger`mi*na"tion</hw> <pr>(-n?"sh?n)</pr>, <pos>n.</pos> <ety>[L.
<ets>regerminatio</ets>.]</ety> <def>A germinating again or
anew.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regest</ent><br/
<hw>Re*gest"</hw> <pr>(r?*j?st")</pr>, <pos>n.</pos> <ety>[L.
<ets>regesta</ets>, pl.: cf. OF. <ets>regestes</ets>, pl. See
<er>Register</er>.]</ety> <def>A register.</def> <mark>[Obs.]</mark>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reget</ent><br/
<hw>Re*get"</hw> <pr>(r?*g?t")</pr>, <pos>v. t.</pos> <def>To get
again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regian</ent><br/
<hw>Re"gi*an</hw> <pr>(r?"j?-<it>a</it>n)</pr>, <pos>n.</pos> <ety>[L.
<ets>regius</ets> regal.]</ety> <def>An upholder of kingly authority; a
royalist.</def> <mark>[Obs.]</mark> <rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regible</ent><br/
<hw>Reg"i*ble</hw> <pr>(r<ecr/j"<icr/*b'l)</pr>, <pos>a.</pos> <ety>[L.
<ets>regibilis</ets>, from <ets>regere</ets> to rule.]</ety>
<def>Governable; tractable.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regicidal</ent><br/
<hw>Reg"i*ci`dal</hw> <pr>(r<ecr/j"<icr/*s<imac/`d<ait/l)</pr>,
<pos>a.</pos> <def>Pertaining to regicide, or to one committing it;
having the nature of, or resembling, regicide.</def> <rj><au>Bp.
Warburton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regicide</ent><br/
<hw>Reg"i*cide</hw> <pr>(r<ecr/j"<icr/*s<imac/d)</pr>, <pos>n.</pos>
<ety>[F. <ets>r<eacute/gicide</ets>; L. <ets>rex</ets>,
<ets>regis</ets>, a king + <ets>caedere</ets> to kill. Cf.
<er>Homicide</er>.]</ety> <sn>1.</sn> <def>One who kills or who murders
a king; specifically <fld>(Eng. Hist.)</fld>, one of the judges who
condemned <person>Charles I.</person> to death.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The killing or the murder of a king.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regidor</ent><br/
\'d8<hw>Re`gi*dor"</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu>pl.
<plw>-dores</plw> <pr>(#)</pr></plu>. <ety>[Sp., fr. <ets>regir</ets> to
rule, L. <ets>regere</ets>.]</ety> <def>One of a body of officers
charged with the government of Spanish municipalities, corresponding to
the English alderman.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Regie</ent><br/
\'d8<hw>R<eacute/`gie"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<sn>1.</sn> <def>Direct management of public finance or public works by
agents of the government for government account; -- opposed to the
<contr><colf>contract system</colf></contr>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <specif>Specif.:</specif> <def>The system of collecting
taxes by officials who have either no interest or a very small interest
in the proceeds, as distinguished from the ancient system of farming
them out.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>3.</sn> <def>Any kind of government monopoly (tobacco, salt,
etc.) used chiefly as a means of taxation. Such monopolies are largely
employed in Austria, Italy, France, and Spain.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Regild</ent><br/
<hw>Re*gild"</hw> <pr>(r<emac/*g<icr/ld")</pr>, <pos>v. t.</pos> <def>To
gild anew.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regime</ent><br/
\'d8<hw>R<eacute/`gime"</hw> <pr>(r?`zh?m")</pr>, <pos>n.</pos> <ety>[F.
See <er>Regimen</er>.]</ety> <sn>1.</sn> <def>Mode or system of rule or
management; character of government, or of the prevailing social
system.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I dream . . . of the new <qex>r<eacute/gime</qex> which is to
come.</q> <rj><qau>H. Kingsley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Hydraul.)</fld> <def>The condition of a river with
respect to the rate of its flow, as measured by the volume of water
passing different cross sections in a given time, <xex>uniform
r<eacute/gime</xex> being the condition when the flow is equal and
uniform at all the cross sections.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>The ancient r<eacute/gime</b></col>, <it>or</it>
<col><b>Ancien r<eacute/gime</b></col></mcol> <ety>[F.]</ety>, <cd>the
former political and social system, as distinguished from the
<xex>modern</xex>; especially, the political and social system existing
in France before the Revolution of 1789.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regimen</ent><br/
<hw>Reg"i*men</hw> <pr>(r?j"?*m?n)</pr>, <pos>n.</pos> <ety>[L.
<ets>regimen</ets>, <ets>-inis</ets>, fr. <ets>regere</ets> to guide, to
rule. See <er>Right</er>, and cf. <er>Regal</er>,
<er>R<eacute/gime</er>, <er>Regiment</er>.]</ety> <sn>1.</sn>
<def>Orderly government; system of order; adminisration.</def>
<rj><au>Hallam.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Any regulation or remedy which is intended to
produce beneficial effects by gradual operation</def>; esp.
<fld>(Med.)</fld>, <def>a systematic course of diet, etc., pursed with a
view to improving or preserving the health, or for the purpose of
attaining some particular effect, as a reduction of flesh; -- sometimes
used synonymously with <altname>hygiene</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Gram.)</fld> <sd>(a)</sd> <def>A syntactical
relation between words, as when one depends on another and is regulated
by it in respect to case or mood; government.</def> <sd>(b)</sd>
<def>The word or words governed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regiment</ent><br/
<hw>Reg"i*ment</hw> <pr>(-m<it>e</it>nt)</pr>, <pos>n.</pos> <ety>[F.
<ets>r<eacute/giment</ets> a regiment of men, OF. also government, L.
<ets>regimentum</ets> government, fr. <ets>regere</ets> to guide, rule.
See <er>Regimen</er>.]</ety> <sn>1.</sn> <def>Government; mode of
ruling; rule; authority; regimen.</def> <mark>[Obs.]</mark>
<au>Spenser.</au> <ldquo/<xex>Regiment</xex> of health.<rdquo/
<au>Bacon.</au><br/
[<source>1913 Webster</source>]</p>

<p><q>But what are kings, when <qex>regiment</qex> is gone,<br/
But perfect shadows in a sunshine day?</q>
<rj><qau>Marlowe.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The law of nature doth now require of necessity some kind of
<qex>regiment</qex>.</q> <rj><qau>Hocker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A region or district governed.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Mil.)</fld> <def>A body of men, either horse, foot,
or artillery, commanded by a colonel, and consisting of a number of
companies, usually ten.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In the British army all the artillery are included in
one regiment, which (reversing the usual practice) is divided into
brigades.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Regiment of the line</b></col> <fld>(Mil.)</fld>, <cd>a
regiment organized for general service; -- in distinction from those (as
the Life Guards) whose duties are usually special.</cd>
<mark>[Eng.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regiment</ent><br/
<hw>Reg"i*ment</hw> <pr>(-m<eit/nt)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Regimented</conjf>; <pos>p. pr.
& vb. n.</pos> <conjf>Regimenting</conjf>.]</vmorph> <sn>1.</sn> <def>To
form into a regiment or into regiments.</def>
<rj><au>Washington.</au></rj><br/
[<source>1913 Webster</source>]<br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>To form into classified units or bodies; to
systematize according to classes, districts or the like.</def></p>

<p><q>The people are organized or <qex>regimented</qex> into bodies, and
special functions are relegated to the several units.</q> <rj><qau>J. W.
Powell.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>3.</sn> <def>To organize and manage in a uniform and rigid
manner; to control with a strict discipline.</def><br/
[<source>PJC</source>]</p>

<p><ent>Regimental</ent><br/
<hw>Reg`i*men"tal</hw> <pr>(-m<ecr/n"t<ait/l)</pr>, <pos>a.</pos>
<def>Belonging to, or concerning, a regiment; <as>as,
<ex>regimental</ex> officers, clothing</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Regimental school</b></col>, <cd>in the British army, a
school for the instruction of the private soldiers of a regiment, and
their children, in the rudimentary branches of education.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regimentally</ent><br/
<hw>Reg`i*men"tal*ly</hw>, <pos>adv.</pos> <def>In or by a regiment or
regiments; <as>as, troops classified
<ex>regimentally</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regimentals</ent><br/
<hw>Reg`i*men"tals</hw> <pr>(-t<it>a</it>lz)</pr>, <pos>n. pl.</pos>
<fld>(Mil.)</fld> <def>The uniform worn by the officers and soldiers of
a regiment; military dress; -- formerly used in the singular in the same
sense.</def> <rj><au>Colman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regiminal</ent><br/
<hw>Re*gim"i*nal</hw> <pr>(r?*j?m"?*n<it>a</it>l)</pr>, <pos>a.</pos>
<def>Of or relating to regimen; <as>as, <ex>regiminal</ex>
rules</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Region</ent><br/
<hw>Re"gion</hw> <pr>(r?"j?n)</pr>, <pos>n.</pos> <ety>[F.
<ets>r<eacute/gion</ets>, from L. <ets>regio</ets> a direction, a
boundary line, region, fr. <ets>regere</ets> to guide, direct. See
<er>Regimen</er>.]</ety> <sn>1.</sn> <def>One of the grand districts or
quarters into which any space or surface, as of the earth or the
heavens, is conceived of as divided; hence, in general, a portion of
space or territory of indefinite extent; country; province; district;
tract.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If thence he 'scappe, into whatever world,<br/
Or unknown <qex>region</qex>.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Tract, part, or space, lying about and including
anything; neighborhood; vicinity; sphere.</def> <ldquo/Though the fork
invade the <xex>region</xex> of my heart.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Philip, tetrarch of .. the <qex>region</qex> of Trachonitis.</q>
<rj><qau>Luke iii. 1.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The upper air; the sky; the heavens.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Anon the dreadful thunder<br/
Doth rend the <qex>region</qex>.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The inhabitants of a district.</def> <rj><au>Matt.
iii. 5. </au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Place; rank; station.</def> <mark>[Obs. or
R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He is of too high a <qex>region</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regional</ent><br/
<hw>Re"gion*al</hw> <pr>(-<it>a</it>l)</pr>, <pos>a.</pos> <def>Of or
pertaining to a particular region; sectional.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regious</ent><br/
<hw>Re"gi*ous</hw> <pr>(-j?*?s)</pr>, <pos>a.</pos> <ety>[L.
<ets>regius</ets> royal, fr. <ets>rex</ets>, <ets>regis</ets>,
king.]</ety> <def>Regal; royal.</def> <mark>[Obs.]</mark>
<rj><au>Harrington.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Register</ent><br/
<hw>Reg"is*ter</hw> <pr>(r?j"?s*t?r)</pr>, <pos>n.</pos> <ety>[OE.
<ets>registre</ets>, F. <ets>registre</ets>, LL.
<ets>registrum</ets>,<ets>regestum</ets>, L. <ets>regesta</ets>, pl.,
fr. <ets>regerere</ets>, <ets>regestum</ets>, to carry back, to
register; pref. <ets>re-</ets> re- + <ets>gerere</ets> to carry. See
<er>Jest</er>, and cf. <er>Regest</er>.]</ety> <sn>1.</sn> <def>A
written account or entry; an official or formal enumeration,
description, or record; a memorial record; a list or roll; a
schedule.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>As you have one eye upon my follies, . . . turn another into the
<qex>register</qex> of your own.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Com.)</fld> <sd>(a)</sd> <def>A record containing a
list and description of the merchant vessels belonging to a port or
customs district.</def> <sd>(b)</sd> <def>A certificate issued by the
collector of customs of a port or district to the owner of a vessel,
containing the description of a vessel, its name, ownership, and other
material facts. It is kept on board the vessel, to be used as an
evidence of nationality or as a muniment of title.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <ety>[Cf. LL. <ets>registrarius</ets>. Cf.
<er>Regisrar</er>.]</ety> <def>One who registers or records; a
registrar; a recorder; especially, a public officer charged with the
duty of recording certain transactions or events; <as>as, a
<ex>register</ex> of deeds</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>That which registers or records.</def> Specifically:
<sd>(a)</sd> <fld>(Mech.)</fld> <def>A contrivance for automatically
noting the performance of a machine or the rapidity of a process.</def>
<sd>(b)</sd> <fld>(Teleg.)</fld> <def>The part of a telegraphic
apparatus which records automatically the message received.</def>
<sd>(c)</sd> <def>A machine for registering automatically the number of
persons passing through a gateway, fares taken, etc.; a
telltale.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A lid, stopper, or sliding plate, in a furnace,
stove, etc., for regulating the admission of air to the fuel; also, an
arrangement containing dampers or shutters, as in the floor or wall of a
room or passage, or in a chimney, for admitting or excluding heated air,
or for regulating ventilation.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Print.)</fld> <sd>(a)</sd> <def>The inner part of
the mold in which types are cast.</def> <sd>(b)</sd> <def>The
correspondence of pages, columns, or lines on the opposite or reverse
sides of the sheet.</def> <sd>(c)</sd> <def>The correspondence or
adjustment of the several impressions in a design which is printed in
parts, as in chromolithographic printing, or in the manufacture of paper
hangings. See <er>Register</er>, <pos>v. i.</pos> 2.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Mus.)</fld> <sd>(a)</sd> <def>The compass of a
voice or instrument; a specified portion of the compass of a voice, or a
series of vocal tones of a given compass; <as>as, the upper, middle, or
lower <ex>register</ex>; the soprano <ex>register</ex>; the tenor
<ex>register</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In respect to the vocal tones, the <xex>thick
register</xex> properly extends below from the F on the lower space of
the treble staff. The <xex>thin register</xex> extends an octave above
this. The <xex>small register</xex> is above the thin. The voice in the
thick register is called the <xex>chest voice</xex>; in the thin, the
<xex>head voice</xex>. <xex>Falsetto</xex> is a kind off voice, of a
thin, shrull quality, made by using the mechanism of the upper thin
register for tones below the proper limit on the scale.</note>
<rj><au>E. Behnke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(b)</sd> <def>A stop or set of pipes in an organ.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Parish register</b></col>, <cd>A book in which are
recorded the births, baptisms, marriages, deaths, and burials in a
parish.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- List; catalogue; roll; record; archives;
chronicle; annals. See <er>List</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Register</ent><br/
<hw>Reg"is*ter</hw> <pr>(r<ecr/j"<icr/s*t<etil/r)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Registere</conjf>
<pr>(-t?rd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Registering</conjf>.]</vmorph> <ety>[Cf. F. <ets>regisrer</ets>,
<ets>exregistrer</ets>, LL. <ets>registrare</ets>. See
<er>Register</er>, <pos>n.</pos>]</ety> <sn>1.</sn> <def>To enter in a
register; to record formally and distinctly, as for future use or
service.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To enroll; to enter in a list.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Such follow him as shall be <qex>registered</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Securities)</fld> <def>To enter the name of the
owner of (a share of stock, a bond, or other security) in a register, or
record book. A registered security is transferable only on the written
assignment of the owner of record and on surrender of his bond, stock
certificate, or the like.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><cs><col><b>Registered letter</b></col>, <cd>a letter, the address of
which is, on payment of a special fee, registered in the post office and
the transmission and delivery of which are attended to with particular
care.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Register</ent><br/
<hw>Reg"is*ter</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To enroll one's
name in a register.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Print.)</fld> <def>To correspond in relative
position; <as>as, two pages, columns, etc.</as> , <xex>register</xex>
when the corresponding parts fall in the same line, or when line falls
exactly upon line in reverse pages, or (as in chromatic printing) where
the various colors of the design are printed consecutively, and perfect
adjustment of parts is necessary.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Registering</ent><br/
<hw>Reg"is*ter*ing</hw>, <pos>a.</pos> <def>Recording; -- applied to
instruments; having an apparatus which registers; <as>as, a
<ex>registering</ex> thermometer</as>. See <er>Recording</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Registership</ent><br/
<hw>Reg"is*ter*ship</hw>, <pos>n.</pos> <def>The office of a
register.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Registrant</ent><br/
<hw>Reg"is*trant</hw> <pr>(-tr<it>a</it>nt)</pr>, <pos>n.</pos> <ety>[L.
<ets>registrans</ets>, p. pr.]</ety> <def>One who registers; esp., one
who , by virtue of securing an official registration, obtains a certain
right or title of possession, as to a trade-mark.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Registrar</ent><br/
<hw>Reg"is*trar</hw> <pr>(-tr?r)</pr>, <pos>n.</pos> <ety>[LL.
<ets>registrarius</ets>, or F. <ets>r<eacute/gistraire</ets>. See
<er>Register</er>.]</ety> <def>One who registers; a recorder; a keeper
of records; <as>as, a <ex>registrar</ex> of births, deaths, and
marriages</as>. See <er>Register</er>, <pos>n.</pos>, 3.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Registrarship</ent><br/
<hw>Reg"is*trar*ship</hw>, <pos>n.</pos> <def>The office of a
registrar.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Registrary</ent><br/
<hw>Reg"is*tra*ry</hw> <pr>(- tr?*r?)</pr>, <pos>n.</pos> <def>A
registrar.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Registrate</ent><br/
<hw>Reg"is*trate</hw> <pr>(-tr?t)</pr>, <pos>v. t.</pos> <def>To
register.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Registration</ent><br/
<hw>Reg`is*tra"tion</hw> <pr>(-tr?"sh?n)</pr>, <pos>n.</pos> <ety>[LL.
<ets>registratio</ets>, or F. <ets>r<eacute/gistration</ets>. See
<er>Register</er>, <pos>v.</pos>]</ety> <sn>1.</sn> <def>The act of
registering; registry; enrollment.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mus.)</fld> <def>The art of selecting and combining
the stops or registers of an organ.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Registry</ent><br/
<hw>Reg"is*try</hw> <pr>(r?j"?s*tr?)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>The act of recording or writing in a register; enrollment;
registration.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The place where a register is kept.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A record; an account; a register.</def> <rj><au>Sir
W. Temple.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regius</ent><br/
\'d8<hw>Re"gi*us</hw> <pr>(r?l"?*?s)</pr>, <pos>a.</pos> <ety>[L.
<ets>regius</ets>, from <ets>rex</ets>, <ets>regis</ets>, a king.]</ety>
<def>Of or pertaining to a king; royal.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Regius professor</b></col>, <cd>an incumbent of a
professorship founded by royal bounty, as in an English
university.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regive</ent><br/
<hw>Re*give"</hw> <pr>(r?*g?v")</pr>, <pos>v. t.</pos> <def>To give
again; to give back.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regle</ent><br/
<hw>Re"gle</hw> <pr>(r?g"'l)</pr>, <pos>v. t.</pos> <ety>[See
<er>Reglement</er>.]</ety> <def>To rule; to govern.</def>
<mark>[Obs.]</mark> <ldquo/To <xex>regle</xex> their lives.<rdquo/
<rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reglement</ent><br/
<hw>Re"gle*ment</hw> <pr>(r?g"'l*m<it>e</it>nt)</pr>, <pos>n.</pos>
<ety>[F. <ets>r<eacute/glement</ets>, fr. <ets>r<eacute/gler</ets>, L.
<ets>regulare</ets>. See <er>Regulate</er>.]</ety>
<def>Regulation.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The reformation and <qex>reglement</qex> of usury.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reglementary</ent><br/
<hw>Reg`le*men"ta*ry</hw> <pr>(-l?*m?n"t?*r?)</pr>, <pos>a.</pos>
<ety>[F. <ets>r<eacute/glementaire</ets>, fr.
<ets>r<eacute/glement</ets>.]</ety> <def>Regulative.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reglet</ent><br/
<hw>Reg"let</hw> <pr>(r?g"l?t)</pr>, <pos>n.</pos> <ety>[F.
<ets>r<eacute/glet</ets>, dim. of <ets>r<egrave/gle</ets> a rule, L.
<ets>regula</ets>. See <er>Rule</er>.]</ety> <sn>1.</sn>
<fld>(Arch.)</fld> <def>A flat, narrow molding, used chiefly to separate
the parts or members of compartments or panels from one another, or
doubled, turned, and interlaced so as to form knots, frets, or other
ornaments. See <er>Illust</er>. (12) of <er>Column</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Print.)</fld> <def>A strip of wood or metal of the
height of a quadrat, used for regulating the space between pages in a
chase, and also for spacing out title-pages and other open matter. It is
graded to different sizes, and designated by the name of the type that
it matches; <as>as, nonpareil <ex>reglet</ex>, pica <ex>reglet</ex>, and
the like</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regma</ent><br/
\'d8<hw>Reg"ma</hw> <pr>(r?g"m?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<?/<?/<?/<?/, -<?/<?/<?/, fracture, fr. <?/<?/<?/<?/<?/<?/ to
break.]</ety> <fld>(Bot.)</fld> <def>A kind of dry fruit, consisting of
three or more cells, each which at length breaks open at the inner
angle.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regmacarp</ent><br/
<hw>Reg"ma*carp</hw> <pr>(-k?rp)</pr>, <pos>n.</pos>
<ety>[<ets>Regma</ets> + Gr. <?/<?/<?/ fruit.]</ety> <fld>(Bot.)</fld>
<def>Any dry dehiscent fruit.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regnal</ent><br/
<hw>Reg"nal</hw> <pr>(r?g"n<it>a</it>l)</pr>, <pos>a.</pos> <ety>[L.
<ets>regnum</ets> reign.]</ety> <def>Of or pertaining to the reign of a
monarch; <as>as, <ex>regnal</ex> years</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regnancy</ent><br/
<hw>Reg"nan*cy</hw> <pr>(-n<it>a</it>n*s?)</pr>, <pos>n.</pos> <def>The
condition or quality of being regnant; sovereignty; rule.</def>
<rj><au>Coleridge.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regnant</ent><br/
<hw>Reg"nant</hw> <pr>(-n<it>a</it>nt)</pr>, <pos>a.</pos> <ety>[L.
<ets>regnans</ets>, <ets>-antis</ets>, p. pr. of <ets>regnare</ets> to
reign: cf. F <ets>r<eacute/gnant</ets>. See <er>Reign</er>.]</ety>
<sn>1.</sn> <def>Exercising regal authority; reigning; <as>as, a queen
<ex>regnant</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Having the chief power; ruling; predominant;
prevalent.</def> <ldquo/A traitor to the vices
<xex>regnant</xex>.<rdquo/ <rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regnative</ent><br/
<hw>Reg"na*tive</hw> <pr>(-n?*t?v)</pr>, <pos>a.</pos> <def>Ruling;
governing.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regne</ent><br/
<hw>Regne</hw> <pr>(r?n)</pr>, <pos>n. & v.</pos> <def>See
<er>Reign</er>.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regorge</ent><br/
<hw>Re*gorge"</hw> <pr>(r?*g?rj")</pr>, <pos>v. t.</pos> <ety>[F.
<ets>regorder</ets>; <ets>re-</ets> + <ets>gorger</ets> to gorge. Cf.
<er>Regurgitate</er>.]</ety> <sn>1.</sn> <def>To vomit up; to eject from
the stomach; to throw back.</def> <rj><au>Hayward.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To swallow again; to swallow back.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Tides at highest mark <qex>regorge</qex> the flood.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1211 --></p>

<p><ent>Regrade</ent><br/
<hw>Re*grade"</hw> <pr>(r?*gr?d")</pr>, <pos>v. i.</pos> <ety>[L.
<ets>re-</ets> re- + <ets>gradi</ets> to go. Cf. <er>Regrede</er>.
]</ety> <def>To retire; to go back.</def> <mark>[Obs.]</mark> <rj><au>W.
Hales.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regraft</ent><br/
<hw>Re*graft"</hw> <pr>(r?*gr?ft")</pr>, <pos>v. t.</pos> <def>To graft
again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regrant</ent><br/
<hw>Re*grant"</hw> <pr>(r?*gr?nt")</pr>, <pos>v. t.</pos> <def>To grant
back; to grant again or anew.</def> <rj><au>Ayliffe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regrant</ent><br/
<hw>Re*grant"</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act of granting
back to a former proprietor.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A renewed of a grant; <as>as, the <ex>regrant</ex>
of a monopoly</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regrate</ent><br/
<hw>Re*grate"</hw> <pr>(r?*gr?t")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Regrated</conjf>; <pos>p. pr. &
vb. n.</pos> <conjf>Regrating</conjf>.]</vmorph> <ety>[F.
<ets>regratter</ets>, literally, to scrape again. See <er>Re</er>-, and
<er>Grate</er>, <pos>v. t.</pos>]</ety> <sn>1.</sn> <fld>(Masonry)</fld>
<def>To remove the outer surface of, as of an old hewn stone, so as to
give it a fresh appearance.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To offend; to shock.</def> <mark>[Obs.]</mark>
<rj><au>Derham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regrate</ent><br/
<hw>Re*grate"</hw>, <pos>v. t.</pos> <ety>[F. <ets>regratter</ets> to
regrate provisions; of uncertain origin.]</ety> <fld>(Eng.Law)</fld>
<def>To buy in large quantities, as corn, provisions, etc., at a market
or fair, with the intention of selling the same again, in or near the
same place, at a higher price, -- a practice which was formerly treated
as a public offense.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regrater</ent><br/
<hw>Re*grat"er</hw> <pr>(-?r)</pr>, <pos>n.</pos> <ety>[F.
<ets>regrattier</ets>.]</ety> <def>One who regrates.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regratery</ent><br/
<hw>Re*grat"er*y</hw>, <pos>n.</pos> <def>The act or practice of
regrating.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regratiatory</ent><br/
<hw>Re*gra"ti*a*to*ry</hw> <pr>(r?*gr?"sh?*?*t?*r?)</pr>, <pos>n.</pos>
<def>A returning or giving of thanks.</def> <mark>[Obs.]</mark>
<rj><au>Skelton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regrator</ent><br/
<hw>Re*grat"or</hw> <pr>(r?*gr?t"?r)</pr>, <pos>n.</pos> <def>One guilty
of regrating.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regrede</ent><br/
<hw>Re*grede"</hw> <pr>(r?*gr?d")</pr>, <pos>v. i.</pos> <ety>[L.
<ets>regredi</ets> to go back. Cf. <er>Regrade</er>,
<er>Regress</er>.]</ety> <def>To go back; to retrograde, as the apsis of
a planet's orbit.</def> <mark>[R.]</mark>
<rj><au>Todhunter.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regredience</ent><br/
<hw>Re*gre"di*ence</hw> <pr>(r?*gr?"d?-<it>e</it>ns)</pr>, <pos>n.</pos>
<def>A going back; a retrogression; a return.</def> <mark>[R.]</mark>
<rj><au>Herrick.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regreet</ent><br/
<hw>Re*greet"</hw> <pr>(r?*gr?t")</pr>, <pos>v. t.</pos> <def>To greet
again; to resalute; to return a salutation to; to greet.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regreet</ent><br/
<hw>Re*greet"</hw>, <pos>n.</pos> <def>A return or exchange of
salutation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regress</ent><br/
<hw>Re"gress</hw> <pr>(r?"gr?s)</pr>, <pos>n.</pos> <ety>[L.
<ets>regressus</ets>, fr. <ets>regredi</ets>, <ets>regressus</ets>. See
<er>Regrede</er>.]</ety> <sn>1.</sn> <def>The act of passing back;
passage back; return; retrogression. <ldquo/The progress or
<xex>regress</xex> of man<rdquo/.</def> <rj><au>F.
Harrison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The power or liberty of passing back.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regress</ent><br/
<hw>Re*gress"</hw> <pr>(r?*gr?s")</pr>, <pos>v. i.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Regressed</conjf>
<pr>(-gr?st")</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Regressing</conjf>.]</vmorph> <def>To go back; to return to a
former place or state.</def> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regression</ent><br/
<hw>Re*gres"sion</hw> <pr>(r?*gr?sh"?n)</pr>, <pos>n.</pos> <ety>[L.
<ets>regressio</ets>: cf. F. <ets>r<eacute/gression</ets>.]</ety>
<def>The act of passing back or returning; retrogression;
retrogradation.</def> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Edge of regression</b></col> (of a surface)
<fld>(Geom.)</fld>, <cd>the line along which a surface turns back upon
itself; -- called also a <altname>cuspidal edge</altname>.</cd> --
<col><b>Regression point</b></col> <fld>(Geom.)</fld>, <cd>a
cusp.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regressive</ent><br/
<hw>Re*gress"ive</hw> <pr>(r?*gr?s"?v)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>r<eacute/gressif</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Passing back; returning.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Characterized by retrogression;
retrogressive.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Regressive metamorphism</b></col>. <sd>(a)</sd>
<fld>(Biol.)</fld> <cd>See <er>Retrogression</er>.</cd> <sd>(b)</sd>
<fld>(Physiol.)</fld> <cd>See <er>Katabolism</er></cd>.</cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regressively</ent><br/
<hw>Re*gress"ive*ly</hw>, <pos>adv.</pos> <def>In a regressive
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regret</ent><br/
<hw>Re*gret"</hw> <pr>(r?*gr?t")</pr>, <pos>n.</pos> <ety>[F., fr.
<ets>regretter</ets>. See <er>Regret</er>, <pos>v.</pos>]</ety>
<sn>1.</sn> <def>Pain of mind on account of something done or
experienced in the past, with a wish that it had been different; a
looking back with dissatisfaction or with longing; grief; sorrow;
especially, a mourning on account of the loss of some joy, advantage, or
satisfaction.</def> <ldquo/A passionate <xex>regret</xex> at sin.<rdquo/
<rj><au>Dr. H. More.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>What man does not remember with <qex>regret</qex> the first time
he read Robinson Crusoe?</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Never any prince expressed a more lively <qex>regret</qex> for the
loss of a servant.</q> <rj><au>Clarendon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>From its peaceful bosom [the grave] spring none but fond
<qex>regrets</qex> and tender recollections.</q> <rj><qau>W.
Irving.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Dislike; aversion.</def> <mark>[Obs.]</mark>
<rj><au>Dr. H. More.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Grief; concern; sorrow; lamentation; repentance;
penitence; self-condemnation.</syn> <usage> -- <er>Regret</er>,
<er>Remorse</er>, <er>Compunction</er>, <er>Contrition</er>,
<er>Repentance</er>. <xex>Regret</xex> does not carry with it the energy
of <xex>remorse</xex>, the sting of <xex>compunction</xex>, the
sacredness of <xex>contrition</xex>, or the practical character of
<xex>repentance</xex>. We even apply the term <xex>regret</xex> to
circumstance over which we have had no control, as the absence of
friends or their loss. When connected with ourselves, it relates rather
to unwise acts than to wrong or sinful ones.</usage> <rj><au>C. J.
Smith.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regret</ent><br/
<hw>Re*gret"</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Regretted</conjf> <pr>(-t<ecr/d)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Regretting</conjf>.]</vmorph> <ety>[F. <ets>regretter</ets>, OF.
<ets>regreter</ets>; L. pref. <ets>re-</ets> re- + a word of Teutonic
origin; cf. Goth. <ets>gr<emac/tan</ets> to weep, Icel.
<ets>gr<amac/ta</ets>. See <er>Greet</er> to lament.]</ety> <def>To
experience regret on account of; to lose or miss with a sense of regret;
to feel sorrow or dissatisfaction on account of (the happening or the
loss of something); <as>as, to <ex>regret</ex> an error; to
<ex>regret</ex> lost opportunities or friends.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Calmly he looked on either life, and here<br/
Saw nothing to <qex>regret</qex>, or there to fear.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>In a few hours they [the Israelites] began to <qex>regret</qex>
their slavery, and to murmur against their leader.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Recruits who <qex>regretted</qex> the plow from which they had
been violently taken.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regretful</ent><br/
<hw>Re*gret"ful</hw> <pr>(-f?l)</pr>, <pos>a.</pos> <def>Full of regret;
indulging in regrets; repining.</def> --
<wordforms><wf>Re*gret"ful*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>regroup</ent><br/
<ent>re-group</ent><br/
<mhw><hw>regroup</hw>, <hw>re-group</hw></mhw> <pos>v. i. & t.</pos>
<def>To reorganize into new groups; to reform a group that has been
dispersed. The spelling without the hyphen is more common.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Regrow</ent><br/
<hw>Re*grow"</hw> <pr>(r?*gr?")</pr>, <pos>v. i. & t.</pos> <def>To grow
again.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The snail had power to <qex>regrow</qex> them all [horns, tongue,
etc.]</q> <rj><qau>A. B. Buckley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regrowth</ent><br/
<hw>Re*growth"</hw> <pr>(r?*gr?th")</pr>, <pos>n.</pos> <def>The act of
regrowing; a second or new growth.</def> <rj><au>Darwin.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>regrowth</qex> of limbs which had been cut off.</q>
<rj><qau>A. B. Buckley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reguardant</ent><br/
<hw>Re*guard"ant</hw> <pr>(r?*g?rd"<it>a</it>nt)</pr>, <pos>a.</pos>
<fld>(Her.)</fld> <def>Same as <er>Regardant</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reguerdon</ent><br/
<hw>Re*guer"don</hw> <pr>(r?*g?r"d?n)</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>re-</ets> re- + <ets>guerdon</ets>: cf. OF.
<ets>reguerdonner</ets>.]</ety> <def>To reward.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regulable</ent><br/
<hw>Reg"u*la*ble</hw> <pr>(r?g"?*l?*b'l)</pr>, <pos>a.</pos>
<def>Capable of being regulated.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regular</ent><br/
<hw>Reg"u*lar</hw> <pr>(-l?r)</pr>, <pos>a.</pos> <ety>[L.
<ets>regularis</ets>, fr. <ets>regula</ets> a rule, fr.
<ets>regere</ets> to guide, to rule: cf. F. <ets>r<eacute/gulier</ets>.
See <er>Rule</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Conformed to a rule; agreeable to an established
rule, law, principle, or type, or to established customary forms;
normal; symmetrical; <as>as, a <ex>regular</ex> verse in poetry; a
<ex>regular</ex> piece of music; a <ex>regular</ex> verb;
<ex>regular</ex> practice of law or medicine; a <ex>regular</ex>
building.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Governed by rule or rules; steady or uniform in
course, practice, or occurence; not subject to unexplained or irrational
variation; returning at stated intervals; steadily pursued; orderlly;
methodical; <as>as, the <ex>regular</ex> succession of day and night;
<ex>regular</ex> habits.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Constituted, selected, or conducted in conformity
with established usages, rules, or discipline; duly authorized;
permanently organized; <as>as, a <ex>regular</ex> meeting; a
<ex>regular</ex> physican; a <ex>regular</ex> nomination;
<ex>regular</ex> troops.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Belonging to a monastic order or community; <as>as,
<ex>regular</ex> clergy, in distinction dfrom the <ex>secular</ex>
clergy</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Thorough; complete; unmitigated; <as>as, a
<ex>regular</ex> humbug</as>.</def> <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Bot. & Zool.)</fld> <def>Having all the parts of
the same kind alike in size and shape; <as>as, a <ex>regular</ex>
flower; a <ex>regular</ex> sea urchin.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Crystallog.)</fld> <def>Same as
<er>Isometric</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Regular polygon</b></col> <fld>(Geom.)</fld>, <cd>a plane
polygon which is both equilateral and equiangular.</cd> --
<col><b>Regular polyhedron</b></col> <fld>(Geom.)</fld>, <cd>a
polyhedron whose faces are equal regular polygons. There are five
regular polyhedrons, -- the tetrahedron, the hexahedron, or cube, the
octahedron, the dodecahedron, and the icosahedron.</cd> --
<col><b>Regular sales</b></col> <fld>(Stock Exchange)</fld>, <cd>sales
of stock deliverable on the day after the transaction.</cd> --
<col><b>Regular troops</b></col>, <cd>troops of a standing or permanent
army; -- opposed to <xex>militia</xex>.</cd></cs><-- or opposed to
reserves --><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Normal; orderly; methodical. See
<er>Normal</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regular</ent><br/
<hw>Reg"u*lar</hw> <pr>(r<ecr/g"<usl/*l<etil/r)</pr>, <pos>n.</pos>
<ety>[LL. <ets>regularis</ets>: cf. F. <ets>r<eacute/gulier</ets>. See
<er>Regular</er>, <pos>a.</pos>]</ety> <sn>1.</sn> <fld>(R. C.
Ch.)</fld> <def>A member of any religious order or community who has
taken the vows of poverty, chastity, and obedience, and who has been
solemnly recognized by the church.</def> <rj><au>Bp.
Fitzpatrick.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mil.)</fld> <def>A soldier belonging to a permanent
or standing army; -- chiefly used in the plural.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regularia</ent><br/
\'d8<hw>Reg`u*la"ri*a</hw>
<pr>(r<ecr/g`<usl/*l<amac/"r<icr/*<adot/)</pr>, <pos>n. pl.</pos>
<ety>[NL.]</ety> <fld>(Zool.)</fld> <def>A division of Echini which
includes the circular, or regular, sea urchins.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regularity</ent><br/
<hw>Reg`u*lar"i*ty</hw> <pr>(-l?r"?*t?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>r<eacute/gularit<eacute/</ets>.]</ety> <def>The condition or
quality of being regular; <as>as, <ex>regularity</ex> of outline; the
<ex>regularity</ex> of motion.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regularize</ent><br/
<hw>Reg"u*lar*ize</hw> <pr>(r<ecr/g"<usl/*l<etil/r*<imac/z)</pr>,
<pos>v. t.</pos> <def>To cause to become regular; to regulate.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regularly</ent><br/
<hw>Reg"u*lar*ly</hw>, <pos>adv.</pos> <def>In a regular manner; in
uniform order; methodically; in due order or time.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regularness</ent><br/
<hw>Reg"u*lar*ness</hw>, <pos>n.</pos> <def>Regularity.</def>
<rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regulate</ent><br/
<hw>Reg"u*late</hw> <pr>(-l<amac/t)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Regulated</conjf>
<pr>(-l<amac/`t<ecr/d)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Regulating</conjf>.]</vmorph> <ety>[L. <ets>regulatus</ets>, p.
p. of <ets>regulare</ets>, fr. <ets>regula</ets>. See
<er>Regular</er>.]</ety> <sn>1.</sn> <def>To adjust by rule, method, or
established mode; to direct by rule or restriction; to subject to
governing principles or laws.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The laws which <qex>regulate</qex> the successions of the
seasons.</q> <rj><au>Macaulay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The herdsmen near the frontier adjudicated their own disputes, and
<qex>regulated</qex> their own police.</q>
<rj><qau>Bancroft.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To put in good order; <as>as, to <ex>regulate</ex>
the disordered state of a nation or its finances</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To adjust, or maintain, with respect to a desired
rate, degree, or condition; <as>as, to <ex>regulate</ex> the temperature
of a room, the pressure of steam, the speed of a machine,
etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>To regulate a watch</b></col> <it>or</it>
<col><b>To regulate a clock</b></col></mcol>, <cd>to adjust its rate of
running so that it will keep approximately standard time.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To adjust; dispose; methodize; arrange; direct;
order; rule; govern.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regulation</ent><br/
<hw>Reg`u*la"tion</hw> <pr>(-l?"sh?n)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>The act of regulating, or the state of being regulated.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The temper and <qex>regulation</qex> of our own minds.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A rule or order prescribed for management or
government; prescription; a regulating principle; a governing direction;
precept; law; <as>as, the <ex>regulations</ex> of a society or a
school</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Regulation sword</b></col>, <col><b>cap</b></col>,
<col><b>uniform</b></col>, etc.</mcol> <fld>(Mil.)</fld>, <cd>a sword,
cap, uniform, etc., of the kind or quality prescribed by the official
regulations.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- <er>Law</er>; rule; method; principle; order;
precept. See <er>Law</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regulative</ent><br/
<hw>Reg"u*la*tive</hw> <pr>(r?g"?*l?*t?v)</pr>, <pos>a.</pos>
<sn>1.</sn> <def>Tending to regulate; regulating.</def>
<rj><au>Whewell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Metaph.)</fld> <def>Necessarily assumed by the mind
as fundamental to all other knowledge; furnishing fundamental
principles; <as>as, the <ex>regulative</ex> principles, or principles
<altname>a priori</altname>; the <ex>regulative</ex> faculty.</as></def>
<rj><au>Sir W. Hamilton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ These terms are borrowed from Kant, and suggest the
thought, allowed by Kant, that possibly these principles are only true
for the human mind, the operations and belief of which they
regulate.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regulator</ent><br/
<hw>Reg"u*la`tor</hw> <pr>(-l?`t?r)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>One who, or that which, regulates.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mach.)</fld> <def>A contrivance for regulating and
controlling motion</def>, <specif>as:</specif> <sd>(a)</sd> <def>The
lever or index in a watch, which controls the effective length of the
hairspring, and thus regulates the vibrations of the balance.</def>
<sd>(b)</sd> <def>The governor of a steam engine.</def> <sd>(c)</sd>
<def>A valve for controlling the admission of steam to the steam chest,
in a locomotive.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A clock, or other timepiece, used as a standard of
correct time. See <cref>Astronomical clock</cref> <sd>(a)</sd>, under
<er>Clock</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A member of a volunteer committee which, in default
of the lawful authority, undertakes to preserve order and prevent
crimes; also, sometimes, one of a band organized for the comission of
violent crimes.</def> <mark>[U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>A few stood neutral, or declared in favor of the
<qex>Regulators</qex>.</q> <rj><qau>Bancroft.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reguline</ent><br/
<hw>Reg"u*line</hw> <pr>(r?g"?*l?n)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>r<eacute/gulin</ets>. See <er>Regulus</er>.]</ety> <fld>(Chem. &
Metal.)</fld> <def>Of or pertaining to regulus.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regulize</ent><br/
<hw>Reg"u*lize</hw> <pr>(-l?z)</pr>, <pos>v. t.</pos> <fld>(Old
Chem.)</fld> <def>To reduce to regulus; to separate, as a metal from
extraneous matter; <as>as, to <ex>regulize</ex> antimony</as>.</def>
<mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regulus</ent><br/
<hw>Reg"u*lus</hw> <pr>(-l?s)</pr>, <pos>n.</pos>; <plu><it>pl.</it> E.
<plw>Reguluses</plw> (-<?/z), L. <plw>Reguli</plw>
<pr>(-l<?/)</pr>.</plu> <ety>[L., a petty king, prince, dim. of
<ets>rex</ets>, <ets>regis</ets>, a king: cf. F.
<ets>r<eacute/gule</ets>. See <er>Regal</er>.]</ety> <sn>1.</sn> <def>A
petty king; a ruler of little power or consequence.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Chem. & Metal.)</fld> <def>The button, globule, or
mass of metal, in a more or less impure state, which forms in the bottom
of the crucible in smelting and reduction of ores.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The name was introduced by the alchemists, and applied
by them in the first instance to antimony. It signifies <xex>little
king</xex>; and from the facility with which antimony alloyed with gold,
these empirical philosophers had great hopes that this metal,
<xex>antimony</xex>, would lead them to the discovery of the
philosopher's stone.</note> <rj><au>Ure.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Astron.)</fld> <def>A star of the first magnitude
in the constellation Leo; -- called also the <altname>Lion's
Heart</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regurgitate</ent><br/
<hw>Re*gur"gi*tate</hw> <pr>(r?*g?r"j?*t?t)</pr>, <pos>v. t.</pos>
<ety>[LL. <ets>regurgitare</ets>, <ets>regurgitatum</ets>; L. pref.
<ets>re-</ets> re- + <ets>gurges</ets>, <ets>-itis</ets>, a gulf. Cf.
<er>Regorge</er>.]</ety> <def>To throw or pour back, as from a deep or
hollow place; to pour or throw back in great quantity.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regurgitate</ent><br/
<hw>Re*gur"gi*tate</hw>, <pos>v. i.</pos> <def>To be thrown or poured
back; to rush or surge back.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The food may <qex>regurgitate</qex>m the stomach into the
esophagus and mouth.</q> <rj><qau>Quain.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Regurgitation</ent><br/
<hw>Re*gur`gi*ta"tion</hw> <pr>(-t?"sh?n)</pr>, <pos>n.</pos> <ety>[Cf.
F. <ets>r<eacute/gurgitation</ets>.]</ety> <sn>1.</sn> <def>The act of
flowing or pouring back by the orifice of entrance</def>; specifically
<fld>(Med.)</fld>, <def>the reversal of the natural direction in which
the current or contents flow through a tube or cavity of the body.</def>
<rj><au>Quain.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The act of swallowing again; reabsorption.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rehabilitate</ent><br/
<hw>Re`ha*bil"i*tate</hw> <pr>(r?`h?*b?l"?*t?t)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Rehabilitated</conjf>
<pr>(-t?`t?d)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Rehabilitating</conjf>.]</vmorph> <ety>[Pref. <ets>re-</ets> re-
+ <ets>habilitate</ets>: cf. LL. <ets>rehabilitare</ets>, F.
<ets>r<eacute/habiliter</ets>.]</ety> <def>To invest or clothe again
with some right, authority, or dignity; to restore to a former capacity;
to reinstate; to qualify again; to restore, as a delinquent, to a former
right, rank, or privilege lost or forfeited; -- a term of civil and
canon law.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Restoring and <qex>rehabilitating</qex> the party.</q>
<rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rehabilitation</ent><br/
<hw>Re`ha*bil`i*ta"tion</hw> <pr>(-t?"sh?n)</pr>, <pos>n.</pos>
<ety>[Cf. LL. <ets>rehabilitatio</ets>, F.
<ets>R<eacute/habilitation</ets>.]</ety> <def>The act of rehabilitating,
or the state of being rehabilitated.</def> <rj><au>Bouvier.
Walsh.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rehash</ent><br/
<hw>Re*hash"</hw> <pr>(r?*h?sh")</pr>, <pos>v. t.</pos> <def>To hash
over again; to prepare or use again; <as>as, to <ex>rehash</ex> old
arguments</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rehash</ent><br/
<hw>Re*hash"</hw>, <pos>n.</pos> <def>Something hashed over, or made up
from old materials.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rehear</ent><br/
<hw>Re*hear"</hw> <pr>(r?*h?r")</pr>, <pos>v. t.</pos> <def>To hear
again; to try a second time; <as>as, to <ex>rehear</ex> a cause in
Chancery</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rehearsal</ent><br/
<hw>Re*hears"al</hw> <pr>(r?*h?rs"<it>a</it>)</pr>, <pos>n.</pos>
<def>The act of rehearsing; recital; narration; repetition;
specifically, a private recital, performance, or season of practice, in
preparation for a public exhibition or exercise.</def>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>In <qex>rehearsal</qex> of our Lord's Prayer.</q>
<rj><qau>Hooker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Here's marvelous convenient place for our
<qex>rehearsal</qex>.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dress rehearsal</b></col> <fld>(Theater)</fld>, <cd>a
private preparatory performance of a drama, opera, etc., in
costume.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rehearse</ent><br/
<hw>Re*hearse"</hw> <pr>(r?*h?rs")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Rehearsed</conjf>
<pr>(-h?rst")</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Rehearsing</conjf>.]</vmorph> <ety>[OE. <ets>rehercen</ets>,
<ets>rehersen</ets>, OF. <ets>reherser</ets>, <ets>rehercier</ets>, to
harrow over again; pref. <ets>re-</ets> re- + <ets>hercier</ets> to
harrow, fr. <ets>herce</ets> a harrow, F. <ets>herse</ets>. See
<er>Hearse</er>.]</ety> <sn>1.</sn> <def>To repeat, as what has been
already said; to tell over again; to recite.</def>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>When the words were heard which David spake, they
<qex>rehearsed</qex> them before Saul.</q> <rj><qau>1 Sam. xvii.
31.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To narrate; to relate; to tell.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Rehearse</qex> the righteous acts of the Lord.</q>
<rj><qau>Judg. . v. 11.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To recite or repeat in private for experiment and
improvement, before a public representation; <as>as, to
<ex>rehearse</ex> a tragedy</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To cause to rehearse; to instruct by
rehearsal.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He has been <qex>rehearsed</qex> by Madame Defarge as to his
having seen her.</q> <rj><qau>Dickens.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To recite; recapitulate; recount; detail;
describe; tell; relate; narrate.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rehearse</ent><br/
<hw>Re*hearse"</hw>, <pos>v. i.</pos> <def>To recite or repeat something
for practice.</def> <ldquo/There will we <xex>rehearse</xex>.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rehearser</ent><br/
<hw>Re*hears"er</hw> <pr>(-?r)</pr>, <pos>n.</pos> <def>One who
rehearses.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reheat</ent><br/
<hw>Re*heat"</hw> <pr>(r?*h?t")</pr>, <pos>v. t.</pos> <sn>1.</sn>
<def>To heat again.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To revive; to cheer; to cherish.</def>
<mark>[Obs.]</mark> <rj><au>Rom. of R.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rehibition</ent><br/
<hw>Re`hi*bi"tion</hw> <pr>(r?`h?*b?sh"?n)</pr>, <pos>n.</pos>
<ety>[Pref. <ets>re-</ets> + L. <ets>habere</ets> to have.]</ety>
<fld>(Law)</fld> <def>The returning of a thing purchased to the seller,
on the ground of defect or frand.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rehibitory</ent><br/
<hw>Re*hib"i*to*ry</hw> <pr>(r?*h?b"?*t?*r?)</pr>, <pos>a.</pos>
<fld>(Law)</fld> <def>Of or relating to rehibition; <as>as, a
<ex>rehibitory</ex> action</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rehire</ent><br/
<hw>Re*hire"</hw> <pr>(r?*h?r")</pr>, <pos>v. t.</pos> <def>To hire
again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rehypothecate</ent><br/
<hw>Re`hy*poth"e*cate</hw> <pr>(r?`h?*p?th"?*k?t)</pr>, <pos>v. t.</pos>
<fld>(Law)</fld> <def>To hypothecate again.</def> --
<wordforms><wf>Re`hy*poth`e*ca"tion</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rei</ent><br/
<hw>Rei</hw> <pr>(r?)</pr>, <pos>n.</pos>;<plu><it>pl.</it>
<plw>Reis</plw> <pr>(r<?/"<?/s <xex>or</xex> r<?/z)</pr>.</plu>
<ety>[Pg. <ets>real</ets>, pl. <ets>reis</ets>. See <er>Real</er> a
coin.]</ety> <def>A portuguese money of account, in value about one
tenth of a cent.</def> <altsp>[Spelt also <asp>ree</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reichsrath</ent><br/
\'d8<hw>Reichs"rath`</hw> <pr>(r?ks"r?t)</pr>, <pos>n.</pos>
<ety>[G]</ety> <def>The parliament of Austria (exclusive of Hungary,
which has its own diet, or parliament). It consists of an Upper and a
Lower House, or a House of Lords and a House of
Representatives.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reichsstand</ent><br/
\'d8<hw>Reichs"stand`</hw> <pr>(r?ks"st?t`)</pr>, <pos>n.</pos>
<ety>[G.]</ety> <def>A free city of the former German empire.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reichstag</ent><br/
\'d8<hw>Reichs"tag`</hw> <pr>(r?ks"t?g`)</pr>, <pos>n.</pos>
<ety>[G.]</ety> <sn>1.</sn> <mark>[Note: from the 1913
definition]</mark> <def>The Diet, or House of Representatives, of the
German empire (and of the Weimar Republic), which was composed of
members elected for a term of three years by the direct vote of the
people. This term is no longer (in 1997) applied to the German
parliament. See also <er>Bundesrath</er>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <mark>[Note: from the 1913 definition]</mark> <def>The
national representative body of Hungary, consisting of a House of
Magnates (including archdukes, peers, high officials of the Roman
Catholic, Greek, and Protestant Churches, and certain other dignitaries)
and a House of Representatives (in 1912 consisting of 453 members). See
<er>Legislative</er>, <er>Diet</er>.</def> <mark>[archaic]</mark> <br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><ent>Reif</ent><br/
<hw>Reif</hw> <pr>(r<emac/f)</pr>, <pos>n.</pos> <ety>[AS.
<ets>re<aacute/f</ets>.]</ety> <def>Robbery; spoil.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reigle</ent><br/
<hw>Rei"gle</hw> <pr>(r?"g'l)</pr>, <pos>n.</pos> <ety>[F.
<ets>r<egrave/gle</ets> a rule, fr. L. <ets>regula</ets>. See
<er>Rule</er>.]</ety> <def>A hollow cut or channel for quiding anything;
<as>as, the <ex>reigle</ex> of a side post for a flood gate</as>.</def>
<rj><au>Carew.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reigle</ent><br/
<hw>Rei"gle</hw>, <pos>v. t.</pos> <def>To regulate; to govern.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reiglement</ent><br/
<hw>Rei"gle*ment</hw> <pr>(-m<it>e</it>nt)</pr>, <pos>n.</pos> <ety>[See
<er>Reglement</er>.]</ety> <def>Rule; regulation.</def>
<mark>[Obs.]</mark> <rj><au>Bacon. Jer. Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reign</ent><br/
<hw>Reign</hw> <pr>(r<amac/n)</pr>, <pos>n.</pos> <ety>[OE.
<ets>regne</ets>, OF. <ets>reigne</ets>, <ets>regne</ets>, F.
<ets>r<egrave/gne</ets>, fr. L. <ets>regnum</ets>, fr. <ets>rex</ets>,
<ets>regis</ets>, a king, fr. <ets>regere</ets> to guide, rule. See
<er>Regal</er>, <er>Regimen</er>.]</ety> <sn>1.</sn> <def>Royal
authority; supreme power; sovereignty; rule; dominion.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He who like a father held his <qex>reign</qex>.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Saturn's sons received the threefold <qex>reign</qex><br/
Of heaven, of ocean, and deep hell beneath.</q>
<rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The territory or sphere which is reigned over;
kingdom; empire; realm; dominion.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>[God] him bereft the <qex>regne</qex> that he had.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The time during which a king, queen, or emperor
possesses the supreme authority; <as>as, it happened in the
<ex>reign</ex> of Elizabeth</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1212 --></p>

<p><ent>Reign</ent><br/
<hw>Reign</hw> <pr>(r?n)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Reigned</conjf> <pr>(r?nd)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Reigning</conjf>.]</vmorph> <ety>[OE. <ets>regnen</ets>,
<ets>reinen</ets>, OF. <ets>regner</ets>, F. <ets>r<eacute/gner</ets>,
fr. L. <ets>regnare</ets>, fr. regnum. See <er>Reign</er>,
<pos>n.</pos>]</ety> <sn>1.</sn> <def>To possess or exercise sovereign
power or authority; to exercise government, as a king or emperor;; to
hold supreme power; to rule.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>We will not have this man to <qex>reign</qex> over us.</q>
<rj><qau>Luke xix. 14.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Shall Banquo's issue ever<br/
<qex>Reign</qex> in this kingdom?</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence, to be predominant; to prevail.</def>
<ldquo/Pestilent diseases which commonly <xex>reign</xex> in
summer.<rdquo/ <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To have superior or uncontrolled dominion; to
rule.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Let not sin therefore <qex>reign</qex> in your mortal body.</q>
<rj><qau>Rom. vi. 12.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To rule; govern; direct; control;
prevail.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reigner</ent><br/
<hw>Reign"er</hw> <pr>(r?n"?r)</pr>, <pos>n.</pos> <def>One who
reigns.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>reignite</ent><br/
<ent>re-ignite</ent><br/
<mhw><hw>reignite</hw>, <hw>re-ignite</hw></mhw> <pos>v. t.</pos>
<def>To ignite anew, as of a fire.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Reillume</ent><br/
<hw>Re`il*lume"</hw> <pr>(r?`?l*l?m")</pr>, <pos>v. t.</pos> <def>To
light again; to cause to shine anew; to relume; to reillumine.</def>
<ldquo/Thou must <xex>reillume</xex> its spark.<rdquo/ <rj><au>J. R.
Drake.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reilluminate</ent><br/
<hw>Re`il*lu"mi*nate</hw> <pr>(-l?"m?*n?t)</pr>, <pos>v. t.</pos>
<def>To enlighten again; to reillumine.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reillumination</ent><br/
<hw>Re`il*lu`mi*na"tion</hw> <pr>(-n?"sh?n)</pr>, <pos>n.</pos> <def>The
act or process of enlightening again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reillumine</ent><br/
<hw>Re`il*lu"mine</hw> <pr>(-l?"m?n)</pr>, <pos>v. t.</pos> <def>To
illumine again or anew; to reillume.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reim</ent><br/
<hw>Reim</hw> <pr>(r?m)</pr>, <pos>n.</pos> <ety>[D. <ets>riem</ets>,
akin to G <ets>riemen</ets>; CF. Gr. <?/<?/<?/<?/ a towing line.]</ety>
<def>A strip of oxhide, deprived of hair, and rendered pliable, -- used
for twisting into ropes, etc.</def> <mark>[South Africa]</mark>
<rj><au>Simmonds.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reimbark</ent><br/
<hw>Re`im*bark"</hw> <pr>(r?`?m*b?rk")</pr>, <pos>v. t. & i.</pos>
<def>See <er>Reembark</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reimbody</ent><br/
<hw>Re`im*bod"y</hw> <pr>(-b?d"?)</pr>, <pos>v. t. & i.</pos> <ety>[See
<er>Reembody</er>.]</ety> <def>To imbody again.</def>
<rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reimbursable</ent><br/
<hw>Re`im*burs"a*ble</hw> <pr>(r?`?m*b?rs"?*b'l)</pr>, <pos>a.</pos>
<ety>[CF. F. <ets>remboursable</ets>.]</ety> <def>Capable of being
repaid; repayable.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A loan has been made of two millions of dollars,
<qex>reimbursable</qex> in ten years.</q> <rj><qau>A.
Hamilton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reimburse</ent><br/
<hw>Re`im*burse"</hw> <pr>(-b?rs")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Reimbursed</conjf>
<pr>(-b?rst")</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Reimbursing</conjf>.]</vmorph> <ety>[Pref. <ets>re-</ets> +
<ets>imburse</ets>: cf. F. <ets>rembourser</ets>.]</ety> <sn>1.</sn>
<def>To replace in a treasury or purse, as an equivalent for what has
been taken, lost, or expended; to refund; to pay back; to restore;
<as>as, to <ex>reimburse</ex> the expenses of a war</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To make restoration or payment of an equivalent to
(a person); to pay back to; to indemnify; -- often reflexive; <as>as, to
<ex>reimburse</ex> one's self by successful speculation</as>.</def>
<rj><au>Paley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reimbursement</ent><br/
<hw>Re`im*burse"ment</hw> <pr>(-b?rs"m<it>e</it>nt)</pr>, <pos>n.</pos>
<ety>[Cf. F. <ets>rembursement</ets>.]</ety> <def>The act
reimbursing.</def> <rj><au>A. Hamilton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reimburser</ent><br/
<hw>Re`im*burs"er</hw> <pr>(-b?rs"?r)</pr>, <pos>n.</pos> <def>One who
reimburses.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reimplant</ent><br/
<hw>Re`im*plant"</hw> <pr>(-pl?nt")</pr>, <pos>v. t.</pos> <def>To
implant again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reimport</ent><br/
<hw>Re`im*port"</hw> <pr>(-p?rt")</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>re-</ets> + <ets>import</ets>: cf. F. <ets>remporter</ets>.]</ety>
<def>To import again; to import what has been exported; to bring
back.</def> <rj><au>Young.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reimportation</ent><br/
<hw>Re*im`por*ta"tion</hw> <pr>(r?*?m`p?r*t?"sh?n)</pr>, <pos>n.</pos>
<def>The act of reimporting; also, that which is reimported.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reimportune</ent><br/
<hw>Re*im`por*tune"</hw> <pr>(-p?r*t?n")</pr>, <pos>v. t.</pos> <def>To
importune again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reimpose</ent><br/
<hw>Re`im*pose"</hw> <pr>(r?`?m*p?z)</pr>, <pos>v. t.</pos> <def>To
impose anew.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reimpregnate</ent><br/
<hw>Re`im*preg"nate</hw> <pr>(-pr?g"n?t)</pr>, <pos>v. t.</pos> <def>To
impregnate again or anew.</def> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reimpress</ent><br/
<hw>Re`im*press"</hw> <pr>(-pr?s")</pr>, <pos>v. t.</pos> <def>To
impress anew.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reimpression</ent><br/
<hw>Re`im*pres"sion</hw> <pr>(-pr?sh"?n)</pr>, <pos>n.</pos> <def>A
second or repeated impression; a reprint.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reimprint</ent><br/
<hw>Re`im*print"</hw> <pr>(-pr?nt")</pr>, <pos>v. t.</pos> <def>To
imprint again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reimprison</ent><br/
<hw>Re`im*pris"on</hw> <pr>(-pr?z'n)</pr>, <pos>v. t.</pos> <def>To
imprison again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reimprisonment</ent><br/
<hw>Re`im*pris"on*ment</hw> <pr>(-m<it>e</it>nt)</pr>, <pos>n.</pos>
<def>The act of reimprisoning, or the state of being
reimprisoned.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rein</ent><br/
<hw>Rein</hw> <pr>(r?n)</pr>, <pos>n.</pos> <ety>[F.
<ets>r<ecir/ne</ets>, fr. (assumed) LL. <ets>retina</ets>, fr. L.
<ets>retinere</ets> to hold back. See <er>Retain</er>.]</ety>
<sn>1.</sn> <def>The strap of a bridle, fastened to the curb or snaffle
on each side, by which the rider or driver governs the horse.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This knight laid hold upon his <qex>reyne</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence, an instrument or means of curbing,
restraining, or governing; government; restraint.</def> <ldquo/Let their
eyes rove without <xex>rein</xex>.<rdquo/ <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>To give rein</b></col>, <col><b>To give the rein
to</b></col></mcol>, <cd>to give license to; to leave withouut
restrain.</cd> -- <col><b>To take the reins</b></col>, <cd>to take the
guidance or government; to assume control.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rein</ent><br/
<hw>Rein</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Reined</conjf> <pr>(r?nd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Reining</conjf>.]</vmorph> <sn>1.</sn> <def>To govern or direct
with the reins; <as>as, to <ex>rein</ex> a horse one way or
another</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He mounts and <qex>reins</qex> his horse.</q>
<rj><qau>Chapman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To restrain; to control; to check.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Being once chafed, he can not<br/
Be <qex>reined</qex> again to temperance.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>To rein in</b></col> <it>or</it> <col><b>To rein
up</b></col></mcol>, <sd>(a)</sd> <cd>to check the speed of, or cause to
stop, by drawing the reins.</cd> <specif>Hence,</specif> <sd>(a)</sd>
<cd>to cause (a person) to slow down or cease some activity; -- <ex>to
rein in</ex> is used commonly of superiors in a chain of command,
ordering a subordinate to moderate or cease some activity deemed
excessive.</cd></cs><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Rein</ent><br/
<hw>Rein</hw>, <pos>v. i.</pos> <def>To be guided by reins.</def>
<mark>[R.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reinaugurate</ent><br/
<hw>Re`in*au"gu*rate</hw>, <pos>v. t.</pos> <def>To inaugurate
anew.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reincit</ent><br/
<hw>Re"in*cit"</hw> <pr>(-s?t")</pr>, <pos>v. t.</pos> <def>To incite
again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reincorporate</ent><br/
<hw>Re`in*cor"po*rate</hw>, <pos>v. t.</pos> <def>To incorporate
again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reincrease</ent><br/
<hw>Re`in*crease"</hw> <pr>(-kr?s")</pr>, <pos>v. t.</pos> <def>To
increase again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reincur</ent><br/
<hw>Re`in*cur"</hw> <pr>(-k?r")</pr>, <pos>v. t.</pos> <def>To incur
again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reindeer</ent><br/
<hw>Rein"deer`</hw> <pr>(r<amac/n"d<emac/r)</pr>, <pos>n.</pos>
<ety>[Icel. <ets>hreinn</ets> reindeer + E. <ets>deer</ets>. Icel.
<ets>hreinn</ets> is of Lapp or Finnish origin; cf. Lappish
<ets>reino</ets> pasturage.]</ety> <altsp>[Formerly written also
<asp>raindeer</asp>, and <asp>ranedeer</asp>.]</altsp>
<fld>(Zool.)</fld> <def>Any ruminant of the genus <gen>Rangifer</gen>,
of the Deer family, found in the colder parts of both the Eastern and
Western hemispheres, and having long irregularly branched antlers, with
the brow tines palmate.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The common European species (<spn>Rangifer
tarandus</spn>) is domesticated in Lapland. The woodland reindeer or
caribou (<spn>Rangifer caribou</spn>) is found in Canada and Maine (see
<er>Caribou</er>.) The Barren Ground reindeer or caribou (<spn>Rangifer
Groenlandicus</spn>), of smaller size, is found on the shores of the
Arctic Ocean, in both hemispheries.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Reindeer moss</b></col> <fld>(Bot.)</fld>, <cd>a gray
branching lichen (<spn>Cladonia rangiferina</spn>) which forms extensive
patches on the ground in arctic and even in north temperature regions.
It is the principal food of the Lapland reindeer in winter.</cd> --
<col><b>Reindeer period</b></col> <fld>(Geol.)</fld>, <cd>a name
sometimes given to a part of the Paleolithic era when the reindeer was
common over Central Europe.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reinduce</ent><br/
<hw>Re`in*duce"</hw> <pr>(r?`?n*d?s")</pr>, <pos>v. t.</pos> <def>To
induce again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reinette</ent><br/
<hw>Rei*nette"</hw> <pr>(r?*n?t")</pr>, <pos>n.</pos> <ety>[F. See 1st
<er>Rennet</er>.]</ety> <fld>(Bot.)</fld> <def>A name given to many
different kinds of apples, mostly of French origin.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reinfect</ent><br/
<hw>Re`in*fect"</hw> <pr>(r?`?n*f?kt)</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>re-</ets> + <ets>infect</ets>: cf. F.
<ets>r<eacute/infecter</ets>.]</ety> <def>To infect again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reinfectious</ent><br/
<hw>Re`in*fec"tious</hw> <pr>(-f?k"sh?s)</pr>, <pos>a.</pos>
<def>Capable of reinfecting.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reinforce</ent><br/
<hw>Re`in*force"</hw> <pr>(-f?rs")</pr>, <pos>v. t.</pos> <def>See
<er>Reenforce</er>, <pos>v. t.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reinforce</ent><br/
<hw>Re`in*force"</hw>, <pos>n.</pos> <def>See <er>Reenforce</er>,
<pos>n.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reinforced concrete</ent><br/
<hw>Re`in*forced con"crete</hw>. <def>Concrete having within its mass a
system of iron or steel supports, such as bars, rods, or a heavy mesh,
to provide increased tensile strength and shear resistance. Same as
<er>Ferro-concrete</er>.</def> <altsp>[Also spelled <asp>reenforced
concrete</asp>.]</altsp><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><ent>Reinforcement</ent><br/
<hw>Re`in*force"ment</hw> <pr>(-m<it>e</it>nt)</pr>, <pos>n.</pos>
<def>See <er>Reenforcement</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reinfund</ent><br/
<hw>Re`in*fund"</hw> <pr>(-f?nd")</pr>, <pos>v. i.</pos> <ety>[Pref.
<ets>re-</ets> + L. <ets>infundere</ets> to pour in.]</ety> <def>To flow
in anew.</def> <mark>[Obs.]</mark> <rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reingratiate</ent><br/
<hw>Re`in*gra"ti*ate</hw> <pr>(-gr?"sh?*?t)</pr>, <pos>v. t.</pos>
<def>To ingratiate again or anew.</def> <rj><au>Sir. T.
Herbert.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reinhabit</ent><br/
<hw>Re`in*hab"it</hw> <pr>(-h?b"?t)</pr>, <pos>v. t.</pos> <def>To
inhabit again.</def> <rj><au>Mede.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reinless</ent><br/
<hw>Rein"less</hw> <pr>(r?n"l?s)</pr>, <pos>a.</pos> <def>Not having, or
not governed by, reins; hence, not checked or restrained.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reins</ent><br/
<hw>Reins</hw> <pr>(r<amac/nz)</pr>, <pos>n. pl.</pos> <ety>[F.
<ets>rein</ets>, pl. <ets>reins</ets>, fr. L. <ets>ren</ets>, pl.
<ets>renes</ets>.]</ety> <sn>1.</sn> <def>The kidneys; also, the region
of the kidneys; the loins.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The inward impulses; the affections and passions; --
so called because formerly supposed to have their seat in the part of
the body where the kidneys are.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>My <qex>reins</qex> rejoice, when thy lips speak right things.</q>
<rj><qau>Prov. xxiii. 16.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I am he which searcheth the <qex>reins</qex> and hearts.</q>
<rj><qau>Rev. ii. 23.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Reins of a vault</b></col> <fld>(Arch.)</fld>, <cd>the
parts between the crown and the spring or abutment, including, and
having especial reference to, the loading or filling behind the shell of
the vault. The reins are to a vault nearly what the haunches are to an
arch, and when a vault gives way by thrusting outward, it is because its
reins are not sufficiently filled up.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reinsert</ent><br/
<hw>Re`in*sert"</hw> <pr>(r?`?n*s?rt")</pr>, <pos>v. t.</pos> <def>To
insert again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reinsertion</ent><br/
<hw>Re`in*ser"tion</hw> <pr>(-s?r"sh?n)</pr>, <pos>n.</pos> <def>The act
of reinserting.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reinspect</ent><br/
<hw>Re`in*spect"</hw> <pr>(-sp?kt")</pr>, <pos>v. t.</pos> <def>To
inspect again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reinspection</ent><br/
<hw>Re`in*spec"tion</hw> <pr>(-sp?k"sh?n)</pr>, <pos>n.</pos> <def>The
act of reinspecting.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reinspire</ent><br/
<hw>Re`in*spire"</hw> <pr>(-sp?r")</pr>, <pos>v. t.</pos> <def>To
inspire anew.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reinspirit</ent><br/
<hw>Re`in*spir"it</hw> <pr>(-sp`r"?t)</pr>, <pos>v. t.</pos> <def>To
give fresh spirit to.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>reinstall</ent><br/
<ent>re-install</ent><br/
<mhw><hw>Re`in*stall"</hw>, <hw>Re`-in*stall"</hw></mhw>
<pr>(-st?l")</pr>, <pos>v. t.</pos> <ety>[Pref. <ets>re-</ets> +
<ets>install</ets>: cf. F. <ets>r<eacute/installer</ets>.]</ety> <def>To
install again; <as>as, She <ex>reinstalled</ex> the the washer after it
had been repaired</as>.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reinstallment</ent><br/
<hw>Re`in*stall"ment</hw> <pr>(-m<eit/nt)</pr>, <pos>n.</pos> <def>A
renewed installment.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reinstate</ent><br/
<hw>Re`in*state"</hw> <pr>(-st?t")</pr>, <pos>v. t.</pos> <def>To place
again in possession, or in a former state; to restore to a state from
which one had been removed; to instate again; <as>as, to
<ex>reinstate</ex> a king in the possession of the
kingdom</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>For the just we have said already thet some of them were
<qex>reinstated</qex> in their pristine happiness and felicity.</q>
<rj><qau>Glanvill.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reinstatement</ent><br/
<hw>Re`in*state"ment</hw> <pr>(-m<it>e</it>nt)</pr>, <pos>n.</pos>
<def>The act of reinstating; the state of being reinstated;
reestablishment.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reinstation</ent><br/
<hw>Re`in*sta"tion</hw> <pr>(-st?"sh?n)</pr>, <pos>n.</pos>
<def>Reinstatement.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reinstruct</ent><br/
<hw>Re`in*struct"</hw> <pr>(-str?kt")</pr>, <pos>v. t.</pos> <def>To
instruct anew.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reinsurance</ent><br/
<hw>Re`in*sur"ance</hw> <pr>(-sh?r"<it>a</it>ns)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>Insurance a second time or again; renewed
insurance.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A contract by which an insurer is insured wholly or
in part against the risk he has incurred in insuring somebody else. See
<er>Reassurance</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>re-insure</ent><br/
<hw>re-insure</hw> <pos>v.</pos> <sn>1.</sn> <def>to provide additional
insurance for.</def><br/
<syn><b>Syn. --</b> reinsure.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>to insure again by transferring to another insurance
company all or a part of a liability assumed.</def><br/
<syn><b>Syn. --</b> reinsure.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Reinsure</ent><br/
<hw>Re`in*sure"</hw> <pr>(-sh?r")</pr>, <pos>v. t.</pos> <sn>1.</sn>
<def>To insure again after a former insurance has ceased; to renew
insurance on.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To insure, as life or property, in favor of one who
has taken an insurance risk upon it.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The insurer may cause the property insured to be
<qex>reinsured</qex> by other persons.</q>
<rj><qau>Walsh.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reinsurer</ent><br/
<hw>Re`in*sur"er</hw> <pr>(-sh?r"?r)</pr>, <pos>n.</pos> <def>One who
gives reinsurance.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reintegrate</ent><br/
<hw>Re*in"te*grate</hw> <pr>(r?*?n"t?*gr?t)</pr>, <pos>v. t.</pos>
<ety>[Pref. <ets>re-</ets> + <ets>integrate</ets>. Cf.
<er>Redintegrate</er>.]</ety> <def>To renew with regard to any state or
quality; to restore; to bring again together into a whole, as the parts
of anything; to reestablish; <as>as, to <ex>reintegrate</ex> a
nation</as>.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reintegration</ent><br/
<hw>Re*in`te*gra"tion</hw> <pr>(-gr?"sh?n)</pr>, <pos>n.</pos> <def>A
renewing, or making whole again. See <er>Redintegration</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reinter</ent><br/
<hw>Re`in*ter"</hw> <pr>(r?`?n*t?r")</pr>, <pos>v. t.</pos> <def>To
inter again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reinterrogate</ent><br/
<hw>Re`in*ter"ro*gate</hw> <pr>(-t?r"r?*g?t)</pr>, <pos>v. t.</pos>
<def>To interrogate again; to question repeatedly.</def>
<rj><au>Cotgrave.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reinthrone</ent><br/
<hw>Re`in*throne"</hw> <pr>(-thr?n")</pr>, <pos>v. t.</pos> <def>See
<er>Reenthrone</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reinthronize</ent><br/
<hw>Re`in*thron"ize</hw> <pr>(-?z)</pr>, <pos>v. t.</pos> <def>To
enthrone again.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reintroduce</ent><br/
<hw>Re*in`tro*duce"</hw> <pr>(r?*?n`tr?*d?s")</pr>, <pos>v. t.</pos>
<def>To introduce again.</def> -- <wordforms><wf>Re*in`tro*duc"tion</wf>
<pr>(-d<?/k"sh<?/n)</pr>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reinvest</ent><br/
<hw>Re`in*vest"</hw> <pr>(r?`?n*v?st")</pr>, <pos>v. t.</pos> <def>To
invest again or anew.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reinvestigate</ent><br/
<hw>Re`in*ves"ti*gate</hw> <pr>(-v?s"t?*g?t)</pr>, <pos>v. t.</pos>
<def>To investigate again.</def> --
<wordforms><wf>Re`in*ves`ti*ga"tion</wf> <pr>(-g<?/"sh<?/n)</pr>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reinvestment</ent><br/
<hw>Re`in*vest"ment</hw> <pr>(-v?st"m<it>e</it>nt)</pr>, <pos>n.</pos>
<def>The act of investing anew; a second or repeated
investment.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reinvigorate</ent><br/
<hw>Re`in*vig"or*ate</hw> <pr>(-v?g"?r*?t)</pr>, <pos>v. t.</pos>
<def>To invigorate anew.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reinvolve</ent><br/
<hw>Re`in*volve"</hw> <pr>(-v?lv")</pr>, <pos>v. t.</pos> <def>To
involve anew.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reis</ent><br/
\'d8<hw>Re`is</hw> <pr>(r?"?s <or/ r?z)</pr>, <pos>n.</pos> <ety>[Pg.,
pl. of <ets>real</ets>, an ancient Portuguese coin.]</ety> <def>The word
is used as a Portuguese designation of money of account, one hundred
reis being about equal in value to eleven cents.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reis</ent><br/
<hw>Reis</hw> <pr>(r<imac/s)</pr>, <pos>n.</pos> <ety>[Ar.
<ets>ra<ium/s</ets> head, chief, prince.]</ety> <def>A common title in
the East for a person in authority, especially the captain of a
ship.</def> <altsp>[Written also <asp>rais</asp> and
<asp>ras</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reis Effendi</ent><br/
\'d8<hw>Reis` Ef*fen"di</hw> <pr>(r?s` ?f*f?n"d?)</pr>. <ety>[See 2d
<er>Reis</er>, and <er>Effendi</er>.]</ety> <def>A title formerly given
to one of the chief Turkish officers of state. He was chancellor of the
empire, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reissner's membrane</ent><br/
<hw>Reiss"ner's mem"brane</hw> <pr>(r?s"n?rz m?m"br?n)</pr>. <ety>[Named
from <person>E. <etsep>Reissner</etsep></person>, A German
anatomist.]</ety> <fld>(Anat.)</fld> <def>The thin membrane which
separates the canal of the cochlea from the vestibular scala in the
internal ear.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reissuable</ent><br/
<hw>Re*is"su*a*ble</hw> <pr>(r?*?sh"?*?*b'l)</pr>, <pos>a.</pos>
<def>Capable of being reissued.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reissue</ent><br/
<hw>Re*is"sue</hw> <pr>(r?*?sh"?)</pr>, <pos>v. t. & i.</pos> <def>To
issue a second time.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reissue</ent><br/
<hw>Re*is"sue</hw>, <pos>n.</pos> <def>A second or repeated
issue.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reit</ent><br/
<hw>Reit</hw> <pr>(r?t)</pr>, <pos>n.</pos> <def>Sedge; seaweed.</def>
<mark>[Obs. or Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reiter</ent><br/
\'d8<hw>Rei"ter</hw> <pr>(r?"t?r)</pr>, <pos>n.</pos> <ety>[G.,
rider.]</ety> <def>A German cavalry soldier of the fourteenth and
fifteenth centuries.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reiterant</ent><br/
<hw>Re*it"er*ant</hw> <pr>(r?-?t"?r-<ait/nt)</pr>, <pos>a.</pos>
<ety>[See <er>Reiterate</er>.]</ety> <def>Reiterating.</def>
<mark>[R.]</mark> <rj><au>Mrs. Browning.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reiterate</ent><br/
<hw>Re*it"er*ate</hw> <pr>(-<amac/t)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Reiterated</conjf>
<pr>(-<amac/`t<ecr/d)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Reiterating</conjf>.]</vmorph> <ety>[Pref. <ets>re-</ets> +
<ets>iterate</ets>: cf. F. <ets>r<eacute/it<eacute/rer</ets>, LL.
<ets>reiterare</ets> to question again.]</ety> <def>To repeat again and
again; to say or do repeatedly; sometimes, to repeat.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That with <qex>reiterated</qex> crimes he might<br/
Heap on himself damnation.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>You never spoke what did become you less<br/
Than this; which to <qex>reiterate</qex> were sin.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To repeat; recapitulate; rehearse.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reiterate</ent><br/
<hw>Re*it"er*ate</hw> <pr>(-?t)</pr>, <pos>a.</pos> <def>Reiterated;
repeated.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reiteratedly</ent><br/
<hw>Re*it"er*a`ted*ly</hw> <pr>(-?`t?d-l?)</pr>, <pos>adv.</pos>
<def>Repeatedly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reiteration</ent><br/
<hw>Re*it`er*a"tion</hw> <pr>(-?"sh?n)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>r<eacute/it<eacute/ration</ets>.]</ety> <def>The act of
reiterating; that which is reiterated.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reiterative</ent><br/
<hw>Re*it"er*a*tive</hw> <pr>(r?-?t"?r-?-t?v)</pr>, <pos>n.</pos>
<sn>1.</sn> <fld>(Gram.)</fld> <def>A word expressing repeated or
reiterated action.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A word formed from another, or used to form another,
by repetition; <as>as, <ex>dillydally</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reiver</ent><br/
<hw>Reiv"er</hw> <pr>(r<emac/v"<etil/r)</pr>, <pos>n.</pos> <def>See
<er>Reaver</er>.</def> <rj><au>Ruskin.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reject</ent><br/
<hw>Re*ject"</hw> <pr>(r?-j?kt")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Rejected</conjf>; <pos>p. pr. &
vb. n.</pos> <conjf>Rejecting</conjf>.]</vmorph> <ety>[L.
<ets>rejectus</ets>, p. p. of <ets>reicere</ets>, <ets>rejicere</ets>;
pref. <ets>re-</ets> re- + <ets>jacere</ets> to throw: cf. F.
<ets>rejeter</ets>, formerly also spelt <ets>rejecter</ets>. See
<er>Jet</er> a shooting forth.]</ety> <sn>1.</sn> <def>To cast from one;
to throw away; to discard.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Therefore all this exercise of hunting . . . the Utopians have
<qex>rejected</qex> to their butchers.</q> <rj><qau>Robynson (More's
Utopia).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Reject</qex> me not from among thy children.</q>
<rj><qau>Wisdom ix. 4.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To refuse to receive or to acknowledge; to decline
haughtily or harshly; to repudiate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That golden scepter which thou didst <qex>reject</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Because thou hast <qex>rejected</qex> knowledge, I will also
<qex>reject</qex> thee, that thou shalt be no priest to me.</q>
<rj><qau>Hos. iv. 6.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To refuse to grant; <as>as, to <ex>reject</ex> a
prayer or request</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To repel; renounce; discard; rebuff; refuse;
decline.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rejectable</ent><br/
<hw>Re*ject"a*ble</hw> <pr>(-?-b'l)</pr>, <pos>a.</pos> <def>Capable of
being, or that ought to be, rejected.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rejectamenta</ent><br/
\'d8<hw>Re*jec`ta*men"ta</hw> <pr>(r?-j?k`t?-m?n"ta)</pr>, <pos>n.
pl.</pos> <ety>[NL., fr. L. <ets>rejectare</ets>, v. intens. fr.
<ets>rejicere</ets>. See <er>Reject</er>.]</ety> <def>Things thrown out
or away; especially, things excreted by a living organism.</def>
<rj><au>J. Fleming.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rejectaneous</ent><br/
<hw>Re`jec*ta"ne*ous</hw> <pr>(r?`j?k-t?"n?-?s)</pr>, <pos>a.</pos>
<ety>[L. <ets>rejectaneus</ets>.]</ety> <def>Not chosen or received;
rejected.</def> <mark>[Obs.]</mark> <ldquo/Profane,
<xex>rejectaneous</xex>, and reprobate people.<rdquo/
<rj><au>Barrow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rejecter</ent><br/
<hw>Re*ject"er</hw> <pr>(r?-j?kt"?r)</pr>, <pos>n.</pos> <def>One who
rejects.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rejection</ent><br/
<hw>Re*jec"tion</hw> <pr>(r?-j?k"sh?n)</pr>, <pos>n.</pos> <ety>[L.
<ets>rejectio</ets>: cf. F. <ets>r<eacute/jection</ets>.]</ety> <def>Act
of rejecting, or state of being rejected.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rejectitious</ent><br/
<hw>Re`jec*ti"tious</hw> <pr>(r?`j?k-t?sh"?s)</pr>, <pos>a.</pos>
<def>Implying or requiring rejection; rejectable.</def>
<rj><au>Cudworth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rejective</ent><br/
<hw>Re*ject"ive</hw> <pr>(r?-j?kt"?v)</pr>, <pos>a.</pos>
<def>Rejecting, or tending to reject.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rejectment</ent><br/
<hw>Re*ject"ment</hw> <pr>(-m<it>e</it>nt)</pr>, <pos>n.</pos> <def>Act
of rejecting; matter rejected, or thrown away.</def>
<rj><au>Eaton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rejoice</ent><br/
<hw>Re*joice"</hw> <pr>(r<esl/*jois")</pr>, <pos>v. i.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Rejoiced</conjf>
<pr>(-joist")</pr>; <pos>p. pr. & vb. n.</pos> <conjf>Rejoicing</conjf>
<pr>(-joi"s?ng)</pr>.]</vmorph> <ety>[OE. <ets>rejoissen</ets>, OF.
<ets>resjouir</ets>, <ets>resjoir</ets>, F. <ets>r<eacute/jouir</ets>;
pref. <ets>re-</ets> re- + OF. <ets>esjouir</ets>, <ets>esjoir</ets>, F.
<ets><eacute/jouir</ets>, to rejoice; pref. <ets>es-</ets> (L.
<ets>ex-</ets>) + OF. <ets>jouir</ets>, <ets>joir</ets>, F.
<ets>jouir</ets>, from L. <ets>gaudere</ets> to rejoice. See
<er>Joy</er>.]</ety> <def>To feel joy; to experience gladness in a high
degree; to have pleasurable satisfaction; to be delighted.</def>
<ldquo/O, <xex>rejoice</xex> beyond a common joy.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I will be glad and <qex>rejoice</qex> in thy mercy.</q>
<rj><qau>Ps. xxxi. 7.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> To delight; joy; exult; triumph.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rejoice</ent><br/
<hw>Re*joice"</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To enjoy.</def>
<mark>[Obs.]</mark> <rj><au>Bp. Peacock.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To give joy to; to make joyful; to
gladden.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I me <qex>rejoysed</qex> of my liberty.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>While she, great saint, <qex>rejoices</qex> heaven.</q>
<rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Were he [Cain] alive, it would <qex>rejoice</qex> his soul to see
what mischief it had made.</q> <rj><qau>Arbuthnot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To please; cheer; exhilarate; delight.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rejoice</ent><br/
<hw>Re*joice"</hw>, <pos>n.</pos> <def>The act of rejoicing.</def>
<rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rejoicement</ent><br/
<hw>Re*joice"ment</hw> <pr>(-m<it>e</it>nt)</pr>, <pos>n.</pos>
<def>Rejoicing.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rejoicer</ent><br/
<hw>Re*joi"cer</hw> <pr>(r?-joi"s?r)</pr>, <pos>n.</pos> <def>One who
rejoices.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rejoicing</ent><br/
<hw>Re*joi"cing</hw> <pr>(-s?ng)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>Joy; gladness; delight.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We should particularly express our <qex>rejoicing</qex> by love
and charity to our neighbors.</q> <rj><qau>R. Nelson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The expression of joy or gladness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The voice of <qex>rejoicing</qex> and salvation is in the
tabernacles of the righteous.</q> <rj><qau>Ps. cxviii.
15.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which causes to rejoice; occasion of
joy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thy testimonies have I taken as an heritage forever, for they are
the <qex>rejoicing</qex> of my heart.</q> <rj><qau>Ps. cxix.
111.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rejoicingly</ent><br/
<hw>Re*joi"cing*ly</hw>, <pos>adv.</pos> <def>With joy or
exultation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rejoin</ent><br/
<hw>Re*join"</hw> <pr>(r?-join")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Rejoined</conjf>
<pr>(-joind")</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Rejoining</conjf>.]</vmorph> <ety>[F. <ets>rejoindre</ets>; pref.
<ets>re-</ets> re- + <ets>joindre</ets> to join. See <er>Join</er>, and
cf. <er>Rejoinder</er>.]</ety> <sn>1.</sn> <def>To join again; to unite
after separation.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To come, or go, again into the presence of; to join
the company of again.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Meet and <qex>rejoin</qex> me, in the pensive grot.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To state in reply; -- followed by an object
clause.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rejoin</ent><br/
<hw>Re*join"</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To answer to a
reply.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>To answer, as the defendant to the
plaintiff's replication.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rejoinder</ent><br/
<hw>Re*join"der</hw> <pr>(-d?r)</pr>, <pos>n.</pos> <ety>[From F.
<ets>rejoindre</ets>, inf., to join again. See <er>Rejoin</er>.]</ety>
<sn>1.</sn> <def>An answer to a reply; or, in general, an answer or
reply.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>The defendant's answer to the
plaintiff's replication.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Reply; answer; replication. See
<er>Reply</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rejoinder</ent><br/
<hw>Re*join"der</hw>, <pos>v. i.</pos> <def>To make a rejoinder.</def>
<mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rejoindure</ent><br/
<hw>Re*join"dure</hw> <pr>(-d?r)</pr>, <pos>n.</pos> <def>Act of joining
again.</def> <mark>[Obs.]</mark> <ldquo/Beguiles our lips of all
<xex>rejoindure</xex><rdquo/ <note>(i.e., kisses).</note>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rejoint</ent><br/
<hw>Re*joint"</hw> <pr>(r<esl/-joint")</pr>, <pos>v. t.</pos>
<sn>1.</sn> <def>To reunite the joints of; to joint anew.</def>
<rj><au>Barrow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Specifically <fld>(Arch.)</fld>, to fill up the
joints of, as stones in buildings when the mortar has been dislodged by
age and the action of the weather.</def> <rj><au>Gwilt.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1213 --></p>

<p><ent>Rejolt</ent><br/
<hw>Re*jolt"</hw> <pr>(r?-j?lt")</pr>, <pos>n.</pos> <def>A reacting
jolt or shock; a rebound or recoil.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>These inward <qex>rejolts</qex> and recoilings of the mind.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rejolt</ent><br/
<hw>Re*jolt"</hw>, <pos>v. t.</pos> <def>To jolt or shake again.</def>
<rj><au>Locke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rejourn</ent><br/
<hw>Re*journ"</hw> <pr>(r?-j?rn")</pr>, <pos>v. t.</pos> <ety>[Cf. F.
<ets>r<eacute/ajourner</ets>. See <er>Adjourn</er>.]</ety> <def>To
adjourn; to put off.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rejournment</ent><br/
<hw>Re*journ"ment</hw> <pr>(-m<eit/nt)</pr>, <pos>n.</pos>
<def>Adjournment.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rejudge</ent><br/
<hw>Re*judge"</hw> <pr>(r?-j?j")</pr>, <pos>v. t.</pos> <def>To judge
again; to reexamine; to review; to call to a new trial and
decision.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Rejudge</qex> his acts, and dignify disgrace.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rejuvenate</ent><br/
<hw>Re*ju"ve*nate</hw> <pr>(r?-j?"v?-n?t)</pr>, <pos>v. t.</pos>
<ety>[Pref. <ets>re-</ets> re- + L. <ets>juventis</ets> young,
youthful.]</ety> <def>To render young again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rejuvenated</ent><br/
<hw>Re*ju"ve*na`ted</hw> <pr>(?)</pr>, <pos>p. a.</pos> <mord>from
<er>Rejuvenate</er>.</mord> <sn>1.</sn> <def>Rendered young again;
<as>as, <ex>rejuvenated</ex> life</as>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <fld>(Phys. Geog.)</fld> <sd>(a)</sd> <def>Stimulated by
uplift to renewed erosive activity; -- said of streams.</def>
<sd>(b)</sd> <def>Developed with steep slopes inside a district
previously worn down nearly to base level; -- said of topography, or
features of topography, as valleys, hills, etc.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Rejuvenation</ent><br/
<hw>Re*ju`ve*na"tion</hw> <pr>(-n?"sh?n)</pr>, <pos>n.</pos>
<def>Rejuvenescence.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rejuvenescence</ent><br/
<hw>Re*ju`ve*nes"cence</hw> <pr>(-n?s"s<it>e</it>ns)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>A renewing of youth; the state of being or growing
young again.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>A method of cell formation in
which the entire protoplasm of an old cell escapes by rupture of the
cell wall, and then develops a new cell wall. It is seen sometimes in
the formation of zoospores, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rejuvenescency</ent><br/
<hw>Re*ju`ve*nes"cen*cy</hw> <pr>(-s<eit/n-s?)</pr>, <pos>n.</pos>
<def>Rejuvenescence.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rejuvenescent</ent><br/
<hw>Re*ju`ve*nes"cent</hw> <pr>(-s<it>e</it>nt)</pr>, <pos>a.</pos>
<def>Becoming, or causing to become, rejuvenated;
rejuvenating.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rejuvenize</ent><br/
<hw>Re*ju`ve*nize</hw> <pr>(r?-j?"v?-n?z)</pr>, <pos>v. t.</pos> <def>To
rejuvenate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rekindle</ent><br/
<hw>Re*kin"dle</hw> <pr>(r?-k?n"d'l)</pr>, <pos>v. t. & i.</pos> <def>To
kindle again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rekne</ent><br/
<hw>Rek"ne</hw> <pr>(r?k"n<it>e</it>)</pr>, <pos>v. t.</pos> <def>To
reckon.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relade</ent><br/
<hw>Re*lade"</hw> <pr>(r<emac/*l<amac/d")</pr>, <pos>v. t.</pos> <def>To
lade or load again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relaid</ent><br/
<hw>Re*laid"</hw> <pr>(r<emac/*l<amac/d")</pr>, <def><pos>imp. & p.
p.</pos> of <er>Relay</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relais</ent><br/
\'d8<hw>Re*lais"</hw> <pr>(r<eit/*l<asl/")</pr>, <pos>n.</pos> <ety>[F.
See <er>Relay</er>, <pos>n.</pos>]</ety> <fld>(Fort.)</fld> <def>A
narrow space between the foot of the rampart and the scarp of the ditch,
serving to receive the earth that may crumble off or be washed down, and
prevent its falling into the ditch.</def> <rj><au>Wilhelm.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reland</ent><br/
<hw>Re*land"</hw> <pr>(r?-l?nd")</pr>, <pos>v. t.</pos> <def>To land
again; to put on land, as that which had been shipped or
embarked.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reland</ent><br/
<hw>Re*land"</hw>, <pos>v. i.</pos> <def>To go on shore after having
embarked; to land again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relapse</ent><br/
<hw>Re*lapse"</hw> <pr>(r?-l?ps")</pr>, <pos>v. i.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Relapsed</conjf>
<pr>(-l?pst")</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Relapsing</conjf>.]</vmorph> <ety>[L. <ets>relapsus</ets>, p. p.
of <ets>relabi</ets> to slip back, to relapse; pref. <ets>re-</ets> re-
+ <ets>labi</ets> to fall, slip, slide. See <er>Lapse</er>.]</ety>
<sn>1.</sn> <def>To slip or slide back, in a literal sense; to turn
back.</def> <mark>[Obs.]</mark> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To slide or turn back into a former state or
practice; to fall back from some condition attained; -- generally in a
bad sense, as from a state of convalescence or amended condition;
<as>as, to <ex>relapse</ex> into a stupor, into vice, or into
barbarism</as>; -- sometimes in a good sense; <as>as, to
<ex>relapse</ex> into slumber after being disturbed</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That task performed, [preachers] <qex>relapse</qex> into
themselves.</q> <rj><qau>Cowper.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Theol.)</fld> <def>To fall from Christian faith
into paganism, heresy, or unbelief; to backslide.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They enter into the justified state, and so continue all along,
unless they <qex>relapse</qex>.</q> <rj><qau>Waterland.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relapse</ent><br/
<hw>Re*lapse"</hw>, <pos>n.</pos> <ety>[For sense 2 cf. F.
<ets>relaps</ets>. See <er>Relapse</er>, <pos>v.</pos>]</ety>
<sn>1.</sn> <def>A sliding or falling back, especially into a former bad
state, either of body or morals; backsliding; the state of having fallen
back.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Alas! from what high hope to what <qex>relapse</qex><br/
Unlooked for are we fallen!</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who has relapsed, or fallen back, into error; a
backslider; specifically, one who, after recanting error, returns to it
again.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relapser</ent><br/
<hw>Re*laps"er</hw> <pr>(-l?ps"?r)</pr>, <pos>n.</pos> <def>One who
relapses.</def> <rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relapsing</ent><br/
<hw>Re*laps"ing</hw>, <pos>a.</pos> <def>Marked by a relapse; falling
back; tending to return to a former worse state.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Relapsing fever</b></col> <fld>(Med.)</fld>, <cd>an
acute, epidemic, contagious fever, which prevails also endemically in
Ireland, Russia, and some other regions. It is marked by one or two
remissions of the fever, by articular and muscular pains, and by the
presence, during the paroxism of spiral bacterium
(<spn>Spirochaete</spn>) in the blood. It is not usually fatal. Called
also <altname>famine fever</altname>, and <altname>recurring
fever</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relate</ent><br/
<hw>Re*late"</hw> <pr>(r?-l?t")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Related</conjf>; <pos>p. pr. &
vb. n.</pos> <conjf>Relating</conjf>.]</vmorph> <ety>[F.
<ets>relater</ets> to recount, LL. <ets>relatare</ets>, fr. L.
<ets>relatus</ets>, used as p. p. of <ets>referre</ets>. See
<er>Elate</er>, and cf. <er>Refer</er>.]</ety> <sn>1.</sn> <def>To bring
back; to restore.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q> Abate your zealous haste, till morrow next again<br/
Both light of heaven and strength of men <qex>relate</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To refer; to ascribe, as to a source.</def>
<mark>[Obs. or R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To recount; to narrate; to tell over.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This heavy act with heavy heart <qex>relate</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To ally by connection or kindred.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To relate one's self</b></col>, <cd>to vent thoughts in
words.</cd> <mark>[R.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To tell; recite; narrate; recount; rehearse;
report; detail; describe.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relate</ent><br/
<hw>Re*late"</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To stand in some
relation; to have bearing or concern; to pertain; to refer; -- with
<xex>to</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>All negative or privative words <qex>relate</qex> positive
ideas.</q> <rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To make reference; to take account.</def> <mark>[R.
& Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Reckoning by the years of their own consecration without
<qex>relating</qex> to any imperial account.</q>
<rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Related</ent><br/
<hw>Re*lat"ed</hw> <pr>(-l?t"?d)</pr>, <pos>p. p. & a.</pos> <sn>1.</sn>
<def>Allied by kindred; connected by blood or alliance, particularly by
consanguinity; <as>as, persons <ex>related</ex> in the first or second
degree</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Standing in relation or connection; <as>as, the
electric and magnetic forcec are closely
<ex>related</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Narrated; told.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Mus.)</fld> <def>Same as <er>Relative</er>,
4.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relatedness</ent><br/
<hw>Re*lat"ed*ness</hw>, <pos>n.</pos> <def>The state or condition of
being related; relationship; affinity.</def> <mark>[R.]</mark>
<rj><au>Emerson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relater</ent><br/
<hw>Re*lat"er</hw> <pr>(-?r)</pr>, <pos>n.</pos> <def>One who relates or
narrates.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relation</ent><br/
<hw>Re*la"tion</hw> <pr>(r?-l?"sh?n)</pr>, <pos>n.</pos> <ety>[F.
<ets>relation</ets>, L. <ets>relatio</ets>. See <er>Relate</er>.]</ety>
<sn>1.</sn> <def>The act of relating or telling; also, that which is
related; recital; account; narration; narrative; <as>as, the
<ex>relation</ex> of historical events</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>poet's <qex>relation</qex> doth well figure them.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The state of being related or of referring; what is
apprehended as appertaining to a being or quality, by considering it in
its bearing upon something else; relative quality or condition; the
being such and such with regard or respect to some other thing;
connection; <as>as, the <ex>relation</ex> of experience to knowledge;
the <ex>relation</ex> of master to servant.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Any sort of connection which is perceived or imagined between two
or more things, or any comparison which is made by the mind, is a
<qex>relation</qex>.</q> <rj><qau>I. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Reference; respect; regard.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I have been importuned to make some observations on this art in
<qex>relation</qex> to its agreement with poetry.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Connection by consanguinity or affinity; kinship;
relationship; <as>as, the <ex>relation</ex> of parents and
children</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Relations</qex> dear, and all the charities<br/
Of father, son, and brother, first were known.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A person connected by cosanguinity or affinity; a
relative; a kinsman or kinswoman.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>For me . . . my <qex>relation</qex> does not care a rush.</q>
<rj><qau>Ld. Lytton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Law)</fld> <sd>(a)</sd> <def>The carrying back, and
giving effect or operation to, an act or proceeding frrom some previous
date or time, by a sort of fiction, as if it had happened or begun at
that time. In such case the act is said to take effect by
<xex>relation</xex>.</def> <sd>(b)</sd> <def>The act of a relator at
whose instance a suit is begun.</def> <rj><au>Wharton.
Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Recital; rehearsal; narration; account;
narrative; tale; detail; description; kindred; kinship; consanguinity;
affinity; kinsman; kinswoman.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relational</ent><br/
<hw>Re*la"tion*al</hw> <pr>(r?-l?"sh?n-<it>a</it>l)</pr>, <pos>a.</pos>
<sn>1.</sn> <def>Having relation or kindred; related.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We might be tempted to take these two nations for <qex>relational
stems</qex>.</q> <rj><qau>Tooke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Indicating or specifying some relation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Relational</qex> words, as prepositions, auxiliaries,
etc.</q> <rj><qau>R. Morris.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relationist</ent><br/
<hw>Re*la"tion*ist</hw>, <pos>n.</pos> <def>A relative; a
relation.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relationship</ent><br/
<hw>Re*la"tion*ship</hw>, <pos>n.</pos> <def>The state of being related
by kindred, affinity, or other alliance.</def>
<rj><au>Mason.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relative</ent><br/
<hw>Rel"a*tive</hw> <pr>(r?l"?-t?v)</pr>, <pos>a.</pos> <ety>[F.
<ets>relatif</ets>, L. <ets>relativus</ets>. See <er>Relate</er>.]</ety>
<sn>1.</sn> <def>Having relation or reference; referring; respecting;
standing in connection; pertaining; <as>as, arguments not
<ex>relative</ex> to the subject</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I'll have grounds<br/
More <qex>relative</qex> than this.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Arising from relation; resulting from connection
with, or reference to, something else; not absolute.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Every thing sustains both an absolute and a <qex>relative</qex>
capacity: an absolute, as it is such a thing, endued with such a nature;
and a <qex>relative</qex>, as it is a part of the universe, and so
stands in such a relations to the whole.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Gram.)</fld> <def>Indicating or expressing
relation; refering to an antecedent; <as>as, a <ex>relative</ex>
pronoun</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Mus.)</fld> <def>Characterizing or pertaining to
chords and keys, which, by reason of the identify of some of their
tones, admit of a natural transition from one to the other.</def>
<rj><au>Moore (Encyc. of Music).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Relative clause</b></col> <fld>(Gram.)</fld>, <cd>a
clause introduced by a relative pronoun.</cd> -- <col><b>Relative
term</b></col>, <cd>a term which implies relation to, as guardian to
ward, matter to servant, husband to wife. Cf.
<er>Correlative</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relative</ent><br/
<hw>Rel"a*tive</hw>, <pos>n.</pos> <def>One who, or that which, relates
to, or is considered in its relation to, something else; a relative
object or term; one of two object or term; one of two objects directly
connected by any relation.</def> Specifically: <sd>(a)</sd> <def>A
person connected by blood or affinity; strictly, one allied by blood; a
relation; a kinsman or kinswoman.</def> <ldquo/Confining our care . . .
to ourselves and <xex>relatives</xex>.<rdquo/ <au>Bp. Fell.</au>
<sd>(b)</sd> <fld>(Gram.)</fld> <def>A relative pronoun; a word which
relates to, or represents, another word or phrase, called its
<xex>antecedent</xex>; <as>as, the <ex>relatives</ex> <ldquo/who<rdquo/,
<ldquo/which<rdquo/, <ldquo/that<rdquo/</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relatively</ent><br/
<hw>Rel"a*tive*ly</hw>, <pos>adv.</pos> <def>In a relative manner; in
relation or respect to something else; not absolutely.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Consider the absolute affections of any being as it is in itself,
before you consider it <qex>relatively</qex>.</q> <rj><qau>I.
Watts.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relativeness</ent><br/
<hw>Rel"a*tive*ness</hw>, <pos>n.</pos> <def>The state of being
relative, or having relation; relativity.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relativistic</ent><br/
<hw>Rel`a*tiv*ist"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>of, pertaining to, or in conformity with the <er>theory of
relativity</er>; <as>as, the <ex>relativistic</ex> increase of mass with
velocity</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>moving at a speed sufficiently high that the changes
of mass or time dilation predicted by the theory of relativity may be
observed; moving at a significant fraction of the speed of light;
<as>as, <ex>relativistic</ex> electrons</as>.</def>br/
[<source>PJC</source>]</p>

<p><ent>Relativistic mass equation</ent><br/
<hw>Rel`a*tiv*ist"ic mass e*qua"tion</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(physics)</fld> <def>an equation expressing the mass of an object
as a function of its velocity: as the velocity <it>v</it> of an object
increases, its mass <it>m</it> increases from its rest mass
<it>m</it><sub>0</sub> according to the equation: <mathex>m =
m<sub>0</sub>/<root>1 - v<exp>2</exp>/c<exp>2</exp></root></mathex>

where <it>c</it> is the speed of light in a vacuum. If the speed of an
object were to become equal to that of light, it can be seen that the
mass would be infinite, from which it follows that nothing can
accelerate up to or beyond the speed of light.</def><br/
[<source>PJC</source>]</p>

<p><note><hand/ The theoretical possibility that there are particles
which always move faster than light cannot at present be disproved and
is not denied by this equation; in such a case, the <ex>relativistic
mass equation</ex> asserts that such particles can never decelerate to
or below the speed of light. Such hypothetical particles are referred to
as <col><b>tachyons</b></col>.</note><br/
[<source>PJC</source>]</p>

<p><ent>relativity</ent><br/
<hw>rel`a*tiv"i*ty</hw> <pr>(-t?v"?-t?)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>The state of being relative; <as>as, the <ex>relativity</ex> of a
subject</as>.</def> <rj><au>Coleridge.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One of two theories (also called
<altname><ecol><b>theory of relativity</b></ecol></altname>) proposed by
<person>Albert Einstein</person>, the <stype>special theory of
relativity</stype>, or the <stype>general theory of relativity</stype>.
The <stype>special theory of relativity</stype> or <stype>special
relativity</stype> is based on the proposition that the speed of light
is a constant no matter how observed, and is independent of the motion
of the observer. From this follows several principles, such as the
increase of mass with velocity (which has been confirmed: see
<er>relativistic mass equation</er>) and the impossibility of
acceleration to a speed greater than that of light; the equivalence of
mass and energy, expressed by the famous equation <mathex>E =
mc<exp>2</exp></mathex>; and time dilation, which is the apparent
slowing of a clock in a system, as observed by an observer in a system
moving relative to the clock. The <stype>general theory of
relativity</stype> is based on the proposition that there is no physical
difference between gravitational force and the force produced by
acceleration. From this follow several results, of which the bending of
light rays in a gravitational field and the equivalence of the inertial
and gravitational masses have been verified. The possible existence of
<er>black holes</er> (believed by many astronomers to have been
adequately proven) is another consequence of the theory.</def><br/
[<source>PJC</source>]</p>

<p><ent>Relator</ent><br/
<hw>Re*lat"or</hw> <pr>(r?-l?t"?r)</pr>, <pos>n.</pos> <ety>[ L.: cf. F.
<ets>relateur</ets>. See <er>Relate</er>.]</ety> <sn>1.</sn> <def>One
who relates; a relater.</def> <ldquo/The several <xex>relators</xex> of
this history.<rdquo/ <rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>A private person at whose relation,
or in whose behalf, the attorney-general allows an information in the
nature of a <xex>quo warranto</xex> to be filed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relatrix</ent><br/
<hw>Re*lat"rix</hw> <pr>(-r?ks)</pr>, <pos>n.</pos> <ety>[L.]</ety>
<fld>(Law)</fld> <def>A female relator.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relax</ent><br/
<hw>Re*lax"</hw> <pr>(r?-l?ks")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Relaxed</conjf>
<pr>(-l?kst")</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Relaxing</conjf>.]</vmorph> <ety>[L. <ets>relaxare</ets>; pref.
<ets>re-</ets> re- + <ets>laxare</ets> to loose, to slacken, from
<ets>laxus</ets> loose. See <er>Lax</er>, and cf. <er>Relay</er>,
<pos>n.</pos>, <er>Release</er>.]</ety> <sn>1.</sn> <def>To make lax or
loose; to make less close, firm, rigid, tense, or the like; to slacken;
to loosen; to open; <as>as, to <ex>relax</ex> a rope or cord; to
<ex>relax</ex> the muscles or sinews.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Horror . . . all his joints <qex>relaxed</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Nor served it to <qex>relax</qex> their serried files.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To make less severe or rigorous; to abate the
stringency of; to remit in respect to strenuousness, earnestness, or
effort; <as>as, to <ex>relax</ex> discipline; to <ex>relax</ex> one's
attention or endeavors.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>The statute of mortmain was at several times <qex>relaxed</qex> by
the legislature.</q> <rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Hence, to relieve from attention or effort; to ease;
to recreate; to divert; <as>as, amusement <ex>relaxes</ex> the
mind</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To relieve from constipation; to loosen; to open;
<as>as, an aperient <ex>relaxes</ex> the bowels</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To slacken; loosen; loose; remit; abate;
mitigate; ease; unbend; divert.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relax</ent><br/
<hw>Re*lax"</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To become lax, weak,
or loose; <as>as, to let one's grasp <ex>relax</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His knees <qex>relax</qex> with toil.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To abate in severity; to become less
rigorous.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In others she <qex>relaxed</qex> again,<br/
And governed with a looser rein.</q> <rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To remit attention or effort; to become less
diligent; to unbend; <as>as, to <ex>relax</ex> in study</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relax</ent><br/
<hw>Re*lax"</hw>, <pos>n.</pos> <def>Relaxation.</def>
<mark>[Obs.]</mark> <rj><au>Feltham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relax</ent><br/
<hw>Re**lax"</hw>, <pos>a.</pos> <def>Relaxed; lax; hence, remiss;
careless.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relaxable</ent><br/
<hw>Re*lax"a*ble</hw> <pr>(-?-b'l)</pr>, <pos>a.</pos> <def>Capable of
being relaxed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relaxant</ent><br/
<hw>Re*lax"ant</hw> <pr>(r?-l?ks"<it>a</it>nt)</pr>, <pos>n.</pos>
<ety>[L. <ets>relaxans</ets>, p. pr. of <ets>relaxare</ets>.]</ety>
<fld>(Med.)</fld> <def>A medicine that relaxes; a laxative.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relaxation</ent><br/
<hw>Re`lax*a"tion</hw> <pr>(r?`l?ks-?"sh?n;277)</pr>, <pos>n.</pos>
<ety>[L. <ets>relaxatio</ets>; cf. F. <ets>relaxation</ets>.]</ety>
<sn>1.</sn> <def>The act or process of relaxing, or the state of being
relaxed; <as>as, <ex>relaxation</ex> of the muscles; <ex>relaxation</ex>
of a law.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Remission from attention and effort; indulgence in
recreation, diversion, or amusement.</def> <ldquo/Hours of careless
<xex>relaxation</xex>.<rdquo/ <rj><au>Macaulay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relaxative</ent><br/
<hw>Re*lax"a*tive</hw> <pr>(r?-l?ks"?-t?v)</pr>, <pos>a.</pos>
<def>Having the quality of relaxing; laxative.</def> --
<def2><pos>n.</pos> <def>A relaxant.</def></def2> <rj><au>B.
Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relay</ent><br/
<hw>Re*lay"</hw> <pr>(r?-l?")</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Relaid</conjf> <pr>(-l?d)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Relaying</conjf>.]</vmorph> <ety>[Pref. <ets>re-</ets> +
<ets>lay</ets>, v.]</ety> <def>To lay again; to lay a second time;
<as>as, to <ex>relay</ex> a pavement</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relay</ent><br/
<hw>Re*lay"</hw> <pr>(r?-l?")</pr>, <pos>n.</pos> <ety>[F.
<ets>relais</ets> (cf. OF. <ets>relais</ets> relaxation, discontinuance,
It. <ets>rilascio</ets> release, relief, <ets>rilasso</ets> relay), fr.
OF. <ets>relaissier</ets> to abandon, release, fr. L.
<ets>relaxare</ets>. See <er>Relax</er>.]</ety> <sn>1.</sn> <def>A
supply of anything arranged beforehand for affording relief from time to
time, or at successive stages; provision for successive relief.</def>
Specifically: <sd>(a)</sd> <def>A supply of horses placced at stations
to be in readiness to relieve others, so that a trveler may proceed
without delay.</def> <sd>(b)</sd> <def>A supply of hunting dogs or
horses kept in readiness at certain places to relive the tired dogs or
horses, and to continue the pursuit of the game if it comes that
way.</def> <sd>(c)</sd> <def>A number of men who relieve others in
carrying on some work.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Elec.)</fld> <def>In various forms of telegraphic
apparatus, a magnet which receives the circuit current, and is caused by
it to bring into into action the power of a local battery for performing
the work of making the record; also, a similar device by which the
current in one circuit is made to open or close another circuit in which
a current is passing.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Relay battery</b></col> <fld>(Elec.)</fld>, <cd>the local
battery which is brought into use by the action of the relay magnet, or
relay.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relay</ent><br/
<hw>Re*lay"</hw>, <pos>a.</pos> <fld>(Mach.)</fld> <def>Relating to, or
having the characteristics of, an auxiliary apparatus put into action by
a feeble force but itself capable of exerting greater force, used to
control a comparatively powerful machine or appliance.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Relay cylinder</ent><br/
<hw>Relay cylinder</hw>. <def>In a variable expansion central-valve
engine, a small auxiliary engine for automatically adjusting the steam
distribution to the load on the main engine.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Relay governor</ent><br/
<hw>Relay governor</hw>. <def>A speed regulator, as a water-wheel
governor, embodying the relay principle.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Relbun</ent><br/
<hw>Rel"bun</hw> <pr>(r?l"b?n)</pr>, <pos>n.</pos> <def>The roots of the
Chilian plant <spn>Calceolaria arachnoidea</spn>, -- used for dyeing
crimson.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Releasable</ent><br/
<hw>Re*leas"a*ble</hw> <pr>(r?-l?s"?-b'l)</pr>, <pos>a.</pos> <def>That
may be released.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Release</ent><br/
<hw>Re*lease"</hw> <pr>(r?-l?s")</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>re</ets> + <ets>lease</ets> to let.]</ety> <def>To lease again; to
grant a new lease of; to let back.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Release</ent><br/
<hw>Re*lease"</hw> <pr>(r?-l?s")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Released</conjf>
<pr>(r?*l?st")</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Releasing</conjf>.]</vmorph> <ety>[OE. <ets>relessen</ets>, OF.
<ets>relassier</ets>, to release, to let free. See <er>Relay</er>,
<pos>n.</pos>, <er>Relax</er>, and cf. <er>Release</er> to lease
again.]</ety> <sn>1.</sn> <def>To let loose again; to set free from
restraint, confinement, or servitude; to give liberty to, or to set at
liberty; to let go.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Now at that feast he <qex>released</qex> unto them one prisoner,
whomsoever they desired.</q> <rj><qau>Mark xv. 6.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To relieve from something that confines, burdens, or
oppresses, as from pain, trouble, obligation, penalty.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Law)</fld> <def>To let go, as a legal claim; to
discharge or relinquish a right to, as lands or tenements, by conveying
to another who has some right or estate in possession, as when the
person in remainder releases his right to the tenant in possession; to
quit.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To loosen; to relax; to remove the obligation of;
<as>as, to <ex>release</ex> an ordinance</as>.</def> <mark>[Obs.]</mark>
<rj><au>Hooker.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A sacred vow that none should aye <qex>release</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To free; liberate; loose; discharge; disengage;
extricate; let go; quit; acquit.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Release</ent><br/
<hw>Re*lease"</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act of letting
loose or freeing, or the state of being let loose or freed; liberation
or discharge from restraint of any kind, as from confinement or
bondage.</def> <ldquo/Who boast'st <xex>release</xex> from hell.<rdquo/
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Relief from care, pain, or any burden.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Discharge from obligation or responsibility, as from
debt, penalty, or claim of any kind; acquittance.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Law)</fld> <def>A giving up or relinquishment of
some right or claim; a conveyance of a man's right in lands or tenements
to another who has some estate in possession; a quitclaim.</def>
<rj><au>Blackstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Steam Engine)</fld> <def>The act of opening the
exhaust port to allow the steam to escape.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Mach.)</fld> <def>A device adapted to hold or
release a device or mechanism as required;</def>
<specif>specif.</specif>: <fld>(Elec.)</fld> <def>A catch on a
motor-starting rheostat, which automatically releases the rheostat arm
and so stops the motor in case of a break in the field circuit; also,
the catch on an electromagnetic circuit breaker for a motor, which acts
in case of an overload.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>7.</sn> <fld>(Phon.)</fld> <def>The act or manner of ending a
sound.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>8.</sn> <fld>(Railroads)</fld> <def>In the block-signaling
system, a printed card conveying information and instructions to be used
at intermediate sidings without telegraphic stations.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><cs><col><b>Lease and release</b></col>. <fld>(Law)</fld> <cd>See
under <er>Lease</er>.</cd> -- <col><b>Out of release</b></col>,
<cd>without cessation.</cd> <mark>[Obs.]</mark>
<au>Chaucer.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Liberation; freedom; discharge. See
<er>Death</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Releasee</ent><br/
<hw>Re*leas`ee"</hw> <pr>(-?")</pr>, <pos>n.</pos> <def>One to whom a
release is given.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Releasement</ent><br/
<hw>Re*lease"ment</hw> <pr>(r?-l?s"m<it>e</it>nt)</pr>, <pos>n.</pos>
<def>The act of releasing, as from confinement or obligation.</def>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Releaser</ent><br/
<hw>Re*leas"er</hw> <pr>(-?r)</pr>, <pos>n.</pos> <def>One who releases,
or sets free.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Releasor</ent><br/
<hw>Re*leas"or</hw> <pr>(-?r)</pr>, <pos>n.</pos> <def>One by whom a
release is given.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relegate</ent><br/
<hw>Rel"e*gate</hw> <pr>(r?l"?-g?t)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Relegated</conjf>
<pr>(-g?`t?d)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Relegating</conjf>.]</vmorph> <ety>[L. <ets>relegatus</ets>, p.
p. of <ets>relegare</ets>; pref. <ets>re-</ets> re- + <ets>legare</ets>
to send with a commission or charge. See <er>Legate</er>.]</ety> <def>To
remove, usually to an inferior position; to consign; to transfer;
specifically, to send into exile; to banish.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It [the Latin language] was <qex>relegated</qex> into the study of
the scholar.</q> <rj><qau>Milman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relegation</ent><br/
<hw>Rel`e*ga"tion</hw> <pr>(-g?"sh?n)</pr>, <pos>n.</pos> <ety>[L.
<ets>relegatio</ets>: cf. F. <ets>rel<eacute/gation</ets>.]</ety>
<def>The act of relegating, or the state of being relegated; removal;
banishment; exile.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relent</ent><br/
<hw>Re*lent"</hw> <pr>(r?-l?nt")</pr>, <pos>v. i.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Relented</conjf>; <pos>p. pr. &
vb. n.</pos> <conjf>Relenting</conjf>.]</vmorph> <ety>[F.
<ets>ralentir</ets>, fr. L. pref. <ets>re-</ets> re- + <ets>ad</ets> to
+ <ets>lentus</ets> pliant, flexible, slow. See <er>Lithe</er>.]</ety>
<sn>1.</sn> <def>To become less rigid or hard; to yield; to dissolve; to
melt; to deliquesce.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He stirred the coals till <qex>relente</qex> gan<br/
The wax again the fire.</q> <rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>[Salt of tartar] placed in a cellar will . . . begin to
<qex>relent</qex>.</q> <rj><qau>Boyle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>When opening buds salute the welcome day,<br/
And earth, <qex>relenting</qex>, feels the genial ray.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To become less severe or intense; to become less
hard, harsh, cruel, or the like; to soften in temper; to become more
mild and tender; to feel compassion.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Can you . . . behold<br/
My sighs and tears, and will not once <qex>relent</qex>?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relent</ent><br/
<hw>Re*lent"</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To slacken; to
abate.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>And oftentimes he would <qex>relent</qex> his pace.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To soften; to dissolve.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To mollify ; to cause to be less harsh or
severe.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1214 --></p>

<p><ent>Relent</ent><br/
<hw>Re*lent"</hw> <pr>(r?-l?nt")</pr>, <pos>n.</pos> <def>Stay; stop;
delay.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Nor rested till she came without <qex>relent</qex><br/
Unto the land of Amazons.</q> <rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relentless</ent><br/
<hw>Re*lent"less</hw>, <pos>a.</pos> <def>Unmoved by appeals for
sympathy or forgiveness; insensible to the distresses of others;
destitute of tenderness; unrelenting; unyielding; unpitying; <as>as, a
prey to <ex>relentless</ex> despotism</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>For this the avenging power employs his darts, . . .<br/
Thus will persist, <qex>relentless</qex> in his ire.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Re*lent"less*ly</wf>, <pos>adv.</pos> --
<wf>Re*lent"less*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relentment</ent><br/
<hw>Re*lent"ment</hw> <pr>(-m<eit/nt)</pr>, <pos>n.</pos> <def>The act
or process of relenting; the state of having relented.</def> <rj><au>Sir
T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relesse</ent><br/
<hw>Re*lesse"</hw> <pr>(r?-l?s")</pr>, <pos>v. t.</pos> <def>To
release.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relessee</ent><br/
<hw>Re`les*see"</hw> <pr>(r?`l?s-s?")</pr>, <pos>n.</pos> <def>See
<er>Releasee</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relessor</ent><br/
<hw>Re`les*sor"</hw> <pr>(-s?r")</pr>, <pos>n.</pos> <def>See
<er>Releasor</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Re-let</ent><br/
<hw>Re-let"</hw> <pr>(r?-l?t")</pr>, <pos>v. t.</pos> <def>To let anew,
as a house.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relevancy</ent><br/
<ent>Relevance</ent><br/
<mhw>{ <hw>Rel"e*vance</hw> <pr>(r?l"?*v<it>a</it>ns)</pr>,
<hw>Rel"e*van*cy</hw> <pr>(-v<it>a</it>n*s?)</pr>, }</mhw> <pos>n.</pos>
<sn>1.</sn> <def>The quality or state of being relevant; pertinency;
applicability.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Its answer little meaning, little <qex>relevancy</qex> bore.</q>
<rj><qau>Poe.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Scots Law)</fld> <def>Sufficiency to infer the
conclusion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relevant</ent><br/
<hw>Rel"e*vant</hw> <pr>(-v<it>a</it>nt)</pr>, <pos>a.</pos> <ety>[F.
<ets>relevant</ets>, p. pr. of <ets>relever</ets> to raise again, to
relieve. See <er>Relieve</er>.]</ety> <sn>1.</sn> <def>Relieving;
lending aid or support.</def> <mark>[R.]</mark>
<rj><au>Pownall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Bearing upon, or properly applying to, the case in
hand; pertinent; applicable.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Close and <qex>relevant</qex> arguments have very little hold on
the passions.</q> <rj><qau>Sydney Smith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Scots Law)</fld> <def>Sufficient to support the
cause.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relevantly</ent><br/
<hw>Rel"e*vant*ly</hw>, <pos>adv.</pos> <def>In a relevant
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relevation</ent><br/
<hw>Rel`e*va"tion</hw> <pr>(-v?"sh?n)</pr>, <pos>n.</pos> <ety>[L.
<ets>relevatio</ets>, fr. <ets>relevare</ets>. See
<er>Relieve</er>.]</ety> <def>A raising or lifting up.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reliability</ent><br/
<hw>Re*li`a*bil"i*ty</hw> <pr>(r?-l?`?-b?l"?-t?)</pr>, <pos>n.</pos>
<def>The state or quality of being reliable; reliableness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reliable</ent><br/
<hw>Re*li"a*ble</hw> <pr>(r?-l?"?-b'l)</pr>, <pos>a.</pos> <def>Suitable
or fit to be relied on; worthy of dependance or reliance;
trustworthy.</def> <ldquo/A <xex>reliable</xex> witness to the truth of
the miracles.<rdquo/ <rj><au>A. Norton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The best means, and most <qex>reliable</qex> pledge, of a higher
object.</q> <rj><qau>Coleridge.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>According to General Livingston's humorous account, his own
village of Elizabethtown was not much more <qex>reliable</qex>, being
peopled in those agitated times by <ldquo/unknown, unrecommended
strangers, guilty-looking Tories, and very knavish Whigs.<rdquo/</q>
<rj><qau>W. Irving.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Some authors take exception to this word, maintaining
that it is unnecessary, and irregular in formation. It is, however,
sanctioned by the practice of many careful writers as a most convenient
substitute for the phrase <xex>to be relied upon</xex>, and a useful
synonym for <xex>trustworthy</xex>, which is by preference applied to
persons, as <xex>reliable</xex> is to things, such as an account,
statement, or the like. The objection that adjectives derived from
neuter verbs do not admit of a passive sense is met by the citation of
<xex>laughable</xex>, worthy of being laughed <xex>at</xex>, from the
neuter verb <xex>to laugh</xex>; <xex>available</xex>, fit or able to be
availed <xex>of</xex>, from the neuter verb <xex>to avail</xex>;
<xex>dispensable</xex>, capable of being dispensed <xex>with</xex>, from
the neuter verb <xex>to dispense</xex>. Other examples might be
added.</note><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Re*li"a*ble*ness</wf>, <pos>n.</pos> --
<wf>Re*li"a*bly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reliance</ent><br/
<hw>Re*li"ance</hw> <pr>(-<it>a</it>ns)</pr>, <pos>n.</pos> <ety>[From
<er>Rely</er>.]</ety> <sn>1.</sn> <def>The act of relying, or the
condition or quality of being reliant; dependence; confidence; trust;
repose of mind upon what is deemed sufficient support or
authority.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In <qex>reliance</qex> on promises which proved to be of very
little value.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Anything on which to rely; dependence; ground of
trust; <as>as, the boat was a poor <ex>reliance</ex></as>.</def>
<rj><au>Richardson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reliant</ent><br/
<hw>Re*li"ant</hw> <pr>(-<it>a</it>nt)</pr>, <pos>a.</pos> <def>Having,
or characterized by, reliance; confident; trusting.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relic</ent><br/
<hw>Rel"ic</hw> <pr>(r?l"?k)</pr>, <pos>n.</pos> <ety>[F.
<ets>relique</ets>, from L. <ets>reliquiae</ets>, pl., akin to
<ets>relinquere</ets> to leave behind. See <er>Relinquish</er>.]</ety>
<altsp>[Formerly written also <asp>relique</asp>.]</altsp> <sn>1.</sn>
<def>That which remains; that which is left after loss or decay; a
remaining portion; a remnant.</def> <rj><au>Chaucer.
Wyclif.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>relics</qex> of lost innocence.</q>
<rj><qau>Kebe.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The fragments, scraps, the bits and greasy <qex>relics</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The body from which the soul has departed; a corpse;
especially, the body, or some part of the body, of a deceased saint or
martyr; -- usually in the plural when referring to the whole
body.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There are very few treasuries of <qex>relics</qex> in Italy that
have not a tooth or a bone of this saint.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Thy <qex>relics</qex>, Rowe, to this fair urn we trust,<br/
And sacred place by Dryden's awful dust.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Hence, a memorial; anything preserved in
remembrance; <as>as, <ex>relics</ex> of youthful days or
friendships</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The pearls were spilt;<br/
Some lost, some stolen, some as <qex>relics</qex> kept.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relicly</ent><br/
<hw>Rel"ic*ly</hw>, <pos>adv.</pos> <def>In the manner of relics.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relict</ent><br/
<hw>Rel"ict</hw> <pr>(-?kt)</pr>, <pos>n.</pos> <ety>[L.
<ets>relicta</ets>, fr. of <ets>relictus</ets>, p. p. of
<ets>relinquere</ets> to leave behind. See <er>Relinquish</er>.]</ety>
<def>A woman whose husband is dead; a widow.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Eli dying without issue, Jacob was obliged by law to marry his
<qex>relict</qex>, and so to raise up seed to his brother Eli.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relicted</ent><br/
<hw>Re*lict"ed</hw> <pr>(r?-l?kt"?d)</pr>, <pos>a.</pos> <ety>[L.
<ets>relictus</ets>, p. p.]</ety> <fld>(Law)</fld> <def>Left uncovered,
as land by recession of water.</def> <rj><au>Bouvier.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reliction</ent><br/
<hw>Re*lic"tion</hw> <pr>(r?-l?k"sh?n)</pr>, <pos>n.</pos> <ety>[L.
<ets>relictio</ets> a leaving behind.]</ety> <fld>(Law)</fld> <def>A
leaving dry; a recession of the sea or other water, leaving dry land;
land left uncovered by such recession.</def>
<rj><au>Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relief</ent><br/
<hw>Re*lief"</hw> <pr>(r?-l?f")</pr>, <pos>n.</pos> <ety>[OE.
<ets>relef</ets>, F. <ets>relief</ets>, properly, a lifting up, a
standing out. See <er>Relieve</er>, and cf. <er>Basrelief</er>,
<er>Rilievi</er>.]</ety> <sn>1.</sn> <def>The act of relieving, or the
state of being relieved; the removal, or partial removal, of any evil,
or of anything oppressive or burdensome, by which some ease is obtained;
succor; alleviation; comfort; ease; redress.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He sees the dire contagion spread so fast,<br/
That, where it seizes, all <qex>relief</qex> is vain.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Release from a post, or from the performance of
duty, by the intervention of others, by discharge, or by relay; <as>as,
a <ex>relief</ex> of a sentry</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>For this <qex>relief</qex> much thanks; 'tis bitter cold.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which removes or lessens evil, pain,
discomfort, uneasiness, etc.; that which gives succor, aid, or comfort;
also, the person who relieves from performance of duty by taking the
place of another; a relay.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Feudal Law)</fld> <def>A fine or composition which
the heir of a deceased tenant paid to the lord for the privilege of
taking up the estate, which, on strict feudal principles, had lapsed or
fallen to the lord on the death of the tenant.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Sculp. & Arch.)</fld> <def>The projection of a
figure above the ground or plane on which it is formed.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Relief</xex> is of three kinds, namely, <stype>high
relief</stype> (<stype>altorilievo</stype>), <stype>low relief</stype>,
(<stype>basso-rilievo</stype>), and <stype>demirelief</stype>
(<stype>mezzo-rilievo</stype>). See these terms in the
Vocabulary.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Paint.)</fld> <def>The appearance of projection
given by shading, shadow, etc., to any figure.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Fort.)</fld> <def>The height to which works are
raised above the bottom of the ditch.</def>
<rj><au>Wilhelm.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <fld>(Physical Geog.)</fld> <def>The elevations and
surface undulations of a country.</def> <rj><au>Guyot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Relief valve</b></col>, <cd>a valve arranged for
relieving pressure of steam, gas, or liquid; an escape
valve.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Alleviation; mitigation; aid; help; succor;
assistance; remedy; redress; indemnification.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reliefful</ent><br/
<hw>Re*lief"ful</hw> <pr>(r?-l?f"f?l)</pr>, <pos>a.</pos> <def>Giving
relief.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reliefless</ent><br/
<hw>Re*lief"less</hw>, <pos>a.</pos> <def>Destitute of relief; also,
remediless.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relier</ent><br/
<hw>Re*li"er</hw> <pr>(r?-l?"?r)</pr>, <pos>n.</pos> <ety>[From
<er>Rely</er>.]</ety> <def>One who relies.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relievable</ent><br/
<hw>Re*liev"a*ble</hw> <pr>(r?-l?v"?-b'l)</pr>, <pos>a.</pos>
<def>Capable of being relieved; fitted to recieve relief.</def>
<rj><au>Sir M. Hale.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relieve</ent><br/
<hw>Re*lieve"</hw> <pr>(r?-l?v")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Relieved</conjf>
<pr>(-l?vd")</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Relieving</conjf>.]</vmorph> <ety>[OE. <ets>releven</ets>, F.
<ets>relever</ets> to raise again, discharge, relieve, fr. L.
<ets>relevare</ets> to lift up, raise, make light, relieve; pref.
<ets>re-</ets> re- + <ets>levare</ets> to raise, fr. <ets>levis</ets>
light. See <er>Levity</er>, and cf. <er>Relevant</er>,
<er>Relief</er>.]</ety> <sn>1.</sn> <def>To lift up; to raise again, as
one who has fallen; to cause to rise.</def> <mark>[Obs.]</mark>
<rj><au>Piers Plowman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To cause to seem to rise; to put in relief; to give
prominence or conspicuousness to; to set off by contrast.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Her tall figure <qex>relieved</qex> against the blue sky; seemed
almost of supernatural height.</q> <rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To raise up something in; to introduce a contrast or
variety into; to remove the monotony or sameness of.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The poet must . . . sometimes <qex>relieve</qex> the subject with
a moral reflection.</q> <rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To raise or remove, as anything which depresses,
weighs down, or crushes; to render less burdensome or afflicting; to
alleviate; to abate; to mitigate; to lessen; <as>as, to <ex>relieve</ex>
pain; to <ex>relieve</ex> the wants of the poor.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To free, wholly or partly, from any burden, trial,
evil, distress, or the like; to give ease, comfort, or consolation to;
to give aid, help, or succor to; to support, strengthen, or deliver;
<as>as, to <ex>relieve</ex> a besieged town</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Now lend assistance and <qex>relieve</qex> the poor.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To release from a post, station, or duty; to put
another in place of, or to take the place of, in the bearing of any
burden, or discharge of any duty.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Who hath <qex>relieved</qex> you?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>To ease of any imposition, burden, wrong, or
oppression, by judicial or legislative interposition, as by the removal
of a grievance, by indemnification for losses, or the like; to
right.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To alleviate; assuage; succor; assist; aid; help;
support; substain; ease; mitigate; lighten; diminish; remove; free;
remedy; redress; indemnify.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relievement</ent><br/
<hw>Re*lieve"ment</hw> <pr>(-m<it>e</it>nt)</pr>, <pos>n.</pos> <def>The
act of relieving, or the state of being relieved; relief; release.</def>
<mark>[Archaic.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reliever</ent><br/
<hw>Re*liev"er</hw> <pr>(-?r)</pr>, <pos>n.</pos> <def>One who, or that
which, relieves.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relieving</ent><br/
<hw>Re*liev"ing</hw>, <pos>a.</pos> <def>Serving or tending to
relieve.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Relieving arch</b></col> <fld>(Arch.)</fld>, <cd>a
discharging arch. See under <er>Discharge</er>, <pos>v. t.</pos></cd> --
<col><b>Relieving tackle</b></col>. <fld>(Naut.)</fld> <sd>(a)</sd>
<cd>A temporary tackle attached to the tiller of a vessel during gales
or an action, in case of accident to the tiller ropes</cd>. <sd>(b)</sd>
<cd>A strong tackle from a wharf to a careened vessel, to prevent her
from going over entirely, and to assist in righting her.</cd>
<rj><au>Totten.</au> <au>Craig.</au></rj> </cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relievo</ent><br/
<hw>Re*lie"vo</hw> <pr>(r?-l?"v?)</pr>, <pos>n.</pos> <ety>[It.
<ets>rilievo</ets>.]</ety> <def>See <er>Relief</er>, <pos>n.</pos>,
5.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relight</ent><br/
<hw>Re*light"</hw> <pr>(r?-l?t")</pr>, <pos>v. t.</pos> <def>To light or
kindle anew.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Religieux</ent><br/
<ent>Religieuse</ent><br/
<mhw>{ \'d8<hw>Re*li`gi`euse"</hw> <pr>(r<eit/-l?`zh?`?z")</pr>, <pos>n.
f.</pos> \'d8<hw>Re*li`gi`eux"</hw> <pr>(r<eit/-l?`zh?`?")</pr>, <pos>n.
m.</pos> }</mhw> <ety>[F.]</ety> <def>A person bound by monastic vows; a
nun; a monk.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Religion</ent><br/
<hw>Re*li"gion</hw> <pr>(r<esl/*l<icr/j"<ucr/n)</pr>, <pos>n.</pos>
<ety>[F., from L. <ets>religio</ets>; cf. <ets>religens</ets> pious,
revering the gods, Gr. <grk>'ale`gein</grk> to heed, have a care. Cf.
<er>Neglect</er>.]</ety> <sn>1.</sn> <def>The outward act or form by
which men indicate their recognition of the existence of a god or of
gods having power over their destiny, to whom obedience, service, and
honor are due; the feeling or expression of human love, fear, or awe of
some superhuman and overruling power, whether by profession of belief,
by observance of rites and ceremonies, or by the conduct of life; a
system of faith and worship; a manifestation of piety; <as>as, ethical
<ex>religions</ex>; monotheistic <ex>religions</ex>; natural
<ex>religion</ex>; revealed <ex>religion</ex>; the <ex>religion</ex> of
the Jews; the <ex>religion</ex> of idol worshipers</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>An orderly life so far as others are able to observe us is now and
then produced by prudential motives or by dint of habit; but without
seriousness there can be no religious principle at the bottom, no course
of conduct from religious motives; in a word, there can be no
<qex>religion</qex>.</q> <rj><qau>Paley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Religion</qex> [was] not, as too often now, used as
equivalent for godliness; but . . . it expressed the outer form and
embodiment which the inward spirit of a true or a false devotion
assumed.</q> <rj><qau>Trench.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Religions</qex>, by which are meant the modes of divine
worship proper to different tribes, nations, or communities, and based
on the belief held in common by the members of them severally. . . .
There is no living <qex>religion</qex> without something like a
doctrine. On the other hand, a doctrine, however elaborate, does not
constitute a <qex>religion</qex>.</q> <rj><qau>C. P. Tiele (Encyc.
Brit.).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Religion</qex> . . . means the conscious relation between man
and God, and the expression of that relation in human conduct.</q>
<rj><qau>J. K<oum/stlin (Schaff-Herzog Encyc.)</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>After the most straitest sect of our <qex>religion</qex> I lived a
Pharisee.</q> <rj><qau>Acts xxvi. 5.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The image of a brute, adorned<br/
With gay <qex>religions</qex> full of pomp and gold.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Specifically, conformity in faith and life to the
precepts inculcated in the Bible, respecting the conduct of life and
duty toward God and man; the Christian faith and practice.</def>
<note>This definition is from the 1913 Webster, which was edited by Noah
Porter, a theologian. His bias toward the Christion religion is evident
not only in this definition, but in others as well as in the choice of
quations or illustrative phrases. <it>Caveat lector</it>. -
PJC</note><br/
[<source>1913 Webster</source>]</p>

<p><q>Let us with caution indulge the supposition that morality can be
maintained without <qex>religion</qex>.</q>
<rj><qau>Washington.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Religion</qex> will attend you . . . as a pleasant and useful
companion in every proper place, and every temperate occupation of
life.</q> <rj><qau>Buckminster.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(R. C. Ch.)</fld> <def>A monastic or religious order
subject to a regulated mode of life; the religious state; <as>as, to
enter <ex>religion</ex></as>.</def> <rj><au>Trench.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A good man was there of <qex>religion</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Strictness of fidelity in conforming to any
practice, as if it were an enjoined rule of conduct.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Those parts of pleading which in ancient times might perhaps be
material, but at this time are become only mere styles and forms, are
still continued with much <qex>religion</qex>.</q> <rj><qau>Sir M.
Hale.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Religion</xex>, as distinguished from
<xex>theology</xex>, is subjective, designating the feelings and acts of
men which relate to God; while <xex>theology</xex> is objective, and
denotes those ideas which man entertains respecting the God whom he
worships, especially his systematized views of God. As distinguished
from <xex>morality</xex>, <xex>religion</xex> denotes the influences and
motives to human duty which are found in the character and will of God,
while <xex>morality</xex> describes the duties to man, to which true
<xex>religion</xex> always influences. As distinguished from
<xex>piety</xex>, <xex>religion</xex> is a high sense of moral
obligation and spirit of reverence or worship which affect the heart of
man with respect to the Deity, while <xex>piety</xex>, which first
expressed the feelings of a child toward a parent, is used for that
filial sentiment of veneration and love which we owe to the Father of
all. As distinguished from <xex>sanctity</xex>, <xex>religion</xex> is
the means by which <xex>sanctity</xex> is achieved, <xex>sanctity</xex>
denoting primarily that purity of heart and life which results from
habitual communion with God, and a sense of his continual
presence.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Natural religion</b></col>, <cd>a religion based upon the
evidences of a God and his qualities, which is supplied by natural
phenomena. See <cref>Natural theology</cref>, under
<er>Natural</er>.</cd> -- <col><b>Religion of humanity</b></col>, <cd>a
name sometimes given to a religion founded upon positivism as a
philosophical basis.</cd> -- <col><b>Revealed religion</b></col>,
<cd>that which is based upon direct communication of God's will to
mankind; especially, the Christian religion, based on the revelations
recorded in the Old and New Testaments.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Religionary</ent><br/
<hw>Re*li"gion*a*ry</hw> <pr>(r?-l?j"?n-?-r?)</pr>, <pos>a.</pos>
<def>Relating to religion; pious; <as>as, <ex>religionary</ex>
professions</as>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Religioner</ent><br/
<ent>Religionary</ent><br/
<mhw>{ <hw>Re*li"gion*a*ry</hw>, <hw>Re*li"gion*er</hw> <pr>(-?r)</pr>,
}</mhw> <pos>n.</pos> <def>A religionist.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Religionism</ent><br/
<hw>Re*li"gion*ism</hw> <pr>(-?z'm)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>The practice of, or devotion to, religion.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Affectation or pretense of religion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Religionist</ent><br/
<hw>Re*li"gion*ist</hw>, <pos>n.</pos> <def>One earnestly devoted or
attached to a religion; a religious zealot.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The chief actors on one side were, and were to be, the Puritan
<qex>religionists</qex>.</q> <rj><qau>Palfrey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>It might be that an Antinomian, a Quaker, or other heterodo<?/
<qex>religionists</qex>, was to be scourged out of the town.</q>
<rj><qau>Hawthorne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Religionize</ent><br/
<hw>Re*li"gion*ize</hw> <pr>(-?z)</pr>, <pos>v. t.</pos> <def>To bring
under the influence of religion.</def> <mark>[R.]</mark>
<rj><au>Mallock.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Religionless</ent><br/
<hw>Re*li"gion*less</hw>, <pos>a.</pos> <def>Destitute of
religion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Religiosity</ent><br/
<hw>Re*lig`i*os"i*ty</hw> <pr>(-l?j`?-?s"?-t?)</pr>, <pos>n.</pos>
<ety>[L. <ets>religiositas</ets>: cf. F.
<ets>religiosit<?/</ets>.]</ety> <def>The quality of being religious;
religious feeling or sentiment; religiousness.</def> <mark>[R.]</mark>
<rj><au>M. Arnold.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Religious</ent><br/
<hw>Re*li"gious</hw> <pr>(r?-l?j"?s)</pr>, <pos>a.</pos> <ety>[OF.
<ets>religius</ets>, <ets>religious</ets>, F. <ets>religieux</ets>, from
L. <ets>religiosus</ets>. See <er>Religion</er>.]</ety> <sn>1.</sn>
<def>Of or pertaining to religion; concerned with religion; teaching, or
setting forth, religion; set apart to religion; <as>as, a
<ex>religious</ex> society; a <ex>religious</ex> sect; a
<ex>religious</ex> place; <ex>religious</ex> subjects, books, teachers,
houses, wars.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Our law forbids at their <qex>religious</qex> rites<br/
My presence.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Possessing, or conforming to, religion; pious;
godly; <as>as, a <ex>religious</ex> man, life, behavior,
etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Men whose lives<br/
<qex>Religious</qex> titled them the sons of God.</q>
<rj><qau>Mlton</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Scrupulously faithful or exact; strict.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thus, Indianlike,<br/
<qex>Religious</qex> in my error, I adore<br/
The sun, that looks upon his worshiper.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Belonging to a religious order; bound by
vows.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>One of them is <qex>religious</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Pious; godly; holy; devout; devotional;
conscientious; strict; rogod; exact.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Religious</ent><br/
<hw>Re*li"gious</hw>, <pos>n.</pos> <def>A person bound by monastic
vows, or sequestered from secular concern, and devoted to a life of
piety and religion; a monk or friar; a nun.</def>
<rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Religiously</ent><br/
<hw>Re*li"gious*ly</hw>, <pos>adv.</pos> <def>In a religious
manner.</def> <rj><au>Drayton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Religiousness</ent><br/
<hw>Re*li"gious*ness</hw>, <pos>n.</pos> <def>The quality of being
religious.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relik</ent><br/
<hw>Rel"ik</hw> <pr>(r?l"?k)</pr>, <pos>n.</pos> <def>Relic.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relinquent</ent><br/
<hw>Re*lin"quent</hw> <pr>(r?-l?n"kw<it>e</it>nt)</pr>, <pos>a.</pos>
<ety>[L. <ets>relinquens</ets>, p. pr. of <ets>relinqquere</ets>. See
<er>Relinquish</er>.]</ety> <def>Relinquishing.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relinquent</ent><br/
<hw>Re*lin"quent</hw>, <pos>n.</pos> <def>One who relinquishes.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relinquish</ent><br/
<hw>Re*lin"quish</hw> <pr>(-kw?sh)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Relinquished</conjf>
<pr>(-kw?sht)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Relinquishing</conjf>.]</vmorph> <ety>[OF. <ets>relinquir</ets>,
L. <ets>relinquere</ets> to leave behind; pref. <ets>re-</ets> re +
<ets>linquere</ets> to leave. See <er>Loan</er>, and cf. <er>Relic</er>,
<er>Relict</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>To withdraw from; to leave behind; to desist from;
to abandon; to quit; <as>as, to <ex>relinquish</ex> a
pursuit</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We ought to <qex>relinquish</qex> such rites.</q>
<rj><qau>Hooker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>They placed Irish tenants upon the lands <qex>relinquished</qex>
by the English.</q> <rj><qau>Sir J. Davies.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To give up; to renounce a claim to; resign; <as>as,
to <ex>relinquish</ex> a debt</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To resign; leave; quit; forsake; abandon; desert;
renounce; forbear; forego. See <er>Resign</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relinquisher</ent><br/
<hw>Re*lin"quish*er</hw> <pr>(-r?r)</pr>, <pos>n.</pos> <def>One who
relinquishes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relinquishment</ent><br/
<hw>Re*lin"quish*ment</hw> <pr>(-m<it>e</it>nt)</pr>, <pos>n.</pos>
<def>The act of relinquishing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reliquary</ent><br/
<hw>Rel"i*qua*ry</hw> <pr>(r?l"?-kw?-r?)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>-ries</plw> <pr>(-r<icr/z)</pr>.</plu> <ety>[LL.
<ets>reliquiarium</ets>, <ets>reliquiare</ets>: cf. F.
<ets>reliquaire</ets>. See <er>Relic</er>.]</ety> <def>A depositary,
often a small box or casket, in which relics are kept.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relique</ent><br/
<hw>Re*lique"</hw> <pr>(r?-l?k")</pr>, <pos>n.</pos> <ety>[F.]</ety>
<def>See <er>Relic</er>.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reliquiae</ent><br/
\'d8<hw>Re*liq"ui*ae</hw> <pr>(r?-l?k"w?-?)</pr>, <pos>n. pl.</pos>
<ety>[L. See <er>Relic</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Remains of the dead; organic remains;
relics.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>Same as
<er>Induviae</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1215 --></p>

<p><ent>Reliquian</ent><br/
<hw>Re*liq"ui*an</hw> <pr>(r<esl/*l<icr/k"w<icr/*<ait/n)</pr>,
<pos>a.</pos> <def>Of or pertaining to a relic or relics; of the nature
of a relic.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reliquidate</ent><br/
<hw>Re*liq"ui*date</hw> <pr>(r<emac/*l<icr/k"w<icr/*d<amac/t)</pr>,
<pos>v. t.</pos> <def>To liquidate anew; to adjust a second
time.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reliquidation</ent><br/
<hw>Re*liq`ui*da"tion</hw>
<pr>(r<emac/*l<icr/k`w<icr/*d<amac/"sh<ucr/n)</pr>, <pos>n.</pos> <def>A
second or renewed liquidation; a renewed adjustment.</def> <rj><au>A.
Hamilton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relish</ent><br/
<hw>Rel"ish</hw> <pr>(r<ecr/l"<icr/sh)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Relished</conjf>
<pr>(r<ecr/l"<icr/sht)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Relishing</conjf>.]</vmorph> <ety>[Of. <ets>relechier</ets> to
lick or taste anew; pref. <ets>re-</ets> re- + <ets>lechier</ets> to
lick, F. <ets>l<eacute/cher</ets>. See <er>Lecher</er>,
<er>Lick</er>.]</ety> <sn>1.</sn> <def>To taste or eat with pleasure; to
like the flavor of; to partake of with gratification; hence, to enjoy;
to be pleased with or gratified by; to experience pleasure from; <as>as,
to <ex>relish</ex> food</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Now I begin to <qex>relish</qex> thy advice.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He knows how to prize his advantages, and to <qex>relish</qex> the
honors which he enjoys.</q> <rj><qau>Atterbury.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To give a relish to; to cause to taste
agreeably.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A savory bit that served to <qex>relish</qex> wine.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relish</ent><br/
<hw>Rel"ish</hw>, <pos>v. i.</pos> <def>To have a pleasing or appetizing
taste; to give gratification; to have a flavor.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Had I been the finder-out of this secret, it would not have
<qex>relished</qex> among my other discredits.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A theory, which, how much soever it may <qex>relish</qex> of wit
and invention, hath no foundation in nature.</q>
<rj><qau>Woodward.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relish</ent><br/
<hw>Rel"ish</hw>, <pos>n.</pos> <sn>1.</sn> <def>A pleasing taste;
flavor that gratifies the palate; hence, enjoyable quality; power of
pleasing.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Much pleasure we have lost while we abstained<br/
From this delightful fruit, nor known till now<br/
True <qex>relish</qex>, tasting.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>When liberty is gone,<br/
Life grows insipid, and has lost its <qex>relish</qex>.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Savor; quality; characteristic tinge.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It preserve some <qex>relish</qex> of old writing.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A taste for; liking; appetite; fondness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>relish</qex> for whatever was excellent in arts.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I have a <qex>relish</qex> for moderate praise, because it bids
fair to be judicious.</q> <rj><qau>Cowper.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>That which is used to impart a flavor; specifically,
something taken with food to render it more palatable or to stimulate
the appetite; a condiment.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Taste; savor; flavor; appetite; zest; gusto;
liking; delight.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relish</ent><br/
<hw>Rel"ish</hw>, <pos>n.</pos> <fld>(Carp.)</fld> <def>The projection
or shoulder at the side of, or around, a tenon, on a tenoned
piece.</def> <rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relishable</ent><br/
<hw>Rel"ish*a*ble</hw> <pr>(-?-b'l)</pr>, <pos>a.</pos> <def>Capable of
being relished; agreeable to the taste; gratifying.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relive</ent><br/
<hw>Re*live"</hw> <pr>(r<emac/*l<icr/v")</pr>, <pos>v. i.</pos> <def>To
live again; to revive.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relive</ent><br/
<hw>Re*live"</hw>, <pos>v. t.</pos> <def>To recall to life; to
revive.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reload</ent><br/
<hw>Re*load"</hw> <pr>(r?-l?d")</pr>, <pos>v. t.</pos> <def>To load
again, as a gun.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reloan</ent><br/
<hw>Re*loan"</hw> <pr>(r?-l?n")</pr>, <pos>n.</pos> <def>A second
lending of the same thing; a renewal of a loan.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relocate</ent><br/
<hw>Re*lo"cate</hw> <pr>(r<emac/*l<omac/"k<amac/t)</pr>, <pos>v.
t.</pos> <def>To locate again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relocation</ent><br/
<hw>Re`lo*ca"tion</hw> <pr>(r<emac/`l<osl/*k<amac/"sh<ucr/n)</pr>,
<pos>n.</pos> <sn>1.</sn> <def>A second location.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Roman & Scots Law)</fld> <def>Renewal of a
lease.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relodge</ent><br/
<hw>Re*lodge"</hw> <pr>(r<emac/*l<ocr/j")</pr>, <pos>v. t.</pos> <def>To
lodge again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relove</ent><br/
<hw>Re*love"</hw> <pr>(r<emac/*l<ucr/v")</pr>, <pos>v. t.</pos> <def>To
love in return.</def> <mark>[Obs.]</mark> <rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relucent</ent><br/
<hw>Re*lu"cent</hw> <pr>(r?-l?"s<it>e</it>nt)</pr>, <pos>a.</pos>
<ety>[L. <ets>relucens</ets>, p. pr. <ets>relucere</ets>. See
<er>Lucent</er>.]</ety> <def>Reflecting light; shining; glittering;
glistening; bright; luminous; splendid.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Gorgeous banners to the sun expand<br/
Their streaming volumes of <qex>relucent</qex> gold.</q>
<rj><qau>Glover.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reluct</ent><br/
<hw>Re*luct"</hw> <pr>(r?-l?kt")</pr>, <pos>v. i.</pos> <ety>[L.
<ets>reluctari</ets>, p. p. <ets>reluctatus</ets>, to struggle; pref.
<ets>re-</ets> re- + <ets>luctari</ets> to struggle, fr.
<ets>lucia</ets> a wresting.]</ety> <def>To strive or struggle against
anything; to make resistance; to draw back; to feel or show repugnance
or reluctance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Apt to <qex>reluct</qex> at the excesses of it [passion].</q>
<rj><qau>Walton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reluctancy</ent><br/
<ent>Reluctance</ent><br/
<mhw>{ <hw>Re*luc"tance</hw> <pr>(r?-l?k"t<it>a</it>ns)</pr>,
<hw>Re*luc"tan*cy</hw> <pr>(-t<it>a</it>n-s?)</pr>, }</mhw>
<pos>n.</pos> <ety>[See <er>Reluctant</er>.]</ety> <sn>1.</sn> <def>The
state or quality of being reluctant; repugnance; aversion of mind;
unwillingness; -- often followed by an infinitive, or by <xex>to</xex>
and a noun, formerly sometimes by <xex>against</xex>.</def>
<ldquo/Tempering the severity of his looks with a <xex>reluctance</xex>
to the action.<rdquo/ <rj><au>Dryden.</au></rj><br/
<syn><b>Syn.</b> See <er>Dislike</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><q>He had some <qex>reluctance</qex> to obey the summons.</q>
<rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Bear witness, Heaven, with what <qex>reluctancy</qex><br/
Her helpless innocence I doom to die.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Elec.)</fld> <def>Magnetic resistance, being equal
to the ratio of magnetomotive force to magnetic flux.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Reluctant</ent><br/
<hw>Re*luc"tant</hw> <pr>(-t<it>a</it>nt)</pr>, <pos>a.</pos> <ety>[L.
<ets>reluctans</ets>, <ets>-antis</ets>, p. pr. of <ets>reluctari</ets>.
See <er>Reluct</er>.]</ety> <sn>1.</sn> <def>Striving against; opposed
in desire; unwilling; disinclined; loth.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Reluctant</qex>, but in vain.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Reluctant</qex> now I touched the trembling string.</q>
<rj><qau>Tickell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Proceeding from an unwilling mind; granted with
reluctance; <as>as, <ex>reluctant</ex> obedience</as>.</def>
<rj><au>Mitford.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Averse; unwilling; loth; disinclined; repugnant;
backward; coy. See <er>Averse</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reluctantly</ent><br/
<hw>Re*luc"tant*ly</hw>, <pos>adv.</pos> <def>In a reluctant
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reluctate</ent><br/
<hw>Re*luc"tate</hw> <pr>(-t?t)</pr>, <pos>v. i.</pos> <ety>[See
<er>Reluct</er>.]</ety> <def>To struggle against anything; to resist; to
oppose.</def> <mark>[Obs.]</mark> <ldquo/To delude their
<xex>reluctating</xex> consciences.<rdquo/ <rj><au>Dr. H.
More.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reluctation</ent><br/
<hw>Rel`uc*ta"tion</hw> <pr>(r?l`?k-t?"sh?n)</pr>, <pos>n.</pos>
<def>Repugnance; resistance; reluctance.</def> <mark>[Obs.]</mark>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reluctivity</ent><br/
<hw>Rel`uc*tiv"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Elec.)</fld>
<def>Specific reluctance.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Relume</ent><br/
<hw>Re*lume"</hw> <pr>(r?-l?m")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Relumed</conjf>
<pr>(-l?md")</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Reluming</conjf>.]</vmorph> <ety>[OF. <ets>relumer</ets> (cf. F.
<ets>rallumer</ets>), L. <ets>reluminare</ets>; pref. <ets>re-</ets> re-
+ <ets>luminare</ets> to light. Cf. <er>Reillume</er>.]</ety> <def>To
rekindle; to light again.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Relumed</qex> her ancient light, not kindled new.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I know not where is that Promethean heat<br/
That can thy light <qex>relume</qex>.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Relumine</ent><br/
<hw>Re*lu"mine</hw> <pr>(r?-l?"m?n)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Relumined</conjf>
<pr>(-m?nd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Relumining</conjf>.]</vmorph> <ety>[See <er>Relume</er>.]</ety>
<sn>1.</sn> <def>To light anew; to rekindle.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To illuminate again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rely</ent><br/
<hw>Re*ly"</hw> <pr>(r?-l?")</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Relied</conjf> <pr>(-l?d")</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Relying</conjf>.]</vmorph> <ety>[Pref. <ets>re-</ets> +
<ets>lie</ets> to rest.]</ety> <def>To rest with confidence, as when
fully satisfied of the veracity, integrity, or ability of persons, or of
the certainty of facts or of evidence; to have confidence; to trust; to
depend; -- with <xex>on</xex>, formerly also with
<xex>in</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Go in thy native innocence; <qex>rely</qex><br/
On what thou hast of virtue.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>On some fond breast the parting soul <qex>relies</qex>.</q>
<rj><qau>Gray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To trust; depend; confide; repose.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remade</ent><br/
<hw>Re*made"</hw> <pr>(r?-m?d")</pr>, <def><pos>imp. & p. p.</pos> of
<er>Remake</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remain</ent><br/
<hw>Re*main"</hw> <pr>(r?-m?n")</pr>, <pos>v. i.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Remained</conjf>
<pr>(-m?nd")</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Remaining</conjf>.]</vmorph> <ety>[OF. <ets>remaindre</ets>,
<ets>remanoir</ets>, L. <ets>remanere</ets>; pref. <ets>re-</ets> re- +
<ets>manere</ets> to stay, remain. See <er>Mansion</er>, and cf.
<er>Remainder</er>, <er>Remnant</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>To stay behind while others withdraw; to be left
after others have been removed or destroyed; to be left after a number
or quantity has been subtracted or cut off; to be left as not included
or comprised.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Gather up the fragments that <qex>remain</qex>.</q> <rj><qau>John
vi. 12.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Of whom the greater part <qex>remain</qex> unto this present, but
some are fallen asleep.</q> <rj><qau>1 Cor. xv. 6.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>That . . . <qex>remains</qex> to be proved.</q>
<rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To continue unchanged in place, form, or condition,
or undiminished in quantity; to abide; to stay; to endure; to
last.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Remain</qex> a widow at thy father's house.</q> <rj><qau>Gen.
xxxviii. 11.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Childless thou art; childless <qex>remain</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To continue; stay; wait; tarry; rest; sojourn;
dwell; abide; last; endure.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remain</ent><br/
<hw>Re*main"</hw>, <pos>v. t.</pos> <def>To await; to be left to.</def>
<mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The easier conquest now <qex>remains</qex> thee.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remain</ent><br/
<hw>Re*main"</hw> <pos>n.</pos> <sn>1.</sn> <def>State of remaining;
stay.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Which often, since my here <qex>remain</qex> in England,<br/
I 've seen him do.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is left; relic; remainder; -- chiefly in
the plural.</def> <ldquo/The <xex>remains</xex> of old Rome.<rdquo/
<rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>When this <qex>remain</qex> of horror has entirely subsided.</q>
<rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <specif>Specif., in the plural:</specif> <sd>(a)</sd>
<def>That which is left of a human being after the life is gone; relics;
a dead body.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Old warriors whose adored <qex>remains</qex><br/
In weeping vaults her hallowed earth contains!</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(b)</sd> <def>The posthumous works or productions, esp. literary
works, of one who is dead; as, Cecil's</def> <xex>Remains</xex>.<br/
[<source>1913 Webster</source>]</p>

<p><ent>Remainder</ent><br/
<hw>Re*main"der</hw> <pr>(r?-m?n"d?r)</pr>, <pos>n.</pos> <ety>[OF.
<ets>remaindre</ets>, inf. See <er>Remain</er>.]</ety> <sn>1.</sn>
<def>Anything that remains, or is left, after the separation and removal
of a part; residue; remnant.</def> <ldquo/The last <xex>remainders</xex>
of unhappy Troy.<rdquo/ <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>If these decoctions be repeated till the water comes off clear,
the <qex>remainder</qex> yields no salt.</q>
<rj><qau>Arbuthnot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Math.)</fld> <def>The quantity or sum that is left
after subtraction, or after any deduction.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Law)</fld> <def>An estate in expectancy, generally
in land, which becomes an estate in possession upon the determination of
a particular prior estate, created at the same time, and by the same
instrument; for example, if land be conveyed to A for life, and on his
death to B, A's life interest is a particuar estate, and B's interest is
a <xex>remainder</xex>, or <xex>estate in remainder</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Balance; rest; residue; remnant;
leavings.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remainder</ent><br/
<hw>Re*main"der</hw>, <pos>a.</pos> <def>Remaining; left; left over;
refuse.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Which is as dry as the <qex>remainder</qex> biscuit<br/
After a voyage.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remainder-man</ent><br/
<hw>Re*main"der-man</hw> <pr>(- m<acr/n)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Remainder-men</plw> <pr>(-m<ecr/n)</pr>.</plu>
<fld>(Law)</fld> <def>One who has an estate after a particular estate is
determined. See <er>Remainder</er>, <pos>n.</pos>, 3.</def>
<rj><au>Blackstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remake</ent><br/
<hw>Re*make"</hw> <pr>(r?-m?k")</pr>, <pos>v. t.</pos> <def>To make
anew.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remand</ent><br/
<hw>Re*mand"</hw> <pr>(r?-m?nd")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Remanded</conjf>; <pos>p. pr. &
vb. n.</pos> <conjf>Remanding</conjf>.]</vmorph> <ety>[F.
<ets>remander</ets> to send word again, L. <ets>remandare</ets>; pref.
<ets>re-</ets> re- + <ets>mandare</ets> to commit, order, send word. See
<er>Mandate</er>.]</ety> <def>To recommit; to send back.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Remand</qex> it to its former place.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Then were they <qex>remanded</qex> to the cage again.</q>
<rj><qau>Bunyan.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remand</ent><br/
<hw>Re*mand"</hw>, <pos>n.</pos> <def>The act of remanding; the order
for recommitment.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remandment</ent><br/
<hw>Re*mand"ment</hw> <pr>(-m<it>e</it>nt)</pr>, <pos>n.</pos> <def>A
remand.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remanency</ent><br/
<ent>Remanence</ent><br/
<mhw>{ <hw>Rem"a*nence</hw> <pr>(r?m"?*n<it>e</it>ns)</pr>,
<hw>Rem"a*nen*cy</hw> <pr>(-n<it>e</it>n*s?)</pr>, }</mhw> <pos>n.</pos>
<ety>[Cf. OF. <ets>remanence</ets>, LL. <ets>remanentia</ets>, fr. L.
<ets>remanens</ets>. See <er>Remanent</er>, <pos>a.</pos>]</ety>
<def>The state of being remanent; continuance; permanence.</def>
<mark>[R.]</mark> <rj><au>Jer. Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>remanence</qex> of the will in the fallen spirit.</q>
<rj><qau>Coleridge.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remanent</ent><br/
<hw>Rem"a*nent</hw> <pr>(-n<it>e</it>nt)</pr>, <pos>n.</pos> <ety>[See
<er>Remanent</er>, <pos>a.</pos>]</ety> <def>That which remains; a
remnant; a residue.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remanent</ent><br/
<hw>Rem"a*nent</hw>, <pos>a.</pos> <ety>[L. <ets>remanens</ets>, p. pr.
of <ets>remanere</ets>. See <er>Remain</er>, and cf.
<er>Remnant</er>.]</ety> <def>Remaining; residual.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That little hope that is <qex>remanent</qex> hath its degree
according to the infancy or growth of the habit.</q> <rj><qau>Jer.
Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Remanent magnetism</b></col> <fld>(Physics)</fld>,
<cd>magnetism which remains in a body that has little coercive force
after the magnetizing force is withdrawn, as soft iron; -- called also
<altname>residual magnetism</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remanet</ent><br/
\'d8<hw>Rem"a*net</hw> <pr>(-n?t)</pr>, <pos>n.</pos> <ety>[L., it
remains.]</ety> <fld>(Legal Practice)</fld> <def>A case for trial which
can not be tried during the term; a postponed case.</def>
<mark>[Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Re-mark</ent><br/
<hw>Re-mark"</hw> <pr>(r?-m?rk")</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>re-</ets> + <ets>mark</ets>.]</ety> <def>To mark again, or a second
time; to mark anew.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remark</ent><br/
<hw>Re*mark"</hw> <pr>(r?-m?rk")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Remarked</conjf>
<pr>(-m?rkt")</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Remarking</conjf>.]</vmorph> <ety>[F. <ets>remarquer</ets>; pref.
<ets>re-</ets> re- + <ets>marquer</ets> to mark, <ets>marque</ets> a
mark, of German origin, akin to E. <ets>mark</ets>. See <er>Mark</er>,
<pos>v. & n.</pos>]</ety> <sn>1.</sn> <def>To mark in a notable manner;
to distinquish clearly; to make noticeable or conspicuous; to piont
out.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou art a man <qex>remarked</qex> to taste a mischief.</q>
<rj><qau>Ford.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>His manacles <qex>remark</qex> him; there he sits.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To take notice of, or to observe, mentally; <as>as,
to <ex>remark</ex> the manner of a speaker</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To express in words or writing, as observed or
noticed; to state; to say; -- often with a substantive clause; <as>as,
he <ex>remarked</ex> that it was time to go</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To observe; notice; heed; regard; note;
say.</syn> <usage> -- <er>Remark</er>, <er>Observe</er>,
<er>Notice</er>. To <xex>observe</xex> is to keep or hold a thing
distinctly before the mind. To <xex>remark</xex> is simply to mark or
take note of whatever may come up. To <xex>notice</xex> implies still
less continuity of attention. When we turn from these mental states to
the <xex>expression</xex> of them in language, we find the same
distinction. An <xex>observation</xex> is properly the result of
somewhat prolonged thought; a <xex>remark</xex> is usually suggested by
some passing occurence; a <xex>notice</xex> is in most cases something
cursory and short. This distinction is not always maintained as to
<xex>remark</xex> and <xex>observe</xex>, which are often used
interchangeably. <ldquo/<xex>Observing</xex> men may form many judgments
by the rules of similitude and proportion.<rdquo/ <au>I. Watts.</au>
<ldquo/He can not distinguish difficult and noble speculations from
trifling and vulgar <xex>remarks</xex>.<rdquo/ <au>Collier.</au>
<ldquo/The thing to be regarded, in taking <xex>notice</xex> of a
child's miscarriage, is what root it springs from.<rdquo/
<au>Locke.</au></usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remark</ent><br/
<hw>Re*mark"</hw> <pr>(r?-m?rk")</pr>, <pos>v. i.</pos> <def>To make a
remark or remarks; to comment.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remark</ent><br/
<hw>Re*mark"</hw>, <pos>n.</pos> <ety>[Cf. F.
<ets>remarque</ets>.]</ety> <sn>1.</sn> <def>Act of remarking or
attentively noticing; notice or observation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The cause, though worth the search, may yet elude<br/
Conjecture and <qex>remark</qex>, however shrewd.</q>
<rj><qau>Cowper.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The expression, in speech or writing, of something
remarked or noticed; the mention of that which is worthy of attention or
notice; hence, also, a casual observation, comment, or statement;
<as>as, a pertinent <ex>remark</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Observation; note; comment; annotation.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remarkable</ent><br/
<hw>Re*mark"a*ble</hw> <pr>(-?-b'l)</pr>, <pos>a.</pos> <ety>[F.
<ets>remarquable</ets>.]</ety> <def>Worthy of being remarked or noticed;
noticeable; conspicuous; hence, uncommon; extraordinary.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>'T is <qex>remarkable</qex>, that they<br/
Talk most who have the least to say.</q> <rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>There is nothing left <qex>remarlable</qex><br/
Beneath the visiting moon.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Observable; noticeable; extraordinary; unusual;
rare; strange; wonderful; notable; eminent.</syn><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Re*mark"a*ble*ness</wf>, <pos>n.</pos> --
<wf>Re*mark"a*bly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remarker</ent><br/
<hw>Re*mark"er</hw> <pr>(-?r)</pr>, <pos>n.</pos> <def>One who
remarks.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remarque proof</ent><br/
<ent>Remark</ent><br/
<ent>Remarque</ent><br/
<mhw><hw>Re*marque"</hw> <pr>(?)</pr>, <pos>n.</pos> Also
<hw>Remark</hw></mhw>. <fld>(Engraving)</fld> <sd>(a)</sd> <def>A small
design etched on the margin of a plate and supposed to be removed after
the earliest proofs have been taken; also, any feature distinguishing a
particular stage of the plate.</def> <sd>(b)</sd> <def>A print or proof
so distinguished; -- commonly called a <altname><hw>Remarque
proof</hw></altname>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Remarriage</ent><br/
<hw>Re*mar"riage</hw> <pr>(r?-m?r"r?j)</pr>, <pos>n.</pos> <def>A second
or repeated marriage.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remarry</ent><br/
<hw>Re*mar"ry</hw> <pr>(r?-m?r"rr?)</pr>, <pos>v. t. & i.</pos> <def>To
marry again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remast</ent><br/
<hw>Re*mast"</hw> <pr>(r?-m?st")</pr>, <pos>v. t.</pos> <def>To furnish
with a new mast or set of masts.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remasticate</ent><br/
<hw>Re*mas"ti*cate</hw> <pr>(r?-m?s"t?-k?t)</pr>, <pos>v. t.</pos>
<def>To chew or masticate again; to chew over and over, as the
cud.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remastication</ent><br/
<hw>Re*mas`ti*ca"tion</hw> <pr>(-k?"sh?n)</pr>, <pos>n.</pos> <def>The
act of masticating or chewing again or repeatedly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remberge</ent><br/
<hw>Rem"berge</hw> <pr>(r?m"b?rj)</pr>, <pos>n.</pos> <def>See
<er>Ramberge</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remblai</ent><br/
\'d8<hw>Rem`blai"</hw> <pr>(r?n`bl?")</pr>, <pos>n.</pos> <ety>[F., fr.
remblayer to fill up an excavation, to embank.]</ety> <fld>(Fort. &
Engin.)</fld> <def>Earth or materials made into a bank after having been
excavated.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remble</ent><br/
<hw>Rem"ble</hw> <pr>(r<?/m"b'l)</pr>, <pos>v. t.</pos> <ety>[Cf. OF.
<ets>embler</ets> to steal, fr. L. <ets>involare</ets> to fly into or
at, to carry off.]</ety> <def>To remove.</def> <mark>[Prov. Eng.]</mark>
<rj><au>Grose. Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reme</ent><br/
<hw>Reme</hw> <pr>(r<?/m)</pr>, <pos>n.</pos> <def>Realm.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remean</ent><br/
<hw>Re*mean"</hw> <pr>(r<?/-m<?/n")</pr>, <pos>v. t.</pos> <def>To give
meaning to; to explain the meaning of; to interpret.</def>
<mark>[Obs.]</mark> <rj><au>Wyclif.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remeant</ent><br/
<hw>Re"me*ant</hw> <pr>(r<?/"m<?/*<it>a</it>nt)</pr>, <pos>a.</pos>
<ety>[L. <ets>remeans</ets>, <ets>-antis</ets>, p. pr. of
<ets>remeare</ets> to go or come back.]</ety> <def>Coming back;
returning.</def> <mark>[R.]</mark> <ldquo/Like the <xex>remeant</xex>
sun.<rdquo/ <rj><au>C. Kingsley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remeasure</ent><br/
<hw>Re*meas"ure</hw> <pr>(r?-m?zh"?r; 135)</pr>, <pos>v. t.</pos>
<def>To measure again; to retrace.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They followed him . . . <br/
The way they came, their steps <qex>remeasured</qex> right.</q>
<rj><qau>Fairfax.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remede</ent><br/
<hw>Re*mede"</hw> <pr>(r?-m?d")</pr>, <pos>n.</pos> <def>Remedy.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remediable</ent><br/
<hw>Re*me"di*a*ble</hw> <pr>(r?-m?"d?-?-b'l)</pr>, <pos>a.</pos>
<ety>[L. <ets>remediabilis</ets>: cf. F.
<ets>rem<eacute/diable</ets>.]</ety> <def>Capable of being remedied or
cured.</def><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Re*me"di*a*ble*ness</wf>, <pos>n.</pos>
-<wf>Re*me"di*a*bly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remedial</ent><br/
<hw>Re*me"di*al</hw> <pr>(-<it>a</it>l)</pr>, <pos>a.</pos> <ety>[L.
<ets>remedialis</ets>.]</ety> <def>Affording a remedy; intended for a
remedy, or for the removal or abatement of an evil; <as>as,
<ex>remedial</ex> treatment</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Statutes are declaratory or <qex>remedial</qex>.</q>
<rj><qau>Blackstone.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>It is an evil not compensated by any beneficial result; it is not
<qex>remedial</qex>, not conservative.</q> <rj><qau>I.
Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remedially</ent><br/
<hw>Re*me"di*al*ly</hw>, <pos>adv.</pos> <def>In a remedial
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remediate</ent><br/
<hw>Re*me"di*ate</hw> <pr>(-?t)</pr>, <pos>a.</pos> <def>Remedial.</def>
<mark>[R.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remediless</ent><br/
<hw>Re*med"i*less</hw> <pr>(r?-m?d"?-l?s <or/ r?m"?-d?-l?s; 277)</pr>,
<pos>a.</pos> <sn>1.</sn> <def>Not admitting of a remedy; incapable of
being restored or corrected; incurable; irreparable; <as>as, a
<ex>remediless</ex> mistake or loss</as>.</def> <ldquo/Chains
<xex>remedilesse</xex>.<rdquo/ <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Hopeless are all my evils, all <qex>remediless</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Not answering as a remedy; ineffectual.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Forced to forego the attempt <qex>remediless</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Incurable; cureless; irremediable; irrecoverable;
irretrievable; irreparable; desperate.</syn><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Re*med"i*less</wf>, <pos>adv.</pos>
<mark>[Obs.]</mark> <au>Udall.</au> -- <wf>Re*med"i*less*ly</wf>,
<pos>adv.</pos> -- <wf>Re*med"i*less*ness</wf>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remedy</ent><br/
<hw>Rem"e*dy</hw> <pr>(r?m"?-d?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Remedies</plw> <pr>(-d<?/z)</pr>.</plu> <ety>[L.
<ets>remedium</ets>; pref. <ets>re-</ets> re- + <ets>mederi</ets> to
heal, to cure: cf. F. <ets>rem<egrave/de</ets> remedy,
<ets>rem<eacute/dier</ets> to remedy. See <er>Medical</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>That which relieves or cures a disease; any medicine
or application which puts an end to disease and restores health; -- with
<xex>for</xex>; <as>as, a <ex>remedy</ex> for the gout</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which corrects or counteracts an evil of any
kind; a corrective; a counteractive; reparation; cure; -- followed by
<xex>for</xex> or <xex>against</xex>, formerly by
<xex>to</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>What may else be <qex>remedy</qex> or cure<br/
To evils which our own misdeeds have wrought,<br/
He will instruct us.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Law)</fld> <def>The legal means to recover a right,
or to obtain redress for a wrong.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Civil remedy</b></col>. <cd>See under
<er>Civil</er>.</cd> -- <col><b>Remedy of the mint</b></col>
<fld>(Coinage)</fld>, <cd>a small allowed deviation from the legal
standard of weight and fineness; -- called also
<altname>tolerance</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Cure; restorative; counteraction; reparation;
redress; relief; aid; help; assistance.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remedy</ent><br/
<hw>Rem"e*dy</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Remedied</conjf> <pr>(-d?d)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Remedying</conjf>.]</vmorph> <ety>[L. <ets>remediare</ets>,
<ets>remediari</ets>: cf. F. <ets>rem<eacute/dier</ets>. See
<er>Remedy</er>, <pos>n.</pos>]</ety> <def>To apply a remedy to; to
relieve; to cure; to heal; to repair; to redress; to correct; to
counteract.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I will <qex>remedy</qex> this gear ere long.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remelt</ent><br/
<hw>Re*melt"</hw> <pr>(r?-m?lt")</pr>, <pos>v. t.</pos> <def>To melt
again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remember</ent><br/
<hw>Re*mem"ber</hw> <pr>(r?-m?m"b?r)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Remembered</conjf>
<pr>(-b?rd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Remembering</conjf>.]</vmorph> <ety>[OF. <ets>remebrer</ets>, L.
<ets>rememorari</ets>; pref. <ets>re-</ets> re- + <ets>memorare</ets> to
bring to remembrance, from <ets>memor</ets> mindful. See
<er>Memory</er>, and cf. <er>Rememorate</er>.]</ety> <sn>1.</sn> <def>To
have (a notion or idea) come into the mind again, as previously
perceived, known, or felt; to have a renewed apprehension of; to bring
to mind again; to think of again; to recollect; <as>as, I
<ex>remember</ex> the fact; he <ex>remembers</ex> the events of his
childhood; I cannot <ex>remember</ex> dates.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>We are said to <qex>remember</qex> anything, when the idea of it
arises in the mind with the consciousness that we have had this idea
before.</q> <rj><qau>I. Watts.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To be capable of recalling when required; to keep in
mind; to be continually aware or thoughtful of; to preserve fresh in the
memory; to attend to; to think of with gratitude, affection, respect, or
any other emotion.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Remember</qex> the Sabbath day, to keep it holy.</q>
<rj><qau>Ex. xx. 8.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>That they may have their wages duly paid 'em,<br/
And something over to <qex>remember</qex> me by.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Remember</qex> what I warn thee; shun to taste.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1216 --></p>

<p><sn>3.</sn> <def>To put in mind; to remind; -- also used reflexively
and impersonally.</def> <mark>[Obs.]</mark>
<ldquo/<xex>Remembering</xex> them the trith of what they themselves
known.<rdquo/ <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>My friends <qex>remembered</qex> me of home.</q>
<rj><qau>Chapman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Remember</qex> you of passed heaviness.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And well thou wost [knowest] if it <qex>remember</qex> thee.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To mention.</def> <mark>[Obs.]</mark> <ldquo/As in
many cases hereafter to be <xex>remembered</xex>.<rdquo/
<rj><au>Ayliffe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To recall to the mind of another, as in the friendly
messages, <xex>remember</xex> me to him, he wishes to be
<xex>remembered</xex> to you, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remember</ent><br/
<hw>Re*mem"ber</hw> <pr>(r?-m?m"b?r)</pr>, <pos>v. i.</pos> <def>To
execise or have the power of memory; <as>as, some <ex>remember</ex>
better than others</as>.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rememberable</ent><br/
<hw>Re*mem"ber*a*ble</hw> <pr>(-?-b'l)</pr>, <pos>a.</pos> <def>Capable
or worthy of being remembered.</def> --
<wordforms><wf>Re*mem"ber*a*bly</wf>, <pos>adv.</pos></wordforms> <-- =
memorable --><br/
[<source>1913 Webster</source>]</p>

<p><q>The whole vale of Keswick is so <qex>rememberable</qex>.</q>
<rj><qau>Coleridge.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rememberer</ent><br/
<hw>Re*mem"ber*er</hw> <pr>(-?r)</pr>, <pos>n.</pos> <def>One who
remembers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remembrance</ent><br/
<hw>Re*mem"brance</hw> <pr>(-br<it>a</it>ns)</pr>, <pos>n.</pos>
<ety>[OF. <ets>remembrance</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>The act of remembering; a holding in mind, or
bringing to mind; recollection.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Lest fierce <qex>remembrance</qex> wake my sudden rage.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Lest the <qex>remembrance</qex> of his grief should fail.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The state of being remembered, or held in mind;
memory; recollection.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This, ever grateful, in <qex>remembrance</qex> bear.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Something remembered; a person or thing kept in
memory.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>That which serves to keep in or bring to mind; a
memorial; a token; a memento; a souvenir; a memorandum or note of
something to be remembered.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And on his breast a bloody cross he bore,<br/
The dear <qex>remembrance</qex> of his dying Lord.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Keep this <qex>remembrance</qex> for thy Julia's sake.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Something to be remembered; counsel; admonition;
instruction.</def> <mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Power of remembering; reach of personal knowledge;
period over which one's memory extends.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thee I have heard relating what was done<br/
Ere my <qex>remembrance</qex>.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Recollection; reminiscence. See
<er>Memory</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remembrancer</ent><br/
<hw>Re*mem"bran*cer</hw> <pr>(-br<it>a</it>n-s?r)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>One who, or that which, serves to bring to, or keep in,
mind; a memento; a memorial; a reminder.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Premature consiolation is but the <qex>remembrancer</qex> of
sorrow.</q> <rj><qau>Goldsmith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Ye that are the lord's <qex>remembrancers</qex>.</q> <rj><qau>Isa.
lxii. 6. (Rev. Ver.).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A term applied in England to several officers,
having various functions, their duty originally being to bring certain
matters to the attention of the proper persons at the proper time.</def>
<ldquo/The <xex>remembrancer</xex> of the lord treasurer in the
exchequer.<rdquo/ <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rememorate</ent><br/
<hw>Re*mem"o*rate</hw> <pr>(-?-r?t)</pr>, <pos>v. i.</pos> <ety>[L.
<ets>rememoratus</ets>, p. p. of <ets>rememorari</ets>. See
<er>Remember</er>.]</ety> <def>To recall something by means of memory;
to remember.</def> <mark>[Obs.]</mark> <rj><au>Bryskett.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rememoration</ent><br/
<hw>Re*mem`o*ra"tion</hw> <pr>(-r?"sh?n)</pr>, <pos>n.</pos> <ety>[F.
<ets>rem<eacute/moration</ets>, or L. <ets>rememoratio</ets>.]</ety>
<def>A recalling by the faculty of memory; remembrance.</def>
<mark>[Obs. & R.]</mark> <rj><au>Bp. Montagu.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rememorative</ent><br/
<hw>Re*mem"o*ra*tive</hw> <pr>(r?-mEm"?-r?-t?v)</pr>, <pos>a.</pos>
<def>Tending or serving to remind.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remenant</ent><br/
<hw>Rem"e*nant</hw> <pr>(r?m"?-n<it>a</it>nt)</pr>, <pos>n.</pos> <def>A
remnant.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remercy</ent><br/
<ent>Remercie</ent><br/
<mhw>{ <hw>Re*mer"cie</hw>, <hw>Re*mer"cy</hw> }</mhw>
<pr>(r<esl/-m<etil/r"s<ycr/)</pr>, <pos>v. t.</pos> <ety>[F.
<ets>remercier</ets>; pref. <ets>re-</ets> re- + OF. <ets>mercier</ets>
to thank, from OF. & F. <ets>merci</ets>. See <er>Mercy</er>.]</ety>
<def>To thank.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>She him <qex>remercied</qex> as the patron of her life.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remerge</ent><br/
<hw>Re*merge"</hw> <pr>(r?-m?rj")</pr>, <pos>v. i.</pos> <def>To merge
again.</def> <ldquo/<xex>Remerging</xex> in the general Soul.<rdquo/
<rj><au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remewe</ent><br/
<ent>Remeve</ent><br/
<mhw>{ <hw>Re*meve"</hw> <pr>(r?-mEv")</pr>, <hw>Re*mewe"</hw>
<pr>(r?-m?")</pr> }</mhw>, <pos>v. t. & i.</pos> <def>To remove.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remiform</ent><br/
<hw>Rem"i*form</hw> <pr>(r?m"?*f?rm)</pr>, <pos>a.</pos> <ety>[L.
<ets>remus</ets> oar + <ets>-form</ets>.]</ety> <def>Shaped like an
oar.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remiges</ent><br/
\'d8<hw>Rem"i*ges</hw> <pr>(r?m"?*j?z)</pr>, <pos>n. pl.</pos>;
<sing>sing. <singw>Remex</singw>. (r<?/"m<?/ks)</sing>. <ety>[L.
<ets>remex</ets>, <ets>-igis</ets>, an oarsman.]</ety>
<fld>(Zool.)</fld> <def>The quill feathers of the wings of a
bird.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remigrate</ent><br/
<hw>Rem"i*grate</hw> <pr>(r?m"?-gr?t <or/ r?-m?"gr?t; 277)</pr>, <pos>v.
i.</pos> <ety>[L. <ets>remigrare</ets>. See <er>Re</er>-, and
<er>Migrate</er>.]</ety> <def>To migrate again; to go back; to
return.</def> <rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remigration</ent><br/
<hw>Rem`i*gra"tion</hw> <pr>(r?m`?-gr?"sh?n)</pr>, <pos>n.</pos>
<def>Migration back to the place from which one came.</def> <rj><au>Sir
M. Hale.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remind</ent><br/
<hw>Re*mind"</hw> <pr>(r?-m?nd")</pr>, <pos>v. t.</pos> <def>To put
(one) in mind of something; to bring to the remembrance of; to bring to
the notice or consideration of (a person).</def><br/
[<source>1913 Webster</source>]</p>

<p><q>When age itself, which will not be defied, shall begin to arrest,
seize, and <qex>remind</qex> us of our mortality.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reminder</ent><br/
<hw>Re*mind"er</hw> <pr>(-?r)</pr>, <pos>n.</pos> <def>One who, or that
which, reminds; that which serves to awaken remembrance.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remindful</ent><br/
<hw>Re**mind"ful</hw> <pr>(f?l)</pr>, <pos>a.</pos> <def>Tending or
adapted to remind; careful to remind.</def>
<rj><au>Southey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reminiscence</ent><br/
<hw>Rem`i*nis"cence</hw> <pr>(r?m`?-n?s"s<it>e</it>ns)</pr>,
<pos>n.</pos> <ety>[F. <ets>r<eacute/miniscence</ets>, L.
<ets>reminiscentia</ets>.]</ety> <sn>1.</sn> <def>The act or power of
recalling past experience; the state of being reminiscent; remembrance;
memory.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The other part of memory, called <qex>reminiscence</qex>, which is
the retrieving of a thing at present forgot, or but confusedly
remembered.</q> <rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I forgive your want of <qex>reminiscence</qex>, since it is long
since I saw you.</q> <rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is remembered, or recalled to mind; a
statement or narration of remembered experience; a recollection; <as>as,
pleasing or painful <ex>reminiscences</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Remembrance; recollection. See
<er>Memory</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reminiscency</ent><br/
<hw>Rem`i*nis"cen*cy</hw> <pr>(-s<it>e</it>n-s?)</pr>, <pos>n.</pos>
<def>Reminiscence.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reminiscent</ent><br/
<hw>Rem`i*nis"cent</hw> <pr>(-s<it>e</it>nt)</pr>, <pos>a.</pos>
<ety>[L. <ets>reminiscens</ets>, <ets>-entis</ets>, p. pr. of
<ets>reminisci</ets> to recall to mind, to recollect; pref.
<ets>re-</ets> re + a word akin to <ets>mens</ets> mind,
<ets>memini</ets> I remember. See <er>Mind</er>.]</ety> <def>Recalling
to mind, or capable of recalling to mind; having remembrance; reminding
one of something.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Some other of existence of which we have been previously
conscious, and are now <qex>reminiscent</qex>.</q> <rj><qau>Sir W.
Hamilton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reminiscent</ent><br/
<hw>Rem`i*nis"cent</hw> <pr>(r?m`?-n?s"s<it>e</it>nt)</pr>,
<pos>n.</pos> <def>One who is addicted to indulging, narrating, or
recording reminiscences.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reminiscential</ent><br/
<hw>Rem`i*nis*cen"tial</hw> <pr>(-n?s-s?n"sh<it>a</it>l)</pr>,
<pos>a.</pos> <def>Of or pertaining to reminiscence, or
remembrance.</def> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remiped</ent><br/
<hw>Rem"i*ped</hw> <pr>(r?m"?-p?d)</pr>, <pos>a.</pos> <ety>[L.
<ets>remus</ets> oar + <ets>pes</ets>, <ets>pedis</ets>, foot: cf. F.
<ets>r<eacute/mip<egrave/de</ets>.]</ety> <fld>(Zool.)</fld> <def>Having
feet or legs that are used as oars; -- said of certain crustaceans and
insects.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remiped</ent><br/
<hw>Rem"i*ped</hw>, <pos>n.</pos> <fld>(Zool.)</fld> <sd>(a)</sd>
<def>An animal having limbs like oars, especially one of certain
crustaceans.</def> <sd>(b)</sd> <def>One of a group of aquatic beetles
having tarsi adapted for swimming. See <er>Water beetle</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remise</ent><br/
<hw>Re*mise"</hw> <pr>(r?-m?z")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Remised</conjf>
<pr>(-m?zd")</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Remising</conjf>.]</vmorph> <ety>[F. <ets>remise</ets> delivery,
surrender, fr. <ets>remettre</ets> to put back, deliver, L.
<ets>remittere</ets>. See <er>Remit</er>.]</ety> <def>To send, give, or
grant back; to release a claim to; to resign or surrender by deed; to
return.</def> <rj><au>Blackstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remise</ent><br/
<hw>Re*mise"</hw>, <pos>n.</pos> <fld>(Law)</fld> <def>A giving or
granting back; surrender; return; release, as of a claim.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remise</ent><br/
<hw>Re*mise"</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A house
for covered carriages; a chaise house.</def>
<rj><au>Sterne.</au></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>A livery carriage of a kind superior to an ordinary
fiacre; -- so called because kept in a remise.</def>
<rj><au>Cooper.</au></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Remiss</ent><br/
<hw>Re*miss"</hw> <pr>(r?-m?s")</pr>, <pos>a.</pos> <ety>[L.
<ets>remissus</ets>, p. p. of <ets>remittere</ets> to send back, relax.
See <er>Remit</er>.]</ety> <def>Not energetic or exact in duty or
business; not careful or prompt in fulfilling engagements; negligent;
careless; tardy; behindhand; lagging; slack; hence, lacking earnestness
or activity; languid; slow.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou never wast <qex>remiss</qex>, I bear thee witness.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>These nervous, bold; those languid and <qex>remiss</qex>.</q>
<rj><qau>Roscommon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Its motion becomes more languid and <qex>remiss</qex>.</q>
<rj><qau>Woodward.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Slack; dilatory; slothful; negligent; careless;
neglectful; inattentive; heedles; thoughtless.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remiss</ent><br/
<hw>Re*miss"</hw>, <pos>n.</pos> <def>The act of being remiss;
inefficiency; failure.</def> <mark>[Obs.]</mark>
<ldquo/<xex>Remisses</xex> of laws.<rdquo/
<rj><au>Puttenham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remissful</ent><br/
<hw>Re*miss"ful</hw> <pr>(-f?l)</pr>, <pos>a.</pos> <def>Inclined to
remit punishment; lenient; clement.</def> <rj><au>Drayton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remissibility</ent><br/
<hw>Re*mis`si*bil"i*ty</hw> <pr>(r?-m?s`s?-b?l"?-t?)</pr>, <pos>n.</pos>
<def>The state or quality of being remissible.</def> <rj><au>Jer.
Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remissible</ent><br/
<hw>Re*mis"si*ble</hw> <pr>(r?-m?s"s?-b'l)</pr>, <pos>a.</pos> <ety>[L.
<ets>remissibilis</ets>: cf. F. <ets>r<eacute/missible</ets>. See
<er>Remit</er>.]</ety> <def>Capable of being remitted or forgiven.</def>
<rj><au>Feltham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remission</ent><br/
<hw>Re*mis"sion</hw> <pr>(r?-m?sh"?n)</pr>, <pos>n.</pos> <ety>[F.
<ets>r<eacute/mission</ets>, L. <ets>remissio</ets>. See
<er>Remit</er>.]</ety> <sn>1.</sn> <def>The act of remitting,
surrendering, resigning, or giving up.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Discharge from that which is due; relinquishment of
a claim, right, or obligation; pardon of transgression; release from
forfeiture, penalty, debt, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This is my blood of the new testament, which is shed for many for
the <qex>remission</qex> of sins.</q> <rj><qau>Matt. xxvi.
28.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>That ples, therefore, . . . <br/
Will gain thee no <qex>remission</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Diminution of intensity; abatement;
relaxation.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Med.)</fld> <def>A temporary and incomplete
subsidence of the force or violence of a disease or of pain, as
destinguished from <xex>intermission</xex>, in which the disease
completely leaves the patient for a time; abatement.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>The act of sending back.</def> <mark>[R.]</mark>
<rj><au>Stackhouse.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Act of sending in payment, as money;
remittance.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remissive</ent><br/
<hw>Re*mis"sive</hw> <pr>(r?-m?s"s?v)</pr>, <pos>a.</pos> <ety>[L.
<ets>remissivus</ets>. See <er>Remit</er>.]</ety> <def>Remitting;
forgiving; abating.</def> <rj><au>Bp. Hacket.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remissly</ent><br/
<hw>Re*miss"ly</hw> <pr>(r?-m?s"l?)</pr>, <pos>adv.</pos> <def>In a
remiss or negligent manner; carelessly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remissness</ent><br/
<hw>Re*miss"ness</hw>, <pos>n.</pos> <def>Quality or state of being
remiss.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remissory</ent><br/
<hw>Re*mis"so*ry</hw> <pr>(r?-m?s"s?-r?)</pr>, <pos>a.</pos>
<def>Serving or tending to remit, or to secure remission;
remissive.</def> <ldquo/A sacrifice expiatory or
<xex>remissory</xex>.<rdquo/ <rj><au>Latimer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remit</ent><br/
<hw>Re*mit"</hw> <pr>(r?-m?t")</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Remitted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Remitting</conjf>.]</vmorph> <ety>[L. <ets>remittere</ets>,
<ets>remissum</ets>, to send back, to slacken, relax; pref.
<ets>re-</ets> re- + <ets>mittere</ets> to send. See <er>Mission</er>,
and cf. <er>Remise</er>, <er>Remiss</er>.]</ety> <sn>1.</sn> <def>To
send back; to give up; to surrender; to resign.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In the case the law <qex>remits</qex> him to his ancient and more
certain right.</q> <rj><qau>Blackstone.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>In grevious and inhuman crimes, offenders should be
<qex>remitted</qex> to their prince.</q>
<rj><qau>Hayward.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The prisoner was <qex>remitted</qex> to the guard.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To restore.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The archbishop was . . . <qex>remitted</qex> to his liberty.</q>
<rj><qau>Hayward.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Com.)</fld> <def>To transmit or send, esp. to a
distance, as money in payment of a demand, account, draft, etc.; <as>as,
he <ex>remitted</ex> the amount by mail</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To send off or away; hence: <sd>(a)</sd> To refer or
direct (one) for information, guidance, help, etc.
<ldquo/<xex>Remitting</xex> them . . . to the works of Galen.<rdquo/
<au>Sir T. Elyot.</au> <sd>(b)</sd> To submit, refer, or leave
(something) for judgment or decision.</def> <ldquo/Whether the counsel
be good I <xex>remit</xex> it to the wise readers.<rdquo/ <rj><au>Sir T.
Elyot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To relax in intensity; to make less violent; to
abate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>So willingly doth God <qex>remit</qex> his ire.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To forgive; to pardon; to remove.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Whose soever sins ye <qex>remit</qex>, they are
<qex>remitted</qex> unto them.</q> <rj><qau>John xx. 23.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>To refrain from exacting or enforcing; <as>as, to
<ex>remit</ex> the performance of an obligation</as>.</def> <ldquo/The
sovereign was undoubtedly competent to <xex>remit</xex>
penalties.<rdquo/ <rj><au>Macaulay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To relax; release; abate; relinguish; forgive;
pardon; absolve.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remit</ent><br/
<hw>Re*mit"</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To abate in force or
in violence; to grow less intense; to become moderated; to abate; to
relax; <as>as, a fever <ex>remits</ex>; the severity of the weather
<ex>remits</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To send money, as in payment.</def>
<rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remitment</ent><br/
<hw>Re*mit"ment</hw> <pr>(-m<it>e</it>nt)</pr>, <pos>n.</pos> <def>The
act of remitting, or the state of being remitted; remission.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Disavowing the <qex>remitment</qex> of Claudius.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remittal</ent><br/
<hw>Re*mit"tal</hw> <pr>(-t<it>a</it>l)</pr>, <pos>n.</pos> <def>A
remitting; a giving up; surrender; <as>as, the <ex>remittal</ex> of the
first fruits</as>.</def> <rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remittance</ent><br/
<hw>Re*mit"tance</hw> <pr>(r?-m?t"t<it>a</it>ns)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>The act of transmitting money, bills, or the like, esp.
to a distant place, as in satisfaction of a demand, or in discharge of
an obligation.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The sum or thing remitted.</def>
<rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remittee</ent><br/
<hw>Re*mit`tee"</hw> <pr>(r?-m?t`t?")</pr>, <pos>n.</pos>
<fld>(Com.)</fld> <def>One to whom a remittance is sent.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remittent</ent><br/
<hw>Re*mit"tent</hw> <pr>(r?-m?t"t<it>e</it>nt)</pr>, <pos>a.</pos>
<ety>[L. <ets>remittens</ets>, p. pr. : cf. F.
<ets>r<eacute/mittent</ets>.]</ety> <def>Remitting; characterized by
remission; having remissions.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Remittent fever</b></col> <fld>(Med.)</fld>, <cd>a fever
in which the symptoms temporarily abate at regular intervals, but do not
wholly cease. See <altname>Malarial fever</altname>, under
<er>Malarial</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remitter</ent><br/
<hw>Re*mit"ter</hw> <pr>(-t?r)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One
who remits.</def> <specif>Specifically:</specif> <sd>(a)</sd> <def>One
who pardons.</def> <sd>(b)</sd> <def>One who makes remittance.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>The sending or placing back of a
person to a title or right he had before; the restitution of one who
obtains possession of property under a defective title, to his rights
under some valid title by virtue of which he might legally have entered
into possession only by suit.</def> <rj><au>Bouvier.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remittitur</ent><br/
\'d8<hw>Re*mit"ti*tur</hw> <pr>(-t?-t?r)</pr>, <pos>n.</pos> <ety>[L.,
(it) is remitted.]</ety> <fld>(Law)</fld> <sd>(a)</sd> <def>A remission
or surrender, -- <stype>remittitur damnut</stype> being a remission of
excess of damages.</def> <sd>(b)</sd> <def>A sending back, as when a
record is remitted by a superior to an inferior court.</def>
<rj><au>Wharton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remittor</ent><br/
<hw>Re*mit"tor</hw> <pr>(-t?r)</pr>, <pos>n.</pos> <fld>(Law)</fld>
<def>One who makes a remittance; a remitter.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remix</ent><br/
<hw>Re*mix"</hw> <pr>(r?-m?ks")</pr>, <pos>v. t.</pos> <def>To mix again
or repeatedly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remnant</ent><br/
<hw>Rem"nant</hw> <pr>(r?m"n<it>a</it>nt)</pr>, <pos>a.</pos> <ety>[OF.
<ets>remanant</ets>, p. pr. of <ets>remanoir</ets>,
<ets>remaindre</ets>. See <er>Remanent</er>, <er>Remain</er>.]</ety>
<def>Remaining; yet left.</def> <mark>[R.]</mark> <ldquo/Because of the
<xex>remnant</xex> dregs of his disease.<rdquo/
<rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And quiet dedicate her <qex>remnant</qex> life<br/
To the just duties of an humble wife.</q> <rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remnant</ent><br/
<hw>Rem"nant</hw>, <pos>n.</pos> <ety>[OF. <ets>remanant</ets>. See
<er>Remnant</er>, <pos>a.</pos>]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>That which remains after a part is removed,
destroyed, used up, performed, etc.; residue.</def>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>remnant</qex> that are left of the captivity.</q>
<rj><qau>Neh. i. 3.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>remnant</qex> of my tale is of a length<br/
To tire your patience.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A small portion; a slight trace; a fragment; a
little bit; a scrap.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Some odd quirks and <qex>remnants</qex> of wit.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Com.)</fld> <def>An unsold end of piece goods, as
cloth, ribbons, carpets, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Residue; rest; remains; remainder.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remodel</ent><br/
<hw>Re*mod"el</hw> <pr>(r?-m?d"?l)</pr>, <pos>v. t.</pos> <def>To model
or fashion anew; to change the form of.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The corporation had been <qex>remodeled</qex>.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remodification</ent><br/
<hw>Re*mod`i*fi*ca"tion</hw> <pr>(-?-f?-k?"sh?n)</pr>, <pos>n.</pos>
<def>The act of remodifying; the state of being remodified.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remodify</ent><br/
<hw>Re*mod"i*fy</hw> <pr>(r?-m?d"?-f?)</pr>, <pos>v. t.</pos> <def>To
modify again or anew; to reshape.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remoulad</ent><br/
<ent>Remolade</ent><br/
<mhw>{ \'d8<hw>R<eacute/`mo`lade"</hw> <pr>(r?`m?`l?d")</pr>,
\'d8<hw>R<eacute/`mou`lad"</hw> <pr>(r?`m??`l?d")</pr>, }</mhw>
<pos>n.</pos> <ety>[F.]</ety> <sn>1.</sn> <def>A kind of piquant sauce
or salad dressing resembling mayonnaise.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An ointment used in farriery.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Remould</ent><br/
<ent>Remold</ent><br/
<mhw>{ <hw>Re*mold"</hw>, <hw>Re*mould"</hw> }</mhw>
<pr>(r<emac/*m<omac/ld")</pr>, <pos>v. t.</pos> <def>To mold or shape
anew or again; to reshape.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remollient</ent><br/
<hw>Re*mol"lient</hw> <pr>(r?-m?l"y<it>e</it>nt <or/
-l?-<it>e</it>nt)</pr>, <pos>a.</pos> <ety>[L. <ets>remolliens</ets>, p.
pr. of <ets>remollire</ets> to mollify: cf. F.
<ets>r<eacute/mollient</ets>. See <er>Mollient</er>.]</ety>
<def>Mollifying; softening.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remonetization</ent><br/
<hw>Re*mon`e*ti*za"tion</hw> <pr>(r?-m?n`?-t?-z?"sh?n <or/ -m?n`-)</pr>,
<pos>n.</pos> <def>The act of remonetizing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remonetize</ent><br/
<hw>Re*mon"e*tize</hw> <pr>(-t?z)</pr>, <pos>v. t.</pos> <def>To restore
to use as money; <as>as, to <ex>remonetize</ex> silver</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remonstrance</ent><br/
<hw>Re*mon"strance</hw> <pr>(-m?n"str<it>a</it>ns)</pr>, <pos>n.</pos>
<ety>[Cf. OF. <ets>remonstrance</ets>, F. <ets>remonstrance</ets>. See
<er>Remonstrate</er>.]</ety> <sn>1.</sn> <def>The act of
remonstrating</def>; as: <sd>(a)</sd> <def>A pointing out;
manifestation; proof; demonstration.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>You may marvel why I . . . would not rather<br/
Make rash <qex>remonstrance</qex> of my hidden power<br/
Than let him be so lost.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(b)</sd> <def>Earnest presentation of reason in opposition to
something; protest; expostulation.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(R.C.Ch.)</fld> <def>Same as
<er>Monstrance</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remonstrant</ent><br/
<hw>Re*mon"strant</hw> <pr>(-str<it>a</it>nt)</pr>, <pos>a.</pos>
<ety>[LL. <ets>remonstranc</ets>, <ets>-antis</ets>, p. pr. of
<ets>remonstrare</ets>: cf. OF. <ets>remonstrant</ets>, F.
<ets>remontrant</ets>.]</ety> <def>Inclined or tending to remonstrate;
expostulatory; urging reasons in opposition to something.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remonstrant</ent><br/
<hw>Re*mon"strant</hw>, <pos>n.</pos> <def>One who remonstrates</def>;
specifically <fld>(Eccl. Hist.)</fld>, <def>one of the Arminians who
remonstrated against the attacks of the Calvinists in 1610, but were
subsequently condemned by the decisions of the Synod of Dort in 1618.
See <er>Arminian</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remonstrantly</ent><br/
<hw>Re*mon"strant*ly</hw>, <pos>adv.</pos> <def>In a remonstrant
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remonstrate</ent><br/
<hw>Re*mon"strate</hw> <pr>(-str?t)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Remonstrated</conjf>
<pr>(-str<?/*t<?/d)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Remonstrating</conjf>.]</vmorph> <ety>[LL.
<ets>remonstratus</ets>, p. p. of <ets>remonstrare</ets> to remonstrate;
L. pref. <ets>re-</ets> + <ets>monstrare</ets> to show. See
<er>Monster</er>.]</ety> <def>To point out; to show clearly; to make
plain or manifest; hence, to prove; to demonstrate.</def>
<mark>[Obs.]</mark> <rj><au>Jer. Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I will <qex>remonstrate</qex> to you the third door.</q>
<rj><qau>B. Jonson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remonstrate</ent><br/
<hw>Re*mon"strate</hw>, <pos>v. i.</pos> <def>To present and urge
reasons in opposition to an act, measure, or any course of proceedings;
to expostulate; <as>as, to <ex>remonstrate</ex> with a person regarding
his habits; to <ex>remonstrate</ex> against proposed
taxation</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It is proper business of a divine to state cases of conscience,
and to <qex>remonstrate</qex> against any growing corruptions in
practice, and especially in principles.</q>
<rj><qau>Waterland.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- <er>Expostulate</er>, <er>Remonstrate</er>.</syn>
<usage> These words are commonly interchangeable, the principal
difference being that <xex>expostulate</xex> is now used especially to
signify remonstrance by a superior or by one in authority. A son
<xex>remonstrates</xex> against the harshness of a father; a father
<xex>expostulates</xex> with his son on his waywardness. Subjects
<xex>remonstrate</xex> with their rulers; sovereigns
<xex>expostulate</xex> with the parliament or the people.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remonstration</ent><br/
<hw>Re`mon*stra"tion</hw> <pr>(r?`m?n*str?"sh?n)</pr>, <pos>n.</pos>
<ety>[Cf. OF. <ets>remonstration</ets>, LL.
<ets>remonstratio</ets>.]</ety> <def>The act of remonstrating;
remonstrance.</def> <mark>[R.]</mark> <rj><au>Todd.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remonstrative</ent><br/
<hw>Re*mon"stra*tive</hw> <pr>(r?*m?n"str?*t?v)</pr>, <pos>a.</pos>
<def>Having the character of a remonstrance; expressing
remonstrance.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1217 --></p>

<p><ent>Remonstrator</ent><br/
<hw>Re*mon"stra*tor</hw> <pr>(r?*m?n"str?*t?r)</pr>, <pos>n.</pos>
<def>One who remonstrates; a remonsrant.</def> <rj><au>Bp.
Burnet.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remontant</ent><br/
<hw>Re*mon"tant</hw> <pr>(-t<it>a</it>nt)</pr>,
<pos>a.</pos><ety>[F.]</ety> <fld>(Hort.)</fld> <def>Rising again; --
applied to a class of roses which bloom more than once in a season; the
hybrid perpetual roses, of which the Jacqueminot is a well-known
example.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remontoir</ent><br/
\'d8<hw>Re*mon`toir"</hw> <pr>(r<it>e</it>-m<er>?n</er>"tw?r"; E.
r?-m?n"tw?r)</pr>, <pos>n.</pos> <ety>[F.]</ety> <fld>(Horology)</fld>
<def>See under <er>Escapement</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remora</ent><br/
\'d8<hw>Rem"o*ra</hw> <pr>(r?m"?*r?)</pr>, <pos>n.</pos> <ety>[L.: cf.
F. <ets>r<eacute/mora</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Delay; obstacle; hindrance.</def>
<mark>[Obs.]</mark> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>Any one of several species of
fishes belonging to <spn>Echeneis</spn>, <spn>Remora</spn>, and allied
genera. Called also <cref>sucking fish</cref>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The anterior dorsal fin is converted into a large
sucking disk, having two transverse rows of lamellae, situated on the
top of the head. They adhere firmly to sharks and other large fishes and
to vessels by this curious sucker, letting go at will. The pegador, or
remora of sharks (<spn>Echeneis naucrates</spn>), and the swordfish
remora (<spn>Remora brachyptera</spn>), are common American
species.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Surg.)</fld> <def>An instrument formerly in use,
intended to retain parts in their places.</def>
<rj><au>Dunglison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remorate</ent><br/
<hw>Rem"o*rate</hw> <pr>(-r?t)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>remoratus</ets>, p. p. of <ets>remorari</ets>; pref. <ets>re-</ets>
re- + <ets>morari</ets> to delay.]</ety> <def>To hinder; to delay.</def>
<mark>[Obs.]</mark> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remord</ent><br/
<hw>Re*mord"</hw> <pr>(r?-m?rd")</pr>, <pos>v. t.</pos> <ety>[L.
<ets>remordere</ets> to bite again, to torment: cf. F.
<ets>remordre</ets>. See <er>Remorse</er>.]</ety> <def>To excite to
remorse; to rebuke.</def> <mark>[Obs.]</mark>
<rj><au>Skelton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remord</ent><br/
<hw>Re*mord"</hw>, <pos>v. i.</pos> <def>To feel remorse.</def>
<mark>[Obs.]</mark> <rj><au>Sir T. Elyot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remordency</ent><br/
<hw>Re*mord"en*cy</hw> <pr>(-<it>e</it>n*s?)</pr>, <pos>n.</pos>
<def>Remorse; compunction; compassion.</def> <mark>[Obs.]</mark>
<rj><au>Killingbeck.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remorse</ent><br/
<hw>Re*morse"</hw> <pr>(r?*m?rs")</pr>, <pos>n.</pos> <ety>[OE.
<ets>remors</ets>, OF. <ets>remors</ets>,F. <ets>remords</ets>, LL.
<ets>remorsus</ets>, fr. L. <ets>remordere</ets>, <ets>remorsum</ets>,
to bite again or back, to torment; pref. <ets>re-</ets> re- +
<ets>mordere</ets> to bite. See <er>Morsel</er>.]</ety> <sn>1.</sn>
<def>The anguish, like gnawing pain, excited by a sense of guilt;
compunction of conscience for a crime committed, or for the sins of
one's past life.</def> <ldquo/Nero will be tainted with
<xex>remorse</xex>.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Sympathetic sorrow; pity; compassion.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Curse on the unpardoning prince, whom tears can draw<br/
To no <qex>remorse</qex>.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>But evermore it seem'd an easier thing<br/
At once without <qex>remorse</qex> to strike her dead.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Compunction; regret; anguish; grief; compassion.
See <er>Compunction</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remorsed</ent><br/
<hw>Re*morsed"</hw> <pr>(r?-m?rst")</pr>, <pos>a.</pos> <def>Feeling
remorse.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remorseful</ent><br/
<hw>Re*morse"ful</hw> <pr>(-m?rs"f?l)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Full of remorse.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The full tide of <qex>remorseful</qex> passion had abated.</q>
<rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Compassionate; feeling tenderly.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Exciting pity; pitiable.</def> <mark>[Obs.]</mark>
<rj><au>Chapman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Re*morse"ful*ly</wf>, <pos>adv.</pos> --
<wf>Re*morse"ful*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remorseless</ent><br/
<hw>Re*morse"less</hw>, <pos>a.</pos> <def>Being without remorse; having
no pity; hence, destitute of sensibility; cruel; insensible to distress;
merciless.</def> <ldquo/<xex>Remorseless</xex> adversaries.<rdquo/
<au>South.</au> <ldquo/With <xex>remorseless</xex> cruelty.<rdquo/
<au>Milton.</au><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Unpitying; pitiless; relentless; unrelenting;
implacable; merciless; unmerciful; savage; cruel.</syn><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Re*morse"less*ly</wf>, <pos>adv.</pos> --
<wf>Re*morse"less*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remote</ent><br/
<hw>Re*mote"</hw> <pr>(r?-m?t")</pr>, <pos>a.</pos>
<amorph>[<pos>Compar.</pos> <adjf>Remoter</adjf> <pr>(-?r)</pr>;
<pos>superl.</pos> <adjf>Remotest</adjf>.]</amorph> <ety>[L.
<ets>remotus</ets>, p. p. of <ets>removere</ets> to remove. See
<er>Remove</er>.]</ety> <sn>1.</sn> <def>Removed to a distance; not
near; far away; distant; -- said in respect to <xex>time</xex> or to
<xex>place</xex>; <as>as, <ex>remote</ex> ages; <ex>remote</ex>
lands.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Places <qex>remote</qex> enough are in Bohemia.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Remote</qex> from men, with God he passed his days.</q>
<rj><qau>Parnell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence, removed; not agreeing, according, or being
related; -- in various figurative uses.</def> Specifically: <sd>(a)</sd>
<def>Not agreeing; alien; foreign.</def> <ldquo/All these propositions,
how <xex>remote</xex> soever from reason.<rdquo/ <au>Locke.</au>
<sd>(b)</sd> <def>Not nearly related; not close; <as>as, a
<ex>remote</ex> connection or consanguinity</as>.</def> <sd>(c)</sd>
<def>Separate; abstracted.</def> <ldquo/Wherever the mind places itself
by any thought, either amongst, or <xex>remote</xex> from, all
bodies.<rdquo/ <au>Locke.</au> <sd>(d)</sd> <def>Not proximate or acting
directly; primary; distant.</def> <ldquo/From the effect to the
<xex>remotest</xex> cause.<rdquo/ <au>Granville.</au> <sd>(e)</sd>
<def>Not obvious or sriking; <as>as, a <ex>remote</ex>
resemblance</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Bot.)</fld> <def>Separated by intervals greater
than usual.</def><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Re*mote"ly</wf>, <pos>adv.</pos> --
<wf>Re*mote"ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remotion</ent><br/
<hw>Re*mo"tion</hw> <pr>(r?-m?"sh?n)</pr>, <pos>n.</pos> <ety>[L.
<ets>remotio</ets>. See <er>Remove</er>.]</ety> <sn>1.</sn> <def>The act
of removing; removal.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>This <qex>remotion</qex> of the duke and her<br/
Is practice only.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The state of being remote; remoteness.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The whitish gleam [of the stars] was the mask conferred by the
enormity of their <qex>remotion</qex>.</q> <rj><qau>De
Quincey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remould</ent><br/
<hw>Re*mould"</hw> <pr>(r<emac/*m<omac/ld")</pr>, <pos>v. t.</pos>
<def>See <er>Remold</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remount</ent><br/
<hw>Re*mount"</hw> <pr>(r?-mount")</pr>, <pos>v. t. & i.</pos> <def>To
mount again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remount</ent><br/
<hw>Re*mount"</hw>, <pos>n.</pos> <def>The opportunity of, or things
necessary for, remounting; specifically, a fresh horse, with his
equipments; <as>as, to give one a <ex>remount</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Removable</ent><br/
<hw>Re*mov"a*ble</hw> <pr>(r?-m??v"?-b'l)</pr>, <pos>a.</pos>
<def>Admitting of being removed.</def> <au>Ayliffe.</au> --
<wordforms><wf>Re*mov`a*bil"i*ty</wf> <pr>(-<?/-b<?/l"<?/-t<?/)</pr>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Removal</ent><br/
<hw>Re*mov"al</hw> <pr>(-<it>a</it>l)</pr>, <pos>n.</pos> <def>The act
of removing, or the state of being removed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remove</ent><br/
<hw>Re*move"</hw> <pr>(r?-m??v")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Removed</conjf>
<pr>(-m??vd")</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Removing</conjf>.]</vmorph> <ety>[OF. <ets>removoir</ets>,
<ets>remouvoir</ets>, L. <ets>removere</ets>, <ets>remotum</ets>; pref.
<ets>re-</ets> re- + <ets>movere</ets> to move. See
<er>Move</er>.]</ety> <sn>1.</sn> <def>To move away from the position
occupied; to cause to change place; to displace; <as>as, to
<ex>remove</ex> a building</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou shalt not <qex>remove</qex> thy neighbor's landmark.</q>
<rj><qau>Deut. xix. 14.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>When we had dined, to prevent the ladies' leaving us, I generally
ordered the table to be <qex>removed</qex>.</q>
<rj><qau>Goldsmith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To cause to leave a person or thing; to cause to
cease to be; to take away; hence, to banish; to destroy; to put an end
to; to kill; <as>as, to <ex>remove</ex> a disease</as>.</def>
<ldquo/King Richard thus <xex>removed</xex>.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To dismiss or discharge from office; <as>as, the
President <ex>removed</ex> many postmasters</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ See the Note under <er>Remove</er>, <pos>v.
i.</pos></note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remove</ent><br/
<hw>Re*move"</hw> <pr>(r?-m??v")</pr>, <pos>v. i.</pos> <def>To change
place in any manner, or to make a change in place; to move or go from
one residence, position, or place to another.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Till Birnam wood <qex>remove</qex> to Dunsinane,<br/
I can not taint with fear.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The verb <xex>remove</xex>, in some of its application,
is synonymous with <xex>move</xex>, but not in all. Thus we do not apply
<xex>remove</xex> to a mere change of posture, without a change of place
or the seat of a thing. A man <xex>moves</xex> his head when he turns
it, or his finger when he bends it, but he does not <xex>remove</xex>
it. <xex>Remove</xex> usually or always denotes a change of place in a
body, but we never apply it to a regular, continued course or motion. We
never say the wind or water, or a ship, <xex>removes</xex> at a certain
rate by the hour; but we say a ship was <xex>removed</xex> from one
place in a harbor to another. <xex>Move</xex> is a generic term,
including the sense of <xex>remove</xex>, which is more generally
applied to a change from one station or permanent position, stand, or
seat, to another station.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remove</ent><br/
<hw>Re*move"</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act of removing; a
removal.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This place should be at once both school and university, not
needing a <qex>remove</qex> to any other house of scholarship.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And drags at each <qex>remove</qex> a lengthening chain.</q>
<rj><qau>Goldsmith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The transfer of one's business, or of one's domestic
belongings, from one location or dwelling house to another; -- in the
United States usually called a <xex>move</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It is an English proverb that three <qex>removes</qex> are as bad
as a fire.</q> <rj><qau>J. H. Newman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The state of being removed.</def>
<rj><au>Locke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>That which is removed, as a dish removed from table
to make room for something else.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>The distance or space through which anything is
removed; interval; distance; stage; hence, a step or degree in any scale
of gradation; specifically, a division in an English public school;
<as>as, the boy went up two <ex>removes</ex> last year</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A freeholder is but one <qex>remove</qex> from a legislator.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Far.)</fld> <def>The act of resetting a horse's
shoe.</def> <rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Removed</ent><br/
<hw>Re*moved"</hw> <pr>(r?-m??vd")</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Changed in place.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Dismissed from office.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Distant in location; remote.</def> <ldquo/Something
finer than you could purchase in so <xex>removed</xex> a
dwelling.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Distant by degrees in relationship; <as>as, a cousin
once <ex>removed</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Re*mov"ed*ness</wf>
<pr>(r<?/-m<?/<?/v"<?/d-n<?/s)</pr>, <pos>n.</pos></wordforms>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remover</ent><br/
<hw>Re*mov"er</hw> <pr>(-?r)</pr>, <pos>n.</pos> <def>One who removes;
<as>as, a <ex>remover</ex> of landmarks</as>.</def>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remuable</ent><br/
<hw>Re*mu"a*ble</hw> <pr>(r?-m?"?-b'l)</pr>, <pos>a.</pos>
<ety>[F.]</ety> <def>That may be removed; removable.</def>
<mark>[Obs.]</mark> <rj><au>Gower.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remue</ent><br/
<hw>Re*mue"</hw> <pr>(r?-m?")</pr>, <pos>v. t.</pos> <ety>[F.
<ets>remuer</ets>. See <er>Mew</er> to molt.]</ety> <def>To
remove.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remugient</ent><br/
<hw>Re*mu"gi*ent</hw> <pr>(r?-m?"j?-<it>e</it>nt)</pr>, <pos>a.</pos>
<ety>[L. <ets>remugiens</ets>, p. pr. of <ets>remugire</ets>. See
<er>Mugient</er>.]</ety> <def>Rebellowing.</def> <rj><au>Dr. H.
More.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remunerable</ent><br/
<hw>Re**mu"ner*a*ble</hw> <pr>(r?-m?"n?r-?-b'l)</pr>, <pos>a.</pos>
<ety>[See <er>Remunerate</er>.]</ety> <def>Admitting, or worthy, of
remuneration.</def> -- <wordforms><wf>Re*mu`ner*a*bil"i*ty</wf>
<pr>(r<?/-m<?/"n<?/r-<?/-b<?/l"i-t<?/)</pr>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remunerate</ent><br/
<hw>Re*mu"ner*ate</hw> <pr>(-?t)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Remunerated</conjf>
<pr>(-?"t?d)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Remunerating</conjf>.]</vmorph> <ety>[L. <ets>remuneratus</ets>,
p. p. of <ets>remunerare</ets>, <ets>remunerari</ets>; pref.
<ets>re-</ets> re- + <ets>munerare</ets>, <ets>munerari</ets>, to give,
present, from <ets>munus</ets>, <ets>muneris</ets>, a gift, present. Cf.
<er>Munificent</er>.]</ety> <def>To pay an equivalent to for any
service, loss, expense, or other sacrifice; to recompense; to requite;
<as>as, to <ex>remunerate</ex> men for labor</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To reward; recompense; compensate; satisfy;
requite; repay; pay; reimburse.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remuneration</ent><br/
<hw>Re*mu`ner*a"tion</hw> <pr>(-?"sh?n)</pr>, <pos>n.</pos> <ety>[L.
<ets>remuneratio</ets>: cf. F.
<ets>r<eacute/mun<eacute/ration</ets>.]</ety> <sn>1.</sn> <def>The act
of remunerating.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is given to remunerate; an equivalent
given, as for services, loss, or sufferings.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Reward; recompense; compensation; pay; payment;
repayment; satisfaction; requital.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remunerative</ent><br/
<hw>Re*mu"ner*a*tive</hw> <pr>(r?-m?"n?r-?-t?v)</pr>, <pos>a.</pos>
<ety>[Cf.F. <ets>r<eacute/mun<?/ratif</ets>.]</ety> <def>Affording
remuneration; <as>as, a <ex>remunerative</ex> payment for services; a
<ex>remunerative</ex> business</as>.</def>
-<wordforms><wf>Re*mu"ner*a*tive*ly</wf>, <pos>adv.</pos> --
<wf>Re*mu"ner*a*tive*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remuneratory</ent><br/
<hw>Re*mu"ner*a*to*ry</hw> <pr>(-t?-r?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>r<eacute/mun<?/ratoire</ets>.]</ety> <def>Remunerative.</def>
<rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Remurmur</ent><br/
<hw>Re*mur"mur</hw> <pr>(r?-m?r"m?r)</pr>, <pos>v. t. & i.</pos>
<ety>[Pref. <ets>re-</ets> + <ets>murmur</ets>: cf. F.
<ets>remurmurare</ets>.]</ety> <def>To murmur again; to utter back, or
reply, in murmurs.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The trembling trees, in every plain and wood,<br/
Her fate <qex>remurmur</qex> to the silver flood.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ren</ent><br/
<hw>Ren</hw> <pr>(r?n)</pr>, <pos>v. t. & i.</pos> <def>See
<er>Renne</er>.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ren</ent><br/
<hw>Ren</hw>, <pos>n.</pos> <def>A run.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renable</ent><br/
<hw>Ren"a*ble</hw> <pr>(r?n"?-b'l)</pr>, <pos>a.</pos> <ety>[OF.
<ets>resnable</ets>.]</ety> <def>Reasonable; also, loquacious.</def>
<mark>[Obs.]</mark> <ldquo/Most <xex>renable</xex> of tongue.<rdquo/
<au>Piers Plowman.</au> -- <wordforms><wf>Ren"a*bly</wf>,
<pos>adv.</pos> <mark>[Obs.]</mark></wordforms>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renaissance</ent><br/
\'d8<hw>Re*nais`sance"</hw> <pr>(F. r<eit/-n<asl/`s<aum/Ns"; E.
r<esl/-n<amac/s"s<ait/ns)</pr>, <pos>n.</pos> <ety>[F., fr.
<ets>rena<icir/tre</ets> to be born again. Cf.
<er>Renascence</er>.]</ety> <def>A new birth, or revival.</def>
Specifically: <sd>(a)</sd> <def>The transitional movement in Europe,
marked by the revival of classical learning and art in Italy in the 15th
century, and the similar revival following in other countries.</def>
<sd>(b)</sd> <def>The style of art which prevailed at this
epoch.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>Renaissance</qex> was rather the last stage of the Middle
Ages, emerging from ecclesiastical and feudal despotism, developing what
was original in mediaeval ideas by the light of classic arts and
letters.</q> <rj><qau>J. A. Symonds (Encyc. Brit.).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renaissant</ent><br/
<hw>Re*nais"sant</hw> <pr>(r?-n?s"s<it>a</it>nt)</pr>, <pos>a.</pos>
<def>Of or pertaining to the Renaissance.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renal</ent><br/
<hw>Re"nal</hw> <pr>(r<emac/"n<ait/l)</pr>, <pos>a.</pos> <ety>[L.
<ets>renalis</ets>, fr. <ets>renes</ets> the kidneys or reins: cf. F.
<ets>r<eacute/nal</ets>. See <er>Reins</er>.]</ety> <fld>(Anat.)</fld>
<def>Of or pertaining to the kidneys; in the region of the
kidneys.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Renal capsules</b></col> <it>or</it> <col><b>Renal
glands</b></col></mcol>, <cd>the suprarenal capsules. See under
<er>Capsule</er>.</cd> -- <mcol><col><b>Renal casts</b></col>,
<col><b>Renal colic</b></col></mcol>. <fld>(Med.)</fld> <cd>See under
<er>Cast</er>, and <er>Colic</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renal calculus</ent><br/
<hw>Renal calculus</hw> <fld>(Med.)</fld>, <def>an abnormal concretion
formed in the excretory passages of the kidney, composed primarily of
calcium oxalates and phosphates; -- also called <altname>kidney
stone</altname>, <altname>nephrolith</altname>, and <altname>nephritic
calculus</altname> (an obsolete term).</def><br/
[<source>PJC</source>]</p>

<p><ent>Renal-portal</ent><br/
<hw>Re"nal-por`tal</hw> <pr>(r?"n<it>a</it>l-p?r"t<it>a</it>l)</pr>,
<pos>a.</pos> <fld>(Anat.)</fld> <def>Both renal and portal. See
<er>Portal</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rename</ent><br/
<hw>Re*name"</hw> <pr>(r?*n?m")</pr>, <pos>v. t.</pos> <def>To give a
new name to.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renard</ent><br/
<hw>Ren"ard</hw> <pr>(r?n"?rd)</pr>, <pos>n.</pos> <ety>[F.
<ets>renard</ets> the fox, the name of the fox in a celebrated epic
poem, and of German origin, G. <ets>Reinhard</ets>, OHG.
<ets>Reginhard</ets>, properly, strong in counsel; <ets>regin</ets>
counsel (akin to Goth. <ets>ragin</ets>) + <ets>hart</ets> hard. See
<er>Hard</er>.]</ety> <def>A fox; -- so called in fables or familiar
tales, and in poetry.</def> <altsp>[Written also
<asp>reynard</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renardine</ent><br/
<hw>Ren"ard*ine</hw> <pr>(-?n)</pr>, <pos>a.</pos> <def>Of or pertaining
to Renard, the fox, or the tales in which Renard is mentioned.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renascence</ent><br/
<hw>Re*nas"cence</hw> <pr>(r?-n?s"s<it>e</it>ns)</pr>, <pos>n.</pos>
<ety>[See <er>Renascent</er>, and cf. <er>Renaissance</er>.]</ety>
<sn>1.</sn> <def>The state of being renascent.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Read the Ph<oe/nix, and see how the single image of
<qex>renascence</qex> is varied.</q> <rj><qau>Coleridge.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Same as <er>Renaissance</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>Renascence</qex> . . . which in art, in literature, and
in physics, produced such splendid fruits.</q> <rj><qau>M.
Arnold.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renascency</ent><br/
<hw>Re*nas"cen*cy</hw> <pr>(-s<it>e</it>n-s?)</pr>, <pos>n.</pos>
<def>State of being renascent.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renascent</ent><br/
<hw>Re*nas"cent</hw> <pr>(-s<it>e</it>nt)</pr>, <pos>a.</pos> <ety>[L.
<ets>renascens</ets>, p. pr. of <ets>renasci</ets> to be born again;
pref. <ets>re-</ets> re- + <ets>nasci</ets> to be born. See
<er>Nascent</er>.]</ety> <sn>1.</sn> <def>Springing or rising again into
being; being born again, or reproduced.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>See <er>Renaissant</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renascible</ent><br/
<hw>Re*nas"ci*ble</hw> <pr>(-s?-b'l)</pr>, <pos>a.</pos> <ety>[LL.
<ets>renascibilis</ets>, from L. <ets>renasci</ets> to be born
again.]</ety> <def>Capable of being reproduced; ablle to spring again
into being.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renate</ent><br/
<hw>Re*nate"</hw> <pr>(r?-n?t")</pr>, <pos>a.</pos> <ety>[L.
<ets>renatus</ets>, p. p. of <ets>renasci</ets>.]</ety> <def>Born again;
regenerate; renewed.</def> <mark>[Obs.]</mark> <rj><au>Beau. &
Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renavigate</ent><br/
<hw>Re*nav"i*gate</hw> <pr>(r?-n?v"?-g?t)</pr>, <pos>v. t.</pos> <def>To
navigate again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renay</ent><br/
<hw>Re*nay"</hw> <pr>(r?-n?")</pr>, <pos>v. t.</pos> <ety>[OF.
<ets>reneier</ets>, F. <ets>renier</ets>, F. <ets>renier</ets>; L. pref.
<ets>re-</ets> re- + <ets>negare</ets> to deny. See
<er>Renegade</er>.]</ety> <def>To deny; to disown.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rencontre</ent><br/
<hw>Ren*con"tre</hw> <pr>(r?n-k?n"t?r; F. r?N`<er>k?n</er>"tr')</pr>,
<pos>n.</pos> <ety>[F.]</ety> <def>Same as <er>Rencounter</er>,
<pos>n.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rencounter</ent><br/
<hw>Ren*coun"ter</hw> <pr>(r?n-koun"t?r)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Rencountered</conjf>
<pr>(-t?rd)</pr>; <pos>p. pr. & vb/ n.</pos>
<conjf>Rencountering</conjf>.]</vmorph> <ety>[F. <ets>rencontrer</ets>;
pref. <ets>re-</ets> + OF. <ets>encontrer</ets> to encounter. See
<er>Encounter</er>.]</ety> <sn>1.</sn> <def>To meet unexpectedly; to
encounter.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To attack hand to hand.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rencounter</ent><br/
<hw>Ren*coun"ter</hw>, <pos>v. i.</pos> <def>To meet unexpectedly; to
encounter in a hostile manner; to come in collision; to
skirmish.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rencounter</ent><br/
<hw>Ren*coun"ter</hw>, <pos>n.</pos> <ety>[F. <ets>rencontre</ets>, from
<ets>renconter</ets> to meet.]</ety> <sn>1.</sn> <def>A meeting of two
persons or bodies; a collision; especially, a meeting in opposition or
contest; a combat, action, or engagement.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The justling chiefs in rude <qex>rencounter</qex> join.</q>
<rj><qau>Granville.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A causal combat or action; a sudden contest or fight
without premeditation, as between individuals or small
parties.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The confederates should . . . outnumber the enemy in all
<qex>rencounters</qex> and engagements.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Combat; fight; conflict; collision;
clash.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rend</ent><br/
<hw>Rend</hw> <pr>(r<ecr/nd)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Rent</conjf> <pr>(r<ecr/nt)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Rending</conjf>.]</vmorph> <ety>[AS. <ets>rendan</ets>,
<ets>hrendan</ets>; cf. OFries. <ets>renda</ets>, <ets>randa</ets>,
Fries. <ets>renne</ets> to cut, rend, Icel. <ets>hrinda</ets> to push,
thrust, AS. <ets>hrindan</ets>; or cf. Icel. <ets>r<ae/na</ets> to rob,
plunder, Ir. <ets>rannaim</ets> to divide, share, part, W.
<ets>rhanu</ets>, Armor. <ets>ranna</ets>.]</ety> <sn>1.</sn> <def>To
separate into parts with force or sudden violence; to tear asunder; to
split; to burst; <as>as, powder <ex>rends</ex> a rock in blasting;
lightning <ex>rends</ex> an oak.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>The dreadful thunder<br/
Doth <qex>rend</qex> the region.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To part or tear off forcibly; to take away by
force.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>An empire from its old foundations <qex>rent</qex>.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I will surely <qex>rend</qex> the kingdom from thee.</q>
<rj><qau>1 Kings xi. 11.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To rap and rend</b></col>. <cd>See under <er>Rap</er>,
<pos>v. t.</pos>, to snatch.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To tear; burst; break; rupture; lacerate;
fracture; crack; split.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rend</ent><br/
<hw>Rend</hw>, <pos>v. i.</pos> <def>To be rent or torn; to become
parted; to separate; to split.</def> <rj><au>Jer. Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Render</ent><br/
<hw>Rend"er</hw> <pr>(-?r)</pr>, <pos>n.</pos> <ety>[From
<er>Rend</er>.]</ety> <def>One who rends.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Render</ent><br/
<hw>Ren"der</hw> <pr>(r?n"d?r)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Rendered</conjf> <pr>(-d?rd)</pr>;<pos>p. pr. & vb.
n.</pos> <conjf>Rendering</conjf>.]</vmorph> <ety>[F. <ets>rendre</ets>,
LL. <ets>rendre</ets>, fr. L. <ets>reddere</ets>; pref. <ets>red-</ets>,
<ets>re-</ets>, re- + <ets>dare</ets> to give. See <er>Date</er>time,
and cf. <er>Reddition</er>, <er>Rent</er>.]</ety> <sn>1.</sn> <def>To
return; to pay back; to restore.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Whose smallest minute lost, no riches <qex>render</qex> may.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To inflict, as a retribution; to requite.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I will <qex>render</qex> vengeance to mine enemies.</q>
<rj><qau>Deut. xxxii. 41.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To give up; to yield; to surrender.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I 'll make her <qex>render</qex> up her page to me.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Hence, to furnish; to contribute.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Logic <qex>renders</qex> its daily service to wisdom and
virtue.</q> <rj><qau>I. Watts.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To furnish; to state; to deliver; <as>as, to
<ex>render</ex> an account; to <ex>render</ex> judgment</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To cause to be, or to become; <as>as, to
<ex>render</ex> a person more safe or more unsafe; to <ex>render</ex> a
fortress secure.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>To translate from one language into another; <as>as,
to <ex>render</ex> Latin into English</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>To interpret; to set forth, represent, or exhibit;
<as>as, an actor <ex>renders</ex> his part poorly; a singer
<ex>renders</ex> a passage of music with great effect; a painter
<ex>renders</ex> a scene in a felicitous manner</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He did <qex>render</qex> him the most unnatural<br/
That lived amongst men.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>To try out or extract (oil, lard, tallow, etc.) from
fatty animal substances; <as>as, to <ex>render</ex>
tallow</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <def>To plaster, as a wall of masonry, without the use
of lath.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Render</ent><br/
<hw>Ren"der</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To give an account;
to make explanation or confession.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Naut.)</fld> <def>To pass; to run; -- said of the
passage of a rope through a block, eyelet, etc.; <as>as, a rope
<ex>renders</ex> well, that is, passes freely</as>; also, to yield or
give way.</def> <rj><au>Totten.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Render</ent><br/
<hw>Ren"der</hw>, <pos>n.</pos> <sn>1.</sn> <def>A surrender.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A return; a payment of rent.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In those early times the king's household was supported by
specific <qex>renders</qex> of corn and other victuals from the tenants
of the demains.</q> <rj><qau>Blackstone.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>An account given; a statement.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1218 --></p>

<p><ent>Renderable</ent><br/
<hw>Ren"der*a*ble</hw> <pr>(r?n"d?r-?-b'l)</pr>, <pos>a.</pos>
<def>Capable of being rendered.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renderer</ent><br/
<hw>Ren"der*er</hw> <pr>(-?r)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One
who renders.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A vessel in which lard or tallow, etc., is
rendered.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rendering</ent><br/
<hw>Ren"der*ing</hw>, <pos>n.</pos> <def>The act of one who renders, or
that which is rendered.</def> Specifically: <sd>(a)</sd> <def>A version;
translation; <as>as, the <ex>rendering</ex> of the Hebrew
text</as>.</def> <au>Lowth.</au> <sd>(b)</sd> <def>In art, the
presentation, expression, or interpretation of an idea, theme, or
part.</def> <sd>(c)</sd> <def>The act of laying the first coat of
plaster on brickwork or stonework.</def> <sd>(d)</sd> <def>The coat of
plaster thus laid on.</def> <au>Gwilt.</au> <sd>(e)</sd> <def>The
process of trying out or extracting lard, tallow, etc., from animal
fat.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rendezvous</ent><br/
<hw>Ren"dez*vous</hw> <pr>(r?n"d?*v<oomac/ <or/ <er>r?n</er>"-;
277)</pr>, <pos>n.</pos>; <plu><it>pl.</it> <plw>Rendezvouses</plw>
<pr>(r<?/n"d<?/-v<oomac/`z<?/z)</pr>.</plu> <note>[Rare in the
plural.]</note> <ety>[F. <ets>rendez-vous</ets>, properly, render
yourselves, repair to a place. See <er>Render</er>.]</ety> <sn>1.</sn>
<def>A place appointed for a meeting, or at which persons customarily
meet.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>An inn, the free <qex>rendezvous</qex> of all travelers.</q>
<rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Especially, the appointed place for troops, or for
the ships of a fleet, to assemble; also, a place for
enlistment.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The king appointed his whole army to be drawn together to a
<qex>rendezvous</qex> at Marlborough.</q>
<rj><qau>Clarendon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A meeting by appointment.</def>
<rj><au>Sprat.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Retreat; refuge.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rendezvous</ent><br/
<hw>Ren"dez*vous</hw> <pr>(r<ecr/n"d<ecr/*v<oomac/ <or/ r<aum/N"-;
277)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Rendezvoused</conjf> <pr>(-v<oomac/d)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Rendezvousing</conjf>
<pr>(-v<oomac/*<icr/ng)</pr>.]</vmorph> <def>To assemble or meet at a
particular place.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rendezvous</ent><br/
<hw>Ren"dez*vous</hw>, <pos>v. t.</pos> <def>To bring together at a
certain place; to cause to be assembled.</def>
<rj><au>Echard.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rendible</ent><br/
<hw>Rend"i*ble</hw> <pr>(r?nd"?-b'l)</pr>, <pos>a.</pos> <ety>[From
<er>Rend</er>.]</ety> <def>Capable of being rent or torn.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rendible</ent><br/
<hw>Ren"di*ble</hw> <pr>(r?n"d?-b'l)</pr>, <pos>a.</pos> <ety>[See
<er>Render</er>.]</ety> <def>Capable, or admitting, of being
rendered.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rendition</ent><br/
<hw>Ren*di"tion</hw> <pr>(r?n-d?sh"?n)</pr>, <pos>n.</pos> <ety>[LL.
<ets>rendere</ets> to render: cf. L. <ets>redditio</ets>. See
<er>Render</er>, and cf. <er>Reddition</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>The act of rendering; especially, the act of
surrender, as of fugitives from justice, at the claim of a foreign
government; also, surrender in war.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The rest of these brave men that suffered in cold blood after
articles of <qex>rendition</qex>.</q> <rj><qau>Evelyn.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Translation; rendering; version.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This <qex>rendition</qex> of the word seems also most naturally to
agree with the genuine meaning of some other words in the same
verse.</q> <rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rendrock</ent><br/
<hw>Rend"rock`</hw> <pr>(r?nd"r?k`)</pr>, <pos>n.</pos> <def>A kind of
dynamite used in blasting.</def> <mark>[U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renegade</ent><br/
<hw>Ren"e*gade</hw> <pr>(r?n"?-g?d)</pr>, <pos>n.</pos> <ety>[Sp.
<ets>renegado</ets>, LL. <ets>renegatus</ets>, fr. <ets>renegare</ets>
to deny; L. pref. <ets>re-</ets> re- + <ets>negare</ets> to deny. See
<er>Negation</er>, <ets>and cf</ets>. <er>Runagate</er>.]</ety> <def>One
faithless to principle or party.</def> Specifically: <sd>(a)</sd>
<def>An apostate from Christianity or from any form of religious
faith.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>James justly regarded these <qex>renegades</qex> as the most
serviceable tools that he could employ.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(b)</sd> <def>One who deserts from a military or naval post; a
deserter.</def> <au>Arbuthnot.</au> <sd>(c)</sd> <def>A common vagabond;
a worthless or wicked fellow.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renegado</ent><br/
<hw>Ren`e*ga"do</hw> <pr>(r?n`?-g?"d?)</pr>, <pos>n.</pos>
<ety>[Sp.]</ety> <def>See <er>Renegade</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renegat</ent><br/
<hw>Ren"e*gat</hw> <pr>(r?n"?-g?t)</pr>, <pos>n.</pos> <ety>[See
<er>Runegate</er>.]</ety> <def>A renegade.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renegation</ent><br/
<hw>Ren`e*ga"tion</hw> <pr>(r?n`?-ga"sh?n)</pr>, <pos>n.</pos> <def>A
denial.</def> <mark>[R.]</mark> <ldquo/Absolute <xex>renegation</xex> of
Christ.<rdquo/ <rj><au>Milman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renege</ent><br/
<hw>Re*nege"</hw> <pr>(r?-n?j" <or/ r?-n?g")</pr>, <pos>v. t.</pos>
<ety>[LL. <ets>renegare</ets>. See <er>Renegade</er>.]</ety> <def>To
deny; to disown.</def> <mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>All Europe high (all sorts of rights <qex>reneged</qex>)<br/
Against the truth and thee unholy leagued.</q>
<rj><qau>Sylvester.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renege</ent><br/
<hw>Re*nege"</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To deny.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To fail to keep (a commitment or promise); -- often
used with <ptcl>on</ptcl>; <as>as, to <ex>renege</ex> on one's
promise</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <fld>(Card Playing)</fld> <def>To revoke; to play a card
that cannot legally be played according to the rules.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Renerve</ent><br/
<hw>Re*nerve"</hw> <pr>(r?-n?rv")</pr>, <pos>v. t.</pos> <def>To nerve
again; to give new vigor to; to reinvigorate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renew</ent><br/
<hw>Re*new"</hw> <pr>(r?-n?")</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Reneved</conjf> <pr>(-n?d")</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Renewing</conjf>.]</vmorph> <ety>[Pref. <ets>re-</ets> +
<ets>new</ets>. Cf. <er>Renovate</er>.]</ety> <sn>1.</sn> <def>To make
new again; to restore to freshness, perfection, or vigor; to give new
life to; to rejuvenate; to re<eum/stablish; to recreate; to
rebuild.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In such a night<br/
Medea gathered the enchanted herbs<br/
That did <qex>renew</qex> old Aeson.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Specifically, to substitute for (an old obligation
or right) a new one of the same nature; to continue in force; to make
again; <as>as, to <ex>renew</ex> a lease, note, or
patent</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To begin again; to recommence.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The last great age . . . <qex>renews</qex> its finished
course.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To repeat; to go over again.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The birds-their notes <qex>renew</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Theol.)</fld> <def>To make new spiritually; to
regenerate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Be ye transformed by the <qex>renewing</qex> of your mind.</q>
<rj><qau>Rom. xii. 2.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renew</ent><br/
<hw>Re*new"</hw>, <pos>v. i.</pos> <def>To become new, or as new; to
grow or begin again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renewability</ent><br/
<hw>Re*new`a*bil"i*ty</hw> <pr>(-?-b?l"?-t?)</pr>, <pos>n.</pos>
<def>The quality or state of being renewable.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renewable</ent><br/
<hw>Re*new"a*ble</hw> <pr>(r?-n?"?-b'l)</pr>, <pos>a.</pos> <def>Capable
of being renewed; <as>as, a lease <ex>renewable</ex> at
pleasure</as>.</def> <rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renewal</ent><br/
<hw>Re*new"al</hw> <pr>(-<it>a</it>l)</pr>, <pos>n.</pos> <def>The act
of renewing, or the state of being renewed; <as>as, the <ex>renewal</ex>
of a treaty</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renewedly</ent><br/
<hw>Re*new"ed*ly</hw>, <pos>adv.</pos> <def>Again; once more.</def>
<mark>[U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renewedness</ent><br/
<hw>Re*new"ed*ness</hw>, <pos>n.</pos> <def>The state of being
renewed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renewer</ent><br/
<hw>Re*new"er</hw> <pr>(-?r)</pr>, <pos>n.</pos> <def>One who, or that
which, renews.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reneye</ent><br/
<hw>Re*neye"</hw> <pr>(r?-n?")</pr>, <pos>v. t.</pos> <ety>[See
<er>Renay</er>.]</ety> <def>To deny; to reject; to renounce.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>For he made every man <qex>reneye</qex> his law.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reng</ent><br/
<hw>Reng</hw> <pr>(r?ng)</pr>, <pos>n.</pos> <ety>[See <er>Rank</er>,
<pos>n.</pos>]</ety> <sn>1.</sn> <def>A rank; a row.</def>
<mark>[Obs.]</mark> <ldquo/In two <xex>renges</xex> fair.<rdquo/
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A rung or round of a ladder.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renidification</ent><br/
<hw>Re*nid`i*fi*ca"tion</hw> <pr>(r?-n?d`?-f?-k?"sh?n)</pr>,
<pos>n.</pos> <fld>(Zool.)</fld> <def>The act of rebuilding a
nest.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reniform</ent><br/
<hw>Ren"i*form</hw> <pr>(r?n"?-f?rm; 277)</pr>, <pos>a.</pos> <ety>[L.
<ets>renes</ets> kidneys + <ets>-form</ets>: cf. F.
<ets>r<eacute/niforme</ets>.]</ety> <def>Having the form or shape of a
kidney; <as>as, a <ex>reniform</ex> mineral; a <ex>reniform</ex>
leaf.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renitency</ent><br/
<ent>Renitence</ent><br/
<mhw>{ <hw>Re*ni"tence</hw> <pr>(r?-n?"t<it>e</it>ns)</pr>,
<hw>Re*ni"ten*cy</hw> <pr>(-t<it>e</it>-s?)</pr>, }</mhw> <pos>n.</pos>
<ety>[Cf. F. <ets>r<eacute/nitence</ets>.]</ety> <def>The state or
quality of being renitent; resistance; reluctance.</def>
<rj><au>Sterne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>We find a <qex>renitency</qex> in ourselves to ascribe life and
irritability to the cold and motionless fibers of plants.</q>
<rj><qau>E. Darwin.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renitent</ent><br/
<hw>Re*ni"tent</hw> <pr>(-t<it>e</it>nt)</pr>, <pos>a.</pos> <ety>[L.
<ets>renitens</ets>, <ets>-entis</ets>, p. pr. of <ets>renit</ets> to
strive or struggle against, resist; pref. <ets>re-</ets> re- +
<ets>niti</ets> to struggle or strive: cf. F.
<ets>r<eacute/nitent</ets>.]</ety> <sn>1.</sn> <def>Resisting pressure
or the effect of it; acting against impulse by elastic force.</def>
<ldquo/[Muscles] soft and yet <xex>renitent</xex>.<rdquo/
<rj><au>Ray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Persistently opposed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renne</ent><br/
<hw>Ren"ne</hw> <pr>(r?n"n<it>e</it>)</pr>, <pos>v. t.</pos> <def>To
plunder; -- only in the phrase <ldquo/to rape and
<xex>renne</xex>.<rdquo/ See under <er>Rap</er>, <pos>v. t.</pos>, to
snatch.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renne</ent><br/
<hw>Ren"ne</hw>, <pos>v. i.</pos> <def>To run.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renner</ent><br/
<hw>Ren"ner</hw> <pr>(-n?r)</pr>, <pos>n.</pos> <def>A runner.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rennet</ent><br/
<hw>Ren"net</hw> <pr>(r?n"n?t)</pr>, <pos>n.</pos> <ety>[F.
<ets>rainette</ets>, <ets>reinette</ets>, perhaps fr. <ets>raine</ets> a
tree frog, L. <ets>rana</ets>, because it is spotted like this kind of
frog. Cf. <er>Ranunculus</er>.]</ety> <fld>(Bot.)</fld> <def>A name of
many different kinds of apples. Cf. <er>Reinette</er>.</def>
<rj><au>Mortimer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rennet</ent><br/
<hw>Ren"net</hw>, <pos>n.</pos> <ety>[AS. <ets>rinnan</ets>,
<ets>rennan</ets>, to run, cf. <ets>gerinnan</ets> to curdle, coagulate.
<root/11. See <er>Run</er>, <pos>v.</pos>]</ety> <sn>1.</sn> <def>The
inner, or mucous, membrane of the fourth stomach of the calf, or other
young ruminant.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>an infusion or preparation of the calf stomach
lining, used for coagulating milk. The active principle in this
coagulating action is the enzyme <er>rennin</er>.</def> <altsp>[Written
also <asp>runnet</asp>.]</altsp><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><cs><col><b>Cheese rennet</b></col>. <fld>(Bot.)</fld> <cd>See under
<er>Cheese</er>.</cd> -- <col><b>Rennet ferment</b></col> <fld>(Physiol.
Chem.)</fld>, <cd>the enzyme <er>rennin</er>, present in rennet and in
variable quantity in the gastric juice of most animals, which has the
power of curdling milk. The enzyme presumably acts by changing the
casein of milk from a soluble to an insoluble form.</cd> --
<col><b>Rennet stomach</b></col> <fld>(Anat.)</fld>, <cd>the fourth
stomach, or abomasum, of ruminants.</cd></cs><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Renneted</ent><br/
<hw>Ren"net*ed</hw>, <pos>a.</pos> <def>Provided or treated with
rennet.</def> <mark>[R.]</mark> <ldquo/Pressed milk
<xex>renneted</xex>.<rdquo/ <rj><au>Chapman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renneting</ent><br/
<hw>Ren"net*ing</hw>, <pos>n.</pos> <fld>(Bot.)</fld> <def>Same as 1st
<er>Rennet</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rennin</ent><br/
<hw>Ren"nin</hw> <pr>(r<ecr/n"n<icr/n)</pr>, <pos>n.</pos>
<fld>(Biochem.)</fld> <def>A milk-clotting enzyme obtained from the true
stomach (abomasum) of a suckling calf. Mol. wt. about 31,000. Also
called <altname>chymosin</altname>, <altname>rennase</altname>, and
<altname>abomasal enzyme</altname>.</def> <au>[Merck Man. 11]</au><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renning</ent><br/
<hw>Ren"ning</hw> <pr>(r?n"n?ng)</pr>, <pos>n.</pos> <def>See 2d
<er>Rennet</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Asses' milk is holden for to be thickest, and therefore they use
it instead of <qex>renning</qex>, to turn milk.</q>
<rj><qau>Holland.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renomee</ent><br/
<hw>Re`no*mee"</hw> <pr>(r<amac/`n<osl/*m<amac/")</pr>, <pos>n.</pos>
<ety>[F. <ets>renomm<eacute/e</ets>.]</ety> <def>Renown.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renounce</ent><br/
<hw>Re*nounce"</hw> <pr>(r<esl/*nouns")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Renounced</conjf>
<pr>(-nounst")</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Renouncing</conjf> <pr>(-noun"s?ng)</pr>.]</vmorph> <ety>[F.
<ets>renoncer</ets>, L. <ets>renuntiare</ets> to bring back word,
announce, revoke, retract, renounce; pref. <ets>re-</ets> re- +
<ets>nuntiare</ets> to announce, fr. <ets>nuncius</ets>, a messenger.
See <er>Nuncio</er>, <ets>and cf</ets>. <er>Renunciation</er>.]</ety>
<sn>1.</sn> <def>To declare against; to reject or decline formally; to
refuse to own or acknowledge as belonging to one; to disclaim; <as>as,
to <ex>renounce</ex> a title to land or to a throne</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To cast off or reject deliberately; to disown; to
dismiss; to forswear.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This world I do <qex>renounce</qex>, and in your sights<br/
Shake patiently my great affliction off.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Card Playing)</fld> <def>To disclaim having a card
of (the suit led) by playing a card of another suit.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To renounce probate</b></col> <fld>(Law)</fld>, <cd>to
decline to act as the executor of a will.</cd> <au>Mozley &
W.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To cast off; disavow; disown; disclaim; deny;
abjure; recant; abandon; forsake; quit; forego; resign; relinquish; give
up; abdicate.</syn> <usage> -- <er>Renounce</er>, <er>Abjure</er>,
<er>Recant</er>. -- To <xex>renounce</xex> is to make an affirmative
declaration of abandonment. To <xex>abjure</xex> is to renounce with, or
as with, the solemnity of an oath. To <xex>recant</xex> is to renounce
or abjure some proposition previously affirmed and
maintained.</usage><br/
[<source>1913 Webster</source>]</p>

<p><q>From Thebes my birth I own; . . . since no disgrace<br/
Can force me to <qex>renounce</qex> the honor of my race.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Either to die the death, or to <qex>abjure</qex><br/
Forever the society of man.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Ease would <qex>recant</qex><br/
Vows made in pain, as violent and void.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renounce</ent><br/
<hw>Re*nounce"</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To make
renunciation.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He of my sons who fails to make it good,<br/
By one rebellious act <qex>renounces</qex> to my blood.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>To decline formally, as an executor
or a person entitled to letters of administration, to take out probate
or letters.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Dryden died without a will, and his widow having
<qex>renounced</qex>, his son Charles administered on June 10.</q>
<rj><qau>W. D. Christie.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renounce</ent><br/
<hw>Re*nounce"</hw>, <pos>n.</pos> <fld>(Card Playing)</fld> <def>Act of
renouncing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renouncement</ent><br/
<hw>Re*nounce"ment</hw> <pr>(-m<it>e</it>nt)</pr>, <pos>n.</pos>
<ety>[Cf. F. <ets>renoncement</ets>.]</ety> <def>The act of disclaiming
or rejecting; renunciation.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renouncer</ent><br/
<hw>Re*noun"cer</hw> <pr>(r?-noun"s?r)</pr>, <pos>n.</pos> <def>One who
renounces.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renovate</ent><br/
<hw>Ren"o*vate</hw> <pr>(r?n"?-v?t)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>renovatus</ets>, p. p. of <ets>renovare</ets>;pref. <ets>re-</ets>
re- + <ets>novare</ets> to make new, fr. <ets>novus</ets> new. See
<er>New</er>, and <?/<?/ <er>Renew</er>.]</ety> <def>To make over again;
to restore to freshness or vigor; to renew.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>All nature feels the <qex>reniovating</qex> force<br/
Of winter.</q> <rj><qau>Thomson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renovation</ent><br/
<hw>Ren`o**va"tion</hw> <pr>(-v?"sh?n)</pr>, <pos>n.</pos> <ety>[L.
<ets>renovatio</ets>: cf. F. <ets>r<eacute/novation</ets>.]</ety>
<def>The act or process of renovating; the state of being renovated or
renewed.</def> <rj><au>Thomson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>There is something inexpressibly pleasing in the annual
<qex>renovation</qex> of the world.</q> <rj><qau>Rabbler.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renovator</ent><br/
<hw>Ren"o*va`tor</hw> <pr>(r?n"?-v?`t?r)</pr>, <pos>n.</pos> <ety>[L.:
cf. F. <ets>r<eacute/novateur</ets>.]</ety> <def>One who, or that which,
renovates.</def> <rj><au>Foster.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renovel</ent><br/
<hw>Re*nov"el</hw> <pr>(r?-n?v"<it>e</it>l)</pr>, <pos>v. t.</pos>
<ety>[F. <ets>renouveler</ets> to renew.]</ety> <def>To renew; to
renovate.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renovelance</ent><br/
<hw>Re*nov"el*ance</hw> <pr>(-<it>a</it>ns)</pr>, <pos>n.</pos>
<def>Renewal.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renowme</ent><br/
<hw>Re*nowme"</hw> <pr>(r?-noum")</pr>, <pos>n.</pos> <def>Renown.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The glory and <qex>renowme</qex> of the ancectors.</q>
<rj><qau>Robynson (More's Utopia).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renowmed</ent><br/
<hw>Re*nowmed"</hw> <pr>(r?-noumd")</pr>, <pos>a.</pos>
<def>Renowned.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renown</ent><br/
<hw>Re*nown"</hw> <pr>(r?-noun")</pr>, <pos>n.</pos> <ety>[F.
<ets>renom</ets>. See <er>Noun</er>, and cf. <er>Renown</er>,
<pos>v.</pos>]</ety> <sn>1.</sn> <def>The state of being much known and
talked of; exalted reputation derived from the extensive praise of great
achievements or accomplishments; fame; celebrity; -- always in a good
sense.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Nor envy we<br/
Thy great <qex>renown</qex>, nor grudge thy victory.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Report of nobleness or exploits; praise.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This famous duke of Milan,<br/
Of whom so often I have heard <qex>renown</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renown</ent><br/
<hw>Re*nown"</hw> <pr>(r?-noun")</pr>, <pos>v. t.</pos> <ety>[F.
<ets>renommer</ets> to name again, celebrate, make famous; pref.
<ets>re-</ets> re- + <ets>nommer</ets> to name, L. <ets>nominare</ets> ,
fr. <ets>nomen</ets> a name. See <er>Noun</er>.]</ety> <def>To make
famous; to give renown to.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>For joy to hear me so <qex>renown</qex> his son.</q>
<rj><qau>Chapman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The bard whom pilfered pastorals <qex>renown</qex>.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renowned</ent><br/
<hw>Re*nowned"</hw> <pr>(r?-nound")</pr>, <pos>a.</pos> <def>Famous;
celebrated for great achievements, for distinguished qualities, or for
grandeur; eminent; <as>as, a <ex>renowned</ex> king</as>.</def>
<ldquo/Some <xex>renowned</xex> metropolis with glistering
spires.<rdquo/ <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>These were the <qex>renowned</qex> of the congregation.</q>
<rj><qau>Num. i. 61.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Famous; famed; distinguished; noted; eminent;
celebrated; remarkable; wonderful. See <er>Famous</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renownedly</ent><br/
<hw>Re*nown"ed*ly</hw> <pr>(r?-noun"?d-l?)</pr>, <pos>adv.</pos>
<def>With renown.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renowner</ent><br/
<hw>Re*nown"er</hw> <pr>(-?r)</pr>, <pos>n.</pos> <def>One who gives
renown.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renownful</ent><br/
<hw>Re*nown"ful</hw> <pr>(-f?l)</pr>, <pos>a.</pos> <def>Having great
renown; famous.</def> <ldquo/<xex>Renownful</xex> Scipio.<rdquo/
<rj><au>Marston.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renownless</ent><br/
<hw>Re*nown"less</hw>, <pos>a.</pos> <def>Without renown;
inglorius.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rensselaerite</ent><br/
<hw>Rens"se*laer*ite</hw> <pr>(r?ns"s<it>e</it>-l?r-?t)</pr>,
<pos>n.</pos> <fld>(Min.)</fld> <def>A soft, compact variety of talc,,
being an altered pyroxene. It is often worked in a lathe into inkstands
and other articles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rent</ent><br/
<hw>Rent</hw> <pr>(r<ecr/nt)</pr>, <pos>v. i.</pos> <def>To rant.</def>
<mark>[R. & Obs.]</mark> <rj><au>Hudibras.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rent</ent><br/
<hw>Rent</hw> <pr>(r<ecr/nt)</pr>, <def><pos>imp. & p. p.</pos> of
<er>Rend</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rent</ent><br/
<hw>Rent</hw> <pr>(r<ecr/nt)</pr>, <pos>n.</pos> <ety>[From
<er>Rend</er>.]</ety> <sn>1.</sn> <def>An opening made by rending; a
break or breach made by force; a tear.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>See what a <qex>rent</qex> the envious Casca made.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Figuratively, a schism; a rupture of harmony; a
separation; <as>as, a <ex>rent</ex> in the church</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Fissure; breach; disrupture; rupture; tear;
dilaceration; break; fracture.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rent</ent><br/
<hw>Rent</hw> <pr>(r<ecr/nt)</pr>, <pos>v. t.</pos> <def>To tear. See
<er>Rend</er>.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rent</ent><br/
<hw>Rent</hw> <pr>(r<ecr/nt)</pr>, <pos>n.</pos> <ety>[F.
<ets>rente</ets>, LL. <ets>renta</ets>, fr. L. <ets>reddita</ets>, fem.
sing. or neut. pl. of <ets>redditus</ets>, p. p. of <ets>reddere</ets>
to give back, pay. See <er>Render</er>.]</ety> <sn>1.</sn> <def>Income;
revenue. See <er>Catel</er>.</def> <mark>[Obs.]</mark> <ldquo/Catel had
they enough and <xex>rent</xex>.<rdquo/ <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>[Bacchus] a waster was and all his <qex>rent</qex><br/
In wine and bordel he dispent.</q> <rj><qau>Gower.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>So bought an annual <qex>rent</qex> or two,<br/
And liv'd, just as you see I do.</q> <rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Pay; reward; share; toll.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Death, that taketh of high and low his <qex>rent</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Law)</fld> <def>A certain periodical profit,
whether in money, provisions, chattels, or labor, issuing out of lands
and tenements in payment for the use; commonly, a certain pecuniary sum
agreed upon between a tenant and his landlord, paid at fixed intervals
by the lessee to the lessor, for the use of land or its appendages;
<as>as, <ex>rent</ex> for a farm, a house, a park, etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The term <xex>rent</xex> is also popularly applied to
compensation for the use of certain personal chattels, as a piano, a
sewing machine, etc.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Polit. Econ.)</fld> <sd>(a)</sd> <def>That portion
of the produce of the earth paid to the landlord for the use of the
<ldquo/original and indestructible powers of the soil;<rdquo/ the excess
of the return from a given piece of cultivated land over that from land
of equal area at the <ldquo/margin of cultivation.<rdquo/ Called also
<altname>economic rent</altname>, <it>or</it> <altname>Ricardian
rent</altname>. Economic rent is due partly to differences of
productivity, but chiefly to advantages of location; it is equivalent to
ordinary or commercial rent less interest on improvements, and nearly
equivalent to <xex>ground rent</xex>.</def> <sd>(b)</sd> <def>Loosely, a
return or profit from a differential advantage for production, as in
case of income or earnings due to rare natural gifts creating a natural
monopoly.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><cs><col><b>Black rent</b></col>. <cd>See <er>Blackmail</er>, 3.</cd>
-- <col><b>Forehand rent</b></col>, <cd>rent which is paid in advance;
foregift.</cd> -- <col><b>Rent arrear</b></col>, rent in arrears; unpaid
rent. <au>Blackstone.</au> -- <col><b>Rent charge</b></col>
<fld>(Law)</fld>, <cd>a rent reserved on a conveyance of land in fee
simple, or granted out of lands by deed; -- so called because, by a
covenant or clause in the deed of conveyance, the land is charged with a
distress for the payment of it.</cd> <au>Bouvier.</au> -- <col><b>Rent
roll</b></col>, <cd>a list or account of rents or income; a rental.</cd>
-- <col><b>Rent seck</b></col> <fld>(Law)</fld>, <cd>a rent reserved by
deed, but without any clause of distress; barren rent. A power of
distress was made incident to rent seck by Statute 4 George II. c.
28.</cd> -- <col><b>Rent service</b></col> <fld>(Eng. Law)</fld>,
<cd>rent reserved out of land held by fealty or other corporeal service;
-- so called from such service being incident to it.</cd> --
<col><b>White rent</b></col>, <cd>a quitrent when paid in silver; --
opposed to <xex>black rent</xex>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rent</ent><br/
<hw>Rent</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Rented</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Renting</conjf>.]</vmorph> <ety>[F. <ets>renter</ets>. See
<er>Rent</er>, <pos>n.</pos>]</ety> <sn>1.</sn> <def>To grant the
possession and enjoyment of, for a rent; to lease; <as>as, the owwner of
an estate or house <ex>rents</ex> it</as>.</def><-- = rent out; to let
--><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To take and hold under an agreement to pay rent;
<as>as, the tennant <ex>rents</ex> an estate of the
owner</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rent</ent><br/
<hw>Rent</hw>, <pos>v. i.</pos> <def>To be leased, or let for rent;
<as>as, an estate <ex>rents</ex> for five hundred dollars a
year</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rentable</ent><br/
<hw>Rent"a*ble</hw> <pr>(-?-b'l)</pr>, <pos>a.</pos> <def>Capable of
being rented, or suitable for renting.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rentage</ent><br/
<hw>Rent"age</hw> <pr>(-?j)</pr>, <pos>n.</pos> <ety>[Cf. OF.
<ets>rentage</ets>.]</ety> <def>Rent.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rental</ent><br/
<hw>Rent"al</hw> <pr>(-<it>a</it>l)</pr>, <pos>n.</pos> <ety>[LL.
<ets>rentale</ets>, fr. <ets>renta</ets>. See <er>Rent</er>
income.]</ety> <sn>1.</sn> <def>A schedule, account, or list of rents,
with the names of the tenants, etc.; a rent roll.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A sum total of rents; <as>as, an estate that yields
a <ex>rental</ex> of ten thousand dollars a year</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rente</ent><br/
\'d8<hw>Rente</hw> <pr>(r<aum/Nt)</pr>, <pos>n.</pos> <ety>[F. See
<er>Rent</er> income.]</ety> <def>In France, interest payable by
government on indebtedness; the bonds, shares, stocks, etc., which
represent government indebtedness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renter</ent><br/
<hw>Rent"er</hw> <pr>(r?nt"?r)</pr>, <pos>n.</pos> <def>One who rents or
leases an estate; -- usually said of a lessee or tenant.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renter</ent><br/
<hw>Ren"ter</hw> <pr>(r?n"t?r)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Rentered</conjf> <pr>(-t?rd)</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>Rentering</conjf>.]</vmorph> <ety>[F.
<ets>rentraire</ets>; L. pref. <ets>re-</ets> re- + <ets>in</ets> into,
in + <ets>trahere</ets> to draw.]</ety> <sn>1.</sn> <def>To sew together
so that the seam is scarcely visible; to sew up with skill and nicety;
to finedraw.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To restore the original design of, by working in new
warp; -- said with reference to tapestry.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renterer</ent><br/
<hw>Ren"ter*er</hw> <pr>(-?r)</pr>, <pos>n.</pos> <def>One who
renters.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rentier</ent><br/
\'d8<hw>Ren`tier"</hw> <pr>(r?N`ty?")</pr>, <pos>n.</pos> <ety>[F. See
5th <er>Rent</er>.]</ety> <def>One who has a fixed income, as from
lands, stocks, or the like.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renumerate</ent><br/
<hw>Re*nu"mer*ate</hw> <pr>(r?-n?"m?r-?t)</pr>, <pos>v. t.</pos>
<ety>[L. <ets>renumeratus</ets>, p. p. of <ets>renumerare</ets> to count
over, count up; pref. <ets>re-</ets> re- + <ets>numerare</ets> to count.
See <er>Numerate</er>.]</ety> <def>To recount.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renunciation</ent><br/
<hw>Re*nun`ci*a"tion</hw> <pr>(r?-n?n`s?-?"sh?n <or/ -sh?-?"sh?n;
277)</pr>, <pos>n.</pos> <ety>[Cf. F. <ets>renonciation</ets>, L.
<ets>renuntiatio</ets> ann announcement. See <er>Renounce</er>.]</ety>
<sn>1.</sn> <def>The act of renouncing.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>Formal declination to take out
letters of administration, or to assume an office, privilege, or
right.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Renouncement; disownment; disavowal; disavowment;
disclaimer; rejection; abjuration; recantation; denial; abandonment;
relinquishment.</syn><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1219 --></p>

<p><ent>Renunciatory</ent><br/
<hw>Re*nun"ci*a*to*ry</hw> <pr>(r?-n?n"sh?-?-t?-r?)</pr>, <pos>a.</pos>
<ety>[Cf. LL. <ets>renuntiatorius</ets>.]</ety> <def>Pertaining to
renunciation; containing or declaring a renunciation; <as>as,
<ex>renunciatory</ex> vows</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renverse</ent><br/
<hw>Ren*verse"</hw> <pr>(r?n-vErs")</pr>, <pos>v. t.</pos> <ety>[F.
<ets>renverser</ets>; L. pref. <ets>re-</ets> re- + <ets>in</ets> in,
into + <ets>versare</ets>, v. intens. fr. <ets>vertere</ets> to
turn.]</ety> <def>To reverse.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Whose shield he bears <qex>renverst</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renverse</ent><br/
<ent>Renverse</ent><br/
<mhw>{ <hw>Ren*verse"</hw> <pr>(r?n*v?rs")</pr>, <it>or</it>
\'d8<hw>Ren`ver`s<eacute/"</hw> <pr>(r?n`v?r`s?")</pr> }</mhw>,
<pos>a.</pos> <ety>[F. <ets>renvers<eacute/</ets>, <ets>p. p.</ets>
]</ety> <fld>(Her.)</fld> <def>Reversed; set with the head downward;
turned contrary to the natural position.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renversement</ent><br/
<hw>Ren*verse"ment</hw> <pr>(-m<it>e</it>nt)</pr>, <pos>n.</pos>
<ety>[F.]</ety> <def>A reversing.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renvoy</ent><br/
<hw>Ren*voy"</hw> <pr>(-voi")</pr>, <pos>v. t.</pos> <ety>[F.
<ets>renvoyer</ets>.]</ety> <def>To send back.</def> <mark>[Obs.]</mark>
<ldquo/Not dismissing or <xex>renvoying</xex> her.<rdquo/
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Renvoy</ent><br/
<hw>Ren*voy"</hw>, <pos>n.</pos> <ety>[F. <ets>renvoi</ets>.]</ety>
<def>A sending back.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reobtain</ent><br/
<hw>Re`ob*tain"</hw> <pr>(r?`?b-t?n")</pr>, <pos>v. t.</pos> <def>To
obtain again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reobtainable</ent><br/
<hw>Re`ob*tain"a*ble</hw> <pr>(-?-b'l)</pr>, <pos>a.</pos> <def>That may
be reobtained.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reoccupy</ent><br/
<hw>Re*oc"cu*py</hw> <pr>(r?-?k"k?-p?)</pr>, <pos>v. t.</pos> <def>To
occupy again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reometer</ent><br/
<hw>Re*om"e*ter</hw> <pr>(r?-?m"?-t$r)</pr>, <pos>n.</pos> <def>Same as
<er>Rheometer</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reopen</ent><br/
<hw>Re*o"pen</hw> <pr>(r?-?"p'n)</pr>, <pos>v. t. & i.</pos> <def>To
open again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reoppose</ent><br/
<hw>Re`op*pose"</hw> <pr>(r?`?p-p?z")</pr>, <pos>v. t.</pos> <def>To
oppose again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reordain</ent><br/
<hw>Re`or*dain"</hw> <pr>(r?`?r-d?n")</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>re-</ets> re- + <ets>ordain</ets>: cf. F.
<ets>r<eacute/ordonner</ets>.]</ety> <def>To ordain again, as when the
first ordination is considered defective.</def> <rj><au>Bp.
Burnet.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reorder</ent><br/
<hw>Re*or"der</hw> <pr>(r?-?r"d?r)</pr>, <pos>v. t.</pos> <def>To order
a second time.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reordination</ent><br/
<hw>Re*or`di*na"tion</hw>, <pos>n.</pos> <def>A second
ordination.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reorganization</ent><br/
<hw>Re*or`gan*i*za"tion</hw> <pr>(-g<it>a</it>n-?-z?"sh?n)</pr>,
<pos>n.</pos> <def>The act of reorganizing; a reorganized existence;
<as>as, <ex>reorganization</ex> of the troops</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>reorganize</ent><br/
<ent>re-organize</ent><br/
<mhw><hw>Re*or"gan*ize</hw>, <hw>Re-or"gan*ize</hw></mhw>
<pr>(r<esl/*<ocir/r"g<ait/n*<imac/z)</pr>, <pos>v. t. & i.</pos> <def>To
organize again or anew; <as>as, to <ex>reorganize</ex> a society or an
army</as>.</def><br/
<syn><b>Syn. --</b> regroup.</syn><br/
[<source>1913 Webster</source>  <source>WordNet 1.5</source>]</p>

<p><ent>Reorient</ent><br/
<hw>Re*o"ri*ent</hw> <pr>(r?-?"r?-<it>e</it>nt)</pr>, <pos>a.</pos>
<def>Rising again.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The life <qex>reorient</qex> out of dust.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reostat</ent><br/
<hw>Re"o*stat</hw> <pr>(r?"?-st?t)</pr>, <pos>n.</pos>
<fld>(Physics)</fld> <def>See <er>Rheostat</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reotrope</ent><br/
<hw>Re"o*trope</hw> <pr>(-tr?p)</pr>, <pos>n.</pos> <fld>(Physics)</fld>
<def>See <er>Rheotrope</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rep</ent><br/
<hw>Rep</hw> <pr>(r<ecr/p)</pr>, <pos>n.</pos> <ety>[Prob. a corruption
of <ets>rib</ets>: cf. F. <ets>reps</ets>.]</ety> <def>A fabric made of
silk or wool, or of silk and wool, and having a transversely corded or
ribbed surface.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rep</ent><br/
<hw>Rep</hw> <pr>(r<ecr/p)</pr>, <pos>a.</pos> <def>Formed with a
surface closely corded, or ribbed transversely; -- applied to textile
fabrics of silk or wool; <as>as, <ex>rep</ex> silk</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repace</ent><br/
<hw>Re*pace"</hw> <pr>(r?-p?s")</pr>, <pos>v. t.</pos> <def>To pace
again; to walk over again in a contrary direction.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repacify</ent><br/
<hw>Re*pac"i*fy</hw> <pr>(r?-p?s"?-f?)</pr>, <pos>v. t.</pos> <def>To
pacify again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repack</ent><br/
<hw>Re*pack"</hw> <pr>(r?-p?k")</pr>, <pos>v. t.</pos> <def>To pack a
second time or anew; <as>as, to <ex>repack</ex> beef; to <ex>repack</ex>
a trunk.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repacker</ent><br/
<hw>Re*pack"er</hw> <pr>(-?r)</pr>, <pos>n.</pos> <def>One who
repacks.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repaganize</ent><br/
<hw>Re*pa"gan*ize</hw> <pr>(r?-p?"g<it>a</it>n-?z)</pr>, <pos>v.
t.</pos> <def>To paganize anew; to bring back to paganism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repaid</ent><br/
<hw>Re*paid"</hw> <pr>(r?-p?d")</pr>, <def><pos>imp. & p. p.</pos> of
<er>Repay</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repaint</ent><br/
<hw>Re*paint"</hw> <pr>(r?-p?nt")</pr>, <pos>v. t.</pos> <def>To paint
anew or again; <as>as, to <ex>repaint</ex> a house; to <ex>repaint</ex>
the ground of a picture.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repair</ent><br/
<hw>Re*pair"</hw> <pr>(r?-p?r")</pr>, <pos>v. i.</pos> <ety>[OE.
<ets>repairen</ets>, OF. <ets>repairier</ets> to return, fr. L.
<ets>repatriare</ets> to return to one's contry, to go home again; pref.
<ets>re-</ets> re- + <ets>patria</ets> native country, fr.
<ets>pater</ets> father. See <er>Father</er>, and cf.
<er>Repatriate</er>.]</ety> <sn>1.</sn> <def>To return.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I thought . . . that he <qex>repaire</qex> should again.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To go; to betake one's self; to resort; ass, to
<xex>repair</xex> to sanctuary for safety.</def>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Go, mount the winds, and to the shades <qex>repair</qex>.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repair</ent><br/
<hw>Re*pair"</hw>, <pos>n.</pos> <ety>[OF. <ets>repaire</ets> retreat,
asylum, abode. See <er>Repair</er> to go.]</ety> <sn>1.</sn> <def>The
act of repairing or resorting to a place.</def> <mark>[R.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The king sent a proclamation for their <qex>repair</qex> to their
houses.</q> <rj><qau>Clarendon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Place to which one repairs; a haunt; a resort.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>There the fierce winds his tender force assail<br/
And beat him downward to his first <qex>repair</qex>.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repair</ent><br/
<hw>Re*pair"</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Repaired</conjf> <pr>(-p?rd")</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Repairing</conjf>.]</vmorph> <ety>[F. <ets>r<eacute/parer</ets>,
L. reparare; pref. <ets>re-</ets> re- + <ets>parare</ets> to prepare.
See <er>Pare</er>, and cf. <er>Reparation</er>.]</ety> <sn>1.</sn>
<def>To restore to a sound or good state after decay, injury,
dilapidation, or partial destruction; to renew; to restore; to mend;
<as>as, to <ex>repair</ex> a house, a road, a shoe, or a ship; to
<ex>repair</ex> a shattered fortune</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Secret refreshings that <qex>repair</qex> his strength.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Do thou, as thou art wont, <qex>repair</qex><br/
My heart with gladness.</q> <rj><qau>Wordsworth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To make amends for, as for an injury, by an
equivalent; to indemnify for; <as>as, to <ex>repair</ex> a loss or
damage</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I 'll <qex>repair</qex> the misery thou dost bear.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To restore, recover; renew; amend; mend;
retrieve; recruit.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repair</ent><br/
<hw>Re*pair"</hw>, <pos>n.</pos> <sn>1.</sn> <def>Restoration to a sound
or good state after decay, waste, injury, or partial restruction; supply
of loss; reparation; <as>as, materials are collected for the
<ex>repair</ex> of a church or of a city</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Sunk down and sought <qex>repair</qex><br/
Of sleep, which instantly fell on me.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Condition with respect to soundness, perfectness,
etc.; <as>as, a house in good, or bad, <ex>repair</ex>; the book is out
of <ex>repair</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repairable</ent><br/
<hw>Re*pair"a*ble</hw> <pr>(-?*b'l)</pr>, <pos>a.</pos>
<def>Reparable.</def> <rj><au>Gauden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repairer</ent><br/
<hw>Re*pair"er</hw> <pr>(-?r)</pr>, <pos>n.</pos> <def>One who, or that
which, repairs, restores, or makes amends.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repairment</ent><br/
<hw>Re*pair"ment</hw>, <pos>n.</pos> <def>Act of repairing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repand</ent><br/
<hw>Re*pand"</hw> <pr>(r?*p?nd)</pr>, <pos>a.</pos> <ety>[L.
<ets>repandus</ets> bent backward, turned up; pref. <ets>re-</ets> re- +
<ets>pandus</ets> bent, crooked.]</ety> <fld>(Bot. & Zool.)</fld>
<def>Having a slightly undulating margin; -- said of leaves.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reparability</ent><br/
<hw>Rep`a*ra*bil"i*ty</hw> <pr>(r?p`?-r?-b?l"?-t?)</pr>, <pos>n.</pos>
<def>The quality or state of being reparable.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reparable</ent><br/
<hw>Rep"a*ra*ble</hw> <pr>(r?p"?-r?-b'l)</pr>, <pos>a.</pos> <ety>[L.
<ets>reparabilis</ets>: cf. F. <ets>r<eacute/parable</ets>.]</ety>
<def>Capable of being repaired, restored to a sound or good state, or
made good; restorable; <as>as, a <ex>reparable</ex>
injury</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reparably</ent><br/
<hw>Rep"a*ra*bly</hw>, <pos>adv.</pos> <def>In a reparable
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reparation</ent><br/
<hw>Rep`a*ra"tion</hw> <pr>(-r?"sh?n)</pr>, <pos>n.</pos> <ety>[F.
<ets>r<eacute/paration</ets>, L. <ets>reparatio</ets>. See
<er>Repair</er> to mend.]</ety> <sn>1.</sn> <def>The act of renewing,
restoring, etc., or the state of being renewed or repaired; <as>as, the
<ex>reparation</ex> of a bridge or of a highway</as>; -- in this sense,
<xex>repair</xex> is oftener used.</def>
<rj><au>Arbuthnot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The act of making amends or giving satisfaction or
compensation for a wrong, injury, etc.; also, the thing done or given;
amends; satisfaction; indemnity; --used, e.g. in the phrase <col><b>make
reparation</b></col>, <col><b>pay reparations</b></col>, <it>or</it>
<col><b>make reparations</b></col>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><q>I am sensible of the scandal I have given by my loose writings,
and make what <qex>reparation</qex> I am able.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Restoration; repair; restitution; compensation;
amends; satisfaction.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reparative</ent><br/
<hw>Re*par"a*tive</hw> <pr>(r?-p?r"?-t?v)</pr>, <pos>a.</pos>
<def>Repairing, or tending to repair.</def> <rj><au>Jer.
Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reparative</ent><br/
<hw>Re*par"a*tive</hw>, <pos>n.</pos> <def>That which repairs.</def>
<rj><au>Sir H. Wotton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reparel</ent><br/
<hw>Re*par"el</hw> <pr>(-?l)</pr>, <pos>n.</pos> <ety>[Cf.
<er>Reapparel</er>.]</ety> <def>A change of apparel; a second or
different suit.</def> <mark>[Obs.]</mark> <rj><au>Beau. &
Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repartee</ent><br/
<hw>Rep`ar*tee"</hw> <pr>(r?p`3r-t?")</pr>, <pos>n.</pos> <ety>[F.
<ets>repartie</ets>, fr. <ets>repartir</ets> to reply, depart again;
pref. <ets>re-</ets> re- <ets>partir</ets> to part, depart. See
<er>Part</er>.]</ety> <def>A smart, ready, and witty reply.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Cupid was as bad as he;<br/
Hear but the youngster's <qex>repartee</qex>.</q>
<rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Retort; reply. See <er>Retort</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repartee</ent><br/
<hw>Rep`ar*tee"</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Reparteed</conjf> <pr>(-t?d")</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Reparteeing</conjf>.]</vmorph> <def>To make smart and witty
replies.</def> <mark>[R.]</mark> <rj><au>Prior.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repartimiento</ent><br/
\'d8<hw>Re`par*ti`mi*en"to</hw> <pr>(r?`p?r-t?`m?-?n"t?)</pr>,
<pos>n.</pos> <ety>[Sp., fr. <ets>repartir</ets> to divide.]</ety>
<def>A partition or distribution, especially of slaves; also, an
assessment of taxes.</def> <rj><au>W. Irving.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repartotion</ent><br/
<hw>Re`par*to"tion</hw> <pr>(r?-p?r-t?sh"?n)</pr>, <pos>n.</pos>
<def>Another, or an additional, separation into parts.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repass</ent><br/
<hw>Re*pass"</hw> <pr>(r?-p?s")</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>re-</ets> + <ets>pass</ets>: cf. F. <ets>repasser</ets>. Cf.
<er>Repace</er>.]</ety> <def>To pass again; to pass or travel over in
the opposite direction; to pass a second time; <as>as, to
<ex>repass</ex> a bridge or a river; to <ex>repass</ex> the
sea.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repass</ent><br/
<hw>Re*pass"</hw>, <pos>v. i.</pos> <def>To pass or go back; to move
back; <as>as, troops passing and <ex>repassing</ex> before our
eyes</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repassage</ent><br/
<hw>Re*pas"sage</hw> <pr>(r?-p?s"s?j;48)</pr>, <pos>n.</pos> <def>The
act of repassing; passage back.</def> <rj><au>Hakluyt.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repassant</ent><br/
<hw>Re*pas"sant</hw> <pr>(r?-p?s"s<it>a</it>nt)</pr>, <pos>a.</pos>
<ety>[Cf. F. <ets>repassant</ets>, p. pr.]</ety> <fld>(Her.)</fld>
<def>Counterpassant.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repast</ent><br/
<hw>Re*past"</hw> <pr>(r?-p?st")</pr>, <pos>n.</pos> <ety>[OF.
<ets>repast</ets>, F. <ets>repas</ets>, LL. <ets>repastus</ets>, fr. L.
<ets>repascere</ets> to feed again; pref. <ets>re-</ets> re- +
<ets>pascere</ets>, <ets>pastum</ets>, to pasture, feed. See
<er>Pasture</er>.]</ety> <sn>1.</sn> <def>The act of taking
food.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>From dance to sweet <qex>repast</qex> they turn.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is taken as food; a meal; figuratively,
any refreshment.</def> <ldquo/Sleep . . . thy best
<xex>repast</xex>.<rdquo/ <rj><au>Denham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Go and get me some <qex>repast</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repast</ent><br/
<hw>Re*past"</hw>, <pos>v. t. & i.</pos> <def>To supply food to; to
feast; to take food.</def> <mark>[Obs.]</mark> <ldquo/<xex>Repast</xex>
them with my blood.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He then, also, as before, left arbitrary the dieting and
<qex>repasting</qex> of our minds.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repaster</ent><br/
<hw>Re*past"er</hw> <pr>(-?r)</pr>, <pos>n.</pos> <def>One who takes a
repast.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repasture</ent><br/
<hw>Re*pas"ture</hw> <pr>(-p?s"t?r;135)</pr>, <pos>n.</pos> <ety>[See
<er>Repast</er>.]</ety> <def>Food; entertainment.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Food for his rage, <qex>repasture</qex> for his den.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repatriate</ent><br/
<hw>Re*pa"tri*ate</hw> <pr>(r?-p?"tr?-?t)</pr>, <pos>v. t.</pos>
<ety>[L. <ets>repatriare</ets>. See 1st <er>Repair</er>.]</ety> <def>To
restore to one's own country.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repatriation</ent><br/
<hw>Re*pa`tri*a"tion</hw> <pr>(-?"sh?n)</pr>, <pos>n.</pos> <ety>[Cf.
LL. <ets>repatriatio</ets> return to one's country.]</ety>
<def>Restoration to one's country.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repay</ent><br/
<hw>Re*pay"</hw> <pr>(r?-p?")</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Repaid</conjf> <pr>(-p?d")</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Repaying</conjf>.]</vmorph> <ety>[Pref. <ets>re-</ets> +
<ets>pay</ets>: cf. F. <ets>repayer</ets>.]</ety> <sn>1.</sn> <def>To
pay back; to refund; <as>as, to <ex>repay</ex> money borrowed or
advanced</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If you <qex>repay</qex> me not on such a day,<br/
In such a place, such sum or sums.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To make return or requital for; to recompense; -- in
a good or bad sense; <as>as, to <ex>repay</ex> kindness; to
<ex>repay</ex> an injury.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Benefits which can not be <qex>repaid</qex> . . . are not commonly
found to increase affection.</q> <rj><qau>Rambler.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To pay anew, or a second time, as a debt.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To refund; restore; return; recompense;
compensate; remunerate; satisfy; reimburse; requite.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repayable</ent><br/
<hw>Re*pay"a*ble</hw> <pr>(-?-b'l)</pr>, <pos>a.</pos> <def>Capable of
being, or proper to be, repaid; due; <as>as, a loan <ex>repayable</ex>
in ten days; services <ex>repayable</ex> in kind.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repayment</ent><br/
<hw>Re*pay"ment</hw> <pr>(-m<it>e</it>nt)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>The act of repaying; reimbursement.</def> <rj><au>Jer.
Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The money or other thing repaid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repeal</ent><br/
<hw>Re*peal"</hw> <pr>(r?-p?l")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Repealed</conjf>
<pr>(-p?ld")</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Repealing</conjf>.]</vmorph> <ety>[OF. <ets>repeler</ets> to call
back, F. <ets>rappeler</ets>; pref. <ets>re-</ets> re- + OF.
<ets>apeler</ets>, F. <ets>appeler</ets>, to call, L.
<ets>appellare</ets>. See <er>Appeal</er>, and. cf.
<er>Repel</er>.]</ety> <sn>1.</sn> <def>To recall; to summon again, as
persons.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The banished Bolingbroke <qex>repeals</qex> himself,<br/
And with uplifted arms is safe arrived.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To recall, as a deed, will, law, or statute; to
revoke; to rescind or abrogate by authority, as by act of the
legislature; <as>as, to <ex>repeal</ex> a law</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To suppress; to repel.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Whence Adam soon <qex>repealed</qex><br/
The doubts that in his heart arose.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To abolish; revoke; rescind; recall; annul;
abrogate; cancel; reverse. See <er>Abolish</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repeal</ent><br/
<hw>Re*peal"</hw>, <pos>n.</pos> <sn>1.</sn> <def>Recall, as from
exile.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The tribunes are no soldiers; and their people<br/
Will be as rash in the <qex>repeal</qex>, as hasty<br/
To expel him thence.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Revocation; abrogation; <as>as, the <ex>repeal</ex>
of a statute; the <ex>repeal</ex> of a law or a usage.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repealability</ent><br/
<hw>Re*peal`a*bil"i*ty</hw> <pr>(-?-b?l"?-t?)</pr>, <pos>n.</pos>
<def>The quality or state of being repealable.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repealable</ent><br/
<hw>Re*peal"a*ble</hw> <pr>(r?-p?l"?-b'l)</pr>, <pos>a.</pos>
<def>Capable of being repealed.</def> --
<wordforms><wf>Re*peal"a*ble*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Revocable; abrogable; voidable;
reversible.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repealer</ent><br/
<hw>Re*peal"er</hw> <pr>(-?r)</pr>, <pos>n.</pos> <def>One who repeals;
one who seeks a repeal; specifically, an advocate for the repeal of the
Articles of Union between Great Britain and Ireland.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repealment</ent><br/
<hw>Re*peal"ment</hw> <pr>(-m<it>e</it>nt)</pr>, <pos>n.</pos>
<def>Recall, as from banishment.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repeat</ent><br/
<hw>Re*peat"</hw> <pr>(-p?t")</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Repeated</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Repeating</conjf>.]</vmorph> <ety>[F.
<ets>r<eacute/p<eacute/ter</ets>, L. <ets>repetere</ets>; pref.
<ets>re-</ets> re- + <ets>petere</ets> to fall upon, attack. See
<er>Petition</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>To go over again; to attempt, do, make, or utter
again; to iterate; to recite; <as>as, to <ex>repeat</ex> an effort, an
order, or a poem</as>.</def> <ldquo/I will <xex>repeat</xex> our former
communication.<rdquo/ <rj><au>Robynson (More's Utopia).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Not well conceived of God; who, though his power<br/
Creation could <qex>repeat</qex>, yet would be loth<br/
Us to abolish.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To make trial of again; to undergo or encounter
again.</def> <mark>[Obs.]</mark> <rj><au>Waller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Scots Law)</fld> <def>To repay or refund (an excess
received).</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To repeat one's self</b></col>, <cd>to do or say what one
has already done or said.</cd> -- <col><b>To repeat signals</b></col>,
<cd>to make the same signals again; specifically, to communicate, by
repeating them, the signals shown at headquarters.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To reiterate; iterate; renew; recite; relate;
rehearse; recapitulate. See <er>Reiterate</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repeat</ent><br/
<hw>Re*peat"</hw> <pr>(r?-p?t")</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
act of repeating; repetition.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is repeated; <as>as, the <ex>repeat</ex>
of a pattern</as>; that is, the repetition of the engraved figure on a
roller by which an impression is produced (as in calico printing,
etc.).</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Mus.)</fld> <def>A mark, or series of dots, placed
before and after, or often only at the end of, a passage to be repeated
in performance.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repeatedly</ent><br/
<hw>Re*peat"ed*ly</hw>, <pos>adv.</pos> <def>More than once; again and
again; indefinitely.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repeater</ent><br/
<hw>Re*peat"er</hw> <pr>(-?r)</pr>, <pos>n.</pos> <def>One who, or that
which, repeats.</def> Specifically: <sd>(a)</sd> <def>A watch with a
striking apparatus which, upon pressure of a spring, will indicate the
time, usually in hours and quarters.</def> <sd>(b)</sd> <def>A repeating
firearm.</def> <sd>(c)</sd> <fld>(Teleg.)</fld> <def>An instrument for
resending a telegraphic message automatically at an intermediate
point.</def><-- or a telephone signal --> <sd>(d)</sd> <def>A person who
votes more than once at an election.</def> <mark>[U.S.]</mark>
<sd>(e)</sd> <def>See <cref>Circulating decimal</cref>, under
<er>Decimal</er>.</def> <sd>(f)</sd> <fld>(Naut.)</fld> <def>A pennant
used to indicate that a certain flag in a hoist of signal is
duplicated.</def> <rj><au>Ham. Nav. Encyc.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repeating</ent><br/
<hw>Re*peat"ing</hw>, <pos>a.</pos> <def>Doing the same thing over
again; accomplishing a given result many times in succession; <as>as, a
<ex>repeating</ex> firearm; a <ex>repeating</ex> watch</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Repeating circle</b></col>. <cd>See the Note under
<er>Circle</er>, <pos>n.</pos>, 3.</cd> -- <col><b>Repeating
decimal</b></col> <fld>(Arith.)</fld>, <cd>a circulating decimal. See
under <er>Decimal</er>.</cd> -- <col><b>Repeating firearm</b></col>,
<cd>a firearm that may be discharged many times in quick
succession</cd>; especially: <sd>(a)</sd> <cd>A form of firearm so
constructed that by the action of the mechanism the charges are
successively introduced from a chamber containing them into the breech
of the barrel, and fired.</cd> <sd>(b)</sd> <cd>A form in which the
charges are held in, and discharged from, a revolving chamber at the
breech of the barrel. See <er>Revolver</er>, and <cref>Magazine
gun</cref>, under <er>Magazine</er>.</cd><-- also called automatic
weapon --> -- <col><b>Repeating instruments</b></col> <fld>(Astron. &
Surv.)</fld>, <cd>instruments for observing angles, as a circle,
theodolite, etc., so constructed that the angle may be measured several
times in succession, and different, but successive and contiguous,
portions of the graduated limb, before reading off the aggregate result,
which aggregate, divided by the number of measurements, gives the angle,
freed in a measure from errors of eccentricity and graduation.</cd> --
<col><b>Repeating watch</b></col>. <cd>See <er>Repeater</er>
<sd>(a)</sd></cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repedation</ent><br/
<hw>Rep"e*da"tion</hw> <pr>(r?p`?-da"sh?n)</pr>, <pos>n.</pos> <ety>[L.
<ets>repedare</ets> to step back; pref. <ets>re-</ets> re- +
<ets>pes</ets>, <ets>pedis</ets>, foot.]</ety> <def>A stepping or going
back.</def> <mark>[Obs.]</mark> <rj><au>Dr. H. More.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repel</ent><br/
<hw>Re**pel"</hw> <pr>(r?-p?l")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Repelled</conjf>
<pr>(-p?ld")</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Repelling</conjf>.]</vmorph> <ety>[L. <ets>repellere</ets>,
<ets>repulsum</ets>; pref. <ets>re-</ets> re- + <ets>pellere</ets> to
drive. See <er>Pulse</er> a beating, and cf. <er>Repulse</er>,
<er>Repeal</er>.]</ety> <sn>1.</sn> <def>To drive back; to force to
return; to check the advance of; to repulse as, to <xex>repel</xex> an
enemy or an assailant.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Hippomedon <qex>repelled</qex> the hostile tide.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>They <qex>repelled</qex> each other strongly, and yet attracted
each other strongly.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To resist or oppose effectually; <as>as, to
<ex>repel</ex> an assault, an encroachment, or an
argument</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>[He] gently <qex>repelled</qex> their entreaties.</q>
<rj><qau>Hawthorne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Tu repulse; resist; oppose; reject;
refuse.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repel</ent><br/
<hw>Re*pel"</hw>, <pos>v. i.</pos> <def>To act with force in opposition
to force impressed; to exercise repulsion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repellency</ent><br/
<ent>Repellence</ent><br/
<mhw>{ <hw>Re*pel"lence</hw> <pr>(-l<it>e</it>ns)</pr>,
<hw>Re*pel"len*cy</hw> <pr>(-l<it>e</it>n-s?)</pr>, }</mhw>
<pos>n.</pos> <def>The principle of repulsion; the quality or capacity
of repelling; repulsion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repellent</ent><br/
<hw>Re*pel"lent</hw> <pr>(-l<it>e</it>nt)</pr>, <pos>a.</pos> <ety>[L.
<ets>repellens</ets>, <ets>-entis</ets>, p. pr. ]</ety> <def>Driving
back; able or tending to repel.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repellent</ent><br/
<hw>Re*pel"lent</hw>, <pos>n.</pos> <sn>1.</sn> <def>That which
repels.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Med.)</fld> <def>A remedy to repel from a tumefied
part the fluids which render it tumid.</def>
<rj><au>Dunglison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A kind of waterproof cloth.</def>
<rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repeller</ent><br/
<hw>Re*pel"ler</hw> <pr>(-l?r)</pr>, <pos>n.</pos> <def>One who, or that
which, repels.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repent</ent><br/
<hw>Re"pent</hw> <pr>(r?"p?nt)</pr>, <pos>a.</pos> <ety>[L.
<ets>repens</ets>, <ets>-entis</ets>, creeping, p. pr. of
<ets>repere</ets> to creep.]</ety> <sn>1.</sn> <fld>(Bot.)</fld>
<def>Prostrate and rooting; -- said of stems.</def>
<rj><au>Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>Same as
<er>Reptant</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repent</ent><br/
<hw>Re*pent"</hw> <pr>(r?-p?nt")</pr>, <pos>v. i.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Repented</conjf>; <pos>p. pr. &
vb. n.</pos> <conjf>Repenting</conjf>.]</vmorph> <ety>[F. <ets>se
repentir</ets>; L. pref. <ets>re-</ets> re- + <ets>poenitere</ets> to
make repent, <ets>poenitet me</ets> it repents me, I repent. See
<er>Penitent</er>.]</ety> <sn>1.</sn> <def>To feel pain, sorrow, or
regret, for what one has done or omitted to do.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>First she relents<br/
With pity; of that pity then <qex>repents</qex>.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To change the mind, or the course of conduct, on
account of regret or dissatisfaction.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Lest, peradventure, the people <qex>repent</qex> when they see
war, and they return to Egypt.</q> <rj><qau>Ex. xiii. 17.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Theol.)</fld> <def>To be sorry for sin as morally
evil, and to seek forgiveness; to cease to love and practice
sin.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Except ye <qex>repent</qex>, ye shall likewise perish.</q>
<rj><qau>Luke xii. 3.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repent</ent><br/
<hw>Re*pent"</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To feel pain on
account of; to remember with sorrow.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I do <qex>repent</qex> it from my very soul.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1220 --></p>

<p><sn>2.</sn> <def>To feel regret or sorrow; -- used
reflexively.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>My father has <qex>repented</qex> him ere now.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To cause to have sorrow or regret; -- used
impersonally.</def> <mark>[Archaic]</mark> <ldquo/And it
<xex>repented</xex> the Lord that he had made man on the earth.<rdquo/
<rj><au>Gen. vi. 6.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repentance</ent><br/
<hw>Re*pent"ance</hw> <pr>(r<esl/*p<ecr/nt"<ait/ns)</pr>, <pos>n.</pos>
<ety>[F. <ets>repentance</ets>.]</ety> <def>The act of repenting, or the
state of being penitent; sorrow for what one has done or omitted to do;
especially, contrition for sin.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Godly sorrow worketh <qex>repentance</qex> to salvation.</q>
<rj><qau>2. Cor. vii. 20.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Repentance</qex> is a change of mind, or a conversion from
sin to God.</q> <rj><qau>Hammond.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Repentance is the relinquishment of any practice from the
conviction that it has offended God. Sorrow, fear, and anxiety are
properly not parts, but adjuncts, of <qex>repentance</qex>; yet they are
too closely connected with it to be easily separated.</q>
<rj><qau>Rambler.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Contrition; regret; penitence; contriteness;
compunction. See <er>Contrition</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repentant</ent><br/
<hw>Re*pent"ant</hw> <pr>(-<ait/nt)</pr>, <pos>a.</pos> <ety>[F.
<ets>repentant</ets>.]</ety> <sn>1.</sn> <def>Penitent; sorry for
sin.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Thus they, in lowliest plight, <qex>repentant</qex> stood.</q>
<rj><qau>Millton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Expressing or showing sorrow for sin; <as>as,
<ex>repentant</ex> tears; <ex>repentant</ex> ashes.</as></def>
<ldquo/<xex>Repentant</xex> sighs and voluntary pains.<rdquo/
<rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repentant</ent><br/
<hw>Re*pent"ant</hw>, <pos>n.</pos> <def>One who repents, especially one
who repents of sin; a penitent.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repentantly</ent><br/
<hw>Re*pent"ant*ly</hw>, <pos>adv.</pos> <def>In a repentant
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repenter</ent><br/
<hw>Re*pent"er</hw> <pr>(-<etil/r)</pr>, <pos>n.</pos> <def>One who
repents.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repentingly</ent><br/
<hw>Re*pent"ing*ly</hw>, <pos>adv.</pos> <def>With repentance;
penitently.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repentless</ent><br/
<hw>Re*pent"less</hw>, <pos>a.</pos> <def>Unrepentant.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repeople</ent><br/
<hw>Re*peo"ple</hw> <pr>(r<emac/*p<emac/"p'l)</pr>, <pos>v. t.</pos>
<ety>[Pref. <ets>re-</ets> + <ets>people</ets>: cf. F.
<ets>repeupler</ets>.]</ety> <def>To people anew.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reperception</ent><br/
<hw>Re`per*cep"tion</hw> <pr>(r?`p?r-s?p"sh?n)</pr>, <pos>n.</pos>
<def>The act of perceiving again; a repeated perception of the same
object.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>No external praise can give me such a glow as my own solitary
<qex>reperception</qex> and ratification of what is fine.</q>
<rj><qau>Keats.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repercuss</ent><br/
<hw>Re`per*cuss"</hw> <pr>(-k<ucr/s")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Repercussed</conjf>
<pr>(-k?st")</pr>;<pos>p. pr. & vb. n.</pos>
<conjf>Repercussing</conjf>.]</vmorph> <ety>[L. <ets>repercusus</ets>,
p. p. of <ets>repercutere</ets> to drive back; pref. <ets>re-</ets> re-
+ <ets>percutere</ets>. See <er>Percussion</er>.]</ety> <def>To drive or
beat back; hence, to reflect; to reverberate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Perceiving all the subjacent country, . . . to
<qex>repercuss</qex> such a light as I could hardly look against.</q>
<rj><qau>Evelyn.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repercussion</ent><br/
<hw>Re`per*cus"sion</hw> <pr>(-k?sh"?n)</pr>, <pos>n.</pos> <ety>[L.
<ets>repercussio</ets>: cf. F. <ets>r<eacute/percussion</ets>.]</ety>
<sn>1.</sn> <def>The act of driving back, or the state of being driven
back; reflection; reverberation; <as>as, the <ex>repercussion</ex> of
sound</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Ever echoing back in endless <qex>repercussion</qex>.</q>
<rj><qau>Hare.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mus.)</fld> <def>Rapid reiteration of the same
sound.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Med.)</fld> <def>The subsidence of a tumor or
eruption by the action of a repellent.</def>
<rj><au>Dunglison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Obstetrics)</fld> <def>In a vaginal examination,
the act of imparting through the uterine wall with the finger a shock to
the fetus, so that it bounds upward, and falls back again against the
examining finger.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repercussive</ent><br/
<hw>Re`per*cuss"ive</hw> <pr>(-k?s"?v)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>r<eacute/percussif</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Tending or able to repercuss; having the power of
sending back; causing to reverberate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Ye <qex>repercussive</qex> rocks! repeat the sound.</q>
<rj><qau>W. Pattison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Repellent.</def> <mark>[Obs.]</mark> <ldquo/Blood is
stanched by astringent and <xex>repercussive</xex> medicines.<rdquo/
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Driven back; rebounding; reverberated.</def>
<ldquo/Rages loud the <xex>repercussive</xex> roar.<rdquo/
<rj><au>Thomson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repercussive</ent><br/
<hw>Re`per*cuss"ive</hw>, <pos>n.</pos> <def>A repellent.</def>
<mark>[Obs.]</mark> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repertitious</ent><br/
<hw>Rep`er*ti"tious</hw> <pr>(r?p`?r-t?sh"?s)</pr>, <pos>a.</pos>
<ety>[L. <ets>reperticius</ets>. See <er>Repertory</er>.]</ety>
<def>Found; gained by finding.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repertoire</ent><br/
\'d8<hw>R<eacute/`per`toire"</hw> <pr>(F. r<asl/`p<acir/r`tw<aum/r"; E.
r<ecr/p"<etil/r*tw<aum/r)</pr>, <pos>n.</pos> <ety>[F. See
<er>Repertory</er>.]</ety> <def>A list of dramas, operas, pieces, parts,
etc., which a company or a person has rehearsed and is prepared to
perform.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repertory</ent><br/
<hw>Rep"er*to*ry</hw> <pr>(r?p"?r-t?-r?)</pr>, <pos>n.</pos> <ety>[L.
<ets>repertorium</ets>, fr. <ets>reperire</ets> to find again; pref.
<ets>re-</ets> re + <ets>parire</ets>, <ets>parere</ets>, to bring
forth, procure: cf. F. <ets>r<eacute/pertoire</ets>. Cf.
<er>Parent</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>A place in which things are disposed in an orderly
manner, so that they can be easily found, as the index of a book, a
commonplace book, or the like.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A treasury; a magazine; a storehouse.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Same as <er>Repertoire</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reperusal</ent><br/
<hw>Re`pe*rus"al</hw> <pr>(r?`p?-r?z"<it>a</it>l)</pr>, <pos>n.</pos>
<def>A second or repeated perusal.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reperuse</ent><br/
<hw>Re`pe*ruse"</hw> <pr>(-r?z")</pr>, <pos>v. t.</pos> <def>To peruse
again.</def> <rj><au>Ld. Lytton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repetend</ent><br/
<hw>Rep`e*tend</hw> <pr>(r?p`?-t?nd")</pr>, <pos>n.</pos> <ety>[L.
<ets>repetendus</ets> to be repeated, fr. <ets>repetere</ets> to
repeat.]</ety> <fld>(Math.)</fld> <def>That part of a circulating
decimal which recurs continually, <xex>ad infinitum</xex>: -- sometimes
indicated by a dot over the first and last figures; thus, in the
circulating decimal .728328328 + (otherwise .7<2dot/8<3dot/), the
<xex>repetend</xex> is 283.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repetition</ent><br/
<hw>Rep`e*ti"tion</hw> <pr>(r<ecr/p`<esl/-t<icr/sh"<ucr/n)</pr>,
<pos>n.</pos> <ety>[L. <ets>repetitio</ets>: cf. F.
<ets>r<eacute/p<eacute/tition</ets>. See <er>Repeat</er>.]</ety>
<sn>1.</sn> <def>The act of repeating; a doing or saying again;
iteration.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I need not be barren of accusations; he hath faults, with surplus
to tire in <qex>repetition</qex>.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Recital from memory; rehearsal.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Mus.)</fld> <def>The act of repeating, singing, or
playing, the same piece or part a second time; reiteration of a
note.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Rhet.)</fld> <def>Reiteration, or repeating the
same word, or the same sense in different words, for the purpose of
making a deeper impression on the audience.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Astron. & Surv.)</fld> <def>The measurement of an
angle by successive observations with a repeating instrument.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Iteration; rehearsal. See
<er>Tautology</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repetitionary</ent><br/
<ent>Repetitional</ent><br/
<mhw>{ <hw>Rep`e*ti"tion*al</hw> <pr>(-<it>a</it>l)</pr>.
<hw>Rep`e*ti"tion*a*ry</hw> <pr>(-?-r?)</pr> }</mhw>, <pos>a.</pos>
<def>Of the nature of, or containing, repetition.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repetitioner</ent><br/
<hw>Rep`e*ti"tion*er</hw> <pr>(-?r)</pr>, <pos>n.</pos> <def>One who
repeats.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repetitious</ent><br/
<hw>Rep`e*ti"tious</hw> <pr>(-t?sh"?s)</pr>, <pos>a.</pos>
<def>Repeating; containing repetition.</def> <mark>[U.S.]</mark>
<rj><au>Dr. T. Dwight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repetitive</ent><br/
<hw>Re*pet"i*tive</hw> <pr>(r?-p?t"?-t?v)</pr>, <pos>a.</pos>
<def>Containing repetition; repeating.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repetitor</ent><br/
\'d8<hw>Rep"e*ti`tor</hw> <pr>(r?p"?-t?`t?r)</pr>, <pos>n.</pos>
<ety>[Cf. L. <ets>repetitor</ets> a reclaimer.]</ety>
<fld>(Ger.Univ.)</fld> <def>A private instructor.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repine</ent><br/
<hw>Re*pine"</hw> <pr>(r?-p?n")</pr>, <pos>v. i.</pos> <ety>[Pref.
<ets>re-</ets> + <ets>pine</ets> to languish.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>To fail; to wane.</def> <mark>[Obs.]</mark>
<ldquo/<xex>Reppening</xex> courage yields no foot to foe.<rdquo/
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To continue pining; to feel inward discontent which
preys on the spirits; to indulge in envy or complaint; to
murmur.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>But Lachesis thereat gan to <qex>repine</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>What if the head, the eye, or ear <qex>repined</qex><br/
To serve mere engines to the ruling mind?</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repine</ent><br/
<hw>Re*pine"</hw>, <pos>n.</pos> <def>Vexation; mortification.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repiner</ent><br/
<hw>Re*pin"er</hw> <pr>(r?-p?n"?r)</pr>, <pos>n.</pos> <def>One who
repines.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repiningly</ent><br/
<hw>Re*pin"ing*ly</hw>, <pos>adv.</pos> <def>With repening or
murmuring.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repkie</ent><br/
\'d8<hw>Rep"kie</hw> <pr>(r?p"k?)</pr>, <pos>n.</pos> <ety>[From the
native name.]</ety> <fld>(Zool.)</fld> <def>Any edible sea urchin.</def>
<mark>[Alaska]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Replace</ent><br/
<hw>Re*place"</hw> <pr>(r?-pl?s")</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>re-</ets> + <ets>place</ets>: cf. F. <ets>replacer</ets>.]</ety>
<sn>1.</sn> <def>To place again; to restore to a former place, position,
condition, or the like.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The earl . . . was <qex>replaced</qex> in his government.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To refund; to repay; to restore; <as>as, to
<ex>replace</ex> a sum of money borrowed</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To supply or substitute an equivalent for; <as>as,
to <ex>replace</ex> a lost document</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With Israel, religion <qex>replaced</qex> morality.</q>
<rj><qau>M. Arnold.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To take the place of; to supply the want of; to
fulfull the end or office of.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This duty of right intention does not <qex>replace</qex> or
supersede the duty of consideration.</q>
<rj><qau>Whewell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To put in a new or different place.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The propriety of the use of <xex>replace</xex> instead
of <xex>displace</xex>, <xex>supersede</xex>, <xex>take the place
of</xex>, as in the third and fourth definitions, is often disputed on
account of etymological discrepancy; but the use has been sanctioned by
the practice of careful writers.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Replaced crystal</b></col> <fld>(Crystallog.)</fld>,
<cd>a crystal having one or more planes in the place of its edges or
angles.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Replaceability</ent><br/
<hw>Re*place`a*bil"i*ty</hw> <pr>(-?-b?l"?-t?)</pr>, <pos>n.</pos>
<def>The quality, state, or degree of being replaceable.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Replaceable</ent><br/
<hw>Re*place"a*ble</hw> <pr>(r?-pl?s"?-b'l)</pr>, <pos>a.</pos>
<sn>1.</sn> <def>Capable or admitting of being put back into a
place.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Admitting of having its place supplied by a like
thing or an equivalent; <as>as, the lost book is
<ex>replaceable</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Chem.)</fld> <def>Capable of being replaced (by),
or of being exchanged (for); <as>as, the hydrogen of acids is
<ex>replaceable</ex> by metals or by basic radicals</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Replacement</ent><br/
<hw>Re*place"ment</hw> <pr>(-m<it>e</it>nt)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>The act of replacing.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Crystallog.)</fld> <def>The removal of an edge or
an angle by one or more planes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Replait</ent><br/
<hw>Re*plait"</hw> <pr>(r?-pl?t")</pr>, <pos>v. t.</pos> <def>To plait
or fold again; to fold, as one part over another, again and
again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Replant</ent><br/
<hw>Re*plant"</hw> <pr>(rE-pl?nt")</pr>, <pos>v. t.</pos> <def>To plant
again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Replantable</ent><br/
<hw>Re*plant"a*ble</hw> <pr>(-?-b'l)</pr>, <pos>a.</pos> <def>That may
be planted again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Replantation</ent><br/
<hw>Re`plan*ta"tion</hw> <pr>(r?`pl?n-t?"sh?n)</pr>, <pos>n.</pos>
<def>The act of planting again; a replanting.</def> <mark>[R.]</mark>
<rj><au>Hallywell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Replead</ent><br/
<hw>Re*plead"</hw> <pr>(r?-pl?d")</pr>, <pos>v. t. & i.</pos> <def>To
plead again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repleader</ent><br/
<hw>Re*plead"er</hw> <pr>(-?r)</pr>, <pos>n.</pos> <fld>(Law)</fld>
<def>A second pleading, or course of pleadings; also, the right of
pleading again.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Whenever a <qex>repleader</qex> is granted, the pleadings must
begin <qex>de novo</qex>.</q> <rj><qau>Blackstone.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Replenish</ent><br/
<hw>Re*plen"ish</hw> <pr>(r?-pl?n"?sh)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Replenished</conjf>
<pr>(-?sht)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Replenishing</conjf>.]</vmorph> <ety>[OE. <ets>replenissen</ets>,
OF. <ets>replenir</ets>; L. pref. <ets>re-</ets> re- + <ets>plenus</ets>
full. See <er>Full</er>, <er>-ish</er>, and cf. <er>Replete</er>.]</ety>
<sn>1.</sn> <def>To fill again after having been diminished or emptied;
to stock anew; hence, to fill completely; to cause to abound.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Multiply and <qex>replenish</qex> the earth.</q> <rj><qau>Gen. i.
28.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The waters thus<br/
With fish <qex>replenished</qex>, and the air with fowl.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To finish; to complete; to perfect.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>We smothered<br/
The most <qex>replenished</qex> sweet work of nature.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Replenish</ent><br/
<hw>Re*plen"ish</hw>, <pos>v. i.</pos> <def>To recover former
fullness.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The humors will not <qex>replenish</qex> so soon.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Replenisher</ent><br/
<hw>Re*plen"ish*er</hw> <pr>(-?r)</pr>, <pos>n.</pos> <def>One who
replenishes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Replenishment</ent><br/
<hw>Re*plen"ish*ment</hw> <pr>(-m<it>e</it>nt)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>The act of replenishing, or the state of being
replenished.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which replenishes; supply.</def>
<rj><au>Cowper.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Replete</ent><br/
<hw>Re*plete"</hw> <pr>(r?-pl?t")</pr>, <pos>a.</pos> <ety>[L.
<ets>repletus</ets>, p. p. of <ets>replere</ets> to fill again, fill up;
pref. <ets>re-</ets> re- + <ets>plere</ets> to fill, akin to
<ets>plenus</ets> full: cf. F. <ets>replet</ets> corpulent. See
<er>Plenty</er>, <er>Replenish</er>.]</ety> <def>Filled again;
completely filled; full; charged; abounding.</def> <ldquo/His words
<xex>replete</xex> with guile.<rdquo/ <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>When he of wine was <qex>replet</qex> at his feast.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>In heads <qex>replete</qex> with thoughts of other men.</q>
<rj><qau>Cowper.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Replete</ent><br/
<hw>Re*plete"</hw>, <pos>v. t.</pos> <def>To fill completely, or to
satiety.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repleteness</ent><br/
<hw>Re*plete"ness</hw>, <pos>n.</pos> <def>The state of being
replete.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repletion</ent><br/
<hw>Re*ple"tion</hw> <pr>(r?-pl?"sh?n)</pr>, <pos>n.</pos> <ety>[L.
<ets>repletio</ets> a filling up: cf. F.
<ets>r<eacute/pl<eacute/tion</ets>. See <er>Replete</er>.]</ety>
<sn>1.</sn> <def>The state of being replete; superabundant
fullness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The tree had too much <qex>repletion</qex>, and was oppressed with
its own sap.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Repleccioun [overeating] ne made her never sick.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Med.)</fld> <def>Fullness of blood;
plethora.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repletive</ent><br/
<hw>Re*ple"tive</hw> <pr>(-t?v)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>r<eacute/pl<eacute/tif</ets>.]</ety> <def>Tending to make replete;
filling.</def> -- <wordforms><wf>Re*ple"tive*ly</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repletory</ent><br/
<hw>Re*ple"to*ry</hw> <pr>(-t?-r?)</pr>, <pos>a.</pos>
<def>Repletive.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repleviable</ent><br/
<hw>Re*plev"i*a*ble</hw> <pr>(r?-pl?v"?-?-b'l)</pr>, <pos>a.</pos>
<ety>[See <er>Replevy</er>.]</ety> <fld>(Law)</fld> <def>Capable of
being replevied.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Replevin</ent><br/
<hw>Re*plev"in</hw> <pr>(-?n)</pr>, <pos>n.</pos> <ety>[LL.
<ets>replevina</ets>. See <er>Replevy</er>, and cf.
<er>Plevin</er>.]</ety> <sn>1.</sn> <fld>(Law)</fld> <def>A personal
action which lies to recover possession of goods and chattle wrongfully
taken or detained. Originally, it was a remedy peculiar to cases for
wrongful distress, but it may generally now be brought in all cases of
wrongful taking or detention.</def> <rj><au>Bouvier.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The writ by which goods and chattels are
replevied.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Replevin</ent><br/
<hw>Re*plev"in</hw>, <pos>v. t.</pos> <fld>(Law)</fld> <def>To
replevy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Replevisable</ent><br/
<hw>Re*plev"i*sa*ble</hw> <pr>(-?-s?-b'l)</pr>, <pos>a.</pos> <ety>[OF.
<ets>replevisable</ets>.]</ety> <def>Repleviable.</def> <rj><au>Sir M.
Hale.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Replevy</ent><br/
<hw>Re*plev"y</hw> <pr>(-?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Replevied</conjf> <pr>(-?d)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Replevying</conjf>.]</vmorph> <ety>[OF.
<ets>replevir</ets>, LL. <ets>replevire</ets>. See <er>Pledge</er>,
<er>Replevin</er>.]</ety> <sn>1.</sn> <fld>(Law)</fld> <def>To take or
get back, by a writ for that purpose (goods and chattels wrongfully
taken or detained), upon giving security to try the right to them in a
suit at law, and, if that should be determined against the plaintiff, to
return the property replevied.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Old Eng. Law)</fld> <def>To bail.</def>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Replevy</ent><br/
<hw>Re*plev"y</hw> <pr>(r?-pl?v"?)</pr>, <pos>n.</pos>
<def>Replevin.</def> <rj><au>Mozley & W.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Replica</ent><br/
\'d8<hw>Rep"li*ca</hw> <pr>(r?p"l?-k?)</pr>, <pos>n.</pos> <ety>[It. See
<er>Reply</er>, <pos>v. & n.</pos>]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <fld>(Fine Arts)</fld> <def>A copy of a work of art, as
of a picture or statue, made by the maker of the original.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mus.)</fld> <def>Repetition.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Replicant</ent><br/
<hw>Rep"li*cant</hw> <pr>(r?p"l?-k<it>a</it>nt)</pr>, <pos>n.</pos>
<def>One who replies.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Replicate</ent><br/
<hw>Rep"li*cate</hw> <pr>(-?-k?t)</pr>, <pos>v. t.</pos> <def>To
reply.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Replicated</ent><br/
<ent>Replicate</ent><br/
<mhw>{ <hw>Rep"li*cate</hw> <pr>(l?-k?t)</pr>, <hw>Rep"li*ca`ted</hw>
<pr>(-k?`t?d)</pr>, }</mhw> <pos>a.</pos> <ety>[L.
<ets>replicatus</ets>, p. p. of <ets>replicare</ets>. See
<er>Reply</er>.]</ety> <def>Folded over or backward; folded back upon
itself; <as>as, a <ex>replicate</ex> leaf or petal; a <ex>replicate</ex>
margin of a shell</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Replication</ent><br/
<hw>Rep`li*ca"tion</hw> <pr>(-k?"sh?n)</pr>, <pos>n.</pos> <ety>[L.
<ets>replicatio</ets>. See <er>Reply</er>.]</ety> <sn>1.</sn> <def>An
answer; a reply.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Withouten any <qex>repplicacioun</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law Pleadings)</fld> <def>The reply of the
plaintiff, in matters of fact, to the defendant's plea.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Return or repercussion, as of sound; echo.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To hear the <qex>replication</qex> of your sounds.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A repetition; a copy.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Biochem.)</fld> <def>The copying, by enzymes, of a
cell's genome, i.e. the DNA or RNA comprising its genetic material, so
as to form an identical genome. This is an essential step in the
division of one cell into two. This differs from
<contr>transcription</contr>, which is the copying of only part of the
genetic information of a cell's genome into RNA, as in the processes of
biosynthesis of messenger RNA or ribosomal RNA.</def><br/
[<source>PJC</source>]</p>

<p><syn><b>Syn.</b> -- Answer; response; reply; rejoinder.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Replier</ent><br/
<hw>Re*pli"er</hw> <pr>(r?-pl?"?r)</pr>, <pos>n.</pos> <def>One who
replies.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Replum</ent><br/
\'d8<hw>Re"plum</hw> <pr>(r?"pl?m)</pr>, <pos>n.</pos> <ety>[L.,
doorcase.]</ety> <fld>(Bot.)</fld> <def>The framework of some pods, as
the cress, which remains after the valves drop off.</def>
<rj><au>Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reply</ent><br/
<hw>Re*ply"</hw> <pr>(r?-pl?")</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Replied</conjf> <pr>(-pl?d")</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>Replying</conjf>.]</vmorph> <ety>[OE.
<ets>replien</ets>, OF. <ets>replier</ets>, F.
<ets>r<eacute/pliquer</ets>, fr. L. <ets>replicare</ets> to fold back,
make a reply; pref. <ets>re-</ets> re- + <ets>plicare</ets> to fold. See
<er>Ply</er>, and cf. <er>Replica</er>.]</ety> <sn>1.</sn> <def>To make
a return in words or writing; to respond; to answer.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>O man, who art thou that <qex>repliest</qex> against God?</q>
<rj><qau>Rom. ix. 20.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>To answer a defendant's
plea.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Figuratively, to do something in return for
something done; <as>as, to <ex>reply</ex> to a signal; to <ex>reply</ex>
to the fire of a battery.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To answer; respond; rejoin.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reply</ent><br/
<hw>Re*ply"</hw>, <pos>v. t.</pos> <def>To return for an answer.</def>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Lords, vouchsafe<br/
To give me hearing what I shall <qex>reply</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reply</ent><br/
<hw>Re*ply"</hw>, <pos>n.</pos>; <plu><it>pl.</it> <plw>Replies</plw>
<pr>(-pl<?/z")</pr>.</plu> <ety>[See <er>Reply</er>, <pos>v. i.</pos>,
and cf. <er>Replica</er>.]</ety> <def>That which is said, written, or
done in answer to what is said, written, or done by another; an answer;
a response.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Answer; rejoinder; response.</syn> <usage> --
<er>Reply</er>, <er>Rejoinder</er>, <er>Answer</er>. A <xex>reply</xex>
is a distinct response to a formal question or attack in speech or
writing. A <xex>rejoinder</xex> is a second reply (a reply to a reply)
in a protracted discussion or controversy. The word <xex>answer</xex> is
used in two senses, namely (1), in the most general sense of a mere
response; as, the <xex>answer</xex> to a question; or (2), in the sense
of a decisive and satisfactory confutation of an adversary's argument,
as when we speak of a triumphant <xex>answer</xex> to the speech or
accusations of an opponent. Here the noun corresponds to a frequent use
of the verb, as when we say. <ldquo/This will <xex>answer</xex> (i.e.,
fully meet) the end in view;<rdquo/ <ldquo/It <xex>answers</xex> the
purpose.<rdquo/</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Replyer</ent><br/
<hw>Re*ply"er</hw> <pr>(-?r)</pr>, <pos>n.</pos> <def>See
<er>Replier</er>.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repolish</ent><br/
<hw>Re*pol"ish</hw> <pr>(r?-p?l"?sh)</pr>, <pos>v. t.</pos> <def>To
polish again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repone</ent><br/
<hw>Re*pone"</hw> <pr>(r?-p?n")</pr>, <pos>v. t.</pos> <ety>[L.
<ets>reponere</ets>; pref. <ets>re-</ets> re- + <ets>ponere</ets> to
place.]</ety> <def>To replace.</def> <rj><au>R. Baillie.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repopulation</ent><br/
<hw>Re*pop`u*la"tion</hw> <pr>(r?*p?p`?*l?"sh?n)</pr>, <pos>n.</pos>
<def>The act of repeopling; act of furnishing with a population
anew.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Report</ent><br/
<hw>Re*port"</hw> <pr>(r?-p?rt")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Reported</conjf>; <pos>p. pr. &
vb. n.</pos> Reporting.]</vmorph> <ety>[F. <ets>reporter</ets> to carry
back, carry (cf. <ets>rapporter</ets>; see <er>Rapport</er>), L.
<ets>reportare</ets> to bear or bring back; pref. <ets>re-</ets> re- +
<ets>portare</ets> to bear or bring. See <er>Port</er> bearing,
demeanor.]</ety> <sn>1.</sn> <def>To refer.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Baldwin, his son, . . . succeeded his father; so like unto him
that we <qex>report</qex> the reader to the character of King Almeric,
and will spare the repeating his description.</q>
<rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To bring back, as an answer; to announce in return;
to relate, as what has been discovered by a person sent to examine,
explore, or investigate; <as>as, a messenger <ex>reports</ex> to his
employer what he has seen or ascertained; the committee
<ex>reported</ex> progress.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>There is no man that may <qex>reporten</qex> all.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To give an account of; to relate; to tell; to
circulate publicly, as a story; <as>as, in the common phrase, it is
<ex>reported</ex></as>.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>It is <qex>reported</qex> among the heathen, and Gashmu saith it,
that thou and the Jews think to rebel.</q> <rj><qau>Neh. vi.
6.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To give an official account or statement of; <as>as,
a treasurer <ex>reports</ex> the receipts and
expenditures</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To return or repeat, as sound; to echo.</def>
<mark>[Obs. or R.]</mark> <ldquo/A church with windows only from above,
that <xex>reporteth</xex> the voice thirteen times.<rdquo/
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Parliamentary Practice)</fld> <def>To return or
present as the result of an examination or consideration of any matter
officially referred; <as>as, the committee <ex>reported</ex> the bill
witth amendments, or <ex>reported</ex> a new bill, or <ex>reported</ex>
the results of an inquiry</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>To make minutes of, as a speech, or the doings of a
public body; to write down from the lips of a speaker.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>To write an account of for publication, as in a
newspaper; <as>as, to <ex>report</ex> a public celebration or a horse
race</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>To make a statement of the conduct of, especially in
an unfavorable sense; <as>as, to <ex>report</ex> a servant to his
employer</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>To be reported</b></col>, <it>or</it> <col><b>To be
reported of</b></col></mcol>, <cd>to be spoken of; to be mentioned,
whether favorably or unfavorably.</cd> <au>Acts xvi. 2.</au> --
<col><b>To report one's self</b></col>, <cd>to betake one's self, as to
a superior or one to whom service is due, and be in readiness to receive
orders or do service.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To relate; narrate; tell; recite;
describe.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Report</ent><br/
<hw>Re*port"</hw> <pr>(r?-p?rt")</pr>, <pos>v. i.</pos> <sn>1.</sn>
<def>To make a report, or response, in respect of a matter inquired of,
a duty enjoined, or information expected; <as>as, the committee will
<ex>report</ex> at twelve o'clock</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To furnish in writing an account of a speech, the
proceedings at a meeting, the particulars of an occurrence, etc., for
publication.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1221 --></p>

<p><sn>3.</sn> <def>To present one's self, as to a superior officer, or
to one to whom service is due, and to be in readiness for orders or to
do service; also, to give information, as of one's address, condition,
etc.; <as>as, the officer <ex>reported</ex> to the general for duty; to
<ex>report</ex> weekly by letter.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Report</ent><br/
<hw>Re*port"</hw> <pr>(r<esl/*p<omac/rt")</pr>, <pos>n.</pos> <ety>[Cf.
F. <ets>rapport</ets>. See <er>Report</er>.<pos>v. t.</pos>]</ety>
<sn>1.</sn> <def>That which is reported.</def> Specifically:
<sd>(a)</sd> <def>An account or statement of the results of examination
or inquiry made by request or direction; relation.</def> <ldquo/From
Thetis sent as spies to make <xex>report</xex>.<rdquo/ <au>Waller.</au>
<sd>(b)</sd> <def>A story or statement circulating by common talk; a
rumor; hence, fame; repute; reputation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It was a true <qex>report</qex> that I heard in mine own land of
thy acts and of thy wisdom.</q> <rj><qau>1 Kings x. 6.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Cornelius the centurion, a just man, and . . . of good
<qex>report</qex> among all the nation of the Jews.</q> <rj><qau>Acts x.
22.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(c)</sd> <def>Sound; noise; as, the <xex>report</xex> of a pistol
or cannon.</def> <sd>(d)</sd> <def>An official statement of facts,
verbal or written; especially, a statement in writing of proceedings and
facts exhibited by an officer to his superiors; <as>as, the
<ex>reports</ex> of the heads af departments to Congress, of a master in
chancery to the court, of committees to a legislative body, and the
like</as>.</def> <sd>(e)</sd> <def>An account or statement of a judicial
opinion or decision, or of case argued and determined in a court of law,
chancery, etc.; also, in the plural, the volumes containing such
reports; <as>as, Coke's <ex>Reports</ex></as>.</def> <sd>(f)</sd> <def>A
sketch, or a fully written account, of a speech, debate, or the
proceedings of a public meeting, legislative body, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Rapport; relation; connection; reference.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The corridors worse, having no <qex>report</qex> to the wings they
join to.</q> <rj><qau>Evelyn.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Account; relation; narration; detail;
description; recital; narrative; story; rumor; hearsay.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reportable</ent><br/
<hw>Re*port"a*ble</hw> <pr>(-<adot/*b'l)</pr>, <pos>a.</pos>
<def>Capable or admitting of being reported.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reportage</ent><br/
<hw>Re*port"age</hw> <pr>(-<asl/j)</pr>, <pos>n.</pos> <def>SAme as
<er>Report</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reporter</ent><br/
<hw>Re*port"er</hw> <pr>(-<etil/r)</pr>, <pos>n.</pos> <def>One who
reports.</def> <specif>Specifically:</specif> <sd>(a)</sd> <def>An
officer or person who makes authorized statements of law proceedings and
decisions, or of legislative debates.</def> <sd>(b)</sd> <def>One who
reports speeches, the proceedings of public meetings, news, etc., for
the newspapers.</def><-- ##?? add other media --><br/
[<source>1913 Webster</source>]</p>

<p><q>Of our tales judge and <qex>reportour</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reportingly</ent><br/
<hw>Re*port"ing*ly</hw>, <pos>adv.</pos> <def>By report or common
fame.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reportorial</ent><br/
<hw>Re`por*to"ri*al</hw>
<pr>(r<emac/`p<osl/r*t<omac/"r<icr/*<ait/l)</pr>, <pos>a.</pos> <def>Of
or pertaining to a reporter or reporters; <as>as, the
<ex>reportorial</ex> staff of a newspaper</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reposal</ent><br/
<hw>Re*pos"al</hw> <pr>(r<esl/*p<omac/z"<ait/l)</pr>, <pos>n.</pos>
<ety>[From <er>Repose</er>.]</ety> <sn>1.</sn> <def>The act or state of
reposing; <as>as, the <ex>reposal</ex> of a trust</as>.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That on which one reposes.</def> <mark>[Obs.]</mark>
<rj><au>Burton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reposance</ent><br/
<hw>Re*pos"ance</hw> <pr>(-<it>a</it>ns)</pr>, <pos>n.</pos>
<def>Reliance.</def> <mark>[Obs.]</mark> <rj><au>John
Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repose</ent><br/
<hw>Re*pose"</hw> <pr>(r<esl/*p<omac/z")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Reposed</conjf>
<pr>(-p?zd")</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Reposing</conjf>.]</vmorph> <ety>[F. <ets>reposer</ets>; L. pref.
<ets>re-</ets> re- + <ets>pausare</ets> to pause. See <er>Pause</er>,
<er>Pose</er>, <pos>v.</pos>]</ety> <sn>1.</sn> <def>To cause to stop or
to rest after motion; hence, to deposit; to lay down; to lodge; to
reposit.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>But these thy fortunes let us straight <qex>repose</qex><br/
In this divine cave's bosom.</q> <rj><qau>Chapman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Pebbles <qex>reposed</qex> in those cliffs amongst the earth . . .
are left behind.</q> <rj><qau>Woodward.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To lay at rest; to cause to be calm or quiet; to
compose; to rest, -- often reflexive; <as>as, to <ex>repose</ex> one's
self on a couch</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>All being settled and <qex>reposed</qex>, the lord archbishop did
present his majesty to the lords and commons.</q>
<rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>After the toil of battle to <qex>repose</qex><br/
Your wearied virtue.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To place, have, or rest; to set; to
intrust.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The king <qex>reposeth</qex> all his confidence in thee.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repose</ent><br/
<hw>Re*pose"</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To lie at rest; to
rest.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Within a thicket I <qex>reposed</qex>.</q>
<rj><qau>Chapman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Figuratively, to remain or abide restfully without
anxiety or alarms.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It is upon these that the soul may <qex>repose</qex>.</q>
<rj><qau>I. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To lie; to be supported; as, trap
<qex>reposing</qex> on sand.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To lie; recline; couch; rest; sleep; settle;
lodge; abide.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repose</ent><br/
<hw>Re*pose"</hw>, <pos>n.</pos> <ety>[F. <ets>repos</ets>. See
<er>Repose</er>, <pos>v.</pos>]</ety> <sn>1.</sn> <def>A lying at rest;
sleep; rest; quiet.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Shake off the golden slumber of <qex>repose</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Rest of mind; tranquillity; freedom from uneasiness;
also, a composed manner or deportment.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Poetic)</fld> <def>A rest; a pause.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Fine Arts)</fld> <def>That harmony or moderation
which affords rest for the eye; -- opposed to the scattering and
division of a subject into too many unconnected parts, and also to
anything which is overstrained; <as>as, a painting may want
<ex>repose</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Angle of repose</b></col> <fld>(Physics)</fld>, <cd>the
inclination of a plane at which a body placed on the plane would remain
at rest, or if in motion would roll or slide down with uniform velocity;
the angle at which the various kinds of earth will stand when abandoned
to themselves.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Rest; recumbency; reclination; ease; quiet;
quietness; tranquillity; peace.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reposed</ent><br/
<hw>Re*posed"</hw> <pr>(r<esl/*p<omac/zd")</pr>, <pos>a.</pos>
<def>Composed; calm; tranquil; at rest.</def> <au>Bacon.</au> --
<wordforms><wf>Re*pos"ed*ly</wf>
<pr>(r<esl/*p<omac/z"<ecr/d*l<ycr/)</pr>, <pos>adv.</pos> --
<wf>Re*pos"ed*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reposeful</ent><br/
<hw>Re*pose"ful</hw> <pr>(r<esl/*p<omac/z"f<usdot/l)</pr>, <pos>a.</pos>
<def>Full of repose; quiet.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reposer</ent><br/
<hw>Re*pos"er</hw> <pr>(r<esl/*p<omac/z"<etil/r)</pr>, <pos>n.</pos>
<def>One who reposes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reposit</ent><br/
<hw>Re*pos"it</hw> <pr>(r<esl/*p<ocr/z"<icr/t)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Reposited</conjf>; <pos>p. pr. &
vb. n.</pos> <conjf>Repositing</conjf>.]</vmorph> <ety>[L.
<ets>repositus</ets>, p. p. of <ets>reponere</ets> to put back; pref.
<ets>re-</ets> re- + <ets>ponere</ets> to put. See
<er>Position</er>.]</ety> <def>To cause to rest or stay; to lay away; to
lodge, as for safety or preservation; to place; to store.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Others <qex>reposit</qex> their young in holes.</q>
<rj><qau>Derham.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reposition</ent><br/
<hw>Re`po*si"tion</hw> <pr>(r<esl/`p<osl/*z<icr/sh"<ucr/n)</pr>,
<pos>n.</pos> <ety>[L. <ets>repositio</ets>.]</ety> <def>The act of
repositing; a laying up.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repositor</ent><br/
<hw>Re*pos"i*tor</hw> <pr>(r<esl/*p<ocr/z"<icr/*t<etil/r)</pr>,
<pos>n.</pos> <fld>(Surg.)</fld> <def>An instrument employed for
replacing a displaced organ or part.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repository</ent><br/
<hw>Re*pos"i*to*ry</hw> <pr>(r<esl/*p<ocr/z"<icr/*t<osl/*r<ycr/)</pr>,
<pos>n.</pos> <ety>[L. <ets>repositorium</ets>, <ets>repostorium</ets>:
cf. OF. <ets>repositoire</ets>.]</ety> <def>A place where things are or
may be reposited, or laid up, for safety or preservation; a
depository.</def> <rj><au>Locke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repossess</ent><br/
<hw>Re`pos*sess"</hw> <pr>(r<esl/`p<ocr/z*z<ecr/s" <it>or</it>
r<esl/`p<ocr/s*s<ecr/s")</pr>, <pos>v. t.</pos> <sn>1.</sn> <def>To
possess again; <as>as, to <ex>repossess</ex> the land</as>.</def>
<rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <specif>Specifically</specif>: <def>To take possession
of, for failure of the possessor to make payments owed for purchase of;
-- used of real estate subject to mortgage payments and of other objects
purchased on a time-payment plan, which may be taken back (repossessed)
by the original vendor if the payments are not made on time.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>To repossess one's self of</b></col> (something), <cd>to
acquire again (something lost).</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repossession</ent><br/
<hw>Re`pos*ses"sion</hw> <pr>(r?`p?z-z?sh"?n <or/ -p?s s?sh"?n)</pr>,
<pos>n.</pos> <def>The act or the state of possessing again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reposure</ent><br/
<hw>Re*po"sure</hw> <pr>(r?-p?"sh?r; 135)</pr>, <pos>n.</pos> <def>Rest;
quiet.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In the <qex>reposure</qex> of most soft content.</q>
<rj><qau>Marston.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repour</ent><br/
<hw>Re*pour"</hw> <pr>(r?-p?r")</pr>, <pos>v. t.</pos> <def>To pour
again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repoussage</ent><br/
\'d8<hw>Re*pous`sage"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. See
<er>Repouss<eacute/</er>.]</ety> <fld>(Art)</fld> <def>Art or process of
hammering out or pressing thin metal from the reverse side: (1) in
producing repouss<eacute/ work; (2) in leveling up any part of an etched
plate that has been worked so as to cause a depression.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Repousse</ent><br/
\'d8<hw>Re*pous`s<eacute/"</hw> <pr>(r<it>e</it> -p??`s?")</pr>,
<pos>a.</pos> <ety>[F., p. p. of <ets>repousser</ets> to thrust back;
pref <ets>re-</ets> + <ets>pousser</ets> to push. See
<er>Push</er>.]</ety> <sd>(a)</sd> <def>Formed in relief, as a pattern
on metal.</def> <sd>(b)</sd> <def>Ornamented with patterns in relief
made by pressing or hammering on the reverse side; -- said of thin
metal, or of a vessel made of thin metal.</def> -- <def2><pos>n.</pos>
<def>Repouss<eacute/ work.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Repouss<eacute/ work</b></col>, <cd>ornamentation of
metal in relief by pressing or hammering on the reverse
side.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reprefe</ent><br/
<hw>Re*prefe"</hw> <pr>(r?-pr?f")</pr>, <pos>n.</pos>
<def>Reproof.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reprehend</ent><br/
<hw>Rep`re*hend"</hw> <pr>(r?p`r?-h?nd")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Reprehended</conjf>; <pos>p. pr.
& vb. n.</pos> <conjf>Reprehending</conjf>.]</vmorph> <ety>[L.
<ets>reprehendere</ets>, <ets>reprehensum</ets>, to hold back, seize,
check, blame; pref. <ets>re-</ets> re- + <ets>prehendere</ets> to lay
hold of. See <er>Prehensile</er>, and cf. <er>Reprisal</er>. ]</ety>
<def>To reprove or reprimand with a view of restraining, checking, or
preventing; to make charge of fault against; to disapprove of; to chide;
to blame; to censure.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Aristippus being <qex>reprehended</qex> of luxury by one that was
not rich, for that he gave six crowns for a small fish.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Pardon me for <qex>reprehending</qex> thee.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>In which satire human vices, ignorance, and errors . . . are
severely <qex>reprehended</qex>.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I nor advise nor <qex>reprehend</qex> the choice.</q> <rj><qau>J.
Philips.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reprehender</ent><br/
<hw>Rep`re*hend"er</hw> <pr>(-?r)</pr>, <pos>n.</pos> <def>One who
reprehends.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reprehensible</ent><br/
<hw>Rep`re*hen"si*ble</hw> <pr>(-h?n"s?-b'l)</pr>, <pos>a.</pos>
<ety>[L. <ets>reprehensibilis</ets>: cf. F.
<ets>r<eacute/pr<eacute/hensible</ets>.]</ety> <def>Worthy of
reprehension; culpable; censurable; blamable.</def> --
<wordforms><wf>Rep`re*hen"si*ble*ness</wf>, <pos>n.</pos> --
<wf>Rep`re*hen"si*bly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reprehension</ent><br/
<hw>Rep`re*hen"sion</hw> <pr>(-sh?n)</pr>, <pos>n.</pos> <ety>[L.
<ets>reprehensio</ets>: cf. F.
<ets>r<eacute/pr<eacute/hension</ets>.]</ety> <def>Reproof; censure;
blame; disapproval.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This Basilius took as though his mistress had given him a secret
<qex>reprehension</qex> that he had not showed more gratefulness to
Dorus.</q> <rj><qau>Sir P. Sidney.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Censure; reproof; reprimand. See
<er>Admonition</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reprehensive</ent><br/
<hw>Rep`re*hen"sive</hw> <pr>(-h?n"s?v)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>r<eacute/pr<eacute/hensif</ets>.]</ety> <def>Containing
reprehension; conveying reproof.</def> <rj><au>South.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Rep`re*hen"sive*ly</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reprehensory</ent><br/
<hw>Rep`re*hen"so*ry</hw> <pr>(-s?-r?)</pr>, <pos>a.</pos>
<def>Containing reproof; reprehensive; <as>as, <ex>reprehensory</ex>
complaint</as>.</def> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Re-present</ent><br/
<hw>Re`-pre*sent"</hw> <pr>(r?`pr?-z?nt")</pr>, <pos>v. t.</pos> <def>To
present again; <as>as, to <ex>re-present</ex> the points of an
argument</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Represent</ent><br/
<hw>Rep`re*sent"</hw> <pr>(r?p`r?-z?nt")</pr>, <pos>v. t.</pos> <ety>[F.
<ets>repr<eacute/senter</ets>, L. <ets>repraesentare</ets>,
<ets>repraesentatum</ets>; pref. <ets>re-</ets> re- +
<ets>preesentare</ets> to place before, present. See <er>Present</er>,
<pos>v. t.</pos>]</ety> <sn>1.</sn> <def>To present again or anew; to
present by means of something standing in the place of; to exhibit the
counterpart or image of; to typify.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Before him burn<br/
Seven lamps, as in a zodiac <qex>representing</qex><br/
The heavenly fires.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To portray by pictoral or plastic art; to delineate;
<as>as, to <ex>represent</ex> a landscape in a picture, a horse in
bronze, and the like</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To portray by mimicry or action of any kind; to act
the part or character of; to personate; <as>as, to <ex>represent</ex>
Hamlet</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To stand in the place of; to supply the place,
perform the duties, exercise the rights, or receive the share, of; to
speak and act with authority in behalf of; to act the part of (another);
<as>as, an heir <ex>represents</ex> his ancestor; an attorney
<ex>represents</ex> his client in court; a member of Congress
<ex>represents</ex> his district in Congress.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To exhibit to another mind in language; to show; to
give one's own impressions and judgement of; to bring before the mind;
to set forth; sometimes, to give an account of; to describe.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He <qex>represented</qex> Rizzio's credit with the queen to be the
chief and only obstacle to his success in that demand.</q>
<rj><qau>Robertson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>This bank is thought the greatest load on the Genoese, and the
managers of it have been <qex>represented</qex> as a second kind of
senate.</q> <rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To serve as a sign or symbol of; <as>as,
mathematical symbols <ex>represent</ex> quantities or relations; words
<ex>represent</ex> ideas or things.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>To bring a sensation of into the mind or sensorium;
to cause to be known, felt, or apprehended; to present.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Among these. Fancy next<br/
Her office holds; of all external things<br/
Which he five watchful senses <qex>represent</qex>,<br/
She forms imaginations, aery shapes.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <fld>(Metaph.)</fld> <def>To form or image again in
consciousness, as an object of cognition or apprehension (something
which was originally apprehended by direct presentation). See
<er>Presentative</er>, 3.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The general capability of knowledge necessarily requires that,
besides the power of evoking out of unconsciousness one portion of our
retained knowledge in preference to another, we posses the faculty of
<qex>representing</qex> in consciousness what is thus evoked . . . This
representative Faculty is Imagination or Phantasy.</q> <rj><qau>Sir. W.
Hamilton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Representable</ent><br/
<hw>Rep`re*sent"a*ble</hw> <pr>(-?-b'l)</pr>, <pos>a.</pos> <def>Capable
of being represented.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Representance</ent><br/
<hw>Rep`re*sent"ance</hw> <pr>(-<it>a</it>ns)</pr>, <pos>n.</pos>
<def>Representation; likeness.</def> <mark>[Obs.]</mark>
<rj><au>Donne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Representant</ent><br/
<hw>Rep`re*sent"ant</hw> <pr>(-<it>a</it>nt)</pr>, <pos>a.</pos>
<ety>[Cf. F. <ets>repr<?/sentant</ets>.]</ety> <def>Appearing or acting
for another; representing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Representant</ent><br/
<hw>Rep`re*sent"ant</hw>, <pos>n.</pos> <ety>[F.
<ets>representant</ets>.]</ety> <def>A representative.</def>
<mark>[Obs.]</mark> <rj><au>Sir H. Wotton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Representation</ent><br/
<hw>Rep`re*sen*ta"tion</hw> <pr>(-z?n-t?"sh?n)</pr>, <pos>n.</pos>
<ety>[F. <ets>repr<?/sentation</ets>, L.
<ets>representatio</ets>.]</ety> <sn>1.</sn> <def>The act of
representing, in any sense of the verb.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which represents.</def> Specifically:
<sd>(a)</sd> <def>A likeness, a picture, or a model; <as>as, a
<ex>representation</ex> of the human face, or figure, and the
like</as>.</def> <sd>(b)</sd> <def>A dramatic performance; <as>as, a
theatrical <ex>representation</ex>; a <ex>representation</ex> of
Hamlet.</as></def> <sd>(c)</sd> <def>A description or statement; <as>as,
the <ex>representation</ex> of an historian, of a witness, or an
advocate</as>.</def> <sd>(d)</sd> <def>The body of those who act as
representatives of a community or society; <as>as, the
<ex>representation</ex> of a State in Congress</as>.</def> <sd>(e)</sd>
<fld>(Insurance Law)</fld> <def>Any collateral statement of fact, made
orally or in writing, by which an estimate of the risk is affected, or
either party is influenced.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The state of being represented.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Description; show; delineaton; portraiture;
likeness; resemblance; exhibition; sight.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Re-presentation</ent><br/
<hw>Re-pres`en*ta"tion</hw> <pr>(r?-prez`?n-t?"sh?n)</pr>, <pos>n.</pos>
<ety>[See <er>Re-present</er>.]</ety> <def>The act of re-presenting, or
the state of being presented again; a new presentation; <as>as,
<ex>re-presentation</ex> of facts previously stated</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Representationary</ent><br/
<hw>Rep`re*sen*ta"tion*a*ry</hw> <pr>(r?p`r?--z?n-t?"sh?n-?-r?)</pr>,
<pos>a.</pos> <def>Implying representation; representative.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Representative</ent><br/
<hw>Rep`re*sent"a*tive</hw> <pr>(-z?nt`?-t?v)</pr>, <pos>a.</pos>
<ety>[Cf. F. <ets>repr<?/sentatif</ets>.]</ety> <sn>1.</sn> <def>Fitted
to represent; exhibiting a similitude.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Bearing the character or power of another; acting
for another or others; <as>as, a council <ex>representative</ex> of the
people</as>.</def> <rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Conducted by persons chosen to represent, or act as
deputies for, the people; <as>as, a <ex>representative</ex>
government</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Nat.Hist.)</fld> <sd>(a)</sd> <def>Serving or
fitted to present the full characters of the type of a group; typical;
<as>as, a <ex>representative</ex> genus in a family</as>.</def>
<sd>(b)</sd> <def>Similar in general appearance, structure, and habits,
but living in different regions; -- said of certain species and
varieties.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Metaph.)</fld> <def>Giving, or existing as, a
transcript of what was originally presentative knowledge; <as>as,
<ex>representative</ex> faculties; <ex>representative</ex>
knowledge</as>. See <er>Presentative</er>, 3 and <er>Represent</er>,
8.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Representative</ent><br/
<hw>Rep`re*sent"a*tive</hw>, <pos>n.</pos> <ety>[Cf. LL.
<ets>repraesentativus</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>One who, or that which, represents (anything); that
which exhibits a likeness or similitude.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A statute of Rumor, whispering an idiot in the ear, who was the
<qex>representative</qex> of Credulity.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Difficulty must cumber this doctrine which supposes that the
perfections of God are the <qex>representatives</qex> to us of whatever
we perceive in the creatures.</q> <rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An agent, deputy, or substitute, who supplies the
place of another, or others, being invested with his or their
authority.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Law)</fld> <def>One who represents, or stands in
the place of, another.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The executor or administrator is ordinarily held to be
the <xex>representative</xex> of a deceased person, and is sometimes
called the <xex>legal representative</xex>, or the <xex>personal
representative</xex>. The heir is sometimes called the <xex>real
representative</xex> of his deceased ancestor. The heirs and executors
or administrators of a deceased person are sometimes compendiously
described as his <xex>real</xex> and <xex>personal
representatives</xex>.</note> <rj><au>Wharton. Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A member of the lower or popular house in a State
legislature, or in the national Congress.</def> <mark>[U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Nat.Hist.)</fld> <sd>(a)</sd> <def>That which
presents the full character of the type of a group.</def> <sd>(b)</sd>
<def>A species or variety which, in any region, takes the place of a
similar one in another region.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Representatively</ent><br/
<hw>Rep`re*sent"a*tive*ly</hw>, <pos>adv.</pos> <def>In a representative
manner; vicariously.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Representativeness</ent><br/
<hw>Rep`re*sent"a*tive*ness</hw>, <pos>n.</pos> <def>The quality or
state of being representative.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Dr. Burnet observes, that every thought is attended with
consciousness and <qex>representativeness</qex>.</q>
<rj><qau>Spectator.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Representer</ent><br/
<hw>Rep`re*sent"er</hw> <pr>(-?r)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>One who shows, exhibits, or describes.</def> <rj><au>Sir T.
Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A representative.</def> <mark>[Obs.]</mark>
<rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Representment</ent><br/
<hw>Rep`re*sent"ment</hw> <pr>(-m<it>e</it>nt)</pr>, <pos>n.</pos>
<def>Representation.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repress</ent><br/
<hw>Re*press"</hw> <pr>(r?-pr?s")</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>re-</ets> + <ets>press</ets>.]</ety> <def>To press again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repress</ent><br/
<hw>Re*press"</hw> <pr>(r?-pr?s")</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>re- + press</ets>: cf. L. <ets>reprimere</ets>,
<ets>repressum</ets>. Cf. <er>Reprimand</er>.]</ety> <sn>1.</sn> <def>To
press back or down effectually; to crush down or out; to quell; to
subdue; to supress; <as>as, to <ex>repress</ex> sedition or rebellion;
to <ex>repress</ex> the first risings of discontent.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence, to check; to restrain; to keep
back.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Desire of wine and all delicious drinks, . . . <br/
Thou couldst <qex>repress</qex>.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To crush; overpower; subdue; suppress; restrain;
quell; curb; check.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repress</ent><br/
<hw>Re*press"</hw>, <pos>n.</pos> <def>The act of repressing.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Represser</ent><br/
<hw>Re*press"er</hw> <pr>(-?r)</pr>, <pos>n.</pos> <def>One who, or that
which, represses.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repressible</ent><br/
<hw>Re*press"i*ble</hw> <pr>(-?-b'l)</pr>, <pos>a.</pos> <def>Capable of
being repressed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repression</ent><br/
<hw>Re*pres"sion</hw> <pr>(r?-pr?sh"?n)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>r<eacute/pression</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>The act of repressing, or state of being repressed;
<as>as, the <ex>repression</ex> of evil and evil doers</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which represses; check; restraint.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repressive</ent><br/
<hw>Re*press"ive</hw> <pr>(r?-pr?s"?v)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>r<eacute/pressif</ets>. LL. <ets>repressivus</ets>.]</ety>
<def>Having power, or tending, to repress; <as>as, <ex>repressive</ex>
acts or measures</as>.</def> -- <wordforms><wf>Re*press"ive*ly</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reprevable</ent><br/
<hw>Re*prev"a*ble</hw> <pr>(r?-pr?v"?-b'l)</pr>, <pos>a.</pos>
<def>Reprovable.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repreve</ent><br/
<hw>Re*preve"</hw> <pr>(r?-pr?v")</pr>, <pos>v. t.</pos> <ety>[See
<er>Reprieve</er>, <pos>v. t.</pos>]</ety> <def>To reprove.</def>
<mark>[Obs.]</mark> <ldquo/<xex>Repreve</xex> him of his vice.<rdquo/
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repreve</ent><br/
<hw>Re*preve"</hw>, <pos>n.</pos> <def>Reproof.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repriefe</ent><br/
<hw>Re*priefe"</hw> <pr>(r?-pr?f")</pr>, <pos>n.</pos>
<def>Repreve.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reprieval</ent><br/
<hw>Re*priev"al</hw> <pr>(r?-pr?v"<it>a</it>l)</pr>, <pos>n.</pos>
<def>Reprieve.</def> <rj><au>Overbury.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reprieve</ent><br/
<hw>Re*prieve</hw> <pr>(r?-pr?v")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Reprieved</conjf>
<pr>(-pr?vd")</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Reprieving</conjf>.]</vmorph> <ety>[OE. <ets>repreven</ets> to
reject, disallow, OF. <ets>reprover</ets> to blame, reproach, condemn
(pres. <ets>il reprueve</ets>), F. <ets>r<eacute/prouver</ets> to
disapprove, fr. L. <ets>reprobare</ets> to reject, condemn; pref.
<ets>re-</ets> re- + <ets>probare</ets> to try, prove. See
<er>Prove</er>, <ets>and cf</ets>. <er>Reprove</er>,
<er>Reprobate</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>To delay the punishment of; to suspend the execution
of sentence on; to give a respite to; to respite; <as>as, to
<ex>reprieve</ex> a criminal for thirty days</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He <qex>reprieves</qex> the sinnner from time to time.</q>
<rj><qau>Rogers.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To relieve for a time, or temporarily.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Company, thought it may <qex>reprieve</qex> a man from his
melaneholy yet can not secure him from his conscience.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1222 --></p>

<p><ent>Reprieve</ent><br/
<hw>Re*prieve"</hw> <pr>(r?-pr?v")</pr>, <pos>n.</pos> <sn>1.</sn>
<def>A temporary suspension of the execution of a sentence, especially
of a sentence of death.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The morning Sir John Hotham was to die, a <qex>reprieve</qex> was
sent to suspend the execution for three days.</q>
<rj><au>Clarendon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Interval of ease or relief; respite.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>All that I ask is but a short <qex>reprieve</qex>,<br/
ll I forget to love, and learn to grieve.</q>
<rj><qau>Denham.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reprimand</ent><br/
<hw>Rep"ri*mand</hw> <pr>(r?p"r?-m?nd)</pr>, <pos>n.</pos> <ety>[F.
<ets>r<eacute/primande</ets>, <ets>fr</ets>. L. <ets>reprimendus</ets>,
<ets>reprimenda</ets>, that is to be checked or suppressed, fr.
<ets>reprimere</ets> to check, repress; pref. <ets>re-</ets> re +
<ets>premere</ets> to press. See <er>Press</er>, and cf.
<er>Repress</er>.]</ety> <def>Severe or formal reproof; reprehension,
private or public.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Goldsmith gave his landlady a sharp <qex>reprimand</qex> for her
treatment of him.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reprimand</ent><br/
<hw>Rep"ri*mand</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Reprimanded</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Reprimanding</conjf>.]</vmorph> <ety>[Cf. F.
<ets>r<eacute/primander</ets>. See <er>Reprimand</er>,
<pos>n.</pos>]</ety> <sn>1.</sn> <def>To reprove severely; to reprehend;
to chide for a fault; to consure formally.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Germanicus was severely <qex>reprimanded</qex> by Tiberius for
traveling into Egypt without his permission.</q>
<rj><qau>Arbuthnot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To reprove publicly and officially, in execution of
a sentence; <as>as, the court ordered him to be
<ex>reprimanded</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To reprove; reprehend; chide; rebuke; censure;
blame. See <er>Reprove</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reprimander</ent><br/
<hw>Rep"ri*mand`er</hw> <pr>(-m?nd`?r)</pr>, <pos>n.</pos> <def>One who
reprimands.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reprimer</ent><br/
<hw>Re*prim"er</hw> <pr>(r?-pr?m"?r)</pr>, <pos>n.</pos>
<fld>(Firearms)</fld> <def>A machine or implement for applying fresh
primers to spent cartridge shells, so that the shells be used
again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reprint</ent><br/
<hw>Re*print"</hw> <pr>(r?-pr?nt")</pr>, <pos>v. t.</pos> <sn>1.</sn>
<def>To print again; to print a second or a new edition of.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To renew the impression of.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The whole business of our redemption is . . . to
<qex>reprint</qex> God's image upon the soul.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reprint</ent><br/
<hw>Re"print`</hw> <pr>(r?"pr?nt`)</pr>, <pos>n.</pos> <def>A second or
a new impression or edition of any printed work; specifically, the
publication in one country of a work previously published in
another.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reprinter</ent><br/
<hw>Re*print"er</hw> <pr>(r?-pr?nt"?r)</pr>, <pos>n.</pos> <def>One who
reprints.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reprisal</ent><br/
<hw>Re*pris"al</hw> <pr>(r?-priz"<it>a</it>l)</pr>, <pos>n.</pos>
<ety>[F. <ets>repr<?/saille</ets>, It. <ets>ripresaglia</ets>,
<ets>rappresaglia</ets>, LL. <ets>reprensaliae</ets>, fr. L.
<ets>reprehendere</ets>, <ets>reprehensum</ets>. See <er>Reprehend</er>,
<er>Reprise</er>.]</ety> <sn>1.</sn> <def>The act of taking from an
enemy by way of retaliation or indemnity.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Debatable ground, on which incursions and <qex>reprisals</qex>
continued to take place.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Anything taken from an enemy in
retaliation.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The act of retorting on an enemy by inflicting
suffering or death on a prisoner taken from him, in retaliation for an
act of inhumanity.</def> <rj><au>Vattel (Trans.)</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Any act of retaliation.</def>
<rj><au>Waterland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Letters of marque and reprisal</b></col>. <cd>See under
<er>Marque</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reprise</ent><br/
<hw>Re*prise"</hw> <pr>(r?-pr?z")</pr>, <pos>n.</pos> <ety>[F.
<ets>reprise</ets>, fr. <ets>reprendre</ets>, <ets>repris</ets>, to take
back, L. <ets>reprehendere</ets>. See <er>Reprehend</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>A taking by way of retaliation.</def>
<mark>[Obs.]</mark> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <pluf>pl.</pluf> <fld>(Law)</fld> <def>Deductions and
duties paid yearly out of a manor and lands, as rent charge, rent seck,
pensions, annuities, and the like.</def> <altsp>[Written also
<asp>reprizes</asp>.]</altsp> <rj><au>Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A ship recaptured from an enemy or from a
pirate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reprise</ent><br/
<hw>Re*prise"</hw>, <pos>v. t.</pos> <ety>[Written also
<ets>reprize</ets>.]</ety> <sn>1.</sn> <def>To take again; to
retake.</def> <mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To recompense; to pay.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repristinate</ent><br/
<hw>Re*pris"tin*ate</hw> <pr>(r?-pr?s"t?n-?t)</pr>, <pos>v. t.</pos>
<ety>[Pref. <ets>re-</ets> + <ets>pristine</ets>.]</ety> <def>To restore
to an original state.</def> <mark>[R.]</mark>
<rj><au>Shedd.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repristination</ent><br/
<hw>Re*pris`ti*na"tion</hw> <pr>(-t?-n?"sh?n)</pr>, <pos>n.</pos>
<def>Restoration to an original state; renewal of purity.</def>
<mark>[R.]</mark> <rj><au>R. Browning.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reprive</ent><br/
<hw>Re*prive"</hw> <pr>(r?-pr?v")</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>re-</ets> + L. <ets>privare</ets> to deprive.]</ety> <def>To take
back or away.</def> <mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reprive</ent><br/
<hw>Re*prive"</hw>, <pos>v. t.</pos> <def>To reprieve.</def>
<mark>[Obs.]</mark> <rj><au>Howell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reprize</ent><br/
<hw>Re*prize"</hw> <pr>(-pr?z")</pr>, <pos>v. t.</pos> <def>See
<er>Reprise</er>.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reprizes</ent><br/
<hw>Re*priz"es</hw> <pr>(-pr?z"?z)</pr>, <pos>n. pl.</pos>
<fld>(Law)</fld> <def>See <er>Reprise</er>, <pos>n.</pos>, 2.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reproach</ent><br/
<hw>Re*proach"</hw> <pr>(r?-pr?ch")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Reproached</conjf>
<pr>(-pr?cht")</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Reproaching</conjf>.]</vmorph> <ety>[F. <ets>reprocher</ets>, OF.
<ets>reprochier</ets>, (assumed) LL. <ets>reproriare</ets>; L. pref.
<ets>re-</ets> again, against, back + <ets>prope</ets> near; hence,
originally, to bring near to, throw in one's teeth. Cf.
<er>Approach</er>.]</ety> <sn>1.</sn> <def>To come back to, or come home
to, as a matter of blame; to bring shame or disgrace upon; to
disgrace.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I thought your marriage fit; else imputation,<br/
For that he knew you, might <qex>reproach</qex> your life.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To attribute blame to; to allege something
disgraceful against; to charge with a fault; to censure severely or
contemptuously; to upbraid.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If ye be <qex>reproached</qex> for the name of Christ.</q>
<rj><qau>1 Peter iv. 14.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>That this newcomer, Shame,<br/
There sit not, and <qex>reproach</qex> us as unclean.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Mezentius . . . with his ardor warmed<br/
His fainting friends, <qex>reproached</qex> their shameful flight.<br/
Repelled the victors.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To upbraid; censure; blame; chide; rebuke;
condemn; revile; vilify.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reproach</ent><br/
<hw>Re*proach"</hw>, <pos>n.</pos> <ety>[F. <ets>reproche</ets>. See
<er>Reproach</er>, <pos>v.</pos>]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>The act of reproaching; censure mingled with
contempt; contumelious or opprobrious language toward any person;
abusive reflections; <as>as, severe <ex>reproach</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>No <qex>reproaches</qex> even, even when pointed and barbed with
the sharpest wit, appeared to give him pain.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Give not thine heritage to <qex>reproach</qex>.</q> <rj><qau>Joel
ii. 17.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A cause of blame or censure; shame;
disgrace.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>An object of blame, censure, scorn, or
derision.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Come, and let us build up the wall of Jerusalem, that we be no
more a <qex>reproach</qex>.</q> <rj><qau>Neh. ii. 17.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Disrepute; discredit; dishonor; opprobrium;
invective; contumely; reviling; abuse; vilification; scurrility;
insolence; insult; scorn; contempt; ignominy; shame; scandal;; disgrace;
infamy.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reproachablr</ent><br/
<hw>Re*proach"a*blr</hw> <pr>(-?-b'l)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>reprochable</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Deserving reproach; censurable.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Opprobrius; scurrilous.</def> <mark>[Obs.]</mark>
<rj><au>Sir T. Elyot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Re*proach"a*ble*ness</wf>, <pos>n.</pos> --
<wf>Re*proach"a*bly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reproacher</ent><br/
<hw>Re*proach"er</hw> <pr>(-?r)</pr>, <pos>n.</pos> <def>One who
reproaches.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reproachful</ent><br/
<hw>Re*proach"ful</hw> <pr>(-f?l)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Expressing or containing reproach; upbraiding; opprobrious;
abusive.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>reproachful</qex> speeches . . . <br/
That he hath breathed in my dishonor here.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Occasioning or deserving reproach; shameful; base;
<as>as, a <ex>reproachful</ex> life</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Opprobrious; contumelious; abusive; offensive;
insulting; contemptuous; scornful; insolent; scurrilous; disreputable;
discreditable; dishonorable; shameful; disgraceful; scandalous; base;
vile; infamous.</syn><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Re*proach"ful*ly</wf>
<pr>(r<?/-pr<?/ch"f<?/l-l<?/)</pr>, <pos>adv.</pos> --
<wf>Re*proach"ful*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reproachless</ent><br/
<hw>Re*proach"less</hw>, <pos>a.</pos> <def>Being without
reproach.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reprobacy</ent><br/
<hw>Rep"ro*ba*cy</hw> <pr>(r?p"r?-b?-c?)</pr>, <pos>n.</pos>
<def>Reprobation.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reprobance</ent><br/
<hw>Rep"ro*bance</hw> <pr>(-b<it>a</it>ns)</pr>, <pos>n.</pos>
<def>Reprobation.</def> <mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reprobate</ent><br/
<hw>Rep"ro*bate</hw> <pr>(-b?t)</pr>, <pos>a.</pos> <ety>[L.
<ets>reprobatus</ets>, p. p. of <ets>reprobare</ets> to disapprove,
condemn. See <er>Reprieve</er>, <er>Reprove</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Not enduring proof or trial; not of standard purity
or fineness; disallowed; rejected.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Reprobate</qex> silver shall men call them, because the Lord
hath rejected them.</q> <rj><qau>Jer. vi. 30.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Abandoned to punishment; hence, morally abandoned
and lost; given up to vice; depraved.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And strength, and art, are easily outdone<br/
By spirits <qex>reprobate</qex>.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Of or pertaining to one who is given up to
wickedness; <as>as, <ex>reprobate</ex> conduct</as>.</def>
<ldquo/<xex>Reprobate</xex> desire.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Abandoned; vitiated; depraved; corrupt; wicked;
profligate; base; vile. See <er>Abandoned</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reprobate</ent><br/
<hw>Rep"ro*bate</hw>, <pos>n.</pos> <def>One morally abandoned and
lost.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I acknowledge myself for a <qex>reprobate</qex>, a villain, a
traitor to the king.</q> <rj><qau>Sir W. Raleigh.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reprobate</ent><br/
<hw>Rep"ro*bate</hw> <pr>(-b?t)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Reprobated</conjf>
<pr>(-b?`t?d)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Reprobating</conjf>.]</vmorph> <sn>1.</sn> <def>To disapprove
with detestation or marks of extreme dislike; to condemn as unworthy; to
disallow; to reject.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Such an answer as this is <qex>reprobated</qex> and disallowed of
in law; I do not believe it, unless the deed appears.</q>
<rj><qau>Ayliffe.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Every scheme, every person, recommended by one of them, was
<qex>reprobated</qex> by the other.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To abandon to punishment without hope of
pardon.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To condemn; reprehend; censure; disown; abandon;
reject.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reprobateness</ent><br/
<hw>Rep"ro*bate*ness</hw>, <pos>n.</pos> <def>The state of being
reprobate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reprobater</ent><br/
<hw>Rep"ro*ba`ter</hw> <pr>(-b?`t?r)</pr>, <pos>n.</pos> <def>One who
reprobates.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reprobation</ent><br/
<hw>Rep`ro*ba"tion</hw> <pr>(-b?`sh?n)</pr>, <pos>n.</pos> <ety>[F.
<ets>r<eacute/probation</ets>, or L. <ets>reprobatio</ets>.]</ety>
<sn>1.</sn> <def>The act of reprobating; the state of being reprobated;
strong disapproval or censure.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The profligate pretenses upon which he was perpetually soliciting
an increase of his disgraceful stipend are mentioned with becoming
<qex>reprobation</qex>.</q> <rj><qau>Jeffrey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Set a brand of <qex>reprobation</qex> on clipped poetry and false
coin.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Theol.)</fld> <def>The predestination of a certain
number of the human race as reprobates, or objects of condemnation and
punishment.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reprobationer</ent><br/
<hw>Rep`ro*ba"tion*er</hw> <pr>(-?r)</pr>, <pos>n.</pos>
<fld>(Theol.)</fld> <def>One who believes in reprobation. See
<er>Reprobation</er>, 2.</def> <rj><au>South.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reprobative</ent><br/
<hw>Rep"ro*ba*tive</hw> <pr>(-b?-t?v)</pr>, <pos>a.</pos> <def>Of or
pertaining to reprobation; expressing reprobation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reprobatory</ent><br/
<hw>Rep"ro*ba`to*ry</hw> <pr>(-b?`t?-r?)</pr>, <pos>a.</pos>
<def>Reprobative.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reproduce</ent><br/
<hw>Re`pro*duce"</hw> <pr>(r?`pr?-d?s")</pr>, <pos>v. t.</pos> <def>To
produce again.</def> Especially: <sd>(a)</sd> <def>To bring forward
again; <as>as, to <ex>reproduce</ex> a witness; to <ex>reproduce</ex>
charges; to <ex>reproduce</ex> a play</as>.</def> <sd>(b)</sd> <def>To
cause to exist again.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Those colors are unchangeable, and whenever all those rays with
those their colors are mixed again they <qex>reproduce</qex> the same
white light as before.</q> <rj><qau>Sir I. Newton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(c)</sd> <def>To produce again, by generation or the like; to
cause the existence of (something of the same class, kind, or nature as
another thing); to generate or beget, as offspring; <as>as, to
<ex>reproduce</ex> a rose; some animals are <ex>reproduced</ex> by
gemmation</as>.</def> <sd>(d)</sd> <def>To make an image or other
representation of; to portray; to cause to exist in the memory or
imagination; to make a copy of; <as>as, to <ex>reproduce</ex> a person's
features in marble, or on canvas; to <ex>reproduce</ex> a
design</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reproducer</ent><br/
<hw>Re`pro*du"cer</hw> <pr>(-d?"s?r)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>One who, or that which, reproduces.</def>
<rj><au>Burke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>In a phonograph, a device containing a sounding
diaphragm and the needle or stylus that traverses the moving record, for
reproducing the sound.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>3.</sn> <def>In a manograph, a device for reproducing the engine
stroke on a reduced scale.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Reproduction</ent><br/
<hw>Re`pro*duc"tion</hw> <pr>(-d?k"sh?n)</pr>, <pos>n.</pos> <ety>[Cf.
F. <ets>reproduction</ets>.]</ety> <sn>1.</sn> <def>The act or process
of reproducing; the state of being reproduced</def>;
<specif>specifically</specif> <fld>(Biol.)</fld>, <def>the process by
which plants and animals give rise to offspring.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ There are two distinct methods of reproduction; viz.:
<stype>asexual reproduction</stype> (agamogenesis) and <stype>sexual
reproduction</stype> (gamogenesis). In both cases the new individual is
developed from detached portions of the parent organism. In asexual
reproduction (gemmation, fission, etc.), the detached portions of the
organism develop into new individuals without the intervention of other
living matter. In sexual reproduction, the detached portion, which is
always a single cell, called the <xex>female germ cell</xex>, is acted
upon by another portion of living matter, the <xex>male germ cell</xex>,
usually from another organism, and in the fusion of the two
(impregnation) a new cell is formed, from the development of which
arises a new individual.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is reproduced.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reproductive</ent><br/
<hw>Re`pro*duc"tive</hw> <pr>(-t?v)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>reproductif</ets>.]</ety> <def>Tending, or pertaining, to
reproduction; employed in reproduction.</def>
<rj><au>Lyell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reproductory</ent><br/
<hw>Re`pro*duc"to*ry</hw> <pr>(-t?-r?)</pr>, <pos>a.</pos>
<def>Reproductive.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reproof</ent><br/
<hw>Re*proof"</hw> <pr>(r?-pr??f")</pr>, <pos>n.</pos> <ety>[OE.
<ets>reproef</ets>. See <er>Proof</er>, <er>Reprove</er>.]</ety>
<sn>1.</sn> <def>Refutation; confutation; contradiction.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An expression of blame or censure; especially, blame
expressed to the face; censure for a fault; chiding; reproach.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Those best can bear <qex>reproof</qex> who merit praise.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Admonition; reprehension; chiding; reprimand;
rebuke; censure; blame. See <er>Admonition</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reprovable</ent><br/
<hw>Re*prov"a*ble</hw> <pr>(r?-pr??v"?-b'l)</pr>, <pos>a.</pos>
<ety>[Cf. F. <ets>r<eacute/prouvable</ets>.]</ety> <def>Worthy of
reproof or censure.</def> <rj><au>Jer. Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Blamable; blameworthy; censurable; reprehensible;
culpable; rebukable.</syn><br/
[<source>1913 Webster</source>]</p>

<p>--<wordforms><wf>Re*prov"a*ble*ness</wf>, <pos>n.</pos> --
<wf>Re*prov"a*bly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Re proval</ent><br/
<hw>Re prov"al</hw> <pr>(-<it>a</it>l)</pr>, <pos>n.</pos>
<def>Reproof.</def> <rj><au>Sir P. Sidney.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reprove</ent><br/
<hw>Re*prove"</hw> <pr>(r?-pr??v")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Reproved</conjf>
<pr>(-pr??vd")</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Reproving</conjf>.]</vmorph> <ety>[F.
<ets>r<eacute/prouver</ets>, OF. <ets>reprover</ets>, fr. L.
<ets>reprobare</ets>. See <er>Reprieve</er>, <er>Reprobate</er>, and cf.
<er>Reproof</er>.]</ety> <sn>1.</sn> <def>To convince.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>When he is come, he will <qex>reprove</qex> the world of sin, and
of righteousness, and of judgment.</q> <rj><qau>John xvi.
9.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To disprove; to refute.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Reprove</qex> my allegation, if you can.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To chide to the face as blameworthy; to accuse as
guilty; to censure.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>What if thy son</q><br/
[<source>1913 Webster</source>]</p>

<p><q>Prove disobedient, and, <qex>reproved</qex>, retort,<br/
<ldquo/Wherefore didst thou beget me?<rdquo/</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To express disapprobation of; <as>as, to
<ex>reprove</ex> faults</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He neither <qex>reproved</qex> the ordinance of John, neither
plainly condemned the fastings of the other men.</q>
<rj><qau>Udall.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To reprehend; chide; rebuke; scold; blame
censure.</syn> <usage> -- <er>Reprove</er>, <er>Rebuke</er>,
<er>Reprimand</er>. These words all signufy the expression of
disapprobation. To <xex>reprove</xex> implies greater calmness and
self-possession. To <xex>rebuke</xex> implies a more excited and
personal feeling. A <xex>reproof</xex> may be administered long after
the offience is committed, and is usually intended for the reformation
of the offender; a <xex>rebuke</xex> is commonly given at the moment of
the wrong, and is administered by way of punishment and condemnation. A
<xex>reprimand</xex> proceeds from a person invested with authority, and
is a formal and offiscial act. A child is <xex>reproved</xex> for his
faults, and <xex>rebuked</xex> for his impudence. A military officer is
<xex>reprimanded</xex> for neglect or violation of duty.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reprover</ent><br/
<hw>Re*prov"er</hw> <pr>(r?-pr??v"?r)</pr>, <pos>n.</pos> <def>One who,
or that which, reproves.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reprovingly</ent><br/
<hw>Re*prov"ing*ly</hw>, <pos>adv.</pos> <def>In a reproving
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reprune</ent><br/
<hw>Re*prune"</hw> <pr>(r<emac/*pr<udd/n")</pr>, <pos>v. t.</pos>
<def>To prune again or anew.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Yet soon <qex>reprunes</qex> her wing to soar anew.</q>
<rj><qau>Young.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rep-silver</ent><br/
<hw>Rep"-sil`ver</hw> <pr>(r?p"s?l`v?r)</pr>, <pos>n.</pos> <ety>[See
<er>Reap</er>.]</ety> <def>Money anciently paid by servile tenants to
their lord, in lieu of the customary service of reaping his corn or
grain.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reptant</ent><br/
<hw>Rep"tant</hw> <pr>(r?p"t<it>a</it>nt)</pr>, <pos>a.</pos> <ety>[L.
<ets>reptans</ets>, <ets>-antis</ets>, p. pr. of <ets>reptare</ets>, v.
intens. from <ets>repere</ets> to creep. See
<er>Reptile</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <fld>(Bot.)</fld> <def>Same as <er>Repent</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>Creeping; crawling; -- said of
reptiles, worms, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reptantia</ent><br/
\'d8<hw>Rep*tan"ti*a</hw> <pr>(r?p-t?n"sh?-?)</pr>, <pos>n. pl.</pos>
<ety>[NL.]</ety> <fld>(Zool.)</fld> <def>A division of gastropods; the
Pectinibranchiata.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reptation</ent><br/
<hw>Rep*ta"tion</hw> <pr>(r?p-t?"sh?n)</pr>, <pos>n.</pos> <ety>[L.
<ets>reptatio</ets>, from <ets>reptare</ets>: cf. F.
<ets>reptation</ets>.]</ety> <fld>(Zool.)</fld> <def>The act of
creeping.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reptatory</ent><br/
<hw>Rep"ta*to*ry</hw> <pr>(r?p"t?-t?-r?)</pr>, <pos>a.</pos>
<fld>(Zool.)</fld> <def>Creeping.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reptile</ent><br/
<hw>Rep"tile</hw> <pr>(r?p"t?l;277)</pr>, <pos>a.</pos> <ety>[F.
<ets>reptile</ets>, L. <ets>reptilis</ets>, fr. <ets>repere</ets>,
<ets>reptum</ets>, to creep; cf. Lith. <ets>reploti</ets>; perh. akin to
L. <ets>serpere</ets>. Cf. <er>Serpent</er>.]</ety> <sn>1.</sn>
<def>Creeping; moving on the belly, or by means of small and short
legs.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence: Groveling; low; vulgar; <as>as, a
<ex>reptile</ex> race or crew; <ex>reptile</ex> vices.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>There is also a false, <qex>reptile</qex> prudence, the result not
of caution, but of fear.</q> <rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And dislodge their <qex>reptile</qex> souls<br/
From the bodies and forms of men.</q> <rj><qau>Coleridge.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reptile</ent><br/
<hw>Rep"tile</hw>, <pos>n.</pos> <sn>1.</sn> <fld>(Zool.)</fld> <def>An
animal that crawls, or moves on its belly, as snakes,, or by means of
small, short legs, as lizards, and the like.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>An inadvertent step may crush the snail<br/
That crawls at evening in the public path;<br/
But he that has humanity, forewarned,<br/
Will tread aside, and let the <qex>reptile</qex> live.</q>
<rj><qau>Cowper.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>One of the Reptilia, or one of
the Amphibia.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The amphibians were formerly classed with Reptilia, and
are still popularly called <xex>reptiles</xex>, though much more closely
allied to the fishes.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A groveling or very mean person.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reptilia</ent><br/
\'d8<hw>Rep*til"i*a</hw> <pr>(r?p-t?l"?-?)</pr>, <pos>n. pl.</pos>
<ety>[NL.]</ety> <fld>(Zool.)</fld> <def>A class of air-breathing
oviparous vertebrates, usually covered with scales or bony plates. The
heart generally has two auricles and one ventricle. The development of
the young is the same as that of birds.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ It is nearly related in many respects to Aves, or birds.
The principal existing orders are <ord>Testidunata</ord> or
<ord>Chelonia</ord> (turtles), <ord>Crocodilia</ord>,
<ord>Lacertilla</ord> (lizards), <ord>Ophidia</ord> (serpents), and
<ord>Rhynchocephala</ord>; the chief extinct orders are
<ord>Dinosauria</ord>, <ord>Theremorpha</ord>, <ord>Mosasauria</ord>,
<ord>Pterosauria</ord>, <ord>Plesiosauria</ord>,
<ord>Ichtyosauria</ord>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reptilian</ent><br/
<hw>Rep*til"i*an</hw> <pr>(-<it>a</it>n)</pr>, <pos>a.</pos>
<def>Belonging to the reptiles.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Reptilian age</b></col> <fld>(Geol.)</fld>, <cd>that part
of geological time comprising the Triassic, Jurassic, and Cretaceous
periods, and distinguished as that era in which the class of reptiles
attained its highest expansion; -- called also the
<altname>Secondary</altname> or <altname>Mezozoic</altname>
age.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reptilian</ent><br/
<hw>Rep*til"i*an</hw>, <pos>n.</pos> <fld>(Zool.)</fld> <def>One of the
Reptilia; a reptile.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Republic</ent><br/
<hw>Re*pub"lic</hw> <pr>(r?-p?b"l?k)</pr>, <pos>n.</pos> <ety>[F.
<ets>r<eacute/publique</ets>, L. <ets>respublica</ets> commonwealth;
<ets>res</ets> a thing, an affair + <ets>publicus</ets>,
<ets>publica</ets>, public. See <er>Real</er>, <pos>a.</pos>, and
<er>Public</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Common weal.</def> <mark>[Obs.]</mark> <rj><au>B.
Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A state in which the sovereign power resides in the
whole body of the people, and is exercised by representatives elected by
them; a commonwealth. Cf. <er>Democracy</er>, 2.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In some ancient states called republics the sovereign
power was exercised by an hereditary aristocracy or a privileged few,
constituting a government now distinctively called an
<xex>aristocracy</xex>. In some there was a division of authority
between an aristocracy and the whole body of the people except slaves.
No existing republic recognizes an exclusive privilege of any class to
govern, or tolerates the institution of slavery.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Republic of letters</b></col>, <cd>The collective body of
literary or learned men.</cd></cs> <-- Democratic republic, a term much
used by countries with a Communist system of government. --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Republican</ent><br/
<hw>Re*pub"lic*an</hw> <pr>(-l?-k<it>a</it>n)</pr>, <pos>a.</pos>
<ety>[F. <ets>r<eacute/publicain</ets>.]</ety> <sn>1.</sn> <def>Of or
pertaining to a republic.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The Roman emperors were <qex>republican</qex> magistrates named by
the senate.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Consonant with the principles of a republic; <as>as,
<ex>republican</ex> sentiments or opinions; <ex>republican</ex>
manners.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Republican party</b></col>. <fld>(U.S. Politics)</fld>
<sd>(a)</sd> <cd>An earlier name of the Democratic party when it was
opposed to the Federal party. Thomas Jefferson was its great
leader.</cd> <sd>(b)</sd> <cd>One of the existing great parties. It was
organized in 1856 by a combination of voters from other parties for the
purpose of opposing the extension of slavery, and in 1860 it elected
Abraham Lincoln president.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1223 --></p>

<p><ent>Republican</ent><br/
<hw>Re*pub"lic*an</hw> <pr>(r?-p?b"l?-k<it>a</it>n)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>One who favors or prefers a republican form of
government.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(U.S.Politics)</fld> <def>A member of the Republican
party.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <sd>(a)</sd> <def>The American cliff
swallow. The cliff swallows build their nests side by side, many
together.</def> <sd>(b)</sd> <def>A South African weaver bird
(<spn>Philetaerus socius</spn>). These weaver birds build many nests
together, under a large rooflike shelter, which they make of
straw.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Red republican</b></col>. <cd>See under
<er>Red</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Republicanism</ent><br/
<hw>Re*pub"lic*an*ism</hw> <pr>(-?z'm)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>r<eacute/publicanisme</ets>.]</ety> <sn>1.</sn> <def>A republican
form or system of government; the principles or theory of republican
government.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Attachment to, or political sympathy for, a
republican form of government.</def> <rj><au>Burke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The principles and policy of the Republican party,
so called</def> <mark>[U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Republicanize</ent><br/
<hw>Re*pub"lic*an*ize</hw> <pr>(-?z)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Republicanized</conjf>
<pr>(-?zd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Republicanizing</conjf> <pr>(-?`z?ng)</pr>.]</vmorph> <ety>[Cf.
F. <ets>r<eacute/publicaniser</ets>.]</ety> <def>To change, as a state,
into a republic; to republican principles; <as>as, France was
<ex>republicanized</ex>; to <ex>republicanize</ex> the rising
generation.</as></def> <rj><au>D. Ramsay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Republicate</ent><br/
<hw>Re*pub"li*cate</hw> <pr>(r?*p?b"l?*k?t)</pr>, <pos>v. t.</pos>
<ety>[Cf. LL. <ets>republicare</ets>.]</ety> <def>To make public again;
to republish.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Republication</ent><br/
<hw>Re*pub`li*ca"tion</hw> <pr>(r?-p?b`l?-k?"sh?n)</pr>, <pos>n.</pos>
<def>A second publication, or a new publication of something before
published, as of a former will, of a volume already published, or the
like; specifically, the publication in one country of a work first
issued in another; a reprint.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If there be many testaments, the last overthrows all the former;
but the <qex>republication</qex> of a former will revokes one of a later
date, and establishes the first.</q> <rj><qau>Blackstone.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Republish</ent><br/
<hw>Re*pub"lish</hw> <pr>(r?-p?b"l?sh)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Republished</conjf>
<pr>(-l?sht)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Republishing</conjf>.]</vmorph> <def>To publish anew;
specifically, to publish in one country (a work first published in
another); also, to revive (a will) by reexecution or codicil.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Subsecquent to the purchase or contract, the devisor
<qex>republished</qex> his will.</q> <rj><qau>Blackstone.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Republisher</ent><br/
<hw>Re*pub"lish*er</hw> <pr>(-?r)</pr>, <pos>n.</pos> <def>One who
republishes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>repudiable</ent><br/
<hw>re*pu"di*a*ble</hw> <pr>(r<esl/*p<umac/"d<icr/*<adot/*b'l)</pr>,
<pos>a.</pos> <ety>[See <er>repudiate</er>.]</ety> <def>Admitting of
repudiation; fit or proper to be put away.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repudiate</ent><br/
<hw>Re*pu"di*ate</hw> <pr>(r<esl/*p<umac/"d<icr/*<amac/t)</pr>, <pos>v.
t.</pos> <vmorph>[<pos>imp. & p. p.</pos> <conjf>Repudiated</conjf>
<pr>(-?`t?d)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Repudiating</conjf>.]</vmorph> <ety>[L. <ets>repudiatus</ets>, p.
p. of <ets>repudiare</ets> to repudiate, reject, fr. <ets>repudium</ets>
separation, divorce; pref. <ets>re-</ets> re- + <ets>pudere</ets> to be
ashamed.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>To cast off; to disavow; to have nothing to do with;
to renounce; to reject.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Servitude is to be <qex>repudiated</qex> with greater care.</q>
<rj><qau>Prynne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To divorce, put away, or discard, as a wife, or a
woman one has promised to marry.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His separation from Terentis, whom he <qex>repudiated</qex> not
long afterward.</q> <rj><qau>Bolingbroke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To refuse to acknowledge or to pay; to disclaim;
<as>as, the State has <ex>repudiated</ex> its debts</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repudiation</ent><br/
<hw>Re*pu`di*a"tion</hw>
<pr>(r<esl/*p<umac/`d<icr/*<amac/"sh<ucr/n)</pr>, <pos>n.</pos>
<ety>[Cf.F. <ets>r<eacute/pudiation</ets>, L.
<ets>repudiatio</ets>.]</ety> <def>The act of repudiating, or the state
of being repuddiated; <as>as, the <ex>repudiation</ex> of a doctrine, a
wife, a debt, etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repudiation</ent><br/
<hw>Re*pu`di*a"tion</hw>, <pos>n.</pos> <def>One who favors repudiation,
especially of a public debt.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repudiator</ent><br/
<hw>Re*pu"di*a`tor</hw> <pr>(r?-p?"d?-?`t?r)</pr>, <pos>n.</pos>
<ety>[L., a rejecter, contemner.]</ety> <def>One who
repudiates.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repugn</ent><br/
<hw>Re*pugn"</hw> <pr>(r?-p?n")</pr>, <pos>v. t.</pos> <ety>[F.
<ets>r<eacute/pugner</ets>, L. <ets>repugnare</ets>,
<ets>repugnatum</ets>; pref. <ets>re-</ets> + <ets>pugnare</ets> to
fight. See <er>Pugnacious</er>.]</ety> <def>To fight against; to oppose;
to resist.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Stubbornly he did <qex>repugn</qex> the truth.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repugnable</ent><br/
<hw>Re*pug"na*ble</hw> <pr>(r?-p?g"n?-b'l)</pr>, <pos>a.</pos>
<def>Capable of being repugned or resisted.</def> <mark>[R.]</mark>
<rj><au>Sir T. North.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repugnancy</ent><br/
<ent>Repugnance</ent><br/
<mhw>{ <hw>Re*pug"nance</hw> <pr>(-n<it>a</it>ns)</pr>,
<hw>Re*pug"nan*cy</hw> <pr>(-n<it>a</it>n-s?)</pr>, }</mhw>
<pos>n.</pos> <ety>[F. <ets>r<eacute/pugnance</ets>, L.
<ets>repugnantia</ets>.]</ety> <def>The state or condition of being
repugnant; opposition; contrariety; especially, a strong instinctive
antagonism; aversion; reluctance; unwillingness, as of mind, passions,
principles, qualities, and the like.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That which causes us to lose most of our time is the
<qex>repugnance</qex> which we naturally have to labor.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Let the foes quietly cut their throats,<br/
Without <qex>repugnancy</qex>.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Aversion; reluctance; unwillingness; dislike;
antipathy; hatred; hostility; irreconcilableness; contrariety;
inconsistency. See <er>Dislike</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repugnant</ent><br/
<hw>Re*pug"nant</hw> <pr>(-n<it>a</it>nt)</pr>, <pos>a.</pos> <ety>[F.
<ets>r<eacute/pugnant</ets>, or L. <ets>repugnans</ets>,
<ets>-antis</ets>, p. pr. of <ets>repugnare</ets>. See
<er>Repugn</er>.]</ety> <def>Disposed to fight against; hostile; at war
with; being at variance; contrary; inconsistent; refractory;
disobedient; also, distasteful in a high degree; offensive; -- usually
followed by <xex>to</xex>, rarely and less properly by <xex>with</xex>;
<as>as, all rudeness was <ex>repugnant</ex> to her
nature</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>[His sword] <qex>repugnant</qex> to command.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>There is no breach of a divine law but is more or less
<qex>repugnant</qex> unto the will of the Lawgiver, God himself.</q>
<rj><qau>Perkins.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Opposite; opposed; adverse; contrary;
inconsistent; irreconcilable; hostile; inimical.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repugnantly</ent><br/
<hw>Re*pug"nant*ly</hw>, <pos>adv.</pos> <def>In a repugnant
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repugnate</ent><br/
<hw>Re*pug"nate</hw> <pr>(-n?t)</pr>, <pos>v. t.</pos> <ety>[From L.
<ets>repugnare</ets>. See <er>Repugn</er>.]</ety> <def>To oppose; to
fight against.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repugner</ent><br/
<hw>Re*pugn"er</hw> <pr>(r?-p?n"?r)</pr>, <pos>n.</pos> <def>One who
repugns.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repullulate</ent><br/
<hw>Re*pul"lu*late</hw> <pr>(r?-p?l"l?-l?t)</pr>, <pos>v. i.</pos>
<ety>[L. <ets>repullulare</ets>, <ets>repullulatum</ets>. See
<er>Pullulate</er>.]</ety> <def>To bud again.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Though tares <qex>repullulate</qex>, there is wheat still left in
the field.</q> <rj><qau>Howell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repullulation</ent><br/
<hw>Re*pul`lu*la"tion</hw> <pr>(r?-p?l`l?-l?"sh?n)</pr>, <pos>n.</pos>
<def>The act of budding again; the state of having budded
again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repulse</ent><br/
<hw>Re*pulse"</hw> <pr>(r?-p?ls")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Repulsed</conjf>
<pr>(-p?lst")</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Repulsing</conjf>.]</vmorph> <ety>[L. <ets>repulsus</ets>, p. p.
of <ets>repellere</ets>. See <er>Repel</er>.]</ety> <sn>1.</sn> <def>To
repel; to beat or drive back; <as>as, to <ex>repulse</ex> an assault; to
<ex>repulse</ex> the enemy.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Complete to have discovered and <qex>repulsed</qex><br/
Whatever wiles of foe or seeming friend.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To repel by discourtesy, coldness, or denial; to
reject; to send away; <as>as, to <ex>repulse</ex> a suitor or a
proffer</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repulse</ent><br/
<hw>Re*pulse"</hw>, <pos>n.</pos> <ety>[L. <ets>repulsa</ets>, fr.
<ets>repellere</ets>, <ets>repulsum</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>The act of repelling or driving back; also, the
state of being repelled or driven back.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>By fate repelled, and with <qex>repulses</qex> tired.</q>
<rj><qau>Denham.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He received in the <qex>repulse</qex> of Tarquin seven hurts in
the body.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Figuratively: Refusal; denial; rejection;
failure.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repulseless</ent><br/
<hw>Re*pulse"less</hw>, <pos>a.</pos> <def>Not capable of being
repulsed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repulser</ent><br/
<hw>Re*puls"er</hw> <pr>(-?r)</pr>, <pos>n.</pos> <def>One who repulses,
or drives back.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repulsion</ent><br/
<hw>Re*pul"sion</hw> <pr>(r?-p?l"sh?n)</pr>, <pos>n.</pos> <ety>[L.
<ets>repulsio</ets>: cf. F. <ets>r<eacute/pulsion</ets>.]</ety>
<sn>1.</sn> <def>The act of repulsing or repelling, or the state of
being repulsed or repelled.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A feeling of violent offence or disgust;
repugnance.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Physics)</fld> <def>The power, either inherent or
due to some physical action, by which bodies, or the particles of
bodies, are made to recede from each other, or to resist each other's
nearer approach; <as>as, molecular <ex>repulsion</ex>; electrical
<ex>repulsion</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repulsive</ent><br/
<hw>Re*pul"sive</hw> <pr>(-s?v)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>r<eacute/pulsif</ets>.]</ety> <sn>1.</sn> <def>Serving, or able, to
repulse; repellent; <as>as, a <ex>repulsive</ex> force</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Repulsive</qex> of his might the weapon stood.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Cold; forbidding; offensive; <as>as,
<ex>repulsive</ex> manners</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Re*pul"sive*ly</wf>, <pos>adv.</pos> --
<wf>Re*pul"sive*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repulsory</ent><br/
<hw>Re*pul"so*ry</hw> <pr>(-s?-r?)</pr>, <pos>a.</pos> <ety>[L.
<ets>repulsorius</ets>.]</ety> <def>Repulsive; driving back.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repurchase</ent><br/
<hw>Re*pur"chase</hw> <pr>(r?*p?r"ch?s; 48)</pr>, <pos>v. t.</pos>
<def>To buy back or again; to regain by purchase.</def> <rj><au>Sir M.
Hale.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repurchase</ent><br/
<hw>Re*pur"chase</hw>, <pos>n.</pos> <def>The act of
repurchasing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repurify</ent><br/
<hw>Re*pu"ri*fy</hw> <pr>(r?-p?"r?-f?)</pr>, <pos>v. t.</pos> <def>To
purify again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reputable</ent><br/
<hw>Rep"u*ta*ble</hw> <pr>(r?p"?-t?-b'l)</pr>, <pos>a.</pos> <ety>[From
<er>Repute</er>.]</ety> <def>Having, or worthy of, good repute; held in
esteem; honorable; praiseworthy; <as>as, a <ex>reputable</ex> man or
character; <ex>reputable</ex> conduct.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>In the article of danger, it is as <qex>reputable</qex> to elude
an enemy as defeat one.</q> <rj><qau>Broome.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Respectable; creditable; estimable.</syn><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Rep"u ta*ble*ness</wf>, <pos>n.</pos> --
<wf>Rep"u*ta*bly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reputation</ent><br/
<hw>Rep`u*ta"tion</hw> <pr>(-t?"sh?n)</pr>, <pos>n.</pos> <ety>[F.
<ets>r<eacute/putation</ets>, L. <ets>reputatio</ets> a reckoning,
consideration. See <er>Repute</er>, <pos>v. t.</pos>]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>The estimation in which one is held; character in
public opinion; the character attributed to a person, thing, or action;
repute.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The best evidence of <qex>reputation</qex> is a man's whole
life.</q> <rj><qau>Ames.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>The character imputed to a person
in the community in which he lives. It is admissible in evidence when he
puts his character in issue, or when such reputation is otherwise part
of the issue of a case.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Specifically: Good reputation; favorable regard;
public esteem; general credit; good name.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I see my <qex>reputation</qex> is at stake.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The security of his <qex>reputation</qex> or good name.</q>
<rj><qau>Blackstone.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Account; value.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>[/Christ] made himself of no <qex>reputation</qex>.</q>
<rj><qau>Phil. ii. 7.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Credit; repute; regard; estimation; esteem;
honor; fame. See the Note under <er>Character</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reputatively</ent><br/
<hw>Re*put"a*tive*ly</hw> <pr>(r?-p?t"?-t?v-l?)</pr>, <pos>adv.</pos>
<def>By repute.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repute</ent><br/
<hw>Re*pute"</hw> <pr>(r?-p?t")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Reputed</conjf>; <pos>p. pr. &
vb. n.</pos> <conjf>Reputing</conjf>.]</vmorph> <ety>[F.
<ets>r<eacute/puter</ets>, L. <ets>reputare</ets> to count over, think
over; pref. <ets>re-</ets> re- + <ets>putare</ets> to count, think. See
<er>Putative</er>.]</ety> <def>To hold in thought; to account; to
estimate; to hold; to think; to reckon.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Wherefore are we counted as beasts, and <qex>reputed</qex> vile in
your sight?</q> <rj><qau>Job xviii. 3.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The king your father was <qex>reputed</qex> for<br/
A prince most prudent.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Repute</ent><br/
<hw>Re*pute"</hw>, <pos>n.</pos> <sn>1.</sn> <def>Character reputed or
attributed; reputation, whether good or bad; established opinion; public
estimate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He who regns<br/
Monarch in heaven, till then as one secure<br/
Sat on his throne, upheld by old <qex>repute</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Specifically: Good character or reputation; credit
or honor derived from common or public opinion; -- opposed to
<xex>disrepute</xex>.</def> <ldquo/Dead stocks, which have been of
<xex>repute</xex>.<rdquo/ <rj><au>F. Beaumont.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reputedly</ent><br/
<hw>Re*put"ed*ly</hw> <pr>(r?-p?t"?d-l?)</pr>, <pos>adv.</pos> <def>In
common opinion or estimation; by repute.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reputeless</ent><br/
<hw>Re*pute"less</hw>, <pos>a.</pos> <def>Not having good repute;
disreputable; disgraceful; inglorius.</def> <mark>[R.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Requere</ent><br/
<hw>Re*quere"</hw> <pr>(r?--kw?r")</pr>, <pos>v. t.</pos> <def>To
require.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Request</ent><br/
<hw>Re*quest"</hw> <pr>(r<esl/*kw<ecr/st")</pr>, <pos>n.</pos> <ety>[OE.
<ets>requeste</ets>, OF. <ets>requeste</ets>, F.
<ets>requ<ecir/te</ets>, LL. <ets>requesta</ets>, for
<ets>requisita</ets>, fr. L. <ets>requirere</ets>,
<ets>requisitum</ets>, to seek again, ask for. See <er>Require</er>, and
cf. <er>Quest</er>.]</ety> <sn>1.</sn> <def>The act of asking for
anything desired; expression of desire or demand; solicitation; prayer;
petition; entreaty.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I will marry her, sir, at your <qex>request</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is asked for or requested.</def>
<ldquo/He gave them their <xex>request</xex>.<rdquo/ <rj><au>Ps. cvi.
15.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I will both hear and grant you your <qex>requests</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A state of being desired or held in such estimation
as to be sought after or asked for; demand.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Knowledge and fame were in as great <qex>request</qex> as wealth
among us now.</q> <rj><qau>Sir W. Temple.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Court of Requests</b></col>. <sd>(a)</sd> <cd>A local
tribunal, sometimes called <altname>Court of Consience</altname>,
founded by act of Parliament to facilitate the recovery of small debts
from any inhabitant or trader in the district defined by the act; -- now
mostly abolished</cd>. <sd>(b)</sd> <cd>A court of equity for the relief
of such persons as addressed the sovereign by supplication; -- now
abolished. It was inferior to the Court of Chancery.</cd>
<mark>[Eng.]</mark> <au>Brande & C.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Asking; solicitation; petition; prayer;
supplication; entreaty; suit.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Request</ent><br/
<hw>Re*quest"</hw> <pr>(r?-kw?st")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Requested</conjf>; <pos>p. pr. &
vb. n.</pos> <conjf>Requesting</conjf>.]</vmorph> <ety>[Cf. OF.
<ets>requester</ets>, F. <ets>requ<ecir/ter</ets>.]</ety> <sn>1.</sn>
<def>To ask for (something); to express desire ffor; to solicit; <as>as,
to <ex>request</ex> his presence, or a favor</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To address with a request; to ask.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I <qex>request</qex> you<br/
To give my poor host freedom.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To ask; solicit; entreat; beseech. See
<er>Beg</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Requester</ent><br/
<hw>Re*quest"er</hw> <pr>(-?r)</pr>, <pos>n.</pos> <def>One who
requests; a petitioner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Requicken</ent><br/
<hw>Re*quick"en</hw> <pr>(r?-kw?k"'n)</pr>, <pos>v. t.</pos> <def>To
quicken anew; to reanimate; to give new life to.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Requiem</ent><br/
<hw>Re"qui*em</hw> <pr>(r?"kw?-?m;277)</pr>, <pos>n.</pos> <ety>[Acc. of
L. <ets>requies</ets> rest, the first words of the Mass being
<ldquo/<ets>Requiem</ets> aeternam dona eis, Domine,<rdquo/ give eternal
rest to them, O lord; pref. <ets>re-</ets> re + <ets>quies</ets> quiet.
See <er>Quiet</er>, <pos>n.</pos>, and cf. <er>Requin</er>.]</ety>
<sn>1.</sn> <fld>(R.C.Ch.)</fld> <def>A mass said or sung for the repose
of a departed soul.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We should profane the service of the dead<br/
To sing a <qex>requiem</qex> and such rest to her<br/
As to peace-parted souls.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Any grand musical composition, performed in honor of
a deceased person.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Rest; quiet; peace.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Else had I an eternal <qex>requiem</qex> kept,<br/
And in the arms of peace forever slept.</q>
<rj><qau>Sandys.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Requietory</ent><br/
<hw>Re*qui"e*to*ry</hw> <pr>(r?-kw?"?-t?-r?)</pr>, <pos>n.</pos>
<ety>[L. <ets>requietorium</ets>, fr. <ets>requiescere</ets>,
<ets>requietum</ets>, to rest. See <er>Re</er>-, and
<er>Quiesce</er>.]</ety> <def>A sepulcher.</def> <mark>[Obs.]</mark>
<rj><au>Weever.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Requin</ent><br/
<hw>Re"quin</hw> <pr>(r?"kw?n)</pr>, <pos>n.</pos> <ety>[F., fr.
<ets>reqiem</ets> a Mass sung for the dead. See <er>Requiem</er>.]</ety>
<fld>(Zool.)</fld> <def>The man-eater, or white shark (<spn>Carcharodon
carcharias</spn>); -- so called on account of its causing
<xex>requiems</xex> to be sung.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Requirable</ent><br/
<hw>Re*quir"a*ble</hw> <pr>(r?-kw?r"?-b'l)</pr>, <pos>a.</pos>
<def>Capable of being required; proper to be required.</def> <rj><au>Sir
M. Hale.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Require</ent><br/
<hw>Re*quire"</hw> <pr>(r?-kw?r")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Required</conjf>
<pr>(-kw?rd")</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Requiring</conjf>.]</vmorph> <ety>[OE. <ets>requeren</ets>,
<ets>requiren</ets>, OF. <ets>requerre</ets>, F. <ets>requ<?/rir</ets>;
L. pref. <ets>re-</ets> re- + <ets>quaerere</ets> to ask; cf. L.
<ets>requirere</ets>. See <er>Query</er>, and cf. <er>Request</er>,
<er>Requisite</er>.]</ety> <sn>1.</sn> <def>To demand; to insist upon
having; to claim as by right and authority; to exact; <as>as, to
<ex>require</ex> the surrender of property</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Shall I say to Caesar<br/
What you <qex>require</qex> of him?</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>By nature did what was by law <qex>required</qex>.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To demand or exact as indispensable; to
need.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Just gave what life <qex>required</qex>, and gave no more.</q>
<rj><qau>Goldsmith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The two last [biographies] <qex>require</qex> to be particularly
noticed.</q> <rj><qau>J. A. Symonds.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To ask as a favor; to request.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I was ashamed to <qex>require</qex> of the king a band of soldiers
and horsemen to help us against the enemy in the way.</q> <rj><qau>Ezra
viii. 22.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To claim; exact; enjoin; prescribe; direct;
order; demand; need.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Requirement</ent><br/
<hw>Re*quire"ment</hw> <pr>(-m<it>e</it>nt)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>The act of requiring; demand; requisition.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is required; an imperative or
authoritative command; an essential condition; something needed or
necessary; a need.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>One of those who believe that they can fill up every
<qex>requirement</qex> contained in the rule of righteousness.</q>
<rj><qau>J. M. Mason.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>God gave her the child, and gave her too an instinctive knowledge
of its nature and <qex>requirements</qex>.</q>
<rj><qau>Hawthorne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Requirer</ent><br/
<hw>Re*quir"er</hw> <pr>(-kw?r"?r)</pr>, <pos>n.</pos> <def>One who
requires.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Requisite</ent><br/
<hw>Req"ui*site</hw> <pr>(r?k"w?-z?t)</pr>, <pos>n.</pos> <def>That
which is required, or is necessary; something indispensable.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>God, on his part, has declared the <qex>requisites</qex> on ours;
what we must do to obtain blessings, is the great business of us all to
know.</q> <rj><qau>Wake.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Requisite</ent><br/
<hw>Req"ui*site</hw>, <pos>a.</pos> <ety>[L. <ets>requisitus</ets>, p.
p. <ets>requirere</ets>; pref. <ets>re-</ets> re- + <ets>quaerere</ets>
to ask. See <er>Require</er>.]</ety> <def>Required by the nature of
things, or by circumstances; so needful that it can not be dispensed
with; necessary; indispensable.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>All truth <qex>requisite</qex> for men to know.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Necessary; needful; indispensable;
essential.</syn><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Req"ui*site*ly</wf>, <pos>adv.</pos> --
<wf>Req"ui*site*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Requisition</ent><br/
<hw>Req`ui*si"tion</hw> <pr>(r?k`w?-z?sh"?n)</pr>,
<pos>n.</pos><ety>[Cf. F. <ets>r<eacute/quisition</ets>, L.
<ets>requisitio</ets> a searching.]</ety> <sn>1.</sn> <def>The act of
requiring, as of right; a demand or application made as by
authority.</def> Specifically: <sd>(a)</sd> <fld>(International
Law)</fld> <def>A formal demand made by one state or government upon
another for the surrender or extradition of a fugitive from
justice.</def> <au>Kent.</au> <sd>(b)</sd> <fld>(Law)</fld> <def>A
notarial demand of a debt.</def> <au>Wharton.</au> <sd>(c)</sd>
<fld>(Mil.)</fld> <def>A demand by the invader upon the people of an
invaded country for supplies, as of provision, forage, transportation,
etc.</def> <au>Farrow.</au> <sd>(d)</sd> <def>A formal application by
one officer to another for things needed in the public service; <as>as,
a <ex>requisition</ex> for clothing, troops, or money</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is required by authority; especially, a
quota of supplies or necessaries.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A written or normal call; an invitation; a summons;
<as>as, a <ex>reqisition</ex> for a public meeting</as>.</def>
<mark>[Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Requisition</ent><br/
<hw>Req`ui*si"tion</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To make a
reqisition on or for; <as>as, to <ex>requisition</ex> a district for
forage; to <ex>requisition</ex> troops</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To present a requisition to; to summon request;
<as>as, to <ex>requisition</ex> a person to be a candidate</as>.</def>
<mark>[Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Requisitionist</ent><br/
<hw>Req`ui*si"tion*ist</hw>, <pos>n.</pos> <def>One who makes or signs a
requisition.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Requisitive</ent><br/
<hw>Re*quis"i*tive</hw> <pr>(r?-kw?z"?-t?v)</pr>, <pos>a.</pos>
<def>Expressing or implying demand.</def> <mark>[R.]</mark>
<rj><au>Harris.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Requisitive</ent><br/
<hw>Re*quis"i*tive</hw>, <pos>n.</pos> <def>One who, or that which,
makes requisition; a requisitionist.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Requisitor</ent><br/
<hw>Re*quis"i*tor</hw> <pr>(-t?r)</pr>, <pos>n.</pos> <def>One who makes
reqisition; esp., one authorized by a requisition to investigate
facts.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Requisitory</ent><br/
<hw>Re*quis"i*to*ry</hw> <pr>(-t?-r?)</pr>, <pos>a.</pos> <def>Sought
for; demanded.</def> <mark>[R.]</mark> <rj><au>Summary on Du Bartas
(1621).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Requitable</ent><br/
<hw>Re*quit"a*ble</hw> <pr>(-kw?t"?-b'l)</pr>, <pos>a.</pos> <def>That
may be requited.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Requital</ent><br/
<hw>Re*quit"al</hw> <pr>(-<it>a</it>l)</pr>, <pos>n.</pos> <ety>[From
<er>Requite</er>.]</ety> <def>The act of requiting; also, that which
requites; return, good or bad, for anything done; in a good sense,
compensation; recompense; <as>as, the <ex>requital</ex> of
services</as>; in a bad sense, retaliation, or punishment; <as>as, the
<ex>requital</ex> of evil deeds</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>No merit their aversion can remove,<br/
Nor ill <qex>requital</qex> can efface their love.</q>
<rj><qau>Waller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1224 --></p>

<p><syn><b>Syn.</b> -- Compensation; recompense; remuneration; reward;
satisfaction; payment; retribution; retaliation; reprisal;
punishment.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Requite</ent><br/
<hw>Re"quite"</hw> <pr>(r?-kw?t")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Requited</conjf>; <pos>p. pr. &
vb. n.</pos> <conjf>Requiting</conjf>.]</vmorph> <ety>[Pref.
<ets>re-</ets> + <ets>quit</ets>.]</ety> <def>To repay; in a good sense,
to recompense; to return (an equivalent) in good; to reward; in a bad
sense, to retaliate; to return (evil) for evil; to punish.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He can <qex>requite</qex> thee; for he knows the charma<br/
That call fame on such gentle acts as these.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou hast seen it; for thou beholdest mischief and spite, to
<qex>requite</qex> it with thy hand.</q> <rj><qau>Ps. x.
14.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To repay; reward; pay; compensate; remunerate;
satisfy; recompense; punish; revenge.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Requitement</ent><br/
<hw>Re*quite"ment</hw> <pr>(-m<it>e</it>nt)</pr>, <pos>n.</pos>
<def>Requital</def> <mark>[Obs.]</mark> <rj><au>E. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Requiter</ent><br/
<hw>Re*quit"er</hw> <pr>(-kw?t"?r)</pr>, <pos>n.</pos> <def>One who
requites.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rerebrace</ent><br/
<hw>Rere"brace`</hw> <pr>(r?r"br?s")</pr>, <pos>n.</pos> <ety>[F.
<ets>arri<?/re-bras</ets>.]</ety> <fld>(Anc. Armor)</fld> <def>Armor for
the upper part of the arm.</def> <rj><au>Fairholt.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reredemain</ent><br/
<hw>Rere`de*main"</hw> <pr>(-d?-m?n")</pr>, <pos>n.</pos> <ety>[F.
<ets>arri<?/re</ets> back + <ets>de</ets> of + <ets>main</ets>
hand.]</ety> <def>A backward stroke.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reredos</ent><br/
<hw>Rere"dos</hw> <pr>(r?r"d?s)</pr>, <pos>n.</pos> <ety>[From
<ets>rear</ets> + F. <ets>dos</ets> back, L. <ets>dorsum</ets>. Cf.
<er>Dorsal</er>.]</ety> <fld>(Arch.)</fld> <sd>(a)</sd> <def>A screen or
partition wall behind an altar.</def> <sd>(b)</sd> <def>The back of a
fireplace.</def> <sd>(c)</sd> <def>The open hearth, upon which fires
were lighted, immediately under the louver, in the center of ancient
halls.</def> <altsp>[Also spelt <asp>reredosse</asp>.]</altsp>
<rj><au>Fairholt.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rerefief</ent><br/
<hw>Rere"fief`</hw> <pr>(r?r"f?f`)</pr>, <pos>n.</pos> <ety>[F.
<ets>arri<egrave/re-fief</ets>. See <er>Rear</er> hinder, and
<er>Fief</er>.]</ety> <fld>(Scots Law)</fld> <def>A fief held of a
superior feudatory; a fief held by an under tenant.</def>
<rj><au>Blackstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rereign</ent><br/
<hw>Re*reign"</hw> <pr>(r?-r?n")</pr>, <pos>v. i.</pos> <def>To reign
again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Re-reiterate</ent><br/
<hw>Re`-re*it"er*ate</hw> <pr>(r?`r?-?t"?r-?t)</pr>, <pos>v. t.</pos>
<def>To reiterate many times.</def> <mark>[R.]</mark> <ldquo/My
<xex>re-reiterated</xex> wish.<rdquo/ <rj><au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reremouse</ent><br/
<hw>Rere"mouse`</hw> <pr>(r?r"mous`)</pr>, <pos>n.</pos>
<fld>(Zool.)</fld> <def>A rearmouse.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Re-resolve</ent><br/
<hw>Re`-re*solve"</hw> <pr>(r?`r?-z?lv")</pr>, <pos>v. t. & i.</pos>
<def>To resolve again.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Resolves, and <qex>re-resolves</qex>, then dies the same.</q>
<rj><qau>Young.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rereward</ent><br/
<hw>Rere"ward`</hw> <pr>(r?r"w?rd`)</pr>, <pos>n.</pos> <ety>[See
<er>Rearward</er>.]</ety> <def>The rear guard of an army.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>reread</ent><br/
<ent>re-read</ent><br/
<mhw><hw>reread</hw>, <hw>re-read</hw></mhw> <pos>v. t.</pos> <def>To
rad again; <as>as, He re-read her letters to him</as>.</def><br/
<syn><b>Syn. --</b> read anew, read-again.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>rerun</ent><br/
<ent>re-run</ent><br/
<mhw><hw>re*run"</hw>, <hw>re-run"</hw></mhw>
<pr>(r<emac/*r<ucr/n")</pr>, <pos>v. t.</pos> <sn>1.</sn> <def>To
broadcast again, as of a film; <as>as, they <ex>reran</ex> the episode
for the tenth time</as>.</def><br/
<syn><b>Syn. --</b> rebroadcast.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>To perform again, as an experiment; <as>as, they
reran the test to confirm the surprising result</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>rerun</ent><br/
<ent>re-run</ent><br/
<mhw><hw>re"run</hw>, <hw>re"-run</hw></mhw> <pr>(r<emac/"r<ucr/n)</pr>,
<pos>n.</pos> <def>A repeated broadcast, such as of a film or episode of
a television series; <as>as, the seventh <ex>rerun</ex> had a
surprisingly large audience</as>.</def><br/
<syn><b>Syn. --</b> rebroadcast.</syn><br/
[<source>PJC</source>]</p>

<p><ent>Res</ent><br/
\'d8<hw>Res</hw> <pr>(r?z)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Res</plw>.</plu> <ety>[L.]</ety> <def>A thing; the particular
thing; a matter; a point.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs>\'d8<col><b>Res gestae</b></col> <ety>[L., things done]</ety>
<fld>(Law)</fld>, <cd>the facts which form the environment of a
litigated issue.</cd> <au>Wharton.</au> -- \'d8<col><b>Res
judicata</b></col> <mark>[L.]</mark> <fld>(Law)</fld>, <cd>a thing
adjudicated; a matter no longer open to controversy.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resail</ent><br/
<hw>Re*sail"</hw> <pr>(r?-s?l")</pr>, <pos>v. t. & i.</pos> <def>To sail
again; also, to sail back, as to a former port.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resale</ent><br/
<hw>Re*sale"</hw> <pr>(r?-s?l" <or/ r?"s?l)</pr>, <pos>n.</pos> <def>A
sale at second hand, or at retail; also, a second sale.</def>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resalgar</ent><br/
<hw>Re*sal"gar</hw> <pr>(r?-s?l"g?r)</pr>, <pos>n.</pos>
<def>Realgar.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resalute</ent><br/
<hw>Re`sa*lute"</hw> <pr>(r?`s?-l?t")</pr>, <pos>v. t.</pos> <def>To
salute again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resaw</ent><br/
<hw>Re*saw"</hw> <pr>(r<?/-s<?/")</pr>, <pos>v. t.</pos> <def>To saw
again; specifically, to saw a balk, or a timber, which has already been
squared, into dimension lumber, as joists, boards, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rescat</ent><br/
<hw>Res"cat</hw> <pr>(r?s"k?t)</pr>, <pos>v. t.</pos> <ety>[Sp.
<ets>rescattar</ets>.]</ety> <def>To ransom; to release; to
rescue.</def> <mark>[Obs.]</mark> <rj><au>Howell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rescat</ent><br/
<hw>Res"cat</hw>, <pos>n.</pos> <ety>[Sp. <ets>rescate</ets>.]</ety>
<def>Ransom; release.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rescind</ent><br/
<hw>Re*scind"</hw> <pr>(r?-s?nd")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Rescinded</conjf>; <pos>p. pr. &
vb. n.</pos> <conjf>Rescinding</conjf>.]</vmorph> <ety>[L.
<ets>rescindere</ets>, <ets>rescissum</ets>; pref <ets>re-</ets> re- +
<ets>scindere</ets> to cut, split: cf. F. <ets>rescinder</ets>. See
<er>Shism</er>.]</ety> <sn>1.</sn> <def>To cut off; to abrogate; to
annul.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The blessed Jesus . . . did sacramentally <qex>rescind</qex> the
impure relics of Adam and the contraction of evil customs.</q>
<rj><qau>Jer. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Specifically, to vacate or make void, as an act, by
the enacting authority or by superior authority; to repeal; <as>as, to
<ex>rescind</ex> a law, a resolution, or a vote; to <ex>rescind</ex> a
decree or a judgment.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To revoke; repeal; abrogate; annul; recall;
reverse; vacate; void.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rescindable</ent><br/
<hw>Re*scind"a*ble</hw> <pr>(-?-b'l)</pr>, <pos>a.</pos> <def>Capable of
being rescinded.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rescindment</ent><br/
<hw>Re*scind"ment</hw> <pr>(-m<it>e</it>nt)</pr>, <pos>n.</pos> <def>The
act of rescinding; rescission.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rescission</ent><br/
<hw>Re*scis"sion</hw> <pr>(r?-s?zh"?n)</pr>, <pos>n.</pos> <ety>[L.
<ets>rescissio</ets>: cf. F. <ets>rescission</ets>. See
<er>Rescind</er>.]</ety> <def>The act of rescinding, abrogating,
annulling, or vacating; <as>as, the <ex>rescission</ex> of a law,
decree, or judgment</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rescissory</ent><br/
<hw>Re*scis"so*ry</hw> <pr>(r?-s?z"?-r? <or/ r?-s?s"-)</pr>,
<pos>a.</pos> <ety>[L. <ets>rescissorius</ets>: cf. F.
<ets>rescisoire</ets>.]</ety> <def>Tending to rescind;
rescinding.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To pass a general act <qex>rescissory</qex> (as it was called),
annulling all the Parliaments that had been held since the year
1633.</q> <rj><qau>Bp. Burnet.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rescous</ent><br/
<hw>Res"cous</hw> <pr>(r?s"k?s)</pr>, <pos>n.</pos> <ety>[OE., fr. OF.
<ets>rescousse</ets>, fr. <ets>rescourre</ets>, p. p.
<ets>rescous</ets>, to rescue. See <er>Rescue</er>.]</ety> <sn>1.</sn>
<def>Rescue; deliverance.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>See <er>Rescue</er>, 2.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rescowe</ent><br/
<hw>Res"cowe</hw> <pr>(r?s"kou)</pr>, <pos>v. t.</pos> <def>To
rescue.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rescribe</ent><br/
<hw>Re*scribe"</hw> <pr>(r?-skr?b")</pr>, <pos>v. t.</pos> <ety>[L.
<ets>rescribere</ets>; pref. <ets>re-</ets> re- + <ets>scribere</ets> to
write. See <er>Scribe</er>.]</ety> <sn>1.</sn> <def>To write back; to
write in reply.</def> <rj><au>Ayliffe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To write over again.</def>
<rj><au>Howell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rescript</ent><br/
<hw>Re"script</hw> <pr>(r?"skr?pt)</pr>, <pos>n.</pos> <ety>[L.
<ets>rescriptum</ets>: cf. F. <ets>rescrit</ets>, formerly also spelt
<ets>rescript</ets>. See <er>Rescribe</er>,<pos>v. t.</pos>]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <fld>(Rom.Antiq.)</fld> <def>The answer of an emperor
when formallyconsulted by particular persons on some difficult question;
hence, an edict or decree.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In their <qex>rescripts</qex> and other ordinances, the Roman
emperors spoke in the plural number.</q> <rj><qau>Hare.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(R.C.Ch.)</fld> <def>The official written answer of
the pope upon a question of canon law, or morals.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A counterpart.</def> <rj><au>Bouvier.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rescription</ent><br/
<hw>Re*scrip"tion</hw> <pr>(r?-skr?p"sh?n)</pr>, <pos>n.</pos> <ety>[L.
<ets>rescriptio</ets>: cf. F. <ets>rescription</ets>. See
<er>Rescribe</er>.]</ety> <def>A writing back; the answering of a
letter.</def> <rj><au>Loveday.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rescriptive</ent><br/
<hw>Re*scrip"tive</hw> <pr>(-t?v)</pr>, <pos>a.</pos> <def>Pertaining
to, or answering the purpose of, a rescript; hence, deciding; settling;
determining.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rescriptively</ent><br/
<hw>Re*scrip"tive*ly</hw>, <pos>adv.</pos> <def>By rescript.</def>
<rj><au>Burke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rescuable</ent><br/
<hw>Res"cu*a*ble</hw> <pr>(r?s"k?-?-b'l)</pr>, <pos>a.</pos> <def>That
may be rescued.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rescue</ent><br/
<hw>Res"cue</hw> <pr>(r<ecr/s"k<usl/)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Rescued</conjf>
<pr>(-k?d)</pr>;<pos>p. pr. & vb. n.</pos>
<conjf>Rescuing</conjf>.]</vmorph> <ety>[OE. <ets>rescopuen</ets>, OF.
<ets>rescourre</ets>, <ets>rescurre</ets>, <ets>rescorre</ets>; L. pref.
<ets>re-</ets> re- + <ets>excutere</ets> to shake or drive out;
<ets>ex</ets> out + <ets>quatere</ets> to shake. See <er>Qtash</er> to
crush, <er>Rercussion</er>.]</ety> <def>To free or deliver from any
confinement, violence, danger, or evil; to liberate from actual
restraint; to remove or withdraw from a state of exposure to evil;
<as>as, to <ex>rescue</ex> a prisoner from the enemy; to <ex>rescue</ex>
seamen from destruction.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Had I been seized by a hungry lion,<br/
I would have been a breakfast to the best,<br/
Rather than have false Proteus <qex>rescue</qex> me.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To retake; recapture; free; deliver; liberate;
release; save.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rescue</ent><br/
<hw>Res"cue</hw> <pr>(r<ecr/s"k<usl/)</pr>, <pos>n.</pos> <ety>[From
<er>Rescue</er>, <pos>v.</pos>; cf. <er>Rescous</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>The act of rescuing; deliverance from restraint,
violence, or danger; liberation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Spur to the <qex>rescue</qex> of the noble Talbot.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <sd>(a)</sd> <def>The forcible retaking,
or taking away, against law, of things lawfully distrained.</def>
<sd>(b)</sd> <def>The forcible liberation of a person from an arrest or
imprisonment.</def> <sd>(c)</sd> <def>The retaking by a party captured
of a prize made by the enemy.</def> <rj><au>Bouvier.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>rescue</qex> of a prisoner from the court is punished
with perpetual imprisonment and forfeiture of goods.</q>
<rj><qau>Blackstone.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Rescue grass</b></col>. <ety>[Etymol. uncertain.]</ety>
<fld>(Bot.)</fld> <cd>A tall grass (<spn>Ceratochloa unioloides</spn>)
somewhat resembling chess, cultivated for hay and forage in the Southern
States.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rescueless</ent><br/
<hw>Res"cue*less</hw>, <pos>a.</pos> <def>Without rescue or
release.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rescuer</ent><br/
<hw>Res"cu*er</hw> <pr>(-k?-?r)</pr>, <pos>n.</pos> <def>One who
rescues.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rescussee</ent><br/
<hw>Res`cus*see"</hw> <pr>(r?s`k?s-s?")</pr>, <pos>n.</pos> <fld>(O.Eng.
Law)</fld> <def>The party in whose favor a rescue is made.</def>
<rj><au>Crabb.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rescussor</ent><br/
<hw>Res*cus"sor</hw> <pr>(r?s-k?s"s?r)</pr>, <pos>n.</pos>
<ety>[LL.]</ety> <fld>(O.Eng.Law)</fld> <def>One who makes an unlawful
rescue; a rescuer.</def> <rj><au>Burril.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rese</ent><br/
<hw>Rese</hw> <pr>(r<emac/z)</pr>, <pos>v. i.</pos> <def>To shake; to
quake; to tremble.</def> <mark>[Obs.]</mark> <ldquo/It made all the
gates for to <xex>rese</xex>.<rdquo/ <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Re-search</ent><br/
<hw>Re-search"</hw> <pr>(r?-s?rch")</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>re-</ets> + <ets>search</ets>.]</ety> <def>To search again; to
examine anew.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Research</ent><br/
<hw>Re*search"</hw> <pr>(r?-s?rch")</pr>, <pos>n.</pos> <ety>[Pref.
<ets>re-</ets> + <ets>search</ets>: cf OF. <ets>recerche</ets>, F.
<ets>recherche</ets>.]</ety> <sn>1.</sn> <def>Diligent inquiry or
examination in seeking facts or principles; laborious or continued
search after truth; <as>as, <ex>researches</ex> of human wisdom; to
<ex>research</ex> a topic in the library; medical
<ex>research</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The dearest interests of parties have frequently been staked on
the results of the <qex>researches</qex> of antiquaries.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Systematic observation of phenomena for the purpose
of learning new facts or testing the application of theories to known
facts; -- also called <stype>scientific research</stype>. This is the
<ex>research</ex> part of the phrase <ldquo/research and
development<rdquo/ (R&D).</def> <note>The distinctive characteristic of
scientific research is the maintenance of records and careful control or
observation of conditions under which the phenomena are studied so that
others will be able to reproduce the observations. When the person
conducting the research varies the conditions beforehand in order to
test directly the effects of changing conditions on the results of the
observation, such investigation is called <stype><col><b>experimental
research</b></col></stype> or
<stype><col><b>experimentation</b></col></stype> or
<stype><col><b>experimental science</b></col></stype>; it is often
conducted in a laboratory. If the investigation is conducted with a view
to obtaining information directly useful in producing objects with
commercial or practical utility, the research is called
<stype><col><b>applied research</b></col></stype>. Investigation
conducted for the primary purpose of discovering new facts about natural
phenomena, or to elaborate or test theories about natural phenomena, is
called <stype><col><b>basic research</b></col></stype> or
<stype><col><b>fundamental research</b></col></stype>. Research in
fields such as astronomy, in which the phenomena to be observed cannot
be controlled by the experimenter, is called
<stype><col><b>observational research</b></col></stype>.
<stype><col><b>Epidemiological research</b></col></stype> is a type of
observational research in which the researcher applies statistical
methods to analyse patterns of occurrence of disease and its association
with other phenomena within a population, with a view to understanding
the origins or mode of transmission of the disease.</note><br/
[<source>PJC</source>]</p>

<p><syn><b>Syn.</b> -- Investigation; examination; inquiry;
scrutiny.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>research</ent><br/
<hw>re*search"</hw>, <pos>v. t.</pos> <ety>[Pref. <ets>re-</ets> +
<ets>search</ets>: cf. OF. <ets>recerchier</ets>, F.
<ets>rechercher</ets>.]</ety> <def>To search or examine with continued
care; to seek diligently.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Researcher</ent><br/
<hw>Re*search"er</hw> <pr>(-<etil/r)</pr>, <pos>n.</pos> <def>One who
conducts research. In the field of scientific research, also called an
<altname>investigator</altname> or
<altname>scientist</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Researchful</ent><br/
<hw>Re*search"ful</hw> <pr>(-f?l)</pr>, <pos>a.</pos> <def>Making
researches; inquisitive.</def> <mark>[R.]</mark>
<rj><au>Coleridge.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reseat</ent><br/
<hw>Re*seat"</hw> <pr>(r?-s?t")</pr>, <pos>v. t.</pos> <sn>1.</sn>
<def>To seat or set again, as on a chair, throne, etc.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To put a new seat, or new seats, in; <as>as, to
<ex>reseat</ex> a theater; to <ex>reseat</ex> a chair or
trousers.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reseau</ent><br/
\'d8<hw>R<eacute/`seau"</hw> <pr>(r<amac/`z<omac/")</pr>, <pos>n.</pos>
<ety>[F.]</ety> <def>A network;</def> <specif>specif.</specif>:
<sd>(a)</sd> <fld>(Astron.)</fld> <def>A system of lines forming small
squares of standard size, which is photographed, by a separate exposure,
on the same plate with star images to facilitate measurements, detect
changes of the film, etc.</def> <sd>(b)</sd> <def>In lace, a ground or
foundation of regular meshes, like network.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Resect</ent><br/
<hw>Re*sect"</hw> <pr>(r?-s?kt")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Resected</conjf>;<pos>p. pr. &
vb. n.</pos> <conjf>Resecting</conjf>.]</vmorph> <ety>[L.
<ets>resectus</ets>, p. p. of <ets>resecare</ets> to cut off; pref.
<ets>re-</ets> re- + <ets>secare</ets> to cut.]</ety> <def>To cut or
pare off; to remove by cutting.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resection</ent><br/
<hw>Re*sec"tion</hw> <pr>(r?-s?k"sh?n)</pr>, <pos>n.</pos> <ety>[L.
<ets>resectio</ets>: cf. F. <ets>r<eacute/section</ets>.]</ety>
<sn>1.</sn> <def>The act of cutting or paring off.</def>
<rj><au>Cotgrave.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Surg.)</fld> <def>The removal of the articular
extremity of a bone, or of the ends of the bones in a false
articulation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reseda</ent><br/
<hw>Re*se"da</hw> <pr>(r?-s?"d?)</pr>, <pos>n.</pos> <ety>[L. , a kind
of plant.]</ety> <sn>1.</sn> <fld>(Bot.)</fld> <def>A genus of plants,
the type of which is mignonette.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A grayish green color, like that of the flowers of
mignonette.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reseek</ent><br/
<hw>Re*seek"</hw> <pr>(r?-s?k")</pr>, <pos>v. t.</pos> <def>To seek
again.</def> <rj><au>J. Barlow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reseize</ent><br/
<hw>Re*seize"</hw> <pr>(r?-s?z")</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>re-</ets> + <ets>seize</ets>: cf. F. <ets>ressaisir</ets>.]</ety>
<sn>1.</sn> <def>To seize again, or a second time.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To put in possession again; to reinstate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And then therein [in his kingdom] <qex>reseized</qex> was
again.</q> <rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Law)</fld> <def>To take possession of, as lands and
tenements which have been disseized.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The sheriff is commanded to <qex>reseize</qex> the land and all
the chattels thereon, and keep the same in his custody till the arrival
of the justices of assize.</q> <rj><qau>Blackstone.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reseizer</ent><br/
<hw>Re*seiz"er</hw> <pr>(-s?z"?r)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>One who seizes again.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Eng. Law)</fld> <def>The taking of lands into the
hands of the king where a general livery, or <xex>oustre le main</xex>,
was formerly mis-sued, contrary to the form and order of law.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reseizure</ent><br/
<hw>Re*sei"zure</hw> <pr>(r<?/-s<?/"zh<?/r; 135)</pr>, <pos>n.</pos>
<def>A second seizure; the act of seizing again.</def>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resell</ent><br/
<hw>Re*sell"</hw> <pr>(r?-s?l")</pr>, <pos>v. t.</pos> <def>To sell
again; to sell what has been bought or sold; to retail.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resemblable</ent><br/
<hw>Re*sem"bla*ble</hw> <pr>(r?-z?m"bl?-b'l)</pr>, <pos>a.</pos>
<ety>[See <er>Resemble</er>.]</ety> <def>Admitting of being compared;
like.</def> <mark>[Obs.]</mark> <rj><au>Gower.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resemblance</ent><br/
<hw>Re*sem"blance</hw> <pr>(-bl<it>a</it>ns)</pr>, <pos>n.</pos>
<ety>[Cf. F. <ets>ressemblance</ets>. See <er>Resemble</er>.]</ety>
<sn>1.</sn> <def>The quality or state of resembling; likeness;
similitude; similarity.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>One main end of poetry and painting is to please; they bear a
great <qex>resemblance</qex> to each other.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which resembles, or is similar; a
representation; a likeness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>These sensible things, which religion hath allowed, are
<qex>resemblances</qex> formed according to things spiritual.</q>
<rj><qau>Hooker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A comparison; a simile.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Probability; verisimilitude.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Likeness; similarity; similitude; semblance;
representation; image.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resemblant</ent><br/
<hw>Re*sem"blant</hw> <pr>(-bl<it>a</it>nt)</pr>, <pos>a.</pos>
<ety>[F., a . and p. pr. fr. <ets>ressembler</ets> to resemble. See
<er>Resemble</er>.]</ety> <def>Having or exhibiting resemblance;
resembling.</def> <mark>[R.]</mark> <rj><au>Gower.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resemble</ent><br/
<hw>Re*sem"ble</hw> <pr>(r?-z?m"b'l)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Resembled</conjf>
<pr>(-b'ld)</pr>; <pos>p. pr. & vb. n.</pos> <conjf>Resembling</conjf>
<pr>(-bl?ng)</pr>.]</vmorph> <ety>[F. <ets>ressembler</ets>; pref.
<ets>re-</ets> re- + <ets>sembler</ets> to seem, resemble, fr. L.
<ets>similare</ets>, <ets>simulare</ets>, to imitate, fr.
<ets>similis</ets> like, similar. See <er>Similar</er>.]</ety>
<sn>1.</sn> <def>To be like or similar to; to bear the similitude of,
either in appearance or qualities; <as>as, these brothers
<ex>resemble</ex> each other</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We will <qex>resemble</qex> you in that.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To liken; to compare; to represent as like.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The other . . . <br/
He did <qex>resemble</qex> to his lady bright.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To counterfeit; to imitate.</def>
<mark>[Obs.]</mark> <ldquo/They can so well <xex>resemble</xex> man's
speech.<rdquo/ <rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To cause to imitate or be like.</def>
<mark>[R.]</mark> <rj><au>H. Bushnell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resembler</ent><br/
<hw>Re*sem"bler</hw> <pr>(r?-z?m"bl?r)</pr>, <pos>n.</pos> <def>One who
resembles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resemblingly</ent><br/
<hw>Re*sem"bling*ly</hw> <pr>(-bl?ng-l?)</pr>, <pos>adv.</pos> <def>So
as to resemble; with resemblance or likeness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reseminate</ent><br/
<hw>Re*sem"i*nate</hw> <pr>(-s?m"?-n?t)</pr>, <pos>v. t.</pos> <ety>[L.
pref. <ets>re-</ets> again + <ets>seminatus</ets>, p. p. of
<ets>seminare</ets> to sow.]</ety> <def>To produce again by means of
seed.</def> <mark>[Obs.]</mark> <rj><au>Sir. T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resend</ent><br/
<hw>Re*send"</hw> <pr>(r?-s?nd")</pr>, <pos>v. t.</pos> <sn>1.</sn>
<def>To send again; <as>as, to <ex>resend</ex> a message</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To send back; <as>as, to <ex>resend</ex> a
gift</as>.</def> <mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Telegraphy)</fld> <def>To send on from an
intermediate station by means of a repeater.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resent</ent><br/
<hw>Re*sent"</hw> <pr>(r?-z?nt")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Resented</conjf>; <pos>p. pr. &
vb. n.</pos> <conjf>Resenting</conjf>.]</vmorph> <ety>[F.
<ets>ressentir</ets>; L. pref. <ets>re-</ets> re- + <ets>sentire</ets>
to feel. See <er>Sense</er>.]</ety> <sn>1.</sn> <def>To be sensible of;
to feel</def>; as: <sd>(a)</sd> <def>In a good sense, to take well; to
receive with satisfaction.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Which makes the tragical ends of noble persons more favorably
<qex>resented</qex> by compassionate readers.</q> <rj><qau>Sir T.
Browne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(b)</sd> <def>In a bad sense, to take ill; to consider as an
injury or affront; to be indignant at.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To express or exhibit displeasure or indignation at,
as by words or acts.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The good prince King James . . . bore dishonorably what he might
have <qex>resented</qex> safely.</q>
<rj><qau>Bolingbroke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To recognize; to perceive, especially as if by
smelling; -- associated in meaning with <xex>sent</xex>, the older
spelling of <xex>scent</xex> to smell. See <er>Resent</er>, <pos>v.
i.</pos></def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>This bird of prey <qex>resented</qex> a worse than earthly savor
in the soul of Saul.</q> <rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Our King Henry the Seventh quickly <qex>resented</qex> his
drift.</q> <rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resent</ent><br/
<hw>Re*sent"</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To feel
resentment.</def> <rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To give forth an odor; to smell; to savor.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The judicious prelate will prefer a drop of the sincere milk of
the word before vessels full of traditionary pottage
<qex>resenting</qex> of the wild gourd of human invention.</q>
<rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resenter</ent><br/
<hw>Re*sent"er</hw> <pr>(-?r)</pr>, <pos>n.</pos> <def>One who
resents.</def> <rj><au>Sir H. Wotton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resentful</ent><br/
<hw>Re*sent"ful</hw> <pr>(-f?l)</pr>, <pos>a.</pos> <def>Inclined to
resent; easily provoked to anger; irritable.</def> --
<wordforms><wf>Re*sent"ful*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resentiment</ent><br/
<hw>Re*sent"i*ment</hw> <pr>(-?-m<it>e</it>nt)</pr>, <pos>n.</pos>
<def>Resentment.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resentingly</ent><br/
<hw>Re*sent"ing*ly</hw>, <pos>adv.</pos> <sn>1.</sn> <def>With deep
sense or strong perception.</def> <mark>[Obs.]</mark> <rj><au>Dr. H.
More.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>With a sense of wrong or affront; with
resentment.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resentive</ent><br/
<hw>Re*sent"ive</hw> <pr>(-?v)</pr>, <pos>a.</pos> <def>Resentful.</def>
<mark>[R.]</mark> <rj><au>Thomson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resentment</ent><br/
<hw>Re*sent"ment</hw> <pr>(-m<it>e</it>nt)</pr>, <pos>n.</pos> <ety>[F.
<ets>ressentiment</ets>.]</ety> <sn>1.</sn> <def>The act of
resenting.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The state of holding something in the mind as a
subject of contemplation, or of being inclined to reflect upon
something; a state of consciousness; conviction; feeling;
impression.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He retains vivid <qex>resentments</qex> of the more solid
morality.</q> <rj><qau>Dr. H. More.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>It is a greater wonder that so many of them die, with so little
<qex>resentment</qex> of their danger.</q> <rj><qau>Jer.
Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>In a good sense, satisfaction; gratitude.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The Council taking notice of the many good services performed by
Mr. John Milton, . . . have thought fit to declare their
<qex>resentment</qex> and good acceptance of the same.</q> <rj><qau>The
Council Book (1651).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>In a bad sense, strong displeasure; anger; hostility
provoked by a wrong or injury experienced.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Resentment</qex> . . . is a deep, reflective displeasure
against the conduct of the offender.</q> <rj><qau>Cogan.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Anger; irritation; vexation; displeasure; grudge;
indignation; choler; gall; ire; wrath; rage; fury.</syn> <usage> --
<er>Resentment</er>, <er>Anger</er>. <xex>Anger</xex> is the broader
term, denoting a keen sense of disapprobation (usually with a desire to
punish) for whatever we feel to be wrong, whether directed toward
ourselves or others. <xex>Resentment</xex> is anger exicted by a sense
of personal injury. It is, etymologically, that reaction of the mind
which we instinctively feel when we think ourselves wronged. Pride and
selfishness are apt to aggravate this feeling until it changes into a
criminal animosity; and this is now the more common signification of the
term. Being founded in a sense of injury, this feeling is hard to be
removed; and hence the expressions <xex>bitter</xex> or <xex>implacable
resentment</xex>. See <er>Anger</er>.</usage><br/
[<source>1913 Webster</source>]</p>

<p><q>Anger is like<br/
A full-hot horse, who being allowed his way,<br/
Self-mettle tires him.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Can heavently minds such high <qex>resentment</qex> show,<br/
Or exercise their spite in human woe?</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reserate</ent><br/
<hw>Res"er*ate</hw> <pr>(r?s"?r-?t)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>reseratus</ets>, p. p. of <ets>reserare</ets> to unlock.]</ety>
<def>To unlock; to open.</def> <mark>[Obs.]</mark>
<rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reservance</ent><br/
<hw>Re*serv"ance</hw> <pr>(r?-z?rv"<it>a</it>ns)</pr>, <pos>n.</pos>
<def>Reservation.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reservation</ent><br/
<hw>Res`er*va"tion</hw> <pr>(r?z`?r-v?"sh?n)</pr>, <pos>n.</pos>
<ety>[Cf. F. <ets>r<eacute/servation</ets>, LL. <ets>reservatio</ets>.
See <er>Reserve</er>.]</ety> <sn>1.</sn> <def>The act of reserving, or
keeping back; concealment, or withholding from disclosure;
reserve.</def> <rj><au>A. Smith.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>With <qex>reservation</qex> of an hundred knights.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Make some <qex>reservation</qex> of your wrongs.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Something withheld, either not expressed or
disclosed, or not given up or brought forward.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A tract of the public land reserved for some special
use, as for schools, for the use of Indians, etc.</def>
<mark>[U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The state of being reserved, or kept in store.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Law)</fld> <sd>(a)</sd> <def>A clause in an
instrument by which some new thing is reserved out of the thing granted,
and not <xex>in esse</xex> before.</def> <sd>(b)</sd> <def>A
proviso.</def> <rj><au>Kent.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ This term is often used in the same sense with
<xex>exception</xex>, the technical distinction being
disregarded.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Eccl.)</fld> <sd>(a)</sd> <def>The portion of the
sacramental elements reserved for purposes of devotion and for the
communion of the absent and sick.</def> <sd>(b)</sd> <def>A term of
canon law, which signifies that the pope reserves to himself appointment
to certain benefices.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>an agreement to have some space, service or other
acommodation, as at a hotel, a restaurant, or on a public transport
system, held for one's future use; also, the record or receipt for such
an agreement, or the contractual obligation to retain that
accommodation; <as>as, a hotel <ex>reservation</ex>; a
<ex>reservation</ex> on a flight to Dallas; to book a
<ex>reservation</ex> at the Ritz</as>.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Mental reservation</b></col>, <cd>the withholding, or
failing to disclose, something that affects a statement, promise, etc.,
and which, if disclosed, would materially change its
import.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1225 --></p>

<p><ent>Reservative</ent><br/
<hw>Re*serv"a*tive</hw> <pr>(r?-z?rv"?-t?v)</pr>, <pos>a.</pos>
<def>Tending to reserve or keep; keeping; reserving.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reservatory</ent><br/
<hw>Re*serv"a*to*ry</hw> <pr>(-t?-r?)</pr>, <pos>n.</pos> <ety>[LL.
<ets>reservatorium</ets>,fr. L. <ets>resservare</ets>. See
<er>Reserve</er>, <pos>v. t.</pos>, and cf. <er>Reservior</er>.]</ety>
<def>A place in which things are reserved or kept.</def>
<rj><au>Woodward.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reserve</ent><br/
<hw>Re*serve"</hw> <pr>(r?-z?rv")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Reserved</conjf>.
(z<?/rvd");<pos>p. pr. & vb. n.</pos>
<conjf>Reserving</conjf>.]</vmorph> <ety>[F. <ets>r<eacute/server</ets>,
L. <ets>reservare</ets>, <ets>reservatum</ets>; pref. <ets>re-</ets> re-
+ <ets>servare</ets> to keep. See <er>Serve</er>.]</ety> <sn>1.</sn>
<def>To keep back; to retain; not to deliver, make over, or
disclose.</def> <ldquo/I have <xex>reserved</xex> to myself
nothing.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence, to keep in store for future or special use;
to withhold from present use for another purpose or time; to keep; to
retain; to make a reservation{7}.</def> <rj><au>Gen. xxvii.
35.</au></rj> <note>In cases where one person or party makes a request
to an agent that some accommodation (such as a hotel room or place at a
restaurant) be kept (<ex>reserved</ex>) for their use at a particular
time, the word <ex>reserve</ex> applies both to the action of the person
making the request, and to the action of the agent who takes the
approproriate action (such as a notation in a book of reservations) to
be certain that the accommodation is available at that time.</note><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><q>Hast thou seen the treasures of the hail, which I have
<qex>reserved</qex> against the time of trouble?</q> <rj><qau>Job
xxxviii. 22,23.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Reserve</qex> your kind looks and language for private
hours.</q> <rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To make an exception of; to except.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reserve</ent><br/
<hw>Re*serve"</hw>, <pos>n.</pos> <ety>[F.
<ets>r<eacute/serve</ets>.]</ety> <sn>1.</sn> <def>The act of reserving,
or keeping back; reservation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>However any one may concur in the general scheme, it is still with
certain <qex>reserves</qex> and deviations.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is reserved, or kept back, as for future
use.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The virgins, besides the oil in their lamps, carried likewise a
<qex>reserve</qex> in some other vessel for a continual supply.</q>
<rj><qau>Tillotson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which is excepted; exception.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Each has some darling lust, which pleads for a
<qex>reserve</qex>.</q> <rj><qau>Rogers.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Restraint of freedom in words or actions;
backwardness; caution in personal behavior.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>My soul, surprised, and from her sex disjoined,<br/
Left all <qex>reserve</qex>, and all the sex, behind.</q>
<rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The clergyman's shy and sensitive <qex>reserve</qex> had balked
this scheme.</q> <rj><qau>Hawthorne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A tract of land reserved, or set apart, for a
particular purpose; <as>as, the Connecticut <ex>Reserve</ex> in Ohio,
originally set apart for the school fund of Connecticut; the Clergy
<ex>Reserves</ex> in Canada, for the support of the
clergy.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Mil.)</fld> <sd>(a)</sd> <def>A body of troops in
the rear of an army drawn up for battle, reserved to support the other
lines as occasion may require; a force or body of troops kept for an
exigency.</def> <sd>(b)</sd> <def>troops trained but released from
active service, retained as a formal part of the military force, and
liable to be recalled to active service in cases of national need (see
<er>Army organization</er>, above).</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>7.</sn> <fld>(Banking)</fld> <def>Funds kept on hand to meet
liabilities.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <fld>(Finance)</fld> <sd>(a)</sd> <def>That part of the
assets of a bank or other financial institution specially kept in cash
in a more or less liquid form as a reasonable provision for meeting all
demands which may be made upon it;</def> <specif>specif.</specif>:
<sd>(b)</sd> <fld>(Banking)</fld> <def>Usually, the uninvested cash kept
on hand for this purpose, called the <altname>real reserve</altname>. In
Great Britain the ultimate <xex>real reserve</xex> is the gold kept on
hand in the Bank of England, largely represented by the notes in hand in
its own banking department; and any balance which a bank has with the
Bank of England is a part of its <xex>reserve</xex>. In the United
States the reserve of a national bank consists of the amount of lawful
money it holds on hand against deposits, which is required by law (in
1913) to be not less than 15 per cent (<au>U. S. Rev. Stat. secs. 5191,
5192</au>), three fifths of which the banks not in a reserve city (which
see) may keep deposited as balances in national banks that are in
reserve cities (<au>U. S. Rev. Stat. sec. 5192</au>).</def> <sd>(c)</sd>
<fld>(Life Insurance)</fld> <def>The amount of funds or assets necessary
for a company to have at any given time to enable it, with interest and
premiums paid as they shall accure, to meet all claims on the insurance
then in force as they would mature according to the particular mortality
table accepted. The reserve is always reckoned as a liability, and is
calculated on net premiums. It is theoretically the difference between
the present value of the total insurance and the present value of the
future premiums on the insurance. The reserve, being an amount for which
another company could, theoretically, afford to take over the insurance,
is sometimes called the <col><b>reinsurance fund</b></col> or the
<col><b>self-insurance fund</b></col>. For the first year upon any
policy the net premium is called the <col><b>initial reserve</b></col>,
and the balance left at the end of the year including interest is the
<col><b>terminal reserve</b></col>. For subsequent years the
<xex>initial reserve</xex> is the net premium, if any, plus the terminal
reserve of the previous year. The portion of the reserve to be absorbed
from the initial reserve in any year in payment of losses is sometimes
called the <col><b>insurance reserve</b></col>, and the terminal reserve
is then called the <col><b>investment reserve</b></col>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>9.</sn> <def>In exhibitions, a distinction which indicates that
the recipient will get a prize if another should be
disqualified.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>10.</sn> <fld>(Calico Printing)</fld> <def>A resist.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>11.</sn> <def>A preparation used on an object being electroplated
to fix the limits of the deposit.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Reserve city</ent><br/
<hw>Reserve city</hw>. <fld>(Banking)</fld> <def>In the national banking
system of the United States, any of certain cities in which the national
banks are required (<au>U. S. Rev. Stat. sec. 5191</au>) to keep a
larger reserve (25 per cent) than the minimum (15 per cent) required of
all other banks. The banks in certain of the reserve cities
(specifically called <stype>central reserve cities</stype>) are required
to keep their reserve on hand in cash; banks in other reserve cities may
keep half of their reserve as deposits in these banks (<au>U. S. Rev.
Stat. sec. 5195</au>).</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><cs><col><b>In reserve</b></col>, <cd>in keeping for other or future
use; in store; <as>as, he has large quantities of wheat <ex>in
reserve</ex>; he has evidence or arguments <ex>in
reserve</ex></as>.</cd> -- <col><b>Reserve air</b></col>.
<fld>(Physiol.)</fld> <cd>Same as <cref>Supplemental air</cref>, under
<er>Supplemental</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Reservation; retention; limitation; backwardness;
reservedness; coldness; restraint; shyness; coyness; modesty.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reserved</ent><br/
<hw>Re*served"</hw> <pr>(-z?rvd")</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Kept for future or special use, or for an exigency; <as>as,
<ex>reserved</ex> troops; a <ex>reserved</ex> seat in a
theater</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Restrained from freedom in words or actions;
backward, or cautious, in communicating one's thoughts and feelings; not
free or frank.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To all obliging, yet <qex>reserved</qex> to all.</q>
<rj><qau>Walsh.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Nothing <qex>reserved</qex> or sullen was to see.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Re*serv"ed*ly</wf>
<pr>(r<?/-z<?/rv"<?/d-l<?/)</pr>, <pos>adv.</pos> --
<wf>Re*serv"ed*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reservee</ent><br/
<hw>Res`er*vee"</hw> <pr>(r<ecr/z`<etil/r*v<emac/")</pr>, <pos>n.</pos>
<def>One to, or for, whom anything is reserved; -- contrasted with
<xex>reservor</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reserver</ent><br/
<hw>Re*serv"er</hw> <pr>(r<esl/*z<etil/rv"<etil/r)</pr>, <pos>n.</pos>
<def>One who reserves.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reservist</ent><br/
<hw>Re*serv"ist</hw>, <pos>n.</pos> <def>A member of a reserve force of
soldiers or militia.</def> <mark>[Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reservoir</ent><br/
<hw>Res"er*voir`</hw> <pr>(r<ecr/z"<etil/r*vw<ocir/r`; 277)</pr>,
<pos>n.</pos> <ety>[F. <ets>r<eacute/servoir</ets>, fr. LL.
<ets>reservatorium</ets>. See <er>Reservatory</er>.]</ety> <sn>1.</sn>
<def>A place where anything is kept in store; especially, a place where
water is collected and kept for use when wanted, as to supply a
fountain, a canal, or a city by means of aqueducts, or to drive a mill
wheel, or the like.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>A small intercellular space, often
containing resin, essential oil, or some other secreted
matter.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Med.)</fld> <def>A large quantity of infectious
microorganisms resident in animals other than man, potentially capable
of being transmitted to humans.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <fld>(Med.)</fld> <def>a large quantity of infectious
microorganisms or parasites resident in animals other than man,
potentially capable of being transmitted to humans; especially, such
organisms in animals where they do little or no harm to the
host.</def><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <def>A large supply or stock of anything which may be
rapidly put to use; a reserve.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Receiving reservoir</b></col> <fld>(Water Works)</fld>,
<cd>a principal reservoir into which an aqueduct or rising main delivers
water, and from which a distributing reservoir draws its
supply.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reservor</ent><br/
<hw>Re*serv"or</hw> <pr>(r?-z?rv"?r <or/ r?z`?r-v?r)</pr>, <pos>n.</pos>
<def>One who reserves; a reserver.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reset</ent><br/
<ent>re-set</ent><br/
<mhw><hw>re-set"</hw>, <hw>Re*set"</hw></mhw> <pr>(r?-s?t")</pr>,
<pos>v. t.</pos> <sn>1.</sn> <def>To set again; <as>as, to
<ex>reset</ex> type; to <ex>reset</ex> copy; to <ex>reset</ex> a
diamond</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To set (an instrument) back to an initial position
after it has changed; of instruments and dials; <as>as, he
<ex>reset</ex> the timer to ten minutes started again</as>.</def><br/
<syn><b>Syn. --</b> reset, set to zero.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Reset</ent><br/
<hw>Re"set</hw> <pr>(r?"s?t)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
act of resetting.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Print.)</fld> <def>That which is reset; matter set
up again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reset</ent><br/
<hw>Re*set"</hw> <pr>(r?-s?t")</pr>, <pos>n.</pos> <ety>[OF.
<ets>recete</ets>, <ets>recepte</ets>, a receiving. Cf.
<er>Receipt</er>.]</ety> <fld>(Scots Law)</fld> <def>The receiving of
stolen goods, or harboring an outlaw.</def>
<rj><au>Jamieson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reset</ent><br/
<hw>Re*set"</hw>, <pos>v. t.</pos> <fld>(Scots Law)</fld> <def>To harbor
or secrete; to hide, as stolen goods or a criminal.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We shall see if an English hound is to harbor and <qex>reset</qex>
the Southrons here.</q> <rj><qau>Sir. W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resetter</ent><br/
<hw>Re*set"ter</hw> <pr>(-t?r)</pr>, <pos>n.</pos> <fld>(Scots
Law)</fld> <def>One who receives or conceals, as stolen goods or
criminal.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resetter</ent><br/
<hw>Re*set"ter</hw> <pr>(r?-S?t"t?r)</pr>, <pos>n.</pos> <def>One who
resets, or sets again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resettle</ent><br/
<hw>Re*set"tle</hw> <pr>(r?-s?t"t'l)</pr>, <pos>v. t.</pos> <def>To
settle again.</def> <rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resettle</ent><br/
<hw>Re*set"tle</hw>, <pos>v. i.</pos> <def>To settle again, or a second
time.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resettlement</ent><br/
<hw>Re*set"tle*ment</hw> <pr>(-m<it>e</it>nt)</pr>, <pos>n.</pos>
<def>Act of settling again, or state of being settled again; <as>as, the
<ex>resettlement</ex> of lees</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>resettlement</qex> of my discomposed soul.</q>
<rj><qau>Norris.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reshape</ent><br/
<hw>Re*shape"</hw> <pr>(r?-sh?p")</pr>, <pos>v. t.</pos> <def>To shape
again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reship</ent><br/
<hw>Re*ship"</hw> <pr>(r?-sh?p")</pr>, <pos>v. t.</pos> <def>To ship
again; to put on board of a vessel a second time; to send on a second
voyage; <as>as, to <ex>reship</ex> bonded merchandise</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reship</ent><br/
<hw>Re*ship"</hw>, <pos>v. i.</pos> <def>To engage one's self again for
service on board of a vessel after having been discharged.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reshipment</ent><br/
<hw>Re*ship"ment</hw> <pr>(-m<it>e</it>nt)</pr>, <pos>n.</pos> <def>The
act of reshipping; also, that which is reshipped.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reshipper</ent><br/
<hw>Re*ship"per</hw> <pr>(-p?r)</pr>, <pos>n.</pos> <def>One who
reships.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resiance</ent><br/
<hw>Res`i*ance</hw> <pr>(r?z"?-<it>a</it>ns)</pr>, <pos>n.</pos>
<ety>[LL. <ets>reseantia</ets>, <?/<?/ OF. <ets>reseance</ets>.]</ety>
<def>Residence; abode.</def> <mark>[Obs.]</mark>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resiant</ent><br/
<hw>Res"i*ant</hw> <pr>(-<it>a</it>nt)</pr>, <pos>a.</pos> <ety>[OF.
<ets>reseant</ets>, <ets>resseant</ets>, L. <ets>residens</ets>. See
<er>Resident</er>.]</ety> <def>Resident; present in a place.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>In which her kingdom's throne is chiefly <qex>resiant</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resiant</ent><br/
<hw>Res"i*ant</hw>, <pos>n.</pos> <def>A resident.</def>
<mark>[Obs.]</mark> <rj><au>Sir T. More.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reside</ent><br/
<hw>Re*side"</hw> <pr>(r?-z?d")</pr>, <pos>v. i.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Resided</conjf>; <pos>p. pr. &
vb. n.</pos> <conjf>Residing</conjf>.]</vmorph> <ety>[F.
<ets>r<eacute/sider</ets>, L. <ets>residere</ets>; pref. <ets>re-</ets>
re- + <ets>sedere</ets> to sit. See <er>Sit</er>. ]</ety> <sn>1.</sn>
<def>To dwell permanently or for a considerable time; to have a settled
abode for a time; to abide continuosly; to have one's domicile of home;
to remain for a long time.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>At the moated grange, <qex>resides</qex> this dejected
Mariana.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>In no fixed place the happy souls <qex>reside</qex>.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To have a seat or fixed position; to inhere; to lie
or be as in attribute or element.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In such like acts, the duty and virtue of contentedness doth
especially <qex>reside</qex>.</q> <rj><qau>Barrow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To sink; to settle, as sediment.</def>
<mark>[Obs.]</mark> <rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To dwell; inhabit; sojourn; abide; remain; live;
domiciliate; domicile.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Residence</ent><br/
<hw>Res"i*dence</hw> <pr>(r?z"?-d<it>e</it>ns)</pr>, <pos>n.</pos>
<ety>[F. <ets>r<eacute/sidence</ets>. See <er>Resident</er>.]</ety>
<sn>1.</sn> <def>The act or fact of residing, abiding, or dwelling in a
place for some continuance of time; <as>as, the <ex>residence</ex> of an
American in France or Italy for a year</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The confessor had often made considerable <qex>residences</qex> in
Normandy.</q> <rj><qau>Sir M. Hale.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The place where one resides; an abode; a dwelling or
habitation; esp., a settled or permanent home or domicile.</def>
<ldquo/Near the <xex>residence</xex> of Posthumus.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Johnson took up his <qex>residence</qex> in London.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Eng. Eccl. Law)</fld> <def>The residing of an
incumbent on his benefice; -- opposed to
<xex>nonresidence</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The place where anything rests
permanently.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>But when a king sets himself to bandy against the highest court
and <qex>residence</qex> of all his regal power, he then, . . . fights
against his own majesty and kingship.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Subsidence, as of a sediment.</def>
<mark>[Obs.]</mark> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>That which falls to the bottom of liquors; sediment;
also, refuse; residuum.</def> <mark>[Obs.]</mark> <rj><au>Jer.
Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Domiciliation; sojourn; stay; abode; home;
dwelling; habitation; domicile; mansion.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Residencia</ent><br/
\'d8<hw>Re`si*den"cia</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sp.]</ety>
<def>In Spanish countries, a court or trial held, sometimes as long as
six months, by a newly elected official, as the governor of a province,
to examine into the conduct of a predecessor.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Residency</ent><br/
<hw>Res"i*den*cy</hw> <pr>(-d<it>e</it>n-s?)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>Residence.</def> <mark>[Obsoles.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A political agency at a native court in British
India, held by an officer styled the Resident; also, a Dutch commercial
colony or province in the East Indies.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resident</ent><br/
<hw>Res"i*dent</hw> <pr>(-d<it>e</it>nt)</pr>, <pos>a.</pos> <ety>[F.
<ets>r<eacute/sident</ets>, L. <ets>residens</ets>, <ets>-entis</ets>,
p. pr. of <ets>residere</ets>. See <er>Reside</er>.]</ety> <sn>1.</sn>
<def>Dwelling, or having an abode, in a place for a continued length of
time; residing on one's own estate; -- opposed to
<ant>nonresident</ant>; <as>as, <ex>resident</ex> in the city or in the
country</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Fixed; stable; certain.</def> <mark>[Obs.]</mark>
<ldquo/Stable and <xex>resident</xex> like a rock.<rdquo/ <rj><au>Jer.
TAylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>One there still <qex>resident</qex> as day and night.</q>
<rj><qau>Davenant.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resident</ent><br/
<hw>Res"i*dent</hw>, <pos>n.</pos> <sn>1.</sn> <def>One who resides or
dwells in a place for some time.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A diplomatic representative who resides at a foreign
court; -- a term usualy applied to ministers of a rank inferior to that
of ambassadors. See the Note under <er>Minister</er>, 4.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Residenter</ent><br/
<hw>Res"i*dent*er</hw> <pr>(-$r)</pr>, <pos>n.</pos> <def>A
resident.</def> <mark>[Obs. or Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Residential</ent><br/
<hw>Res`i*den""tial</hw> <pr>(-d?n"sh<it>a</it>l)</pr>, <pos>a.</pos>
<sn>1.</sn> <def>Of or pertaining to a residence or residents; <as>as,
<ex>residential</ex> trade; a <ex>residential</ex> part of
town</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Residing; residentiary.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Residentiary</ent><br/
<hw>Res`i*den"tia*ry</hw> <pr>(-d?n"sh?-r?; 277)</pr>, <pos>a.</pos>
<ety>[LL. <ets>residentiaris</ets>.]</ety> <def>Having residence;
<as>as, a canon <ex>residentary</ex>; a <ex>residentiary</ex>
guardian.</as></def> <rj><au>Dr. H. More.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Residentiary</ent><br/
<hw>Res`i*den"tia*ry</hw>, <pos>n.</pos> <sn>1.</sn> <def>One who is
resident.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>residentiary</qex>, or the frequent visitor of the
favored spot, . . . will discover that both have been there.</q>
<rj><qau>Coleridge.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An ecclesiastic who keeps a certain
residence.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Inhabitant; inhabiter; dweller;
sojourner.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Residentiaryship</ent><br/
<hw>Res`i*den"tia*ry*ship</hw>, <pos>n.</pos> <def>The office or
condition of a residentiary.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Residentship</ent><br/
<hw>Res"i*dent*ship</hw> <pr>(r?z"?-d<it>e</it>nt-sh?p)</pr>,
<pos>n.</pos> <def>The office or condition of a resident.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resider</ent><br/
<hw>Re*sid"er</hw> <pr>(r?-z?d"?r)</pr>, <pos>n.</pos> <def>One who
resides in a place.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Residual</ent><br/
<hw>Re*sid"u*al</hw> <pr>(r?-z?d"?-<it>a</it>l)</pr>, <pos>a.</pos>
<ety>[See <er>Residue</er>.]</ety> <def>Pertaining to a residue;
remaining after a part is taken.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Residual air</b></col> <fld>(Physiol.)</fld>, <cd>that
portion of air contained in the lungs which can not be expelled even by
the most violent expiratory effort. It amounts to from 75 to 100 cubic
inches. Cf. <cref>Supplemental air</cref>, under
<er>Supplemental</er>.</cd> -- <col><b>Residual error</b></col>.
<fld>(Mensuration)</fld> <cd>See <er>Error</er>, 6 <sd>(b)</sd>.</cd> --
<col><b>Residual figure</b></col> <fld>(Geom.)</fld>, <cd>the figure
which remains after a less figure has been taken from a greater
one.</cd> -- <col><b>Residual magnetism</b></col> <fld>(Physics)</fld>,
<cd>remanent magnetism. See under <er>Remanent</er>.</cd> --
<col><b>Residual product</b></col>, <cd>a by product, as cotton waste
from a cotton mill, coke and coal tar from gas works, etc.</cd> --
<col><b>Residual quantity</b></col> <fld>(Alg.)</fld>, <cd>a binomial
quantity the two parts of which are connected by the negative sign, as
<mathex>a-b</mathex>.</cd> -- <col><b>Residual root</b></col>
<fld>(Alg.)</fld>, <cd>the root of a residual quantity, as
<mathex><root/(a-b)</mathex>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Residual</ent><br/
<hw>Re*sid"u*al</hw>, <pos>n.</pos> <fld>(Math.)</fld> <sd>(a)</sd>
<def>The difference of the results obtained by observation, and by
computation from a formula.</def> <sd>(b)</sd> <def>The difference
between the mean of several observations and any one of them.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Residuary</ent><br/
<hw>Re*sid"u*a*ry</hw> <pr>(-?-r?)</pr>, <pos>a.</pos> <ety>[See
<er>Residue</er>.]</ety> <def>Consisting of residue; <as>as,
<ex>residuary</ex> matter</as>; pertaining to the residue, or part
remaining; <as>as, the <ex>residuary</ex> advantage of an
estate</as>.</def> <rj><au>Ayliffe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Residuary clause</b></col> <fld>(Law)</fld>, <cd>that
part of the testator's will in which the residue of his estate is
disposed of.</cd> -- <col><b>Residuary devise</b></col>
<fld>(Law)</fld>, <cd>the person to whom the residue of real estate is
devised by a will.</cd> -- <col><b>Residuary legatee</b></col>
<fld>(Law)</fld>, <cd>the person to whom the residue of personal estate
is bequeathed.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Residue</ent><br/
<hw>Res"i*due</hw> <pr>(r?z"?-d?)</pr>, <pos>n.</pos> <ety>[F.
<ets>r<eacute/sidu</ets>, L. <ets>residuum</ets>, fr.
<ets>residuus</ets> that is left behind, remaining, fr.
<ets>residere</ets> to remain behind. See <er>Reside</er>, and cf.
<er>Residuum</er>.]</ety> <sn>1.</sn> <def>That which remains after a
part is taken, separated, removed, or designated; remnant;
remainder.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>residue</qex> of them will I deliver to the sword.</q>
<rj><qau>Jer. xv. 9.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>If church power had then prevailed over its victims, not a
<qex>residue</qex> of English liberty would have been saved.</q>
<rj><qau>I. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>That part of a testeator's estate
wwhich is not disposed of in his will by particular and special legacies
and devises, and which remains after payment of debts and
legacies.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Chem.)</fld> <def>That which remains of a molecule
after the removal of a portion of its constituents; hence, an atom or
group regarded as a portion of a molecule; a <altname>moiety</altname>
or <altname>group</altname>; -- used as nearly equivalent to
<altname>radical</altname>, but in a more general sense.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><note><hand/ The term <xex>radical</xex> is sometimes restricted to
groups containing carbon, the term <xex>residue</xex> and
<altname>moiety</altname> being applied to the others.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Theory of Numbers)</fld> <def>Any positive or
negative number that differs from a given number by a multiple of a
given modulus; <as>thus, if 7 is the modulus, and 9 the given number,
the numbers -5, 2, 16, 23, etc., are <ex>residues</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Rest; remainder; remnant; balance; residuum;
remains; leavings; relics.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Residuous</ent><br/
<hw>Re*sid"u*ous</hw> <pr>(r?-z?d"?-?s)</pr>, <pos>a.</pos> <ety>[L.
<ets>residuus</ets>.]</ety> <def>Remaining; residual.</def>
<rj><au>Landor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Residuum</ent><br/
<hw>Re*sid"u*um</hw> <pr>(-?m)</pr>, <pos>n.</pos> <ety>[L. See
<er>Residue</er>.]</ety> <def>That which is left after any process of
separation or purification; that which remains after certain specified
deductions are made; residue.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><ldquo/I think so,<rdquo/ is the whole <qex>residuum</qex> . . .
after evaporating the prodigious pretensions of the zealot
demagogue.</q> <rj><qau>L. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resiege</ent><br/
<hw>Re*siege"</hw> <pr>(r?-s?j")</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>re-</ets> + <ets>siege</ets> a seat.]</ety> <def>To seat again; to
reinstate.</def> <mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Re-sign</ent><br/
<hw>Re-sign"</hw> <pr>(r?-s?n")</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>re-</ets> + <ets>sign</ets>.]</ety> <def>To affix one's signature
to, a second time; to sign again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resign</ent><br/
<hw>Re*sign"</hw> <pr>(r?-z?n")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Resigned</conjf>
<pr>(-z?nd")</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Resigning</conjf>.]</vmorph> <ety>[F. <ets>r<eacute/signer</ets>,
L. <ets>resignare</ets> to unseal, annul, assign, resign; pref.
<ets>re-</ets> re- + <ets>signare</ets> to seal, stamp. See
<er>Sign</er>, <ets>and cf</ets>. <er>Resignation</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>To sign back; to return by a formal act; to yield to
another; to surrender; -- said especially of office or emolument. Hence,
to give up; to yield; to submit; -- said of the wishes or will, or of
something valued; -- also often used reflexively.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I here <qex>resign</qex> my government to thee.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Lament not, Eve, but patiently <qex>resign</qex><br/
What justly thou hast lost.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>What more reasonable, than that we should in all things
<qex>resign</qex> up ourselves to the will of God?</q>
<rj><qau>Tiilotson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To relinquish; to abandon.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He soon <qex>resigned</qex> his former suit.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To commit to the care of; to consign.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Gentlement of quality have been sent beyong the seas,
<qex>resigned</qex> and concredited to the conduct of such as they call
governors.</q> <rj><qau>Evelyn.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To abdicate; surrender; submit; leave;
relinquish; forego; quit; forsake; abandon; renounce.</syn> <usage> --
<er>Resign</er>, <er>Relinquish</er>. To <xex>resign</xex> is to give
up, as if breaking a seal and yielding all it had secured; hence, it
marks a formal and deliberate surrender. To <xex>relinquish</xex> is
less formal, but always implies abandonment and that the thing given up
has been long an object of pursuit, and, usually, that it has been
prized and desired. We <xex>resign</xex> what we once held or considered
as our own, as an office, employment, etc. We speak of
<xex>relinquishing</xex> a claim, of <xex>relinquishing</xex> some
advantage we had sought or enjoyed, of <xex>relinquishing</xex> seme
right, privilege, etc. <ldquo/Men are weary with the toil which they
bear, but can not find it in their hearts to <xex>relinquish</xex>
it.<rdquo/ <au>Steele.</au> See <er>Abdicate</er>.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Re sign</ent><br/
<hw>Re sign"</hw>, <pos>n.</pos> <def>Resignation.</def>
<mark>[Obs.]</mark> <rj><au>Beau. & Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resignation</ent><br/
<hw>Res`ig*na"tion</hw> <pr>(r<ecr/z`<icr/g*n<amac/"sh<ucr/n)</pr>,
<pos>n.</pos> <ety>[F. <ets>r<eacute/signation</ets>. See
<er>Resign</er>.]</ety> <sn>1.</sn> <def>The act of resigning or giving
up, as a claim, possession, office, or the like; surrender; <as>as, the
<ex>resignation</ex> of a crown or commission</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The state of being resigned or submissive; quiet or
patient submission; unresisting acquiescence; <as>as,
<ex>resignation</ex> to the will and providence of God</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Patience; surrender; relinquishment; forsaking;
abandonment; abdication; renunciation; submission; acquiescence;
endurance. See <er>Patience</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resigned</ent><br/
<hw>Re*signed"</hw> <pr>(r<esl/*z<imac/nd")</pr>, <pos>a.</pos>
<def>Submissive; yielding; not disposed to resist or murmur.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A firm, yet cautious mind;<br/
Sincere, though prudent; constant, yet <qex>resigned</qex>.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resignedly</ent><br/
<hw>Re*sign"ed*ly</hw> <pr>(r<esl/*z<imac/n"<ecr/d*l<ycr/)</pr>,
<pos>adv.</pos> <def>With submission.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resignee</ent><br/
<hw>Res`ign*ee"</hw> <pr>(r<ecr/z`<icr/*n<emac/")</pr>, <pos>n.</pos>
<def>One to whom anything is resigned, or in whose favor a resignation
is made.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resigner</ent><br/
<hw>Re*sign"er</hw> <pr>(r<esl/*z<imac/n"<etil/r)</pr>, <pos>n.</pos>
<def>One who resigns.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resignment</ent><br/
<hw>Re*sign"ment</hw> <pr>(r<esl/*z<imac/n"m<eit/nt)</pr>, <pos>n.</pos>
<def>The act of resigning.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>resile</ent><br/
<hw>re*sile"</hw> <pr>(r<esl/*z<imac/l")</pr>, <pos>v. i.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>resiled</conjf>
<pr>(-z<imac/ld")</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>resiling</conjf>.]</vmorph> <ety>[L. <ets>resilire</ets> to leap
or spring back; pref. <ets>re-</ets> re- + <ets>salire</ets> to leap,
spring. See <er>Salient</er>.]</ety> <def>To start back; to recoil; to
recede from a purpose.</def> <rj><au>J. Ellis.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>resiliency</ent><br/
<ent>resilience</ent><br/
<mhw>{ <hw>re*sil"i*ence</hw> <pr>(r<esl/*z<icr/l"<icr/*<eit/ns)</pr>,
<hw>re*sil"i*en*cy</hw> <pr>(r<esl/*z<icr/l"<icr/*<eit/n*s<ycr/)</pr>,
}</mhw> <pos>n.</pos> <sn>1.</sn> <def>The act of springing back,
rebounding, or resiling; <as>as, the <ex>resilience</ex> of a ball or of
sound</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The power or inherent property of returning to the
form from which a substance is bent, stretched, compressed, or twisted;
elasticity[1]; springiness; -- of objects and substances.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <specif>Hence:</specif> <def>The power or ability to
recover quickly from a setback, depression, illness, overwork or other
adversity; buoyancy; elasticity[2]; -- of people.</def><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <fld>(Mech. & Engin.)</fld> <def>The mechanical work
required to strain an elastic body, as a deflected beam, stretched
spring, etc., to the elastic limit; also, the work performed by the body
in recovering from such strain.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resilient</ent><br/
<hw>Re*sil"i*ent</hw> <pr>(-<it>e</it>nt)</pr>, <pos>a.</pos> <ety>[L.
<ets>resiliens</ets>, p. pr.]</ety> <def>Leaping back; rebounding;
recoiling.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resilition</ent><br/
<hw>Res`i*li"tion</hw> <pr>(r?z`?-l?sh"?n)</pr>, <pos>n.</pos>
<def>Resilience.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resin</ent><br/
<hw>Res"in</hw> <pr>(r<ecr/z"<icr/n)</pr>, <pos>n.</pos> <ety>[F.
<ets>r<eacute/sine</ets>, L. <ets>resina</ets>; cf. Gr.
<grk>"rhti`nh</grk> Cf. <er>Rosin</er>.]</ety> <def>Any one of a class
of yellowish brown solid inflammable substances, of vegetable origin,
which are nonconductors of electricity, have a vitreous fracture, and
are soluble in ether, alcohol, and essential oils, but not in water;
specif., pine resin (see <er>Rosin</er>).</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Resins</xex> exude from trees in combination with
essential oils, gums, etc., and in a liquid or semiliquid state. They
are composed of carbon, hydrogen, and oxygen, and they consist primarily
of polymerized small molecules having carboxylic groups. Copal, mastic,
guaiacum, and colophony or pine resin, are some of them. When mixed with
gum, they form the gum resins, like asafetida and gamboge; mixed with
essential oils, they form balsams, or oleoresins. They are also used in
making varnishes.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Any of various polymeric substance resembling the
natural resins[1], prepared synthetically; -- they are used, especially
in particulate form, in research and industry for their property of
specifically absorbing or adsorbing substances of particular types; they
are especially useful in separation processes such as chromatography;
<as>as, an ion-exchange <er>resin</er></as>.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Highgate resin</b></col> <fld>(Min.)</fld>, <cd>a fossil
resin resembling copal, occuring in blue clay at Highgate, near
London.</cd> -- <col><b>Resin bush</b></col> <fld>(Bot.)</fld>, <cd>a
low composite shrub (<spn>Euryops speciosissimus</spn>) of South Africa,
having smooth pinnately parted leaves and abounding in
resin.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resinaceous</ent><br/
<hw>Res`in*a"ceous</hw> <pr>(r<ecr/z`<icr/n*<amac/"sh<ucr/s)</pr>,
<pos>a.</pos> <def>Having the quality of resin; resinous.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resinate</ent><br/
<hw>Res"in*ate</hw> <pr>(r<ecr/z"<icr/n*<asl/t)</pr>, <pos>n.</pos>
<fld>(Chem.)</fld> <def>Any one of the salts the resinic
acids.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1226 --></p>

<p><ent>Resinic</ent><br/
<hw>Re*sin"ic</hw> <pr>(r<esl/*z<icr/n"<icr/k)</pr>, <pos>a.</pos>
<fld>(Chem.)</fld> <def>Pertaining to, or obtained from, resin; <as>as,
the <ex>resinic</ex> acids</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resiniferous</ent><br/
<hw>Res`in*if"er*ous</hw> <pr>(r?z`?n-?f"?r-?s)</pr>, <pos>a.</pos>
<ety>[<ets>Resin</ets> + <ets>-ferous</ets>: cf. F.
<ets>r<eacute/sinif<egrave/re</ets>.]</ety> <def>Yielding resin; <as>as,
a <ex>resiniferous</ex> tree or vessel</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resiniform</ent><br/
<hw>Res"in*i*form</hw> <pr>(r?z"?n-?-f?rm)</pr>, <pos>a.</pos>
<ety>[<ets>Resin</ets> + <ets>-form</ets>: cf. F.
<ets>r<eacute/siniforme</ets>.]</ety> <def>Having the form of
resin.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resino-electric</ent><br/
<hw>Res`in*o-e*lec"tric</hw> <pr>(-?-?-l?k"tr?k)</pr>, <pos>a.</pos>
<fld>(Elec.)</fld> <def>Containing or exhibiting resinous
electricity.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resinoid</ent><br/
<hw>Res"in*oid</hw> <pr>(r?z"?n-oid)</pr>, <pos>a.</pos> <def>Somewhat
like resin.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resinous</ent><br/
<hw>Res"in*ous</hw> <pr>(-?s)</pr>, <pos>a.</pos> <ety>[L.
<ets>resinous</ets>: cf. F. <ets>r<eacute/sineux</ets>. See
<er>Resin</er>.]</ety> <def>Of or pertaining to resin; of the nature of
resin; resembling or obtained from resin.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Resinous electricity</b></col> <fld>(Elec.)</fld>,
<cd>electricity which is exited by rubbing bodies of the resinous kind.
See <cref>Negative electricity</cref>, under
<er>Negative</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resinously</ent><br/
<hw>Res"in*ous*ly</hw>, <pos>adv.</pos> <def>By means, or in the manner,
of resin.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resinousness</ent><br/
<hw>Res"in*ous*ness</hw>, <pos>n.</pos> <def>The quality of being
resinous.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resiny</ent><br/
<hw>Res"in*y</hw> <pr>(-?)</pr>, <pos>a.</pos> <def>Like resin;
resinous.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resipiscence</ent><br/
<hw>Res`i*pis"cence</hw> <pr>(r?s`?-p?s"s<it>e</it>ns)</pr>,
<pos>n.</pos> <ety>[L. <ets>resipiscentia</ets>, from
<ets>resipiscere</ets> to recover one's senses: cf. F.
<ets>r<eacute/sipiscence</ets>.]</ety> <def>Wisdom derived from severe
experience; hence, repentance.</def> <mark>[R.]</mark> <rj><au>Bp.
Montagu.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resist</ent><br/
<hw>Re*sist"</hw> <pr>(r?-z?st")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Resisted</conjf>; <pos>p. pr. &
vb. n.</pos> <conjf>Resisting</conjf>.]</vmorph> <ety>[F.
<ets>r<eacute/sister</ets>, L. <ets>resistere</ets>, pref.
<ets>re-</ets> re- + <ets>sistere</ets> to stand, cause to stand, v.
causative of <ets>stare</ets> to stand. See <er>Stand</er>.]</ety>
<sn>1.</sn> <def>To stand against; to withstand; to obstruct.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That mortal dint,<br/
Save He who reigns above, none can <qex>resist</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To strive against; to endeavor to counteract,
defeat, or frustrate; to act in opposition to; to oppose.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>God <qex>resisteth</qex> the proud.</q> <rj><qau>James iv.
6.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Contrary to his high will<br/
Whom we <qex>resist</qex>.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To counteract, as a force, by inertia or
reaction.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To be distasteful to.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To withstand; oppose; hinder; obstruct;
counteract; check; thwart; baffle; disappoint.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resist</ent><br/
<hw>Re*sist"</hw>, <pos>v. i.</pos> <def>To make opposition.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resist</ent><br/
<hw>Re*sist"</hw>, <pos>n.</pos> <sn>1.</sn> <fld>(Calico
Printing)</fld> <def>A substance used to prevent a color or mordant from
fixing on those parts to which it has been applied, either by acting
machanically in preventing the color, etc., from reaching the cloth, or
chemically in changing the color so as to render it incapable of fixing
itself in the fibers; -- also called <altname>reserve</altname>. The
pastes prepared for this purpose are called <xex>resist
pastes</xex>.</def> <rj><au>F. C. Calvert.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Technology)</fld> <def>Something that resists or
prevents a certain action;</def> <specif>specif.</specif>: <def>A
substance applied to a surface, as of metal, or of a silicon wafer, to
prevent the action on it of acid, other chemical agents, or any other
process such as irradiation or deposition, which would modify the
surface if not protected. The resist is usually applied or in some way
formed into a pattern so that the underlying surface may be modified in
a complementary pattern.</def><br/
[<source>PJC</source>]</p>

<p><ent>Resistance</ent><br/
<hw>Re*sist"ance</hw> <pr>(-<it>a</it>ns)</pr>, <pos>n.</pos> <ety>[F.
<ets>r<eacute/sistance</ets>, LL. <ets>resistentia</ets>, fr.
<ets>resistens</ets>, <ets>-entis</ets>, p. pr. See
<er>Resist</er>.]</ety> <sn>1.</sn> <def>The act of resisting;
opposition, passive or active.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>When King Demetrius saw that . . . no <qex>resistance</qex> was
made against him, he sent away all his forces.</q> <rj><qau>1. Macc. xi.
38.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Physics)</fld> <def>The quality of not yielding to
force or external pressure; that power of a body which acts in
opposition to the impulse or pressure of another, or which prevents the
effect of another power; <as>as, the <ex>resistance</ex> of the air to a
body passing through it; the <ex>resistance</ex> of a target to
projectiles.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A means or method of resisting; that which
resists.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Unfold to us some warlike <qex>resistance</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Elec.)</fld> <def>A certain hindrance or opposition
to the passage of an electrical current or discharge offered by
conducting bodies. It bears an inverse relation to the conductivity, --
good conductors having a small resistance, while poor conductors or
insulators have a very high resistance. The unit of resistance is the
ohm.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Resistance box</b></col> <fld>(Elec.)</fld>, <cd>a
rheostat consisting of a box or case containing a number of resistance
coils of standard values so arranged that they can be combined in
various ways to afford more or less resistance.</cd> --
<col><b>Resistance coil</b></col> <fld>(Elec.)</fld>, <cd>a coil of wire
introduced into an electric circuit to increase the resistance.</cd> --
<col><b>Solid of least resistance</b></col> <fld>(Mech.)</fld>, <cd>a
solid of such a form as to experience, in moving in a fluid, less
resistance than any other solid having the same base, height, and
volume.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resistance frame</ent><br/
<hw>Re*sist"ance frame`</hw>. <fld>(Elec.)</fld> <def>A rheostat
consisting of an open frame on which are stretched spirals of wire.
Being freely exposed to the air, they radiate heat rapidly.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Resistant</ent><br/
<hw>Re*sist"ant</hw> <pr>(-<it>a</it>nt)</pr>, <pos>a.</pos> <ety>[F.
<ets>r<eacute/sistant</ets>: cf. L. <ets>resistens</ets>. See
<er>Resist</er>.]</ety> <def>Making resistance; resisting.</def> --
<def2><pos>n.</pos> <def>One who, or that which, resists.</def></def2>
<rj><au>Bp. Pearson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resister</ent><br/
<hw>Re*sist"er</hw> <pr>(-?r)</pr>, <pos>n.</pos> <def>One who
resists.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resistful</ent><br/
<hw>Re*sist"ful</hw> <pr>(-f?l)</pr>, <pos>a.</pos> <def>Making much
resistance.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resistibility</ent><br/
<hw>Re*sist`i*bil"i*ty</hw> <pr>(-?-b?l"?-t?)</pr>, <pos>n..</pos>
<sn>1.</sn> <def>The quality of being resistible;
resistibleness.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The quality of being resistant;
resitstance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The name <ldquo/body<rdquo/ being the complex idea of extension
and <qex>resistibility</qex> together in the same subject.</q>
<rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resistible</ent><br/
<hw>Re*sist"i*ble</hw> <pr>(r?-z?st"?-b'l)</pr>, <pos>a.</pos> <ety>[Cf.
F. <ets>r<eacute/sistible</ets>.]</ety> <def>Capable of being resisted;
<as>as, a <ex>resistible</ex> force</as>.</def> <au>Sir M. Hale.</au> --
<wordforms><wf>Re*sist"i*ble*ness</wf>, <pos>n.</pos> --
<wf>Re*sist"i*bly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resisting</ent><br/
<hw>Re*sist"ing</hw>, <pos>a.</pos> <def>Making resistance; opposing;
<as>as, a <ex>resisting</ex> medium</as>.</def> --
<wordforms><wf>Re*sist"ing ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resistive</ent><br/
<hw>Re*sist"ive</hw> <pr>(-?v)</pr>, <pos>a.</pos> <def>Serving to
resist.</def> <rj><au>B. Jonsosn.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resistless</ent><br/
<hw>Re*sist"less</hw>, <pos>a.</pos> <sn>1.</sn> <def>Having no power to
resist; making no opposition.</def> <mark>[Obs. or R.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Incapable of being resisted; irresistible.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Masters' commands come with a power <qex>resistless</qex><br/
To such as owe them absolute subjection.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Re*sist"less*ly</wf>, <pos>adv.</pos> --
<wf>Re*sist"less*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resoluble</ent><br/
<hw>Res"o*lu*ble</hw> <pr>(r?z"?-l?-b'l)</pr>, <pos>a.</pos><ety>[L.
<ets>resolubolis</ets>: cf. F. <ets>r<eacute/soluble</ets>. See
<er>Resolve</er>, and cf. <er>Resolvable</er>.]</ety> <def>Admitting of
being resolved; resolvable; <as>as, bodies <ex>resoluble</ex> by
fire</as>.</def> <au>Boyle.</au> --
<wordforms><wf>Res"o*lu*ble*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resolute</ent><br/
<hw>Res"o*lute</hw> <pr>(r?z"?-l?t)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>r<eacute/solu</ets>. The L. <ets>resolutus</ets> (p. p. of
<ets>resolvere</ets>) means, relaxed, enervated, effeminate. See
<er>Resolve</er>, <pos>v. t. & i.</pos>]</ety> <sn>1.</sn> <def>Having a
decided purpose; determined; resolved; fixed in a determination; hence,
bold; firm; steady.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Edward is at hand,<br/
Ready to fight; therefore be <qex>resolute</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Convinced; satisfied; sure.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Resolving, or explaining; <as>as, the
<ex>Resolute</ex> Doctor Durand</as>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Determined; decided; fixed; steadfast; steady;
constant; persevering; firm; bold; unshaken.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resolute</ent><br/
<hw>Res"o*lute</hw> <pr>(r?z"?-l?t)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>One who is resolute; hence, a desperado.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Redelivery; repayment.</def> <mark>[Obs.]</mark>
<ldquo/Yearly <xex>resolutes</xex>, deductions, and payments.<rdquo/
<rj><au>Bp. Burnet.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resolutely</ent><br/
<hw>Res"o*lute*ly</hw>, <pos>adv.</pos> <def>In a resolute manner; with
fixed purpose; boldly; firmly; steadily; with perseverance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Some . . . facts he examines, some he <qex>resolutely</qex>
denies.</q> <rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resoluteness</ent><br/
<hw>Res"o*lute*ness</hw>, <pos>n.</pos> <def>The quality of being
resolute.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resolution</ent><br/
<hw>Res`o*lu"tion</hw> <pr>(-l?"sh?n)</pr>, <pos>n.</pos> <ety>[F.
<ets>r<eacute/solution</ets>. L. <ets>resolutio</ets> a loosening,
solution. See <er>Resolve</er>.]</ety> <sn>1.</sn> <def>The act,
operation, or process of resolving.</def> <specif>Specifically:</specif>
<sd>(a)</sd> <def>The act of separating a compound into its elements or
component parts.</def> <sd>(b)</sd> <def>The act of analyzing a complex
notion, or solving a vexed question or difficult problem.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The unraveling and <qex>resolution</qex> of the difficulties that
are met with in the execution of the design are the end of an
action.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The state of being relaxed; relaxation.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The state of being resolved, settled, or determined;
firmness; steadiness; constancy; determination.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Be it with <qex>resolution</qex> then to fight.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>That which is resolved or determined; a settled
purpose; determination. Specifically: A formal expression of the opinion
or will of an official body or a public assembly, adopted by vote;
<as>as, a legislative <ex>resolution</ex>; the <ex>resolutions</ex> of a
public meeting.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>The state of being resolved or firm in opinion or
thought; conviction; assurance.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Little <qex>resolution</qex> and certainty there is as touching
the islands of Mauritania.</q> <rj><qau>Holland.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Math.)</fld> <def>The act or process of solving;
solution; <as>as, the <ex>resolution</ex> of an equation or
problem</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Med.)</fld> <def>A breaking up, disappearance; or
termination, as of a fever, a tumor, or the like.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <fld>(Mus.)</fld> <def>The passing of a dissonant into a
consonant chord by the rising or falling of the note which makes the
discord.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <fld>(Technical)</fld> <def>The act of distinguishing
between two close but not identical objects, or, when taking a
measurement, bbetween two close values of the property
measured.</def><br/
[<source>PJC</source>]</p>

<p><sn>10.</sn> <fld>(Technical)</fld> <def>a measure of the ability to
distinguish between two close but not identical values of the property
being measured; it is expressed as the difference in values of a
property necessary to make such a distinction; <as>as, a microscope with
a <ex>resolution</ex> of one micron; a thermometer with a
<ex>resolution</ex> of one-tenth of a degree</as>. Also called
<altname>resolving power</altname>.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Joint resolution</b></col>. <cd>See under <er>Joint</er>,
<pos>a.</pos></cd> -- <mcol><col><b>Resolution of a force</b></col>
<it>or</it> <col><b>Resolution of a motion</b></col></mcol>
<fld>(Mech.)</fld>, <cd>the separation of a single force or motion into
two or more which have different directions, and, taken together, are an
equivalent for the single one; -- the opposite of <ant>composition of a
force</ant>.</cd> -- <col><b>Resolution of a nebula</b></col>
<fld>(Astron.)</fld>, <cd>the exhibition of it to the eye by a telescope
of such power as to show it to be composed of small stars.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Decision; analysis; separation; disentanglement;
dissolution; resolvedness; resoluteness; firmness; constancy;
perseverance; steadfastness; fortitude; boldness; purpose; resolve. See
<er>Decision</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resolutioner</ent><br/
<hw>Res`o*lu"tion*er</hw> <pr>(-?r)</pr>, <pos>n.</pos> <def>One who
makes a resolution; one who joins with others in a declaration or
resolution; specifically, one of a party in the Scottish Church in the
17th century.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He was sequestrated afterwards as a <qex>Resolutioner</qex>.</q>
<rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resolutionist</ent><br/
<hw>Res`o*lu"tion*ist</hw>, <pos>n.</pos> <def>One who makes a
resolution.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resolutive</ent><br/
<hw>Res"o*lu`tive</hw> <pr>(r?z"?-lu`t?v)</pr>, <pos>a.</pos>
<ety>[Cf.F. <ets>r<eacute/solutif</ets>.]</ety> <def>Serving to dissolve
or relax.</def> <mark>[R.]</mark> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resolutory</ent><br/
<hw>Res"o*lu*to*ry</hw> <pr>(r?z"?-l?-t?-r?)</pr>, <pos>a.</pos>
<def>Resolutive.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resolvability</ent><br/
<hw>Re*solv`a*bil"i*ty</hw> <pr>(r?-z?lv`?-b?l"?-t?)</pr>, <pos>n.</pos>
<def>The quality or condition of being resolvable;
resolvableness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resolvable</ent><br/
<hw>Re*solv"a*ble</hw> <pr>(r?-z?lv"?-b'l)</pr>, <pos>a.</pos> <ety>[See
<er>Resolve</er>, and cf. <er>Resoluble</er>.]</ety> <def>Admitting of
being resolved; admitting separation into constituent parts, or
reduction to first principles; admitting solution or explanation;
<as>as, <ex>resolvable</ex> compounds; <ex>resolvable</ex> ideas or
difficulties</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resolvableness</ent><br/
<hw>Re*solv"a*ble*ness</hw>, <pos>n.</pos> <def>The quality of being
resolvable; resolvability.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resolve</ent><br/
<hw>Re*solve"</hw> <pr>(r?*z?lv")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Resolved</conjf>
<pr>(-z?lvd")</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Resolving</conjf>.]</vmorph> <ety>[L. <ets>resolvere</ets>,
<ets>resolutum</ets>, to untie, loosen, relax, enfeeble; pref.
<ets>re-</ets> re- + <ets>solvere</ets> to loosen, dissolve: cf. F.
<ets>r<eacute/soudare</ets> to resolve. See <er>Solve</er>, and cf.
<er>Resolve</er>, <pos>v. i.</pos>, <er>Resolute</er>,
<er>Resolution</er>.]</ety> <sn>1.</sn> <def>To separate the component
parts of; to reduce to the constituent elements; -- said of compound
substances; hence, sometimes, to melt, or dissolve.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>O, that this too too solid flesh would melt,<br/
Thaw, and <qex>resolve</qex> itself into a dew!</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Ye immortal souls, who once were men,<br/
And now <qex>resolved</qex> to elements again.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To reduce to simple or intelligible notions; -- said
of complex ideas or obscure questions; to make clear or certain; to free
from doubt; to disentangle; to unravel; to explain; hence, to clear up,
or dispel, as doubt; <as>as, to <ex>resolve</ex> a riddle</as>.</def>
<ldquo/<xex>Resolve</xex> my doubt.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To the <qex>resolving</qex> whereof we must first know that the
Jews were commanded to divorce an unbelieving Gentile.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To cause to perceive or understand; to acquaint; to
inform; to convince; to assure; to make certain.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Sir, be <qex>resolved</qex>. I must and will come.</q>
<rj><qau>Beau. & Fl.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Resolve</qex> me, Reason, which of these is worse,<br/
Want with a full, or with an empty purse?</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>In health, good air, pleasure, riches, I am <qex>resolved</qex> it
can not be equaled by any region.</q> <rj><qau>Sir W.
Raleigh.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>We must be <qex>resolved</qex> how the law can be pure and
perspicuous, and yet throw a polluted skirt over these Eleusinian
mysteries.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To determine or decide in purpose; to make ready in
mind; to fix; to settle; <as>as, he was <ex>resolved</ex> by an
unexpected event</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To express, as an opinion or determination, by
resolution and vote; to declare or decide by a formal vote; -- followed
by a clause; <as>as, the house resolved (or, it was resolved by the
house) that no money should be apropriated (or, to appropriate no
money)</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To change or convert by resolution or formal vote;
-- used only reflexively; <as>as, the house <ex>resolved</ex> itself
into a committee of the whole</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Math.)</fld> <def>To solve, as a problem, by
enumerating the several things to be done, in order to obtain what is
required; to find the answer to, or the result of.</def>
<rj><au>Hutton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <fld>(Med.)</fld> <def>To dispere or scatter; to discuss,
as an inflammation or a tumor.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <fld>(Mus.)</fld> <def>To let the tones (as of a discord)
follow their several tendencies, resulting in a concord.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <def>To relax; to lay at ease.</def> <mark>[Obs.]</mark>
<rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To resolve a nebula</b></col>.<fld>(Astron.)</fld>
<cd>See <cref>Resolution of a nebula</cref>, under
<er>Resolution</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To solve; analyze; unravel;
disentangle.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resolve</ent><br/
<hw>Re*solve"</hw> <pr>(r?-z?lv")</pr>, <pos>v. i.</pos> <ety>[The sense
<ldquo/to be convinced, to determine<rdquo/ comes from the idea of
loosening, breaking up into parts, analyzing, hence,
determining.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>To be separated into its component parts or distinct
principles; to undergo resolution.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To melt; to dissolve; to become fluid.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>When the blood stagnates in any part, it first coagulates, then
<qex>resolves</qex>, and turns alkaline.</q>
<rj><qau>Arbuthhnot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To be settled in opinion; to be convinced.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Let men <qex>resolve</qex> of that as they plaease.</q>
<rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To form a purpose; to make a decision; especially,
to determine after reflection; <as>as, to <ex>resolve</ex> on a better
course of life</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To determine; decide; conclude;
purpose.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resolve</ent><br/
<hw>Re*solve"</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act of resolving
or making clear; resolution; solution.</def> <ldquo/To give a full
<xex>resolve</xex> of that which is so much controverted.<rdquo/
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which has been resolved on or determined;
decisive conclusion; fixed purpose; determination; also, legal or
official determination; a legislative declaration; a
resolution.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Nor is your firm <qex>resolve</qex> unknown.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Caesar's approach has summoned us together,<br/
And Rome attends her fate from our <qex>resolves</qex>.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resolved</ent><br/
<hw>Re*solved"</hw> <pr>(r?-z?lvd")</pr>, <pos>p. p. & a.</pos>
<def>Having a fixed purpose; determined; resolute; -- usually placed
after its noun; <as>as, a man <ex>resolved</ex> to be
rich</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That makes him a <qex>resolved</qex> enemy.</q> <rj><qau>Jer.
Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I am <qex>resolved</qex> she shall not settle here.</q>
<rj><qau>Fielding.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resolvedly</ent><br/
<hw>Re*solv"ed*ly</hw> <pr>(r?z?lv"?d-l?)</pr>, <pos>adv.</pos>
<sn>1.</sn> <def>So as to resolve or clear up difficulties;
clearly.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Of that, and all the progress, more or less,<br/
<qex>Resolvedly</qex> more leisure shall express.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Resolutely; decidedly; firmly.</def>
<rj><au>Grew.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resolvedness</ent><br/
<hw>Re*solv"ed*ness</hw>, <pos>n.</pos> <def>Fixedness of purpose;
firmness; resolution.</def> <rj><au>Dr. H. More.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resolvent</ent><br/
<hw>Re*solv"ent</hw> <pr>(-<it>e</it>nt)</pr>, <pos>a.</pos> <def>Having
power to resolve; causing solution; solvent.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resolvent</ent><br/
<hw>Re*solv"ent</hw>, <pos>n.</pos> <ety>[L. <ets>resolvens</ets>, p.
pr. of <ets>resolvere</ets>: cf. F. <ets>r<eacute/solvant</ets>. See
<er>Resolve</er>.]</ety> <sn>1.</sn> <def>That which has the power of
resolving, or causing solution; a solvent.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Med.)</fld> <def>That which has power to disperse
inflammatory or other tumors; a discutient; anything which aids the
absorption of effused products.</def> <rj><au>Coxe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Math.)</fld> <def>An equation upon whose solution
the solution of a given pproblem depends.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resolver</ent><br/
<hw>Re*solv"er</hw> <pr>(r?-z?lv"?r)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>That which decomposes, or dissolves.</def>
<rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which clears up and removes difficulties, and
makes the mind certain or determined.</def> <rj><au>Bp.
Burnet.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>One who resolves, or formal a firm
purpose.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resonance</ent><br/
<hw>Res"o*nance</hw> <pr>(r?z"?-n<it>a</it>ns)</pr>, <pos>n.</pos>
<ety>[Cf. F. <ets>r<eacute/sonance</ets>, L. <ets>resonantia</ets> an
echo.]</ety> <sn>1.</sn> <def>The act of resounding; the quality or
state of being resonant.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Acoustics)</fld> <def>A prolongation or increase of
any sound, either by reflection, as in a cavern or apartment the walls
of which are not distant enough to return a distinct echo, or by the
production of vibrations in other bodies, as a sounding-board, or the
bodies of musical instruments.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Physics)</fld> <def>A phenomenon in which a
vibration or other cyclic process (such as tide cycles) of large
amplitude is produced by smaller impulses, when the frequency of the
external impulses is close to that of the natural cycling frequency of
the process in that system.</def> <note>The shattering of a glass object
when impinged upon by sound of a certain frequency is one example of
this phenomenon; another is the very large tides in certain basins such
as that of the Bay of Fundy, which has a natural cycling frequency close
to that of the tidal cycle.</note><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <fld>(Electronics)</fld> <def>An electric phenomenon
corresponding to that of acoustic resonance, due to the existance of
certain relations of the capacity, inductance, resistance, and frequency
of an alternating circuit; the tuning of a radio transmitter or receiver
to send or detect waves of specific frequencies depends on this
phenomenon.</def><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><cs><col><b>Pulmonary resonance</b></col> <fld>(Med.)</fld>, <cd>the
sound heard on percussing over the lungs.</cd> -- <col><b>Vocal
resonance</b></col> <fld>(Med.)</fld>, <cd>the sound transmitted to the
ear when auscultation is made while the patient is
speaking.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resonancy</ent><br/
<hw>Res"o*nan*cy</hw> <pr>(-n<it>a</it>n-s?)</pr>, <pos>n.</pos>
<def>Resonance.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resonant</ent><br/
<hw>Res"o*nant</hw> <pr>(-n<it>a</it>nt)</pr>, <pos>a.</pos> <ety>[L.
<ets>resonans</ets>, p. pr. of <ets>resonare</ets> to resound: cf. F.
<ets>r<eacute/sonnant</ets>. See <er>Resound</er>.]</ety> <sn>1.</sn>
<def>Returning, or capable of returning, sound; fitted to resound;
resounding; echoing back.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Through every hour of the golden morning, the streets were
<qex>resonant</qex> with female parties of young and old.</q>
<rj><qau>De Quincey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Elec.)</fld> <def>Adjusted as to dimensions (as an
electric circuit) so that currents or electric surgings are produced by
the passage of electric waves of a given frequency.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Resonantly</ent><br/
<hw>Res"o*nant*ly</hw>, <pos>adv.</pos> <def>In a resonant
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resonator</ent><br/
<hw>Res"o*na`tor</hw> <pr>(-n?`t?r)</pr>, <pos>n.</pos> <ety>[NL. &
G.]</ety> <sn>1.</sn> <fld>(Acoustics)</fld> <def>Anything which
resounds; specifically, a vessel in the form of a cylinder open at one
end, or a hollow ball of brass with two apertures, so contrived as to
greatly intensify a musical tone by its resonance. It is used for the
study and analysis of complex sounds.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Anything that resounds or resonates;</def>
<specif>specif.</specif>: <sd>(a)</sd> <fld>(Teleg.)</fld> <def>An open
box for containing a sounder and designed to concentrate and amplify the
sound.</def> <sd>(b)</sd> <fld>(Elec.)</fld> <def>Any of various
apparatus for exhibiting or utilizing the effects of resonance in
connection with open circuits, as a device having an oscillating circuit
which includes a helix of bare copper wire, a variable number of coils
of which can be connected in circuit with a condenser and spark gap
excited with an induction coil. It is used to create high-frequency
electric brush discharges.</def> <sd>(c)</sd> <fld>(Wireless
Teleg.)</fld> <def>The antenna system and other high-frequency circuits
of a receiving apparatus.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Resorb</ent><br/
<hw>Re*sorb"</hw> <pr>(r?-s?rb")</pr>, <pos>v. t.</pos> <ety>[L.
<ets>reorbere</ets>; pref. <ets>re-</ets> re- + <ets>sorbere</ets> to
suck or drink in.]</ety> <sn>1.</sn> <def>To swallow up.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Now lifted by the tide, and now <qex>resorbed</qex>.</q>
<rj><qau>Young.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Biol.)</fld> <def>to absorb (something which has
been secreted or exuded by the same organism).</def><br/
[<source>PJC</source>]</p>

<p><ent>Resorbent</ent><br/
<hw>Re*sorb"ent</hw> <pr>(-<it>e</it>nt)</pr>, <pos>a.</pos> <ety>[L.
<ets>resorbens</ets>, p. pr. of <ets>resorbere</ets>.]</ety>
<def>Swallowing up.</def> <rj><au>Wodhull.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resorcin</ent><br/
<hw>Res*or"cin</hw> <pr>(r?z-?r"s?n)</pr>, <pos>n.</pos>
<ety>[<ets>Res</ets>in + <ets>orcin</ets>. So called because in its
higher homologue it resembles <ets>orcin</ets>.]</ety>
<fld>(Chem.)</fld> <def>A colorless crystalline substance of the phenol
series, obtained by melting certain resins, as galbanum, asafetida,
etc., with caustic potash. It is also produced artificially and used in
making certain dyestuffs, as phthalein, fluorescein, and
eosin.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resorcylic</ent><br/
<hw>Res`or*cyl"ic</hw> <pr>(r?z`?r-s?l"?k)</pr>, <pos>a.</pos>
<fld>(Chem.)</fld> <def>Of, or pertaining to, or producing, resorcin;
<as>as, <ex>resorcylic</ex> acid</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resorption</ent><br/
<hw>Re*sorp"tion</hw> <pr>(r?*s?rp"sh?n)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>The act of resorbing; also, the act of absorbing again;
reabsorption.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Petrography)</fld> <def>The redissolving wholly or
in part, in the molten magma of an igneous rock, of crystals previously
formed. The dissolved material may again solidify, giving rise to a mass
of small crystals, usually of a different kind.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Resort</ent><br/
<hw>Re*sort"</hw> <pr>(r?*z?rt")</pr>, <pos>n.</pos> <ety>[F.
<ets>ressort</ets>.]</ety> <def>Active power or movement; spring.</def>
<mark>[A Gallicism]</mark> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Some . . . know the <qex>resorts</qex> and falls of business that
can not sink into the main of it.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resort</ent><br/
<hw>Re*sort"</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Resorted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Resorting</conjf>.]</vmorph> <ety>[OF. <ets>resortir</ets> to
withdraw, take refuge, F. <ets>ressortir</ets> to be in the
jurisdiction, LL. <ets>resortire</ets>; pref. <ets>re-</ets> re- + L.
<ets>sortiri</ets> to draw lots, obtain by lot, from <ets>sors</ets>
lot. See <er>Sort</er>. The meaning is first to reobtain (by lot), then
to gain by appeal to a higher court (as a law term), to appeal, go for
protection or refuge.]</ety> <sn>1.</sn> <def>To go; to repair; to
betake one's self.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>What men name <qex>resort</qex> to him?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To fall back; to revert.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The inheritance of the son never <qex>resorted</qex> to the
mother, or to any of her ancestors.</q> <rj><qau>Sir M.
Hale.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1227 --></p>

<p><sn>3.</sn> <def>To have recourse; to apply; to one's self for help,
relief, or advantage.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The king thought it time to <qex>resort</qex> to other
counsels.</q> <rj><qau>Clarendon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resort</ent><br/
<hw>Re*sort"</hw> <pr>(r?*z?rt")</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>ressort</ets> jurisdiction. See <er>Resort</er>,
<pos>v.</pos>]</ety> <sn>1.</sn> <def>The act of going to, or making
application; a betaking one's self; the act of visiting or seeking;
recourse; <as>as, a place of popular <ex>resort</ex></as>; -- often
figuratively; <as>as, to have <ex>resort</ex> to force</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Join with me to forbid him her <qex>resort</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A place to which one betakes himself habitually; a
place of frequent assembly; a haunt.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Far from all <qex>resort</qex> of mirth.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That to which one resorts or looks for help;
resource; refuge.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Last resort</b></col>, <cd>ultimate means of relief;
also, final tribunal; that from which there is no appeal.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resorter</ent><br/
<hw>Re*sort"er</hw> <pr>(-?r)</pr>, <pos>n.</pos> <def>One who resorts;
a frequenter.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resoun</ent><br/
<hw>Re*soun"</hw> <pr>(r?*z??n")</pr>, <pos>n.</pos> <def>Reason.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resoun</ent><br/
<hw>Re*soun"</hw>, <pos>v. i. & t.</pos> <def>To resound.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Re-sound</ent><br/
<hw>Re-sound"</hw> <pr>(r?*sound")</pr>, <pos>v. t. & i.</pos>
<ety>[Pref. <ets>re- + sound</ets>.]</ety> <def>To sound again or
anew.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resound</ent><br/
<hw>Re*sound"</hw> <pr>(r?*zound")</pr>, <pos>v. i.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Resounded</conjf>; <pos>p. pr. &
vb. n.</pos> <conjf>Resounding</conjf>.]</vmorph> <ety>[OE.
<ets>resounen</ets>, OF. <ets>resoner</ets>, F.
<ets>r<eacute/sonner</ets>, from L. <ets>resonare</ets>; pref.
<ets>re-</ets> re- + <ets>sonare</ets> to sound, <ets>sonus</ets> sound.
See <er>Sound</er> to make a noise.]</ety> <sn>1.</sn> <def>To sound
loudly; <as>as, his voice <ex>resounded</ex> far</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To be filled with sound; to ring; <as>as, the woods
<ex>resound</ex> with song</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To be echoed; to be sent back, as sound.</def>
<ldquo/Common fame . . . <xex>resounds</xex> back to them again.<rdquo/
<rj><au>South.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To be mentioned much and loudly.</def>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To echo or reverberate; to be resonant; <as>as, the
earth <ex>resounded</ex> with his praise</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resound</ent><br/
<hw>Re*sound"</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To throw back, or
return, the sound of; to echo; to reverberate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Albion's cliffs <qex>resound</qex> the rural lay.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To praise or celebrate with the voice, or the sound
of instruments; to extol with sounds; to spread the fame of.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The man for wisdom's various arts renowned,<br/
Long exercised in woes, O muse, <qex>resound</qex>.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To echo; reecho; reverberate; sound.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resound</ent><br/
<hw>Re*sound"</hw>, <pos>n.</pos> <def>Return of sound; echo.</def>
<rj><au>Beaumont.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resource</ent><br/
<hw>Re*source"</hw> <pr>(r?*s?rs")</pr>, <pos>n.</pos> <ety>[F.
<ets>ressource</ets>, fr. OF. <ets>ressourdre</ets>,
<ets>resourdre</ets>, to spring forth or up again; pref. <ets>re-</ets>
re- + <ets>sourdre</ets> to spring forth. See <er>Source</er>.]</ety>
<sn>1.</sn> <def>That to which one resorts orr on which one depends for
supply or support; means of overcoming a difficulty; resort;
expedient.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Threat'nings mixed with prayers, his last <qex>resource</qex>.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <pluf>pl.</pluf> <def>Pecuniary means; funds; money, or
any property that can be converted into supplies; available means or
capabilities of any kind.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Scotland by no means escaped the fate ordained for every country
which is connected, but not incorporated, with another country of
greater <qex>resources</qex>.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Expedient; resort; means; contrivance.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resourceful</ent><br/
<hw>Re*source"ful</hw> <pr>(-f?l)</pr>, <pos>a.</pos> <def>Full of
resources.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resourceless</ent><br/
<hw>Re*source"less</hw>, <pos>a.</pos> <def>Destitute of
resources.</def> <rj><au>Burke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Re*source"less*ness</wf>, <pos>n.</pos> <au>R.
Browning.</au></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resow</ent><br/
<hw>Re*sow"</hw> <pr>(r?*s?")</pr>, <pos>v. t.</pos> <def>To sow
again.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resown</ent><br/
<hw>Re*sown"</hw> <pr>(r?*zoun")</pr>, <pos>v.</pos> <def>To
resound.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Respeak</ent><br/
<hw>Re*speak"</hw> <pr>(r<emac/*sp<emac/k")</pr>, <pos>v. t.</pos>
<sn>1.</sn> <def>To speak or utter again.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To answer; to echo.</def> <mark>[Obs. or
Poetic]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Respect</ent><br/
<hw>Re*spect"</hw> <pr>(r?*sp?kt")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Respected</conjf>; <pos>p. pr. &
vb. n.</pos> <conjf>Respecting</conjf>.]</vmorph> <ety>[L.
<ets>respectare</ets>, v. intens. from <ets>respicere</ets>,
<ets>respectum</ets>, to look back, respect; pref. <ets>re-</ets> re- +
<ets>specere</ets>, <ets>spicere</ets>, to look, to view: cf. F.
<ets>respecter</ets>. See <er>Spy</er>, and cf. <er>Respite</er>.]</ety>
<sn>1.</sn> <def>To take notice of; to regard with special attention; to
regard as worthy of special consideration; hence, to care for; to
heed.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou <qex>respectest</qex> not spilling Edward's blood.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>In orchards and gardens, we do not so much <qex>respect</qex>
beauty as variety of ground for fruits, trees, and herbs.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To consider worthy of esteem; to regard with
honor.</def> <ldquo/I do <xex>respect</xex> thee as my soul.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To look toward; to front upon or toward.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Palladius adviseth the front of his house should so
<qex>respect</qex> the truth.</q> <rj><qau>Sir T. Browne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To regard; to consider; to deem.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>To whom my father gave this name of Gaspar,<br/
And as his own <qex>respected</qex> him to death.</q> <rj><qau>B.
Jonson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To have regard to; to have reference to; to relate
to; <as>as, the treaty particularly <ex>respects</ex> our
commerce</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>As respects</b></col>, <cd>as regards; with regard to; as
to.</cd> <au>Macaulay.</au> -- <mcol><col><b>To respect the
person</b></col> <it>or</it> <col><b>To respect the
persons</b></col></mcol>, <cd>to favor a person, or persons on corrupt
grounds; to show partiality.</cd> <ldquo/Ye shall not <xex>respect
persons</xex> in judgment.<rdquo/ <au>Deut. i. 17.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To regard; esteem; honor; revere;
venerate.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Respect</ent><br/
<hw>Re*spect"</hw>, <pos>n.</pos> <ety>[L. <ets>respectus</ets>: cf. F.
<ets>respect</ets>. See <er>Respect</er>, <pos>v.</pos>, and cf.
<er>Respite</er>.]</ety> <sn>1.</sn> <def>The act of noticing with
attention; the giving particular consideration to; hence, care;
caution.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>But he it well did ward with wise <qex>respect</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Esteem; regard; consideration; honor.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Seen without awe, and served without <qex>respect</qex>.</q>
<rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The same men treat the Lord's Day with as little
<qex>respect</qex>.</q> <rj><qau>R. Nelson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <pluf>pl.</pluf> <def>An expression of respect of
deference; regards; <as>as, to send one's <ex>respects</ex> to
another</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Reputation; repute.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Many of the best <qex>respect</qex> in Rome.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Relation; reference; regard.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They believed but one Supreme Deity, which, with
<qex>respect</qex> to the various benefits men received from him, had
several titles.</q> <rj><qau>Tillotson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Particular; point regarded; point of view; <as>as,
in this <ex>respect</ex>; in any <ex>respect</ex>; in all
<ex>respects</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Everything which is imperfect, as the world must be acknowledged
in many <qex>respects</qex>.</q> <rj><qau>Tillotson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>In one <qex>respect</qex> I'll be thy assistant.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>Consideration; motive; interest.</def>
<mark>[Obs.]</mark> <ldquo/Whatever secret <xex>respects</xex> were
likely to move them.<rdquo/ <rj><au>Hooker.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To the publik good<br/
Private <qex>respects</qex> must yield.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>In respect</b></col>, <cd>in comparison.</cd>
<mark>[Obs.]</mark> <au>Shak.</au> -- <col><b>In respect of</b></col>.
<sd>(a)</sd> <cd>In comparison with.</cd> <mark>[Obs.]</mark>
<au>Shak.</au> <sd>(b)</sd> <cd>As to; in regard to.</cd>
<mark>[Archaic]</mark> <ldquo/Monsters <xex>in respect of</xex> their
bodies.<rdquo/ <au>Bp. Wilkins.</au> <ldquo/<xex>In respect of</xex>
these matters.<rdquo/ <au>Jowett. (Thucyd.)</au> -- <mcol><col><b>In
respect to</b></col>, <it>or</it> <col><b>With respect
to</b></col></mcol>, <cd>in relation to; with regard to; as
respects.</cd> <au>Tillotson.</au> -- <col><b>To have respect of
persons</b></col>, <cd>to regard persons with partiality or undue bias,
especially on account of friendship, power, wealth, etc.</cd> <ldquo/It
is not good <xex>to have respect of persons</xex> in judgment.<rdquo/
<au>Prov. xxiv. 23.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Deference; attention; regard; consideration;
estimation. See <er>Deference</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Respectability</ent><br/
<hw>Re*spect`a*bil"i*ty</hw> <pr>(r?*sp?kt`?*b?l"?*t?)</pr>,
<pos>n.</pos> <def>The state or quality of being respectable; the state
or quality which deserves or commands respect.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Respectable</ent><br/
<hw>Re*spect"a*ble</hw> <pr>(-<?/-b'l)</pr>, <pos>a.</pos> <ety>[F.
<ets>respectable</ets>, LL. <ets>respectabilis</ets>.]</ety> <sn>1.</sn>
<def>Worthy of respect; fitted to awaken esteem; deserving regard;
hence, of good repute; not mean; <as>as, a <ex>respectable</ex>
citizen</as>.</def> <ldquo/The <xex>respectable</xex> quarter of
Sicca.<rdquo/ <rj><au>J. H. Newman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>No government, any more than an individual, will long be
respected, without being truly <qex>respectable</qex>.</q>
<rj><qau>Madison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Moderate in degree of excellence or in number;
<as>as, a <ex>respectable</ex> performance; a <ex>respectable</ex>
audience</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p>--<wordforms><wf>Re*spect"a*ble*ness</wf>,<pos>n.</pos> --
<wf>Re*spect"a*bly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Respectant</ent><br/
<hw>Re*spect"ant</hw> <pr>(-<it>a</it>nt)</pr>, <pos>a.</pos> <ety>[F.,
p. pr. of <ets>respecter</ets>. See <er>Respect</er>.]</ety>
<fld>(Her.)</fld> <def>Placed so as to face one another; -- said of
animals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Respecter</ent><br/
<hw>Re*spect"er</hw> <pr>(-?r)</pr>, <pos>n.</pos> <def>One who
respects.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>A respecter of persons</b></col>, <cd>one who regards or
judges with partiality.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><q>Of a truth I perceive that God is no <qex>respecter of
persons</qex>.</q> <rj><qau>Acts x. 34.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Respectful</ent><br/
<hw>Re*spect"ful</hw> <pr>(-f?l)</pr>, <pos>a.</pos> <def>Marked or
characterized by respect; <as>as, <ex>respectful</ex>
deportment</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With humble joy and with <qex>respectful</qex> fear.</q>
<rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Re*spect"ful*ly</wf>, <pos>adv.</pos> --
<wf>Re*spect"ful*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Respecting</ent><br/
<hw>Re*spect"ing</hw>, <pos>prep.</pos> <def>With regard or relation to;
regarding; concerning; <as>as, <ex>respecting</ex> his conduct there is
but one opinion</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Respection</ent><br/
<hw>Re*spec"tion</hw> <pr>(r<esl/*sp<ecr/k"sh<ucr/n)</pr>, <pos>n.</pos>
<ety>[Cf.LL. <ets>respectio</ets>.]</ety> <def>The act of respecting;
respect; regard.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Without difference or <qex>respection</qex> of persons.</q>
<rj><qau>Tyndale.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Respective</ent><br/
<hw>Re*spec"tive</hw> <pr>(r<esl/*sp<ecr/k"t<icr/v)</pr>, <pos>a.</pos>
<ety>[Cf. F. <ets>respectif</ets>, LL. <ets>respectivus</ets>. See
<er>Respect</er>.]</ety> <sn>1.</sn> <def>Noticing with attention;
hence, careful; wary; considerate.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>If you look upon the church of England with a
<qex>respective</qex> eye, you can not . . . refuse this charge.</q>
<rj><qau>A<?/p. Sandys.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Looking towardl having reference to; relative, not
absolute; <as>as, the <ex>respective</ex> connections of
society</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Relating to particular persons or things, each to
each; particular; own; <as>as, they returned to their
<ex>respective</ex> places of abode</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Fitted to awaken respect.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Rendering respect; respectful; regardful.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>With <qex>respective</qex> shame, rose, took us by the hands.</q>
<rj><qau>Chapman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>With thy equals familiar, yet <qex>respective</qex>.</q>
<rj><qau>Lord Burleigh.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Respectively</ent><br/
<hw>Re*spec"tive*ly</hw>, <pos>adv.</pos> <sn>1.</sn> <def>As relating
to each; particularly; as each belongs to each; as each refers to each
in order; <as>as, let each man <ex>respectively</ex> perform his
duty</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The impressions from the objects or the senses do mingle
<qex>respectively</qex> every one with its kind.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Relatively; not absolutely.</def>
<mark>[Obs.]</mark> <rj><au>Sir W. Raleigh.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Partially; with respect to private views.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>With respect; regardfully.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Respectless</ent><br/
<hw>Re*spect"less</hw> <pr>(r<esl/*sp<ecr/k"l<ecr/s)</pr>, <pos>a.</pos>
<def>Having no respect; without regard; regardless.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Rather than again<br/
Endure, <qex>respectless</qex>, their so moving cries.</q>
<rj><qau>Chapman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Re*spect"less*ness</wf>, <pos>n.</pos>
<mark>[R.]</mark></wordforms> <rj><au>Shelton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Respectuous</ent><br/
<hw>Re*spec"tu*ous</hw> <pr>(r?*sp?k"t?*?s;135)</pr>, <pos>a.</pos>
<sn>1.</sn> <def>Respectful; <as>as, a <ex>respectuous</ex>
silence</as>.</def> <mark>[Obs.]</mark> <rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Respectable.</def> <mark>[Obs.]</mark>
<rj><au>Knolles.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Respell</ent><br/
<hw>Re*spell"</hw> <pr>(r?*sp?l")</pr>, <pos>v. t.</pos> <def>To spell
again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resperse</ent><br/
<hw>Re*sperse"</hw> <pr>(r?*sp?rs")</pr>, <pos>v. t.</pos> <ety>[L.
<ets>respersus</ets>, p. p. of <ets>respergere</ets>; pref.
<ets>re-</ets> re- + <ets>spargere</ets> to srew, sprinkle.]</ety>
<def>To sprinkle; to scatter.</def> <mark>[Obs.]</mark> <rj><au>Jer.
Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Respersion</ent><br/
<hw>Re*sper"sion</hw> <pr>(r?*sp?r"sh?n)</pr>, <pos>n.</pos> <ety>[L.
<ets>respersio</ets>.]</ety> <def>The act of sprinkling or
scattering.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Respirability</ent><br/
<hw>Re*spir`a*bil"i*ty</hw> <pr>(r?*sp?r`?*b?l"?*t? <or/
r?s`p?*r?-)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>respirabilit<?/</ets>.]</ety> <def>The quality or state of being
respirable; respirableness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Respirable</ent><br/
<hw>Re*spir"a*ble</hw> <pr>(r?*sp?r"?*b'l <or/ r?s"p?*r?*b'l)</pr>,
<pos>a.</pos> <ety>[Cf. F. <ets>respirable</ets>.]</ety> <def>Suitable
for being breathed; adapted for respiration.</def> --
<wordforms><wf>Re*spir"a*ble*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Respiration</ent><br/
<hw>Res`pi*ra"tion</hw> <pr>(r?s`p?*r?"sh?n)</pr>, <pos>n.</pos>
<ety>[L. <ets>respiratio</ets>: cf. F. <ets>respiration</ets>. See
<er>Respire</er>.]</ety> <sn>1.</sn> <def>The act of respiring or
breathing again, or catching one's breath.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Relief from toil or suffering: rest.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Till the day<br/
Appear of <qex>respiration</qex> to the just<br/
And vengeance to the wicked.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Interval; intermission.</def> <mark>[Obs.]</mark>
<rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Physiol.)</fld> <def>The act of resping or
breathing; the act of taking in and giving out air; the aggregate of
those processes bu which oxygen is introduced into the system, and
carbon dioxide, or carbonic acid, removed.</def><br/
[<source>1913 Webster</source>]</p>

<note><p><hand/ Respiration in the higher animals is divided into:
(<stype>a</stype>) <xex>Internal respiration</xex>, or the interchange
of oxygen and carbonic acid between the cells of the body and the
bathing them, which in one sense is a process of nutrition.
(<stype>b</stype>) <xex>External respiration</xex>, or the gaseous
interchange taking place in the special respiratory organs, the lungs.
This constitutes respiration proper. <rj><au>Gamgee.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p> In the respiration of plants oxygen is likewise absorbed and
carbonic acid exhaled, but in the light this process is obscured by
another process which goes on with more vigor, in which the plant
inhales and absorbs carbonic acid and exhales free oxygen.<br/
[<source>1913 Webster</source>]</p></note>

<p><ent>Respirational</ent><br/
<hw>Res`pi*ra"tion*al</hw> <pr>(r?s`p?*r?"sh?n-<it>a</it>l)</pr>,
<pos>a.</pos> <def>Of or pertaining to respiration; <as>as,
<ex>respirational</ex> difficulties</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Respirative</ent><br/
<hw>Re*spir"a*tive</hw> <pr>(r?*sp?*r?*t?v)</pr>, <pos>a.</pos> <def>Of
or pertaining to respiration; <as>as, <ex>respirative</ex>
organs</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Respirator</ent><br/
<hw>Res"pi*ra`tor</hw> <pr>(r?s"p?*r?`t?r)</pr>, <pos>n.</pos> <ety>[Cf.
F. <ets>respirateur</ets>.]</ety> <def>A divice of gauze or wire,
covering the mouth or nose, to prevent the inhalation of noxious
substances, as dust or smoke. Being warmed by the breath, it tempers
cold air passing through it, and may also be used for the inhalation of
medicated vapors.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Respiratory</ent><br/
<hw>Re*spir"a*to*ry</hw> <pr>(r?*sp?r"?*t?*r? <or/ r?s"p?*r?-)</pr>,
<pos>a.</pos> <fld>(Physiol.)</fld> <def>Of or pertaining to
respiration; serving for respiration; <as>as, the <ex>respiratory</ex>
organs; <ex>respiratory</ex> nerves; the <ex>respiratory</ex> function;
<ex>respiratory</ex> changes.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Respiratory foods</b></col>. <fld>(Physiol.)</fld>
<cd>See 2d Note under <er>Food</er>, <pos>n.</pos>, 1.</cd> --
<col><b>Respiratory tree</b></col> <fld>(Zool.)</fld>, <cd>the branched
internal gill of certain holothurians.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Respire</ent><br/
<hw>Re*spire"</hw> <pr>(r?*sp?r)</pr>, <pos>v. i.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Respired</conjf>
<pr>(-sp?rd")</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Respiring</conjf>.]</vmorph> <ety>[L. <ets>respirare</ets>,
<ets>respiratum</ets>; pref. <ets>re-</ets> re- + <ets>spirare</ets> to
breathe: cf. F. <ets>respirer</ets>. See <er>Spirit</er>.]</ety>
<sn>1.</sn> <def>To take breath again; hence, to take rest or
refreshment.</def> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Here leave me to <qex>respire</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>From the mountains where I now <qex>respire</qex>.</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Physiol.)</fld> <def>To breathe; to inhale air into
the lungs, and exhale it from them, successively, for the purpose of
maintaining the vitality of the blood.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Respire</ent><br/
<hw>Re*spire"</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To breathe in and
out; to inspire and expire,, as air; to breathe.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A native of the land where I <qex>respire</qex><br/
The clear air for a while.</q> <rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To breathe out; to exhale.</def> <mark>[R.]</mark>
<rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Respite</ent><br/
<hw>Res"pite</hw> <pr>(r?s"p?t)</pr>, <pos>n.</pos> <ety>[OF.
<ets>respit</ets>, F. <ets>r<eacute/pit</ets>, from L.
<ets>respectus</ets> respect, regard, delay, in LL., the deferring of a
day. See <er>Respect</er>.]</ety> <sn>1.</sn> <def>A putting off of that
which was appointed; a postponement or delay.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I crave but four day's <qex>respite</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Temporary intermission of labor, or of any process
or operation; interval of rest; pause; delay.</def> <ldquo/Without more
<xex>respite</xex>.<rdquo/ <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Some pause and <qex>respite</qex> only I require.</q>
<rj><qau>Denham.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Law)</fld> <sd>(a)</sd> <def>Temporary suspension
of the execution of a capital offender; reprieve.</def> <sd>(b)</sd>
<def>The delay of appearance at court granted to a jury beyond the
proper term.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Pause; interval; stop; cessation; delay;
postponement; stay; reprieve.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Respite</ent><br/
<hw>Res"pite</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Respited</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Respiting</conjf>.]</vmorph> <ety>[OF. <ets>respiter</ets>, LL.
<ets>respectare</ets>. See <er>Respite</er>, <pos>n.</pos>]</ety>
<def>To give or grant a respite to.</def> Specifically: <sd>(a)</sd>
<def>To delay or postpone; to put off.</def> <sd>(b)</sd> <def>To keep
back from execution; to reprieve.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Forty days longer we do <qex>respite</qex> you.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(c)</sd> <def>To relieve by a pause or interval of rest.</def>
<ldquo/To <xex>respite</xex> his day labor with repast.<rdquo/
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Respiteless</ent><br/
<hw>Res"pite*less</hw>, <pos>a.</pos> <def>Without respite.</def>
<rj><au>Baxter.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resplendency</ent><br/
<ent>Resplendence</ent><br/
<mhw>{ <hw>Re*splen"dence</hw> <pr>(r?*spl?n"d<it>e</it>ns)</pr>,
<hw>Re*splen"den*cy</hw> <pr>(-d<it>e</it>n*s?)</pr>, }</mhw>
<pos>n.</pos> <ety>[L. <ets>resplendentia</ets>.]</ety> <def>The quality
or state of being resplendent; brilliant luster; vivid brightness;
splendor.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Son! thou in whom my glory I behold<br/
In full <qex>resplendence</qex>, heir of all my might.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>resplendency</qex> of his own almighty goodness.</q>
<rj><qau>Dr. J. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resplendent</ent><br/
<hw>Re*splen"dent</hw> <pr>(-d<it>e</it>nt)</pr>, <pos>a.</pos> <ety>[L.
<ets>resplendens</ets>, <ets>-entis</ets>, p. pr. of
<ets>resplendere</ets> to shine brightly; pref. <ets>re-</ets> re- +
<ets>splendere</ets> to shine. See <er>Splendid</er>.]</ety>
<def>Shining with brilliant luster; very bright.</def> --
<wordforms><wf>Re*splen"dent*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><q>With royal arras and <qex>resplendent</qex> gold.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resplendishant</ent><br/
<hw>Re*splen"dish*ant</hw> <pr>(-d?sh*<it>a</it>nt)</pr>, <pos>a.</pos>
<def>Resplendent; brilliant.</def> <mark>[R. & Obs.]</mark>
<rj><au>Fabyan.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resplendishing</ent><br/
<hw>Re*splen"dish*ing</hw>, <pos>a.</pos> <def>Resplendent.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resplit</ent><br/
<hw>Re*split"</hw> <pr>(r<esl/*spl<icr/t")</pr>, <pos>v. t. & i.</pos>
<def>To split again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Respond</ent><br/
<hw>Re*spond"</hw> <pr>(r<esl/*sp<ocr/nd")</pr>, <pos>v. i.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Responded</conjf>; <pos>p. pr. &
vb. n.</pos> <conjf>Responding</conjf>.]</vmorph> <ety>[OF.
<ets>respondre</ets>, F. <ets>r<eacute/pondre</ets>, fr. L.
<ets>respondere</ets>, <ets>responsum</ets>; pref. <ets>re-</ets> re- +
<ets>spondere</ets> to promise. See <er>Sponsor</er>.]</ety> <sn>1.</sn>
<def>To say something in return; to answer; to reply; <as>as, to
<ex>respond</ex> to a question or an argument</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To show some effect in return to a force; to act in
response; to accord; to correspond; to suit.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A new affliction strings a new cord in the heart, which
<qex>responds</qex> to some new note of complaint within the wide scale
of human woe.</q> <rj><qau>Buckminster.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To every theme <qex>responds</qex> thy various lay.</q>
<rj><qau>Broome.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To render satisfaction; to be answerable; <as>as,
the defendant is held to <ex>respond</ex> in damages</as>.</def>
<mark>[U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To answer; reply; rejoin. See
<er>Reply</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Respond</ent><br/
<hw>Re*spond"</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To answer; to
reply.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To suit or accord with; to correspond to.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>For his great deeds <qex>respond</qex> his speeches great.</q>
<rj><qau>Fairfax.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Respond</ent><br/
<hw>Re*spond"</hw>, <pos>n.</pos> <sn>1.</sn> <def>An answer; a
response.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Eccl.)</fld> <def>A short anthem sung at intervals
during the reading of a chapter.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Arch.)</fld> <def>A half pier or pillar attached to
a wall to support an arch.</def> <rj><au>Oxf. Gloss.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Respondency</ent><br/
<ent>Respondence</ent><br/
<mhw>{ <hw>Re*spond"ence</hw> <pr>(-<it>?</it>ns)</pr>,
<hw>Re*spond"en*cy</hw> <pr>(-<it>e</it>n*s?)</pr>, }</mhw>
<pos>n.</pos> <def>The act of responding; the state of being respondent;
an answering.</def> <rj><au>A. Chalmers.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The angelical soft trembling voice made<br/
To the instruments divine <qex>respondence</qex> meet.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Respondent</ent><br/
<hw>Re*spond"ent</hw> <pr>(-<it>e</it>nt)</pr>, <pos>a.</pos> <ety>[L.
<ets>respondens</ets>, p. pr. of <ets>respondere</ets>.]</ety>
<def>Disposed or expected to respond; answering; according;
corresponding.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Wealth <qex>respondent</qex> to payment and contributions.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Respondent</ent><br/
<hw>Re*spond"ent</hw>, <pos>n.</pos> <ety>[Cf. F.
<ets>r<eacute/pondant</ets>.]</ety> <def>One who responds. It
corresponds in general to <xex>defendant</xex>.</def> Specifically:
<sd>(a)</sd> <fld>(Law)</fld> <def>One who answers in certain suits or
proceedings, generally those which are not according to the course of
the common law, as in equity and admiralty causes, in petitions for
partition, and the like; -- distinquished from
<xex>appellant</xex>.</def> <sd>(b)</sd> <def>One who maintains a thesis
in reply, and whose province it is to refute objections, or overthrow
arguments; -- distinguished from <xex>opponent</xex>.</def> <rj><au>I.
Watts. </au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1228 --></p>

<p><ent>Respondentia</ent><br/
\'d8<hw>Re`spon*den"ti*a</hw> <pr>(r?`sp?n*d?n"sh?*?)</pr>,
<pos>n.</pos> <ety>[NL. See <er>Respondence</er>.]</ety>
<fld>(Commercial Law)</fld> <def>A loan upon goods laden on board a
ship. It differs from <xex>bottomry</xex>, which is a loan on the ship
itself.</def> <rj><au>Bouvier.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Responsal</ent><br/
<hw>Re*spon"sal</hw> <pr>(r?*sp?n"s<it>a</it>l)</pr>, <pos>a.</pos>
<def>Answerable.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Responsal</ent><br/
<hw>Re*spon"sal</hw>, <pos>n.</pos> <ety>[Cf.LL.
<ets>resposalis</ets>.]</ety> <sn>1.</sn> <def>One who is answerable or
responsible.</def> <mark>[Obs.]</mark> <rj><au>Barrow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Response.</def> <mark>[Obs.]</mark>
<rj><au>Brevint.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Response</ent><br/
<hw>Re*sponse"</hw> <pr>(r?*sp?ns")</pr>, <pos>n.</pos> <ety>[OF.
<ets>response</ets>, <ets>respons</ets>, F. <ets>r<eacute/ponse</ets>,
from L. <ets>responsum</ets>, from <ets>respondere</ets>. See
<er>Respond</er>.]</ety> <sn>1.</sn> <def>The act of
responding.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An answer or reply.</def> Specifically: <sd>(a)</sd>
<def>Reply to an objection in formal disputation.</def> <au>I.
Watts.</au> <sd>(b)</sd> <fld>(Eccl.)</fld> <def>The answer of the
people or congregation to the priest or clergyman, in the litany and
other parts of divine service.</def> <sd>(c)</sd> <fld>(R.C.Ch.)</fld>
<def>A kind of anthem sung after the lessons of matins and some other
parts of the office.</def> <sd>(d)</sd> <fld>(Mus.)</fld> <def>A
repetition of the given subject in a fugue by another part on the fifth
above or fourth below.</def> <au>Busby.</au><br/
[<source>1913 Webster</source>]</p>

<p><ent>Responseless</ent><br/
<hw>Re*sponse"less</hw>, <pos>a.</pos> <def>Giving no
response.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Responsibility</ent><br/
<hw>Re*spon`si*bil"i*ty</hw> <pr>(r?*sp?n`s?*b?l"?*t?)</pr>,
<pos>n.</pos>; <plu><it>pl.</it> <plw>-ties</plw>
<pr>(-t<?/z)</pr>.</plu> <ety>[Cf. F.
<ets>responsabilit<eacute/</ets>.]</ety> <sn>1.</sn> <def>The state of
being responsible, accountable, or answerable, as for a trust, debt, or
obligation.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That for which anyone is responsible or accountable;
<as>as, the <ex>resonsibilities</ex> of power</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Ability to answer in payment; means of
paying.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Responsible</ent><br/
<hw>Re*spon"si*ble</hw> <pr>(r?*sp?n"s?*b'l)</pr>, <pos>a.</pos>
<ety>[Cf. F. <ets>responsable</ets>. See <er>Respond</er>.]</ety>
<sn>1.</sn> <def>Liable to respond; likely to be called upon to answer;
accountable; answerable; amenable; <as>as, a guardian is
<ex>responsible</ex> to the court for his conduct in the
office</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Able to respond or answer for one's conduct and
obligations; trustworthy, financially or otherwise; <as>as, to have a
<ex>responsible</ex> man for surety</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Involving responsibility; involving a degree of
accountability on the part of the person concerned; <as>as, a
<ex>responsible</ex> office</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Accountable; answerable; amenable.</syn><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Re*spon"si*ble*ness</wf>, <pos>n.</pos> --
<wf>Re*spon"si*bly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Responsion</ent><br/
<hw>Re*spon"sion</hw> <pr>(-sh?n)</pr>, <pos>n.</pos> <ety>[L.
<ets>responsio</ets>. See <er>Respond</er>.]</ety> <sn>1.</sn> <def>The
act of answering.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(University of Oxford)</fld> <def>The first
university examination; -- called also <altname>little go</altname>. See
under <er>Little</er>, <pos>a.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Responsive</ent><br/
<hw>Re*spon"sive</hw> <pr>(-s?v)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>resposif</ets>.]</ety> <sn>1.</sn> <def>That responds; ready or
inclined to respond.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Suited to something else; correspondent.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The vocal lay <qex>responsive</qex> to the strings.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Responsible.</def> <mark>[Obs.]</mark> <rj><au>Jer.
Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Re*spon"sive*ly</wf>, <pos>adv.</pos> --
<wf>Re*spon"sive*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Responsorial</ent><br/
<hw>Re`spon*so"ri*al</hw> <pr>(r?`sp?n*s?"r?-<it>a</it>l)</pr>,
<pos>a.</pos> <def>Responsory; antiphonal.</def> <rj><au>J. H.
Newman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Responsory</ent><br/
<hw>Re*spon"so*ry</hw> <pr>(r?*sp?n"s?*r?)</pr>, <pos>a.</pos>
<def>Containing or making answer; answering.</def>
<rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Responsory</ent><br/
<hw>Re*spon"so*ry</hw>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>-ries</plw> <pr>(-r<?/z)</pr>.</plu> <ety>[LL.
<ets>responsorium</ets>.]</ety> <sn>1.</sn> <fld>(Eccl.)</fld>
<sd>(a)</sd> <def>The answer of the people to the priest in alternate
speaking, in church service.</def> <sd>(b)</sd> <def>A versicle sung in
answer to the priest, or as a refrain.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Which, if should repeat again, would turn my answers into
<qex>responsories</qex>, and beget another liturgy.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Eccl.)</fld> <def>An antiphonary; a response
book.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ressaldar</ent><br/
\'d8<hw>Res"sal*dar</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Hind.
<ets>ris<amac/ld<amac/r</ets>, fr. <ets>ris<amac/lt<amac/</ets>troop of
horse + Per. <ets>d<amac/r</ets> holding.]</ety> <fld>(Mil.)</fld>
<def>In the Anglo-Indian army, a native commander of a
ressala.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Rest</ent><br/
<hw>Rest</hw> <pr>(r<ecr/st)</pr>, <pos>v. t.</pos> <ety>[For
<ets>arrest</ets>.]</ety> <def>To arrest.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rest</ent><br/
<hw>Rest</hw>, <pos>n.</pos> <ety>[AS. <ets>rest</ets>,
<ets>r<ae/st</ets>, rest; akin to D. <ets>rust</ets>, G.
<ets>rast</ets>. OHG. <ets>rasta</ets>, Dan. & Sw. <ets>rast</ets> rest,
repose, Icel. <ets>r<oum/st</ets> the distance between two resting
places, a mole, Goth. <ets>rasta</ets> a mile, also to Goth.
<ets>razn</ets> house, Icel. <ets>rann</ets>, and perhaps to G.
<ets>ruhe</ets> rest, repose, AS. <ets>r<omac/w</ets>, Gr.
<grk>'erwh`</grk>. Cf. <er>Ransack</er>.]</ety> <sn>1.</sn> <def>A state
of quiet or repose; a cessation from motion or labor; tranquillity;
<as>as, <ex>rest</ex> from mental exertion; <ex>rest</ex> of body or
mind</as>.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Sleep give thee all his <qex>rest</qex>!</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence, freedom from everything which wearies or
disturbs; peace; security.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And the land had <qex>rest</qex> fourscore years.</q>
<rj><qau>Judges iii. 30.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Sleep; slumber; hence, poetically, death.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>How sleep the brave who sink to <qex>rest</qex>,<br/
By all their country's wishes blest.</q>
<rj><qau>Collins.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>That on which anything rests or leans for support;
<as>as, a <ex>rest</ex> in a lathe, for supporting the cutting tool or
steadying the work</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He made narrowed <qex>rests</qex> round about, that the beams
should not be fastened in the walls of the house.</q> <rj><qau>1 Kings
vi. 6.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Anc. Armor)</fld> <def>A projection from the right
side of the cuirass, serving to support the lance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Their visors closed, their lances in the <qex>rest</qex>.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>A place where one may rest, either temporarily, as
in an inn, or permanently, as, in an abode.</def> <ldquo/Halfway houses
and travelers' <xex>rests</xex>.<rdquo/ <rj><au>J. H.
Newman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>In dust our final <qex>rest</qex>, and native home.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Ye are not as yet come to the <qex>rest</qex> and to the
inheritance which the Lord your God giveth you.</q> <rj><qau>Deut. xii.
9.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Pros.)</fld> <def>A short pause in reading verse; a
caesura.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>The striking of a balance at regular intervals in a
running account.</def> <ldquo/An account is said to be taken with annual
or semiannual <xex>rests</xex>.<rdquo/ <rj><au>Abbott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>A set or game at tennis.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <fld>(Mus.)</fld> <def>Silence in music or in one of its
parts; the name of the character that stands for such silence. They are
named as notes are, <xex>whole</xex>, <xex>half</xex>,
<xex>quarter</xex>,etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Rest house</b></col>, <cd>an empty house for the
accomodation of travelers; a caravansary.</cd> <mark>[India]</mark> --
<mcol><col><b>To set one's rest</b></col> <it>or</it> <col><b>To set up
one's rest</b></col></mcol>, <cd>to have a settled determination; --
from an old game of cards, when one so expressed his intention to stand
or rest upon his hand.</cd> <mark>[Obs.]</mark> <au>Shak.</au>
<au>Bacon.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Cessation; pause; intermission; stop; stay;
repose; slumber; quiet; ease; quietness; stillness; tranquillity;
peacefulness; peace.</syn> <usage> -- <er>Rest</er>, <er>Repose</er>.
<xex>Rest</xex> is a ceasing from labor or exertion; <xex>repose</xex>
is a mode of resting which gives relief and refreshment after toil and
labor. The words are commonly interchangeable.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rest</ent><br/
<hw>Rest</hw> <pr>(r<ecr/st)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Rested</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Resting</conjf>.]</vmorph> <ety>[AS. <ets>restan</ets>. See
<er>Rest</er>, <pos>n.</pos>]</ety> <sn>1.</sn> <def>To cease from
action or motion, especially from action which has caused weariness; to
desist from labor or exertion.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>God . . . <qex>rested</qex> on the seventh day from all his work
which he had made.</q> <rj><qau>Gen. ii. 2.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Six days thou shalt do thy work, and on the seventh day thou shalt
<qex>rest</qex>.</q> <rj><qau>Ex. xxiii. 12.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To be free from whatever wearies or disturbs; to be
quiet or still.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There <qex>rest</qex>, if any rest can harbor there.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To lie; to repose; to recline; to lan; <as>as, to
<ex>rest</ex> on a couch</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To stand firm; to be fixed; to be supported; <as>as,
a column <ex>rests</ex> on its pedestal</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To sleep; to slumber; hence, poetically, to be
dead.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Fancy . . . then retries<br/
Into her private cell when Nature <qex>rests</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To lean in confidence; to trust; to rely; to repose
without anxiety; <as>as, to <ex>rest</ex> on a man's
promise</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>On him I <qex>rested</qex>, after long debate,<br/
And not without considering, fixed my fate.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>To be satisfied; to acquiesce.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>rest</qex> in Heaven's determination.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To rest with</b></col>, <cd>to be in the power of; to
depend upon; as, it <xex>rests with</xex> him to decide.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rest</ent><br/
<hw>Rest</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To lay or place at
rest; to quiet.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Your piety has paid<br/
All needful rites, to <qex>rest</qex> my wandering shade.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To place, as on a support; to cause to
lean.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Her weary head upon your bosom <qex>rest</qex>.</q>
<rj><qau>Waller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rest</ent><br/
<hw>Rest</hw>, <pos>n.</pos> <ety>[F. <ets>reste</ets>, fr.
<ets>rester</ets> to remain, L. <ets>restare</ets> to stay back, remain;
pref. <ets>re-</ets> re- + <ets>stare</ets> to stand, stay. See
<er>Stand</er>, and cf. <er>Arrest</er>, <er>Restive</er>.]</ety> (With
the definite article.) <sn>1.</sn> <def>That which is left, or which
remains after the separation of a part, either in fact or in
contemplation; remainder; residue.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Religion gives part of its reward in hand, the present comfort of
having done our duty, and, for the <qex>rest</qex>, it offers us the
best security that Heaven can give.</q>
<rj><qau>Tillotson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Those not included in a proposition or description;
the remainder; others.</def> <ldquo/Plato and the <xex>rest</xex> of the
philosophers.<rdquo/ <rj><au>Bp. Stillingfleet.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Armed like the <qex>rest</qex>, the Trojan prince appears.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Com.)</fld> <def>A surplus held as a reserved fund
by a bank to equalize its dividends, etc.; in the Bank of England, the
balance of assets above liabilities.</def> <mark>[Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Remainder; overplus; surplus; remnant; residue;
reserve; others.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rest</ent><br/
<hw>Rest</hw>, <pos>v. i.</pos> <ety>[F. <ets>rester</ets>. See
<er>Rest</er> remainder.]</ety> <def>To be left; to remain; to continue
to be.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The affairs of men <qex>rest</qex> still uncertain.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Restagnant</ent><br/
<hw>Re*stag"nant</hw> <pr>(r<esl/*st<acr/g"n<ait/nt)</pr>, <pos>a.</pos>
<ety>[L. <ets>restagnans</ets>, p. pr. ]</ety> <def>Stagnant;
motionless.</def> <mark>[Obs.]</mark> <rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Restagnate</ent><br/
<hw>Re*stag"nate</hw> <pr>(r<esl/*st<acr/g"n<amac/t)</pr>, <pos>v.
i.</pos> <ety>[L. <ets>restagnare</ets> to overflow.]</ety> <def>To
stagnate; to cease to flow.</def> <mark>[Obs.]</mark>
<rj><au>Wiseman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Restagnation</ent><br/
<hw>Re`stag*na"tion</hw> <pr>(r<esl/`st<acr/g*n<amac/"sh<ucr/n)</pr>,
<pos>n.</pos> <ety>[L. <ets>restagnatio</ets> an inundation.]</ety>
<def>Stagnation.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Restant</ent><br/
<hw>Res"tant</hw> <pr>(r<ecr/s"t<ait/nt)</pr>, <pos>a.</pos> <ety>[L.
<ets>restans</ets>, p. pr. of <ets>restare</ets>: cf. F.
<ets>restant</ets>. See <er>Rest</er> remainder.]</ety>
<fld>(Bot.)</fld> <def>Persistent.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Restate</ent><br/
<hw>Re*state"</hw> <pr>(r<emac/*st<amac/t")</pr>, <pos>v. t.</pos>
<def>To state anew.</def> <rj><au>Palfrey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Restaurant</ent><br/
<hw>Res"tau*rant</hw> <pr>(r<ecr/s"t<osl/*r<adot/nt; 277)</pr>,
<pos>n.</pos> <ety>[F., fr. <ets>restaurer</ets>. See
<er>Restore</er>.]</ety> <def>An eating house.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Restaurate</ent><br/
<hw>Res"tau*rate</hw> <pr>(r?s"t?*r?t)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>restauratus</ets>, p. p. of <ets>restaurare</ets>. See
<er>Restore</er>.]</ety> <def>To restore.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Restaurateur</ent><br/
\'d8<hw>Re`stau`ra`teur"</hw>
<pr>(r<asl/`st<omac/`r<adot/`t<etil/r")</pr>, <pos>n.</pos>
<ety>[F.]</ety> <def>The keeper of an eating house or a
restaurant.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Restauration</ent><br/
<hw>Res`tau*ra"tion</hw> <pr>(r?s`t?*r?"sh?n)</pr>, <pos>n.</pos>
<ety>[LL. <ets>restauratio</ets>: cf. F. <ets>restauration</ets>.]</ety>
<def>Restoration.</def> <mark>[Obs.]</mark> <rj><au>Cower.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rest cure</ent><br/
<hw>Rest cure</hw>. <fld>(Med.)</fld> <def>Treatment of severe nervous
disorder, as neurasthenia, by rest and isolation with systematic feeding
and the use of massage and electricity.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Restem</ent><br/
<hw>Re*stem"</hw> <pr>(r<esl/*st<ecr/m")</pr>, <pos>v. t.</pos>
<sn>1.</sn> <def>To force back against the current; <as>as, to
<ex>restem</ex> their backward course</as>.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To stem, or move against; <as>as, to <ex>restem</ex>
a current</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Restful</ent><br/
<hw>Rest"ful</hw> <pr>(r?st"f?l)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Being at rest; quiet.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Giving rest; freeing from toil, trouble,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Tired with all these, for <qex>restful</qex> death I cry.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Rest"ful*ly</wf>, <pos>adv.</pos> --
<wf>Rest"ful*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rest-harrow</ent><br/
<hw>Rest"-har`row</hw> <pr>(-h?r`r?)</pr>, <pos>n.</pos>
<fld>(Bot.)</fld> <def>A European leguminous plant (<spn>Ononis
arvensis</spn>) with long, tough roots.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Restiff</ent><br/
<hw>Rest"iff</hw>, <pos>a.</pos> <def>Restive.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Restiff</ent><br/
<hw>Rest"iff</hw>, <pos>n.</pos> <def>A restive or stubborn horse.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Restiffness</ent><br/
<hw>Rest"iff*ness</hw>, <pos>n.</pos> <def>Restiveness.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Restiform</ent><br/
<hw>Res"ti*form</hw> <pr>(r<ecr/s"t<icr/*f<ocir/rm)</pr>,
<pos>a.</pos><ety>[L. <ets>restis</ets> rope + <ets>-form</ets>.]</ety>
<fld>(Anat.)</fld> <def>Formed like a rope; -- applied especially to
several ropelike bundles or masses of fibers on the dorsal side of the
medulla oblongata.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Restily</ent><br/
<hw>Rest"i*ly</hw> <pr>(r<ecr/st"<icr/*l<ycr/)</pr>, <pos>adv.</pos>
<def>In a resty manner.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Restinction</ent><br/
<hw>Re*stinc"tion</hw> <pr>(r?*st?nk"sh?n)</pr>, <pos>n.</pos><ety>[L.
<ets>restinctio</ets>. See <er>Restinguish</er>.]</ety> <def>Act of
quenching or extingishing.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Restiness</ent><br/
<hw>Rest"i*ness</hw> <pr>(r?st`<icr/*n?s)</pr>, <pos>n.</pos> <def>The
quality or state of being resty; sluggishness.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The snake by <qex>restiness</qex> and lying still all winter.</q>
<rj><qau>Holland.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resting</ent><br/
<hw>Rest"ing</hw>, <def><pos>a. & n.</pos> from <er>Rest</er>, <pos>v.
t. & i.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Resting spore</b></col> <fld>(Bot.)</fld>, <cd>a spore in
certain orders of algae, which remains quiescent, retaining its
vitality, for long periods of time.</cd> <rj><au>C. E.
Bessey.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Restinguish</ent><br/
<hw>Re*stin"guish</hw> <pr>(r?*st?n"gw?sh)</pr>, <pos>v. t.</pos>
<ety>[L. <ets>restinquere</ets>, <ets>restinctum</ets>; pref.
<ets>re-</ets> re- + <ets>stinquere</ets> to quench.]</ety> <def>To
quench or extinguish.</def> <mark>[Obs.]</mark> <rj><au>R.
Field.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Restitute</ent><br/
<hw>Res"ti*tute</hw> <pr>(r?s"t?*t?t)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>restitutus</ets>, p. p. of <ets>restituere</ets>; pref.
<ets>re-</ets> re- + <ets>statuere</ets> to put, place. See
<er>Statute</er>.]</ety> <def>To restore to a former state.</def>
<mark>[R.]</mark> <rj><au>Dyer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Restitute</ent><br/
<hw>Res"ti*tute</hw>, <pos>n.</pos> <def>That which is restored or
offered in place of something; a substitute.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Restitution</ent><br/
<hw>Res`ti*tu"tion</hw> <pr>(r?s`t?*t?"sh?n)</pr>, <pos>n.</pos>
<ety>[F. <ets>restitution</ets>, L. <ets>restitutio</ets>. See
<er>Restitute</er>, <pos>v.</pos>]</ety> <sn>1.</sn> <def>The act of
restoring anything to its rightful owner, or of making good, or of
giving an equivalent for any loss, damage, or injury;
indemnification.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>restitution</qex> of ancient rights unto the crown.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He <qex>restitution</qex> to the value makes.</q>
<rj><qau>Sandys.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is offered or given in return for what
has been lost, injured, or destroyed; compensation.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Physics)</fld> <def>The act of returning to, or
recovering, a former state; <as>as, the <ex>restitution</ex> of an
elastic body</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Med.)</fld> <def>The movement of rotation which
usually occurs in childbirth after the head has been delivered, and
which causes the latter to point towards the side to which it was
directed at the beginning of labor.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Restoration; return; indemnification; reparation;
compensation; amends; remuneration.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Restitutor</ent><br/
<hw>Res"ti*tu`tor</hw> <pr>(r?s"t?*t?`t?r)</pr>, <pos>n.</pos> <ety>[L.:
cf. F. <ets>restituteur</ets>.]</ety> <def>One who makes
restitution.</def> <mark>[R]</mark>.<br/
[<source>1913 Webster</source>]</p>

<p><ent>Restive</ent><br/
<hw>Rest"ive</hw> <pr>(r?st"?v)</pr>, <pos>a.</pos> <ety>[OF.
<ets>restif</ets>, F. <ets>r<eacute/tif</ets>, fr. L. <ets>restare</ets>
to stay back, withstand, resist. See <er>Rest</er> remainder, and cf.
<er>Restiff</er>.]</ety> . <def>Unwilling to go on; obstinate in
refusing to move forward; stubborn; drawing back.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Restive</qex> or resty, drawing back, instead of going
forward, as some horses do.</q> <rj><qau>E. Philips
(1658).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The people remarked with awe and wonder that the beasts which were
to drag him [Abraham Holmes] to the gallows became <qex>restive</qex>,
and went back.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Inactive; sluggish.</def> <mark>[Obs.]</mark>
<rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Impatient under coercion, chastisement, or
opposition; refractory.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Uneasy; restless; averse to standing still;
fidgeting about; -- applied especially to horses.</def>
<rj><au>Trench.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Rest"ive</wf>, <pos>adv.</pos> --
<wf>Rest"ive*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Restless</ent><br/
<hw>Rest"less</hw>, <pos>a.</pos> <ety>[AS.
<ets>restle<aacute/s</ets>.]</ety> <sn>1.</sn> <def>Never resting;
unquiet; uneasy; continually moving; <as>as, a <ex>restless</ex>
child</as>.</def> <au>Chaucer.</au> <ldquo/<xex>Restless</xex>
revolution day by day.<rdquo/ <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Not satisfied to be at rest or in peace; averse to
repose or quiet; eager for change; discontented; <as>as,
<ex>restless</ex> schemers; <ex>restless</ex> ambition;
<ex>restless</ex> subjects</as>.</def> <ldquo/<xex>Restless</xex> at
home , and ever prone to range.<rdquo/ <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Deprived of rest or sleep.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Restless</qex> he passed the remnants of the night.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Passed in unquietness; <as>as, the patient has had a
<ex>restless</ex> night</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Not affording rest; <as>as, a <ex>restless</ex>
chair</as>.</def> <rj><au>Cowper.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Restless thrush</b></col>. <fld>(Zool.)</fld> <cd>See
<er>Grinder</er>, 3.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Unquiet; uneasy; disturbed; disquieted;
sleepless; agitated; unsettled; roving; wandering.</syn><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Rest"less*ly</wf>, <pos>adv.</pos>-
<wf>Rest"less*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Restorable</ent><br/
<hw>Re*stor"a*ble</hw> <pr>(r?*st?r"?*b'l)</pr>, <pos>a.</pos>
<def>Admitting of being restored; capable of being reclaimed; <as>as,
<ex>restorable</ex> land</as>.</def> <au>Swift.</au> --
<wordforms><wf>Re*stor"a*ble*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Restoral</ent><br/
<hw>Re*stor"al</hw> <pr>(-<it>a</it>l)</pr>, <pos>n.</pos>
<def>Restoration.</def> <mark>[Obs.]</mark>
<rj><au>Barrow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Restoration</ent><br/
<hw>Res`to*ra"tion</hw> <pr>(r?s`t?*r?"sh?n)</pr>, <pos>n.</pos>
<ety>[OE. <ets>restauracion</ets>, F. <ets>restauration</ets>, fr. L.
<ets>restauratio</ets>. See <er>Restore</er>.]</ety> <sn>1.</sn>
<def>The act of restoring or bringing back to a former place, station,
or condition; the fact of being restored; renewal; reestablishment;
<as>as, the <ex>restoration</ex> of friendship between enemies; the
<ex>restoration</ex> of peace after war</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Behold the different climes agree,<br/
Rejoicing in thy <qex>restoration</qex>.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The state of being restored; recovery of health,
strength, etc.; <as>as, <ex>restoration</ex> from
sickness</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which is restored or renewed.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>The restoration</b></col> <fld>(Eng. Hist.)</fld>,
<cd>the return of King Charles II. in 1660, and the reestablishment of
monarchy.</cd> -- <col><b>Universal restoration</b></col>
<fld>(Theol.)</fld>, <cd>the final recovery of all men from sin and
alienation from God to a state of happiness; universal
salvation.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Recovery; replacement; renewal; renovation;
redintegration; reinstatement; reestablishment; return; revival;
restitution; reparation.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Restorationer</ent><br/
<hw>Res`to*ra"tion*er</hw> <pr>(-?r)</pr>, <pos>n.</pos> <def>A
Restorationist.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Restorationism</ent><br/
<hw>Res`to*ra"tion*ism</hw> <pr>(-?z'm)</pr>, <pos>n.</pos> <def>The
belief or doctrines of the Restorationists.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Restorationist</ent><br/
<hw>Res`to*ra"tion*ist</hw>, <pos>n.</pos> <def>One who believes in a
temporary future punishment and a final restoration of all to the favor
and presence of God; a Universalist.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Restorative</ent><br/
<hw>Re*stor"a*tive</hw> <pr>(r?*st?r"?*t?v)</pr>, <pos>a.</pos>
<ety>[Cf. F. <ets>restoratif</ets>.]</ety> <def>Of or pertaining to
restoration; having power to restore.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Destroys life's enemy,<br/
Hunger, with sweet <qex>restorative</qex> delight.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Restorative</ent><br/
<hw>Re*stor"a*tive</hw>, <pos>n.</pos> <def>Something which serves to
restore; especially, a restorative medicine.</def>
<rj><au>Arbuthnot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Restoratively</ent><br/
<hw>Re*stor"a*tive*ly</hw>, <pos>adv.</pos> <def>In a restorative
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Restorator</ent><br/
<hw>Res"to*ra`tor</hw> <pr>(r?s"t?*r?`t?r)</pr>, <pos>n.</pos> <def>A
restaurateur.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Restoratory</ent><br/
<hw>Re*stor"a*to*ry</hw> <pr>(r?*st?r"?*t?*r?)</pr>, <pos>a.</pos>
<def>Restorative.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Re-store</ent><br/
<hw>Re-store"</hw> <pr>(r<emac/*st<omac/r")</pr>, <pos>v. t.</pos>
<ety>[Pref. <ets>re-</ets> + <ets>store</ets>.]</ety> <def>To store
again; <as>as, the goods taken out were
<ex>re-stored</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Restore</ent><br/
<hw>Re*store"</hw> <pr>(r<esl/*st<omac/r")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Restored</conjf>
<pr>(r<esl/*st<omac/rd")</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Restoring</conjf>.]</vmorph> <ety>[OE. <ets>restoren</ets>, OF.
<ets>restorer</ets>, F. <ets>restaurer</ets>, fr. L.
<ets>restaurare</ets>; pref. <ets>re-</ets> re- + an unused word; cf.
Gr. <grk>stayro`s</grk> an upright pale or stake, Skr.
<ets>sth<amac/vara</ets> fixed, firm. Cf. <er>Restaurant</er>,
<er>Store</er>.]</ety> <def>To bring back to its former state; to bring
back from a state of ruin, decay, disease, or the like; to repair; to
renew; to recover.</def> <ldquo/To <xex>restore</xex> and to build
Jerusalem.<rdquo/ <rj><au>Dan. ix. 25.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Our fortune <qex>restored</qex> after the severest
afflictions.</q> <rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And his hand was <qex>restored</qex> whole as the other.</q>
<rj><qau>Mark iii. 5.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To give or bring back, as that which has been lost.,
or taken away; to bring back to the owner; to replace.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Now therefore <qex>restore</qex> the man his wife.</q>
<rj><qau>Gen. xx. 7.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Loss of Eden, till one greater man<br/
<qex>Restore</qex> us, and regain the blissful seat.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The father banished virtue shall <qex>restore</qex>.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To renew; to reestablish; <as>as, to
<ex>restore</ex> harmony among those who are variance</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To give in place of, or as satisfaction
for.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He shall <qex>restore</qex> five oxen for an ox, and four sheep
for a sheep.</q> <rj><qau>Ex. xxii. 1.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1229 --></p>

<p><sn>5.</sn> <def>To make good; to make amends for.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>But if the while I think on thee, dear friend,<br/
All losses are <qex>restored</qex>, and sorrows end.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Fine Arts)</fld> <sd>(a)</sd> <def>To bring back
from a state of injury or decay, or from a changed condition; <as>as, to
<ex>restore</ex> a painting</as>, statue, etc.</def> <sd>(b)</sd>
<def>To form a picture or model of, as of something lost or mutilated;
<as>as, to <ex>restore</ex> a ruined building, city, or the
like</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To return; replace; refund; repay; reinstate;
rebuild; reestablish; renew; repair; revive; recover; heal;
cure.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Restore</ent><br/
<hw>Re*store"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Restoration.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Restorement</ent><br/
<hw>Re*store"ment</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Restoration.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Restorer</ent><br/
<hw>Re*stor"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, restores.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Restrain</ent><br/
<hw>Re*strain"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Restrained</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Restraining</conjf>.]</vmorph> <ety>[OE.
<ets>restreinen</ets>, F. <ets>restreindre</ets>, fr. L.
<ets>restringere</ets>, <ets>restrictum</ets>; pref. <ets>re-</ets> re-
+ <ets>stringere</ets> to draw, bind, or press together. See
<er>Strain</er>, <pos>v. t.</pos>, and cf. <er>Restrict</er>.]</ety>
<sn>1.</sn> <def>To draw back again; to hold back from acting,
proceeding, or advancing, either by physical or moral force, or by any
interposing obstacle; to repress or suppress; to keep down; to
curb.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Restrain</qex> in me the cursed thoughts that nature<br/
Gives way to in repose!</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To draw back toghtly, as a rein.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To hinder from unlimited enjoiment; to
abridge.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Though they two were committed, at least <qex>restrained</qex> of
their liberty.</q> <rj><qau>Clarendon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To limit; to confine; to restrict.</def>
<rj><au>Trench.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Not only a metaphysical or natural, but a moral, universality also
is to be <qex>restrained</qex> by a part of the predicate.</q>
<rj><qau>I. Watts.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To withhold; to forbear.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou <qex>restrained</qex> prayer before God.</q> <rj><qau>Job.
xv. 4.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To check; hinder; stop; withhold; repress; curb;
suppress; coerce; restrict; limit; confine.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Restrainable</ent><br/
<hw>Re*strain"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of
being restrained; controllable.</def> <rj><au>Sir T.
Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Restrainedly</ent><br/
<hw>Re*strain"ed*ly</hw>, <pos>adv.</pos> <def>With restraint.</def>
<rj><au>Hammond.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Restrainer</ent><br/
<hw>Re*strain"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, restrains.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Restrainment</ent><br/
<hw>Re*strain"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
restraining.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Restraint</ent><br/
<hw>Re*straint"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>restraincte</ets>, fr. <ets>restrainct</ets>, F.
<ets>restreint</ets>, p. p. of <ets>restraindre</ets>,
<ets>restrendre</ets>. See <er>Restrain</er>.]</ety> <sn>1.</sn>
<def>The act or process of restraining, or of holding back or hindering
from motion or action, in any manner; hindrance of the will, or of any
action, physical or mental.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>No man was altogether above the <qex>restrains</qex> of law, and
no man altogether below its protection.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The state of being restrained.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which restrains, as a law, a prohibition, or
the like; limitation; restriction.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>For one <qex>restraint</qex>, lords of the world besides.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Repression; hindrance; check; stop; curb;
coercion; confinement; limitation; restriction.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Restrengthen</ent><br/
<hw>Re*strength"en</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To
strengthen again; to fortify anew.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Restrict</ent><br/
<hw>Re*strict"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>restrictus</ets>, p. p. of <ets>restringere</ets>. See
<er>Restrain</er>.]</ety> <def>Restricted.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Restrict</ent><br/
<hw>Re*strict"</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Restricted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Restricting</conjf>.]</vmorph> <def>To restrain within bounds; to
limit; to confine; <as>as, to <ex>restrict</ex> worlds to a particular
meaning; to <ex>restrict</ex> a patient to a certain
diet.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To limit; bound; circumscribe; restrain; repress;
curb; coerce.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Restriction</ent><br/
<hw>Re*stric"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>restriction</ets>, L. <ets>restrictio</ets>.]</ety> <sn>1.</sn>
<def>The act of restricting, or state of being restricted; confinement
within limits or bounds.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This is to have the same <qex>restriction</qex> with all other
recreations,that it be made a divertisement.</q> <rj><qau>Giv. of
Tonque.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which restricts; limitation; restraint; <as>as,
<ex>restrictions</ex> on trade</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Restrictionary</ent><br/
<hw>Re*stric"tion*a*ry</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Restrictive.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Restrictive</ent><br/
<hw>Re*strict"ive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>restrictif</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Serving or tending to restrict; limiting; <as>as, a
<ex>restrictive</ex> particle; <ex>restrictive</ex> laws of
trade.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Astringent or styptic in effect.</def>
<mark>[Obs.]</mark> <rj><au>Wiseman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p>--<wordforms><wf>Re*strict"ive*ly</wf>, <pos>adv.</pos> --
<wf>Re*strict"ive*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Restringe</ent><br/
<hw>Re*stringe"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Restringed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Restringing</conjf> <pr>(?)</pr>.]</vmorph> <ety>[L.
<ets>restringere</ets>. See <er>Restrain</er>.]</ety> <def>To confine;
to contract; to stringe.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Restringency</ent><br/
<hw>Re*strin"gen*cy</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Quality or
state of being restringent; astringency.</def> <mark>[Obs.]</mark>
<rj><au>Sir W. Petty.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Restringent</ent><br/
<hw>Re*strin"gent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>restringens</ets>, p. pr.: cf. F. <ets>restringent</ets>.]</ety>
<def>Restringing; astringent; styptic.</def> <mark>[Obs.]</mark> --
<def2><pos>n.</pos> <def>A restringent medicine.</def></def2>
<mark>[Obs.]</mark> <rj><au>Harvey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Restrive</ent><br/
<hw>Re*strive"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To strive
anew.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resty</ent><br/
<hw>Rest"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Disposed to rest;
indisposed toexercton; sluggish; also, restive.</def>
<mark>[Obs.]</mark> <rj><au>Burton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Where the master is too <qex>resty</qex> or too rich to say his
own prayers.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resubjection</ent><br/
<hw>Re`sub*jec"tion</hw>, <pos>n.</pos> <def>A second
subjection.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resublime</ent><br/
<hw>Re`sub*lime"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To sublime
again.</def> <au>Newton.</au> -- <wordforms><wf>Re*sub`li*ma"tion</wf>
<pr>(#)</pr>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resudation</ent><br/
<hw>Re`su*da"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>resudare</ets> to sweat again. See <er>Sudation</er>.]</ety>
<def>Act of sweating again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Result</ent><br/
<hw>Re*sult"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Resulted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Resulting</conjf>.]</vmorph> <ety>[F. <ets>r<eacute/sulter</ets>,
fr. L. <ets>resultare</ets>, <ets>resultarum</ets>, to spring or leap
back, v. intens. fr. <ets>resilire</ets>. See <er>Resile</er>.]</ety>
<sn>1.</sn> <def>To leap back; to rebound.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The huge round stone, <qex>resulting</qex> with a bound.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To come out, or have an issue; to terminate; to have
consequences; -- followed by <xex>in</xex>; <as>as, this measure will
<ex>result</ex> in good or in evil</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To proceed, spring, or rise, as a consequence, from
facts, arguments, premises, combination of circumstances, consultation,
thought, or endeavor.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Pleasure and peace do naturally <qex>result</qex> from a holy and
good life.</q> <rj><qau>Tillotson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Resulting trust</b></col> <fld>(Law)</fld>, <cd>a trust
raised by implication for the benefit of a party granting an estate. The
phrase is also applied to a trust raised by implication for the benefit
of a party who advances the purchase money of an estate, etc.</cd>
<au>Bouvier.</au> -- <col><b>Resulting use</b></col> <fld>(Law)</fld>,
<cd>a use which, being limited by the deed, expires or can not vest, and
thence returns to him who raised it.</cd> <au>Bouvier.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To proceed; spring; rise; arise; ensue;
terminate.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Result</ent><br/
<hw>Re*sult"</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A flying
back; resilience.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Sound is produced between the string and the air by the return or
the <qex>result</qex> of the string.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which results; the conclusion or end to which
any course or condition of things leads, or which is obtained by any
process or operation; consequence or effect; <as>as, the <ex>result</ex>
of a course of action; the <ex>result</ex> of a mathematical
operation</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If our proposals once again were heard,<br/
We should compel them to a quick <qex>result</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The decision or determination of a council or
deliberative assembly; a resolve; a decree.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Then of their session ended they bid cry<br/
With trumpet's regal sound the great <qex>result</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Effect; consequence; conclusion; inference;
issue; event. See <er>Effect</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resultance</ent><br/
<hw>Re*sult"ance</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
resulting; that which results; a result.</def>
<rj><au>Donne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resultant</ent><br/
<hw>Re*sult"ant</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>resultans</ets>, p. pr. : cf. F.
<ets>r<eacute/sultant</ets>.]</ety> <def>Resulting or issuing from a
combination; existing or following as a result or consequence.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Resultant force</b></col> <it>or</it>
<col><b>Resultant motion</b></col></mcol> <fld>(Mech.)</fld>, <cd>a
force which is the result of two or more forces acting conjointly, or a
motion which is the result of two or more motions combined. See
<cref>Composition of forces</cref>, under
<er>Composition</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resultant</ent><br/
<hw>Re*sult"ant</hw>, <pos>n.</pos> <def>That which results.</def>
Specifically: <sd>(a)</sd> <fld>(Mech.)</fld> <def>A reultant force or
motion.</def> <sd>(b)</sd> <fld>(Math.)</fld> <def>An
eliminant.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>resultant</qex> of homogeneous general functions of
<it>n</it> variables is that function of their coefficients which,
equaled to zero, expresses in the simplest terms the condition of the
possibility of their existence.</q> <rj><qau>Sylvester.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resultate</ent><br/
<hw>Re*sult"ate</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>resultatus</ets>, p. p. ]</ety> <def>A result.</def>
<mark>[Obs.]</mark> <ldquo/The <xex>resultate</xex> of their
counsil.<rdquo/ <rj><au>BAcon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resultful</ent><br/
<hw>Re*sult"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>HAving results or
effects.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resultive</ent><br/
<hw>Re*sult"ive</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Resultant.</def>
<mark>[Obs.]</mark> <rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resultless</ent><br/
<hw>Re*sult"less</hw>, <pos>a.</pos> <def>Being without result; <as>as,
<ex>resultless</ex> investigations</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resumable</ent><br/
<hw>Re*sum"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of, or
admitting of, being resumed.</def> <rj><au>Sir M. Hale.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resume</ent><br/
\'d8<hw>R<eacute/`su"m<eacute/"</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[F. See <er>Resume</er>.]</ety> <def>A summing up; a condensed
statement; an abridgment or brief recapitulation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The exellent little <qex>r<eacute/sum<eacute/</qex> thereof in Dr.
Landsborough's book.</q> <rj><qau>C. Kingsley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A brief summary of the education, experience,
accomplishments, and other professional qualifications of a person, such
as that prepared by one applying for a job.</def><br/
[<source>PJC</source>]</p>

<p><ent>Resume</ent><br/
<hw>Re*sume"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Resumed</conjf> <pr>(?)</pr>;<pos>p. pr. & vb. n.</pos>
<conjf>Resuming</conjf>.]</vmorph> <ety>[L. <ets>resumere</ets>,
<ets>resumptum</ets>; pref. <ets>re-</ets> re- + <ets>sumere</ets> to
take: cf. F. <ets>r<eacute/sumer</ets>. See <er>Assume</er>,
<er>Redeem</er>.]</ety> <sn>1.</sn> <def>To take back.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The sun, like this, from which our sight we have,<br/
Gazed on too long, <qex>resumes</qex> the light he gave.</q>
<rj><qau>Denham.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Perhaps God will <qex>resume</qex> the blessing he has bestowed
ere he attains the age of manhood.</q> <rj><qau>Sir W.
Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To enter upon, or take up again.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Reason <qex>resumed</qex> her place, and Passion fled.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To begin again; to recommence, as something which
has been interrupted; <as>as, to <ex>resume</ex> an argument or
discourse</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resummon</ent><br/
<hw>Re*sum"mon</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To summon
again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resummons</ent><br/
<hw>Re*sum"mons</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A second
summons.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resumption</ent><br/
<hw>Re*sump"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[cf. F.
<ets>r<eacute/sumption</ets>, L. <ets>resumptio</ets> restoration,
recovery, fr. <ets>resumere</ets>. See <er>Resume</er>.]</ety>
<sn>1.</sn> <def>The act of resuming; <as>as, the <ex>resumption</ex> of
a grant, of delegated powers, of an argument, of specie payments,
etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Eng.Law)</fld> <def>The taking again into the
king's hands of such lands or tenements as he had granted to any man on
false suggestions or other error.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resumptive</ent><br/
<hw>Re*sump"tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[cf. L.
<ets>resumptivus</ets> restorative.]</ety> <def>Taking back; resuming,
or tending toward resumption; <as>as, <ex>resumptive</ex>
measures</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resupinate</ent><br/
<hw>Re*su"pi*nate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>resupinatus</ets>, p. p. of <ets>resupinare</ets> to bend back. See
<er>Resupine</er>.]</ety> <def>Inverted in position; appearing to be
upside down or reversed, as the flowers of the orchis and the leaves of
some plants.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resupinated</ent><br/
<hw>Re*su"pi*na`ted</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Resupinate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resupination</ent><br/
<hw>Re*su`pi*na"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state of
luing on the back; the state of being resupinate, or reversed.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Our Vitruvius calleth this affection in the eye a
<qex>resupination</qex> of the figure.</q> <rj><qau>Sir H.
Wotton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resupine</ent><br/
<hw>Re`su*pine"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>resupinus</ets>; pref. <ets>re-</ets> re- + <ets>supinus</ets> bent
backward, supine.]</ety> <def>Lying on the back; supine; hence,
careless.</def> <rj><au>Sir K. Digby.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He spake, and, downward swayed, fell <qex>resupine</qex>,<br/
With his huge neck aslant.</q> <rj><qau>Cowper.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resupply</ent><br/
<hw>Re`sup*ply"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To supply
again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resurgence</ent><br/
<hw>Re*sur"gence</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of rising
again; resurrection.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resurgent</ent><br/
<hw>Re*sur"gent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>resurgens</ets>, <ets>-entis</ets>, p. pr. of <ets>resurgere</ets>.
See <er>Resurrection</er>.]</ety> <def>Rising again, as from the
dead.</def> <rj><au>Coleridge.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resurgent</ent><br/
<hw>Re*sur"gent</hw>, <pos>n.</pos> <def>One who rises again, as from
the dead.</def> <mark>[R.]</mark> <rj><au>Sydney Smith.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resurrect</ent><br/
<hw>Res`ur*rect"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[See
<er>Resurrection</er>.]</ety> <sn>1.</sn> <def>To take from the grave;
to disinter.</def> <mark>[Slang]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To reanimate; to restore to life; to bring to view
(that which was forgotten or lost).</def> <mark>[Slang]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resurrection</ent><br/
<hw>Res`ur*rec"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>r<eacute/surrection</ets>, L. <ets>resurrectio</ets>, fr.
<ets>resurgere</ets>, <ets>resurrectum</ets>, to rise again; pref.
<ets>re-</ets> re- + <ets>surgere</ets> to rise. See
<er>Source</er>.]</ety> <sn>1.</sn> <def>A rising again; the resumption
of vigor.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Especially, the rising again from the dead; the
resumption of life by the dead; <as>as, the <ex>resurrection</ex> of
Jesus Christ; the general <ex>resurrection</ex> of all the dead at the
Day of Judgment.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Nor after <qex>resurrection</qex> shall he stay<br/
Longer on earth.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>State of being risen from the dead; future
state.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In the <qex>resurrection</qex> they neither marry nor are given in
marriage.</q> <rj><qau>Matt. xxii. 30.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The cause or exemplar of a rising from the
dead.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I am the <qex>resurrection</qex>, and the life.</q> <rj><qau>John
xi. 25.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Cross of the resurrection</b></col>, <cd>a slender cross
with a pennant floating from the junction of the bars.</cd> --
<col><b>Resurrection plant</b></col> <fld>(Bot.)</fld>, <cd>a name given
to several species of <gen>Selaginella</gen> (as <spn>Selaginella
convoluta</spn> and <spn>Selaginella lepidophylla</spn>), flowerless
plants which, when dry, close up so as to resemble a bird's nest, but
revive and expand again when moistened. The name is sometimes also given
to the rose of Jericho. See under <er>Rose</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resurrectionist</ent><br/
<hw>Res`ur*rec"tion*ist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
steals bodies from the grave, as for dissection.</def>
<mark>[Slang]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resurrectionize</ent><br/
<hw>Res`ur*rec"tion*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To
raise from the dead.</def> <mark>[R.]</mark>
<rj><au>Southey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resurvey</ent><br/
<hw>Re`sur*vey"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To survey again
or anew; to review.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resurvey</ent><br/
<hw>Re*sur"vey</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A second or new
survey.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resuscitable</ent><br/
<hw>Re*sus"ci*ta*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of
resuscitation; <as>as, <ex>resuscitable</ex> plants</as>.</def>
<rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resuscitant</ent><br/
<hw>Re*sus"ci*tant</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or
that which resuscitates. Also used adjectively.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resuscitate</ent><br/
<hw>Re*sus"ci*tate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>resuscitatus</ets>, p. p. of <ets>resuscitare</ets>; pref.
<ets>re-</ets> re- + <ets>suscitare</ets> to raise, rouse. See
<er>Suscitate</er>.]</ety> <def>Restored to life.</def>
<mark>[R.]</mark> <rj><au>Bp. Gardiner.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resuscitate</ent><br/
<hw>Re*sus"ci*tate</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Resuscitated</conjf>
<pr>(?)</pr>;<pos>p. pr. & vb. n.</pos>
<conjf>Resuscitating</conjf>.]</vmorph> <def>To revivify; to revive;
especially, to recover or restore from apparent death; <as>as, to
<ex>resuscitate</ex> a drowned person; to <ex>resuscitate</ex> withered
plants.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resuscitate</ent><br/
<hw>Re*sus"ci*tate</hw>, <pos>v. i.</pos> <def>To come to life again; to
revive.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>These projects, however often slain, always
<qex>resuscitate</qex>.</q> <rj><qau>J. S. Mill.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resuscitation</ent><br/
<hw>Re*sus`ci*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>resuscitatio</ets>.]</ety> <def>The act of resuscitating, or state
of being resuscitated.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The subject of <qex>resuscitation</qex> by his sorceries.</q>
<rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resuscitative</ent><br/
<hw>Re*sus"ci*ta*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Tending to
resuscitate; reviving; revivifying.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Resuscitator</ent><br/
<hw>Re*sus"ci*ta`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.]</ety>
<sn>1.</sn> <def>One who, or that which, resuscitates.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <specif>Specifically:</specif> <fld>(Med.)</fld> <def>A
device which is used to force oxygen or a mixture of oxygen and other
gases into the lungs of patients who are suffering from asphyxiation, to
revive the patient and induce resumption of respiration.</def><br/
[<source>PJC</source>]</p>

<p><ent>Ret</ent><br/
<hw>Ret</hw> <pr>(r<ecr/t)</pr>, <pos>v. t.</pos> <def>See
<er>Aret</er>.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ret</ent><br/
<hw>Ret</hw>, <pos>v. t.</pos> <ety>[Akin to <ets>rot</ets>.]</ety>
<def>To prepare for use, as flax, by separating the fibers from the
woody part by process of soaking, macerating, and other treatment.</def>
<rj><au>Ure.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retable</ent><br/
<hw>Re*ta"ble</hw> <pr>(r<esl/*t<amac/"b'l)</pr>, <pos>n.</pos>
<fld>(Eccl.)</fld> <def>A shelf behind the altar, for display of lights,
vases of flowers, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retail</ent><br/
<hw>Re"tail</hw> <pr>(r<emac/"t<amac/l)</pr>, <pos>n.</pos> <ety>[F.
<ets>retaille</ets> piece cut off, shred, paring, or OF.
<ets>retail</ets>, from <ets>retailler</ets>. See <er>Retail</er>,
<pos>v.</pos>]</ety> <def>The sale of commodities in small quantities or
parcels; -- opposed to <contr>wholesale</contr>; sometimes, the sale of
commodities at second hand.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retail</ent><br/
<hw>Re"tail</hw>, <pos>a.</pos> <def>Done at retail; engaged in
retailing commodities; as a <xex>retail</xex> trade; a <xex>retail</xex>
grocer.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retail</ent><br/
<hw>Re*tail"</hw> <pr>(r<esl/*t<amac/l")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Retailed</conjf>
<pr>(?)</pr>;<pos>p. pr. & vb. n.</pos>
<conjf>Retailing</conjf>.]</vmorph> <ety>[Cf. F. <ets>retailler</ets> to
cut again; pref. <ets>re-</ets> re + <ets>tailler</ets> to cut. See
<er>Retail</er>, <pos>n.</pos>, <er>Tailor</er>, and cf.
<er>Detail</er>.]</ety> <sn>1.</sn> <def>To sell in small quantities, as
by the single yard, pound, gallon, etc.; to sell directly to the
consumer; <as>as, to <ex>retail</ex> cloth or groceries</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To sell at second hand.</def> <mark>[Obs. or
R.]</mark> <rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To distribute in small portions or at second hand;
to tell again or to many (what has been told or done); to report;
<as>as, to <ex>retail</ex> slander</as>.</def> <ldquo/To whom I will
<xex>retail</xex> my conquest won.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He is wit's peddler, and <qex>retails</qex> his wares<br/
At wakes and wassails.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retailer</ent><br/
<hw>Re*tail"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who retails
anything; <as>as, a <ex>retailer</ex> of merchandise; a
<ex>retailer</ex> of gossip</as>; -- used also of businesses, including
large corporations; <as>as, <org>Sears, Roebuck</org> is one the the
country's largest <ex>retailers</ex></as>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Retailment</ent><br/
<hw>Re*tail"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
retailing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retain</ent><br/
<hw>Re*tain"</hw> <pr>(r<esl/*t<amac/n")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Retained</conjf>
<pr>(r<esl/*t<amac/nd")</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Retaining</conjf>.]</vmorph> <ety>[F. <ets>retainir</ets>, L.
<ets>retinere</ets>; pref. <ets>re-</ets> re- + <ets>tenere</ets> to
hold, keep. See <er>Tenable</er>, and cf. <er>Rein</er> of a bridle,
<er>Retention</er>, <er>Retinue</er>.]</ety> <sn>1.</sn> <def>To
continue to hold; to keep in possession; not to lose, part with, or
dismiss; to restrain from departure, escape, or the like.</def>
<ldquo/Thy shape invisible <xex>retain</xex>.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Be obedient, and <qex>retain</qex><br/
Unalterably firm his love entire.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>An executor may <qex>retain</qex> a debt due to him from the
testator.</q> <rj><qau>Blackstone.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To keep in pay; to employ by a preliminary fee paid;
to hire; to engage; <as>as, to <ex>retain</ex> a
counselor</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A Benedictine convent has now <qex>retained</qex> the most learned
father of their order to write in its defense.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To restrain; to prevent.</def> <mark>[Obs.]</mark>
<rj><au>Sir W. Temple.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Retaining wall</b></col> <fld>(Arch. & Engin.)</fld>,
<cd>a wall built to keep any movable backing, or a bank of sand or
earth, in its place; -- called also <altname>retain
wall</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To keep; hold; restrain. See
<er>Keep</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retain</ent><br/
<hw>Re*tain"</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To belong; to
pertain.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>A somewhat languid relish, <qex>retaining</qex> to bitterness.</q>
<rj><qau>Boyle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To keep; to continue; to remain.</def>
<mark>[Obs.]</mark> <rj><au>Donne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retainable</ent><br/
<hw>Re*tain"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of being
retained.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retainal</ent><br/
<hw>Re*tain"al</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
retaining; retention.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retainer</ent><br/
<hw>Re*tain"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One
who, or that which, retains.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who is retained or kept in service; an
attendant; an adherent; a hanger-on.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Hence, a servant, not a domestic, but occasionally
attending and wearing his master's livery.</def>
<rj><au>Cowell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Law)</fld> <sd>(a)</sd> <def>The act of a client by
which he engages a lawyer or counselor to manage his cause.</def>
<sd>(b)</sd> <def>The act of withholding what one has in his hands by
virtue of some right.</def> <sd>(c)</sd> <def>A fee paid to engage a
lawyer or counselor to maintain a cause, or to prevent his being
employed by the opposing party in the case; -- called also
<altname>retaining fee</altname>.</def> <rj><au>Bouvier.</au>
<au>Blackstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1230 --></p>

<p><sn>5.</sn> <def>The act of keeping dependents, or the state of being
in dependence.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retainment</ent><br/
<hw>Re*tain"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
retaining; retention.</def> <rj><au>Dr. H. More.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retake</ent><br/
<hw>Re*take"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <sn>1.</sn> <def>To
take or receive again.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To take from a captor; to recapture; <as>as, to
<ex>retake</ex> a ship or prisoners</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retaker</ent><br/
<hw>Re*tak"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who takes again
what has been taken; a recaptor.</def> <rj><au>Kent.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retaliate</ent><br/
<hw>Re*tal"i*ate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Retaliated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Retaliating</conjf>.]</vmorph> <ety>[L.
<ets>retaliatus</ets>, p. p. of <ets>retaliare</ets> to retaliate; pref.
<ets>re-</ets> re- + a word akin to <ets>talio</ets> talion,
retaliation. Cf. <er>Talion</er>.]</ety> <def>To return the like for; to
repay or requite by an act of the same kind; to return evil for (evil).
[Now seldom used except in a bad sense.]</def><br/
[<source>1913 Webster</source>]</p>

<p><q>One ambassador sent word to the duke's son that his visit should
be <qex>retaliated</qex>.</q> <rj><qau>Sir T. Herbert.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>It is unlucky to be obliged to <qex>retaliate</qex> the injuries
of authors, whose works are so soon forgotten that we are in danger of
appearing the first aggressors.</q> <rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retaliate</ent><br/
<hw>Re*tal"i*ate</hw>, <pos>v. i.</pos> <def>To return like for like;
specifically, to return evil for evil; <as>as, to <ex>retaliate</ex>
upon an enemy</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retaliation</ent><br/
<hw>Re*tal`i*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
retaliating, or of returning like for like; retribution; now,
specifically, the return of evil for evil; <xex>e</xex>.<xex>g</xex>.,
an eye for an eye, a tooth for a tooth.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>God . . . takes what is done to others as done to himself, and by
promise obloges himself to full <qex>retaliation</qex>.</q>
<rj><qau>Calamy.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Requital; reprisal; retribution;
punishment.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retaliative</ent><br/
<hw>Re*tal"i*a*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Same as
<er>Retaliatory</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retaliatory</ent><br/
<hw>Re*tal"i*a*to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Tending to,
or involving, retaliation; retaliative; as <xex>retaliatory</xex>
measures.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retard</ent><br/
<hw>Re*tard"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Retarded</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Retarding</conjf>.]</vmorph> <ety>[L. <ets>retardare</ets>,
<ets>retardatum</ets>; pref. <ets>re-</ets> re- + <ets>tardare</ets> to
make slow, to delay, fr. <ets>tardus</ets> slow: cf. F.
<ets>retarder</ets>. See <er>Tardy</er>.]</ety> <sn>1.</sn> <def>To keep
delaying; to continue to hinder; to prevent from progress; to render
more slow in progress; to impede; to hinder; <as>as, to <ex>retard</ex>
the march of an army; to <ex>retard</ex> the motion of a ship</as>; --
opposed to <ant>accelerate</ant>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To put off; to postpone; <as>as, to <ex>retard</ex>
the attacks of old age; to <ex>retard</ex> a rupture between
nations.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To impede; hinder; obstruct; detain; delay;
procrastinate; postpone; defer.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retard</ent><br/
<hw>Re*tard"</hw>, <pos>v. i.</pos> <def>To stay back.</def>
<mark>[Obs.]</mark> <rj><au>Sir. T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retard</ent><br/
<hw>Re*tard"</hw>, <pos>n.</pos> <sn>1.</sn> <def>Retardation;
delay.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A mentally retarded person.</def> <mark>[Colloq. and
disparaging]</mark><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>a person who is stupid or inept, especially in
social situations.</def> <mark>[Colloq. and disparaging]</mark><br/
[<source>PJC</source>]</p>

<p><cs><mcol><col><b>Retard of the tide</b></col>, <it>or</it>
<col><b>Age of the tide</b></col></mcol>, <cd>the interval between the
transit of the moon at which a tide originates and the appearance of the
tide itself. It is found, in general, that any particular tide is not
principally due to the moon's transit immediately proceeding, but to a
transit which has occured some time before, and which is said to
correspond to it. The <xex>retard of the tide</xex> is thus
distinguished from the <xex>lunitidal interval</xex>. See under
<er>Retardation</er>.</cd> <au>Ham. Nav. Encyc.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retardation</ent><br/
<hw>Re`tar*da"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>retardatio</ets>: cf. F. <ets>retardation</ets>.]</ety> <sn>1.</sn>
<def>The act of retarding; hindrance; the act of delaying; <as>as, the
<ex>retardation</ex> of the motion of a ship</as>; -- opposed to
<ant>acceleration</ant>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>retardations</qex> of our fluent motion.</q> <rj><qau>De
Quinsey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which retards; an obstacle; an
obstruction.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Hills, sloughs, and other terrestrial <qex>retardations</qex>.</q>
<rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Mus.)</fld> <def>The keeping back of an approaching
consonant chord by prolonging one or more tones of a previous chord into
the intermediate chord which follows; -- differing from
<xex>suspension</xex> by resolving upwards instead of
downwards.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The extent to which anything is retarded; the amount
of retarding or delay.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Retardation of the tide</b></col>. <sd>(a)</sd> <cd>The
lunitidal interval, or the hour angle of the moon at the time of high
tide any port; the interval between the transit of the moon and the time
of high tide next following</cd>. <sd>(b)</sd> <cd>The age of the tide;
the retard of the tide. See under <er>Retard</er>,
<pos>n.</pos></cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retardative</ent><br/
<hw>Re*tard"a*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>retardatif</ets>.]</ety> <def>Tending, or serving, to
retard.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retarded</ent><br/
<hw>Re*tard"ed</hw>, <pos>n.</pos> <def>having a limited or below normal
mental ability; same as <col><b>mentally retarded</b></col>; -- used
especially in relation to performance in academic tasks.</def><br/
[<source>PJC</source>]</p>

<p><ent>Retarder</ent><br/
<hw>Re*tard"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One
who, or that which, retards.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Steam Boiler)</fld> <def>Any of various devices, as
a helix of flat metal strip, introduced into a boiler tube to increase
the heating effect of the fire.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>3.</sn> <fld>(Photog.)</fld> <def>A substance, as potassium
bromide, added to a developer to retard its action.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Retardment</ent><br/
<hw>Re*tard"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>retardement</ets>.]</ety> <def>The act of retarding;
retardation.</def> <rj><au>Cowley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retch</ent><br/
<hw>Retch</hw> <pr>(r<ecr/ch <it>or</it> r<emac/ch; 277)</pr>, <pos>v.
i.</pos> <vmorph>[<pos>imp. & p. p.</pos> <conjf>Retched</conjf>
<pr>(r<ecr/cht)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Retching</conjf>.]</vmorph> <ety>[AS. <ets>hr<ae/can</ets> to
clear the throat, hawk, fr. <ets>hraca</ets> throat; akin to G.
<ets>rachen</ets>, and perhaps to E. <ets>rack</ets> neck.]</ety>
<def>To make an effort to vomit; to strain, as in vomiting.</def>
<altsp>[Written also <asp>reach</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><q>Beloved Julia, hear me still beseeching!<br/
(Here he grew inarticulate with <qex>retching</qex>.)</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retch</ent><br/
<hw>Retch</hw>, <pos>v. t. & i.</pos> <ety>[See <er>Reck</er>.]</ety>
<def>To care for; to heed; to reck.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retchless</ent><br/
<hw>Retch"less</hw>, <pos>a.</pos> <def>Careless; reckless.</def>
<mark>[Obs.]</mark> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p>--- <wordforms><wf>Retch"less*ly</wf>, <pos>adv.</pos> --
<wf>Retch"less*ness</wf>, <pos>n.</pos>
<mark>[Obs.]</mark></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rete</ent><br/
\'d8<hw>Re"te</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., a net.]</ety>
<fld>(Anat.)</fld> <def>A net or network; a plexus; particularly, a
network of blood vessels or nerves, or a part resembling a
network.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retecious</ent><br/
<hw>Re*te"cious</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>rete</ets> a net.]</ety> <def>Resembling network;
retiform.</def><-- sic. --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retection</ent><br/
<hw>Re*tec"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>retegere</ets>, <ets>retectum</ets>, to uncover; pref.
<ets>re-</ets> + <ets>tegere</ets> to cover.]</ety> <def>Act of
disclosing or uncovering something concealed.</def> <mark>[Obs.]</mark>
<rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retell</ent><br/
<hw>Re*tell</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To tell
again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retene</ent><br/
<hw>Ret"ene</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/<?/<?/ pine
resin.]</ety> <fld>(Chem.)</fld> <def>A white crystalline hydrocarbon,
polymeric with benzene. It is extracted from pine tar, and is also found
in certain fossil resins.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retent</ent><br/
<hw>Re*tent"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>retentum</ets>, fr. <ets>retentus</ets>, p. p. See
<er>Retain</er>.]</ety> <def>That which is retained.</def>
<rj><au>Hickok.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retention</ent><br/
<hw>Re*ten"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>retentio</ets>: cf. F. <ets>r<eacute/tention</ets>. See
<er>Retain</er>.]</ety> <sn>1.</sn> <def>The act of retaining, or the
state of being ratined.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The power of retaining; retentiveness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>No woman's heart<br/
So big, to hold so much; they lack <qex>retention</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which contains something, as a tablet; a
<?/<?/<?/<?/ of preserving impressions.</def> <mark>[R.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The act of withholding; retraint; reserve.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Place of custody or confinement.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Law)</fld> <def>The right of withholding a debt, or
of retaining property until a debt due to the person claiming the right
be duly paid; a lien.</def> <rj><au>Erskine. Craig.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Retention cyst</b></col> <fld>(Med.)</fld>, <cd>a cyst
produced by obstruction of a duct leading from a secreting organ and the
consequent retention of the natural secretions.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retentive</ent><br/
<hw>Re*ten"tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>r<eacute/tentif</ets>.]</ety> <def>Having power to retain; <as>as,
a <ex>retentive</ex> memory</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Nor airless dungeon, nor strong links of iron,<br/
Can be <qex>retentive</qex> to the strength of spirit.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retentive</ent><br/
<hw>Re*ten"tive</hw>, <pos>n.</pos> <def>That which retains or confines;
a restraint.</def> <mark>[R.]</mark> <rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retentively</ent><br/
<hw>Re*ten"tive*ly</hw>, <pos>adv.</pos> <def>In a retentive
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retentiveness</ent><br/
<hw>Re*ten"tive*ness</hw>, <pos>n.</pos> <def>The quality of being
retentive.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retentivity</ent><br/
<hw>Re`ten*tiv"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The power of
retaining; retentive force; <as>as, the <ex>retentivity</ex> of a
magnet</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retentor</ent><br/
\'d8<hw>Re*ten"tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., a
retainer.]</ety> <fld>(Zool.)</fld> <def>A muscle which serves to retain
an organ or part in place, esp. when retracted. See <xex>Illust.</xex>
of <er>Phylactolemata</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retepore</ent><br/
<hw>Re`te*pore</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>rete</ets>
a net + <ets>porus</ets> pore.]</ety> <fld>(Zool.)</fld> <def>Any one of
several species of bryozoans of the genus <gen>Retepora</gen>. They form
delicate calcareous corals, usually composed of thin fenestrated
fronds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retex</ent><br/
<hw>Re*tex"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>retexere</ets>, lit., to unweave; pref. <ets>re-</ets> re +
<ets>texere</ets> to weave. ]</ety> <def>To annual, as orders.</def>
<mark>[Obs.]</mark> <rj><au>Bp. Hacket.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retexture</ent><br/
<hw>Re*tex"ture</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of weaving
or forming again.</def> <rj><au>Carlyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rethor</ent><br/
<hw>Reth"or</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>rh<eacute/teur</ets>. See <er>Rhetor</er>.]</ety> <def>A
rhetorician; a careful writer.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>If a <qex>rethor</qex> couthe fair endite.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rethoryke</ent><br/
<hw>Reth"o*ryke</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Rhetoric.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retiarius</ent><br/
\'d8<hw>Re`ti*a"ri*us</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., fr.
<ets>rete</ets> a net.]</ety> <fld>(Rom.Antiq.)</fld> <def>A gladiator
armed with a net for entangling his adversary and a trident for
despatching him.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retiary</ent><br/
<hw>Re"ti*a*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Retiarius</er>.]</ety> <sn>1.</sn> <fld>(Zool.)</fld> <def>Any
spider which spins webs to catch its prey.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A retiarius.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retiary</ent><br/
<hw>Re`ti*a*ry</hw>, <pos>a.</pos> <ety>[Cf. LL.
<ets>retiarius</ets>.]</ety> <sn>1.</sn> <def>Netlike.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This work is in <qex>retiary</qex>, or hanging textures.</q>
<rj><qau>Sir T. Browne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Constructing or using a web, or net, to catch prey;
-- said of certain spiders.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Armed with a net; hence, skillful to
entangle.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Scholastic <qex>retiary</qex> versatility of logic.</q>
<rj><qau>Coleridge.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reticence</ent><br/
<hw>Ret"i*cence</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>reticentia</ets>: cf. F. <ets>r<eacute/ticence</ets>.]</ety>
<sn>1.</sn> <def>The quality or state of being reticent, or keeping
silence; the state of holding one's tonque; refraining to speak of that
which is suggested; uncommunicativeness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Such fine reserve and noble <qex>reticence</qex>.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Rhet.)</fld> <def>A figure by which a person really
speaks of a thing while he makes a show as if he would say nothingon the
subject.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reticency</ent><br/
<hw>Ret"i*cen*cy</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Reticence.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reticent</ent><br/
<hw>Ret"i*cent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>reticens</ets>, p. pr. of <ets>reticere</ets> to keep silence;
<ets>re-</ets> + <ets>tacere</ets> to be silent. See
<er>Tacit</er>.]</ety> <def>Inclined to keep silent; reserved;
uncommunicative.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reticle</ent><br/
<hw>Ret"i*cle</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Reticule</er>.]</ety> <sn>1.</sn> <def>A small net.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A reticule. See <er>Reticule</er>, 2.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reticular</ent><br/
<hw>Re*tic"u*lar</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>r<eacute/ticulaire</ets>. See <er>Reticule</er>.]</ety> <sn>1.</sn>
<def>Having the form of a net, or of network; formed with interstices;
retiform; <as>as, <ex>reticular</ex> cartilage; a <ex>reticular</ex>
leaf</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Anat.)</fld> <def>Of or pertaining to a
reticulum.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reticularia</ent><br/
\'d8<hw>Re*tic`u*la"ri*a</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.
See <er>Reticular</er>.]</ety> <fld>(Zool.)</fld> <def>An extensive
division of rhizopods in which the pseudopodia are more or less slender
and coalesce at certain points, forming irregular meshes. It includes
the shelled Foraminifera, together with some groups which lack a true
shell.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reticularian</ent><br/
<hw>Re*tic`u*la"ri*an</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Zool.)</fld>. <def>One of the Reticularia.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reticularly</ent><br/
<hw>Re*tic"u*lar*ly</hw>, <pos>adv.</pos> <def>In a reticular
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reticulated</ent><br/
<ent>Reticulate</ent><br/
<mhw>{ <hw>Re*tic"u*late</hw> <pr>(?)</pr>, <hw>Re*tic"u*la`ted</hw>
<pr>(?)</pr> }</mhw>, <pos>a.</pos> <ety>[L. <ets>reticulatus</ets>. See
<er>Reticule</er>.]</ety> <sn>1.</sn> <def>Resembling network; having
the form or appearance of a net; netted; <as>as, a <ex>reticulated</ex>
structure</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Having veins, fibers, or lines crossing like the
threads or fibers of a network; <as>as, a <ex>reticulate</ex> leaf; a
<ex>reticulated</ex> surface; a <ex>reticulated</ex> wing of an
insect.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Reticulated glass</b></col>, <cd>ornamental ware made
from glass in which one set of white or colored lines seems to meet and
interlace with another set in a different plane.</cd> --
<col><b>Reticulated micrometer</b></col>, <cd>a micrometer for an
optical instrument, consisting of a reticule in the focus of an
eyepiece.</cd> -- <col><b>Reticulated work</b></col>
<fld>(Masonry)</fld>, <cd>work constructed with diamond-shaped stones,
or square stones placed diagonally.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reticulation</ent><br/
<hw>Re*tic`u*la"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The quality
or state of being reticulated, or netlike; that which is reticulated;
network; an organization resembling a net.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The particular net you occupy in the great
<qex>reticulation</qex>.</q> <rj><qau>Carlyle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reticule</ent><br/
<hw>Ret"i*cule</hw> <pr>(?)</pr>, <pos>n..</pos> <ety>[F.
<ets>r<eacute/ticule</ets>, L. <ets>reticulum</ets>, dim. of
<ets>rete</ets> a net. Cf.<er>Retina</er>, <er>Reticle</er>.]</ety>
<sn>1.</sn> <def>A little bag, originally of network; a woman's workbag,
or a little bag to be carried in the hand.</def> <rj><au>De
Quincey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A system of wires or lines in the focus of a
telescope or other instrument; a reticle.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reticulosa</ent><br/
\'d8<hw>Re*tic`u*lo"sa</hw> <pr>(?)</pr>, <pos>n. pl.</pos>
<ety>[NL.]</ety> <fld>(Zool.)</fld> <def>Same as
<er>Reticularia</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reticulose</ent><br/
<hw>Re*tic"u*lose`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Forming a
network; characterized by a reticulated sructure.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Reticulose rhizopod</b></col> <fld>(Zool.)</fld>, <cd>a
rhizopod in which the pseudopodia blend together and form irregular
meshes.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reticulum</ent><br/
\'d8<hw>Re*tic"u*lum</hw> <pr>(?)</pr>, <pos>n.</pos>;<plu><it>pl.</it>
<plw>Reticula</plw> <pr>(#)</pr>.</plu> <ety>[L. dim. of <ets>rete</ets>
a net.]</ety> <fld>(Anat.)</fld> <sd>(a)</sd> <def>The second stomach of
ruminants, in which folds of the mucous membrane form hexagonal cells;
-- also called the <altname>honeycomb stomach</altname>.</def>
<sd>(b)</sd> <def>The neuroglia.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retiform</ent><br/
<hw>Ret"i*form</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>rete</ets>
a net + <ets>-form</ets>. cf. F. <ets>r<eacute/tiforme</ets>.]</ety>
<def>Composed of crossing lines and interstices; reticular; netlike;
<as>as, the <ex>retiform</ex> coat of the eye</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retina</ent><br/
<hw>Ret"i*na</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., from L.
<ets>rete</ets> a net. Cf. <er>Reticule</er>.]</ety> <fld>(Anat.)</fld>
<def>The delicate membrane by which the back part of the globe of the
eye is lined, and in which the fibers of the optic nerve terminate. See
<er>Eye</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The fibers of the optic nerve and the retinal blood
vessels spread out upon the front surface of the retina, while the
sensory layer (called <xex>Jacob's membrane</xex>), containing the rods
and cones, is on the back side, next the choroid coat.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retinaculum</ent><br/
\'d8<hw>Ret`i*nac"u*lum</hw> <pr>(?)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Retinacula</plw> <pr>(#)</pr>.</plu> <ety>[L., a
holdfast, a band. See <er>Retain</er>.]</ety> <sn>1.</sn>
<fld>(Anat.)</fld> <sd>(a)</sd> <def>A connecting band; a fraenum;
<as>as, the <ex>retinacula</ex> of the ileocaecal and ileocolic
valves</as>.</def> <sd>(b)</sd> <def>One of the annular ligaments which
hold the tendons close to the bones at the larger joints, as at the
wrist and ankle.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>One of the retractor muscles of
the proboscis of certain worms.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Bot.)</fld> <def>A small gland or process to which
bodies are attached; <as>as, the glandular <ex>retinacula</ex> to which
the pollinia of orchids are attached, or the hooks which support the
seeds in many acanthaceous plants</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retinal</ent><br/
<hw>Ret"i*nal</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Anat.)</fld>
<def>Of or pertaining to the retina.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Retinal purple</b></col> <fld>(Physiol. Chem.)</fld>,
<cd>the visual purple.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retinal</ent><br/
<hw>Ret"i*nal</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld> <def>A
retinoid compound (<chform>C20H28O</chform>), closely related to vitamin
A, which is a component of the visual pigments in the eye. It is also
called <altname>retinaldehyde</altname> and <altname>vitamin A
aldehyde</altname>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Retinalite</ent><br/
<hw>Re*tin"a*lite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<?/<?/<?/<?/ resin + <ets>-lite</ets>.]</ety> <fld>(Min.)</fld> <def>A
translucent variety of serpentine, of a honey yellow or greenish yellow
color, having a waxy resinlike luster.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retinasphaltum</ent><br/
<ent>Retinasphalt</ent><br/
<mhw>{ <hw>Ret`in*as"phalt</hw> <pr>(?)</pr>,
\'d8<hw>Ret`in*as*phal"tum</hw> <pr>(?)</pr>, }</mhw> <pos>n.</pos>
<ety>[Gr. <?/<?/<?/<?/ resin + <?/<?/<?/<?/<?/ asphalt.]</ety>
<fld>(Min.)</fld> <def>Retinite.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retinerved</ent><br/
<hw>Ret"i*nerved`</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>rete</ets> a net + E. <ets>nerve</ets>.]</ety> <fld>(Bot.)</fld>
<def>Having reticulated veins.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retineum</ent><br/
\'d8<hw>Ret`i*ne"um</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Retinea</plw> <pr>(#)</pr>.</plu> <ety>[NL. See
<er>Retina</er>.]</ety> <fld>(Zool.)</fld> <def>That part of the eye of
an invertebrate which corresponds in function with the retina of a
vertebrate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retinic</ent><br/
<hw>Re*tin"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/<?/<?/<?/
resin.]</ety> <fld>(Min. Chem.)</fld> <def>Of or pertaining to resin;
derived from resin; specifically, designating an acid found in certain
fossil resins and hydrocarbons.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retinite</ent><br/
<hw>Ret"i*nite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.<?/<?/<?/
resin: cf. F. <ets>r<eacute/tinite</ets>.]</ety> <fld>(Min.)</fld>
<def>An inflammable mineral resin, usually of a yellowish brown color,
found in roundish masses, sometimes with coal.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retinitis</ent><br/
<hw>Ret`i*ni"tis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. NL. &
E. <ets>retina + -tis</ets>.]</ety> <fld>(Med.)</fld> <def>Inflammation
of the retina.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retinoic acid</ent><br/
<hw>Ret`in*o"ic ac"id</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Chem.)</fld> <def>A retinoid compound (<chform>C20H28O2</chform>),
closely related to vitamin A. It is also called
<altname>tretinoin</altname> and <altname>vitamin A
acid</altname>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Retinoid</ent><br/
<hw>Ret"i*noid</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/<?/<?/
resin + <ets>-oid</ets>.]</ety> <def>Resinlike, or resinform; resembling
a resin without being such.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retinol</ent><br/
<hw>Ret"i*nol</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/<?/<?/ resin
+ L. <ets>ole</ets>um oil.]</ety> <sn>1.</sn> <fld>(Chem.)</fld> <def>A
hydrocarbon oil <chform>C32H16</chform>, obtained by the distillation of
resin, -- used as a solvent, as an antiseptic, and in printer's
ink.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>One of the compounds which function as vitamin A.
Called also <altname>vitamin A</altname>, <altname>vitamin A1</altname>
and <altname>vitamin A alcohol</altname>. See <er>vitamin
A1</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Retinophora</ent><br/
\'d8<hw>Ret`i*noph"o*ra</hw> <pr>(?)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Retiniphorae</plw> <pr>(#)</pr>.</plu> <ety>[NL.,
fr. NL. & E. <ets>retina</ets> + Gr. <grk>fe`rein</grk> to bear.]</ety>
<fld>(Zool.)</fld> <def>One of group of two to four united cells which
occupy the axial part of the ocelli, or ommatidia, of the eyes of
invertebrates, and contain the terminal nerve fibrillae. See
<xex>Illust.</xex> under <er>Ommatidium</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retinophoral</ent><br/
<hw>Ret`i*noph"o*ral</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Of or pertaining to retinophorae.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retinoscopy</ent><br/
<hw>Ret`i*nos"co*py</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Retina</ets> + <ets>-scopy</ets>.]</ety>
<fld>(Physiol.)</fld> <def>The study of the retina of the eye by means
of the ophthalmoscope.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retinue</ent><br/
<hw>Ret"i*nue</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>retinue</ets>, OF. <ets>retinue</ets>, fr. <ets>retenir</ets> to
retain, engage, hire. See <er>Retain</er>.]</ety> <def>The body of
retainers who follow a prince or other distinguished person; a train of
attendants; a suite.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Others of your insolent <qex>retinue</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>What followers, what <qex>retinue</qex> canst thou gain?</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To have at one's retinue</b></col>, <cd>to keep or employ
as a retainer; to retain.</cd> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retinula</ent><br/
\'d8<hw>Re*tin"u*la</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Retinulae</plw> <pr>(#)</pr>.</plu> <ety>[NL., dim. of NL. & E.
<ets>retina</ets>.]</ety> <fld>(Zool.)</fld> <def>One of the group of
pigmented cells which surround the retinophorae of invertebrates. See
<xex>Illust.</xex> under <er>Ommatidium</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retinulate</ent><br/
<hw>Re*tin"u*late</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Having, or characterized by, retinul<?/.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retiped</ent><br/
<hw>Ret`i*ped</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>rete</ets>
a net + <ets>pes</ets>, <ets>pedis</ets>, a foot: cf. F.
<ets>r<eacute/tinop<egrave/de</ets>.]</ety> <fld>(Zool.)</fld> <def>A
bird having small polygonal scales covering the tarsi.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retiracy</ent><br/
<hw>Re*tir"a*cy</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Retirement; --
mostly used in a jocose or burlesque way.</def> <mark>[U.S.]</mark>
<rj><au>Bartlett.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>What one of our great men used to call dignified
<qex>retiracy</qex>.</q> <rj><qau>C. A. Bristed.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retirade</ent><br/
<hw>Ret`i*rade"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.; cf. Sp.
<ets>retirada</ets> retreat. See <er>Retire</er>.]</ety>
<fld>(Fort.)</fld> <def>A kind of retrenchment, as in the body of a
bastion, which may be disputed inch by inch after the defenses are
dismantled. It usually consists of two faces which make a reentering
angle.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retire</ent><br/
<hw>Re*tire"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Retired</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Retiring</conjf>.]</vmorph> <ety>[F. <ets>retirer</ets>; pref.
<ets>re-</ets> re- + <ets>tirer</ets> to draw. See
<er>Tirade</er>.]</ety> <sn>1.</sn> <def>To withdraw; to take away; --
sometimes used reflexively.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He . . . <qex>retired</qex> himself, his wife, and children into a
forest.</q> <rj><qau>Sir P. Sidney.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>As when the sun is present all the year,<br/
And never doth <qex>retire</qex> his golden ray.</q> <rj><qau>Sir J.
Davies.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1231 --></p>

<p><sn>2.</sn> <def>To withdraw from circulation, or from the market; to
take up and pay; <as>as, to <ex>retire</ex> bonds; to <ex>retire</ex> a
note.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To cause to retire; specifically, to designate as no
longer qualified for active service; to place on the retired list;
<as>as, to <ex>retire</ex> a military or naval officer</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retire</ent><br/
<hw>Re*tire"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <sn>1.</sn> <def>To go
back or return; to draw back or away; to keep aloof; to withdraw or
retreat, as from observation; to go into privacy; <as>as, to
<ex>retire</ex> to his home; to <ex>retire</ex> from the world, or from
notice.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>To Una back he cast him to <qex>retire</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The mind contracts herself, and shrinketh in,<br/
And to herself she gladly doth <qex>retire</qex>.</q> <rj><qau>Sir J.
Davies.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To retreat from action or danger; to withdraw for
safety or pleasure; <as>as, to <ex>retire</ex> from
battle</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Set Uriah in the forefront of the hottest battle, and
<qex>retire</qex> ye from him, that he may be smitten, and die.</q>
<rj><qau>2 Sam. xi. 15.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To withdraw from a public station, or from business;
<as>as, having made a large fortune, he <ex>retired</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And from Britannia's public posts <qex>retire</qex>.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To recede; to fall or bend back; <as>as, the shore
of the sea <ex>retires</ex> in bays and gulfs</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To go to bed; <as>as, he usually <ex>retires</ex>
early</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To withdraw; leave; depart; secede; recede;
retreat; retrocede.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retire</ent><br/
<hw>Re*tire"</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act of retiring,
or the state of being retired; also, a place to which one retires.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The battle and the <qex>retire</qex> of the English succors.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>[Eve] discover'd soon the place of her <qex>retire</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mil.)</fld> <def>A call sounded on a bugle,
announcing to skirmishers that they are to retire, or fall
back.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retired</ent><br/
<hw>Re*tired"</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Private;
secluded; quiet; <as>as, a <ex>retired</ex> life; a person of
<ex>retired</ex> habits.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>retired</qex> part of the peninsula.</q>
<rj><qau>Hawthorne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Withdrawn from active duty or business; <as>as, a
<ex>retired</ex> officer; a <ex>retired</ex> physician.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Retired flank</b></col> <fld>(Fort.)</fld>, <cd>a flank
bent inward toward the rear of the work.</cd> -- <col><b>Retired
list</b></col> <fld>(Mil. & Naval)</fld>, <cd>a list of officers, who,
by reason of advanced age or other disability, are relieved from active
service, but still receive a specified amount of pay from the
government.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Re*tired"ly</wf>, <pos>adv.</pos> --
<wf>Re*tired"ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retirement</ent><br/
<hw>Re*tire"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>retirement</ets>.]</ety> <sn>1.</sn> <def>The act of retiring, or
the state of being retired; withdrawal; seclusion; <as>as, the
<ex>retirement</ex> of an officer</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>O, blest <qex>Retirement</qex>, friend of life's decline.</q>
<rj><qau>Goldsmith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Retirement</qex>, rural quiet, friendship, books.</q>
<rj><qau>Thomson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A place of seclusion or privacy; a place to which
one withdraws or retreats; a private abode.</def>
<mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>This coast full of princely <qex>retirements</qex> for the
sumptousness of their buildings and nobleness of the plantations.</q>
<rj><qau>Evelyn.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Caprea had been the <qex>retirement</qex> of Augustus.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Solitude; withdrawment; departure; retreat;
seclusion; privacy. See <er>Solitude</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retirer</ent><br/
<hw>Re*tir"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
retires.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retiring</ent><br/
<hw>Re*tir"ing</hw>, <pos>a.</pos> <sn>1.</sn> <def>Reserved; shy; not
forward or obtrusive; <as>as, <ex>retiring</ex> modesty;
<ex>retiring</ex> manners.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of or pertaining to retirement; causing retirement;
suited to, or belonging to, retirement.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Retiring board</b></col> <fld>(Mil.)</fld>, <cd>a board
of officers who consider and report upon the alleged incapacity of an
officer for active service.</cd> -- <col><b>Retiring pension</b></col>,
<cd>a pension granted to a public officer on his retirement from office
or service.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retistene</ent><br/
<hw>Ret"i*stene</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>A white crystalline hydrocarbon produced indirectly from
retene.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retitelae</ent><br/
\'d8<hw>Ret`i*te"lae</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL., fr.
<ets>rete</ets> a net + <ets>tela</ets> a web.]</ety> <fld>(Zool.)</fld>
<def>A group of spiders which spin irregular webs; -- called also
<altname>Retitelariae</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retold</ent><br/
<hw>Re*told"</hw> <pr>(?)</pr>, <def><pos>imp. & p. p.</pos> of
<er>Retell</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retorsion</ent><br/
<hw>Re*tor"sion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Retortion</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retort</ent><br/
<hw>Re*tort"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Retorted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Retorting</conjf>.]</vmorph> <ety>[L. <ets>retortus</ets>, p. p.
of <ets>retorquere</ets>; pref. <ets>re-</ets> re- + <ets>torquere</ets>
to turn twist. See <er>Torsion</er>, and cf. <er>Retort</er>,
<pos>n.</pos>, 2.]</ety> <sn>1.</sn> <def>To bend or curve back; <as>as,
a <ex>retorted</ex> line</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With <qex>retorted</qex> head, pruned themselves as they
floated.</q> <rj><qau>Southey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To throw back; to reverberate; to reflect.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>As when his virtues, shining upon others,<br/
Heat them and they <qex>retort</qex> that heat again<br/
To the first giver.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To return, as an argument, accusation, censure, or
incivility; <as>as, to <ex>retort</ex> the charge of
vanity</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And with <qex>retorted</qex> scorn his back he turned.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retort</ent><br/
<hw>Re*tort"</hw>, <pos>v. i.</pos> <def>To return an argument or a
charge; to make a severe reply.</def> <rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retort</ent><br/
<hw>Re*tort"</hw>, <pos>n.</pos> <ety>[See <er>Retort</er>, <pos>v.
t.</pos>]</ety> <sn>1.</sn> <def>The return of, or reply to, an
argument, charge, censure, incivility, taunt, or witticism; a quick and
witty or severe response.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This is called the <qex>retort</qex> courteous.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <ety>[F. <ets>retorte</ets> (cf. Sp. <ets>retorta</ets>),
fr. L. <ets>retortus</ets>, p. p. of <ets>retorquere</ets>. So named
from its bent shape. See <er>Retort</er>, <pos>v. t.</pos>]</ety>
<fld>(Chem. & the Arts)</fld> <def>A vessel in which substances are
subjected to distillation or decomposition by heat. It is made of
different forms and materials for different uses, as a bulb of glass
with a curved beak to enter a receiver for general chemical operations,
or a cylinder or semicylinder of cast iron for the manufacture of gas in
gas works.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Tubulated retort</b></col> <fld>(Chem.)</fld>, <cd>a
retort having a tubulure for the introduction or removal of the
substances which are to be acted upon.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Repartee; answer.</syn> <usage> --
<er>Retort</er>, <er>Repartee</er>. A <xex>retort</xex> is a short and
pointed reply, turning back on an assailant the arguments, censure, or
derision he had thrown out. A <xex>repartee</xex> is usually a
good-natured return to some witty or sportive remark.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retorter</ent><br/
<hw>Re*tort"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
retorts.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retortion</ent><br/
<hw>Re*tor"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>r<eacute/torsion</ets>. See <er>Retort</er>, <pos>v.
t.</pos>]</ety> <sn>1.</sn> <def>Act of retorting or throwing back;
reflection or turning back.</def> <altsp>[Written also
<asp>retorsion</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><q>It was, however, necessary to possess some single term expressive
of this intellectual <qex>retortion</qex>.</q> <rj><qau>Sir W.
Hamilton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>Retaliation.</def>
<rj><au>Wharton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retortive</ent><br/
<hw>Re*tort"ive</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Containing
retort.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retoss</ent><br/
<hw>Re*toss"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To toss back or
again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retouch</ent><br/
<hw>Re*touch"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>re-</ets> + <ets>touch</ets>: cf. F. <ets>retoucher</ets>.]</ety>
<sn>1.</sn> <def>To touch again, or rework, in order to improve; to
revise; <as>as, to <ex>retouch</ex> a picture or an
essay</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Photog.)</fld> <def>To correct or change, as a
negative, by handwork.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retouch</ent><br/
<hw>Re*touch"</hw>, <pos>n.</pos> <fld>(Fine Arts)</fld> <def>A partial
reworking,as of a painting, a sculptor's clay model, or the
like.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retoucher</ent><br/
<hw>Re*touch"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
retouches.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retrace</ent><br/
<hw>Re*trace"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>re-</ets> + <ets>trace</ets>: cf. F. <ets>retracer</ets>. Cf.
<er>Retract</er>.]</ety> <sn>1.</sn> <def>To trace back, as a
line.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Then if the line of Turnus you <qex>retrace</qex>,<br/
He springs from Inachus of Argive race.</q>
<rj><qau>Driden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To go back, in or over (a previous course); to go
over again in a reverse direction; <as>as, to <ex>retrace</ex> one's
steps; to <ex>retrace</ex> one's proceedings.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To trace over again, or renew the outline of, as a
drawing; to draw again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retract</ent><br/
<hw>Re*tract"</hw> <pr>(r<esl/*tr<amac/kt")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Retracted</conjf>; <pos>p. pr. &
vb. n.</pos> <conjf>Retracting</conjf>.]</vmorph> <ety>[F.
<ets>r<eacute/tracter</ets>, L. <ets>retractare</ets>,
<ets>retractatum</ets>, to handle again, reconsider, retract, fr.
<ets>retrahere</ets>, <ets>retractum</ets>, to draw back. See
<er>Retreat</er>.]</ety> <sn>1.</sn> <def>To draw back; to draw up or
shorten; <as>as, the cat can <ex>retract</ex> its claws; to
<ex>retract</ex> a muscle.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To withdraw; to recall; to disavow; to recant; to
take back; <as>as, to <ex>retract</ex> an accusation or an
assertion</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I would as freely have <qex>retracted</qex> this charge of
idolatry as I ever made it.</q> <rj><qau>Bp.
Stillingfleet.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To take back,, as a grant or favor previously
bestowed; to revoke.</def> <mark>[Obs.]</mark>
<rj><au>Woodward.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To recall; withdraw; rescind; revoke; unsay;
disavow; recant; abjure; disown.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retract</ent><br/
<hw>Re*tract"</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To draw back; to
draw up; <as>as, muscles <ex>retract</ex> after
amputation</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To take back what has been said; to withdraw a
concession or a declaration.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>She will, and she will not; she grants, denies,<br/
Consents, <qex>retracts</qex>, advances, and then files.</q>
<rj><qau>Granville.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retract</ent><br/
<hw>Re*tract"</hw>, <pos>n.</pos> <fld>(Far.)</fld> <def>The pricking of
a horse's foot in nailing on a shoe.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retractable</ent><br/
<hw>Re*tract"a*ble</hw> <pr>(r<esl/*tr<amac/kt"<adot/*b'l)</pr>,
<pos>a.</pos> <ety>[Cf. F. <ets>r<eacute/tractable</ets>.]</ety>
<def>Capable of being retracted; retractile.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retractate</ent><br/
<hw>Re*tract"ate</hw> <pr>(r<esl/*tr<amac/kt"<amac/t)</pr>, <pos>v.
t.</pos> <ety>[L. <ets>retractatus</ets>, p. p. of
<ets>retractare</ets>. See <er>Retract</er>.]</ety> <def>To retract; to
recant.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retractation</ent><br/
<hw>Re`trac*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>r<eacute/tractation</ets>, L. <ets>retractatio</ets> a revision,
reconsideration. ]</ety> <def>The act of retracting what has been said;
recantation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retractible</ent><br/
<hw>Re*tract"i*ble</hw> <pr>(r<esl/*tr<amac/kt"<icr/*b'l)</pr>,
<pos>a.</pos> <def>Retractable.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retractile</ent><br/
<hw>Re*tract"ile</hw> <pr>(r<esl/*tr<amac/kt"<icr/l)</pr>, <pos>a.</pos>
<ety>[Cf. F. <ets>-r<eacute/tractile</ets>.]</ety> <fld>(Physiol.)</fld>
<def>Capable of retraction; capable of being drawn back or up; <as>as,
the claws of a cat are <ex>retractile</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retraction</ent><br/
<hw>Re*trac"tion</hw> <pr>(r<esl/*tr<amac/k"sh<ucr/n)</pr>,
<pos>n.</pos> <ety>[Cf. F. <ets>r<eacute/traction</ets>, L.
<ets>retractio</ets> a drawing back, hesitation.]</ety> <sn>1.</sn>
<def>The act of retracting, or drawing back; the state of being
retracted; <as>as, the <ex>retraction</ex> of a cat's
claws</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The act of withdrawing something advanced, stated,
claimed, or done; declaration of change of opinion;
recantation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Other men's insatiable desire of revenge hath wholly beguiled both
church and state of the benefit of all my either <qex>retractions</qex>
or concessions.</q> <rj><qau>Eikon Basilike.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Physiol.)</fld> <sd>(a)</sd> <def>The act of
retracting or shortening; <as>as, the <ex>retraction</ex> of a severed
muscle; the <ex>retraction</ex> of a sinew</as>.</def> <sd>(b)</sd>
<def>The state or condition of a part when drawn back, or towards the
center of the body.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retractive</ent><br/
<hw>Re*tract"ive</hw> <pr>(r<esl/*tr<amac/kt"<icr/v)</pr>, <pos>a.</pos>
<def>Serving to retract; of the nature of a retraction.</def> --
<wordforms><wf>Re*tract"ive*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retractive</ent><br/
<hw>Re*tract"ive</hw>, <pos>n.</pos> <def>That which retracts, or
withdraws.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retractor</ent><br/
<hw>Re*tract"or</hw> <pr>(r<esl/*tr<amac/kt"<etil/r)</pr>, <pos>n.</pos>
<def>One who, or that which, retracts.</def>
<specif>Specifically:</specif> <sd>(a)</sd> <def>In breech-loading
firearms, a device for withdrawing a cartridge shell from the
barrel.</def> <sd>(b)</sd> <fld>(Surg.)</fld> <def>An instrument for
holding apart the edges of a wound during amputation.</def> <sd>(c)</sd>
<fld>(Surg.)</fld> <def>A bandage to protect the soft parts from injury
by the saw during amputation.</def> <sd>(d)</sd> <fld>(Anat. &
Zool.)</fld> <def>A muscle serving to draw in any organ or part. See
<xex>Illust.</xex> under <er>Phylactolaemata</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retraict</ent><br/
<hw>Re*traict"</hw> <pr>(r<esl/*tr<amac/t")</pr>, <pos>n.</pos>
<def>Retreat.</def> <mark>[Obs.]</mark> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retrait</ent><br/
<hw>Re*trait"</hw> <pr>(r<esl/*tr<amac/t")</pr>, <pos>n.</pos> <ety>[It.
<ets>ritratto</ets>, fr. <ets>ritrarre</ets> to draw back, draw, fr. L.
<ets>retrahere</ets>. See <er>Retract</er>.]</ety> <def>A portrait; a
likeness.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Whose fair <qex>retrait</qex> I in my shield do bear.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retransform</ent><br/
<hw>Re`trans*form"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To transform
anew or back.</def> -- <wordforms><wf>Re`trans*for*ma"tion</wf>
<pr>(#)</pr>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retranslate</ent><br/
<hw>Re`trans*late"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To translate
anew; especially, to translate back into the original
language.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retraxit</ent><br/
\'d8<hw>Re*trax"it</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., (he) has
withdrawn. See <er>Retract</er>.]</ety> <fld>(O. Eng. Law)</fld>
<def>The withdrawing, or open renunciation, of a suit in court by the
plaintiff, by which he forever lost his right of action.</def>
<rj><au>Blackstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retread</ent><br/
<hw>Re*tread"</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <def>To tread
again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retreat</ent><br/
<hw>Re*treat"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>retraite</ets>, fr. <ets>retraire</ets> to withdraw, L.
<ets>retrahere</ets>; pref. <ets>re-</ets> re- + <ets>trahere</ets> to
draw. See <er>Trace</er>, and cf. <er>Retract</er>,
<er>Retrace</er>.]</ety> <sn>1.</sn> <def>The act of retiring or
withdrawing one's self, especially from what is dangerous or
disagreeable.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In a <qex>retreat</qex> he outruns any lackey.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The place to which anyone retires; a place or
privacy or safety; a refuge; an asylum.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He built his son a house of pleasure, and spared no cost to make a
delicious <qex>retreat</qex>.</q> <rj><qau>L'Estrange.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>That pleasing shade they sought, a soft <qex>retreat</qex><br/
From sudden April showers, a shelter from the heat.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Mil. & Naval.)</fld> <sd>(a)</sd> <def>The retiring
of an army or body of men from the face of an enemy, or from any ground
occupied to a greater distance from the enemy, or from an advanced
position.</def> <sd>(b)</sd> <def>The withdrawing of a ship or fleet
from an enemy for the purpose of avoiding an engagement or escaping
after defeat.</def> <sd>(c)</sd> <def>A signal given in the army or
navy, by the beat of a drum or the sounding of trumpet or bugle, at
sunset (when the roll is called), or for retiring from action.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ A <xex>retreat</xex> is properly an orderly march, in
which circumstance it differs from a <xex>flight</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Eccl.)</fld> <sd>(a)</sd> <def>A special season of
solitude and silence to engage in religious exercises.</def>
<sd>(b)</sd> <def>A period of several days of withdrawal from society to
a religious house for exclusive occupation in the duties of devotion;
<as>as, to appoint or observe a <ex>retreat</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Retirement; departure; withdrawment; seclusion;
solitude; privacy; asylum; shelter; refuge.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retreat</ent><br/
<hw>Re*treat"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Retreated</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Retreating</conjf>.]</vmorph> <def>To make a retreat; to retire
from any position or place; to withdraw; <as>as, the defeated army
<ex>retreated</ex> from the field</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The rapid currents drive<br/
Towards the <qex>retreating</qex> sea their furious tide.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retreatful</ent><br/
<hw>Re*treat"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Furnishing or
serving as a retreat.</def> <mark>[R.]</mark> <ldquo/Our
<xex>retreatful</xex> flood.<rdquo/ <rj><au>Chapman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retreatment</ent><br/
<hw>Re*treat"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
retreating; specifically, the Hegira.</def> <mark>[R.]</mark>
<rj><au>D'Urfey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retrench</ent><br/
<hw>Re*trench"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Retrenched</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Retrenching</conjf>.]</vmorph> <ety>[OF.
<ets>retrenchier</ets>, F. <ets>retrancher</ets>; pref. <ets>re-</ets>
re- + OF. <ets>trenchier</ets>, F. <ets>trancher</ets>, to cut. See
<er>Trench</er>.]</ety> <sn>1.</sn> <def>To cut off; to pare
away.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thy exuberant parts <qex>retrench</qex>.</q>
<rj><qau>Denham.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To lessen; to abridge; to curtail; <as>as, to
<ex>retrench</ex> superfluities or expenses</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>But this thy glory shall be soon <qex>retrenched</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To confine; to limit; to restrict.</def>
<rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>These figures, ought they then to receive a <qex>retrenched</qex>
interpretation?</q> <rj><qau>I. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Fort.)</fld> <def>To furnish with a retrenchment;
<as>as, to <ex>retrench</ex> bastions</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To lesen; diminish; curtail; abridge.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retrench</ent><br/
<hw>Re*trench"</hw>, <pos>v. i.</pos> <def>To cause or suffer
retrenchment; specifically, to cut down living expenses; <as>as, it is
more reputable to <ex>retrench</ex> than to live
embarrassed</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retrenchment</ent><br/
<hw>Re*trench"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>retrenchment</ets>.]</ety> <sn>1.</sn> <def>The act or process of
retrenching; <as>as, the <ex>retrenchment</ex> of words in a
writing</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>retrenchment</qex> of my expenses will convince you that
<?/ mean to replace your fortune as far as I can.</q>
<rj><qau>Walpole.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Fort.)</fld> <def>A work constructed within
another, to prolong the defense of the position when the enemy has
gained possession of the outer work; or to protect the defenders till
they can retreat or obtain terms for a capitulation.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Lessening; curtailment; diminution; reduction;
abridgment.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retrial</ent><br/
<hw>Re*tri"al</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A secdond trial,
experiment, or test; a second judicial trial, as of an accused
person.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retribute</ent><br/
<hw>Re*trib"ute</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>retributus</ets>, p. p. of<ets>retribuere</ets> to retribute; pref
<ets>re-</ets> + <ets>tribuere</ets> to bestow, assign, pay. See
<er>Tribute</er>.]</ety> <def>To pay back; to give in return, as
payment, reward, or punishment; to requite; <as>as, to
<ex>retribute</ex> one for his kindness; to <ex>retribute</ex> just
punishment to a criminal</as>.</def> <mark>[Obs. or R.]</mark>
<rj><au>Locke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retributer</ent><br/
<hw>Re*trib"u*ter</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who makes
retribution.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retribution</ent><br/
<hw>Ret`ri*bu"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>retributio</ets>: cf. F. <ets>r<eacute/tribution</ets>.]</ety>
<sn>1.</sn> <def>The act of retributing; repayment.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In good offices and due <qex>retributions</qex>, we may not be
pinching and niggardly.</q> <rj><qau>Bp. Hall.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is given in repayment or compensation;
return suitable to the merits or deserts of, as an action; commonly,
condign punishment for evil or wrong.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>All who have their reward on earth, . . . <br/
Naught seeking but the praise of men, here find<br/
Fit <qex>retribution</qex>, empty as their deeds.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Specifically, reward and punishment, as distributed
at the general judgment.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It is a strong argument for a state of <qex>retribution</qex>
hereafter, that in this world virtuous persons are very often
unfortunate, and vicious persons prosperous.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Repayment; requital; recompense; payment;
retaliation.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retributory</ent><br/
<ent>Retributive</ent><br/
<mhw>{ <hw>Re*trib"u*tive</hw> <pr>(?)</pr>, <hw>Re*trib"u*to*ry</hw>
}</mhw>, <pos>a.</pos> <ety>[Cf. LL. <ets>retributorius</ets> worthy of
retribution.]</ety> <def>Of or pertaining to retribution; of the nature
of retribution; involving retribution or repayment; <as>as,
<ex>retributive</ex> justice; <ex>retributory</ex>
comforts.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retrievable</ent><br/
<hw>Re*triev"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From
<er>Retrieve</er>.]</ety> <def>That may be retrieved or recovered;
admitting of retrieval.</def> --
<wordforms><wf>Re*triev"a*ble*ness</wf>, <pos>n.</pos> --
<wf>Re*triev"a*bly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retrieval</ent><br/
<hw>Re*triev"al</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act
retrieving.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retrieve</ent><br/
<hw>Re*trieve"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Retrieved</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Retrieving</conjf>.]</vmorph> <ety>[OE.
<ets>retreven</ets>, OF. <ets>retrover</ets> to find again, recover
(<ets>il retroeve</ets>e finds again), F. <ets>retrouver</ets>; pref.
<ets>re-</ets> re- + OF. <ets>trover</ets> to find, F.
<ets>trouver</ets>. See <er>Trover</er>.]</ety> <sn>1.</sn> <def>To find
again; to recover; to regain; to restore from loss or injury; <as>as, to
<ex>retrieve</ex> one's character; to <ex>retrieve</ex>
independence</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With late repentance now they would <qex>retrieve</qex><br/
The bodies they forsook, and wish to live.</q>
<rj><qau>Dryden</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To recall; to bring back.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>retrieve</qex> them from their cold, trivial conceits.</q>
<rj><qau>Berkeley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1232 --></p>

<p><sn>3.</sn> <def>To remedy the evil consequence of, to repair, as a
loss or damadge.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Accept my sorrow, and <qex>retrieve</qex> my fall.</q>
<rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>There is much to be done . . . and much to be
<qex>retrieved</qex>.</q> <rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To recover; regain; recruit; repair;
restore.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retrieve</ent><br/
<hw>Re*trieve"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <fld>(Sport.)</fld>
<def>To discover and bring in game that has been killed or wounded;
<as>as, a dog naturally inclined to <ex>retrieve</ex></as>.</def>
<rj><au>Walsh.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retrieve</ent><br/
<hw>Re*trieve"</hw>, <pos>n.</pos> <sn>1.</sn> <def>A seeking again; a
discovery.</def> <mark>[Obs.]</mark> <rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The recovery of game once sprung; -- an old sporting
term.</def> <mark>[Obs.]</mark> <rj><au>Nares.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retrievement</ent><br/
<hw>Re*trieve"ment</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Retrieval.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retriever</ent><br/
<hw>Re*triev"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One
who retrieves.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>A dor, or a breed of dogs,
chiefly employed to retrieve, or to find and recover game birds that
have been killed or wounded.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retrim</ent><br/
<hw>Re*trim"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To trim
again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retriment</ent><br/
<hw>Ret"ri*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>retrimentum</ets>.]</ety> <def>Refuse; dregs.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retro-</ent><br/
<hw>Retro-</hw>. <ety>[L. <ets>retro</ets>, adv., backward, back. Cf.
<er>Re</er>-.]</ety> <def>A prefix or combining form signifying
<xex>backward</xex>, <xex>back</xex>; <as>as, <ex>retro</ex>act, to act
backward; <ex>retro</ex>spect, a looking back</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retroact</ent><br/
<hw>Re`tro*act"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[Pref.
<ets>retro- + act</ets>.]</ety> <def>To act backward, or in return; to
act in opposition; to be retrospective.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retroaction</ent><br/
<hw>Re`tro*ac"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>r<eacute/troaction</ets>.]</ety> <sn>1.</sn> <def>Action returned,
or action backward.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Operation on something past or preceding.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retroactive</ent><br/
<hw>Re`tro*act"ive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>r<eacute/troactif</ets>.]</ety> <def>Fitted or designed to
retroact; operating by returned action; affecting what is past;
retrospective.</def> <rj><au>Beddoes.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Retroactive law</b></col> <it>or</it>
<col><b>Retroactive statute</b></col></mcol> <fld>(Law)</fld>, <cd>one
which operates to make criminal or punishable, or in any way expressly
to affect, acts done prior to the passing of the law.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retroactively</ent><br/
<hw>Re`tro*act"ive*ly</hw>, <pos>adv.</pos> <def>In a retroactive
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retrocede</ent><br/
<hw>Re"tro*cede</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>retro-</ets> + <ets>cede</ets>: cf. F.
<ets>r<eacute/troc<eacute/der</ets>.]</ety> <def>To cede or grant back;
<as>as, to <ex>retrocede</ex> a territory to a former
proprietor</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retrocede</ent><br/
<hw>Re"tro*cede</hw>, <pos>v. i.</pos> <ety>[L. <ets>retrocedere</ets>;
<ets>retro</ets> backward, back + <ets>cedere</ets> to go. See
<er>Cede</er>.]</ety> <def>To go back.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retrocedent</ent><br/
<hw>Re`tro*ced"ent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>retrocedens</ets>, p. pr.]</ety> <def>Disposed or likely to
retrocede; -- said of diseases which go from one part of the body to
another, as the gout.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retrocession</ent><br/
<hw>Re`tro*ces"sion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>r<eacute/trocession</ets>. See <er>Retrocede</er>.]</ety>
<sn>1.</sn> <def>The act of retroceding.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The state of being retroceded, or granted
back.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Med.)</fld> <def>Metastasis of an eruption or a
tumor from the surface to the interior of the body.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retrochoir</ent><br/
<hw>Re"tro*choir</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>retro-</ets> + <ets>choir</ets>.]</ety> <fld>(Eccl. Arch.)</fld>
<def>Any extension of a church behind the high altar, as a chapel; also,
in an apsidal church, all the space beyond the line of the back or
eastern face of the altar.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retrocopulant</ent><br/
<hw>Re`tro*cop"u*lant</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Retrocopulation</er>.]</ety> <def>Copulating backward, or from
behind.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retrocopulation</ent><br/
<hw>Re`tro*cop`u*la"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>retro- + copulation</ets>.]</ety> <def>Copulation from
behind.</def> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retroduction</ent><br/
<hw>Re`tro*duc"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>retroducere</ets>, <ets>retroductum</ets>, to lead or bring back;
<ets>retro</ets> backward + <ets>ducere</ets> to lead.]</ety> <def>A
leading or bringing back.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retroflexed</ent><br/
<ent>Retroflex</ent><br/
<mhw>{ <hw>Re"tro*flex</hw> <pr>(?)</pr>, <hw>Re"tro*flexed</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[Pref. <ets>retro-</ets> + L.
<ets>flectere</ets>, <ets>flexum</ets>, to bend, to turn.]</ety>
<def>Reflexed; bent or turned abruptly backward.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retroflexion</ent><br/
<hw>Re`tro*flex"ion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
reflexing; the state of being retroflexed. Cf.
<er>Retroversion</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retrofracted</ent><br/
<ent>Retrofract</ent><br/
<mhw>{ <hw>Re"tro*fract</hw> <pr>(?)</pr>, <hw>Re"tro*fract`ed</hw>,
}</mhw> <pos>a.</pos> <ety>[Pref. <ets>retro-</ets> + L.
<ets>fractus</ets>, p. p. of <ets>frangere</ets> to break.]</ety>
<fld>(Bot.)</fld> <def>Refracted; <as>as, a <ex>retrofract</ex>
stem</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retrogenerative</ent><br/
<hw>Re`tro*gen"er*a*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>retro- + generative</ets>.]</ety> <def>Begetting young by
retrocopulation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retrogradation</ent><br/
<hw>Re`tro*gra*da"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>r<eacute/trogradation</ets> or L. <ets>retrogradatio</ets>. See
<er>Retrograde</er>.]</ety> <sn>1.</sn> <def>The act of retrograding, or
moving backward.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The state of being retrograde; decline.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retrograde</ent><br/
<hw>Re"tro*grade</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>retrogradus</ets>, from <ets>retrogradi</ets>,
<ets>retrogressus</ets>, to retrograde; <ets>retro</ets> back +
<ets>gradi</ets> to step: cf. F. <ets>r<eacute/trograde</ets>. See
<er>Grade</er>.]</ety> <sn>1.</sn> <fld>(Astron.)</fld> <def>Apparently
moving backward, and contrary to the succession of the signs, that is,
from east to west, as a planet.</def> <rj><au>Hutton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And if he be in the west side in that condition, then is he
<qex>retrograde</qex>.</q> <rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Tending or moving backward; having a backward
course; contrary; <as>as, a <ex>retrograde</ex> motion</as>; -- opposed
to <ant>progressive</ant>.</def> <ldquo/Progressive and not
<xex>retrograde</xex>.<rdquo/ <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>It is most <qex>retrograde</qex> to our desire.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Declining from a better to a worse state; <as>as, a
<ex>retrograde</ex> people; <ex>retrograde</ex> ideas, morals,
etc.</as></def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retrograde</ent><br/
<hw>Re"tro*grade</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Retrograded</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Retrograding</conjf>.]</vmorph> <ety>[L. <ets>retrogradare</ets>,
<ets>retrogradi</ets>: cf. F. <ets>r<eacute/trograder</ets>.]</ety>
<sn>1.</sn> <def>To go in a retrograde direction; to move, or appear to
move, backward, as a planet.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence, to decline from a better to a worse
condition, as in morals or intelligence.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retrogradingly</ent><br/
<hw>Re"tro*gra`ding*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>By
retrograding; so as to retrograde.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retrogress</ent><br/
<hw>Re"tro*gress</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. L.
<ets>retrogressus</ets>.]</ety> <def>Retrogression.</def>
<mark>[R.]</mark> <rj><au>H. Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retrogression</ent><br/
<hw>Re`tro*gres"sion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>r<eacute/trogression</ets>. See <er>Retrograde</er>, and cf.
<er>Digression</er>.]</ety> <sn>1.</sn> <def>The act of retrograding, or
going backward; retrogradation.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Biol.)</fld> <def>Backward development; a passing
from a higher to a lower state of organization or structure, as when an
animal, approaching maturity, becomes less highly organized than would
be expected from its earlier stages or known relationship. Called also
<altname>retrograde development</altname>, and <altname>regressive
metamorphism</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retrogressive</ent><br/
<hw>Re`tro*gres"sive</hw>, <pos>a.</pos> <ety>[Cf. F.
<ets>r<eacute/trogressif</ets>.]</ety> <sn>1.</sn> <def>Tending to
retrograde; going or moving backward; declining from a better to a worse
state.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Biol.)</fld> <def>Passing from a higher to a lower
condition; declining from a more perfect state of organization;
regressive.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retrogressively</ent><br/
<hw>Re`tro*gres"sive*ly</hw>, <pos>adv.</pos> <def>In a retrogressive
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retromingency</ent><br/
<hw>Re`tro*min"gen*cy</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The quality
or state of being retromingent.</def> <rj><au>Sir T.
Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retromingent</ent><br/
<hw>Re`tro*min"gent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>retro-</ets> + L. <ets>mingens</ets>, p. pr. of <ets>mingere</ets>
to urinate.]</ety> <def>Organized so as to discharge the urine
backward.</def> -- <def2><pos>n.</pos> <fld>(Zool.)</fld> <def>An animal
that discharges its urine backward.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retropulsive</ent><br/
<hw>Re`tro*pul"sive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>retro-</ets> + L. <ets>pellere</ets>, <ets>pulsum</ets>, to
impel.]</ety> <def>Driving back; repelling.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retrorse</ent><br/
<hw>Re*trorse"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>retrorsus</ets>, <ets>retroversus</ets>; <ets>retro</ets> back +
<ets>vertere</ets>, <ets>versum</ets>, to turn. Cf.
<er>Retrovert</er>.]</ety> <def>Bent backward or downward.</def> --
<wordforms><wf>Re*trorse"ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retrospect</ent><br/
<hw>Re"tro*spect</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[L.
<ets>retrospicere</ets>; <ets>retro</ets> back + <ets>specere</ets>,
<ets>spectum</ets>, to look. See <er>Spy</er>, <ets>and cf</ets>.
<er>Expect</er>.]</ety> <def>To look backward; hence, to affect or
concern what is past.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It may be useful to <qex>retrospect</qex> to an early period.</q>
<rj><qau>A. Hamilton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retrospect</ent><br/
<hw>Re"tro*spect</hw>, <pos>n.</pos> <def>A looking back on things past;
view or contemplation of the past.</def> <rj><au>Cowper.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>We may introduce a song without <qex>retrospect</qex> to the old
comedy.</q> <rj><qau>Landor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retrospection</ent><br/
<hw>Re`tro*spec"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act, or
the faculty, of looking back on things past.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retrospective</ent><br/
<hw>Re`tro*spec"tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>r<eacute/trospectif</ets>.]</ety> <sn>1.</sn> <def>Looking
backward; contemplating things past; -- opposed to
<ant>prospective</ant>; <as>as, a <ex>retrospective</ex>
view</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The sage, with <qex>retrospective</qex> eye.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Having reference to what is past; affecting things
past; retroactive; <as>as, a <ex>retrospective</ex> law</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Inflicting death by a <qex>retrospective</qex> enactment.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retrospectively</ent><br/
<hw>Re`tro*spec"tive*ly</hw>, <pos>adv.</pos> <def>By way of
retrospect.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retrovaccination</ent><br/
<hw>Re`tro*vac`ci*na"tion</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Med.)</fld> <def>The inoculation of a cow with human vaccine
virus.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retroversion</ent><br/
<hw>Re`tro*ver"sion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>r<eacute/troversion</ets>. See <er>Retrovert</er>.]</ety> <def>A
turning or bending backward; also, the state of being turned or bent
backward; displacement backwards; <as>as, <ex>retroversion</ex> of the
uterus</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In <xex>retroversion</xex> the bending is gradual or
curved; in <xex>retroflexion</xex> it is abrupt or angular.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retrovert</ent><br/
<hw>Re"tro*vert</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Retroverted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Retroverting</conjf>.]</vmorph> <ety>[Pref. <ets>retro-</ets> +
L. <ets>vertere</ets>, <ets>versum</ets>, to turn. Cf.
<er>Retrorse</er>.]</ety> <def>To turn back.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retroverted</ent><br/
<hw>Re"tro*vert*ed</hw>, <pos>a.</pos> <def>In a state of
retroversion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retrude</ent><br/
<hw>Re*trude"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Retruded</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Retruding</conjf>.]</vmorph> <ety>[L. <ets>retrudere</ets>;
<ets>re-</ets> + <ets>trudere</ets> to thrust.]</ety> <def>To thrust
back.</def> <mark>[R.]</mark> <rj><au>Dr. H. More.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retruse</ent><br/
<hw>Re*truse"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>retrusus</ets> concealed, p. p. of <ets>retrudere</ets>.]</ety>
<def>Abstruse.</def> <mark>[Obs.]</mark> <rj><au>Dr. H.
More.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retrusion</ent><br/
<hw>Re*tru"sion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
retruding, or the state of being retruded.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In virtue of an endless remotion or <qex>retrusion</qex> of the
constituent cause.</q> <rj><qau>Coleridge.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retry</ent><br/
<hw>Re*try"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To try (esp.
judicially) a second time; <as>as, to <ex>retry</ex> a case; to
<ex>retry</ex> an accused person.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rette</ent><br/
<hw>Rette</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>See
<er>Aret</er>.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rettery</ent><br/
<hw>Ret"ter*y</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A place or
establishment where flax is retted. See <er>Ret</er>.</def>
<rj><au>Ure.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retting</ent><br/
<hw>Ret"ting</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The act
or process of preparing flax for use by soaking, maceration, and kindred
processes; -- also called <altname>rotting</altname>. See
<er>Ret</er>.</def> <rj><au>Ure.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A place where flax is retted; a rettery.</def>
<rj><au>Ure.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retund</ent><br/
<hw>Re*tund"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>retundere</ets>, <ets>retusum</ets>; pref. <ets>re-</ets> re- +
<ets>tundere</ets> to beat.]</ety> <def>To blunt; to turn, as an edge;
figuratively, to cause to be obtuse or dull; <as>as, to <ex>retund</ex>
confidence</as>.</def> <rj><au>Ray. Cudworth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Re-turn</ent><br/
<hw>Re-turn"</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <def>To turn
again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Return</ent><br/
<hw>Re*turn"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Returned</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Returning</conjf>.]</vmorph> <ety>[OE.
<ets>returnen</ets>, <ets>retournen</ets>, F. <ets>retourner</ets>;
pref. <ets>re-</ets> re- + <ets>tourner</ets> to turn. See
<er>Turn</er>.]</ety> <sn>1.</sn> <def>To turn back; to go or come again
to the same place or condition.</def> <ldquo/<xex>Return</xex> to your
father's house.<rdquo/ <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>On their embattled ranks the waves <qex>return</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>If they <qex>returned</qex> out of bondage, it must be into a
state of freedom.</q> <rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Dust thou art, and unto dust shalt thou <qex>return</qex>.</q>
<rj><qau>Gen. iii. 19.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To come back, or begin again, after an interval,
regular or irregular; to appear again.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With the year<br/
Seasons <qex>return</qex>; but not me <qex>returns</qex><br/
Day or the sweet approach of even or morn.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To speak in answer; to reply; to respond.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He said, and thus the queen of heaven <qex>returned</qex>.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To revert; to pass back into possession.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And Jeroboam said in his heart, Now shall the kingdom
<qex>return</qex> to the house of David.</q> <rj><qau>1Kings xii.
26.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To go back in thought, narration, or argument.</def>
<ldquo/But to <xex>return</xex> to my story.<rdquo/
<rj><au>Fielding.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Return</ent><br/
<hw>Re*turn"</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To bring, carry,
send, or turn, back; <as>as, to <ex>return</ex> a borrowed book, or a
hired horse</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Both fled attonce, ne ever back <qex>returned</qex> eye.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To repay; <as>as, to <ex>return</ex> borrowed
money</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To give in requital or recompense; to
requite.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The Lord shall <qex>return</qex> thy wickedness upon thine own
head.</q> <rj><qau>1 Kings ii. 44.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To give back in reply; <as>as, to <ex>return</ex> an
answer; to <ex>return</ex> thanks.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To retort; to throw back; <as>as, to <ex>return</ex>
the lie</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If you are a malicious reader, you <qex>return</qex> upon me, that
I affect to be thought more impartial than I am.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To report, or bring back and make known.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And all the people answered together, . . . and Moses
<qex>returned</qex> the words of the people unto the Lord.</q>
<rj><qau>Ex. xix. 8.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>To render, as an account, usually an official
account, to a superior; to report officially by a list or statement;
<as>as, to <ex>return</ex> a list of stores, of killed or wounded; to
<ex>return</ex> the result of an election.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>Hence, to elect according to the official report of
the election officers.</def> <mark>[Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>To bring or send back to a tribunal, or to an
office, with a certificate of what has been done; <as>as, to
<ex>return</ex> a writ</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <def>To convey into official custody, or to a general
depository.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Instead of a ship, he should levy money, and <qex>return</qex> the
same to the treasurer for his majesty's use.</q>
<rj><qau>Clarendon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>11.</sn> <fld>(Tennis)</fld> <def>To bat (the ball) back over the
net.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>12.</sn> <fld>(Card Playing)</fld> <def>To lead in response to
the lead of one's partner; <as>as, to <ex>return</ex> a trump; to
<ex>return</ex> a diamond for a club.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To return a lead</b></col> <fld>(Card Playing)</fld>,
<cd>to lead the same suit led by one's partner.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To restore; requite; repay; recompense; render;
remit; report.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Return</ent><br/
<hw>Re*turn"</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The act
of returning (intransitive), or coming back to the same place or
condition; <as>as, the <ex>return</ex> of one long absent; the
<ex>return</ex> of health; the <ex>return</ex> of the seasons, or of an
anniversary.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>At the <qex>return</qex> of the year the king of Syria will come
up against thee.</q> <rj><qau>1 Kings xx. 22.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>His personal <qex>return</qex> was most required and
necessary.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The act of returning (transitive), or sending back
to the same place or condition; restitution; repayment; requital;
retribution; <as>as, the <ex>return</ex> of anything borrowed, as a book
or money; a good <ex>return</ex> in tennis.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>You made my liberty your late request:<br/
Is no <qex>return</qex> due from a grateful breast?</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which is returned.</def> Specifically:
<sd>(a)</sd> <def>A payment; a remittance; a requital.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I do expect <qex>return</qex><br/
Of thrice three times the value of this bond.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(b)</sd> <def>An answer; as, a <xex>return</xex> to one's
question.</def> <sd>(c)</sd> <def>An account, or formal report, of an
action performed, of a duty discharged, of facts or statistics, and the
like; <as>as, election <ex>returns</ex>; a <ex>return</ex> of the amount
of goods produced or sold</as>; especially, in the plural, a set of
tabulated statistics prepared for general information.</def>
<sd>(d)</sd> <def>The profit on, or advantage received from, labor, or
an investment, undertaking, adventure, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The fruit from many days of recreation is very little; but from
these few hours we spend in prayer, the <qex>return</qex> is great.</q>
<rj><qau>Jer. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Arch.)</fld> <def>The continuation in a different
direction, most often at a right angle, of a building, face of a
building, or any member, as a molding or mold; -- applied to the shorter
in contradistinction to the longer; thus, a facade of sixty feet east
and west has a <xex>return</xex> of twenty feet north and
south.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Law)</fld> <sd>(a)</sd> <def>The rendering back or
delivery of writ, precept, or execution, to the proper officer or
court.</def> <sd>(b)</sd> <def>The certificate of an officer stating
what he has done in execution of a writ, precept, etc., indorsed on the
document.</def> <sd>(c)</sd> <def>The sending back of a commission with
the certificate of the commissioners.</def> <sd>(d)</sd> <def>A day in
bank. See <cref>Return day</cref>, below.</def>
<rj><au>Blackstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Mil. & Naval)</fld> <def>An official account,
report, or statement, rendered to the commander or other superior
officer; <as>as, the <ex>return</ex> of men fit for duty; the
<ex>return</ex> of the number of the sick; the <ex>return</ex> of
provisions, etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <pluf>pl.</pluf> <fld>(Fort. & Mining)</fld> <def>The
turnings and windings of a trench or mine.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Return ball</b></col>, <cd>a ball held by an elastic
string so that it returns to the hand from which it is thrown, -- used
as a plaything.</cd> -- <col><b>Return bend</b></col>, <cd>a pipe
fitting for connecting the contiguous ends of two nearly parallel pipes
lying alongside or one above another.</cd> -- <col><b>Return
day</b></col> <fld>(Law)</fld>, <cd>the day when the defendant is to
appear in court, and the sheriff is to return the writ and his
proceedings.</cd> -- <col><b>Return flue</b></col>, <cd>in a steam
boiler, a flue which conducts flame or gases of combustion in a
direction contrary to their previous movement in another flue.</cd> --
<col><b>Return pipe</b></col> <fld>(Steam Heating)</fld>, <cd>a pipe by
which water of condensation from a heater or radiator is conveyed back
toward the boiler.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Returnable</ent><br/
<hw>Re*turn"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Capable of, or admitting of, being returned.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>Legally required to be returned,
delivered, given, or rendered; <as>as, a writ or precept
<ex>returnable</ex> at a certain day; a verdict <ex>returnable</ex> to
the court</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Returner</ent><br/
<hw>Re*turn"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
returns.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Returnless</ent><br/
<hw>Re*turn"less</hw>, <pos>a.</pos> <def>Admitting no return.</def>
<rj><au>Chapman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Retuse</ent><br/
<hw>Re*tuse"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>retusus</ets>, p. p. : cf. F. <ets>r<eacute/tus</ets>. See
<er>Retund</er>.]</ety> <fld>(Bot. & Zool.)</fld> <def>Having the end
rounded and slightly indented; <as>as, a <ex>retuse</ex>
leaf</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reule</ent><br/
<hw>Reule</hw> <pr>(?)</pr>, <pos>n. & v.</pos> <def>Rule.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reume</ent><br/
<hw>Reume</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Realm.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reunion</ent><br/
<hw>Re*un"ion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref. <ets>re- +
union</ets>: cf. F. <ets>r<eacute/union</ets>.]</ety> <sn>1.</sn> <def>A
second union; union formed anew after separation, secession, or discord;
<as>as, a <ex>reunion</ex> of parts or particles of matter; a
<ex>reunion</ex> of parties or sects.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An assembling of persons who have been separated, as
of a family, or the members of a disbanded regiment; an assembly so
composed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reunite</ent><br/
<hw>Re`u*nite"</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <def>To unite
again; to join after separation or variance.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1233 --></p>

<p><ent>Reunitedly</ent><br/
<hw>Re`u*nit"ed*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a reunited
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reunition</ent><br/
<hw>Re`u*ni"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A second
uniting.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reurge</ent><br/
<hw>Re*urge"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To urge
again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revaccinate</ent><br/
<hw>Re*vac"ci*nate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To vaccinate
a second time or again.</def> --
<wordforms><wf>Re*vac`ci*na"tion</wf><pr>(#)</pr>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revalescence</ent><br/
<hw>Rev`a*les"cence</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
growing well; the state of being revalescent.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Would this prove that the patient's <qex>revalescence</qex> had
been independent of the medicines given him?</q>
<rj><qau>Coleridge.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revalescent</ent><br/
<hw>Rev`a*les"cent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>revalescens</ets>, <ets>-entis</ets>, p. pr. of
<ets>revalescere</ets>; pref. <ets>re-</ets> re- + <ets>valescere</ets>,
v. incho. fr. <ets>valere</ets> to be well.]</ety> <def>Growing well;
recovering strength.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revaluation</ent><br/
<hw>Re*val`u*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A second or
new valuation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revamp</ent><br/
<hw>Re*vamp"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To vamp again;
hence, to patch up; to reconstruct.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reve</ent><br/
<hw>Reve</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To reave.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reve</ent><br/
<hw>Reve</hw>, <pos>n.</pos> <ety>[See <er>Reeve</er>.]</ety> <def>An
officer, steward, or governor.</def> <altsp>[Usually written
<asp>reeve</asp>.]</altsp> <mark>[Obs.]</mark> <rj><au>Piers
Plowman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reveal</ent><br/
<hw>Re*veal"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Revealed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Revealing</conjf>.]</vmorph> <ety>[F.
<ets>r<eacute/v<eacute/ler</ets>, L. <ets>revelare</ets>,
<ets>revelatum</ets>, to unveil, reveal; pref. <ets>re-</ets> re- +
<ets>velare</ets> to veil; fr. <ets>velum</ets> a veil. See
<er>Veil</er>.]</ety> <sn>1.</sn> <def>To make known (that which has
been concealed or kept secret); to unveil; to disclose; to
show.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Light was the wound, the prince's care unknown,<br/
She might not, would not, yet <qex>reveal</qex> her own.</q>
<rj><qau>Waller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Specifically, to communicate (that which could not
be known or discovered without divine or supernatural instruction or
agency).</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To communicate; disclose; divulge; unveil;
uncover; open; discover; impart; show.</syn> <usage> See
<er>Communicate</er>. -- <er>Reveal</er>, <er>Divulge</er>. To
<xex>reveal</xex> is literally to <xex>lift the veil</xex>, and thus
make known what was previously concealed; to <xex>divulge</xex> is to
scatter abroad among the people, or make publicly known. A mystery or
hidden doctrine may be <xex>revealed</xex>; something long confined to
the knowledge of a few is at length <xex>divulged</xex>. <ldquo/Time,
which <xex>reveals</xex> all things, is itself not to be
discovered.<rdquo/ <au>Locke.</au> <ldquo/A tragic history of facts
<xex>divulged</xex>.<rdquo/ <au>Wordsworth.</au></usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reveal</ent><br/
<hw>Re*veal"</hw>, <pos>n.</pos> <sn>1.</sn> <def>A revealing; a
disclosure.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Arch.)</fld> <def>The side of an opening for a
window, doorway, or the like, between the door frame or window frame and
the outer surface of the wall; or, where the opening is not filled with
a door, etc., the whole thickness of the wall; the jamb.</def>
<altsp>[Written also <asp>revel</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revealability</ent><br/
<hw>Re*veal`a*bil"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The quality
or state of being revealable; revealableness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revealable</ent><br/
<hw>Re*veal"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of being
revealed.</def> -- <wordforms><wf>Re*veal"a*ble*ness</wf>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revealer</ent><br/
<hw>Re*veal"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, reveals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revealment</ent><br/
<hw>Re*veal"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Act of
revealing.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revegetate</ent><br/
<hw>Re*veg"e*tate</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To vegetate
anew.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reveille</ent><br/
<hw>Re*veil"le</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>r<eacute/veil</ets>, fr. <ets>r<eacute/veiller</ets> to awake;
pref. <ets>re-</ets> re- + pref. <ets>es-</ets> (L. <ets>ex</ets>) +
<ets>veiller</ets> to awake, watch, L. <ets>vigilare</ets> to watch. The
English form was prob. taken by mistake from the French imper.
<ets>r<eacute/veillez</ets>,<ets>2d</ets> pers. pl. See
<er>Vigil</er>.]</ety> <fld>(Mil.)</fld> <def>The beat of drum, or bugle
blast, about break of day, to give notice that it is time for the
soldiers to rise, and for the sentinels to forbear challenging.</def>
<ldquo/Sound a <xex>reveille</xex>.<rdquo/ <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>For at dawning to assail ye<br/
Here no bugles sound <qex>reveille</qex>.</q> <rj><qau>Sir W.
Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revel</ent><br/
<hw>Rev"el</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Arch.)</fld> <def>See
<er>Reveal</er>.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revel</ent><br/
<hw>Rev"el</hw>, <pos>n.</pos> <ety>[OF. <ets>revel</ets> rebellion,
disorder, feast, sport. See <er>Revel</er>, <pos>v. i.</pos>]</ety>
<def>A feast with loose and noisy jollity; riotous festivity or
merrymaking; a carousal.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This day in mirth and <qex>revel</qex> to dispend.</q>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Some men ruin . . . their bodies by incessant
<qex>revels</qex>.</q> <rj><qau>Rambler.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Master of the revels</b></col>, <col><b>Revel
master</b></col></mcol>. <cd>Same as <cref>Lord of misrule</cref>, under
<er>Lord</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revel</ent><br/
<hw>Rev"el</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Reveled</conjf> <pr>(?)</pr> or <conjf>Revelled</conjf>; <pos>p.
pr. & vb. n.</pos> <conjf>Reveling</conjf> or
<conjf>Revelling</conjf>.]</vmorph> <ety>[OF. <ets>reveler</ets> to
revolt, rebel, make merry, fr. L. <ets>rebellare</ets>. See
<er>Rebel</er>.]</ety> <sn>1.</sn> <def>To feast in a riotous manner; to
carouse; to act the bacchanalian; to make merry.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To move playfully; to indulge without
restraint.</def> <ldquo/Where joy most <xex>revels</xex>.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revel</ent><br/
<hw>Re*vel"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>revellere</ets>; <ets>re-</ets> + <ets>vellere</ets> to pluck,
pull.]</ety> <def>To draw back; to retract.</def> <mark>[Obs.]</mark>
<rj><au>Harvey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revelate</ent><br/
<hw>Rev"e*late</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>revelatus</ets>, p. p. of <ets>revelare</ets> to reveal.]</ety>
<def>To reveal.</def> <mark>[Obs.]</mark> <rj><au>Frith.
Barnes.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revelation</ent><br/
<hw>Rev`e*la"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>r<eacute/v<eacute/lation</ets>, L. <ets>revelatio</ets>. See
<er>Reveal</er>.]</ety> <sn>1.</sn> <def>The act of revealing,
disclosing, or discovering to others what was before unknown to
them.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is revealed.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Theol.)</fld> <sd>(a)</sd> <def>The act of
revealing divine truth.</def> <sd>(b)</sd> <def>That which is revealed
by God to man; esp., the Bible.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>By <qex>revelation</qex> he made known unto me the mystery, as I
wrote afore in few words.</q> <rj><qau>Eph. iii. 3.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Specifically, the last book of the sacred canon,
containing the prophecies of <person>St. John</person>; the
<altname>Apocalypse</altname> or <altname>Book of Revelation</altname>
or <altname>The Revelation of Saint John</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revelator</ent><br/
<hw>Rev"e*la`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.]</ety>
<def>One who makes a revelation; a revealer.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reveler</ent><br/
<hw>Rev"el*er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Written also
<ets>reveller</ets>.]</ety> <def>One who revels.</def> <ldquo/Moonshine
<xex>revelers</xex>.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revellent</ent><br/
<hw>Re*vel"lent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>revellens</ets>, p. pr. of <ets>revellere</ets>. See
<er>Revel</er>, <pos>v. t.</pos>]</ety> <def>Causing revulsion;
revulsive.</def> -- <def2><pos>n.</pos> <fld>(Med.)</fld> <def>A
revulsive medicine.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revelment</ent><br/
<hw>Rev"el*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
reveling.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revelous</ent><br/
<hw>Rev"el*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OF.
<ets>reveleus</ets>.]</ety> <def>Fond of festivity; given to merrymaking
or reveling.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Companionable and <qex>revelous</qex> was she.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revel-rout</ent><br/
<hw>Rev"el-rout`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Rout</er>.]</ety> <sn>1.</sn> <def>Tumultuous festivity;
revelry.</def> <mark>[Obs.]</mark> <rj><au>Rowe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A rabble; a riotous assembly; a mob.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revelry</ent><br/
<hw>Rev"el*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See <er>Revel</er>,
<pos>v. i. & n.</pos>]</ety> <def>The act of engaging in a revel; noisy
festivity; reveling.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And pomp and feast and <qex>revelry</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revendicate</ent><br/
<hw>Re*ven"di*cate</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Revendicated</conjf>
<pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Revendicating</conjf>.]</vmorph><ety>[Cf. F.
<ets>revendiquer</ets>. See <er>Revenge</er>.]</ety> <def>To reclaim; to
demand the restoration of.</def> <mark>[R.]</mark> <rj><au>Vattel
(Trans.).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revendication</ent><br/
<hw>Re*ven`di*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>revendication</ets>.]</ety> <def>The act of revendicating.</def>
<mark>[R.]</mark> <rj><au>Vattel (Trans.)</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revenge</ent><br/
<hw>Re*venge"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Revenged</conjf> <pr>(?)</pr>, <pos>p. pr. & vb.
n.</pos> <conjf>Revenging</conjf> <pr>(<?/)</pr>.]</vmorph> <ety>[OF.
<ets>revengier</ets>, F. <ets>revancher</ets>; pref. <ets>re-</ets> re-
+ OF. <ets>vengier</ets> to avenge, revenge, F. <ets>venger</ets>, L.
<ets>vindicare</ets>. See <er>Vindicate</er>, <er>Vengerance</er>, and
cf. <er>Revindicate</er>.]</ety> <sn>1.</sn> <def>To inflict harm in
return for, as an injury, insult, etc.; to exact satisfaction for, under
a sense of injury; to avenge; -- followed either by the wrong received,
or by the person or thing wronged, as the object, or by the reciprocal
pronoun as direct object, and a preposition before the wrong done or the
wrongdoer.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>revenge</qex> the death of our fathers.</q> <rj><qau>Ld.
Berners.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The gods are just, and will <qex>revenge</qex> our cause.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Come, Antony, and young Octavius, come,<br/
<qex>Revenge</qex> yourselves alone on Cassius.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To inflict injury for, in a spiteful, wrong, or
malignant spirit; to wreak vengeance for maliciously.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To avenge; vindicate. See
<er>Avenge</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revenge</ent><br/
<hw>Re*venge"</hw>, <pos>v. i.</pos> <def>To take vengeance; --
with</def> <xex>upon</xex>. <mark>[Obs.]</mark> <ldquo/A bird that will
<xex>revenge</xex> upon you all.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revenge</ent><br/
<hw>Re*venge"</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act of revenging;
vengeance; retaliation; a returning of evil for evil.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Certainly, in taking <qex>revenge</qex>, a man is even with his
enemy; but in passing it over he is superior.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The disposition to revenge; a malignant wishing of
evil to one who has done us an injury.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Revenge</qex> now goes<br/
To lay a complot to betray thy foes.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The indulgence of <qex>revenge</qex> tends to make men more savage
and cruel.</q> <rj><qau>Kames.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revengeable</ent><br/
<hw>Re*venge"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of
being revenged; <as>as, <ex>revengeable</ex> wrong</as>.</def>
<rj><au>Warner.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revengeance</ent><br/
<hw>Re*venge"ance</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Vengeance;
revenge.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revengeful</ent><br/
<hw>Re*venge"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Full of, or prone
to, revenge; vindictive; malicious; revenging; wreaking
revenge.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If thy <qex>revengeful</qex> heart can not forgive.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>May my hands . . . <br/
Never brandish more <qex>revengeful</qex> steel.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Vindictive; vengeful; resentful;
malicious.</syn><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Re*venge"ful*ly</wf>, <pos>adv.</pos> --
<wf>Re*venge"ful*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revengeless</ent><br/
<hw>Re*venge"less</hw>, <pos>a.</pos> <def>Unrevenged.</def>
<mark>[Obs.]</mark> <rj><au>Marston.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revengement</ent><br/
<hw>Re*venge"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Revenge.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He 'll breed <qex>revengement</qex> and a scourge for me.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revenger</ent><br/
<hw>Re*ven"ger</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
revenges.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revenging</ent><br/
<hw>Re*ven"ging</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Executing revenge;
revengeful.</def> -- <wordforms><wf>Re*ven"ging*ly</wf>,
<pos>adv.</pos></wordforms> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revenue</ent><br/
<hw>Rev"e*nue</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>revenu</ets>, OF. <ets>revenue</ets>, fr. <ets>revenir</ets> to
return, L. <ets>revenire</ets>; pref. <ets>re-</ets> re- +
<ets>venire</ets> to come. See <er>Come</er>.]</ety> <sn>1.</sn>
<def>That which returns, or comes back, from an investment; the annual
rents, profits, interest, or issues of any species of property, real or
personal; income.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Do not anticipate your <qex>revenues</qex> and live upon air till
you know what you are worth.</q> <rj><qau>Gray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence, return; reward; <as>as, a <ex>revenue</ex> of
praise</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The annual yield of taxes, excise, customs, duties,
rents, etc., which a nation, state, or municipality collects and
receives into the treasury for public use.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Revenue cutter</b></col>, <cd>an armed government vessel
employed to enforce revenue laws, prevent smuggling, etc.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reverb</ent><br/
<hw>Re*verb"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To echo.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reverberant</ent><br/
<hw>Re*ver"ber*ant</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>reverberans</ets>, p. pr. : cf. F.
<ets>r<eacute/verb<eacute/rant</ets>. See <er>Reverberate</er>.]</ety>
<def>Having the quality of reverberation; reverberating.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reverberate</ent><br/
<hw>Re*ver"ber*ate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>reverberatus</ets>, p. p. of <ets>reverberare</ets> to strike back,
repel; pref. <ets>re-</ets> re- + <ets>verberare</ets> to lash, whip,
beat, fr. <ets>verber</ets> a lash, whip, rod.]</ety> <sn>1.</sn>
<def>Reverberant.</def> <mark>[Obs.]</mark> <ldquo/The
<xex>reverberate</xex> hills.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Driven back, as sound; reflected.</def>
<mark>[Obs.]</mark> <rj><au>Drayton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reverberate</ent><br/
<hw>Re*ver"ber*ate</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Reverberated</conjf>
<pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Reverberating</conjf>.]</vmorph> <sn>1.</sn> <def>To return or
send back; to repel or drive back; to echo, as sound; to reflect, as
light, as light or heat.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Who, like an arch, <qex>reverberates</qex><br/
The voice again.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To send or force back; to repel from side to side;
<as>as, flame is <ex>reverberated</ex> in a furnace</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Hence, to fuse by reverberated heat.</def>
<mark>[Obs.]</mark> <ldquo/<xex>Reverberated</xex> into glass.<rdquo/
<rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reverberate</ent><br/
<hw>Re*ver"ber*ate</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To resound;
to echo.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To be driven back; to be reflected or repelled, as
rays of light; to be echoed, as sound.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reverberation</ent><br/
<hw>Re*ver`ber*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[CF. F.
<ets>r<eacute/verb<eacute/ration</ets>.]</ety> <def>The act of
reverberating; especially, the act of reflecting light or heat, or
reechoing sound; <as>as, the <ex>reverberation</ex> of rays from a
mirror; the <ex>reverberation</ex> of rays from a mirror; the
<ex>reverberation</ex> of voices; the <ex>reverberation</ex> of heat or
flame in a furnace.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reverberative</ent><br/
<hw>Re*ver"ber*a*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of the
nature of reverberation; tending to reverberate; reflective.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This <qex>reverberative</qex> influence is that which we have
intended above, as the influence of the mass upon its centers.</q>
<rj><qau>I. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reverberator</ent><br/
<hw>Re*ver"ber*a`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or
that which, produces reverberation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reverberatory</ent><br/
<hw>Re*ver"ber*a*to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Producing
reverberation; acting by reverberation; reverberative.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Reverberatory furnace</b></col>. <cd>See the Note under
<er>Furnace</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reverberatory</ent><br/
<hw>Re*ver"ber*a*to*ry</hw>, <pos>n.</pos> <def>A reverberatory
furnace.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reverdure</ent><br/
<hw>Re*ver"dure</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To cover again
with verdure.</def> <rj><au>Ld. Berners.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revere</ent><br/
<hw>Re*vere"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Revered</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Revering</conjf>.]</vmorph> <ety>[L. <ets>revereri</ets>; pref.
<ets>re-</ets> re- + <ets>vereri</ets> to fear, perh. akin to E.
<ets>wary</ets>: cf. F. <ets>r<eacute/v<eacute/rer</ets>.]</ety> <def>To
regard with reverence, or profound respect and affection, mingled with
awe or fear; to venerate; to reverence; to honor in
estimation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Marcus Aurelius, whom he rather <qex>revered</qex> as his father
than treated as his partner in the empire.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To venerate; adore; reverence.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reverence</ent><br/
<hw>Rev"er*ence</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>r<eacute/v<eacute/rence</ets>, L. <ets>reverentia</ets>. See
<er>Reverent</er>.]</ety> <sn>1.</sn> <def>Profound respect and esteem
mingled with fear and affection, as for a holy being or place; the
disposition to revere; veneration.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If thou be poor, farewell thy <qex>reverence</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Reverence</qex>, which is the synthesis of love and fear.</q>
<rj><qau>Coleridge.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>When discords, and quarrels, and factions, are carried openly and
audaciously, it is a sign the <qex>reverence</qex> of government
islost.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Formerly, as in Chaucer, <xex>reverence</xex> denoted
<ldquo/respect<rdquo/ <ldquo/honor<rdquo/, without awe or
fear.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The act of revering; a token of respect or
veneration; an obeisance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Make twenty <qex>reverences</qex> upon receiving . . . about
twopence.</q> <rj><qau>Goldsmith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And each of them doeth all his diligence<br/
To do unto the feast <qex>reverence</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which deserves or exacts manifestations of
reverence; reverend character; dignity; state.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I am forced to lay my <qex>reverence</qex> by.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A person entitled to be revered; -- a title applied
to priests or other ministers with the pronouns <xex>his</xex> or
<xex>your</xex>; sometimes poetically to a father.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<cs><p><mcol><col><b>Save your reverence</b></col>, <col><b>Saving your
reverence</b></col></mcol>, <cd>an apologetical phrase for an unseemly
expression made in the presence of a priest or clergyman.</cd> --
<col><b>Sir reverence</b></col>, <cd>a contracted form of <altname>Save
your reverence</altname>.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>Such a one as a man may not speak of, without he say.
<ldquo/<qex>Sir reverence</qex>.<rdquo/</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <col><b>To do reverence</b></col>, <cd>to show reverence or honor;
to perform an act of reverence.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>Now lies he there,<br/
And none so poor <qex>to do</qex> him <qex>reverence</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p></cs>

<p><syn><b>Syn.</b> -- Awe; honor; veneration; adoration; dread.</syn>
<usage> -- <er>Awe</er>, <er>Reverence</er>, <er>Dread</er>,
<er>Veneration</er>. <xex>Reverence</xex> is a strong sentiment of
respect and esteem, sometimes mingled slightly with fear; as,
<xex>reverence</xex> for the divine law. <xex>Awe</xex> is a mixed
feeling of sublimity and dread in view of something great or terrible,
sublime or sacred; as, <xex>awe</xex> at the divine presence. It does
not necessarily imply love. <xex>Dread</xex> is an anxious fear in view
of an impending evil; as, <xex>dread</xex> of punishment.
<xex>Veneration</xex> is reverence in its strongest manifestations. It
is the highest emotion we can exercise toward human beings. Exalted and
noble objects produce <xex>reverence</xex>; terrific and threatening
objects awaken <xex>dread</xex>; a sense of the divine presence fills us
with <xex>awe</xex>; a union of wisdom and virtue in one who is advanced
in years inspires us with <xex>veneration</xex>.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reverence</ent><br/
<hw>Rev"er*ence</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Reverenced</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Reverencing</conjf> <pr>(?)</pr>.]</vmorph> <def>To regard or
treat with reverence; to regard with respect and affection mingled with
fear; to venerate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Let . . . the wife see that she <qex>reverence</qex> her
husband.</q> <rj><qau>Eph. v. 33.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Those that I <qex>reverence</qex> those I fear, the wise.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reverencer</ent><br/
<hw>Rev"er*en*cer</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who regards
with reverence.</def> <ldquo/<xex>Reverencers</xex> of crowned
heads.<rdquo/ <rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reverend</ent><br/
<hw>Rev"er*end</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F.
<ets>r<eacute/v<eacute/rend</ets>, L. <ets>reverendus</ets>, fr.
<ets>revereri</ets>. See <er>Revere</er>.]</ety> <def>Worthy of
reverence; entitled to respect mingled with fear and affection;
venerable.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>reverend</qex> sire among them came.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>They must give good example and <qex>reverend</qex> deportment in
the face of their children.</q> <rj><qau>Jer. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ This word is commonly given as a title of respect to
ecclesiastics. A clergyman is styled the <xex>reverend</xex>; a dean,
the <xex>very reverend</xex>; a bishop, the <xex>right reverend</xex>;
an archbishop, the <xex>most reverend</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reverendly</ent><br/
<hw>Rev"er*end*ly</hw>, <pos>adv.</pos> <def>Reverently.</def>
<mark>[Obs.]</mark> <rj><au>Foxe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reverent</ent><br/
<hw>Rev"er*ent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>reverens</ets>, <ets>-entis</ets>, p. pr. of <ets>revereri</ets>.
See <er>Revere</er>.]</ety> <sn>1.</sn> <def>Disposed to revere;
impressed with reverence; submissive; humble; respectful; <as>as,
<ex>reverent</ex> disciples</as>.</def> <ldquo/They . . . prostrate fell
before him <xex>reverent</xex>.<rdquo/ <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Expressing reverence, veneration, devotion, or
submission; <as>as, <ex>reverent</ex> words; <ex>reverent</ex>
behavior</as>.</def> <rj><au>Joye.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reverential</ent><br/
<hw>Rev`er*en"tial</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>r<eacute/v<eacute/renciel</ets>. See <er>Reverence</er>.]</ety>
<def>Proceeding from, or expressing, reverence; having a reverent
quality; reverent; <as>as, <ex>reverential</ex> fear or awe</as>.</def>
<ldquo/A <xex>reverential</xex> esteem of things sacred.<rdquo/
<rj><au>South.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reverentially</ent><br/
<hw>Rev`er*en"tial*ly</hw>, <pos>adv.</pos> <def>In a reverential
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reverently</ent><br/
<hw>Rev"er*ent*ly</hw>, <pos>adv.</pos> <def>In a reverent manner; in
respectful regard.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reverer</ent><br/
<hw>Re*ver"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
reveres.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revery</ent><br/
<ent>Reverie</ent><br/
<mhw>{ <hw>Rev"er*ie</hw> <pr>(?)</pr>, <hw>Rev"er*y</hw> <pr>(?)</pr>,
}</mhw> <pos>n.</pos>; <plu><it>pl.</it> <plw>Reveries</plw>
<pr>(#)</pr>.</plu> <ety>[F. <ets>r<eacute/verie</ets>, fr.
<ets>r<ecir/ver</ets> to dream, rave, be light-headed. Cf.
<er>Rave</er>.]</ety> <sn>1.</sn> <def>A loose or irregular train of
thought occurring in musing or mediation; deep musing; daydream.</def>
<ldquo/Rapt in nameless <xex>reveries</xex>.<rdquo/
<rj><au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>When ideas float in our mind without any reflection or regard of
the understanding, it is that which the French call <qex>revery</qex>,
our language has scarce a name for it.</q>
<rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An extravagant conceit of the fancy; a vision.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>There are infinite <qex>reveries</qex> and numberless
extravagancies pass through both [wise and foolish minds].</q>
<rj><qau>Addison.</qau></rj> <-- sic. left out a "which"? --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revers</ent><br/
\'d8<hw>Re*vers"</hw> <pr>(r<eit/*v<acir/r"; <it>colloq.</it>
r<eit/*v<emac/r", r<eit/*v<etil/r")</pr>, <pos>n. sing & pl.</pos>
<ety>[F. See <er>Reverse</er>, <pos>n.</pos>]</ety> <fld>(Dressmaking,
Tailoring, etc.)</fld> <def>A part turned or folded back so as to show
the inside, or a piece put on in imitation of such a part, as the lapel
of a coat.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Reversal</ent><br/
<hw>Re*ver"sal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Reverse</er>.]</ety> <def>Intended to reverse; implying
reversal.</def> <mark>[Obs.]</mark> <rj><au>Bp. Burnet.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reversal</ent><br/
<hw>Re*ver"sal</hw>, <pos>n.</pos> <ety>[From <er>Reverse</er>.]</ety>
<sn>1.</sn> <def>The act of reversing; the causing to move or face in an
opposite direction, or to stand or lie in an inverted position; <as>as,
the <ex>reversal</ex> of a rotating wheel; the <ex>reversal</ex> of
objects by a convex lens.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A change or overthrowing; <as>as, the
<ex>reversal</ex> of a judgment, which amounts to an official
declaration that it is false; the <ex>reversal</ex> of an attainder, or
of an outlawry, by which the sentence is rendered void.</as></def>
<rj><au>Blackstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reverse</ent><br/
<hw>Re*verse"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OE.
<ets>revers</ets>, OF. <ets>revers</ets>, L. <ets>reversus</ets>, p. p.
of <ets>revertere</ets>. See <er>Revert</er>.]</ety> <sn>1.</sn>
<def>Turned backward; having a contrary or opposite direction; hence;
opposite or contrary in kind; <as>as, the <ex>reverse</ex> order or
method</as>.</def> <ldquo/A vice <xex>reverse</xex> unto this.<rdquo/
<rj><au>Gower.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Turned upside down; greatly disturbed.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He found the sea diverse<br/
With many a windy storm <qex>reverse</qex>.</q>
<rj><qau>Gower.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Bot. & Zool.)</fld> <def>Reversed; <as>as, a
<ex>reverse</ex> shell</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Reverse bearing</b></col> <fld>(Surv.)</fld>, <cd>the
bearing of a back station as observed from the station next in
advance.</cd> -- <col><b>Reverse curve</b></col> <fld>(Railways)</fld>,
<cd>a curve like the letter <universbold>S</universbold>, formed of two
curves bending in opposite directions.</cd> -- <col><b>Reverse
fire</b></col> <fld>(Mil.)</fld>, <cd>a fire in the rear.</cd> --
<col><b>Reverse operation</b></col> <fld>(Math.)</fld>, <cd>an operation
the steps of which are taken in a contrary order to that in which the
same or similar steps are taken in another operation considered as
<xex>direct</xex>; an operation in which that is sought which in another
operation is given, and that given which in the other is sought; as,
finding the length of a pendulum from its time of vibration is the
<xex>reverse operation</xex> to finding the time of vibration from the
length.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1234 --></p>

<p><ent>Reverse</ent><br/
<hw>Re*verse"</hw> <pr>(r<esl/*v<etil/rs")</pr>, <pos>n.</pos> <ety>[Cf.
F. <ets>revers</ets>. See <er>Reverse</er>, <pos>a.</pos>]</ety>
<sn>1.</sn> <def>That which appears or is presented when anything, as a
lance, a line, a course of conduct, etc., is reverted or turned contrary
to its natural direction.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He did so with the <qex>reverse</qex> of the lance.</q>
<rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is directly opposite or contrary to
something else; a contrary; an opposite.</def>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And then mistook <qex>reverse</qex> of wrong for right.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To make everything the <qex>reverse</qex> of what they have seen,
is quite as easy as to destroy.</q> <rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The act of reversing; complete change; reversal;
hence, total change in circumstances or character; especially, a change
from better to worse; misfortune; a check or defeat; <as>as, the enemy
met with a <ex>reverse</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The strange <qex>reverse</qex> of fate you see;<br/
I pitied you, now you may pity me.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>By a <qex>reverse</qex> of fortune, Stephen becomes rich.</q>
<rj><qau>Lamb.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The back side; <as>as, the <ex>reverse</ex> of a
drum or trench; the <ex>reverse</ex> of a medal or coin, that is, the
side opposite to the <ant>obverse</ant></as>. See
<er>Obverse</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A thrust in fencing made with a backward turn of the
hand; a backhanded stroke.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Surg.)</fld> <def>A turn or fold made in bandaging,
by which the direction of the bandage is changed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reverse</ent><br/
<hw>Re*verse"</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Reversed</conjf> <pr>(r<esl/*v<etil/rst")</pr>;<pos>p. pr. & vb.
n.</pos> <conjf>Reversing</conjf>.]</vmorph> <ety>[See <er>Reverse</er>,
<pos>a.</pos>, and cf. <er>Revert</er>.]</ety> <sn>1.</sn> <def>To turn
back; to cause to face in a contrary direction; to cause to
depart.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And that old dame said many an idle verse,<br/
Out of her daughter's heart fond fancies to <qex>reverse</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To cause to return; to recall.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>And to his fresh remembrance did <qex>reverse</qex><br/
The ugly view of his deformed crimes.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To change totally; to alter to the
opposite.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Reverse</qex> the doom of death.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>She <qex>reversed</qex> the conduct of the celebrated vicar of
Bray.</q> <rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To turn upside down; to invert.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A pyramid <qex>reversed</qex> may stand upon his point if balanced
by admirable skill.</q> <rj><qau>Sir W. Temple.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Hence, to overthrow; to subvert.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>These can divide, and these <qex>reverse</qex>, the state.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Custom . . . <qex>reverses</qex> even the distinctions of good and
evil.</q> <rj><qau>Rogers.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Law)</fld> <def>To overthrow by a contrary
decision; to make void; to under or annual for error; <as>as, to
<ex>reverse</ex> a judgment, sentence, or decree</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Reverse arms</b></col> <fld>(Mil.)</fld>, <cd>a position
of a soldier in which the piece passes between the right elbow and the
body at an angle of 45<deg/, and is held as in the illustration.</cd> --
<mcol><col><b>To reverse an engine</b></col> <it>or</it> <col><b>To
reverse a machine</b></col></mcol>, <cd>to cause it to perform its
revolutions or action in the opposite direction.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To overturn; overset; invert; overthrow; subvert;
repeal; annul; revoke; undo.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reverse</ent><br/
<hw>Re*verse"</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To return; to
revert.</def> <mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To become or be reversed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reversed</ent><br/
<hw>Re*versed"</hw> <pr>(r<esl/*v<etil/rst")</pr>, <pos>a.</pos>
<sn>1.</sn> <def>Turned side for side, or end for end; changed to the
contrary;</def> <specif>specifically</specif> <fld>(Bot. & Zool.)</fld>,
<def>sinistrorse or sinistral; <as>as, a <ex>reversed</ex>, or
sinistral, spiral or shell</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>Annulled and the contrary
substituted; <as>as, a <ex>reversed</ex> judgment or
decree</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Reversed positive</b></col> <it>or</it>
<col><b>Reversed negative</b></col></mcol> <fld>(Photog.)</fld>, <cd>a
picture corresponding with the original in light and shade, but reversed
as to right and left.</cd> <rj><au>Abney.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reversedly</ent><br/
<hw>Re*vers"ed*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a reversed
way.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reverseless</ent><br/
<hw>Re*verse"less</hw>, <pos>a.</pos> <def>Irreversible.</def>
<mark>[R.]</mark> <rj><au>A. Seward.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reversely</ent><br/
<hw>Re*verse"ly</hw>, <pos>adv.</pos> <def>In a reverse manner; on the
other hand; on the opposite.</def> <rj><au>Bp. Pearson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reverser</ent><br/
<hw>Re*vers"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
reverses.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reversibility</ent><br/
<hw>Re*vers`i*bil"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The quality
of being reversible.</def> <rj><au>Tyndall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reversible</ent><br/
<hw>Re*vers"i*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>r<eacute/versible</ets> revertible, reversionary.]</ety>
<sn>1.</sn> <def>Capable of being reversed; <as>as, a chair or seat
having a <ex>reversible</ex> back; a <ex>reversible</ex> judgment or
sentence</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence, having a pattern or finished surface on both
sides, so that either may be used; -- said of fabrics.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Reversible lock</b></col>, <cd>a lock that may be applied
to a door opening in either direction, or hinged to either jamb.</cd> --
<col><b>Reversible process</b></col>. <cd>See under
<er>Process</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reversibly</ent><br/
<hw>Re*vers"i*bly</hw>, <pos>adv.</pos> <def>In a reversible
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reversing</ent><br/
<hw>Re*vers"ing</hw>, <pos>a.</pos> <def>Serving to effect reversal, as
of motion; capable of being reversed.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Reversing engine</b></col>, <cd>a steam engine having a
reversing gear by means of which it can be made to run in either
direction at will.</cd> -- <col><b>Reversing gear</b></col>
<fld>(Mach.)</fld>, <cd>gear for reversing the direction of rotation at
will.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reversion</ent><br/
<hw>Re*ver"sion</hw> <pr>(r<esl/*v<etil/r"sh<ucr/n)</pr>, <pos>n.</pos>
<ety>[F. <ets>r<eacute/version</ets>, L. <ets>reversio</ets> a turning
back. See <er>Revert</er>.]</ety> <sn>1.</sn> <def>The act of returning,
or coming back; return.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>After his <qex>reversion</qex> home, [he] was spoiled, also, of
all that he brought with him.</q> <rj><qau>Foxe.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which reverts or returns; residue.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The small <qex>reversion</qex> of this great navy which came home
might be looked upon by religious eyes as relics.</q>
<rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Law)</fld> <def>The returning of an estate to the
grantor or his heirs, by operation of law, after the grant has
terminated; hence, the residue of an estate left in the proprietor or
owner thereof, to take effect in possession, by operation of law, after
the termination of a limited or less estate carved out of it and
conveyed by him.</def> <rj><au>Kent.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Hence, a right to future possession or enjoyment;
succession.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>For even <qex>reversions</qex> are all begged before.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Annuities)</fld> <def>A payment which is not to be
received, or a benefit which does not begin, until the happening of some
event, as the death of a living person.</def> <rj><au>Brande &
C.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Biol.)</fld> <def>A return towards some ancestral
type or character; atavism.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Reversion of series</b></col> <fld>(Alg.)</fld>, <cd>the
act of reverting a series. See <cref>To revert a series</cref>, under
<er>Revert</er>, <pos>v. t.</pos></cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reversionary</ent><br/
<hw>Re*ver"sion*a*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Law)</fld>
<def>Of or pertaining to a reversion; involving a reversion; to be
enjoyed in succession, or after the termination of a particular estate;
<as>as, a <ex>reversionary</ex> interest or right</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reversionary</ent><br/
<hw>Re*ver"sion*a*ry</hw>, <pos>n.</pos> <fld>(Law)</fld> <def>That
which is to be received in reversion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reversioner</ent><br/
<hw>Re*ver"sion*er</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Law)</fld>
<def>One who has a reversion, or who is entitled to lands or tenements,
after a particular estate granted is terminated.</def>
<rj><au>Blackstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reversis</ent><br/
<hw>Re*ver"sis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety> <def>A
certain game at cards.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revert</ent><br/
<hw>Re*vert"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Reverted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Reverting</conjf>.]</vmorph> <ety>[L. <ets>revertere</ets>,
<ets>reversum</ets>; pref. <ets>re-</ets> re- + <ets>vertere</ets> to
turn: cf. OF. <ets>revertir</ets>. See <er>Verse</er>, and cf.
<er>Reverse</er>.]</ety> <sn>1.</sn> <def>To turn back, or to the
contrary; to reverse.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Till happy chance <qex>revert</qex> the cruel scence.</q>
<rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The tumbling stream . . . <br/
<qex>Reverted</qex>, plays in undulating flow.</q>
<rj><qau>Thomson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To throw back; to reflect; to reverberate.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Chem.)</fld> <def>To change back. See
<er>Revert</er>, <pos>v. i.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To revert a series</b></col> <fld>(Alg.)</fld>, <cd>to
treat a series, as <mathex>y = a + bx + cx<exp>2</exp> + etc.</mathex>,
where one variable <it>y</it> is expressed in powers of a second
variable <it>x</it>, so as to find therefrom the second variable
<it>x</it>, expressed in a series arranged in powers of
<it>y</it>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revert</ent><br/
<hw>Re*vert"</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To return; to come
back.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>So that my arrows<br/
Would have <qex>reverted</qex> to my bow again.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>To return to the proprietor after
the termination of a particular estate granted by him.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Biol.)</fld> <def>To return, wholly or in part,
towards some preexistent form; to take on the traits or characters of an
ancestral type.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Chem.)</fld> <def>To change back, as from a soluble
to an insoluble state or the reverse; <as>thus, phosphoric acid in
certain fertilizers <ex>reverts</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revert</ent><br/
<hw>Re*vert"</hw>, <pos>n.</pos> <def>One who, or that which,
reverts.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>An active promoter in making the East Saxons converts, or rather
<qex>reverts</qex>, to the faith.</q> <rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reverted</ent><br/
<hw>Re*vert"ed</hw>, <pos>a.</pos> <def>Turned back; reversed.
Specifically: <fld>(Her.)</fld> Bent or curved twice, in opposite
directions, or in the form of an <universbold>S</universbold>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revertent</ent><br/
<hw>Re*vert"ent</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Med.)</fld>
<def>A remedy which restores the natural order of the inverted
irritative motions in the animal system.</def> <mark>[Obs.]</mark>
<rj><au>E. Darwin.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reverter</ent><br/
<hw>Re*vert"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One
who, or that which, reverts.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>Reversion.</def>
<rj><au>Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revertible</ent><br/
<hw>Re*vert"i*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of, or
admitting of, reverting or being reverted; <as>as, a <ex>revertible</ex>
estate</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revertive</ent><br/
<hw>Re*vert"ive</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Reverting, or
tending to revert; returning.</def> --
<wordforms><wf>Re*vert"ive*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><q>The tide <qex>revertive</qex>, unattracted, leaves<br/
A yellow waste of idle sands behind.</q>
<rj><qau>Thomson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revery</ent><br/
<hw>Rev"er*y</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Reverie</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revest</ent><br/
<hw>Re*vest"</hw> <pr>(r<emac/*v<ecr/st")</pr>, <pos>v. t.</pos>
<ety>[OF <ets>reverstir</ets>, F. <ets>rev<ecir/tir</ets>, L.
<ets>revestire</ets>; pref. <ets>re-</ets> re- + <ets>vestire</ets> to
clothe, fr. <ets>vestis</ets> a garment. See <er>Vestry</er>, and cf.
<er>Revet</er>.]</ety> <sn>1.</sn> <def>To clothe again; to cover, as
with a robe; to robe.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Her, nathless, . . . the enchanter<br/
Did thus <qex>revest</qex> and decked with due habiliments.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To vest again with possession or office; <as>as, to
<ex>revest</ex> a magistrate with authority</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revest</ent><br/
<hw>Re*vest"</hw>, <pos>v. i.</pos> <def>To take effect or vest again,
as a title; to revert to former owner; <as>as, the title or right
<ex>revests</ex> in A after alienation</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revestiary</ent><br/
<hw>Re*ves"ti*a*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL.
<ets>revestiarium</ets>: cf. F. <ets>revestiaire</ets>. See
<er>Revest</er>.]</ety> <def>The apartment, in a church or temple, where
the vestments, etc., are kept; -- now contracted into
<altname>vestry</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revestry</ent><br/
<hw>Re*ves"try</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Revestiary</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revestture</ent><br/
<hw>Re*vest"ture</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Vesture.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Rich<qex>revesture</qex> of cloth of gold.</q> <rj><qau>E.
Hall.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revet</ent><br/
<hw>Re*vet"</hw> <pr>(r<esl/*v<ecr/t")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Revetted</conjf>;<pos>p. pr. &
vb. n.</pos> <conjf>Revetting</conjf>.]</vmorph> <ety>[See
<er>Revetment</er>.]</ety> <fld>(Mil. & Civil Engineering)</fld> <def>To
face, as an embankment, with masonry, wood, or other material.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revetment</ent><br/
<hw>Re*vet"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>rev<ecir/tement</ets> the lining of a ditch, fr.
<ets>rev<ecir/tir</ets> to clothe, L. <ets>revestire</ets>. See
<er>Revest</er>, <pos>v. t.</pos>]</ety> <fld>(Fort. & Engin.)</fld>
<def>A facing of wood, stone, or any other material, to sustain an
embankment when it receives a slope steeper than the natural slope;
also, a retaining wall.</def> <altsp>[Written also
<asp>rev<ecir/tement</asp> <pr>(<?/)</pr>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revibrate</ent><br/
<hw>Re*vi"brate</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To vibrate back
or in return.</def> -- <wordforms><wf>Re`vi*bra"tion</wf> <pr>(#)</pr>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revict</ent><br/
<hw>Re*vict"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>revictus</ets>, p. p. of <ets>revincere</ets> to conquer.]</ety>
<def>To reconquer.</def> <mark>[Obs.]</mark> <rj><au>Bp.
Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reviction</ent><br/
<hw>Re*vic"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From L.
<ets>revivere</ets>, <ets>revictum</ets>, to live again; pref.
<ets>re-</ets> re- + <ets>vivere</ets> to live.]</ety> <def>Return to
life.</def> <mark>[Obs.]</mark> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revictual</ent><br/
<hw>Re*vict"ual</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To victual
again.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revie</ent><br/
<hw>Re*vie"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <sn>1.</sn> <def>To vie
with, or rival, in return.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Card Playing)</fld> <def>To meet a wager on, as on
the taking of a trick, with a higher wager.</def> <mark>[Obs.]</mark>
<rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revie</ent><br/
<hw>Re*vie"</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To exceed an
adversary's wager in card playing.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To make a retort; to bandy words.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Review</ent><br/
<hw>Re*view"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Reviewed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Reveiwing</conjf>.]</vmorph> <ety>[Pref. <ets>re-</ets>
+ <ets>view</ets>. Cf. <er>Review</er>, <pos>n.</pos> ]</ety>
<sn>1.</sn> <def>To view or see again; to look back on.</def>
<mark>[R.]</mark> <ldquo/I shall <xex>review</xex> Sicilia.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To go over and examine critically or
deliberately.</def> Specifically: <sd>(a)</sd> <def>To reconsider; to
revise, as a manuscript before printing it, or a book for a new
edition.</def> <sd>(b)</sd> <def>To go over with critical examination,
in order to discover exellences or defects; hence, to write a critical
notice of; <as>as, to <ex>review</ex> a new novel</as>.</def>
<sd>(c)</sd> <def>To make a formal or official examination of the state
of, as troops, and the like; <as>as, to <ex>review</ex> a
regiment</as>.</def> <sd>(d)</sd> <fld>(Law)</fld> <def>To reexamine
judically; <as>as, a higher court may <ex>review</ex> the proceedings
and judgments of a lower one</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To retrace; to go over again.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Shall I the long, laborious scene <qex>review</qex>?</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Review</ent><br/
<hw>Re*view"</hw>, <pos>v. i.</pos> <def>To look back; to make a
review.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Review</ent><br/
<hw>Re*view"</hw>, <pos>n.</pos> <ety>[F. <ets>revue</ets>, fr.
<ets>revu</ets>, p. p. of <ets>revoir</ets> to see again, L.
<ets>revidere</ets>; pref. <ets>re-</ets> re- + <ets>videre</ets> to
see. See <er>View</er>, <ets>and cf</ets>. <er>Revise</er>.]</ety>
<sn>1.</sn> <def>A second or repeated view; a reexamination; a
retrospective survey; a looking over again; <as>as, a <ex>review</ex> of
one's studies; a <ex>review</ex> of life</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An examination with a view to amendment or
improvement; revision; <as>as, an author's <ex>review</ex> of his
works</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A critical examination of a publication, with
remarks; a criticism; a critique.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A periodical containing critical essays upon matters
of interest, as new productions in literature, art, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>An inspection, as of troops under arms or of a naval
force, by a high officer, for the purpose of ascertaining the state of
discipline, equipments, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Law)</fld> <def>The judicial examination of the
proceedings of a lower court by a higher.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>A lesson studied or recited for a second
time.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Bill of review</b></col> <fld>(Equity)</fld>, <cd>a bill,
in the nature of proceedings in error, filed to procure an examination
and alteration or reversal of a final decree which has been duly signed
and enrolled.</cd> <au>Wharton.</au> -- <col><b>Commission of
review</b></col> <fld>(Eng. Eccl. Law)</fld>, <cd>a commission formerly
granted by the crown to revise the sentence of the court of
delegates.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Reexamination; resurvey; retrospect; survey;
reconsideration; revisal; revise; revision.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reviewable</ent><br/
<hw>Re*view"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of being
reviewed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reviewal</ent><br/
<hw>Re*view"al</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A review.</def>
<mark>[R.]</mark> <rj><au>Southey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reviewer</ent><br/
<hw>Re*view"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who reviews or
reexamines; an inspector; one who examines publications critically, and
publishes his opinion upon their merits; a professional critic of
books.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revigorate</ent><br/
<hw>Re*vig"or*ate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[LL.
<ets>revigoratus</ets>, p. p. of <ets>revigorare</ets>; L.
<ets>re-</ets> + <ets>vigor</ets> vigor.]</ety> <def>Having new vigor or
strength; invigorated anew.</def> <mark>[R.]</mark>
<rj><au>Southey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revigorate</ent><br/
<hw>Re*vig"or*ate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To give new
vigor to.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revile</ent><br/
<hw>Re*vile"</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Reviled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Reviling</conjf>.]</vmorph> <ety>[Pref. <ets>re-</ets> +
OF. <ets>aviler</ets> to make vile, depreciate, F. <ets>avilir</ets>;
<agrave/ (L. <ets>ad</ets>.) + <ets>vil</ets> vile. See
<er>Vile</er>.]</ety> <def>To address or abuse with opprobrious and
contemptuous language; to reproach.</def> <ldquo/And did not she herself
<xex>revile</xex> me there?<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Who, when he was <qex>reviled</qex>, <qex>reviled</qex> not
again.</q> <rj><qau>1 Pet. ii. 23.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To reproach; vilify; upbraid;
calumniate.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revile</ent><br/
<hw>Re*vile"</hw>, <pos>n.</pos> <def>Reproach; reviling.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The gracious Judge, without <qex>revile</qex>, replied.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revilement</ent><br/
<hw>Re*vile"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
reviling; also, contemptuous language; reproach; abuse.</def>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reviler</ent><br/
<hw>Re*vil"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
reviles.</def> <rj><au>1. Cor. vi. 10.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reviling</ent><br/
<hw>Re*vil"ing</hw>, <pos>n.</pos> <def>Reproach; abuse;
vilification.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Neither be ye afraid of their <qex>revilings</qex>.</q>
<rj><qau>Isa. li. 7.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reviling</ent><br/
<hw>Re*vil"ing</hw>, <pos>a.</pos> <def>Uttering reproaches; containing
reproaches.</def> -- <wordforms><wf>Re*vil"ing*ly</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revince</ent><br/
<hw>Re*vince"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[See
<er>Revict</er>.]</ety> <def>To overcome; to refute, as error.</def>
<mark>[Obs.]</mark> <rj><au>Foxe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revindicate</ent><br/
<hw>Re*vin"di*cate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>re-</ets> + <ets>vindicate</ets>. Cf. <er>Revindicate</er>,
<er>Revenge</er>.]</ety> <def>To vindicate again; to reclaim; to demand
and take back.</def> <rj><au>Mitford.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revirescence</ent><br/
<hw>Rev`i*res"cence</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>revirescens</ets>, p. pr. of <ets>revirescere</ets> to grow green
again.]</ety> <def>A growing green or fresh again; renewal of youth or
vigor.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revisable</ent><br/
<hw>Re*vis"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>That may be
revised.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revisal</ent><br/
<hw>Re*vis"al</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<er>Revise</er>.]</ety> <def>The act of revising, or reviewing and
reexamining for correction and improvement; revision; <as>as, the
<ex>revisal</ex> of a manuscript; the <ex>revisal</ex> of a proof sheet;
the <ex>revisal</ex> of a treaty.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revise</ent><br/
<hw>Re*vise"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Revised</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Revising</conjf>.]</vmorph> <ety>[F. <ets>reviser</ets>, fr. L.
<ets>revidere</ets>, <ets>revisum</ets>, to see again; pref.
<ets>re-</ets> re- + <ets>videre</ets>, <ets>visum</ets>, to see. See
<er>Review</er>, <er>View</er>.]</ety> <sn>1.</sn> <def>To look at again
for the detection of errors; to reexamine; to review; to look over with
care for correction; <as>as, to <ex>revise</ex> a writing; to
<ex>revise</ex> a translation.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Print.)</fld> <def>To compare (a proof) with a
previous proof of the same matter, and mark again such errors as have
not been corrected in the type.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To review, alter, and amend; <as>as, to
<ex>revise</ex> statutes; to <ex>revise</ex> an agreement; to
<ex>revise</ex> a dictionary.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>The Revised Version of the Bible</b></col>, <cd>a version
prepared in accordance with a resolution passed, in 1870, by both houses
of the Convocation of the Province of Canterbury, England. Both English
and American revisers were employed on the work. It was first published
in a complete form in 1885, and is a revised form of the Authorized
Version. See <cref>Authorized Version</cref>, under
<er>Authorized</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revise</ent><br/
<hw>Re*vise"</hw>, <pos>n.</pos> <sn>1.</sn> <def>A review; a
revision.</def> <rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Print.)</fld> <def>A second proof sheet; a proof
sheet taken after the first or a subsequent correction.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reviser</ent><br/
<hw>Re*vis"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
revises.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revision</ent><br/
<hw>Re*vi"sion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>r<eacute/vision</ets>, L. revisio.]</ety> <sn>1.</sn> <def>The act
of revising; reexamination for correction; review; <as>as, the
<ex>revision</ex> of a book or writing, or of a proof sheet; a
<ex>revision</ex> of statutes.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is made by revising.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Reexamination; revisal; revise; review.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revisionary</ent><br/
<ent>Revisional</ent><br/
<mhw>{ <hw>Re*vi"sion*al</hw> <pr>(?)</pr>, <hw>Re*vi"sion*a*ry</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <def>Of or pertaining to revision;
revisory.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1235 --></p>

<p><ent>Revisit</ent><br/
<hw>Re*vis"it</hw> <pr>(?)</pr>, <pos>v. t.</pos> <sn>1.</sn> <def>To
visit again.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To revise.</def> <mark>[Obs.]</mark> <rj><au>Ld.
Berners.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revisitation</ent><br/
<hw>Re*vis`it*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
revisiting.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revisory</ent><br/
<hw>Re*vi"so*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having the power
or purpose to revise; revising.</def> <rj><au>Story.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revitalize</ent><br/
<hw>Re*vi"tal*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To restore
vitality to; to bring back to life.</def> <rj><au>L. S.
Beale.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revivable</ent><br/
<hw>Re*viv"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>That may be
revived.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revival</ent><br/
<hw>Re*viv"al</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<er>Revive</er>.]</ety> <def>The act of reviving, or the state of being
revived.</def> Specifically: <sd>(a)</sd> <def>Renewed attention to
something, as to letters or literature.</def> <sd>(b)</sd> <def>Renewed
performance of, or interest in, something, as the drama and
literature.</def> <sd>(c)</sd> <def>Renewed interest in religion, after
indifference and decline; a period of religious awakening; special
religious interest.</def> <sd>(d)</sd> <def>Reanimation from a state of
langour or depression; -- applied to the health, spirits, and the
like.</def> <sd>(e)</sd> <def>Renewed pursuit, or cultivation, or
flourishing state of something, as of commerce, arts, agriculture.</def>
<sd>(f)</sd> <def>Renewed prevalence of something, as a practice or a
fashion.</def> <sd>(g)</sd> <fld>(Law)</fld> <def>Restoration of force,
validity, or effect; renewal; <as>as, the <ex>revival</ex> of a debt
barred by limitation; the <ex>revival</ex> of a revoked will,
etc.</as></def> <sd>(h)</sd> <def>Revivification, as of a metal. See
<er>Revivification</er>, 2.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revivalism</ent><br/
<hw>Re*viv"al*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The spirit of
religious revivals; the methods of revivalists.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revivalist</ent><br/
<hw>Re*viv"al*ist</hw>, <pos>n.</pos> <def>A clergyman or layman who
promotes revivals of religion; an advocate for religious revivals;
sometimes, specifically, a clergyman, without a particular charge, who
goes about to promote revivals. Also used adjectively.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revivalistic</ent><br/
<hw>Re*viv`al*is"tic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to
revivals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revive</ent><br/
<hw>Re*vive"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Revived</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Reviving</conjf>.]</vmorph> <ety>[F. <ets>revivere</ets>, L.
<ets>revivere</ets>; pref. <ets>re-</ets> re- + <ets>vivere</ets> to
live. See <er>Vivid</er>.]</ety> <sn>1.</sn> <def>To return to life; to
recover life or strength; to live anew; to become reanimated or
reinvigorated.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The Lord heard the voice of Elijah; and the soul of the child came
into again, and he <qex>revived</qex>.</q> <rj><qau>1 Kings xvii.
22.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence, to recover from a state of oblivion,
obscurity, neglect, or depression; <as>as, classical learning
<ex>revived</ex> in the fifteenth century</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Old Chem.)</fld> <def>To recover its natural or
metallic state, as a metal.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revive</ent><br/
<hw>Re*vive"</hw>, <pos>v. t.</pos> <ety>[Cf. F. <ets>reviver</ets>. See
<er>Revive</er>, <pos>v. i.</pos>]</ety> <sn>1.</sn> <def>To restore, or
bring again to life; to reanimate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Those bodies, by reason of whose mortality we died, shall be
<qex>revived</qex>.</q> <rj><qau>Bp. Pearson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To raise from coma, languor, depression, or
discouragement; to bring into action after a suspension.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Those gracious words <qex>revive</qex> my drooping thoughts.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Your coming, friends, <qex>revives</qex> me.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Hence, to recover from a state of neglect or disuse;
<as>as, to <ex>revive</ex> letters or learning</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To renew in the mind or memory; to bring to
recollection; to recall attention to; to reawaken.</def>
<ldquo/<xex>Revive</xex> the libels born to die.<rdquo/
<rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The mind has a power in many cases to <qex>revive</qex>
perceptions which it has once had.</q> <rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Old Chem.)</fld> <def>To restore or reduce to its
natural or metallic state; <as>as, to <ex>revive</ex> a metal after
calcination</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revivement</ent><br/
<hw>Re*vive"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Revival.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reviver</ent><br/
<hw>Re*viv"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, revives.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revivificate</ent><br/
<hw>Re`vi*vif"i*cate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>re-</ets> + <ets>vivificate</ets>: cf. L. <ets>revivificare</ets>,
<ets>revivificatum</ets>. Cf. <er>Revivify</er>.]</ety> <def>To revive;
to recall or restore to life.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revivification</ent><br/
<hw>Re*viv`i*fi*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>r<eacute/vivification</ets>.]</ety> <sn>1.</sn> <def>Renewal of
life; restoration of life; the act of recalling, or the state of being
recalled, to life.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Old Chem.)</fld> <def>The reduction of a metal from
a state of combination to its metallic state.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revivify</ent><br/
<hw>Re*viv"i*fy</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Cf. F.
<ets>r<eacute/vivifier</ets>, L. <ets>revivificare</ets>. See
<er>Vivify</er>.]</ety> <def>To cause to revive.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Some association may <qex>revivify</qex> it enough to make it
flash, after a long oblivion, into consciousness.</q> <rj><qau>Sir W.
Hamilton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reviving</ent><br/
<hw>Re*viv"ing</hw> <pr>(?)</pr>, <pos>a. & n.</pos> <def>Returning or
restoring to life or vigor; reanimating.</def> <au>Milton.</au> --
<wordforms><wf>Re*viv"ing*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reviviscency</ent><br/
<ent>Reviviscence</ent><br/
<mhw>{ <hw>Rev`i*vis"cence</hw> <pr>(?)</pr>, <hw>Rev`i*vis"cen*cy</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <def>The act of reviving, or the
state of being revived; renewal of life.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In this age we have a sort of <qex>reviviscence</qex>, not, I
fear, of the power, but of a taste for the power, of the early
times.</q> <rj><qau>Coleridge.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reviviscent</ent><br/
<hw>Rev`i*vis"cent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>reviviscens</ets>, p. pr. of<ets>reviviscere</ets> to revive; pref.
<ets>re-</ets> re- + <ets>viviscere</ets>, v. incho. fr.
<ets>vivere</ets> to live.]</ety> <def>Able or disposed to revive;
reviving.</def> <rj><au>E. Darwin.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revivor</ent><br/
<hw>Re*viv"or</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Eng. Law)</fld>
<def>Revival of a suit which is abated by the death or marriage of any
of the parties, -- done by a bill of <xex>revivor</xex>.</def>
<rj><au>Blackstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revocability</ent><br/
<hw>Rev`o*ca*bil"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The quality
of being revocable; <as>as, the <ex>revocability</ex> of a
law</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revocable</ent><br/
<hw>Rev"o*ca*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>revocabilis</ets>: cf. F. <ets>r<eacute/vocable</ets>. See
<er>Revoke</er>.]</ety> <def>Capable of being revoked; <as>as, a
<ex>revocable</ex> edict or grant; a <ex>revocable</ex>
covenant.</as></def><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Rev"o*ca*ble*ness</wf>, <pos>n.</pos> --
<wf>Rev"o*ca*bly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revocate</ent><br/
<hw>Rev"o*cate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>revocatus</ets>, p. p. of <ets>revocare</ets>. See
<er>Revoke</er>.]</ety> <def>To recall; to call back.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revocation</ent><br/
<hw>Rev`o*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>revocatio</ets>: cf. F. <ets>r<eacute/vocation</ets>.]</ety>
<sn>1.</sn> <def>The act of calling back, or the state of being
recalled; recall.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>One that saw the people bent for the <qex>revocation</qex> of
Calvin, gave him notice of their affection.</q>
<rj><qau>Hooker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The act by which one, having the right, annuls an
act done, a power or authority given, or a license, gift, or benefit
conferred; repeal; reversal; <as>as, the <ex>revocation</ex> of an
edict, a power, a will, or a license</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revocatory</ent><br/
<hw>Rev"o**ca*to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>revocatorius</ets>: cf. F. <ets>r<eacute/vocatoire</ets>.]</ety>
<def>Of or pertaining to revocation; tending to, or involving, a
revocation; revoking; recalling.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revoice</ent><br/
<hw>Re*voice"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To refurnish with
a voice; to refit, as an organ pipe, so as to restore its
tone.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revoke</ent><br/
<hw>Re*voke"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Revoked</conjf> <pr>(?)</pr>;<pos>p. pr. & vb. n.</pos>
<conjf>Revoking</conjf>.]</vmorph> <ety>[F. <ets>r<eacute/voquer</ets>,
L. <ets>revocare</ets>; pref. <ets>re-</ets> re- + <ets>vocare</ets> to
call, fr. <ets>vox</ets>, <ets>vocis</ets>, voice. See <er>Voice</er>,
and cf. <er>Revocate</er>.]</ety> <sn>1.</sn> <def>To call or bring
back; to recall.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The faint sprite he did <qex>revoke</qex> again,<br/
To her frail mansion of morality.</q> <rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence, to annul, by recalling or taking back; to
repeal; to rescind; to cancel; to reverse, as anything granted by a
special act; <as>as, , to <ex>revoke</ex> a will, a license, a grant, a
permission, a law, or the like</as>.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To hold back; to repress; to restrain.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>[She] still strove their sudden rages to <qex>revoke</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To draw back; to withdraw.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To call back to mind; to recollect.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>A man, by <qex>revoking</qex> and recollecting within himself
former passages, will be still apt to inculcate these sad memoris to his
conscience.</q> <rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To abolish; recall; repeal; rescind; countermand;
annul; abrogate; cancel; reverse. See <er>Abolish</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revoke</ent><br/
<hw>Re*voke"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <fld>(Card
Playing)</fld> <def>To fail to follow suit when holding a card of the
suit led, in violation of the rule of the game; to renege.</def>
<rj><au>Hoyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revoke</ent><br/
<hw>Re*voke"</hw>, <pos>n.</pos> <fld>(Card Playing)</fld> <def>The act
of revoking.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>She [Sarah Battle] never made a <qex>revoke</qex>.</q>
<rj><qau>Lamb.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revokement</ent><br/
<hw>Re*voke"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Revocation.</def>
<mark>[R.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revoker</ent><br/
<hw>Re*vok"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
revokes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revokingly</ent><br/
<hw>Re*vok"ing*ly</hw>, <pos>adv.</pos> <def>By way of
revocation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revolt</ent><br/
<hw>Re*volt"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Revolted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Revolting</conjf>.]</vmorph> <ety>[Cf. F.
<ets>r<eacute/voller</ets>, It. <ets>rivoltare</ets>. See
<er>Revolt</er>, <pos>n.</pos>]</ety> <sn>1.</sn> <def>To turn away; to
abandon or reject something; specifically, to turn away, or shrink, with
abhorrence.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>But this got by casting pearl to hogs,<br/
That bawl for freedom in their senseless mood,<br/
And still <qex>revolt</qex> when trith would set them free.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>His clear intelligence <qex>revolted</qex> from the dominant
sophisms of that time.</q> <rj><qau>J. Morley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence, to be faithless; to desert one party or
leader for another; especially, to renounce allegiance or subjection; to
rise against a government; to rebel.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Our discontented counties do <qex>revolt</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Plant those that have <qex>revolted</qex> in the van.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To be disgusted, shocked, or grossly offended;
hence, to feel nausea; -- with <xex>at</xex>; <as>as, the stomach
<ex>revolts</ex> at such food; his nature <ex>revolts</ex> at
cruelty.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revolt</ent><br/
<hw>Re*volt"</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To cause to turn
back; to roll or drive back; to put to flight.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To do violence to; to cause to turn away or shrink
with abhorrence; to shock; <as>as, to <ex>revolt</ex> the
feelings</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This abominable medley is made rather to <qex>revolt</qex> young
and ingenuous minds.</q> <rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To derive delight from what inflicts pain on any sentient
creatuure <qex>revolted</qex> his conscience and offended his
reason.</q> <rj><qau>J. Morley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revolt</ent><br/
<hw>Re*volt"</hw>, <pos>n.</pos> <ety>[F. <ets>r<eacute/volte</ets>, It.
<ets>rivolta</ets>, fr. <ets>rivolto</ets>, p. p. fr. L.
<ets>revolvere</ets>, <ets>revolutum</ets>. See <er>Revolve</er>.]</ety>
<sn>1.</sn> <def>The act of revolting; an uprising against legitimate
authority; especially, a renunciation of allegiance and subjection to a
government; rebellion; <as>as, the <ex>revolt</ex> of a province of the
Roman empire</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Who first seduced them to that foul <qex>revolt</qex>?</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A revolter.</def> <mark>[Obs.]</mark> <ldquo/Ingrate
<xex>revolts</xex>.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Insurrection; sedition; rebellion; mutiny. See
<er>Insurrection</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revolter</ent><br/
<hw>Re*volt"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
revolts.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revolting</ent><br/
<hw>Re*volt"ing</hw>, <pos>a.</pos> <def>Causing abhorrence mixed with
disgust; exciting extreme repugnance; loathsome; <as>as,
<ex>revolting</ex> cruelty</as>.</def> --
<wordforms><wf>Re*volt"ing*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revoluble</ent><br/
<hw>Rev"o*lu*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>revolubilis</ets> that may be rolled back. See
<er>Revolve</er>.]</ety> <def>Capable of revolving; rotatory;
revolving.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Us, then, to whom the thrice three year<br/
Hath filled his <qex>revoluble</qex> orb since our arrival here,<br/
I blame not.</q> <rj><qau>Chapman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revolute</ent><br/
<hw>Rev"o*lute</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>revolutus</ets>, p. p. of <ets>revolvere</ets>. See
<er>Revolve</er>.]</ety> <fld>(Bot. & Zool.)</fld> <def>Rolled backward
or downward.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ A <xex>revolute</xex> leaf is coiled downwards, with the
lower surface inside the coil. A leaf with <xex>revolute</xex> margins
has the edges rolled under, as in the <xex>Andromeda
polifilia</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revolution</ent><br/
<hw>Rev`o*lu"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>r<eacute/volution</ets>, L. <ets>revolutio</ets>. See
<er>Revolve</er>.]</ety> <sn>1.</sn> <def>The act of revolving, or
turning round on an axis or a center; the motion of a body round a fixed
point or line; rotation; <as>as, the <ex>revolution</ex> of a wheel, of
a top, of the earth on its axis, etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Return to a point before occupied, or to a point
relatively the same; a rolling back; return; <as>as, <ex>revolution</ex>
in an ellipse or spiral</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That fear<br/
Comes thundering back, with dreadful <qex>revolution</qex>,<br/
On my defenseless head.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The space measured by the regular return of a
revolving body; the period made by the regular recurrence of a measure
of time, or by a succession of similar events.</def> <ldquo/The short
<xex>revolution</xex> of a day.<rdquo/ <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Astron.)</fld> <def>The motion of any body, as a
planet or satellite, in a curved line or orbit, until it returns to the
same point again, or to a point relatively the same; -- designated as
the <xex>annual</xex>, <xex>anomalistic</xex>, <xex>nodical</xex>,
<xex>sidereal</xex>, or <xex>tropical revolution</xex>, according as the
point of return or completion has a fixed relation to the year, the
anomaly, the nodes, the stars, or the tropics; <as>as, the
<ex>revolution</ex> of the earth about the sun; the <ex>revolution</ex>
of the moon about the earth.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The term is sometimes applied in astronomy to the motion
of a single body, as a planet, about its own axis, but this motion is
usually called <xex>rotation</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Geom.)</fld> <def>The motion of a point, line, or
surface about a point or line as its center or axis, in such a manner
that a moving point generates a curve, a moving line a surface (called a
<xex>surface of revolution</xex>), and a moving surface a solid (called
a <xex>solid of revolution</xex>); <as>as, the <ex>revolution</ex> of a
right-angled triangle about one of its sides generates a cone; the
<ex>revolution</ex> of a semicircle about the diameter generates a
sphere.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>A total or radical change; <as>as, a
<ex>revolution</ex> in one's circumstances or way of
living</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The ability . . . of the great philosopher speedily produced a
complete <qex>revolution</qex> throughout the department.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Politics)</fld> <def>A fundamental change in
political organization, or in a government or constitution; the
overthrow or renunciation of one government, and the substitution of
another, by the governed.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The violence of <qex>revolutions</qex> is generally proportioned
to the degree of the maladministration which has produced them.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ When used without qualifying terms, the word is often
applied specifically, by way of eminence, to: (<xex>a</xex>) The English
<xex>Revolution</xex> in 1689, when William of Orange and Mary became
the reigning sovereigns, in place of James II. (<xex>b</xex>) The
American <xex>Revolution</xex>, beginning in 1775, by which the English
colonies, since known as the United States, secured their independence.
(<xex>c</xex>) The <xex>revolution</xex> in France in 1789, commonly
called <xex>the French Revolution</xex>, the subsequent revolutions in
that country being designated by their dates, as the
<xex>Revolution</xex> of 1830, of 1848, etc.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revolutionary</ent><br/
<hw>Rev`o*lu"tion*a*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>r<eacute/volutionnaire</ets>.]</ety> <def>Of or pertaining to a
revolution in government; tending to, or promoting, revolution; <as>as,
<ex>revolutionary</ex> war; <ex>revolutionary</ex> measures;
<ex>revolutionary</ex> agitators</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revolutionary</ent><br/
<hw>Rev`o*lu"tion*a*ry</hw>, <pos>n.</pos> <def>A revolutionist.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Dumfries was a Tory town, and could not tolerate a
<qex>revolutionary</qex>.</q> <rj><qau>Prof. Wilson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revolutioner</ent><br/
<hw>Rev`o*lu"tion*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who is
engaged in effecting a revolution; a revolutionist.</def>
<rj><au>Smollett.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revolutionism</ent><br/
<hw>Rev`o*lu"tion*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state of
being in revolution; revolutionary doctrines or principles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revolutionist</ent><br/
<hw>Rev`o*lu"tion*ist</hw>, <pos>n.</pos> <def>One engaged in effecting
a change of government; a favorer of revolution.</def>
<rj><au>Burke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revolutionize</ent><br/
<hw>Rev`o*lu"tion*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Revolutioniezed</conjf>
<pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Revolutionizing</conjf><pr>(?)</pr>.]</vmorph> <def>To change
completely, as by a revolution; <as>as, to <ex>revolutionize</ex> a
government</as>.</def> <rj><au>Ames.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The gospel . . . has <qex>revolutionized</qex> his soul.</q>
<rj><qau>J. M. Mason.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revolutive</ent><br/
<hw>Re*vol"u*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Inclined to
revolve things in the mind; meditative.</def> <mark>[Obs.]</mark>
<rj><au>Feltham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revolvable</ent><br/
<hw>Re*volv"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>That may be
revolved.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revolve</ent><br/
<hw>Re*volve"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Revolved</conjf><pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Revolving</conjf>.]</vmorph> <ety>[L.
<ets>revolvere</ets>, <ets>revolutum</ets>; pref. <ets>re-</ets> re- +
<ets>volvere</ets> to roll, turn round. See <er>Voluble</er>, and cf.
<er>Revolt</er>, <er>revolution</er>.]</ety> <sn>1.</sn> <def>To turn or
roll round on, or as on, an axis, like a wheel; to rotate, -- which is
the more specific word in this sense.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If the earth <qex>revolve</qex> thus, each house near the equator
must move a thousand miles an hour.</q> <rj><qau>I.
Watts.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To move in a curved path round a center; <as>as, the
planets <ex>revolve</ex> round the sun</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To pass in cycles; <as>as, the centuries
<ex>revolve</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To return; to pass.</def> <mark>[R.]</mark>
<rj><au>Ayliffe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revolve</ent><br/
<hw>Re*volve"</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To cause to turn,
as on an axis.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Then in the east her turn she shines,<br/
<qex>Revolved</qex> on heaven's great axile.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence, to turn over and over in the mind; to reflect
repeatedly upon; to consider all aspects of.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This having heard, straight I again <qex>revolved</qex><br/
The law and prophets.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revolvement</ent><br/
<hw>Re*volve"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Act of
revolving.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revolvency</ent><br/
<hw>Re*volv"en*cy</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act or state
of revolving; revolution.</def> <mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Its own <qex>revolvency</qex> upholds the world.</q>
<rj><qau>Cowper.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revolver</ent><br/
<hw>Re*volv"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, revolves; specifically, a firearm ( commonly a pistol) with
several chambers or barrels so arranged as to revolve on an axis, and be
discharged in succession by the same lock; a repeater.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revolving</ent><br/
<hw>Re*volv"ing</hw>, <pos>a.</pos> <def>Making a revolution or
revolutions; rotating; -- used also figuratively of time, seasons, etc.,
depending on the revolution of the earth.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>But grief returns with the <qex>revolving</qex> year.</q>
<rj><qau>Shelley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Revolving</qex> seasons, fruitless as they pass.</q>
<rj><qau>Cowper.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Revolving firearm</b></col>. <cd>See
<er>Revolver</er>.</cd> -- <col><b>Revolving light</b></col>, <cd>a
light or lamp in a lighthouse so arranged as to appear and disappear at
fixed intervals, either by being turned about an axis so as to show
light only at intervals, or by having its light occasionally intercepted
by a revolving screen.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revulse</ent><br/
<hw>Re*vulse"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>revulsus</ets>, p. p. of <ets>revellere</ets>.]</ety> <def>To pull
back with force.</def> <mark>[R.]</mark> <rj><au>Cowper.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revulsion</ent><br/
<hw>Re*vul"sion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>r<eacute/vulsion</ets>, L. <ets>revulsio</ets>, fr.
<ets>revellere</ets>, <ets>revulsum</ets>, to pluck or pull away; pref.
<ets>re-</ets> re- + <ets>vellere</ets> to pull. Cf.
<er>Convulse</er>.]</ety> <sn>1.</sn> <def>A strong pulling or drawing
back; withdrawal.</def> <ldquo/<xex>Revulsions</xex> and
pullbacks.<rdquo/ <rj><au>SSir T. Brovne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A sudden reaction; a sudden and complete change; --
applied to the feelings.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A sudden and violent <qex>revulsion</qex> of feeling, both in the
Parliament and the country, followed.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Med.)</fld> <def>The act of turning or diverting
any disease from one part of the body to another. It resembles
<xex>derivation</xex>, but is usually applied to a more active form of
counter irritation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revulsive</ent><br/
<hw>Re*vul"sive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>r<eacute/vulsif</ets>.]</ety> <def>Causing, or tending to,
revulsion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Revulsive</ent><br/
<hw>Re*vul"sive</hw>, <pos>n.</pos> <def>That which causes revulsion;
specifically <fld>(Med.)</fld>, a revulsive remedy or agent.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rew</ent><br/
<hw>Rew</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See <er>Row</er> a
series.]</ety> <def>A row.</def> <mark>[Obs.]</mark> <au>Chaucer.</au>
<ldquo/A <xex>rew</xex> of sundry colored stones.<rdquo/
<rj><au>Chapman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rewake</ent><br/
<hw>Re*wake""</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <def>To wake
again.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1236 --></p>

<p><ent>Reward</ent><br/
<hw>Re*ward"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Rewarded</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Rewarding</conjf>.]</vmorph> <ety>[OF. <ets>rewarder</ets>,
another form of <ets>regarder</ets>, of German origin. The original
sense is, to look at, regard, hence, to regard as worthy, give a reward
to. See <er>Ward</er>, <er>Regard</er>.]</ety> <def>To give in return,
whether good or evil; -- commonly in a good sense; to requite; to
recompense; to repay; to compensate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>After the deed that is done, one doom shall <qex>reward</qex>,<br/
Mercy or no mercy as truth will accord.</q> <rj><qau>Piers
Plowman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou hast <qex>rewarded</qex> me good, whereas I have
<qex>rewarded</qex> thee evil.</q> <rj><qau>1 Sam. xxiv.
17.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I will render vengeance to mine enemies, and will
<qex>reward</qex> them that hate me.</q> <rj><qau>Deut. xxxii.
41.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>God <qex>rewards</qex> those that have made use of the single
talent.</q> <rj><qau>Hammond.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reward</ent><br/
<hw>Re*ward"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See <er>Reward</er>,
<pos>v.</pos>, and cf. <er>Regard</er>, <pos>n.</pos>]</ety> <sn>1.</sn>
<def>Regard; respect; consideration.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Take <qex>reward</qex> of thine own value.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is given in return for good or evil done
or received; esp., that which is offered or given in return for some
service or attainment, as for excellence in studies, for the return of
something lost, etc.; recompense; requital.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou returnest<br/
From flight, seditious angel, to receive<br/
Thy merited <qex>reward</qex>.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Rewards</qex> and punishments do always presuppose something
willingly done well or ill.</q> <rj><qau>Hooker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Hence, the fruit of one's labor or works.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The dead know not anything, neither have they any more a
<qex>reward</qex>.</q> <rj><qau>Eccl. ix. 5.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Law)</fld> <def>Compensation or remuneration for
services; a sum of money paid or taken for doing, or forbearing to do,
some act.</def> <rj><au>Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Recompense; compensation; remuneration; pay;
requital; retribution; punishment.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rewardable</ent><br/
<hw>Re*ward"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Worthy of
reward.</def> -- <wordforms><wf>Re*ward"a*ble*ness</wf>, <pos>n.</pos>
-- <wf>Re*ward"a*bly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rewarder</ent><br/
<hw>Re*ward"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
rewards.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rewardful</ent><br/
<hw>Re*ward"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Yielding
reward.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rewardless</ent><br/
<hw>Re*ward"less</hw>, <pos>a.</pos> <def>Having, or affording, no
reward.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rewe</ent><br/
<hw>Rewe</hw> <pr>(r<udd/)</pr>, <pos>v. t. & i.</pos> <def>To
rue.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rewel bone</ent><br/
<hw>Rew"el bone`</hw> <pr>(?)</pr>. <ety>[Perh. from F.
<ets>rouelle</ets>, dim. of <ets>roue</ets> a wheel, L.
<ets>rota</ets>.]</ety> <def>An obsolete phrase of disputed meaning, --
perhaps, smooth or polished bone.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His saddle was of <qex>rewel boon</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rewet</ent><br/
<hw>Rew"et</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Rouet</er>.]</ety> <def>A gunlock.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rewful</ent><br/
<hw>Rew"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Rueful.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rewin</ent><br/
<hw>Re*win"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To win again, or
win back.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The Palatinate was not worth the <qex>rewinning</qex>.</q>
<rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rewle</ent><br/
<hw>Rewle</hw> <pr>(?)</pr>, <pos>n. & v.</pos> <def>Rule.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rewme</ent><br/
<hw>Rewme</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Realm.</def>
<mark>[Obs.]</mark> <rj><au>Piers Plowman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reword</ent><br/
<hw>Re*word"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <sn>1.</sn> <def>To
repeat in the same words; to reecho.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To alter the wording of; to restate in other words;
<as>as, to <ex>reword</ex> an idea or a passage</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rewrite</ent><br/
<hw>Re*write"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To write
again.</def> <rj><au>Young.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rewth</ent><br/
<hw>Rewth</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Ruth.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rex</ent><br/
\'d8<hw>Rex</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Reges</plw> <pr>(#)</pr>.</plu> <ety>[L.]</ety> <def>A
king.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To play rex</b></col>, <cd>to play the king; to
domineer.</cd> <mark>[Obs.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reyn</ent><br/
<hw>Reyn</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Rain or rein.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reynard</ent><br/
<hw>Rey"nard</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An appelation applied
after the manner of a proper name to the fox. Same as
<er>Renard</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reyse</ent><br/
<hw>Reyse</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To raise.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Reyse</ent><br/
<hw>Reyse</hw>, <pos>v. i.</pos> <ety>[Cf. G. <ets>reisen</ets> to
travel.]</ety> <def>To go on a military expedition.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rez-de-chaussee</ent><br/
\'d8<hw>Rez`-de-chaus`s<eacute/e"</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[F., lit., level of the street. See <er>Raze</er>, <pos>v.
t.</pos>, and <er>Causey</er>.]</ety> <fld>(Arch.)</fld> <def>The ground
story of a building, either on a level with the street or raised
slightly above it; -- said esp. of buildings on the continent of
Europe.</def></p>

<p><q>Tier above tier of neat apartments rise over the little shops
which form the <qex>rez-de-chauss<eacute/e</qex>.</q> <rj><qau>The
Century.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Rhabarbarate</ent><br/
<hw>Rha*bar"ba*rate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From NL.
<ets>rhabarbarum</ets>, an old name of rhubarb. See
<er>Rhubarb</er>.]</ety> <def>Impregnated or tinctured with
rhubarb.</def> <rj><au>Floyer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhabarbarine</ent><br/
<ent>Rhabarbarin</ent><br/
<mhw>{ <hw>Rha*bar"ba*rin</hw> <pr>(?)</pr>, <it>or</it>
<hw>Rha*bar"ba*rine</hw> <pr>(?)</pr> }</mhw>, <pos>n.</pos>
<fld>(Chem.)</fld> <def>Chrysophanic acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhabdite</ent><br/
<hw>Rhab"dite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>"ra`bdos</grk> a rod.]</ety> <sn>1.</sn> <fld>(Zool.)</fld> <def>A
minute smooth rodlike or fusiform structure found in the tissues of many
Turbellaria.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>One of the hard parts forming the
ovipositor of insects.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhabdocoela</ent><br/
\'d8<hw>Rhab`do*coe"la</hw> <pr>(r<acr/b`d<osl/*s<emac/"l<adot/)</pr>,
<pos>n. pl.</pos> <ety>[NL., fr. Gr. <grk>"ra`bdos</grk> a rod +
<grk>koi^los</grk> hollow.]</ety> <fld>(Zool.)</fld> <def>A suborder of
Turbellaria including those that have a simple cylindrical, or saclike,
stomach, without an intestine.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhabdocoelous</ent><br/
<hw>Rhab`do*coe"lous</hw> <pr>(r<acr/b`d<osl/*s<emac/"l<ucr/s)</pr>,
<pos>a.</pos> <fld>(Zool.)</fld> <def>Of or pertaining to the
Rhabdocoela.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhabdoidal</ent><br/
<hw>Rhab*doid"al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>See
<er>Sagittal</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhabdolith</ent><br/
<hw>Rhab"do*lith</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>"ra`bdos</grk> a rod + <ets>-lith</ets>.]</ety> <def>A minute
calcareous rodlike structure found both at the surface and the bottom of
the ocean; -- supposed by some to be a calcareous alga.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhabdology</ent><br/
<hw>Rhab*dol"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Rabdology</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhabdom</ent><br/
<hw>Rhab"dom</hw> <pr>(r<acr/b"d<ocr/m)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>"ra`bdwma</grk> a bundle of rods, fr. <grk>"ra`bdos</grk> a
rod.]</ety> <fld>(Zool.)</fld> <def>One of numerous minute rodlike
structures formed of two or more cells situated behind the retinulae in
the compound eyes of insects, etc. See <xex>Illust.</xex> under
<er>Ommatidium</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhabdomancy</ent><br/
<hw>Rhab"do*man`cy</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Rabdomancy</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhabdomere</ent><br/
<hw>Rhab"do*mere</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Rhabdom</ets> + <ets>-mere</ets>.]</ety> <fld>(Zool.)</fld>
<def>One of the several parts composing a rhabdom.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhabdophora</ent><br/
\'d8<hw>Rhab*doph"o*ra</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
fr. Gr. <grk>"ra`bdos</grk> a rod + <grk>fe`rein</grk> to bear.]</ety>
<fld>(Zool.)</fld> <def>An extinct division of Hydrozoa which includes
the graptolities.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhabdopleura</ent><br/
\'d8<hw>Rhab`do*pleu"ra</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <grk>"ra`bdos</grk> a rod + <?/<?/<?/<?/ the side.]</ety>
<fld>(Zool.)</fld> <def>A genus of marine Bryozoa in which the tubular
cells have a centralchitinous axis and the tentacles are borne on a
bilobed lophophore. It is the type of the order Pterobranchia, or
Podostomata</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhabdosphere</ent><br/
<hw>Rhab"do*sphere</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>"ra`bdos</grk> a rod + E. <ets>sphere</ets>.]</ety> <def>A minute
sphere composed of rhabdoliths.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhachialgia</ent><br/
\'d8<hw>Rha`chi*al"gi*a</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[NL.]</ety> <def>See <er>Rachialgia</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhachidian</ent><br/
<hw>Rha*chid"i*an</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining
to the rhachis; <as>as, the <ex>rhachidian</ex> teeth of a
mollusk</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhachiglossa</ent><br/
\'d8<hw>Rhach`i*glos"sa</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.
See <er>Rhachis</er>, and <er>Glossa</er>.]</ety> <fld>(Zool.)</fld>
<def>A division of marine gastropods having a retractile proboscis and
three longitudinal rows of teeth on the radula. It includes many of the
large ornamental shells, as the <stype>miters</stype>,
<stype>murices</stype>, <stype>olives</stype>, <stype>purpuras</stype>,
<stype>volutes</stype>, and <stype>whelks</stype>. See
<xex>Illust.</xex> in the Appendix.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhachilla</ent><br/
\'d8<hw>Rha*chil"la</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<grk>"ra`chis</grk> the spine.]</ety> <fld>(Bot.)</fld> <def>A branch of
inflorescence; the zigzag axis on which the florets are arranged in the
spikelets of grasses.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhachiodont</ent><br/
<hw>Rha"chi*o*dont</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>"ra`chis</grk>, <grk>-ios</grk>, the spine + <?/<?/<?/, <?/<?/<?/,
a tooth.]</ety> <fld>(Zool.)</fld> <def>Having gular teeth formed by a
peculiar modification of the inferior spines of some of the vertebrae,
as certain South African snakes (<gen>Dasypeltis</gen>) which swallow
birds' eggs and use these gular teeth to crush them.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhachis</ent><br/
\'d8<hw>Rha"chis</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it> E.
<plw>Rhachises</plw> <pr>(#)</pr>, L. <plw>Rhachides</plw>
<pr>(#)</pr>.</plu> <ety>[See <er>Rachis</er>.]</ety> <altsp>[Written
also <asp>rechis</asp>.]</altsp> <sn>1.</sn> <fld>(Anat.)</fld> <def>The
spine.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <sd>(a)</sd> <def>The continued stem or
midrib of a pinnately compound leaf, as in a rose leaf or a fern.</def>
<sd>(b)</sd> <def>The principal axis in a raceme, spike, panicle, or
corymb.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <sd>(a)</sd> <def>The shaft of a
feather. The rhachis of the after-shaft, or plumule, is called the
<xex>hyporhachis</xex>.</def> <sd>(b)</sd> <def>The central cord in the
stem of a crinoid.</def> <sd>(c)</sd> <def>The median part of the radula
of a mollusk.</def> <sd>(d)</sd> <def>A central cord of the ovary of
nematodes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhachitis</ent><br/
\'d8<hw>Rha*chi"tis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL.]</ety>
<def>See <er>Rachitis</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhadamanthine</ent><br/
<hw>Rhad`a*man"thine</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or
pertaining to <persfn>Rhadamanthus</persfn>; rigorously just; <as>as, a
<ex>Rhadamanthine</ex> judgment</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhadamanthus</ent><br/
<hw>Rhad`a*man"thus</hw> <pr>(?)</pr>, <pos>prop. n.</pos> <ety>[L., fr.
Gr. <?/<?/<?/.]</ety> <fld>(Greek Mythol.)</fld> <def>One of the three
judges of the infernal regions; figuratively, a strictly just
judge.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhaetian</ent><br/
<hw>Rhae"ti*an</hw> <pr>(?)</pr>, <pos>a & n.</pos>
<def>Rhetain.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhaetic</ent><br/
<hw>Rhae"tic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>Rhaeticus</ets> Rhetian.]</ety> <fld>(Geol.)</fld> <def>Pertining
to, or of the same horizon as, certain Mesozoic strata of the Rhetian
Alps. These strata are regarded as closing the Triassic period. See the
<xex>Chart</xex> of <er>Geology</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhaetizite</ent><br/
<hw>Rhae"ti*zite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[So called from
L. <etsep>Rhaetia</etsep>, <ets>Raetia</ets>, the Rhetian Alps, where it
is found.]</ety> <fld>(Min.)</fld> <def>A variety of the mineral
cyanite.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhamadan</ent><br/
\'d8<hw>Rham`a*dan"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Ramadan</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhamnaceous</ent><br/
<hw>Rham*na"ceous</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Bot.)</fld>
<def>Of or pertaining to a natural order of shrubs and trees
(<ord>Rhamnaceae</ord>, or <ord>Rhamneae</ord>) of which the buckthorn
(<gen>Rhamnus</gen>) is the type. It includes also the New Jersey tea,
the supple-jack, and one of the plants called lotus
(<gen>Zizyphus</gen>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhamnus</ent><br/
\'d8<hw>Rham"nus</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., from Gr.
<grk>"ra`mnos</grk> a kind of prickly shrub; cf. L.
<ets>rhamnos</ets>.]</ety> <fld>(Bot.)</fld> <def>A genus of shrubs and
small trees; buckthorn. The California <spn>Rhamnus Purshianus</spn> and
the European <spn>Rhamnus catharticus</spn> are used in medicine. The
latter is used for hedges.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhamphorhynchus</ent><br/
\'d8<hw>Rham`pho*rhyn"chus</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL.,
fr. Gr. <grk>"ra`mfos</grk> a beak + <?/<?/<?/<?/ snout.]</ety>
<fld>(Paleon.)</fld> <def>A genus of pterodactyls in which the elongated
tail supported a leathery expansion at the tip.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhamphotheca</ent><br/
\'d8<hw>Rham`pho*the"ca</hw> <pr>(?)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Rhamphothecae</plw> <pr>(#)</pr>.</plu>
<ety>[NL., fr. Gr <grk>"ra`mnos</grk> a beak + <?/<?/ a case.]</ety>
<fld>(Zool.)</fld> <def>The horny covering of the bill of
birds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhaphe</ent><br/
<hw>Rha"phe</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<?/<?/<?/ seam, fr. <?/<?/<?/ to sew. ]</ety> <fld>(Bot.)</fld> <def>The
continuation of the seed stalk along the side of an anatropous ovule or
seed, forming a ridge or seam.</def> <altsp>[Written also
<asp>raphe</asp>.]</altsp> <rj><au>Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhaphides</ent><br/
\'d8<hw>Rhaph"i*des</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL., fr.
Gr. <?/<?/<?/, <?/<?/<?/, a needle, F. <ets>raphides</ets>.]</ety>
<fld>(Bot.)</fld> <def>Minute transparent, often needle-shaped, crystals
found in the tissues of plants.</def> <altsp>[Written also
<asp>raphides</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhaponticine</ent><br/
<hw>Rha*pon"ti*cine</hw> <pr>(<?/)</pr>, <pos>n.</pos> <ety>[L.
<ets>rhaponticum</ets> rhubarb. See <er>Rhubarb</er>.]</ety>
<fld>(Chem.)</fld> <def>Chrysophanic acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhapsode</ent><br/
<hw>Rhap"sode</hw> <pr>(r<acr/p"s<omac/d)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>"rapsw,do`s</grk>. See <er>Rhapsody</er>.]</ety> <fld>(Gr.
Antiq.)</fld> <def>A rhapsodist.</def> <mark>[R.]</mark>
<rj><au>Grote.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhapsoder</ent><br/
<hw>Rhap"so*der</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A
rhapsodist.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhapsodic</ent><br/
<ent>Rhapsodic</ent><br/
<mhw>{ <hw>Rhap*sod"ic</hw> <pr>(?)</pr>, <hw>Rhap*sod"ic</hw>
<pr>(?)</pr> }</mhw>, <pos>a.</pos> <ety>[Gr. <grk>"rapsw,diko`s</grk>:
cf. F. <ets>rhapsodique</ets>.]</ety> <def>Of or pertaining to rhapsody;
consisting of rhapsody; hence, confused; unconnected.</def> --
<wordforms><wf>Rhap*sod"ic*al*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhapsodist</ent><br/
<hw>Rhap"so*dist</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<er>Rhapsody</er>.]</ety> <sn>1.</sn> <def>Anciently, one who recited or
composed a rhapsody; especially, one whose profession was to recite the
verses of Hormer and other epic poets.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence, one who recites or sings poems for a
livelihood; one who makes and repeats verses extempore.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The same populace sit for hours listening to
<qex>rhapsodists</qex> who recite Ariosto.</q>
<rj><qau>Carlyle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>One who writes or speaks disconnectedly and with
great excitement or affectation of feeling.</def> <rj><au>I.
Watts.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhapsodize</ent><br/
<hw>Rhap"so*dize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Rhapsodized</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Rhapsodizing</conjf>.]</vmorph> <def>To utter as a
rhapsody, or in the manner of a rhapsody</def>
<rj><au>Sterne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhapsodize</ent><br/
<hw>Rhap"so*dize</hw>, <pos>v. i.</pos> <def>To utter rhapsodies.</def>
<rj><au>Jefferson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhapsodomancy</ent><br/
<hw>Rhap"so*do*man`cy</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Rhapsody</ets> + <ets>-mancy</ets>.]</ety> <def>Divination by
means of verses.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhapsody</ent><br/
<hw>Rhap"so*dy</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Rhapsodies</plw> <pr>(#)</pr>.</plu> <ety>[F. <ets>rhapsodie</ets>,
L. <ets>rhapsodia</ets>, Gr. <grk>"rapsw,di`a</grk>, fr.
<grk>"rapsw,do`s</grk> a rhapsodist; <grk>"ra`ptein</grk> to sew, stitch
together, unite + <grk>'w,dh`</grk> a song. See <er>Ode</er>.]</ety>
<sn>1.</sn> <def>A recitation or song of a rhapsodist; a portion of an
epic poem adapted for recitation, or usually recited, at one time;
hence, a division of the Iliad or the Odyssey; -- called also a
<altname>book</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A disconnected series of sentences or statements
composed under excitement, and without dependence or natural connection;
rambling composition.</def> <ldquo/A <xex>rhapsody</xex> of
words.<rdquo/ <au>Shak.</au> <ldquo/A <xex>rhapsody</xex> of
tales.<rdquo/ <rj><au>Locke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Mus.)</fld> <def>A composition irregular in form,
like an improvisation; <as>as, Liszt's <ldquo/Hungarian
<ex>Rhapsodies</ex></as>.<rdquo/</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhatanhy</ent><br/
<ent>Rhatany</ent><br/
<mhw>{ <hw>Rhat"a*ny</hw>, <hw>Rhat"an*hy</hw> }</mhw> <pr>(?)</pr>,
<pos>n.</pos> <ety>[Sp. <ets>ratania</ets>, <ets>rata<ntil/a</ets>,
Peruv. <ets>rata<ntil/a</ets>.]</ety> <def>The powerfully astringent
root of a half-shrubby Peruvian plant (<spn>Krameria triandra</spn>). It
is used in medicine and to color port wine.</def> <altsp>[Written also
<asp>ratany</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Savanilla rhatany</b></col>, <cd>the root of
<spn>Krameria Ixina</spn>, a native of New Granada.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhea</ent><br/
<hw>Rhe"a</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>The
ramie or grass-cloth plant. See <cref>Grass-cloth plant</cref>, under
<er>Grass</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhea</ent><br/
<hw>Rhe"a</hw>, <pos>n.</pos> <ety>[L., a proper name.]</ety>
<fld>(Zool.)</fld> <def>Any one of three species of large South American
ostrichlike birds of the genera <gen>Rhea</gen> and
<gen>Pterocnemia</gen>. Called also the <altname>American
ostrich</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The common rhea, or nandou (<spn>Rhea Americana</spn>),
ranges from Brazil to Patagonia. Darwin's rhea (<spn>Pterocnemia
Darwinii</spn>), of Patagonia, is smaller, and has the legs feathered
below the knee.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rheae</ent><br/
\'d8<hw>Rhe"ae</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.]</ety>
<fld>(Zool.)</fld> <def>A suborder of struthious birds including the
rheas.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rheeboc</ent><br/
<hw>Rhee"boc</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[D. <ets>reebok</ets>
roebuck.]</ety> <fld>(Zool.)</fld> <def>The peele.</def> <altsp>[Written
also <asp>reebok</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rheic</ent><br/
<hw>Rhe"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[NL. <ets>Rheum</ets>
rhubarb, Gr. <?/<?/<?/ See <er>Rhubarb</er>.]</ety> <fld>(Chem.)</fld>
<def>Pertaining to, or designating, an acid (commonly called
chrysophanic acid) found in rhubarb (<gen>Rheum</gen>).</def>
<mark>[Obsoles.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhein</ent><br/
<hw>Rhe"in</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>Chrysophanic acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rheinberry</ent><br/
<hw>Rhein"ber*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[G.
<ets>rheinbeere</ets>.]</ety> <fld>(Bot.)</fld> <def>One of the berries
or drupes of the European buckthorn; also, the buckthorn
itself.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhematic</ent><br/
<hw>Rhe*mat"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/<?/<?/<?/
of or for a verb, fr. <?/<?/<?/, <?/<?/<?/, a sentence. See
<er>Rhetoric</er>.]</ety> <fld>(Gram.)</fld> <def>Having a verb for its
base; derived from a verb; <as>as, <ex>rhematic</ex>
adjectives</as>.</def> <rj><au>Ftzed. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhematic</ent><br/
<hw>Rhe*mat"ic</hw>, <pos>n.</pos> <def>The doctrine of propositions or
sentences.</def> <rj><au>Coleridge.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhemish</ent><br/
<hw>Rhemish</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining to
Rheimis, or Reima, in France.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Rhemish Testament</b></col>, <cd>the English version of
the New Testament used by Roman Catholics. See <er>Douay
Bible</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhenish</ent><br/
<hw>Rhen"ish</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>Rhenus</ets>
the Rhine. ]</ety> <def>Of or pertaining to the river Rhine; <as>as,
<ex>Rhenish</ex> wine</as>.</def> -- <def2><pos>n.</pos> <def>Rhine
wine.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rheochord</ent><br/
<hw>Rhe"o*chord</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>"rei^n</grk> to flow + <?/<?/<?/ chord.]</ety> <fld>(Elec.)</fld>
<def>A metallic wire used for regulating the resistance of a circuit, or
varying the strength of an electric current, by inserting a greater or
less length of it in the circuit.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rheocrat</ent><br/
<hw>Rhe"o*crat</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>"rei^n</grk> to flow + <grk>kratei^n</grk> to rule.]</ety>
<fld>(Elec.)</fld> <def>A kind of motor speed controller permitting of
very gradual variation in speed and of reverse. It is especially
suitable for use with motor driven machine tools.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Rheometer</ent><br/
<hw>Rhe*om"e*ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>"rei^n</grk> to flow + <ets>-meter</ets>.]</ety> <altsp>[Written
also <asp>reometer</asp>.]</altsp> <sn>1.</sn> <fld>(Physics)</fld>
<def>An instrument for measuring currents, especially the force or
intensity of electrical currents; a galvanometer.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Physiol.)</fld> <def>An instrument for measuring
the velocity of the blood current in the arteries.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rheometric</ent><br/
<hw>Rhe`o*met"ric</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining
to a rheometer or rheometry.</def> <rj><au>Lardner.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rheometry</ent><br/
<hw>Rhe*om"e*try</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
measurement of the force or intensity of currents.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Math.)</fld> <def>The calculus; fluxions.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rheomotor</ent><br/
<hw>Rhe"o*mo`tor</hw> <pr>(r<emac/"<osl/*m<omac/*t<etil/r)</pr>,
<pos>n.</pos> <ety>[Gr. <grk>"rei^n</grk> to flow + E.
<ets>motor</ets>.]</ety> <fld>(Elec.)</fld> <def>Any apparatus by which
an electrical current is originated.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rheophore</ent><br/
<hw>Rhe"o*phore</hw> <pr>(r<emac/"<osl/*f<omac/r)</pr>, <pos>n.</pos>
<ety>[Gr. <grk>"rei^n</grk> to flow + <?/<?/<?/ to carry.]</ety>
<fld>(Elec.)</fld> <sd>(a)</sd> <def>A connecting wire of an electric or
voltaic apparatus, traversed by a current.</def> <sd>(b)</sd> <def>One
of the poles of a voltaic battery; an electrode.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rheoscope</ent><br/
<hw>Rhe"o*scope</hw> <pr>(r<emac/"<osl/*sk<omac/p)</pr>, <pos>n.</pos>
<ety>[Gr. <grk>"rei^n</grk> to flow + <ets>-scope</ets>.]</ety>
<fld>(Physics)</fld> <def>An instrument for detecting the presence or
movement of currents, as of electricity.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rheostat</ent><br/
<hw>Rhe"o*stat</hw> <pr>(r<emac/"<osl/*st<acr/t)</pr>, <pos>n.</pos>
<ety>[Gr. <grk>"rei^n</grk> + <grk>stato`s</grk> standing still.]</ety>
<fld>(Elec.)</fld> <def>A contrivance for adjusting or regulating the
strength of electrical currents, operating usually by the intercalation
of resistance which can be varied at will.</def> <au>Wheatstone.</au>
--<wordforms><wf>Rhe`o*stat"ic</wf> <pr>(#)</pr>,
<pos>a.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rheotome</ent><br/
<hw>Rhe"o*tome</hw> <pr>(r<emac/"<osl/*t<omac/m)</pr>, <pos>n.</pos>
<ety>[Gr. <grk>"rei^n</grk> to flow + <grk>te`mnein</grk> to cut.]</ety>
<fld>(Elec.)</fld> <def>An instrument which periodically or otherwise
interrupts an electric current.</def> <rj><au>Wheatstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rheotrope</ent><br/
<hw>Rhe"o*trope</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>"rei^n</grk> to flow + <?/<?/<?/ to turn.]</ety> <fld>(Elec.)</fld>
<def>An instrument for reversing the direction of an electric
current.</def> <altsp>[Written also <asp>reotrope</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhesus</ent><br/
\'d8<hw>Rhe"sus</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>Rhesus</ets>, a proper name, Gr. <?/<?/<?/.]</ety>
<fld>(Zool.)</fld> <def>A monkey; the bhunder.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1237 --></p>

<p><ent>Rhetian</ent><br/
<hw>Rhe"ti*an</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>Rhaetius</ets>, <ets>Raetius</ets>: cf. F.
<ets>rh<eacute/tien</ets>.]</ety> <def>Pertaining to the ancient Rhaeti,
or Rhaetians, or to Rhaetia, their country; <as>as, the <ex>Rhetian</ex>
Alps, now the country of Tyrol and the Grisons</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhetic</ent><br/
<hw>Rhe"tic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Min.)</fld> <def>Same
as <er>Rhaetic</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhetizite</ent><br/
<hw>Rhe"ti*zite</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Min.)</fld>
<def>Same as <er>Rhaetizite</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhetor</ent><br/
<hw>Rhe"tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., fr. Gr.
<?/<?/<?/.]</ety> <def>A rhetorician.</def> <mark>[Obs.]</mark>
<rj><au>Hammond.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhetoric</ent><br/
<hw>Rhet"o*ric</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>rh<eacute/torique</ets>, L. <ets>rhetorica</ets>, Gr. <?/<?/<?/<?/
(sc. <?/<?/<?/), fr. <?/<?/<?/ rhetorical, oratorical, fr. <?/<?/<?/
orator, rhetorician; perhaps akin to E. <ets>word</ets>; cf. <?/<?/<?/
to say.]</ety> <sn>1.</sn> <def>The art of composition; especially,
elegant composition in prose.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Oratory; the art of speaking with propriety,
elegance, and force.</def> <rj><au>Locke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Hence, artificial eloquence; fine language or
declamation without conviction or earnest feeling.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Fig. : The power of persuasion or attraction; that
which allures or charms.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Sweet, silent <qex>rhetoric</qex> of persuading eyes.</q>
<rj><qau>Daniel.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhetorical</ent><br/
<hw>Rhe*tor"ic*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>rhetoricus</ets>, Gr. <?/<?/<?/<?/. See <er>Rhetoric</er>.]</ety>
<def>Of or pertaining to rhetoric; according to, or exhibiting,
rhetoric; oratorical; <as>as, the <ex>rhetorical</ex> art; a
<ex>rhetorical</ex> treatise; a <ex>rhetorical</ex>
flourish.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>They permit him to leave their poetical taste ungratified,
provided that he gratifies their <qex>rhetorical</qex> sense.</q>
<rj><qau>M. Arnold.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Rhe*tor"ic*al*ly</wf>, <pos>adv.</pos> --
<wf>Rhe*tor"ic*al*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhetoricate</ent><br/
<hw>Rhe*tor"i*cate</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[L.
<ets>rhetoricari</ets>. See <er>Rhetoric</er>.]</ety> <def>To play the
orator.</def> <mark>[Obs.]</mark> <rj><au>South.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhetorication</ent><br/
<hw>Rhe*tor`i*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>rh<eacute/torication</ets>.]</ety> <def>Rhetorical
amplification.</def> <mark>[Obs.]</mark>
<rj><au>Waterland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhetorician</ent><br/
<hw>Rhet`o*ri"cian</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>rh<eacute/toricien</ets>.]</ety> <sn>1.</sn> <def>One well versed
in the rules and principles of rhetoric.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The understanding is that by which a man becomes a mere logician
and a mere <qex>rhetorician</qex>.</q> <rj><qau>F. W.
Robertson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A teacher of rhetoric.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The ancient sophists and <qex>rhetoricians</qex>, which ever had
young auditors, lived till they were an hundred years old.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>An orator; specifically, an artificial orator
without genuine eloquence; a declaimer.</def>
<rj><au>Macaulay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhetorician</ent><br/
<hw>Rhet`o*ri"cian</hw>, <pos>a.</pos> <def>Suitable to a master of
rhetoric.</def> <ldquo/With <xex>rhetorician</xex> pride.<rdquo/
<rj><au>Blackmore.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhetorize</ent><br/
<hw>Rhet"o*rize</hw> <pr>(r<ecr/t"<osl/*r<imac/z)</pr>, <pos>v. i.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Rhetorized</conjf>
<pr>(-r<imac/zd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Rhetorizing</conjf> <pr>(-r<imac/`z<icr/ng)</pr>.]</vmorph>
<def>To play the orator.</def> <rj><au>Colgrave.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhetorize</ent><br/
<hw>Rhet"o*rize</hw>, <pos>v. t.</pos> <def>To represent by a figure of
rhetoric, or by personification.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rheum</ent><br/
\'d8<hw>Rhe"um</hw> <pr>(r<emac/"<ucr/m)</pr>, <pos>n.</pos> <ety>[NL.,
from L. <ets>Rha</ets> the river Volga, on the banks of which it grows.
See <er>Rhubarb</er>.]</ety> <fld>(Bot.)</fld> <def>A genus of plants.
See <er>Rhubarb</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rheum</ent><br/
<hw>Rheum</hw> <pr>(r<udd/m)</pr>, <pos>n.</pos> <ety>[OF.
<ets>reume</ets>, <ets>rheume</ets>, F. <ets>rhume</ets> a cold,, L.
<ets>rheuma</ets> rheum, from Gr. <?/<?/<?/, fr. <grk>"rei^n</grk> to
flow, akin to E. <ets>stream</ets>. See <er>Stream</er>, <pos>n.</pos>,
and cf. <er>Hemorrhoids</er>.]</ety> <fld>(Med.)</fld> <def>A serous or
mucous discharge, especially one from the eves or nose.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I have a <qex>rheum</qex> in mine eyes too.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Salt rheum</b></col>. <fld>(Med.)</fld> <cd>See <er>Salt
rheum</er>, in the Vocabulary.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rheumatic</ent><br/
<hw>Rheu*mat"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/<?/<?/
subject to a discharge or flux: cf. L. <ets>rheumaticus</ets>, F.
<ets>rhumatique</ets>. See <er>Rheum</er>, <er>Rheumatism</er>.]</ety>
<sn>1.</sn> <def>Derived from, or having the character of, rheum;
rheumic.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Med.)</fld> <def>Of or pertaining to rheumatism;
<as>as, <ex>rheumatic</ex> pains or affections</as>; affected with
rheumatism; <as>as, a <ex>rheumatic</ex> old man</as>; causing
rheumatism; <as>as, a <ex>rheumatic</ex> day</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That <qex>rheumatic</qex> diseases do abound.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rheumatic</ent><br/
<hw>Rheu*mat"ic</hw>, <pos>n.</pos> <def>One affected with
rheumatism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rheumatism</ent><br/
<hw>Rheu"ma*tism</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>rheumatismus</ets> rheum, Gr. <?/<?/<?/<?/, fr.<?/<?/<?/ to have or
suffer from a flux, fr. <?/<?/<?/ rheum: cf. F. <ets>rheumatisme</ets>.
See <er>2d Rheum</er>.]</ety> <fld>(Med.)</fld> <def>A general disease
characterized by painful, often multiple, local inflammations, usually
affecting the joints and muscles, but also extending sometimes to the
deeper organs, as the heart.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Inflammatory rheumatism</b></col> <fld>(Med.)</fld>,
<cd>acute rheumatism attended with fever, and attacking usually the
larger joints, which become swollen, hot, and very painful.</cd> --
<col><b>Rheumatism root</b></col>. <fld>(Bot.)</fld> <cd>See
<er>Twinleaf</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rheumatismal</ent><br/
<hw>Rheu`ma*tis"mal</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Med.)</fld>
<def>Of or pertaining to rheumatism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rheumatismoid</ent><br/
<hw>Rheu`ma*tis"moid</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Rheumatism</ets> + <ets>-oid</ets>.]</ety> <fld>(Med.)</fld>
<def>Of or resembling rheum or rheumatism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rheumic</ent><br/
<hw>Rheum"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Med.)</fld>
<def>Pertaining to, or characterized by, rheum.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Rheumic diathesis</b></col>. <cd>See <cref>Dartrous
diathesis</cref>, under <er>Dartrous</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rheumides</ent><br/
\'d8<hw>Rheu"mi*des</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL. See
<er>Rheum</er>.]</ety> <fld>(Med.)</fld> <def>The class of skin disease
developed by the dartrous diathesis. See under
<er>Dartrous</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rheumy</ent><br/
<hw>Rheum"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining to
rheum; abounding in, or causing, rheum; affected with rheum.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His head and <qex>rheumy</qex> eyes distill in showers.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And tempt the <qex>rheumy</qex> and unpurged air<br/
To add unto his sickness.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhigolene</ent><br/
<hw>Rhig"o*lene</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/<?/<?/
cold + L. <ets>oleum</ets> oil.]</ety> <fld>(Chem.)</fld> <def>A mixture
of volatile hydrocarbons intermediate between gsolene and cymogene. It
is obtained in the purification of crude petroleum, and is used as a
refregerant.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhime</ent><br/
<hw>Rhime</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Rhyme</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhinal</ent><br/
<hw>Rhi"nal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr<?/<?/<?/,
<?/<?/<?/, the nose.]</ety> <fld>(Anat.)</fld> <def>Og or pertaining to
the nose or olfactory organs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhinaster</ent><br/
\'d8<hw>Rhi*nas"ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<?/<?/<?/, <?/<?/<?/, nose + <?/<?/<?/ star.]</ety> <fld>(Zool.)</fld>
<def>The borele.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhine</ent><br/
<hw>Rhine</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS. <ets>ryne</ets>.
See <er>Run</er>.]</ety> <def>A water course; a ditch.</def>
<altsp>[Written also <asp>rean</asp>.]</altsp> <mark>[Prov. Eng.]</mark>
<rj><au>Macaulay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhinencephalic</ent><br/
<hw>Rhi`nen*ce*phal"ic</hw> <pr>(?)</pr>, <pos>a.</pos>
<fld>(Anat.)</fld> <def>Of or pertaining to the
rhinencephalon.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhinencephalon</ent><br/
\'d8<hw>Rhi`nen*ceph"a*lon</hw>
<pr>(r<imac/`n<ecr/n*s<ecr/f"<adot/*l<ocr/n)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Rhinencephala</plw>
<pr>(r<imac/`n<ecr/n*s<ecr/f"<adot/*l<adot/)</pr>.</plu> <ety>[NL., fr.
Gr. <grk>"ri`s</grk>, <grk>"rino`s</grk>, the nose +
<grk>'egke`falos</grk> the brain.]</ety> <fld>(Anat.)</fld> <def>The
division of the brain in front of the prosencephalon, consisting of the
two olfactory lobes from which the olfactory nerves arise.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The term is sometimes used for one of the olfactory
lobes, the plural being used for the two taken together.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhinestone</ent><br/
<hw>Rhine"stone`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. G.
<ets>rheinkiesel</ets> Rhine quartz.]</ety> <def>A colorless stone of
high luster, made of paste. It is much used as an inexpensive
ornament.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhinitis</ent><br/
\'d8<hw>Rhi*ni"tis</hw> <pr>(r<isl/*n<imac/"t<icr/s)</pr>, <pos>n.</pos>
<ety>[NL., fr. Gr. <grk>"ri`s</grk>, <grk>"rino`s</grk>, the nose +
<ets>-itis</ets>.]</ety> <fld>(Med.)</fld> <def>Inflammation of the
nose; esp., inflammation of the mucous membrane of the
nostrils.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhino</ent><br/
<hw>Rhi*no</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Etymol.
uncertain.]</ety> <def>Gold and silver, or money.</def>
<mark>[Cant]</mark> <rj><au>W. Wagstaffe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>As long as the <qex>rhino</qex> lasted.</q>
<rj><qau>Marryat.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhino-</ent><br/
<hw>Rhi"no-</hw>. <def>A combining form from Greek <?/<?/, <?/<?/<?/,
<xex>the nose</xex>, as in <xex>rhino</xex>lith,
<xex>rhino</xex>logy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhinocerical</ent><br/
<ent>Rhinocerial</ent><br/
<mhw>{ <hw>Rhi`no*ce"ri*al</hw> <pr>(?)</pr>, <hw>Rhi`no*cer"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <fld>(Zool.)</fld> <def>Of or
pertaining to the rhinoceros; resembling the rhinoceros, or his
horn.</def> <rj><au>Tatler.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhinoceros</ent><br/
<hw>Rhi*noc"e*ros</hw> <pr>(r<isl/*n<ocr/s"<esl/*r<ocr/s)</pr>,
<pos>n.</pos> <ety>[L., fr. Gr. <grk>"rinoke`rws</grk>,
<grk>"rinoke`rwtos</grk>; <grk>"ri`s</grk>, <grk>"rino`s</grk>, the nose
+ <grk>ke`ras</grk> a horn: cf. F. <ets>rhinoc<eacute/ros</ets>. See
<er>Horn</er>.]</ety> <fld>(Zool.)</fld> <def>Any pachyderm belonging to
the genera <gen>Rhinoceros</gen>, <gen>Atelodus</gen>, and several
allied genera of the family <fam>Rhinocerotidae</fam>, of which several
living, and many extinct, species are known. They are large and
powerful, and usually have either one or two stout conical median horns
on the snout.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The Indian, or white, and the Javan rhinoceroses
(<spn>Rhinoceros Indicus</spn> and <spn>Rhinoceros Sondaicus</spn>) have
incisor and canine teeth, but only one horn, and the very thick skin
forms shieldlike folds. The two or three African species belong to
<spn>Atelodus</spn>, and have two horns, but lack the dermal folds, and
the incisor and canine teeth. The two Malay, or East Indian, two-horned
species belong to <gen>Ceratohinus</gen>, in which incisor and canine
teeth are present. See <er>Borele</er>, and <er>Keitloa</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Rhinoceros auk</b></col> <fld>(Zool.)</fld>, <cd>an auk
of the North Pacific (<spn>Cerorhina monocrata</spn>) which has a
deciduous horn on top of the bill.</cd> -- <col><b>Rhinoceros
beetle</b></col> <fld>(Zool.)</fld>, <cd>a very large beetle of the
genus <gen>Dynastes</gen>, having a horn on the head.</cd> --
<col><b>Rhinoceros bird</b></col>. <fld>(Zool.)</fld> <sd>(a)</sd> <cd>A
large hornbill (<spn>Buceros rhinoceros</spn>), native of the East
Indies. It has a large hollow hornlike process on the bill. Called also
<altname>rhinoceros hornbill</altname></cd>. See <er>Hornbill</er>.
<sd>(b)</sd> <cd>An African beefeater (<spn>Buphaga Africana</spn>). It
alights on the back of the rhinoceros in search of parasitic
insects.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhinocerote</ent><br/
<hw>Rhi*noc"e*rote</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A
rhinoceros.</def> <mark>[Obs.]</mark> <rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhinocerotic</ent><br/
<hw>Rhi*noc`e*rot"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or
pertaining to the rhinoceros.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhinolith</ent><br/
<ent>Rhinolite</ent><br/
<mhw>{ <hw>Rhi"no*lite</hw> <pr>(?)</pr>, <hw>Rhi"no*lith</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[<ets>Rhino-</ets> +
<ets>-lite</ets>, <ets>-lith</ets>.]</ety> <fld>(Med.)</fld> <def>A
concretion formed within the cavities of the nose.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhinological</ent><br/
<hw>Rhi`no*log"ic*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or
pertaining to rhinology.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhinologist</ent><br/
<hw>Rhi*nol"o*gist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One skilled in
rhinology.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhinology</ent><br/
<hw>Rhi*nol"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Rhino-</ets> + <ets>-logy</ets>.]</ety> <def>The science
which treats of the nose, and its diseases.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhinolophid</ent><br/
<hw>Rhi*nol"o*phid</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Rhino-</ets> + Gr. <?/<?/<?/ crest.]</ety> <fld>(Zool.)</fld>
<def>Any species of the genus <gen>Rhinilophus</gen>, or family
<fam>Rhinolophidae</fam>, having a horseshoe-shaped nasal crest; a
horseshoe bat.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhinolophine</ent><br/
<hw>Rhi*nol"o*phine</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Like or pertaining to the rhinolophids, or horseshoe
bats.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhinophore</ent><br/
<hw>Rhi"no*phore</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Rhino-</ets> + Gr. <grk>fe`rein</grk> to bear.]</ety>
<fld>(Zool.)</fld> <def>One of the two tentacle-like organs on the back
of the head or neck of a nudibranch or tectibranch mollusk. They are
usually retractile, and often transversely furrowed or plicate, and are
regarded as olfactory organs. Called also <altname>dorsal
tentacles</altname>. See <xex>Illust.</xex> under <er>Pygobranchia</er>,
and <er>Opisthobranchia</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhinoplastic</ent><br/
<hw>Rhi`no*plas"tic</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Rhino-</ets> + <ets>-plastic</ets>: cf. F.
<ets>rhinoplastique</ets>.]</ety> <fld>(Surg.)</fld> <def>Of or
pertaining to rhinoplasty; <as>as, a <ex>rhinoplastic</ex>
operation</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhinoplasty</ent><br/
<hw>Rhi"no*plas`ty</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Rhino-</ets> + <ets>-plasty</ets>: cf. F.
<ets>rhinoplastie</ets>.]</ety> <def>Plastic surgery of the nose to
correct deformity or to replace lost tissue. Tissue may be transplanted
from the patient's cheek, forehead, arm, etc., or even from another
person.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhinopome</ent><br/
<hw>Rhi"no*pome</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Rhino-</ets>
+ Gr. <grk>pw^ma</grk> a lid. ]</ety> <fld>(Zool.)</fld> <def>Any
old-world bat of the genus <gen>Rhinopoma</gen>. The rhinopomes have a
long tail extending beyond the web, and inhabit caves and
tombs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhinoscleroma</ent><br/
\'d8<hw>Rhi`no*scle*ro"ma</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Rhino-</ets> + <ets>scleroma</ets>.]</ety> <fld>(Med.)</fld>
<def>A rare disease of the skin, characterized by the development of
very hard, more or less flattened, prominences, appearing first upon the
nose and subsequently upon the neighboring parts, esp. the lips, palate,
and throat.</def> <rj><au>J. V. Shoemaker.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhinoscope</ent><br/
<hw>Rhi"no*scope</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Rhino-</ets> + <ets>-scope</ets>.]</ety> <def>A small mirror
for use in rhinoscopy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhinoscopic</ent><br/
<hw>Rhi`no*scop"ic</hw> <pr>(?)</pr>, <pos>a.</pos>
<fld>(Physiol.)</fld> <def>Of or pertaining to rhinoscopy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhinoscopy</ent><br/
<hw>Rhi*nos"co*py</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Rhino-</ets> + <ets>-scopy</ets>.]</ety>
<fld>(Physiol.)</fld> <def>The examination or study of the soft palate,
posterior nares, etc., by means of a laryngoscopic mirror introduced
into the pharynx.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhinotheca</ent><br/
\'d8<hw>Rhi`no*the"ca</hw> <pr>(?)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Rhinothecae</plw> <pr>(#)</pr>.</plu> <ety>[NL.,
from gr. <?/<?/<?/, <?/<?/<?/, the nose + <?/<?/<?/ case.]</ety>
<fld>(Zool.)</fld> <def>The sheath of the upper mandible of a
bird.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhipidoglossa</ent><br/
\'d8<hw>Rhi*pi`do*glos"sa</hw> <pr>(?)</pr>, <pos>n. pl.</pos>
<ety>[NL., fr. Gr. <?/<?/<?/ a fan + <?/<?/<?/<?/ a tongue.]</ety>
<fld>(Zool.)</fld> <def>A division of gastropod mollusks having a large
number of long, divergent, hooklike, lingual teeth in each transverse
row. It includes the scutibranchs. See <xex>Illustration</xex> in
Appendix.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhipipter</ent><br/
<hw>Rhi*pip"ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/<?/<?/ a
fan + <?/<?/<?/ wing.]</ety> <fld>(Zool.)</fld> <def>One of the
<ord>Rhipiptera</ord>, a group of insects having wings which fold like a
fan; a strepsipter.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhipipteran</ent><br/
<hw>Rhi*pip"ter*an</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>Same as <er>Rhipipter</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhizanthous</ent><br/
<hw>Rhi*zan"thous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/<?/<?/
root + <?/<?/<?/ flower.]</ety> <fld>(Bot.)</fld> <def>Producing flowers
from a rootstock, or apparently from a root.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhizine</ent><br/
<hw>Rhi"zine</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/<?/<?/
root.]</ety> <fld>(Bot.)</fld> <def>A rootlike filament or hair growing
from the stems of mosses or on lichens; a rhizoid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhizocarpous</ent><br/
<hw>Rhi`zo*car"pous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/<?/<?/
root + <?/<?/<?/ fruit.]</ety> <fld>(Bot.)</fld> <def>Having perennial
rootstocks or bulbs, but annual flowering stems; -- said of all
perennial herbs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhizocephala</ent><br/
\'d8<hw>Rhi`zo*ceph"a*la</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
fr. Gr. <?/<?/<?/ root + <?/<?/<?/ head.]</ety> <fld>(Zool.)</fld>
<def>A division of Pectostraca including saclike parasites of Crustacea.
They adhere by rootlike extensions of the head. See
<xex>Illusration</xex> in Appendix.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhizodont</ent><br/
<hw>Rhiz"o*dont</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/<?/<?/
root + <?/<?/<?/, <?/<?/<?/, a tooth.]</ety> <fld>(Zool.)</fld> <def>A
reptile whose teeth are rooted in sockets, as the crocodile.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhizogan</ent><br/
<hw>Rhiz"o*gan</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/<?/<?/ root
+ <ets>-gen</ets>: cf. F. <ets>rhizog<egrave/ne</ets>.]</ety>
<fld>(Bot.)</fld> <def>Prodicing roots.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhizogen</ent><br/
<hw>Rhiz"o*gen</hw>, <pos>n.</pos> <fld>(Bot.)</fld> <def>One of a
proposed class of flowering plants growning on the roots of other plants
and destitute of green foliage.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhizoid</ent><br/
<hw>Rhi"zoid</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/<?/<?/ root +
<ets>-oid</ets>.]</ety> <fld>(Bot.)</fld> <def>A rootlike
appendage.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhizoma</ent><br/
\'d8<hw>Rhi*zo"ma</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Rhizomata</plw> <pr>(#)</pr>.</plu> <ety>[NL.]</ety>
<fld>(Bot.)</fld> <def>Same as <er>Rhizome</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhizomatous</ent><br/
<hw>Rhi*zo"ma*tous</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Bot.)</fld>
<def>Having the nature or habit of a rhizome or rootstock.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhizome</ent><br/
<hw>Rhi*zome"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/<?/<?/ the
mass of roots (of a tree), a stem, race, fr. <?/<?/<?/ to make to root,
pass., to take root, fr. <?/<?/<?/ a root: cf. F.
<ets>rhizome</ets>.]</ety> <fld>(Bot.)</fld> <def>A rootstock, such as
one of an iris. See <er>Rootstock</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhizophaga</ent><br/
\'d8<hw>Rhi*zoph"a*ga</hw> <pr>(?)</pr>, <pos>n. pl.</pos>
<ety>[NL.]</ety> <fld>(Zool.)</fld> <def>A division of marsupials. The
wombat is the type.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhizophagous</ent><br/
<hw>Rhi*zoph"a*gous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<?/<?/<?/; <?/<?/<?/ a root + <?/<?/<?/ to eat.]</ety> <def>Feeding on
roots; root-eating.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhizophora</ent><br/
\'d8<hw>Rhi*zoph"o*ra</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. See
<er>Rhizophorous</er>.]</ety> <fld>(Bot.)</fld> <def>A genus of trees
including the mangrove. See <er>Mangrove</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhizophorous</ent><br/
<hw>Rhi*zoph"o*rous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/<?/<?/
a root + <grk>fe`rein</grk> to bear.]</ety> <fld>(Bot.)</fld>
<def>Bearing roots.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhizopod</ent><br/
<hw>Rhiz"o*pod</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>One of the Rhizopoda.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The rhizopods belonging to the Radiolaria and
Foraminifera have been of great geological importance, especially in the
Cretaceous and Tertiary periods. Chalk is mostly made from the shells of
Foraminifera. The nummulites are the principal ingredient of a limestone
which is of great extent in Europe and Asia, and is the material of
which some of the pyramids of Egypt are made. The shells are abundant in
deepsea mud, and are mostly minute, seldom larger than a small grain of
sand, except in the case of the nummulities, which are sometimes an inch
in diameter.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhizopoda</ent><br/
\'d8<hw>Rhi*zop"o*da</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL., fr.
Gr. <?/<?/<?/ a root + <ets>-poda</ets>.]</ety> <fld>(Zool.)</fld>
<def>An extensive class of Protozoa, including those which have
pseudopodia, by means of which they move about and take their food. The
principal groups are Lobosa (or Am<oe/bea), Helizoa, Radiolaria, and
Foraminifera (or Reticularia). See <er>Protozoa</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhizopodous</ent><br/
<hw>Rhi*zop"o*dous</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Of or pertaining to the rhizopods.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhizostomata</ent><br/
\'d8<hw>Rhi`zo*stom"a*ta</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
fr. Gr. <?/<?/<?/ a root + <?/<?/<?/, <?/<?/<?/<?/, a mouth.]</ety>
<fld>(Zool.)</fld> <def>A suborder of Medusae which includes very large
species without marginal tentacles, but having large mouth lobes closely
united at the edges. See <xex>Illust.</xex> in Appendix.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhizostome</ent><br/
<hw>Rhiz"o*stome</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>One of the Rhizostomata.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1238 --></p>

<p><ent>Rhizotaxis</ent><br/
\'d8<hw>Rhi`zo*tax"is</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <?/<?/<?/ a root + <?/<?/<?/ arrangement.]</ety> <fld>(Bot.)</fld>
<def>The arrangement of the roots of plants.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhob</ent><br/
<hw>Rhob</hw> <pr>(r<ocr/b)</pr>, <pos>n.</pos> <def>See 1st
<er>Rob</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhodammonium</ent><br/
<hw>Rho`dam*mo"ni*um</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Chem.)</fld>
<def>Pertaining to, derived from, or containing, rhodium and ammonia; --
said of certain complex compounds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhodanate</ent><br/
<hw>Rho"da*nate</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>A salt of rhodanic acid; a sulphocyanate.</def>
<mark>[Obsoles.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhodanic</ent><br/
<hw>Rho*dan"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/<?/<?/ the
rose.]</ety> <fld>(Chem.)</fld> <def>Pertaining to, or designating, an
acid (commonly called <xex>sulphocyanic acid</xex>) which frms a red
color with ferric salts.</def> <mark>[Obsoles.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhodeoretin</ent><br/
<hw>Rho`de*o*re"tin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/<?/<?/
the rose + <?/<?/<?/ resin.]</ety> <fld>(Chem.)</fld> <def>Same as
<er>Convolvuln</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhodian</ent><br/
<hw>Rho"di*an</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>Rhodius</ets>: cf. F. <ets>rhodien</ets>.]</ety> <def>Of or
pertaining to Rhodes, an island of the Mediterranean.</def> --
<def2><pos>n.</pos> <def>A native or inhabitant of
Rhodes.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhodic</ent><br/
<hw>Rho"dic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Chem.)</fld> <def>Of
or pertaining to rhodium; containing rhodium.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhodium</ent><br/
<hw>Rho"di*um</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<grk>"ro`don</grk> the rose. So called from the rose-red color of
certain of its solutions. See <er>Rhododendron</er>.]</ety>
<fld>(Chem.)</fld> <def>A rare element of the light platinum group. It
is found in platinum ores, and obtained free as a white inert metal
which it is very difficult to fuse. Symbol Rh. Atomic weight 104.1.
Specific gravity 12.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhodizonic</ent><br/
<hw>Rho`di*zon"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/<?/<?/
to be rose-red.]</ety> <fld>(Chem.)</fld> <def>Pertaining to, or
designating, a colorless crystalline substance (called <xex>rhodizonic
acid</xex>, and <xex>carboxylic acid</xex>) obtained from potassium
carboxide and from certain quinones. It forms brilliant red, yellow, and
purple salts.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhodochrosite</ent><br/
<hw>Rho`do*chro"site</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>"ro`don</grk> the rose + <?/<?/<?/ a coloring.]</ety>
<fld>(Min.)</fld> <def>Manganese carbonate, a rose-red mineral sometimes
occuring crystallized, but generally massive with rhombohedral cleavage
like calcite; -- called also <altname>dialogite</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhodocrinite</ent><br/
<hw>Rho*doc"ri*nite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>"ro`don</grk> rose + <?/<?/<?/ lily.]</ety> <fld>(Paleon.)</fld>
<def>A rose encrinite.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhododendron</ent><br/
<hw>Rho`do*den"dron</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., fr. Gr.
<grk>"rodo`dendron</grk>, literally, rose tree; <grk>"ro`don</grk> rose
+ <grk>de`ndron</grk> tree. See <er>Rose</er>.]</ety> <fld>(Bot.)</fld>
<def>A genus of shrubs or small trees, often having handsome evergreen
leaves, and remarkable for the beauty of their flowers;
rosebay.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhodomontade</ent><br/
<hw>Rhod`o*mon*tade"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Rodomontade</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhodomontader</ent><br/
<hw>Rhod`o*mon*tad"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Rodomontador</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhodonite</ent><br/
<hw>Rho"don*ite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>"ro`don</grk> the rose. ]</ety> <fld>(Min.)</fld> <def>Manganese
spar, or silicate of manganese, a mineral occuring crystallised and in
rose-red masses. It is often used as an ornamental stone.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhodophane</ent><br/
<hw>Rho"do*phane</hw> <pr>(r<omac/"d<osl/*f<amac/n)</pr>, <pos>n.</pos>
<ety>[Gr. <grk>"ro`don</grk> the rose + <grk>fai`nein</grk> to
show.]</ety> <fld>(Physiol.)</fld> <def>The red pigment contained in the
inner segments of the cones of the retina in animals. See
<er>Chromophane</er>.</def> <rj><au>W. K<uum/hne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhodopsin</ent><br/
<hw>Rho*dop"sin</hw> <pr>(r<osl/*d<ocr/p"s<icr/n)</pr>, <pos>n.</pos>
<ety>[Gr. <grk>"ro`don</grk> rose + <grk>"w`ps</grk> eye.]</ety>
<fld>(Physiol.)</fld> <def>The visual purple. See under
<er>Visual</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhodosperm</ent><br/
<hw>Rho"do*sperm</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>"ro`don</grk> the rose + <grk>spe`rma</grk> a seed.]</ety>
<fld>(Bot.)</fld> <def>Any seaweed with red spores.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ As the name of a subclass, <xex>Rhodosperms</xex>, or
<spn>Rhodospermeae</spn>, is synonymous with <spn>Florideae</spn> (which
see.)</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhomb</ent><br/
<hw>Rhomb</hw> <pr>(r<ocr/mb <it>or</it> r<ocr/m; 277)</pr>,
<pos>n.</pos> <ety>[L. <ets>rhombus</ets>, Gr. <grk>"ro`mbos</grk>
rhomb, a spinning top, magic wheel, fr. <grk>"re`mbein</grk> to turn or
whirl round, perhaps akin to E. <ets>wrench</ets>: cf. F.
<ets>rhombe</ets>. Cf. <er>Rhombus</er>, <er>Rhumb</er>.]</ety>
<sn>1.</sn> <fld>(Geom.)</fld> <def>An equilateral parallelogram, or
quadrilateral figure whose sides are equal and the opposite sides
parallel. The angles may be unequal, two being obtuse and two acute, as
in the cut, or the angles may be equal, in which case it is usually
called a <stype>square</stype>.</def> <-- Illustr. of Rhomb. --><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Geom.)</fld> <def>A rhombohedron.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fresnel's rhomb</b></col> <fld>(Opt.)</fld>, <cd>a rhomb
or oblique parallelopiped of crown or St. Gobain glass so cut that a ray
of light entering one of its faces at right angles shall emerge at right
angles at the opposite face, after undergoing within the rhomb, at other
faces, two reflections. It is used to produce a ray circularly polarized
from a plane-polarized ray, or the reverse.</cd>
<rj><au>Nichol.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhombic</ent><br/
<hw>Rhom"bic</hw> <pr>(r<ocr/m"b<icr/k)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Shaped like a rhomb.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Crystallog.)</fld> <def>Same as
<er>Orthorhombic</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhomboganoid</ent><br/
<hw>Rhom`bo*ga"noid</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Rhomb</ets> + <ets>ganoid</ets>.]</ety> <fld>(Zool.)</fld>
<def>A ganoid fish having rhombic enameled scales; one of the
Rhomboganoidei.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhomboganoidei</ent><br/
\'d8<hw>Rhom`bo*ga*noi"de*i</hw> <pr>(?)</pr>, <pos>n. pl.</pos>
<ety>[NL.]</ety> <fld>(Zool.)</fld> <def>Same as
<er>Ginglymodi</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhombogene</ent><br/
<hw>Rhom"bo*gene</hw> <pr>(r<ocr/m"b<osl/*j<emac/n)</pr>, <pos>n.</pos>
<ety>[<ets>Rhomb</ets> + root of Gr. <grk>gi`gnesqai</grk> to be
born.]</ety> <fld>(Zool.)</fld> <def>A dicyemid which produces
infusorialike embryos; -- opposed to <contr>nematogene</contr>. See
<er>Dicyemata</er>.</def> <altsp>[Written also
<asp>rhombogen</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhombohedral</ent><br/
<hw>Rhom`bo*he"dral</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Geom. &
Crystallog.)</fld> <def>Related to the rhombohedron; presenting the form
of a rhombohedron, or a form derivable from a rhombohedron; relating to
a system of forms including the rhombohedron and
scalenohedron.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Rhombohedral iron ore</b></col> <fld>(Min.)</fld> <cd>See
<er>Hematite</er>.</cd> -- <col><b>Rhombohedral system</b></col>
<fld>(Crystallog.)</fld>, <cd>a division of the hexagonal system
embracing the rhombohedron, scalenohedron, etc.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhombohedric</ent><br/
<hw>Rhom`bo*hed"ric</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Geom. &
Crystallog.)</fld> <def>Rhombohedral.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhombohedron</ent><br/
<hw>Rhom`bo*he"dron</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<?/<?/<?/ rhomb + <?/<?/<?/ seat, base.]</ety> <fld>(Geom. &
Crystallog.)</fld> <def>A solid contained by six rhomboids; a
parallelopiped.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhomboid</ent><br/
<hw>Rhom"boid</hw> <pr>(r<ocr/m"boid)</pr>, <pos>n.</pos> <ety>[Gr.
<?/<?/<?/ rhomboidal; <?/<?/<?/ rhomb + <grk>e'i^dos</grk> shape: cf. F.
<ets>rhombo<ium/de</ets>.]</ety> <fld>(Geom.)</fld> <def>An
oblique-angled parallelogram like a rhomb, but having only the opposite
sides equal, the length and with being different.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhomboid</ent><br/
<hw>Rhom"boid</hw> <pr>(r<ocr/m"boid)</pr>, <pos>a.</pos> <def>Same as
<er>Rhomboidal</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhomboidal</ent><br/
<hw>Rhom*boid"al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>rhombo<ium/dal</ets>.]</ety> <def>Having, or approaching, the shape
of a rhomboid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhomboides</ent><br/
<hw>Rhom*boid"es</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A rhomboid.</def>
<mark>[R.]</mark> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhomboid-ovate</ent><br/
<hw>Rhom`boid-o"vate</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Between
rhomboid and ovate, or oval, in shape.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhomb spar</ent><br/
<hw>Rhomb" spar`</hw> <pr>(?)</pr>. <fld>(Min.)</fld> <def>A variety of
dolomite.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhombus</ent><br/
<hw>Rhom"bus</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.]</ety> <def>Same
as <er>Rhomb</er>, 1.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhonchal</ent><br/
<hw>Rhon`chal</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Med.)</fld>
<def>Rhonchial.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhonchial</ent><br/
<hw>Rhon"chi*al</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Med.)</fld>
<def>Of or pertaining to a rhonchus; produced by rhonchi.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Rhonchial fremitus</b></col>. <ety>[L.
<ets>fremitus</ets> a dull roaring or murmuring.]</ety>
<fld>(Med.)</fld> <cd>A vibration of the chest wall that may be felt by
the hand laid upon its surface. It is caused in the production of
rhonchi in the bronchial tubes.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhonchisonant</ent><br/
<hw>Rhon*chis"o*nant</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>rhonchus</ets> a snoring + <ets>sonans</ets>, p. pr. of
<ets>sonare</ets> to sound.]</ety> <def>Making a snorting noise;
snorting.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhonchus</ent><br/
\'d8<hw>Rhon"chus</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Rhonchi</plw> <pr>(#)</pr>.</plu> <ety>[L., a snoring, a
croaking.]</ety> <fld>(Med.)</fld> <def>An adventitious whistling or
snoring sound heard on auscultation of the chest when the air channels
are partially obstructed. By some writers the term <xex>rhonchus</xex>
is used as equivalent to <xex>r<acir/le</xex> in its widest sense. See
<er>R<acir/le</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhopalic</ent><br/
<hw>Rho*pal"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/<?/<?/<?/
club-shaped; fr. <?/<?/<?/ a club: cf. F. <ets>rhopalique</ets>.]</ety>
<fld>(Pros.)</fld> <def>Applied to a line or verse in which each
successive word has one more syllable than the preceding.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhopalium</ent><br/
\'d8<hw>Rho*pa"li*um</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Rhopalia</plw> <pr>(#)</pr>.</plu> <ety>[NL.]</ety>
<fld>(Zool.)</fld> <def>One of the marginal sensory bodies of medusae
belonging to the Discophora.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhopalocera</ent><br/
\'d8<hw>Rhop`a*loc"e*ra</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
from Gr. <?/<?/<?/ a club + <?/<?/<?/ ahorn.]</ety> <fld>(Zool.)</fld>
<def>A division of Lepidoptera including all the butterflies. They
differ from other Lepidoptera in having club-shaped antennae.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhotacism</ent><br/
<hw>Rho"ta*cism</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>"rwtaki`zein</grk> to use the letter <it>r</it> (<rho/) overmuch:
cf. F. <ets>rhotacisme</ets>.]</ety> <def>An oversounding, or a misuse,
of the letter <xex>r</xex>; specifically <fld>(Phylol.)</fld>, the
tendency, exhibited in the Indo-European languages, to change
<xex>s</xex> to <xex>r</xex>, as <xex>wese</xex> to
<xex>were</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhubarb</ent><br/
<hw>Rhu"barb</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>rhubarbe</ets>, OF. <ets>rubarbe</ets>, <ets>rheubarbe</ets>,
<ets>reubarbare</ets>, <ets>reobarbe</ets>, LL. <ets>rheubarbarum</ets>
for <ets>rheum barbarum</ets>, Gr. <?/<?/<?/ (and <?/<?/) rhubarb, from
the river <ets>Rha</ets> (the Volga) on whose banks it grew. Originally,
therefore, it was the barbarian plant from the Rha. Cf.
<er>Barbarous</er>, <er>Rhaponticine</er>.]</ety> <sn>1.</sn>
<fld>(Bot.)</fld> <def>The name of several large perennial herbs of the
genus <gen>Rheum</gen> and order <ord>Polygonaceae</ord>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The large and fleshy leafstalks of <spn>Rheum
Rhaponticum</spn> and other species of the same genus. They are
pleasantly acid, and are used in cookery. Called also
<altname>pieplant</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Med.)</fld> <def>The root of several species of
<spn>Rheum</spn>, used much as a cathartic medicine.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Monk's rhubarb</b></col>. <fld>(Bot.)</fld> <cd>See under
<er>Monk</er>.</cd> -- <col><b>Turkey rhubarb</b></col>
<fld>(Med.)</fld>, <cd>the roots of <spn>Rheum
Emodi</spn>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhubarby</ent><br/
<hw>Rhu"barb*y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Like
rhubarb.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhumb</ent><br/
<hw>Rhumb</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>rumb</ets>, Sp.
<ets>rumbo</ets>, or Pg. <ets>rumbo</ets>, <ets>rumo</ets>, probably fr.
Gr. <?/<?/<?/ a magic wheel, a whirling motion, hence applied to a point
of the compass. See <er>Rhomb</er>.]</ety> <fld>(Navigation)</fld>
<def>A line which crosses successive meridians at a constant angle; --
called also <altname>rhumb line</altname>, and <altname>loxodromic
curve</altname>. See <er>Loxodromic</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To sail on a rhumb</b></col>, <cd>to sail continuously on
one course, following a rhumb line.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhus</ent><br/
\'d8<hw>Rhus</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., sumac, fr. Gr.
<?/<?/<?/.]</ety> <fld>(Bot.)</fld> <def>A genus of shrubs and small
treets. See <er>Sumac</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhusma</ent><br/
<hw>Rhus"ma</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Rusma</er>.]</ety> <def>A mixtire of caustic lime and orpiment, or
tersulphide of arsenic, -- used in the depilation of hides.</def>
<rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhyme</ent><br/
<hw>Rhyme</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>ryme</ets>,
<ets>rime</ets>, AS. <ets>r<imac/m</ets> number; akin to OHG.
<ets>r<imac/m</ets> number, succession, series, G. <ets>reim</ets>
rhyme. The modern sense is due to the influence of F. <ets>rime</ets>,
which is of German origin, and originally the same word.]</ety>
<altsp>[The Old English spelling <asp>rime</asp> is becoming again
common. See Note under <er>Prime</er>.]</altsp> <sn>1.</sn> <def>An
expression of thought in numbers, measure, or verse; a composition in
verse; a rhymed tale; poetry; harmony of language.</def> <ldquo/Railing
<xex>rhymes</xex>.<rdquo/ <rj><au>Daniel.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>ryme</qex> I learned long ago.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He knew<br/
Himself to sing, and build the lofty <qex>rime</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Pros.)</fld> <def>Correspondence of sound in the
terminating words or syllables of two or more verses, one succeeding
another immediately or at no great distance. The words or syllables so
used must not begin with the same consonant, or if one begins with a
vowel the other must begin with a consonant. The vowel sounds and
accents must be the same, as also the sounds of the final consonants if
there be any.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>For <qex>rhyme</qex> with reason may dispense,<br/
And sound has right to govern sense.</q> <rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Verses, usually two, having this correspondence with
each other; a couplet; a poem containing rhymes.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A word answering in sound to another word.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Female rhyme</b></col>. <cd>See under
<er>Female</er>.</cd> -- <col><b>Male rhyme</b></col>. <cd>See under
<er>Male</er>.</cd> -- <col><b>Rhyme or reason</b></col>, <cd>sound or
sense.</cd> -- <col><b>Rhyme royal</b></col> <fld>(Pros.)</fld>, <cd>a
stanza of seven decasyllabic verses, of which the first and third, the
second, fourth, and fifth, and the sixth and seventh
rhyme.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhyme</ent><br/
<hw>Rhyme</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Rhymed</conjf> <pr>(?)</pr>;<pos>p. pr. & vb. n.</pos>
<conjf>Rhyming</conjf>.]</vmorph> <ety>[OE. <ets>rimen</ets>,
<ets>rymen</ets>, AS. <ets>r<imac/man</ets> to count: cf. F.
<ets>rimer</ets> to rhyme. See <er>Rhyme</er>, <pos>n.</pos>]</ety>
<sn>1.</sn> <def>To make rhymes, or verses.</def> <ldquo/Thou shalt no
longer <xex>ryme</xex>.<rdquo/ <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>There marched the bard and blockhead, side by side,<br/
Who <qex>rhymed</qex> for hire, and patronized for pride.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To accord in rhyme or sound.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And, if they <qex>rhymed</qex> and rattled, all was well.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhyme</ent><br/
<hw>Rhyme</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To put into
rhyme.</def> <rj><au>Sir T. Wilson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To influence by rhyme.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Hearken to a verser, who may chance<br/
<qex>Rhyme</qex> thee to good.</q> <rj><qau>Herbert.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhymeless</ent><br/
<hw>Rhyme"less</hw>, <pos>a.</pos> <def>Destitute of rhyme.</def>
<rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhymer</ent><br/
<hw>Rhym"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who makes rhymes;
a versifier; -- generally in contempt; a poor poet; a
poetaster.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This would make them soon perceive what despicaple creatures our
common <qex>rhymers</qex> and playwriters be.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhymery</ent><br/
<hw>Rhym"er*y</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The art or habit of
making rhymes; rhyming; -- in contempt.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhymester</ent><br/
<hw>Rhyme"ster</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A rhymer; a maker
of poor poetry.</def> <rj><au>Bp. Hall. Byron.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhymic</ent><br/
<hw>Rhym"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to
rhyme.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhymist</ent><br/
<hw>Rhym"ist</hw>, <pos>n.</pos> <def>A rhymer; a rhymester.</def>
<rj><au>Johnston.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhynchobdellea</ent><br/
\'d8<hw>Rhyn`chob*del"le*a</hw> <pr>(?)</pr>, <pos>n. pl.</pos>
<ety>[NL., fr. Gr. <grk>"ry`gchos</grk> snout + <?/<?/<?/ a
leech.]</ety> <fld>(Zool.)</fld> <def>A suborder of leeches including
those that have a protractile proboscis, without jaws. Clepsine is the
type.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhynchocephala</ent><br/
\'d8<hw>Rhyn`cho*ceph"a*la</hw> <pr>(?)</pr>, <pos>n. pl.</pos>
<ety>[NL., fr. Gr. <grk>"ry`gchos</grk> snout + <grk>kefalh`</grk>
head.]</ety> <fld>(Zool.)</fld> <def>An order of reptiles having
biconcave vertebrae, immovable quadrate bones, and many other peculiar
osteological characters. Hatteria is the only living genus, but numerous
fossil genera are known, some of which are among the earliest of
reptiles. See <er>Hatteria</er>. Called also
<altname>Rhynchocephalia</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhynchocoela</ent><br/
\'d8<hw>Rhyn`cho*coe"la</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
fr. Gr. <grk>"ry`gchos</grk> snout + <grk>koi`los</grk> hollow.]</ety>
<fld>(Zool.)</fld> <def>Same as <er>Nemertina</er>.</def> --
<wordforms><wf>Rhyn`cho*coe"lous</wf> <pr>(#)</pr>,
<pos>a.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhyncholite</ent><br/
<hw>Rhyn"cho*lite</hw> <pr>(<?/)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>"ry`gchos</grk> snout, beak + <ets>-lie</ets>: cf. F.
<ets>rhyncholithe</ets>.]</ety> <fld>(Paleon.)</fld> <def>A fossil
cephalopod beak.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhynchonella</ent><br/
\'d8<hw>Rhyn`cho*nel"la</hw> <pr>(<?/)</pr>, <pos>n.</pos> <ety>[NL.,
fr. Gr. <grk>"ry`gchos</grk> snout.]</ety> <fld>(Zool.)</fld> <def>A
genus of brachiopods of which some species are still living, while many
are found fossil.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhynchophora</ent><br/
\'d8<hw>Rhyn*choph"o*ra</hw> <pr>(<?/)</pr>, <pos>n. pl.</pos>
<ety>[NL., fr. Gr. <grk>"ry`gchos</grk> snout + <grk>fe`rein</grk> to
carry.]</ety> <fld>(Zool.)</fld> <def>A group of Coleoptera having a
snoutlike head; the snout beetles, curculios, or weevils.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhynchophore</ent><br/
<hw>Rhyn"cho*phore</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>One of the Rhynchophora.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhynchota</ent><br/
\'d8<hw>Rhyn*cho"ta</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL., fr.
Gr. <grk>"ry`gchos</grk> snout.]</ety> <fld>(Zool.)</fld> <def>Same as
<er>Hemiptera</er>.</def> <altsp>[Written also
<asp>Rhyncota</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhyolite</ent><br/
<hw>Rhy"o*lite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>"rei^n</grk> to flow + <ets>-lite</ets>.]</ety> <fld>(Min.)</fld>
<def>A quartzose trachyte, an igneous rock often showing a fluidal
structure.</def> -- <wordforms><wf>Rhy`o*lit"ic</wf>, <pr>(#)</pr>,
<pos>a.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhyparography</ent><br/
<hw>Rhy`pa*rog"ra*phy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<?/<?/<?/<?/ painting foul or mean objects; <grk>"ryparo`s</grk> filthy,
dirty + <grk>gra`fein</grk> to write, paint.]</ety> <def>In ancient art,
the painting of genre or still-life pictures.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhysimeter</ent><br/
<hw>Rhy*sim"e*ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/<?/<?/
flow + <ets>-meter</ets>.]</ety> <def>An instrument, acting on the
principle of Pitot's tube, for measuring the velocity of a fluid
current, the speed of a ship, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhythm</ent><br/
<hw>Rhythm</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>rhythme</ets>,
<ets>rythme</ets>, L. <ets>rhythmus</ets>, fr. Gr. <?/<?/<?/ measured
motion, measure, proportion, fr. <grk>"rei^n</grk> to flow. See
<er>Stream</er>.]</ety> <sn>1.</sn> <def>In the widest sense, a dividing
into short portions by a regular succession of motions, impulses,
sounds, accents, etc., producing an agreeable effect, as in music
poetry, the dance, or the like.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mus.)</fld> <def>Movement in musical time, with
periodical recurrence of accent; the measured beat or pulse which marks
the character and expression of the music; symmetry of movement and
accent.</def> <rj><au>Moore (Encyc.)</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A division of lines into short portions by a regular
succession of <xex>arses</xex> and <xex>theses</xex>, or percussions and
remissions of voice on words or syllables.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The harmonious flow of vocal sounds.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1239 --></p>

<p><ent>Rhythmer</ent><br/
<hw>Rhyth"mer</hw> <pr>(r<icr/th"m<etil/r <it>or</it>
r<icr/<th/"-)</pr>, <pos>n.</pos> <def>One who writes in rhythm, esp. in
poetic rhythm or meter.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>One now scarce counted a <qex>rhythmer</qex>, formerly admitted
for a poet.</q> <rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhythmical</ent><br/
<ent>Rhythmic</ent><br/
<mhw>{ <hw>Rhyth"mic</hw> <pr>(-m<icr/k)</pr>, <hw>Rhyth"mic*al</hw>
<pr>(-m<icr/*k<ait/l)</pr>, }</mhw> <pos>a.</pos> <ety>[Gr.
<?/<?/<?/<?/: cf. L. <ets>rhythmicus</ets>, F.
<ets>rhythmique</ets>.]</ety> <def>Pertaining to, or of the nature of,
rhythm</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Day and night<br/
I worked my <qex>rhythmic</qex> thought.</q> <rj><qau>Mrs.
Browning.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Rhythmical accent</b></col>. <fld>(Mus.)</fld> <cd>See
<er>Accent</er>, <pos>n.</pos>, 6 <sd>(c)</sd>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhythmically</ent><br/
<hw>Rhyth"mic*al*ly</hw>, <pos>adv.</pos> <def>In a rhythmical
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhythmics</ent><br/
<hw>Rhyth"mics</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The department of
musical science which treats of the length of sounds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhythming</ent><br/
<hw>Rhyth"ming</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Writing rhythm;
verse making.</def> <ldquo/The <xex>rhythming</xex> monk.<rdquo/
<rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhythmless</ent><br/
<hw>Rhythm"less</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Being without
rhythm.</def> <rj><au>Coleridge.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhythmometer</ent><br/
<hw>Rhyth*mom"e*ter</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Rhythm</ets> + <ets>-meter</ets>.]</ety> <def>An instrument
for marking time in musical movements. See <er>Metronome</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhythmus</ent><br/
\'d8<hw>Rhyth"mus</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.]</ety>
<def>Rhythm.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rhytina</ent><br/
\'d8<hw>Rhyt"i*na</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>See <er>Rytina</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rial</ent><br/
<hw>Ri"al</hw> <pr>(<?/)</pr>, <pos>n.</pos> <def>A Spanish coin. See
<er>Real</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rial</ent><br/
<hw>Ri*al"</hw>, <pos>a.</pos> <def>Royal.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rial</ent><br/
<hw>Ri"al</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<er>Royal</er>.]</ety> <def>A gold coin formerly current in England, of
the value of ten shillings sterling in the reign of Henry VI., and of
fifteen shillings in the reign of Elizabeth.</def> <altsp>[Spelt also
<asp>ryal</asp>.]</altsp> <rj><au>Brande & C.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Riant</ent><br/
\'d8<hw>Ri`ant"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F.
<ets>riant</ets>, p. pr. of <ets>rire</ets> to laugh, L.
<ets>ridere</ets>.]</ety> <def>Laughing; laughable; exciting gayety;
gay; merry; delightful to the view, as a landscape.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In such cases the sublimity must be drawn from the other sources,
with a strict caution, howewer, against anything light and
<qex>riant</qex>.</q> <rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rib</ent><br/
<hw>Rib</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS. <ets>rib</ets>,
<ets>ribb</ets>; akin to D. <ets>rib</ets>, G. <ets>rippe</ets>, OHG.
<ets>rippa</ets>, <ets>rippi</ets>, Dan. <ets>ribbe</ets>, Icel.
<ets>rif</ets>, Russ. <ets>rebro</ets>.]</ety> <sn>1.</sn>
<fld>(Anat.)</fld> <def>One of the curved bones attached to the
vertebral column and supporting the lateral walls of the
thorax.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In man there are twelve ribs on each side, of which the
upper seven are directly connected with the sternum by cartilages, and
are called <xex>sternal</xex>, or <xex>true</xex>, <xex>ribs</xex>. The
remaining five pairs are called <xex>asternal</xex>, or
<xex>false</xex>, <xex>ribs</xex>, and of these each of the three upper
pairs is attached to the cartilage of the rib above, while the two lower
pairs are free at the ventral ends, and are called <xex>floating
ribs</xex>. See <er>Thorax</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which resembles a rib in form or use.</def>
Specifically: <sd>(a)</sd> <fld>(Shipbuilding)</fld> <def>One of the
timbers, or bars of iron or steel, that branch outward and upward from
the keel, to support the skin or planking, and give shape and strength
to the vessel.</def> <sd>(b)</sd> <fld>(Mach. & Structures)</fld> <def>A
ridge, fin, or wing, as on a plate, cylinder, beam, etc., to strengthen
or stiffen it.</def> <sd>(c)</sd> <def>One of the rods on which the
cover of an umbrella is extended.</def> <sd>(d)</sd> <def>A prominent
line or ridge, as in cloth.</def> <sd>(e)</sd> <def>A longitudinal strip
of metal uniting the barrels of a double-barreled gun.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Bot.)</fld> <def>The chief nerve, or one of the
chief nerves, of a leaf.</def> <sd>(b)</sd> <def>Any longitudinal ridge
in a plant.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Arch.)</fld> <sd>(a)</sd> <def>In Gothic vaulting,
one of the primary members of the vault. These are strong arches,
meeting and crossing one another, dividing the whole space into
triangles, which are then filled by vaulted construction of lighter
material. Hence, an imitation of one of these in wood, plaster, or the
like.</def> <sd>(b)</sd> <def>A projecting mold, or group of moldings,
forming with others a pattern, as on a ceiling, ornamental door, or the
like.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Mining)</fld> <sd>(a)</sd> <def>Solid coal on the
side of a gallery; solid ore in a vein.</def> <sd>(b)</sd> <def>An
elongated pillar of ore or coal left as a support.</def>
<rj><au>Raymond.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>A wife; -- in allusion to Eve, as made out of Adam's
rib.</def> <mark>[Familiar & Sportive]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>How many have we known whose heads have been broken with their own
<qex>rib</qex>.</q> <rj><qau>Bp. Hall.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Chuck rib</b></col>, <cd>a cut of beef immediately in
front of the middle rib. See <er>Chuck</er>.</cd> -- <col><b>Fore
ribs</b></col>, <cd>a cut of beef immediately in front of the
sirloin.</cd> -- <col><b>Middle rib</b></col>, <cd>a cut of beef between
the chuck rib and the fore ribs.</cd> -- <col><b>Rib grass</b></col>.
<fld>(Bot.)</fld> <cd>Same as <er>Ribwort</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rib</ent><br/
<hw>Rib</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Ribbed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Ribbing</conjf>.]</vmorph> <sn>1.</sn> <def>To furnish with ribs;
to form with rising lines and channels; <as>as, to <ex>rib</ex>
cloth</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To inclose, as with ribs, and protect; to shut
in.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- 3. To kid; to poke fun at. --><br/
[<source>1913 Webster</source>]</p>

<p><q>It [lead] were too gross<br/
To <qex>rib</qex> her cerecloth in the obscure grave.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To rib land</b></col>, <cd>to leave strips of undisturbed
ground between the furrows in plowing.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ribald</ent><br/
<hw>Rib"ald</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>ribald</ets>, <ets>ribaud</ets>, F. <ets>ribaud</ets>, OF.
<ets>ribald</ets>, <ets>ribault</ets>, LL. <ets>ribaldus</ets>, of
German origin; cf. OHG <ets>hr<imac/pa</ets> prostitute. For the ending
<ets>-ald</ets> cf. E. <er>Herald</er>.]</ety> <def>A low, vulgar,
brutal, foul-mouthed wretch; a lewd fellow.</def> <rj><au>Spenser.
Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Ribald</qex> was almost a class name in the feudal system . .
. He was his patron's parasite, bulldog, and tool . . . It is not to be
wondered at that the word rapidly became a synonym for everything
ruffianly and brutal.</q> <rj><qau>Earle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ribald</ent><br/
<hw>Rib"ald</hw>, <pos>a.</pos> <def>Low; base; mean; filthy;
obscene.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The busy day,<br/
Waked by the lark, hath roused the <qex>ribald</qex> crows.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ribaldish</ent><br/
<hw>Rib"ald*ish</hw>, <pos>a.</pos> <def>Like a ribald.</def>
<rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ribaldrous</ent><br/
<hw>Rib"ald*rous</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of a ribald
quality.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ribaldry</ent><br/
<hw>Rib"ald*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>ribaldrie</ets>, <ets>ribaudrie</ets>, OF. <ets>ribalderie</ets>,
<ets>ribauderie</ets>.]</ety> <def>The talk of a ribald; low, vulgar
language; indecency; obscenity; lewdness; -- now chiefly applied to
indecent language, but formerly, as by Chaucer, also to indecent acts or
conduct.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>ribaldry</qex> of his conversation moved astonishment
even in that age.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Riban</ent><br/
<hw>Rib"an</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Ribbon</er>.</def> <mark>[Obs.]</mark> <rj><au>Piers
Plowman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Riband</ent><br/
<hw>Rib"and</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Ribbon</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Riband jasper</b></col> <fld>(Min.)</fld>, <cd>a variety
of jasper having stripes of different colors, as red and
green.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Riband</ent><br/
<hw>Rib"and</hw>, <pos>n.</pos> <fld>(Naut.)</fld> <def>See
<er>Rib-band</er>.</def> <rj><au>Totten.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ribanded</ent><br/
<hw>Rib"and*ed</hw>, <pos>a.</pos> <def>Ribboned.</def> <rj><au>B.
Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ribaud</ent><br/
<hw>Rib"aud</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A ribald.</def>
<mark>[Obs.]</mark> <rj><au>P. Plowman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ribaudequin</ent><br/
\'d8<hw>Ri*bau"de*quin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<sn>1.</sn> <def>An engine of war used in the Middle Ages, consisting of
a protected elevated staging on wheels, and armed in front with pikes.
It was (after the 14th century) furnished with small cannon.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A huge bow fixed on the wall of a fortified town for
casting javelins.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ribaudrous</ent><br/
<ent>Ribaudred</ent><br/
<mhw>{ <hw>Rib"aud*red</hw> <pr>(?)</pr>, <hw>Rib"aud*rous</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <def>Filthy; obscene; ribald.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ribaudry</ent><br/
<hw>Rib"aud*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Ribaldry.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ribaudy</ent><br/
<hw>Rib"aud*y</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Ribaldry.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ribauld</ent><br/
<hw>Rib"auld</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A ribald.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ribband</ent><br/
<hw>Rib"band</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A ribbon.</def>
<rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ribband</ent><br/
<hw>Rib"band`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Rib</ets> +
<ets>band</ets>.]</ety> <ety>[Written also <ets>riband</ets>, and
<ets>ribbon</ets>.]</ety> <fld>(Shipbuilding)</fld> <def>A long, narrow
strip of timber bent and bolted longitudinally to the ribs of a vessel,
to hold them in position, and give rigidity to the framework.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Rib-band lines</b></col>, <cd>oblique longitudinal
sections of the hull of a vessel.</cd>
<rj><au>Knight.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ribbed</ent><br/
<hw>Ribbed</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Furnished
or formed with ribs; <as>as, a <ex>ribbed</ex> cylinder; <ex>ribbed</ex>
cloth</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mining)</fld> <def>Intercalated with slate; -- said
of a seam of coal.</def> <rj><au>Raymond.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ribbing</ent><br/
<hw>Rib"bing</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An assemblage or
arrangement of ribs, as the timberwork for the support of an arch or
coved ceiling, the veins in the leaves of some plants, ridges in the
fabric of cloth, or the like.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ribbon</ent><br/
<hw>Rib"bon</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>riban</ets>,
OF. <ets>riban</ets>, F. <ets>ruban</ets>, probably of German origin;
cf. D. <ets>ringband</ets> collar, necklace, E. <ets>ring</ets> circle,
and <ets>band</ets>.]</ety> <altsp>[Written also <asp>riband</asp>,
<asp>ribband</asp>.]</altsp> <sn>1.</sn> <def>A fillet or narrow woven
fabric, commonly of silk, used for trimming some part of a woman's
attire, for badges, and other decorative purposes.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A narrow strip or shred; <as>as, a steel or
magnesium <ex>ribbon</ex>; sails torn to
<ex>ribbons</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Shipbuilding)</fld> <def>Same as
<er>Rib-band</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <pluf>pl.</pluf> <def>Driving reins.</def>
<mark>[Cant]</mark> <rj><au>London Athenaeum.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Her.)</fld> <def>A bearing similar to the bend, but
only one eighth as wide.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Spinning)</fld> <def>A silver.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>The blue ribbon</xex>, and <xex>The red
ribbon</xex>, are phrases often used to designate the British orders of
the Garter and of the Bath, respectively, the badges of which are
suspended by ribbons of these colors. See <cref>Blue ribbon</cref>,
under <er>Blue</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Ribbon fish</b></col>. <fld>(Zool.)</fld> <sd>(a)</sd>
<cd>Any elongated, compressed, ribbon-shaped marine fish of the family
<fam>Trachypteridae</fam>, especially the species of the genus
<gen>Trachypterus</gen>, and the oarfish (<spn>Regelecus Banksii</spn>)
of the North Atlantic, which is sometimes over twenty feet long</cd>.
<sd>(b)</sd> <cd>The hairtail, or bladefish</cd>. <sd>(c)</sd> <cd>A
small compressed marine fish of the genus <gen>Cepola</gen>, having a
long, slender, tapering tail. The European species (<spn>Cepola
rubescens</spn>) is light red throughout. Called also <altname>band
fish</altname>.</cd> -- <col><b>Ribbon grass</b></col>
<fld>(Bot.)</fld>, <cd>a variety of reed canary grass having the leaves
stripped with green and white; -- called also <altname>Lady's
garters</altname>. See <cref>Reed grass</cref>, under
<er>Reed</er>.</cd> -- <col><b>Ribbon seal</b></col> <fld>(Zool.)</fld>,
<cd>a North Pacific seal (<spn>Histriophoca fasciata</spn>). The adult
male is dark brown, conspicuously banded and striped with yellowish
white.</cd> -- <col><b>Ribbon snake</b></col> <fld>(Zool.)</fld>, <cd>a
common North American snake (<spn>Eutainia saurita</spn>). It is
conspicuously striped with bright yellow and dark brown.</cd> --
<col><b>Ribbon Society</b></col>, <cd>a society in Ireland, founded in
the early part of the 19th century in antagonism to the Orangemen. It
afterwards became an organization of tennant farmers banded together to
prevent eviction by landlords. It took its name from the green ribbon
worn by members as a badge.</cd> -- <col><b>Ribborn worm</b></col>.
<fld>(Zool.)</fld> <sd>(a)</sd> <cd>A tapeworm</cd>. <sd>(b)</sd> <cd>A
nemertean.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ribbon</ent><br/
<hw>Rib"bon</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Ribboned</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Ribboning</conjf>.]</vmorph> <def>To adorn with, or as with,
ribbons; to mark with stripes resembling ribbons.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ribbonism</ent><br/
<hw>Rib"bon*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The principles and
practices of the Ribbonmen. See <cref>Ribbon Society</cref>, under
<er>Ribbon</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ribbonman</ent><br/
<hw>Rib"bon*man</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>-men</plw>.</plu> <def>A member of the Ribbon Society. See
<cref>Ribbon Society</cref>, under <er>Ribbon</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ribbonwood</ent><br/
<hw>Rib"bon*wood`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>A malvaceous tree (<spn>Hoheria populnea</spn>) of New Zealand, the
bark of which is used for cordage.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ribes</ent><br/
\'d8<hw>Ri"bes</hw> <pr>(?)</pr>, <pos>n.</pos><ety>[NL.; cf. Dan.
<ets>ribs</ets>, and Ar. <ets>r<imac/b<amac/s</ets> a plant with an acid
juice.]</ety> <fld>(Bot.)</fld> <def>A genus of shrubs including
gooseberries and currants of many kinds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ribibe</ent><br/
<hw>Rib"ibe</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Rebec</er>.]</ety> <sn>1.</sn> <def>A sort of stringed instrument; a
rebec.</def> <mark>[Obs.]</mark> <rj><au>Nares.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An old woman; -- in contempt.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A bawd; a prostitute.</def> <mark>[Obs.]</mark>
<rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ribible</ent><br/
<hw>Rib"i*ble</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Ribibe</er>.]</ety> <def>A small threestringed viol; a rebec.</def>
<rj><au>Moore (Encyc. of Music).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>All can be play on gittern or <qex>ribible</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ribless</ent><br/
<hw>Rib"less</hw>, <pos>a.</pos> <def>Having no ribs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ribroast</ent><br/
<hw>Rib"roast`</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To beat
soundly.</def> <mark>[Slang]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ribwort</ent><br/
<hw>Rib"wort`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>A
species of plantain (<spn>Plantago lanceolata</spn>) with long, narrow,
ribbed leaves; -- called also <altname>rib grass</altname>,
<altname>ripple grass</altname>, <altname>ribwort
plantain</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>-ric</ent><br/
<hw>-ric</hw> <pr>(?)</pr>. <ety>[AS <ets>r<imac/ce</ets> kingdom,
dominion. See <er>Rich</er>.]</ety> <def>A suffix signifying
<xex>dominion</xex>, <xex>jurisdiction</xex>; <as>as,
bishop<ex>ric</ex>, the district over which a bishop exercises
authority</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rice</ent><br/
<hw>Rice</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>riz</ets> (cf.
Pr. <ets>ris</ets>, It. <ets>riso</ets>), L. <ets>oryza</ets>, Gr.
<?/<?/<?/, <?/<?/<?/, probably from the Persian; cf. OPers.
<ets>br<imac/zi</ets>, akin to Skr. <ets>vr<imac/hi</ets>; or perh. akin
to E. <ets>rye</ets>. Cf. <er>Rye</er>.]</ety> <fld>(Bot.)</fld> <def>A
well-known cereal grass (<spn>Oryza sativa</spn>) and its seed. This
plant is extensively cultivated in warm climates, and the grain forms a
large portion of the food of the inhabitants. In America it grows
chiefly on low, moist land, which can be overflowed.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Ant rice</b></col>. <fld>(Bot.)</fld> <cd>See under
<er>Ant</er>.</cd> -- <col><b>French rice</b></col>. <fld>(Bot.)</fld>
<cd>See <er>Amelcorn</er>.</cd> -- <col><b>Indian rice</b></col>., <cd>a
tall reedlike water grass (<spn>Zizania aquatica</spn>), bearing
panicles of a long, slender grain, much used for food by North American
Indians. It is common in shallow water in the Northern States. Called
also <altname>water oat</altname>, <altname>Canadian wild
rice</altname>, etc.</cd> -- <col><b>Mountain rice</b></col>, <cd>any
species of an American genus (<spn>Oryzopsis</spn>) of grasses, somewhat
resembling rice.</cd> -- <col><b>Rice bunting</b></col>.
<fld>(Zool.)</fld> <cd>Same as <er>Ricebird</er>.</cd> -- <col><b>Rice
hen</b></col> <fld>(Zool.)</fld>, <cd>the Florida gallinule.</cd> --
<col><b>Rice mouse</b></col> <fld>(Zool.)</fld>, <cd>a large
dark-colored field mouse (<spn>Calomys palistris</spn>) of the Southern
United States.</cd> -- <col><b>Rice paper</b></col>, <cd>a kind of thin,
delicate paper, brought from China, -- used for painting upon, and for
the manufacture of fancy articles. It is made by cutting the pith of a
large herb (<spn>Fatsia papyrifera</spn>, related to the ginseng) into
one roll or sheet, which is flattened out under pressure. Called also
<altname>pith paper</altname>.</cd> -- <col><b>Rice troupial</b></col>
<fld>(Zool.)</fld>, <cd>the bobolink.</cd> -- <col><b>Rice
water</b></col>, <cd>a drink for invalids made by boiling a small
quantity of rice in water.</cd> -- <col><b>Rice-water
discharge</b></col> <fld>(Med.)</fld>, <cd>a liquid, resembling rice
water in appearance, which is vomited, and discharged from the bowels,
in cholera.</cd> -- <col><b>Rice weevil</b></col> <fld>(Zool.)</fld>,
<cd>a small beetle (<spn>Calandra oryzae</spn>, <it>or</it>
<spn>Sitophilus oryzae</spn>) which destroys rice, wheat, and Indian
corn by eating out the interior; -- called also <altname>black
weevil</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ricebird</ent><br/
<hw>Rice"bird`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<sd>(a)</sd> <def>The Java sparrow.</def> <sd>(b)</sd> <def>The
bobolink.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rice-shell</ent><br/
<hw>Rice"-shell`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>Any one of numerous species of small white polished marine shells
of the genus <gen>Olivella</gen>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rich</ent><br/
<hw>Rich</hw>, <pr>(r<icr/ch)</pr>, <pos>a.</pos>
<amorph>[<pos>Compar.</pos> <adjf>Richer</adjf> <pr>(<?/)</pr>;
<pos>superl.</pos> <adjf>Richest</adjf>.]</amorph> <ety>[OE.
<ets>riche</ets>, AS. <ets>r<imac/ce</ets> rich, powerful; akin to OS.
<ets>r<imac/ki</ets>, D. <ets>rijk</ets>, G. <ets>reich</ets>, OHG.
<ets>r<imac/hhi</ets>, Icel. <ets>r<imac/kr</ets>, Sw. <ets>rik</ets>,
Dan. <ets>rig</ets>, Goth. <ets>reiks</ets>; from a word meaning, ruler,
king, probably borrowed from Celtic, and akin to L. <ets>rex</ets>,
<ets>regis</ets>, king, <ets>regere</ets> to guide, rule. <root/283. See
<er>Right</er>, and cf. <er>Derrick</er>, <er>Enrich</er>,
<er>Rajah</er>, <er>Riches</er>, <er>Royal</er>.]</ety> <sn>1.</sn>
<def>Having an abundance of material possessions; possessed of a large
amount of property; well supplied with land, goods, or money; wealthy;
opulent; affluent; -- opposed to <ant>poor</ant>.</def>
<ldquo/<xex>Rich</xex> merchants.<rdquo/ <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>rich</qex> [person] hath many friends.</q> <rj><qau>Prov.
xiv. 20.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>As a thief, bent to unhoard the cash<br/
Of some <qex>rich</qex> burgher.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence, in general, well supplied; abounding;
abundant; copious; bountiful; <as>as, a <ex>rich</ex> treasury; a
<ex>rich</ex> entertainment; a <ex>rich</ex> crop</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If life be short, it shall be glorious;<br/
Each minute shall be <qex>rich</qex> in some great action.</q>
<rj><qau>Rowe.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The gorgeous East with <qex>richest</qex> hand<br/
Showers on her kings barbaric pearl and gold.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Yielding large returns; productive or fertile;
fruitful; <as>as, <ex>rich</ex> soil or land; a <ex>rich</ex>
mine.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Composed of valuable or costly materials or
ingredients; procured at great outlay; highly valued; precious;
sumptuous; costly; <as>as, a <ex>rich</ex> dress; <ex>rich</ex> silk or
fur; <ex>rich</ex> presents</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Like to <qex>rich</qex> and various gems.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Abounding in agreeable or nutritive qualities; --
especially applied to articles of food or drink which are high-seasoned
or abound in oleaginous ingredients, or are sweet, luscious, and
high-flavored; <as>as, a <ex>rich</ex> dish; <ex>rich</ex> cream or
soup; <ex>rich</ex> pastry; <ex>rich</ex> wine or fruit</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Sauces and <qex>rich</qex> spices are fetched from India.</q>
<rj><qau>Baker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Not faint or delicate; vivid; <as>as, a
<ex>rich</ex> color</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>Full of sweet and harmonius sounds; <as>as, a
<ex>rich</ex> voice; <ex>rich</ex> music</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>Abounding in beauty; gorgeous; <as>as, a
<ex>rich</ex> landscape; <ex>rich</ex> scenery</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>Abounding in humor; exciting amusement;
entertaining; <as>as, the scene was a <ex>rich</ex> one; a <ex>rich</ex>
incident or character</as>.</def> <mark>[Colloq.]</mark>
<rj><au>Thackeray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Rich</xex> is sometimes used in the formation of
self-explaining compounds; as, <xex>rich</xex>-fleeced,
<xex>rich</xex>-jeweled, <xex>rich</xex>-laden,
<xex>rich</xex>-stained.</note><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Wealthy; affluent; opulent; ample; copious;
abundant; plentiful; fruitful; costly; sumptuous; precious; generous;
luscious.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rich</ent><br/
<hw>Rich</hw>, <pos>v. t.</pos> <def>To enrich.</def>
<mark>[Obs.]</mark> <rj><au>Gower.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Riches</ent><br/
<hw>Rich"es</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[OE.
<ets>richesse</ets>, F. <ets>richesse</ets>, from <ets>riche</ets> rich,
of German origin. See <er>Rich</er>,<pos>a.</pos>]</ety> <sn>1.</sn>
<def>That which makes one rich; an abundance of land, goods, money, or
other property; wealth; opulence; affluence.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Riches</qex> do not consist in having more gold and silver,
but in having more in proportion, than our neighbors.</q>
<rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which appears rich, sumptuous, precious, or the
like.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>riche</qex> of heaven's pavement, trodden gold.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Richesse</xex>, the older form of this word, was in
the singular number. The form <xex>riches</xex>, however, is plural in
appearance, and has now come to be used as a plural.</note><br/
[<source>1913 Webster</source>]</p>

<p><q>Against the <qex>richesses</qex> of this world shall they have
misease of poverty.</q> <rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>In one hour so great <qex>riches</qex> is come to nought.</q>
<rj><qau>Rev. xviii. 17.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And for that <qex>riches</qex> where is my deserving?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Wealth; opulence; affluence; wealthiness;
richness; plenty; abundance.</syn><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1240 --></p>

<p><ent>Richesse</ent><br/
<hw>Rich"esse</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. See
<er>Riches</er>.]</ety> <def>Wealth; riches. See the Note under
<er>Riches</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Some man desireth for to have <qex>richesse</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>richesse</qex> of all heavenly grace.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Richly</ent><br/
<hw>Rich"ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a rich
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Richness</ent><br/
<hw>Rich"ness</hw>, <pos>n.</pos> <def>The quality or state of being
rich (in any sense of the adjective).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Richweed</ent><br/
<hw>Rich"weed`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>An herb (<spn>Pilea pumila</spn>) of the Nettle family, having a
smooth, juicy, pellucid stem; -- called also
<altname>clearweed</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ricinelaidic</ent><br/
<hw>Ric`in*e`la*id"ic</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Ricin</ets>oleic + <ets>elaidic</ets>.]</ety> <def>Pertaining
to, or designating, an isomeric modification of ricinoleic acid obtained
as a white crystalline solid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ricinelaidin</ent><br/
<hw>Ric`in*e*la"i*din</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Chem.)</fld> <def>The glycerin salt of ricinelaidic acid, obtained
as a white crystalline waxy substance by treating castor oil with
nitrous acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ricinic</ent><br/
<hw>Ri*cin"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>ricinus</ets> castor-oil plant.]</ety> <fld>(Chem.)</fld>
<def>Pertaining to, or derived from, castor oil; formerly, designating
an acid now called <altname>ricinoleic</altname>
<it>acid.</it></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ricinine</ent><br/
<hw>Ric"i*nine</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>ricinus</ets> castor-oil plant.]</ety> <fld>(Chem.)</fld> <def>A
bitter white crystalline alkaloid (<chform>C8H8N2O2</chform>) extracted
from the seeds of the castor-oil plant (<spn>Ricinus communalis</spn>).
Called also <altname>ricidine</altname>. Ingestion may cause vomiting
and various other toxic reactions, including liver and kidney damage,
convulsions, hypotension, and death.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Ricinoleate</ent><br/
<hw>Ric`in*o"le*ate</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>A salt of ricinoleic acid; -- formerly called
<altname>palmate</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ricinoleic</ent><br/
<hw>Ric`in*o"le*ic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Chem.)</fld>
<def>Pertaining to, or designating, a fatty acid analogous to oleic
acid, obtained from castor oil as an oily substance,
<chform>C18H34O3</chform> with a harsh taste. Formerly written
<altname>ricinolic</altname> and formerly referred to as
<altname>palmic</altname>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>ricinoleic acid</ent><br/
<hw>ric`in*o"le*ic ac"id</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Chem.)</fld> <def>An organic acid (<chform>C18H34O3</chform>)
obtained from the castor-oil plant (<spn>Ricinus communis</spn>, or
<spn>Palma Christi</spn>) and other species of the family
<fam>Euphorbiaceae</fam>; chemicaly it is d-12-hydroxyoleic acid
(<chform>CH3(CH2)5.CH(OH).CH2.CH=CH.(CH2)7COOH</chform>). Formerly
called <altname>palmic acid</altname>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Ricinolein</ent><br/
<hw>Ric`in*o"le*in</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>ricinus</ets> castor-oil plant + <ets>oleum</ets> oil.]</ety>
<fld>(Chem.)</fld> <def>The glycerin salt of ricinoleic acid, occuring
as a characteristic constituent of castor oil; -- formerly called
<altname>palmin</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ricinolic</ent><br/
<hw>Ric`i*nol"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Chem.)</fld>
<def>Ricinoleic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ricinus</ent><br/
\'d8<hw>Ric"i*nus</hw> <pr>(<?/)</pr>, <pos>n.</pos> <ety>[L., the
castor-oil plant.]</ety> <fld>(Bot.)</fld> <def>A genus of plants of the
Spurge family, containing but one species (<spn>Ricinus communis</spn>),
the castor-oil plant. The fruit is three-celled, and contains three
large seeds from which castor oil is expressed. See <er>Palma
Christi</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rick</ent><br/
<hw>Rick</hw> <pr>(r<icr/k)</pr>, <pos>n.</pos> <ety>[OE.
<ets>reek</ets>, <ets>rek</ets>, AS. <ets>hre<aacute/c</ets> a heap;
akin to <ets>hryce</ets> rick, Icel. hraukr.]</ety> <def>A stack or
pile, as of grain, straw, or hay, in the open air, usually protected
from wet with thatching.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Golden clusters of beehive <qex>ricks</qex>, rising at intervals
beyond the hedgerows.</q> <rj><qau>G. Eliot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rick</ent><br/
<hw>Rick</hw>, <pos>v. t.</pos> <def>To heap up in ricks, as hay,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ricker</ent><br/
<hw>Rick"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A stout pole for use
in making a rick, or for a spar to a boat.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ricketish</ent><br/
<hw>Rick"et*ish</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Rickety.</def>
<mark>[Obs.]</mark> <rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rickets</ent><br/
<hw>Rick"ets</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[Of uncertain
origin; but cf. AS. <ets>wrigian</ets> to bend, D. <ets>wrikken</ets> to
shake, E. <ets>wriggle</ets>.]</ety> <fld>(Med.)</fld> <def>A disease
which affects children, and which is characterized by a bulky head,
crooked spine and limbs, depressed ribs, enlarged and spongy articular
epiphyses, tumid abdomen, and short stature, together with clear and
often premature mental faculties. The essential cause of the disease
appears to be the nondeposition of earthy salts in the osteoid tissues.
Children afflicted with this malady stand and walk unsteadily. Called
also <altname>rachitis</altname>.</def> <-- also, infantile or juvenile
osteomalacia. Deficient calcification of bone causing skeletal
abnormalities. It is caused by vitamin D deficiency. --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rickety</ent><br/
<hw>Rick"et*y</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Affected
with rickets.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Feeble in the joints; imperfect; weak;
shaky.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rickrack</ent><br/
<hw>Rick"rack`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A kind of openwork
edging made of serpentine braid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rickstand</ent><br/
<hw>Rick"stand`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A flooring or
framework on which a rick is made.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ricochet</ent><br/
<hw>Ric`o*chet"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<sn>1.</sn> <def>A rebound or skipping, as of a bullet bouncing off a
hard surface, or off the ground when a gun is fired at a low angle of
elevation, or of a flat stone thrown along the surface of
water.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A peculiar gait used by certain animals such as the
kangaroo who move by a type of bouncing motion.</def><br/
[<source>PJC</source>]</p>

<p><q>Kangaroos and wallabies (macropodids) as well as kangaroo mice and
jerboas, locate themselves differently, though, and do not use the
forelimbs at all in their distinctive <i>modus locatus</i>, to which
<persfn>Muybridge</persfn> applied the term
<ldquo/<qex>ricochet</qex><rdquo/, . . .</q> <qau>Jaime A.
Headden</qau><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Ricochet firing</b></col> <fld>(Mil.)</fld>, <cd>the
firing of guns or howitzers, usually with small charges, at an elevation
of only a few degrees, so as to cause the balls or shells to bound or
skip along the ground.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ricochet</ent><br/
<hw>Ric`o*chet"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Ricochetted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Ricochetting</conjf>.]</vmorph> <def>To operate upon by ricochet
firing. See <er>Ricochet</er>, <pos>n.</pos></def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ricochet</ent><br/
<hw>Ric`o*chet"</hw>, <pos>v. i.</pos> <def>To skip with a rebound or
rebounds, as a flat stone on the surface of water, or a cannon ball on
the ground. See <er>Ricochet</er>, <pos>n.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rictal</ent><br/
<hw>Ric"tal</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld> <def>Of
or pertaining to the rictus; <as>as, <ex>rictal</ex>
bristles</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ricture</ent><br/
<hw>Ric"ture</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>ringi</ets>,
<ets>rictus</ets>, to open wide the mouth, to gape.]</ety> <def>A
gaping.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rictus</ent><br/
\'d8<hw>Ric"tus</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., the aperture
of the mouth.]</ety> <def>The gape of the mouth, as of birds; -- often
resricted to the corners of the mouth.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rid</ent><br/
<hw>Rid</hw> <pr>(?)</pr>, <def><pos>imp. & p. p.</pos> of
<er>Ride</er>, <pos>v. i.</pos></def> <mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He <qex>rid</qex> to the end of the village, where he
alighted.</q> <rj><qau>Thackeray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rid</ent><br/
<hw>Rid</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Rid</conjf> <it>or</it> <conjf>Ridded</conjf>; <pos>p. pr. & vb.
n.</pos> <conjf>Ridding</conjf>.]</vmorph> <ety>[OE. <ets>ridden</ets>,
<ets>redden</ets>, AS. <ets>hreddan</ets> to deliver, liberate; akin to
D. & LG. <ets>redden</ets>, G. <ets>retten</ets>, Dan. <ets>redde</ets>,
Sw. <ets>r<aum/dda</ets>, and perhaps to Skr. <ets><?/rath</ets> to
loosen.]</ety> <sn>1.</sn> <def>To save; to rescue; to deliver; -- with
<xex>out of</xex>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Deliver the poor and needy; <qex>rid</qex> them out of the hand of
the wicked.</q> <rj><qau>Ps. lxxxii. 4.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To free; to clear; to disencumber; -- followed by
<xex>of</xex>.</def> <ldquo/<xex>Rid</xex> all the sea of
pirates.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>In never <qex>ridded</qex> myself of an overmastering and brooding
sense of some great calamity traveling toward me.</q> <rj><qau>De
Quincey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To drive away; to remove by effort or violence; to
make away with; to destroy.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I will <qex>red</qex> evil beasts out of the land.</q>
<rj><qau>Lev. xxvi. 6.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Death's men, you have <qex>rid</qex> this sweet young prince!</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To get over; to dispose of; to dispatch; to
finish.</def> <mark>[R.]</mark> <ldquo/Willingness <xex>rids</xex>
way.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Mirth will make us <qex>rid</qex> ground faster than if thieves
were at our tails.</q> <rj><qau>J. Webster.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To be rid of</b></col>, <cd>to be free or delivered
from.</cd> -- <col><b>To get rid of</b></col>, <cd>to get deliverance
from; to free one's self from.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ridable</ent><br/
<hw>Rid"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Suitable for riding;
<as>as, a <ex>ridable</ex> horse; a <ex>ridable</ex>
road.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Riddance</ent><br/
<hw>Rid"dance</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The act
of ridding or freeing; deliverance; a cleaning up or out.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou shalt not make clean <qex>riddance</qex> of the corners of
thy field.</q> <rj><qau>Lev. xxiii. 22.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The state of being rid or free; freedom;
escape.</def> <ldquo/<xex>Riddance</xex> from all adversity.<rdquo/
<rj><au>Hooker.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ridden</ent><br/
<hw>Rid"den</hw> <pr>(?)</pr>, <def><pos>p. p.</pos> of
<er>Ride.</er></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ridder</ent><br/
<hw>Rid"der</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, rids.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Riddle</ent><br/
<hw>Rid"dle</hw> <pr>(r<icr/d"d'l)</pr>, <pos>n.</pos> <ety>[OE.
<ets>ridil</ets>, AS. <ets>hridder</ets>; akin to G. <ets>reiter</ets>,
L. <ets>cribrum</ets>, and to Gr. <grk>kri`nein</grk> to distinguish,
separate, and G. <ets>rein</ets> clean. See <er>Crisis</er>,
<er>Certain</er>.]</ety> <sn>1.</sn> <def>A sieve with coarse meshes,
usually of wire, for separating coarser materials from finer, as chaff
from grain, cinders from ashes, or gravel from sand.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A board having a row of pins, set zigzag, between
which wire is drawn to straighten it.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Riddle</ent><br/
<hw>Rid"dle</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Riddled</conjf> <pr>(r<icr/d"d'ld)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Riddling</conjf> <pr>(r<icr/d"dl<icr/ng)</pr>.]</vmorph>
<sn>1.</sn> <def>To separate, as grain from the chaff, with a riddle; to
pass through a riddle; <as>as, <ex>riddle</ex> wheat; to <ex>riddle</ex>
coal or gravel</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To perforate so as to make like a riddle; to make
many holes in; <as>as, a house <ex>riddled</ex> with
shot</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Riddle</ent><br/
<hw>Rid"dle</hw>, <pos>n.</pos> <ety>[For <ets>riddels</ets>, <it>s</it>
being misunderstood as the plural ending; OE. <ets>ridels</ets>,
<ets>redels</ets>. AS. r<aemac/dels; akin to D. <ets>raadsel</ets>, G.
<ets>r<aum/thsel</ets>; fr. AS. <ets>r<aemac/dan</ets> to counsel or
advise, also, to guess. <root/116. Cf. <er>Read</er>.]</ety>
<def>Something proposed to be solved by guessing or conjecture; a
puzzling question; an ambiguous proposition; an enigma; hence, anything
ambiguous or puzzling.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To wring from me, and tell to them, my secret,<br/
That solved the <qex>riddle</qex> which I had proposed.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>'T was a strange <qex>riddle</qex> of a lady.</q>
<rj><qau>Hudibras.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Riddle</ent><br/
<hw>Rid"dle</hw>, <pos>v. t.</pos> <def>To explain; to solve; to
unriddle.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Riddle</qex> me this, and guess him if you can.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Riddle</ent><br/
<hw>Rid"dle</hw>, <pos>v. i.</pos> <def>To speak ambiguously or
enigmatically.</def> <ldquo/<persfn>Lysander</persfn> <xex>riddles</xex>
very prettily.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Riddler</ent><br/
<hw>Rid"dler</hw> <pr>(r<icr/d"dl<icr/)</pr>, <pos>n.</pos> <def>One who
riddles (grain, sand, etc.).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Riddler</ent><br/
<hw>Rid"dler</hw>, <pos>n.</pos> <def>One who speaks in, or propounds,
riddles.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>The Riddler</b></col> <mark>[Capitalized]</mark> <cd>A
fictional character in the Batman comic books series and also in the
Batman series of movies. He was an enemy of Batman who proposed
riddles.</cd></cs><br/
[<source>PJC</source>]</p>

<p><ent>Riddling</ent><br/
<hw>Rid"dling</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Speaking in a riddle
or riddles; containing a riddle.</def> <ldquo/<xex>Riddling</xex>
triplets.<rdquo/ <au>Tennyson.</au> -- <wordforms><wf>Rid"dling</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ride</ent><br/
<hw>Ride</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp.</pos>
<conjf>Rode</conjf> <pr>(r<omac/d)</pr> (<conjf>Rid</conjf> [r<icr/d],
<mark>archaic</mark>); <pos>p. p.</pos> <conjf>Ridden</conjf>
<pr>(<?/)</pr> (<conjf>Rid</conjf>, <mark>archaic</mark>); <pos>p. pr. &
vb. n.</pos> <conjf>Riding</conjf> <pr>(<?/)</pr>.]</vmorph> <ety>[AS.
<ets>r<imac/dan</ets>; akin to LG. <ets>riden</ets>, D.
<ets>rijden</ets>, G. <ets>reiten</ets>, OHG. <ets>r<imac/tan</ets>,
Icel. <ets>r<imac/<edh/a</ets>, Sw. <ets>rida</ets>, Dan.
<ets>ride</ets>; cf. L. <ets>raeda</ets> a carriage, which is from a
Celtic word. Cf. <er>Road</er>.]</ety> <sn>1.</sn> <def>To be carried on
the back of an animal, as a horse.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To-morrow, when ye <qex>riden</qex> by the way.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Let your master <qex>ride</qex> on before, and do you gallop after
him.</q> <rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To be borne in a carriage; <as>as, to <ex>ride</ex>
in a coach, in a car, and the like</as>. See Synonym, below.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The richest inhabitants exhibited their wealth, not by
<qex>riding</qex> in gilden carriages, but by walking the streets with
trains of servants.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To be borne or in a fluid; to float; to
lie.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Men once walked where ships at anchor <qex>ride</qex>.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To be supported in motion; to rest.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Strong as the exletree<br/
On which heaven <qex>rides</qex>.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>On whose foolish honesty<br/
My practices <qex>ride</qex> easy!</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To manage a horse, as an equestrian.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He <qex>rode</qex>, he fenced, he moved with graceful ease.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To support a rider, as a horse; to move under the
saddle; <as>as, a horse <ex>rides</ex> easy or hard, slow or
fast</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To ride easy</b></col> <fld>(Naut.)</fld>, <cd>to lie at
anchor without violent pitching or straining at the cables.</cd> --
<col><b>To ride hard</b></col> <fld>(Naut.)</fld>, <cd>to pitch
violently.</cd> -- <col><b>To ride out</b></col>. <sd>(a)</sd> <cd>To go
upon a military expedition.</cd> <mark>[Obs.]</mark> <au>Chaucer.</au>
<sd>(b)</sd> <cd>To ride in the open air.</cd> <mark>[Colloq.]</mark> --
<col><b>To ride to hounds</b></col>, <cd>to ride behind, and near to,
the hounds in hunting.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Drive.</syn> <usage> -- <er>Ride</er>,
<er>Drive</er>. <xex>Ride</xex> originally meant (and is so used
throughout the English Bible) to be carried on horseback or in a vehicle
of any kind. At present in England, <xex>drive</xex> is the word applied
in most cases to progress in a carriage; as, a <xex>drive</xex> around
the park, etc.; while <xex>ride</xex> is appropriated to progress on a
horse. Johnson seems to sanction this distinction by giving <ldquo/to
<xex>travel</xex> on horseback<rdquo/ as the leading sense of
<xex>ride</xex>; though he adds <ldquo/to <xex>travel</xex> in a
vehicle<rdquo/ as a secondary sense. This latter use of the word still
occurs to some extent; as, the queen <xex>rides</xex> to Parliament in
her coach of state; to <xex>ride</xex> in an omnibus.</usage><br/
[<source>1913 Webster</source>]</p>

<p><q><ldquo/Will you <qex>ride</qex> over or <qex>drive</qex>?<rdquo/
said Lord Willowby to his quest, after breakfast that morning.</q>
<rj><qau>W. Black.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ride</ent><br/
<hw>Ride</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To sit on, so as to be
carried; <as>as, to <ex>ride</ex> a horse; to <ex>ride</ex> a
bicycle.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>[They] rend up both rocks and hills, and <qex>ride</qex> the
air<br/
In whirlwind.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To manage insolently at will; to domineer
over.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The nobility could no longer endure to be <qex>ridden</qex> by
bakers, cobblers, and brewers.</q> <rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To convey, as by riding; to make or do by
riding.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Tue only men that safe can <qex>ride</qex><br/
Mine errands on the Scottish side.</q> <rj><qau>Sir W.
Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Surg.)</fld> <def>To overlap (each other); -- said
of bones or fractured fragments.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To ride a hobby</b></col>, <cd>to have some favorite
occupation or subject of talk.</cd> -- <col><b>To ride and
tie</b></col>, <cd>to take turn with another in labor and rest; -- from
the expedient adopted by two persons with one horse, one of whom
<xex>rides</xex> the animal a certain distance, and then <xex>ties</xex>
him for the use of the other, who is coming up on foot.</cd>
<au>Fielding.</au> -- <col><b>To ride down</b></col>. <sd>(a)</sd>
<cd>To ride over; to trample down in riding; to overthrow by riding
against; <as>as, <ex>to ride down</ex> an enemy</as></cd>. <sd>(b)</sd>
<fld>(Naut.)</fld> <cd>To bear down, as on a halyard when hoisting a
sail.</cd> -- <col><b>To ride out</b></col> <fld>(Naut.)</fld>, <cd>to
keep safe afloat during (a storm) while riding at anchor or when hove to
on the open sea; <as>as, <ex>to ride out</ex> the gale</as>.</cd></cs>
<-- <col><b>to ride the lightning</b></col>, (Colloq.) <cd>to be
executed by electrocution in an electric chair.</cd> --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ride</ent><br/
<hw>Ride</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act of riding; an
excursion on horseback or in a vehicle.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A saddle horse.</def> <mark>[Prov. Eng.]</mark>
<rj><au>Wright.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A road or avenue cut in a wood, or through grounds,
to be used as a place for riding; a riding.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rideau</ent><br/
<hw>Ri*deau"</hw> <pr>(r<esl/*d<omac/")</pr>, <pos>n.</pos>
<ety>[F.]</ety> <def>A small mound of earth; ground slightly elevated; a
small ridge.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Riden</ent><br/
<hw>Rid"en</hw> <pr>(r<imac/d"'n)</pr>, <mark>obs.</mark> <def><pos>imp.
pl. & p. p.</pos> of <er>Ride</er>.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rident</ent><br/
<hw>Ri"dent</hw> <pr>(r<imac/"d<eit/nt)</pr>, <pos>a.</pos> <ety>[L.
<ets>ridens</ets>, p. pr. of <ets>ridere</ets> to laugh.]</ety>
<def>Laughing.</def> <mark>[R.]</mark> <rj><au>Thackeray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rider</ent><br/
<hw>Rid"er</hw> <pr>(r<imac/d"<etil/r)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>One who, or that which, rides.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Formerly, an agent who went out with samples of
goods to obtain orders; a commercial traveler.</def>
<mark>[Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>One who breaks or manages a horse.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>An addition or amendment to a manuscript or other
document, which is attached on a separate piece of paper; in legislative
practice, an additional clause annexed to a bill while in course of
passage; something extra or burdensome that is imposed.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>After the third reading, a foolish man stood up to propose a
<qex>rider</qex>.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>This [question] was a <qex>rider</qex> which Mab found difficult
to answer.</q> <rj><qau>A. S. Hardy.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Math.)</fld> <def>A problem of more than usual
difficulty added to another on an examination paper.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <ety>[D. <ets>rijder</ets>.]</ety> <def>A Dutch gold coin
having the figure of a man on horseback stamped upon it.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His moldy money ! half a dozen <qex>riders</qex>.</q> <rj><qau>J.
Fletcher.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Mining)</fld> <def>Rock material in a vein of ore,
dividing it.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <fld>(Shipbuilding)</fld> <def>An interior rib
occasionally fixed in a ship's hold, reaching from the keelson to the
beams of the lower deck, to strengthen her frame.</def>
<rj><au>Totten.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <fld>(Naut.)</fld> <def>The second tier of casks in a
vessel's hold.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <def>A small forked weight which straddles the beam of a
balance, along which it can be moved in the manner of the weight on a
steelyard.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>11.</sn> <def>A robber.</def> <mark>[Obs. or Prov. Eng.]</mark>
<rj><au>Drummond.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Rider's bone</b></col> <fld>(Med.)</fld>, <cd>a bony
deposit in the muscles of the upper and inner part of the thigh, due to
the pressure and irritation caused by the saddle in
riding.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Riderless</ent><br/
<hw>Rid"er*less</hw>, <pos>a.</pos> <def>Having no rider; <as>as, a
<ex>riderless</ex> horse</as>.</def> <rj><au>H. Kingsley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>ride the lightning</ent><br/
<hw>ride the lightning</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>to be
executed by electrocution in the <uses>electric chair</uses>.</def>
<mark>[jocose slang]</mark> <br/
[<source>PJC</source>]</p>

<p><ent>Ridge</ent><br/
<hw>Ridge</hw> <pr>(r<icr/j)</pr>, <pos>n.</pos> <ety>[OE.
<ets>rigge</ets> the back, AS. <ets>hrycg</ets>; akin to D.
<ets>rug</ets>, G. <ets>r<uum/cken</ets>, OHG. <ets>rucki</ets>,
<ets>hrukki</ets>, Icel. <ets>hryggr</ets>, Sw. <ets>rugg</ets>, Dan.
<ets>ryg</ets>. <root/16.]</ety> <sn>1.</sn> <def>The back, or top of
the back; a crest.</def> <rj><au>Hudibras.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A range of hills or mountains, or the upper part of
such a range; any extended elevation between valleys.</def> <ldquo/The
frozen <xex>ridges</xex> of the Alps.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Part rise in crystal wall, or <qex>ridge</qex> direct.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A raised line or strip, as of ground thrown up by a
plow or left between furrows or ditches, or as on the surface of metal,
cloth, or bone, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Arch.)</fld> <def>The intersection of two surface
forming a salient angle, especially the angle at the top between the
opposite slopes or sides of a roof or a vault.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Fort.)</fld> <def>The highest portion of the glacis
proceeding from the salient angle of the covered way.</def>
<rj><au>Stocqueler.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ridge</ent><br/
<hw>Ridge</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Ridged</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Ridging</conjf>.]</vmorph> <sn>1.</sn> <def>To form a ridge of;
to furnish with a ridge or ridges; to make into a ridge or
ridges.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Bristles ranged like those that <qex>ridge</qex> the back<br/
Of chafed wild boars.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To form into ridges with the plow, as
land.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To wrinkle.</def> <ldquo/With a forehead
<xex>ridged</xex>.<rdquo/ <rj><au>Cowper.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ridgeband</ent><br/
<hw>Ridge"band`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The part of a
harness which passes over the saddle, and supports the shafts of a cart;
-- called also <altname>ridgerope</altname>, and
<altname>ridger</altname>.</def> <rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ridgebone</ent><br/
<hw>Ridge"bone`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The
backbone.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Blood . . . lying cluttered about the <qex>ridgebone</qex>.</q>
<rj><qau>Holland.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ridgel</ent><br/
<hw>Ridg"el</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>Same as <er>Ridgelling</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ridgelet</ent><br/
<hw>Ridge"let</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A little
ridge.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ridgeling</ent><br/
<hw>Ridge"ling</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Prov. E.
<ets>riggilt</ets>, <ets>riggot</ets>, ananimal half castrated, a sheep
having only one testicle; cf. Prov. G. <ets>rigel</ets>, <ets>rig</ets>,
a barrow hog, <ets>rigler</ets> a cock half castrated.]</ety>
<fld>(Zool.)</fld> <def>A half-castrated male animal.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ridgeplate</ent><br/
<ent>Ridgepiece</ent><br/
<mhw>{ <hw>Ridge"piece`</hw> <pr>(?)</pr>, <hw>Ridge"plate`</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <def>See
<er>Ridgepole</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ridgepole</ent><br/
<hw>Ridge"pole`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Arch.)</fld>
<def>The timber forming the ridge of a roof, into which the rafters are
secured.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ridgerope</ent><br/
<hw>Ridge"rope`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Naut.)</fld>
<def>See <cref>Life line</cref> <sd>(a)</sd>, under
<er>Life</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ridgingly</ent><br/
<hw>Ridg"ing*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>So as to form
ridges.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ridgy</ent><br/
<hw>Ridg"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having a ridge or
ridges; rising in a ridge.</def> <ldquo/Lifted on a <xex>ridgy</xex>
wave.<rdquo/ <rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ridicle</ent><br/
<hw>Rid"i*cle</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Ridicule.</def>
<mark>[Obs.]</mark> <rj><au>Foxe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ridicule</ent><br/
<hw>Rid"i*cule</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>ridicule</ets>, L. <ets>ridiculum</ets> a jest, fr.
<ets>ridiculus</ets>. See <er>Ridiculous</er>.]</ety> <sn>1.</sn>
<def>An object of sport or laughter; a laughingstock; a laughing
matter.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>[Marlborough] was so miserably ignorant, that his deficiencies
made him the <qex>ridicule</qex> of his contemporaries.</q>
<rj><qau>Buckle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To the people . . . but a trifle, to the king but a
<qex>ridicule</qex>.</q> <rj><qau>Foxe.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Remarks concerning a subject or a person designed to
excite laughter with a degree of contempt; wit of that species which
provokes contemptuous laughter; disparagement by making a person an
object of laughter; banter; -- a term lighter than
<xex>derision</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We have in great measure restricted the meaning of
<qex>ridicule</qex>, which would properly extend over whole region of
the ridiculous, -- the laughable, -- and we have narrowed it so that in
common usage it mostly corresponds to <ldquo/derision<rdquo/, which does
indeed involve personal and offensive feelings.</q>
<rj><qau>Hare.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Safe from the bar, the pulpit, and the throne,<br/
Yet touched and shamed by <qex>ridicule</qex> alone.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Quality of being ridiculous; ridiculousness.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>To see the <qex>ridicule</qex> of this practice.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Derision; banter; raillery; burlesque; mockery;
irony; satire; sarcasm; gibe; jeer; sneer; ribbing.</syn> <usage> --
<er>Ridicule</er>, <er>Derision</er>, <er>mockery</er>,
<er>ribbing</er>: All four words imply disapprobation; but
<xex>ridicule</xex> and <xex>mockery</xex> may signify either
good-natured opposition without manifest malice, or more maliciously, an
attempt to humiliate. <xex>Derision</xex> is commonly bitter and
scornful, and sometimes malignant. <er>ribbing</er> is almost always
good-natured and fun-loving.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ridicule</ent><br/
<hw>Rid"i*cule</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Ridiculed</conjf> <pr>(?)</pr>;<pos>p. pr. & vb. n.</pos>
<conjf>Ridiculing</conjf>.]</vmorph> <def>To laugh at mockingly or
disparagingly; to awaken ridicule toward or respecting.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I 've known the young, who <qex>ridiculed</qex> his rage.</q>
<rj><qau>Goldsmith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To deride; banter; rally; burlesque; mock;
satirize; lampoon. See <er>Deride</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1241 --></p>

<p><ent>Ridicule</ent><br/
<hw>Rid"i*cule</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F.]</ety>
<def>Ridiculous.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>This action . . . became so <qex>ridicule</qex>.</q>
<rj><qau>Aubrey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ridiculer</ent><br/
<hw>Rid"i*cu`ler</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
ridicules.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ridiculize</ent><br/
<hw>Ri*dic"u*lize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To make
ridiculous; to ridicule.</def> <mark>[Obs.]</mark>
<rj><au>Chapman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ridiculosity</ent><br/
<hw>Ri*dic`u*los"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The quality
or state of being ridiculous; ridiculousness; also, something
ridiculous.</def> <mark>[Archaic]</mark> <rj><au>Bailey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ridiculous</ent><br/
<hw>Ri*dic"u*lous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>ridiculosus</ets>, <ets>ridiculus</ets>, fr. <ets>ridere</ets> to
laigh. Cf. <er>Risible</er>.]</ety> <sn>1.</sn> <def>Fitted to excite
ridicule; absurd and laughable; unworthy of serious consideration;
<as>as, a <ex>ridiculous</ex> dress or behavior</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Agricola, discerning that those little targets and unwieldy
glaives ill pointed would soon become <qex>ridiculous</qex> against the
thrust and close, commanded three Batavian cohorts . . . to draw up and
come to handy strokes.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Involving or expressing ridicule.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>[It] provokes me to <qex>ridiculous</qex> smiling.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Ludicrous; laughable; risible; droll; comical;
absurd; preposterous. See <er>Ludicrous</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p>--- <wordforms><wf>Ri*dic"u*lous*ly</wf>, <pos>adv.</pos> --
<wf>Ri*dic"u*lous*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Riding</ent><br/
<hw>Rid"ing</hw> <pr>(r<imac/d"<icr/ng)</pr>, <pos>n.</pos> <ety>[For
<ets>thriding</ets>, Icel. <ets><thorn/ri<edh/jungr</ets> the third
part, fr. <ets><thorn/ri<edh/i</ets> third, akin to E. <ets>third</ets>.
See <er>Third</er>.]</ety> <def>One of the three jurisdictions into
which the county of York, in England, is divided; -- formerly under the
government of a reeve. They are called the <xex>North</xex>, the
<xex>East</xex>, and the <xex>West</xex>, <xex>Riding</xex>.</def>
<rj><au>Blackstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Riding</ent><br/
<hw>Rid"ing</hw>, <pos>a.</pos> <sn>1.</sn> <def>Employed to travel;
traveling; <as>as, a <ex>riding</ex> clerk</as>.</def> <ldquo/One
<xex>riding</xex> apparitor.<rdquo/ <rj><au>Ayliffe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Used for riding on; <as>as, a <ex>riding</ex>
horse</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Used for riding, or when riding; devoted to riding;
<as>as, a <ex>riding</ex> whip; a <ex>riding</ex> habit; a
<ex>riding</ex> day.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Riding clerk</b></col>. <sd>(a)</sd> <cd>A clerk who
traveled for a commercial house</cd>. <mark>[Obs. Eng.]</mark>
<sd>(b)</sd> <cd>One of the <ldquo/six clerks<rdquo/ formerly attached
to the English Court of Chancery.</cd> -- <col><b>Riding hood</b></col>.
<sd>(a)</sd> <cd>A hood formerly worn by women when riding</cd>.
<sd>(b)</sd> <cd>A kind of cloak with a hood.</cd> -- <col><b>Riding
master</b></col>, <cd>an instructor in horsemanship.</cd> --
<col><b>Riding rhyme</b></col> <fld>(Pros.)</fld>, <cd>the meter of five
accents, with couplet rhyme; -- probably so called from the mounted
pilgrims described in the Canterbury Tales.</cd> <au>Dr. Guest.</au> --
<col><b>Riding school</b></col>, <cd>a school or place where the art of
riding is taught.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Riding</ent><br/
<hw>Rid"ing</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act or state of one
who rides.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A festival procession.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>When there any <qex>riding</qex> was in Cheap.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Same as <er>Ride</er>, <pos>n.</pos>, 3.</def>
<rj><au>Sir P. Sidney.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A district in charge of an excise officer.</def>
<mark>[Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ridotto</ent><br/
\'d8<hw>Ri*dot"to</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[It., fr. LL.
<ets>reductus</ets> a retreat. See <er>Redoubt</er>.]</ety> <sn>1.</sn>
<def>A favorite Italian public entertainment, consisting of music and
dancing, -- held generally on fast eves.</def> <rj><au>Brande &
C.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>There are to be <qex>ridottos</qex> at guinea tickets.</q>
<rj><qau>Walpole.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Music)</fld> <def>An arrangement or abridgment of a
piece from the full score.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Ridotto</ent><br/
<hw>Ri*dot"to</hw>, <pos>v. i.</pos> <def>To hold ridottos.</def>
<mark>[R.]</mark> <rj><au>J. G. Cooper.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rie</ent><br/
<hw>Rie</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See <er>Rye</er>.</def>
<mark>[Obs.]</mark> <rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Rie grass</b></col>. <fld>(Bot.)</fld> <sd>(a)</sd> <cd>A
kind of wild barley (<spn>Hordeum pratense</spn>)</cd>. <au>Dr.
Prior.</au> <sd>(b)</sd> <cd>Ray grass.</cd> <au>Dr.
Prior.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rief</ent><br/
<hw>Rief</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Reave</er>.]</ety> <def>Robbery.</def> <mark>[Obs. or
Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rietboc</ent><br/
<hw>Riet"boc</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[D. <ets>riet</ets>
reed + <ets>bok</ets> buck.]</ety> <fld>(Zool.)</fld> <def>The reedbuck,
a South African antelope (<spn>Cervicapra arundinacea</spn>); -- so
called from its frequenting dry places covered with high grass or reeds.
Its color is yellowish brown. Called also <altname>inghalla</altname>,
and <altname>rietbok</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rifacimento</ent><br/
\'d8<hw>Ri*fa`ci*men"to</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu>pl.
<plw>Rifacimenti</plw> <pr>(#)</pr></plu>. <ety>[It.]</ety> <def>A
remaking or recasting; an adaptation, esp. of a literary work or musical
composition.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Rife</ent><br/
<hw>Rife</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[AS. <ets>r<imac/f</ets>
abundant, or Icel. <ets>r<imac/fr</ets> munificent; akin to OD.
<ets>riff</ets>, <ets>rijve</ets>, abundant.]</ety> <sn>1.</sn>
<def>Prevailing; prevalent; abounding.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Before the plague of London, inflammations of the lungs were
<qex>rife</qex> and mortal.</q> <rj><qau>Arbuthnot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Even now the tumult of loud mirth<br/
Was <qex>rife</qex>, and perfect in may listening ear.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Having power; active; nimble.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>What! I am <qex>rife</qex> a little yet.</q> <rj><qau>J.
Webster.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Rife"ly</wf>, <pos>adv.</pos> --
<wf>Rife"ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Riffle</ent><br/
<hw>Rif"fle</hw> <pr>(r<icr/f"f'l)</pr>, <pos>n.</pos> <ety>[CF. G.
<ets>riffeln</ets>, <ets>riefeln</ets>, to groove. Cf. <er>Rifle</er> a
gun.]</ety> <sn>1.</sn> <fld>(Mining)</fld> <def>A trough or sluice
having cleats, grooves, or steps across the bottom for holding
quicksilver and catching particles of gold when auriferous earth is
washed; also, one of the cleats, grooves, or steps in such a trough.
Also called <xex>ripple</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A ripple in a stream or current of water; also, a
place where the water ripples, as on a shallow rapid.</def>
<mark>[Local, U. S.]</mark></p>

<p><q>The bass have left the cool depth beside the rock and are on the
<qex>riffle</qex> or just below it.</q> <rj><qau>James A.
Henshall.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Riffler</ent><br/
<hw>Rif"fler</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Riffle</er>.]</ety> <def>A curved file used in carving wool and
marble.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Riffraff</ent><br/
<hw>Riff"raff`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>rif and
raf</ets> every particle, OF. <ets>rif et raf</ets>. CF. <er>Raff</er>,
<ets>and 1st</ets> <er>Rifle</er>.]</ety> <def>Sweepings; refuse; the
lowest order of society.</def> <rj><au>Beau. & Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rifle</ent><br/
<hw>Ri"fle</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Rifled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Rifling</conjf> <pr>(?)</pr>.]</vmorph> <ety>[F.
<ets>rifler</ets> to rifle, sweep away; of uncertain origin. CF.
<er>Raff</er>.]</ety> <sn>1.</sn> <def>To seize and bear away by force;
to snatch away; to carry off.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Till time shall <qex>rifle</qex> every youthful grace.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To strip; to rob; to pillage.</def> <rj><au>Piers
Plowman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Stand, sir, and throw us that you have about ye:<br/
If not, we'll make you sit and <qex>rifle</qex> you.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To raffle.</def> <mark>[Obs.]</mark> <rj><au>J.
Webster.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rifle</ent><br/
<hw>Ri"fle</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To raffle.</def>
<mark>[Obs.]</mark> <rj><au>Chapman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To commit robbery.</def> <mark>[R.]</mark>
<rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rifle</ent><br/
<hw>Ri"fle</hw>, <pos>n.</pos> <ety>[Akin to Dan. <ets>rifle</ets>, or
<ets>riffel</ets>, the rifle of a gun, a chamfer (cf. <ets>riffel</ets>,
<ets>riffel</ets>b<oum/sse, a rifle gun, <ets>rifle</ets> to rifle a
gun, G. <ets>riefeln</ets>, <ets>riefen</ets>, to chamfer, groove), and
E. <ets>rive</ets>. See <er>Rive</er>, and cf. <er>Riffle</er>,
<er>Rivel</er>.]</ety> <sn>1.</sn> <def>A gun, the inside of whose
barrel is grooved with spiral channels, thus giving the ball a rotary
motion and insuring greater accuracy of fire. As a military firearm it
has superseded the musket.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <pluf>pl.</pluf> <fld>(Mil.)</fld> <def>A body of
soldiers armed with rifles.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A strip of wood covered with emery or a similar
material, used for sharpening scythes.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Rifle pit</b></col> <fld>(Mil.)</fld>, <cd>a trench for
sheltering sharpshooters.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rifle</ent><br/
<hw>Ri"fle</hw> <pr>(?)</pr>, <pos>v. t.</pos> <sn>1.</sn> <def>To
grove; to channel; especially, to groove internally with spiral
channels; <as>as, to <ex>rifle</ex> a gun barrel or a
cannon</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To whet with a rifle. See <er>Rifle</er>,
<pos>n.</pos>, 3.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Riflebird</ent><br/
<hw>Ri"fle*bird`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>Any one of several species of beautiful birds of Australia and New
Guinea, of the genera <gen>Ptiloris</gen> and <gen>Craspidophora</gen>,
allied to the paradise birds.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The largest and best known species is <spn>Ptiloris
paradisea</spn> of Australia. Its general color is rich velvety brown,
glossed with lilac; the under parts are varied with rich olive green,
and the head, throat, and two middle tail feathers are brilliant
metallic green.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rifleman</ent><br/
<hw>Ri"fle*man</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Rifleman</plw> <pr>(<?/)</pr>.</plu> <fld>(Mil.)</fld> <def>A
soldier armed with a rifle.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rifler</ent><br/
<hw>Ri"fler</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who rifles; a
robber.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rifling</ent><br/
<hw>Ri"fling</hw> <pr>(?)</pr>, <pos>n.</pos> <sd>(a)</sd> <def>The act
or process of making the grooves in a rifled cannon or gun barrel.</def>
<sd>(b)</sd> <def>The system of grooves in a rifled gun barrel or
cannon.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Shunt rifling</b></col>, <cd>rifling for cannon, in which
one side of the groove is made deeper than the other, to facilitate
loading with shot having projections which enter by the deeper part of
the grooves.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rift</ent><br/
<hw>Rift</hw> <pr>(?)</pr>, <mark>obs.</mark> <def><pos>p. p.</pos> of
<er>Rive</er>.</def> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rift</ent><br/
<hw>Rift</hw>, <pos>n.</pos> <altsp>[Written also
<asp>reft</asp>.]</altsp> <ety>[Dan. <ets>rift</ets>, fr.
<ets>rieve</ets> to rend. See <er>Rive</er>.]</ety> <sn>1.</sn> <def>An
opening made by riving or splitting; a cleft; a fissure.</def>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A shallow place in a stream; a ford.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rift</ent><br/
<hw>Rift</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Rifted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Rifting</conjf>.]</vmorph> <def>To cleave; to rive; to split;
<as>as, to <ex>rift</ex> an oak or a rock; to <ex>rift</ex> the
clouds.</as></def> <rj><au>Longfellow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To dwell these <qex>rifted</qex> rocks between.</q>
<rj><qau>Wordsworth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rift</ent><br/
<hw>Rift</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To burst open; to
split.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Timber . . . not apt to <qex>rif</qex> with ordnance.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To belch.</def> <mark>[Prov. Eng. &
Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rifter</ent><br/
<hw>Rift"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A rafter.</def>
<mark>[Obs.]</mark> <rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rig</ent><br/
<hw>Rig</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Ridge</er>.]</ety> <def>A ridge.</def> <mark>[Prov. or
Scott.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rig</ent><br/
<hw>Rig</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Rigged</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Rigging</conjf> <pr>(?)</pr>.]</vmorph> <ety>[Norweg.
<ets>rigga</ets> to bind, particularly, to wrap round, rig; cf. AS.
<ets>wr<imac/han</ets> to cover.]</ety> <sn>1.</sn> <def>To furnish with
apparatus or gear; to fit with tackling.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To dress; to equip; to clothe, especially in an odd
or fanciful manner; -- commonly followed by <xex>out</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Jack was <qex>rigged</qex> out in his gold and silver lace.</q>
<rj><qau>L'Estrange.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To rig a purchase</b></col>, <cd>to adapt apparatus so as
to get a purchase for moving a weight, as with a lever, tackle, capstan,
etc.</cd> -- <col><b>To rig a ship</b></col> <fld>(Naut.)</fld>, <cd>to
fit the shrouds, stays, braces, etc., to their respective masts and
yards.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rig</ent><br/
<hw>Rig</hw>, <pos>n.</pos> <sn>1.</sn> <fld>(Naut.)</fld> <def>The
peculiar fitting in shape, number, and arrangement of sails and masts,
by which different types of vessels are distinguished; <as>as, schooner
<ex>rig</ex>, ship <ex>rig</ex>, etc.</as> See <xex>Illustration</xex>
in Appendix.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Dress; esp., odd or fanciful clothing.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rig</ent><br/
<hw>Rig</hw>, <pos>n.</pos> <ety>[Cf. <er>Wriggle</er>.]</ety>
<sn>1.</sn> <def>A romp; a wanton; one given to unbecoming
conduct.</def> <mark>[Obs.]</mark> <rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A sportive or unbecoming trick; a frolic.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A blast of wind.</def> <mark>[Prov. Eng.]</mark>
<rj><au>Wright.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>That uncertain season before the <qex>rigs</qex> of Michaelmas
were yet well composed.</q> <rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To run a rig</b></col>, <cd>to play a trick; to engage in
a frolic; to do something strange and unbecoming.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><q>He little dreamt when he set out<br/
Of <qex>running</qex> such <qex>a rig</qex>.</q>
<rj><qau>Cowper.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rig</ent><br/
<hw>Rig</hw>, <pos>v. i.</pos> <def>To play the wanton; to act in an
unbecoming manner; to play tricks.</def> <ldquo/<xex>Rigging</xex> and
rifling all ways.<rdquo/ <rj><au>Chapman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rig</ent><br/
<hw>Rig</hw>, <pos>v. t.</pos> <def>To make free with; hence, to steal;
to pilfer.</def> <mark>[Obs. or Prov.]</mark>
<rj><au>Tusser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To rig the market</b></col> <fld>(Stock Exchange)</fld>,
<cd>to raise or lower market prices, as by some fraud or trick.</cd>
<mark>[Cant]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rigadoon</ent><br/
<hw>Rig`a*doon"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>rigadon</ets>, <ets>rigaudon</ets>.]</ety> <def>A gay, lively dance
for one couple, -- said to have been borrowed from Provence in
France.</def> <rj><au>W. Irving.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Whose dancing dogs in <qex>rigadoons</qex> excel.</q>
<rj><qau>Wolcott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Riga fir</ent><br/
<hw>Ri"ga fir`</hw> <pr>(?)</pr>, <ety>[So called from <ets>Riga</ets>,
a city in Russia.]</ety> <fld>(Bot.)</fld> <def>A species of pine
(<spn>Pinus sylvestris</spn>), and its wood, which affords a valuable
timber; -- called also <altname>Scotch pine</altname>, and <altname>red
deal</altname> <it>or</it> <altname>yellow deal</altname>. It grows in
all parts of Europe, in the Caucasus, and in Siberia.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rigarion</ent><br/
<hw>Ri*ga"rion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>rigatio</ets>, fr. <ets>rigare</ets> to water.]</ety> <def>See
<er>Irrigation</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rigel</ent><br/
<hw>Ri"gel</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Ar. <ets>rijl</ets>,
properly, foot.]</ety> <fld>(Astron.)</fld> <def>A fixed star of the
first magnitude in the left foot of the constellation Orion.</def>
<altsp>[Written also <asp>Regel</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rigescent</ent><br/
<hw>Ri*ges"cent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>rigescens</ets>, p. pr. fr. <ets>rigescere</ets> to grow
stiff.]</ety> <def>Growing stiff or numb.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rigger</ent><br/
<hw>Rig"ger</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who
rigs or dresses; one whose occupation is to fit the rigging of a
ship.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A cylindrical pulley or drum in machinery.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Painting)</fld> <def>A long slender, and pointed
sable brush for making fine lines, etc.; -- said to be so called from
its use by marine painters for drawing the lines of the
rigging.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Rigging</ent><br/
<hw>Rig"ging</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Dress; tackle;
especially <fld>(Naut.)</fld>, the ropes, chains, etc., that support the
masts and spars of a vessel, and serve as purchases for adjusting the
sails, etc. See <xex>Illustr</xex>. of <er>Ship</er> and
<er>Sails</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Running rigging</b></col> <fld>(Naut.)</fld>, <cd>all
those ropes used in bracing the yards, making and shortening sail, etc.,
such as braces, sheets, halyards, clew lines, and the like.</cd> --
<col><b>Standing rigging</b></col> <fld>(Naut.)</fld>, <cd>the shrouds
and stays.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Riggish</ent><br/
<hw>Rig"gish</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Like a rig or
wanton.</def> <mark>[Obs.]</mark> <ldquo/<xex>Riggish</xex> and
unmaidenly.<rdquo/ <rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Riggle</ent><br/
<hw>Rig"gle</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>See
<er>Wriggle</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Riggle</ent><br/
<hw>Rig"gle</hw>, <pos>n.</pos> <def>The European lance fish.</def>
<mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Right</ent><br/
<hw>Right</hw> <pr>(r<imac/t)</pr>, <pos>a.</pos> <ety>[OE.
<ets>right</ets>, <ets>riht</ets>, AS. <ets>riht</ets>; akin to D.
<ets>regt</ets>, OS. & OHG. <ets>reht</ets>, G. <ets>recht</ets>, Dan.
<ets>ret</ets>, Sw. r<aum/tt, Icel. <ets>rettr</ets>, Goth.
<ets>ra<iacute/hts</ets>, L. <ets>rectus</ets>, p. p. of
<ets>regere</ets> to guide, rule; cf. Skr. <ets><rsdot/ju</ets>
straight, right. <root/115. Cf. <er>Adroit</er>,<er>Alert</er>,
<er>Correct</er>, <er>Dress</er>, <er>Regular</er>, <er>Rector</er>,
<er>Recto</er>, <er>Rectum</er>, <er>Regent</er>, <er>Region</er>,
<er>Realm</er>, <er>Rich</er>, <er>Royal</er>, <er>Rule</er>.]</ety>
<sn>1.</sn> <def>Straight; direct; not crooked; <as>as, a <ex>right</ex>
line</as>.</def> <ldquo/<xex>Right</xex> as any line.<rdquo/
<rj><au>Chaucer</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Upright; erect from a base; having an upright axis;
not oblique; <as>as, <ex>right</ex> ascension; a <ex>right</ex> pyramid
or cone.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Conformed to the constitution of man and the will of
God, or to justice and equity; not deviating from the true and just;
according with truth and duty; just; true.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That which is conformable to the Supreme Rule is absolutely
<qex>right</qex>, and is called <qex>right</qex> simply without relation
to a special end.</q> <rj><qau>Whately.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Fit; suitable; proper; correct; becoming; <as>as,
the <ex>right</ex> man in the <ex>right</ex> place; the <ex>right</ex>
way from London to Oxford.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Characterized by reality or genuineness; real;
actual; not spurious.</def> <ldquo/His <xex>right</xex> wife.<rdquo/
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>In this battle, . . . the Britons never more plainly manifested
themselves to be <qex>right</qex> barbarians.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>According with truth; passing a true judgment;
conforming to fact or intent; not mistaken or wrong; not erroneous;
correct; <as>as, this is the <ex>right</ex> faith</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>You are <qex>right</qex>, Justice, and you weigh this well.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>If there be no prospect beyond the grave, the inference is . . .
<qex>right</qex>, <ldquo/Let us eat and drink, for to-morrow we
die.<rdquo/</q> <rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>Most favorable or convenient; fortunate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The lady has been disappointed on the <qex>right</qex> side.</q>
<rj><qau>Spectator.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>Of or pertaining to that side of the body in man on
which the muscular action is usually stronger than on the other side; --
opposed to <xex>left</xex> when used in reference to a part of the body;
<as>as, the <ex>right</ex> side, hand, arm</as>. Also applied to the
corresponding side of the lower animals.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Became the sovereign's favorite, his <qex>right</qex> hand.</q>
<rj><qau>Longfellow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In designating the banks of a river, <xex>right</xex>
and <xex>left</xex> are used always with reference to the position of
one who is facing in the direction of the current's flow.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>Well placed, disposed, or adjusted; orderly; well
regulated; correctly done.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <def>Designed to be placed or worn outward; <as>as, the
<ex>right</ex> side of a piece of cloth</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>At right angles</b></col>, <cd>so as to form a right
angle or right angles, as when one line crosses another
perpendicularly.</cd> -- <col><b>Right and left</b></col>, <cd>in both
or all directions.</cd> <mark>[Colloq.]</mark> -- <col><b>Right and left
coupling</b></col> <fld>(Pipe fitting)</fld>, <cd>a coupling the
opposite ends of which are tapped for a right-handed screw and a
left-handed screw, respectivelly.</cd> -- <col><b>Right angle</b></col>.
<sd>(a)</sd> <cd>The angle formed by one line meeting another
perpendicularly, as the angles <xex>ABD</xex>, <xex>DBC</xex>.</cd>
<sd>(b)</sd> <fld>(Spherics)</fld> <cd>A spherical angle included
between the axes of two great circles whose planes are perpendicular to
each other.</cd> -- <col><b>Right ascension</b></col>. <cd>See under
<er>Ascension</er>.</cd> -- <col><b>Right Center</b></col>
<fld>(Politics)</fld>, <cd>those members belonging to the Center in a
legislative assembly who have sympathies with the Right on political
questions. See <er>Center</er>, <pos>n.</pos>, 5.</cd> --
<mcol><col><b>Right cone</b></col>, <col><b>Right cylinder</b></col>,
<col><b>Right prism</b></col>, <col><b>Right pyramid</b></col></mcol>
<fld>(Geom.)</fld>, <cd>a cone, cylinder, prism, or pyramid, the axis of
which is perpendicular to the base.</cd> -- <col><b>Right
line</b></col>. <cd>See under <er>Line</er>.</cd> -- <col><b>Right
sailing</b></col> <fld>(Naut.)</fld>, <cd>sailing on one of the four
cardinal points, so as to alter a ship's latitude or its longitude, but
not both.</cd> <au>Ham. Nav. Encyc.</au> -- <col><b>Right
sphere</b></col> <fld>(Astron. & Geol.)</fld>, <cd>a sphere in such a
position that the equator cuts the horizon at right angles; in spherical
projections, that position of the sphere in which the primitive plane
coincides with the plane of the equator.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Right</xex> is used elliptically for <xex>it is
right</xex>, <xex>what you say is right</xex>,
<xex>true</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><q><ldquo/<qex>Right</qex>,<rdquo/ cries his lordship.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Straight; direct; perpendicular; upright; lawful;
rightful; true; correct; just; equitable; proper; suitable;
becoming.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Right</ent><br/
<hw>Right</hw>, <pos>adv.</pos> <sn>1.</sn> <def>In a right
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>In a right or straight line; directly; hence;
straightway; immediately; next; <as>as, he stood <ex>right</ex> before
me; it went <ex>right</ex> to the mark; he came <ex>right</ex> out; he
followed <ex>right</ex> after the guide.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Unto Dian's temple goeth she <qex>right</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Let thine eyes look <qex>right</qex> on.</q> <rj><qau>Prov. iv.
25.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Right</qex> across its track there lay,<br/
Down in the water, a long reef of gold.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Exactly; just.</def> <mark>[Obs. or
Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Came he <qex>right</qex> now to sing a raven's note?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>According to the law or will of God; conforming to
the standard of truth and justice; righteously; <as>as, to live
<ex>right</ex>; to judge <ex>right</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>According to any rule of art; correctly.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>You with strict discipline instructed <qex>right</qex>.</q>
<rj><qau>Roscommon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>According to fact or truth; actually; truly; really;
correctly; exactly; <as>as, to tell a story <ex>right</ex></as>.</def>
<ldquo/<xex>Right</xex> at mine own cost.<rdquo/
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Right</qex> as it were a steed of Lumbardye.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>His wounds so smarted that he slept <qex>right</qex> naught.</q>
<rj><qau>Fairfax.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>In a great degree; very; wholly; unqualifiedly;
extremely; highly; <as>as, <ex>right</ex> humble; <ex>right</ex> noble;
<ex>right</ex> valiant</as>.</def> <ldquo/He was not <xex>right</xex>
fat<rdquo/. <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>For which I should be <qex>right</qex> sorry.</q>
<rj><qau>Tyndale.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>[I] return those duties back as are <qex>right</qex> fit.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In this sense now chiefly prefixed to titles; as,
<xex>right</xex> honorable; <xex>right</xex> reverend.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Right honorable</b></col>, <cd>a title given in England
to peers and peeresses, to the eldest sons and all daughters of such
peers as have rank above viscounts, and to all privy councilors; also,
to certain civic officers, as the lord mayor of London, of York, and of
Dublin.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1242 --></p>

<p><note><hand/ <xex>Right</xex> is used in composition with other
adverbs, as up<xex>right</xex>, down<xex>right</xex>,
forth<xex>right</xex>, etc.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Right along</b></col>, <cd>without cessation;
continuously; <as>as, to work <ex>right along</ex> for several
hours</as>.</cd> <mark>[Colloq. U.S.]</mark> -- <mcol><col><b>Right
away</b></col>, <it>or</it> <col><b>Right off</b></col></mcol>, <cd>at
once; straightway; without delay.</cd> <mark>[Colloq. U.S.]</mark>
<ldquo/We will . . . shut ourselves up in the office and do the work
<xex>right off</xex>.<rdquo/ <au>D. Webster.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Right</ent><br/
<hw>Right</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS. <ets>right</ets>.
See <er>Right</er>, <pos>a.</pos>]</ety> <sn>1.</sn> <def>That which is
right or correct.</def> Specifically: <sd>(a)</sd> <def>The straight
course; adherence to duty; obedience to lawful authority, divine or
human; freedom from guilt, -- the opposite of moral
<xex>wrong</xex>.</def> <sd>(b)</sd> <def>A true statement; freedom from
error of falsehood; adherence to truth or fact.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Seldom your opinions err;<br/
Your eyes are always in the <qex>right</qex>.</q>
<rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(c)</sd> <def>A just judgment or action; that which is true or
proper; justice; uprightness; integrity.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Long love to her has borne the faithful knight,<br/
And well deserved, had fortune done him <qex>right</qex>.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That to which one has a just claim.</def>
<specif>Specifically:</specif> <sd>(a)</sd> <def>That which one has a
natural claim to exact.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There are no <qex>rights</qex> whatever, without corresponding
duties.</q> <rj><qau>Coleridge.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(b)</sd> <def>That which one has a legal or social claim to do or
to exact; legal power; authority; <as>as, a sheriff has a <ex>right</ex>
to arrest a criminal</as>.</def> <sd>(c)</sd> <def>That which justly
belongs to one; that which one has a claim to possess or own; the
interest or share which anyone has in a piece of property; title; claim;
interest; ownership.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Born free, he sought his <qex>right</qex>.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Hast thou not <qex>right</qex> to all created things?</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Men have no <qex>right</qex> to what is not reasonable.</q>
<rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(d)</sd> <def>Privilege or immunity granted by
authority.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The right side; the side opposite to the
left.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Led her to the Souldan's <qex>right</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>In some legislative bodies of Europe (as in France),
those members collectively who are conservatives or monarchists. See
<er>Center</er>, 5.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>The outward or most finished surface, as of a piece
of cloth, a carpet, etc.</def><br/
[<source>1913 Webster</source>]</p>

<cs><p><col><b>At all right</b></col>, <cd>at all points; in all
respects.</cd> <mark>[Obs.]</mark> <au>Chaucer.</au> -- <col><b>Bill of
rights</b></col>, <cd>a list of rights; a paper containing a declaration
of rights, or the declaration itself. See under <er>Bill</er>.</cd> --
<mcol><col><b>By right</b></col>, <col><b>By rights</b></col>,
<it>or</it> <col><b>By good rights</b></col></mcol>, <cd>rightly;
properly; correctly.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>He should himself use it <qex>by right</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I should have been a woman <qex>by right</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <col><b>Divine right</b></col>, <it>or</it> <col><b>Divine right
of kings</b></col>, <cd>a name given to the patriarchal theory of
government, especially to the doctrine that no misconduct and no
dispossession can forfeit the right of a monarch or his heirs to the
throne, and to the obedience of the people.</cd> -- <col><b>To
rights</b></col>. <sd>(a)</sd> <cd>In a direct line; straight.</cd>
<mark>[R.]</mark> <au>Woodward.</au> <sd>(b)</sd> <cd>At once;
directly.</cd> <mark>[Obs. or Colloq.]</mark> <au>Swift.</au> --
<mcol><col><b>To set to rights</b></col>, <col><b>To put to
rights</b></col></mcol>, <cd>to put in good order; to adjust; to
regulate, as what is out of order.</cd> -- <col><b>Writ of
right</b></col> <fld>(Law)</fld>, <cd>a writ which lay to recover lands
in fee simple, unjustly withheld from the true owner.</cd>
<au>Blackstone.</au><br/
[<source>1913 Webster</source>]</p></cs>

<p><ent>Right</ent><br/
<hw>Right</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Righted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Righting</conjf>.]</vmorph> <ety>[AS. <ets>rihtan</ets>. See
<er>Right</er>, <pos>a.</pos>]</ety> <sn>1.</sn> <def>To bring or
restore to the proper or natural position; to set upright; to make right
or straight (that which has been wrong or crooked); to
correct.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To do justice to; to relieve from wrong; to restore
rights to; to assert or regain the rights of; <as>as, to <ex>right the
oppressed</ex>; <ex>to right</ex> one's self</as>; also, to
vindicate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>So just is God, to <qex>right</qex> the innocent.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>All experience hath shown that mankind are more disposed to suffer
while evils are sufferable, than to <qex>right</qex> themselves by
abolishing the forms to which they are accustomed.</q>
<rj><qau>Jefferson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To right a vessel</b></col> <fld>(Naut.)</fld>, <cd>to
restore her to an upright position after careening.</cd> -- <col><b>To
right the helm</b></col> <fld>(Naut.)</fld>, <cd>to place it in line
with the keel.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Right</ent><br/
<hw>Right</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To recover the proper
or natural condition or position; to become upright.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Naut.)</fld> <def>Hence, to regain an upright
position, as a ship or boat, after careening.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Right-about</ent><br/
<hw>Right"-a*bout`</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Right</ets>, adv. + <ets>about</ets>, adv.]</ety> <def>A
turning directly about by the right, so as to face in the opposite
direction; also, the quarter directly opposite; <as>as, to turn to the
<ex>right-about</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To send to the right-about</b></col>, <cd>to cause to
turn toward the opposite point or quarter; -- hence, of troops, to cause
to turn and retreat.</cd> <mark>[Colloq.]</mark> <rj><au>Sir W.
Scott.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Right-angled</ent><br/
<hw>Right"-an`gled</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Containing a
right angle or right angles; <as>as, a <ex>right-angled</ex>
triangle</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Righten</ent><br/
<hw>Right"en</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To do justice
to.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Relieve [marginal reading, <qex>righten</qex>] the opressed.</q>
<rj><qau>Isa. i. 17.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Righteous</ent><br/
<hw>Right"eous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OE.
<ets>rightways</ets>, <ets>rightwise</ets>, AS.
<ets>rightw<imac/s</ets>; <ets>riht</ets> right + <ets>w<imac/s</ets>
wise, having wisdom, prudent. See <er>Right</er>, <pos>a.</pos>,
<er>Wise</er>, <pos>a.</pos>]</ety> <def>Doing, or according with, that
which is right; yielding to all their due; just; equitable; especially,
free from wrong, guilt, or sin; holy; <as>as, a <ex>righteous</ex> man
or act; a <ex>righteous</ex> retribution</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Fearless in his <qex>righteous</qex> cause.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Upright; just; godly; holy; uncorrupt; virtuous;
honest; equitable; rightful.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Righteoused</ent><br/
<hw>Right"eoused</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Made
righteous.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Righteously</ent><br/
<hw>Right"eous*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <ety>[AS.
<ets>rightw<imac/sl<imac/ce</ets>.]</ety> <def>In a righteous manner;
<as>as, to judge <ex>righteously</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Righteousness</ent><br/
<hw>Right"eous*ness</hw>, <pos>n.</pos> <ety>[AS.
<ets>rihtw<imac/snes</ets>.]</ety> <sn>1.</sn> <def>The quality or state
of being righteous; holiness; purity; uprightness; rectitude.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Righteousness</xex>, as used in Scripture and
theology, in which it chiefly occurs, is nearly equivalent to
<xex>holiness</xex>, comprehending holy principles and affections of
heart, and conformity of life to the divine law.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A righteous act, or righteous quality.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>All our <qex>righteousnesses</qex> are as filthy rags.</q>
<rj><qau>Isa. lxiv. 6.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The act or conduct of one who is
righteous.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Blessed are they that keep judgment, and he that doeth
<qex>righteousness</qex> at all times.</q> <rj><qau>Ps. cvi.
3.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Theol.)</fld> <def>The state of being right with
God; justification; the work of Christ, which is the ground of
justification.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There are two kinds of Christian <qex>righteousness</qex>: the one
without us, which we have by imputation; the other in us, which
consisteth of faith, hope, and charity, and other Christian virtues.</q>
<rj><qau>Hooker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Only for the <qex>righteousness</qex> of Christ imputed to us, and
received by faith alone.</q> <rj><qau>Westminster
Catechism.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Uprightness; holiness; godliness; equity;
justice; rightfulness; integrity; honesty; faithfulness.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Righter</ent><br/
<hw>Right"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who sets right;
one who does justice or redresses wrong.</def>
<rj><au>Shelton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rightful</ent><br/
<hw>Right"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Righteous; upright; just; good; -- said of persons.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Consonant to justice; just; <as>as, a
<ex>rightful</ex> cause</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Having the right or just claim according to
established laws; being or holding by right; <as>as, the
<ex>rightful</ex> heir to a throne or an estate; a <ex>rightful</ex>
king.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Belonging, held, or possessed by right, or by just
claim; <as>as, a <ex>rightful</ex> inheritance; <ex>rightful</ex>
authority.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Just; lawful; true; honest; equitable;
proper.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rightfully</ent><br/
<hw>Right"ful*ly</hw>, <pos>adv.</pos> <def>According to right or
justice.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rightfulness</ent><br/
<hw>Right"ful*ness</hw>, <pos>n.</pos> <sn>1.</sn> <def>The quality or
state of being rightful; accordance with right and justice.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Moral rectitude; righteousness.</def>
<mark>[Obs.]</mark> <rj><au>Wyclif.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>We fail of perfect <qex>rightfulness</qex>.</q> <rj><qau>Sir P.
Sidney.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Right-hand</ent><br/
<hw>Right"-hand`</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Situated or being on the right; nearer the right hand than the
left; <as>as, the <ex>right-hand</ex> side, room, or
road</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Chiefly relied on; almost indispensable.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Mr. Alexander Truncheon, who is their <qex>right-hand</qex> man in
the troop.</q> <rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Right-hand rope</b></col>, <cd>a rope which is laid up
and twisted with the sun, that is, in the same direction as plain-laid
rope. See <xex>Illust.</xex> of <er>Cordage</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Right-handed</ent><br/
<hw>Right"-hand`ed</hw>, <pos>a.</pos> <sn>1.</sn> <def>Using the right
hand habitually, or more easily than the left.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Having the same direction or course as the movement
of the hands of a watch seen in front; -- said of the motion of a
revolving object looked at from a given direction.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <def>Having the whorls rising from
left to right; dextral; -- said of spiral shells. See <xex>Illust.</xex>
of <er>Scalaria</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Right-handed screw</b></col>, <cd>a screw, the threads of
which, like those of a common wood screw, wind spirally in such a
direction that the screw advances away from the observer when turned
with a right-handed movement in a fixed nut.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Right-handedness</ent><br/
<hw>Right"-hand`ed*ness</hw>, <pos>n.</pos> <def>The state or quality of
being right-handed; hence, skill; dexterity.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Right-hearted</ent><br/
<hw>Right"-heart`ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having a right
heart or disposition.</def> -- <wordforms><wf>Right"-heart`ed*ness</wf>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rightless</ent><br/
<hw>Right"less</hw>, <pos>a.</pos> <def>Destitute of right.</def>
<rj><au>Sylvester.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Right-lined</ent><br/
<hw>Right"-lined`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Formed by right
lines; rectilineal; <as>as, a <ex>right-lined</ex> angle</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rightly</ent><br/
<hw>Right"ly</hw>, <pos>adv.</pos> <ety>[AS.
<ets>richtlice</ets>.]</ety> <sn>1.</sn> <def>Straightly; directly; in
front.</def> <mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>According to justice; according to the divine will
or moral rectitude; uprightly; <as>as, duty <ex>rightly</ex>
performed</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Properly; fitly; suitably; appropriately.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Eve <qex>rightly</qex> called, Mother of all mankind.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>According to truth or fact; correctly; not
erroneously; exactly.</def> <ldquo/I can not <xex>rightly</xex>
say.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou didst not <qex>rightly</qex> see.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Right-minded</ent><br/
<hw>Right"-mind`ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having a right
or honest mind.</def> -- <wordforms><wf>Right"-mind`ed*ness</wf>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rightness</ent><br/
<hw>Right"ness</hw>, <pos>n.</pos> <ety>[AS. <ets>rihtnes</ets>.]</ety>
<def>Straightness; <as>as, the <ex>rightness</ex> of a line</as>.</def>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The quality or state of being right; right
relation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The craving for <qex>rightness</qex> with God.</q> <rj><qau>J. C.
Shairp.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Right-running</ent><br/
<hw>Right"-run`ning</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Straight;
direct.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rightward</ent><br/
<hw>Right"ward</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>Toward the
right.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Rightward</qex> and leftward rise the rocks.</q>
<rj><qau>Southey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Right whale</ent><br/
<hw>Right" whale`</hw> <pr>(?)</pr>. <fld>(Zool.)</fld> <sd>(a)</sd>
<def>The bowhead, Arctic, or Greenland whale (<spn>Balaena
mysticetus</spn>), from whose mouth the best whalebone is
obtained.</def> <sd>(b)</sd> <def>Any other whale that produces valuable
whalebone, as the Atlantic, or Biscay, right whale (<spn>Balaena
cisarctica</spn>), and the Pacific right whale (<spn>Balaena
Sieboldii</spn>); a bone whale.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Pygmy right whale</b></col> <fld>(Zool.)</fld>, <cd>a
small New Zealand whale <spn>(Neobalaena marginata)</spn> which is only
about sixteen feet long. It produces short, but very elastic and tough,
whalebone.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rightwise</ent><br/
<hw>Right"wise`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Righteous.</def>
<mark>[Obs.]</mark> <rj><au>Wyclif.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rightwise</ent><br/
<hw>Right"wise`</hw>, <pos>v. t.</pos> <def>To make righteous.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rightwisely</ent><br/
<hw>Right"wise`ly</hw>, <pos>adv.</pos> <def>Righteously.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rightwiseness</ent><br/
<hw>Right"wise`ness</hw>, <pos>n.</pos> <def>Righteousness.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>In doom and eke in <qex>rightwisnesse</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rigid</ent><br/
<hw>Rig"id</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>rigidus</ets>,
fr. <ets>rigere</ets> to be stiff or numb: cf. F. <ets>rigide</ets>. Cf.
<er>Rigor</er>. ]</ety> <sn>1.</sn> <def>Firm; stiff; unyielding; not
pliant; not flexible.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Upright beams innumerable<br/
Of <qex>rigid</qex> spears.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence, not lax or indulgent; severe; inflexible;
strict; <as>as, a <ex>rigid</ex> father or master; <ex>rigid</ex>
discipline; <ex>rigid</ex> criticism; <ex>a rigid</ex>
sentence.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>The more <qex>rigid</qex> order of principles in religion and
government.</q> <rj><qau>Hawthorne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Stiff; unpliant; inflexible; unyielding; strict;
exact; severe; austere; stern; rigorous; unmitigated.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rigidity</ent><br/
<hw>Ri*gid"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>rigiditas</ets>: cf. F. <ets>rigidit<eacute/</ets>. See
<er>Rigid</er>.]</ety> <sn>1.</sn> <def>The quality or state of being
rigid; want of pliability; the quality of resisting change of form; the
amount of resistance with which a body opposes change of form; --
opposed to <xex>flexibility</xex>, <xex>ductility</xex>,
<xex>malleability</xex>, and <xex>softness</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Stiffness of appearance or manner; want of ease or
elegance.</def> <rj><au>Sir H. Wotton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Severity; rigor.</def> <mark>[Obs. orR.]</mark>
<rj><au>Bp. Burnet.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Stiffness; rigidness; inflexibility.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rigidly</ent><br/
<hw>Rig"id*ly</hw> <pr>(?)</pr>, <pos>v.</pos> <def>In a rigid manner;
stiffly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rigidness</ent><br/
<hw>Rig"id*ness</hw>, <pos>n.</pos> <def>The quality or state of being
rigid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rigidulous</ent><br/
<hw>Ri*gid"u*lous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Dim. from
<ets>rigid</ets>.]</ety> <fld>(Bot.)</fld> <def>Somewhat rigid or stiff;
<as>as, a <ex>rigidulous</ex> bristle</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Riglet</ent><br/
<hw>Rig"let</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Print.)</fld>
<def>See <er>Reglet</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rigmarole</ent><br/
<hw>Rig"ma*role</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[For <ets>ragman
roll</ets>. See <er>Ragman's roll</er>.]</ety> <def>A succession of
confused or nonsensical statements; foolish talk; nonsense.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Often one's dear friend talks something which one scruples to call
<qex>rigmarole</qex>.</q> <rj><qau>De Quincey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rigmarole</ent><br/
<hw>Rig"ma*role</hw>, <pos>a.</pos> <def>Consisting of rigmarole;
frivolous; nonsensical; foolish.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rigol</ent><br/
<hw>Rig"ol</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. also
<ets>ringol</ets>. Cf. <er>Ring</er>.]</ety> <def>A circle; hence, a
diadem.</def> <mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rigolette</ent><br/
<hw>Rig`o*lette"</hw> <pr>(r<icr/g`<osl/*l<ecr/t")</pr>, <pos>n.</pos>
<ety>[Prob. fr. <etsep>Rigolette</etsep>, name of a girl in Eugene Sue's
novel <ldquo/Myst<egrave/res de Paris.<rdquo/]</ety> <def>A woman's
light scarflike head covering, usually knit or crocheted of
wool.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Rigoll</ent><br/
<hw>Rig"oll</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Corrupted fr.
<ets>regal</ets>.]</ety> <def>A musical instrument formerly in use,
consisting of several sticks bound together, but separated by beads, and
played with a stick with a ball at its end.</def> <au>Moore (Encyc. of
Music.).</au><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rigor</ent><br/
\'d8<hw>Ri"gor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. See
<er>Rigor</er>., below.]</ety> <sn>1.</sn> <def>Rigidity;
stiffness.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(ed.)</fld> <def>A sense of chilliness, with
contraction of the skin; a convulsive shuddering or tremor, as in the
chill preceding a fever.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs>\'d8<col><b>Rigor caloris</b></col> <pr>(<?/)</pr> <ety>[L.,
rigor of heat]</ety> <fld>(Physiol.)</fld>, <cd>a form of rigor mortis
induced by heat, as when the muscle of a mammal is heated to about
50<deg/ C.</cd> -- \'d8<col><b>Rigor mortis</b></col> <pr>(<?/)</pr>
<ety>[L. , rigor of death]</ety>, <cd>death stiffening; the rigidity of
the muscles that occurs at death and lasts till decomposition sets in.
It is due to the formation of myosin by the coagulation of the contents
of the individual muscle fibers.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rigor</ent><br/
<hw>Rig"or</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>rigour</ets>,
OF. <ets>rigour</ets>, F. <ets>rigueur</ets>, from L. <ets>rigor</ets>,
fr. <ets>rigere</ets> to be stiff. See <er>Rigid</er>.]</ety>
<altsp>[Written also <asp>rigour</asp>.]</altsp> <sn>1.</sn> <def>The
becoming stiff or rigid; the state of being rigid; rigidity; stiffness;
hardness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The rest his look<br/
Bound with Gorgonian <qex>rigor</qex> not to move.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Med.)</fld> <def>See 1st <er>Rigor</er>,
2.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Severity of climate or season; inclemency; <as>as,
the <ex>rigor</ex> of the storm; the <ex>rigors</ex> of
winter.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Stiffness of opinion or temper; rugged sternness;
hardness; relentless severity; hard-heartedness; cruelty.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>All his <qex>rigor</qex> is turned to grief and pity.</q>
<rj><qau>Denham.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>If I shall be condemn'd<br/
Upon surmises, . . . I tell you<br/
'T is <qex>rigor</qex> and not law.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Exactness without allowance, deviation, or
indulgence; strictness; <as>as, the <ex>rigor</ex> of criticism; to
execute a law with <ex>rigor</ex>; to enforce moral duties with
<ex>rigor</ex></as>; -- opposed to <ant>lenity</ant>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Severity of life; austerity; voluntary submission to
pain, abstinence, or mortification.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The prince lived in this convent with all the <qex>rigor</qex> and
austerity of a capuchin.</q> <rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>Violence; force; fury.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Whose raging <qex>rigor</qex> neither steel nor brass could
stay.</q> <rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Stiffness; rigidness; inflexibility; severity;
austerity; sternness; harshness; strictness; exactness.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rigorism</ent><br/
<hw>Rig"or*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>rigorisme</ets>.]</ety> <sn>1.</sn> <def>Rigidity in principle or
practice; strictness; -- opposed to <ant>laxity</ant>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Severity, as of style, or the like.</def>
<rj><au>Jefferson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Ethics)</fld> <def>Strictness in ethical
principles; -- usually applied to ascetic ethics, and opposed to ethical
<contr>latitudinarianism</contr>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Rigorist</ent><br/
<hw>Rig"or*ist</hw>, <pos>n.</pos> <ety>[Cf. F.
<ets>rigoriste</ets>.]</ety> <def>One who is rigorous; -- sometimes
applied to an extreme Jansenist.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rigorous</ent><br/
<hw>Rig"or*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F.
<ets>rigoureux</ets>, LL. <ets>rigorosus</ets>. See
<er>Rigor</er>.]</ety> <sn>1.</sn> <def>Manifesting, exercising, or
favoring rigor; allowing no abatement or mitigation; scrupulously
accurate; exact; strict; severe; relentless; <as>as, a <ex>rigorous</ex>
officer of justice; a <ex>rigorous</ex> execution of law; a
<ex>rigorous</ex> definition or demonstration.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>He shall be thrown down the Tarpeian Rock<br/
With <qex>rigorous hands</qex>.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>We do not connect the scattered phenomena into their
<qex>rigorous</qex> unity.</q> <rj><qau>De Quincey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Severe; intense; inclement; <as>as, a
<ex>rigorous</ex> winter</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Violent.</def> <mark>[Obs.]</mark>
<ldquo/<xex>Rigorous</xex> uproar.<rdquo/ <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Mathematics, Logic)</fld> <def>Adhering
scrupulously and exactly to accepted principles; hence, logically valid;
<as>as, a <ex>rigorous</ex> proof</as>.</def><br/
[<source>PJC</source>]</p>

<p><syn><b>Syn.</b> -- Rigid; inflexible; unyielding; stiff; severe;
austere; stern; harsh; strict; exact.</syn><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Rig"or*ous*ly</wf>, <pos>adv.</pos> --
<wf>Rig"or*ous*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rigsdag</ent><br/
\'d8<hw>Rigs"dag</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Dan. Cf.
<er>Reichstag</er>.]</ety> <def>See <er>Legislature</er>,
<xex>Denmark</xex>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Rigsdaler</ent><br/
\'d8<hw>Rigs"da`ler</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Dan. See
<er>Rix-dollar</er>.]</ety> <def>A Danish coin worth about fifty-four
cents. It was the former unit of value in Denmark.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rig-Veda</ent><br/
\'d8<hw>Rig`-Ve"da</hw> <pr>(?)</pr>. <def>See <er>Veda</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Riksdaler</ent><br/
\'d8<hw>Riks"da`ler</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sw. See
<er>Rix-dollar</er>.]</ety> <def>A Swedish coin worth about twenty-seven
cents. It was formerly the unit of value in Sweden.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rile</ent><br/
<hw>Rile</hw> <pr>(r<imac/l)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Riled</conjf> <pr>(r<imac/ld)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Riling</conjf>.]</vmorph> <ety>[See
<er>Roil</er>.]</ety> <sn>1.</sn> <def>To render turbid or muddy; to
stir up; to roil.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To stir up in feelings; to make angry; to
vex.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In both senses provincial in England and colloquial in
the United States.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rilievo</ent><br/
\'d8<hw>Ri*lie"vo</hw> <pr>(?)</pr>, <pos>n.</pos><ety>[It. See
<er>Relief</er>.]</ety> <fld>(Sculp. & Arch.)</fld> <def>Same as
<er>Relief</er>, <pos>n.</pos>, 5.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rill</ent><br/
<hw>Rill</hw> <pr>(r<icr/l)</pr>, <pos>n.</pos> <ety>[Cf. LG.
<ets>rille</ets> a small channel or brook, a furrow, a chamfer, OE.
<ets>rigol</ets> a small brook, F. <ets>rigole</ets> a trench or furrow
for water, W. <ets>rhill</ets> a row, <ets>rhigol</ets> a little ditch.
<root/11.]</ety> <sn>1.</sn> <def>A very small brook; a
streamlet.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Astron.)</fld> <def>See <er>Rille</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rill</ent><br/
<hw>Rill</hw>, <pos>v. i.</pos> <def>To run a small stream.</def>
<mark>[R.]</mark> <rj><au>Prior.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rille</ent><br/
<hw>Rille</hw> <pr>(r<icr/l)</pr>, <pos>n.</pos> <ety>[G.
<ets>rille</ets> a furrow.]</ety> <fld>(Astron.)</fld> <def>One of
certain narrow, crooked valleys seen, by aid of the telescope, on the
surface of the moon.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rillet</ent><br/
<hw>Rill"et</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A little rill.</def>
<rj><au>Burton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rily</ent><br/
<hw>Ri"ly</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Roily.</def>
<mark>[Prov. Eng. & Colloq. U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1243 --></p>

<p><ent>Rim</ent><br/
<hw>Rim</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[As. <ets>rima</ets>,
<ets>reoma</ets>, edge; cf. W. <ets>rhim</ets>, <ets>rhimp</ets>, a rim,
edge, boundary, termination, Armor, <ets>rim</ets>. Cf.
<er>Rind</er>.]</ety> <sn>1.</sn> <def>The border, edge, or margin of a
thing, usually of something circular or curving; <as>as, the
<ex>rim</ex> of a kettle or basin</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The lower part of the abdomen.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Arch rim</b></col> <fld>(Phonetics)</fld>, <cd>the line
between the gums and the palate.</cd> -- <col><b>Rim-fire
cartridge</b></col>. <fld>(Mil.)</fld> <cd>See under
<er>Cartridge</er>.</cd> -- <col><b>Rim lock</b></col>. <cd>See under
<er>Lock</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rim</ent><br/
<hw>Rim</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Rimmed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Rimming</conjf>.]</vmorph> <def>To furnish with a rim; to
border.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rima</ent><br/
\'d8<hw>Ri"ma</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Rimae</plw> <pr>(#)</pr>.</plu> <ety>[L.]</ety> <fld>(Anat.)</fld>
<def>A narrow and elongated aperture; a cleft; a fissure.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rimau dahan</ent><br/
\'d8<hw>Ri"mau da"han</hw> <pr>(?)</pr>. <ety>[From the native Oriental
name.]</ety> <fld>(Zool.)</fld> <def>The clouded tiger cat (<spn>Felis
marmorata</spn>) of Southern Asia and the East Indies.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rimbase</ent><br/
<hw>Rim"base`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Mil.)</fld> <def>A
short cylinder connecting a trunnion with the body of a cannon. See
<xex>Illust.</xex> of <er>Cannon</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rime</ent><br/
<hw>Rime</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>rima</ets>.]</ety> <def>A rent or long aperture; a chink; a
fissure; a crack.</def> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rime</ent><br/
<hw>Rime</hw>, <pos>n.</pos> <ety>[AS. <ets>hr<imac/m</ets>; akin to D.
<ets>rijm</ets>, Icel. <ets>hr<imac/m</ets>, Dan. <ets>rim</ets>, Sw.
<ets>rim</ets>; cf. D. <ets>rijp</ets>, G. <ets>reif</ets>, OHG.
<ets>r<imac/fo</ets>, <ets>hr<imac/fo</ets>.]</ety> <def>White frost;
hoarfrost; congealed dew or vapor.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The trees were now covered with <qex>rime</qex>.</q> <rj><qau>De
Quincey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rime</ent><br/
<hw>Rime</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Rimed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Riming</conjf>.]</vmorph> <def>To freeze or congeal into
hoarfrost.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rime</ent><br/
<hw>Rime</hw>, <pos>n.</pos> <ety>[Etymol. uncertain.]</ety> <def>A step
or round of a ladder; a rung.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rime</ent><br/
<hw>Rime</hw>, <pos>n.</pos> <def>Rhyme. See <er>Rhyme</er>.</def>
<rj><au>Coleridge.</au> <au>Landor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ This spelling, which is etymologically preferable, is
coming into use again.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rime</ent><br/
<hw>Rime</hw>, <pos>v. i. & t.</pos> <def>To rhyme. See
<er>Rhyme</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rimer</ent><br/
<hw>Rim"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A rhymer; a
versifier.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rimer</ent><br/
<hw>Rim"er</hw>, <pos>n.</pos> <def>A tool for shaping the rimes of a
ladder.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rimey</ent><br/
<hw>Rim"ey</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Cf. OF.
<ets>rimoier</ets>. See <er>Ryime</er>.]</ety> <def>To compose in rhyme;
to versify.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>[Lays] <qex>rimeyed</qex> in their first Breton tongue.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rim-fire</ent><br/
<hw>Rim"-fire`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having the
percussion fulminate in a rim surrounding the base, distinguished from
<contr>center-fire</contr>; -- said of cartridges; also, using rim-fire
cartridges; <as>as, a <ex>rim-fire</ex> gun</as>. Such cartridges are
now little used.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Rimmer</ent><br/
<hw>Rim"mer</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An implement for
cutting, trimming, or ornamenting the rim of anything, as the edges of
pies, etc.; also, a reamer.</def> <rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rimose</ent><br/
<hw>Ri*mose"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>rimosus</ets>, fr. <ets>rima</ets> a chink: cf. F.
<ets>rimeux</ets>.]</ety> <sn>1.</sn> <def>Full of rimes, fissures, or
chinks.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Nat. Hist.)</fld> <def>Having long and nearly
parallel clefts or chinks, like those in the bark of trees.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rimosely</ent><br/
<hw>Ri*mose"ly</hw>, <pos>adv.</pos> <def>In a rimose manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rimosity</ent><br/
<hw>Ri*mos"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>State of being
rimose.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rimous</ent><br/
<hw>Rim"ous</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Rimose.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rimple</ent><br/
<hw>Rim"ple</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS.
<ets>hrimpele</ets>, or <ets>rimpel</ets>. See Rumple.]</ety> <def>A
fold or wrinkle. See <er>Rumple</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rimple</ent><br/
<hw>Rim"ple</hw>, <pos>v. t. & i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Rimpled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Rimpling</conjf> <pr>(?)</pr>.]</vmorph> <def>To rumple; to
wrinkle.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rimy</ent><br/
<hw>Rim"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Abounding with rime;
frosty.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rincon</ent><br/
\'d8<hw>Rin*con"</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu>pl.
<plw>Rincones</plw> <pr>(#)</pr></plu>. <ety>[Sp.
<ets>rinc<oacute/n</ets>.]</ety> <def>An interior corner; a nook; hence,
an angular recess or hollow bend in a mountain, river, cliff, or the
like.</def> <mark>[Western & Southern U. S.]</mark> <rj><au>D. S.
Jordan.</au></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Rind</ent><br/
<hw>Rind</hw> <pr>(r<imac/nd)</pr>, <pos>n.</pos> <ety>[AS.
<ets>rind</ets> bark, crust of bread; akin to OHG. <ets>rinta</ets>, G.
<ets>rinde</ets>, and probably to E. <ets>rand</ets>, <ets>rim</ets>;
cf. Skr. <ets>ram</ets> to end, rest.]</ety> <def>The external covering
or coat, as of flesh, fruit, trees, etc.; skin; hide; bark; peel;
shell.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou canst not touch the freedom of my mind<br/
With all thy charms, although this corporal <qex>rind</qex><br/
Thou hast immanacled.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Sweetest nut hath sourest <qex>rind</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rind</ent><br/
<hw>Rind</hw>, <pos>v. t.</pos> <def>To remove the rind of; to
bark.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rinderpest</ent><br/
<hw>Rin"der*pest</hw> <pr>(r<icr/n"d<etil/r*p<ecr/st)</pr>,
<pos>n.</pos> <ety>[G., fr. <ets>rind</ets>, pl. <ets>rinder</ets>,
cattle + <ets>pest</ets> pest, plague.]</ety> <def>A highly contagious
distemper or murrain, affecting neat cattle, and less commonly sheep and
goats; -- called also <altname>cattle plague</altname>, <altname>Russian
cattle plague</altname>, and <altname>steppe
murrain</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rindle</ent><br/
<hw>Rin"dle</hw> <pr>(r<icr/n"d'l)</pr>, <pos>n.</pos> <ety>[AS.
<ets>rynele</ets>. <root/11. See <er>Run</er>.]</ety> <def>A small water
course or gutter.</def> <rj><au>Ash.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rindless</ent><br/
<hw>Rind"less</hw> <pr>(r<imac/nd"l<ecr/s)</pr>, <pos>a.</pos>
<def>Destitute of a rind.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rindy</ent><br/
<hw>Rind"y</hw> <pr>(r<imac/nd"<ycr/)</pr>, <pos>a.</pos> <def>Having a
rind or skin.</def> <rj><au>Ash.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rine</ent><br/
<hw>Rine</hw> <pr>(r<imac/n)</pr>, <pos>n.</pos> <def>See
<er>Rind</er>.</def> <mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rined</ent><br/
<hw>Rined</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having a rind</def>
<mark>[Obs.]</mark> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rinforzando</ent><br/
\'d8<hw>Rin`for*zan"do</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[It., fr.
<ets>rinforzare</ets> to reenforce, strengthen.]</ety> <fld>(Mus.)</fld>
<def>Increasing; strengthening; -- a direction indicating a sudden
increase of force (abbreviated <abbr>rf.</abbr>, <abbr>rfz.</abbr>) Cf.
<er>Forzando</er>, and <er>Sforzando</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ring</ent><br/
<hw>Ring</hw> <pr>(r<icr/ng)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp.</pos> <conjf>Rang</conjf> <pr>(r<acr/ng)</pr> or
<conjf>Rung</conjf> <pr>(r<ucr/ng)</pr>; <pos>p. p.</pos>
<conjf>Rung</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Ringing</conjf>.]</vmorph> <ety>[AS. <ets>hringan</ets>; akin to
Icel. <ets>hringja</ets>, Sw. <ets>ringa</ets>, Dan. <ets>ringe</ets>,
OD. <ets>ringhen</ets>, <ets>ringkelen</ets>. <root/19.]</ety>
<sn>1.</sn> <def>To cause to sound, especially by striking, as a
metallic body; <as>as, to <ex>ring</ex> a bell</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To make (a sound), as by ringing a bell; to
sound.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The shard-borne beetle, with his drowsy hums,<br/
Hath <qex>rung</qex> night's yawning peal.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To repeat often, loudly, or earnestly.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To ring a peal</b></col>, <cd>to ring a set of changes on
a chime of bells.</cd> -- <col><b>To ring the changes upon</b></col>.
<cd>See under <er>Change</er>.</cd> -- <mcol><col><b>To ring
in</b></col> <it>or</it> <col><b>To ring out</b></col></mcol>, <cd>to
usher, attend on, or celebrate, by the ringing of bells; <as>as, <ex>to
ring out</ex> the old year and <ex>ring in</ex> the new</as>.</cd>
<au>Tennyson</au>. -- <col><b>To ring the bells backward</b></col>,
<cd>to sound the chimes, reversing the common order; -- formerly done as
a signal of alarm or danger.</cd> <au>Sir W. Scott.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ring</ent><br/
<hw>Ring</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To sound, as a bell or
other sonorous body, particularly a metallic one.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Now <qex>ringen</qex> trompes loud and clarion.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Why <qex>ring</qex> not out the bells?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To practice making music with bells.</def>
<rj><au>Holder.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To sound loud; to resound; to be filled with a
ringing or reverberating sound.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With sweeter notes each rising temple <qex>rung</qex>.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The hall with harp and carol <qex>rang</qex>.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>My ears still <qex>ring</qex> with noise.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To continue to sound or vibrate; to
resound.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The assertion is still <qex>ringing</qex> in our ears.</q>
<rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To be filled with report or talk; <as>as, the whole
town <ex>rings</ex> with his fame</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ring</ent><br/
<hw>Ring</hw>, <pos>n.</pos> <sn>1.</sn> <def>A sound; especially, the
sound of vibrating metals; <as>as, the <ex>ring</ex> of a
bell</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Any loud sound; the sound of numerous voices; a
sound continued, repeated, or reverberated.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>ring</qex> of acclamations fresh in his ears.</q>
<rj><qau>Bacon</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A chime, or set of bells harmonically
tuned.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>As great and tunable a <qex>ring</qex> of bells as any in the
world.</q> <rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ring</ent><br/
<hw>Ring</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS. <ets>hring</ets>,
<ets>hrinc</ets>; akin to Fries. <ets>hring</ets>, D. & G.
<ets>ring</ets>, OHG. <ets>ring</ets>, <ets>hring</ets>, Icel.
<ets>hringr</ets>, DAn. & SW. <ets>ring</ets>; cf. Russ.
<ets>krug'</ets>. Cf. <er>Harangue</er>, <er>Rank</er> a
row,<er>Rink</er>.]</ety> <def>A circle, or a circular line, or anything
in the form of a circular line or hoop.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Specifically, a circular ornament of gold or other
precious material worn on the finger, or attached to the ear, the nose,
or some other part of the person; <as>as, a wedding
<ex>ring</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Upon his thumb he had of gold a <qex>ring</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The dearest <qex>ring</qex> in Venice will I give you.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A circular area in which races are or run or other
sports are performed; an arena.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Place me, O, place me in the dusty <qex>ring</qex>,<br/
Where youthful charioteers contend for glory.</q> <rj><qau>E.
Smith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>An inclosed space in which pugilists fight; hence,
figuratively, prize fighting.</def> <ldquo/The road was an institution,
the <xex>ring</xex> was an institution.<rdquo/
<rj><au>Thackeray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A circular group of persons.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And hears the Muses in a <qex>ring</qex><br/
Aye round about Jove's alter sing.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Geom.)</fld> <sd>(a)</sd> <def>The plane figure
included between the circumferences of two concentric circles.</def>
<sd>(b)</sd> <def>The solid generated by the revolution of a circle, or
other figure, about an exterior straight line (as an axis) lying in the
same plane as the circle or other figure.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Astron. & Navigation)</fld> <def>An instrument,
formerly used for taking the sun's altitude, consisting of a brass ring
suspended by a swivel, with a hole at one side through which a solar ray
entering indicated the altitude on the graduated inner surface
opposite.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <fld>(Bot.)</fld> <def>An elastic band partly or wholly
encircling the spore cases of ferns. See <xex>Illust.</xex> of
<er>Sporangium</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>A clique; an exclusive combination of persons for a
selfish purpose, as to control the market, distribute offices, obtain
contracts, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The ruling <qex>ring</qex> at Constantinople.</q> <rj><qau>E. A.
Freeman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Ring armor</b></col>, <cd>armor composed of rings of
metal. See <cref>Ring mail</cref>, below, and <cref>Chain mail</cref>,
under <er>Chain</er>.</cd> -- <col><b>Ring blackbird</b></col>
<fld>(Zool.)</fld>, <cd>the ring ousel.</cd> -- <col><b>Ring
canal</b></col> <fld>(Zool.)</fld>, <cd>the circular water tube which
surrounds the esophagus of echinoderms.</cd> -- <mcol><col><b>Ring
dotterel</b></col>, <it>or</it> <col><b>Ringed
dotterel</b></col></mcol>. <fld>(Zool.)</fld> <cd>See <er>Dotterel</er>,
and <xex>Illust.</xex> of <er>Pressiroster</er>.</cd> -- <col><b>Ring
dropper</b></col>, <cd>a sharper who pretends to have found a ring
(dropped by himself), and tries to induce another to buy it as valuable,
it being worthless.</cd> -- <col><b>Ring fence</b></col>. <cd>See under
<er>Fence</er>.</cd> -- <col><b>Ring finger</b></col>, <cd>the third
finger of the left hand, or the next the little finger, on which the
ring is placed in marriage.</cd> -- <col><b>Ring formula</b></col>
<fld>(Chem.)</fld>, <cd>a graphic formula in the shape of a closed ring,
as in the case of benzene, pyridine, etc. See <xex>Illust.</xex> under
<er>Benzene</er>.</cd> -- <col><b>Ring mail</b></col>, <cd>a kind of
mail made of small steel rings sewed upon a garment of leather or of
cloth.</cd> -- <col><b>Ring micrometer</b></col>. <fld>(Astron.)</fld>
<cd>See <cref>Circular micrometer</cref>, under
<er>Micrometer</er>.</cd> -- <col><b>Saturn's rings</b></col>. <cd>See
<er>Saturn</er>.</cd> -- <col><b>Ring ousel</b></col>.
<fld>(Zool.)</fld> <cd>See <er>Ousel</er>.</cd> -- <col><b>Ring
parrot</b></col> <fld>(Zool.)</fld>, <cd>any one of several species of
Old World parrakeets having a red ring around the neck, especially
<spn>Palaeornis torquatus</spn>, common in India, and <spn>Palaeornis
Alexandri</spn> of <er>Java</er>.</cd> -- <col><b>Ring plover</b></col>.
<fld>(Zool.)</fld> <sd>(a)</sd> <cd>The ringed dotterel</cd>.
<sd>(b)</sd> <cd>Any one of several small American plovers having a dark
ring around the neck, as the semipalmated plover (<spn>Aegialitis
semipalmata</spn>).</cd> -- <col><b>Ring snake</b></col>
<fld>(Zool.)</fld>, <cd>a small harmless American snake (<spn>Diadophis
punctatus</spn>) having a white ring around the neck. The back is
ash-colored, or sage green, the belly of an orange red.</cd> --
<col><b>Ring stopper</b></col>. <fld>(Naut.)</fld> <cd>See under
<er>Stopper</er>.</cd> -- <col><b>Ring thrush</b></col>
<fld>(Zool.)</fld>, <cd>the ring ousel.</cd> -- <col><b>The prize
ring</b></col>, <cd>the ring in which prize fighters contend; prize
fighters, collectively.</cd> -- <col><b>The ring</b></col>. <sd>(a)</sd>
<cd>The body of sporting men who bet on horse races</cd>.
<mark>[Eng.]</mark> <sd>(b)</sd> <cd>The prize ring.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ring</ent><br/
<hw>Ring</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Ringed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Ringing</conjf>.]</vmorph> <sn>1.</sn> <def>To surround with a
ring, or as with a ring; to encircle.</def> <ldquo/<xex>Ring</xex> these
fingers.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Hort.)</fld> <def>To make a ring around by cutting
away the bark; to girdle; <as>as, to <ex>ring</ex> branches or
roots</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To fit with a ring or with rings, as the fingers, or
a swine's snout.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ring</ent><br/
<hw>Ring</hw>, <pos>v. i.</pos> <fld>(Falconry)</fld> <def>To rise in
the air spirally.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ring armature</ent><br/
<hw>Ring armature</hw>. <fld>(Elec.)</fld> <def>An armature for a dynamo
or motor having the conductors wound on a ring.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Ringbill</ent><br/
<hw>Ring"bill`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>The ring-necked scaup duck; -- called also <altname>ring-billed
blackhead</altname>. See <er>Scaup</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ringbird</ent><br/
<hw>Ring"bird`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>The reed bunting. It has a collar of white feathers. Called also
<altname>ring bunting</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ringbolt</ent><br/
<hw>Ring"bolt`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An eyebolt having a
ring through the eye.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ringbone</ent><br/
<hw>Ring"bone`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Far.)</fld> <def>A
morbid growth or deposit of bony matter between or on the small pastern
and the great pastern bones.</def> <rj><au>J. H. Walsh.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ringdove</ent><br/
<hw>Ring"dove`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>A European wild pigeon (<spn>Columba palumbus</spn>) having a white
crescent on each side of the neck, whence the name. Called also
<altname>wood pigeon</altname>, and <altname>cushat</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ringed</ent><br/
<hw>Ringed</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Encircled
or marked with, or as with, a ring or rings.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Wearning a wedding ring; hence, lawfully
wedded.</def> <ldquo/A <xex>ringed</xex> wife.<rdquo/
<rj><au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Ringed seal</b></col> <fld>(Zool.)</fld>, <cd>a North
Pacific seal (<spn>Phoca foetida</spn>) having ringlike spots on the
body.</cd> -- <col><b>Ringed snake</b></col> <fld>(Zool.)</fld>, <cd>a
harmless European snake (<spn>Tropidonotus natrix</spn>) common in
England.</cd> -- <col><b>Ringed worm</b></col> <fld>(Zool.)</fld>,
<cd>an annelid.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ringent</ent><br/
<hw>Rin"gent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>ringens</ets>, <ets>-entis</ets>, p. pr. of <ets>ringi</ets> to
open wide the mouth: cf. F. <ets>ringent</ets>.]</ety> <fld>(Bot.)</fld>
<def>Having the lips widely separated and gaping like an open mouth;
<as>as a <ex>ringent</ex> bilabiate corolla</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ringer</ent><br/
<hw>Ring"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who,
or that which, rings; especially, one who rings chimes on
bells.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mining)</fld> <def>A crowbar.</def>
<rj><au>Simmonds.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ringer</ent><br/
<hw>Ring"er</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Horse Racing)</fld>
<def>A horse that is not entitled to take part in a race, but is
fraudulently got into it.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ringhead</ent><br/
<hw>Ring"head`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Cloth
Manuf.)</fld> <def>An instrument used for stretching woolen
cloth.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ringing</ent><br/
<hw>Ring"ing</hw>, <def><pos>a & n.</pos> from <er>Ring</er>,
<pos>v.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Ringing engine</b></col>, <cd>a simple form of pile
driver in which the monkey is lifted by men pulling on
ropes.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ringingly</ent><br/
<hw>Ring"ing*ly</hw>, <pos>adv.</pos> <def>In a ringing
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ringleader</ent><br/
<hw>Ring"lead`er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
leader of a circle of dancers; hence, the leader of a number of persons
acting together; the leader of a herd of animals.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A primacy of order, such an one as the <qex>ringleader</qex> hath
in a dance.</q> <rj><qau>Barrow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Opprobriously, a leader of a body of men engaged in
the violation of law or in an illegal enterprise, as rioters, mutineers,
or the like.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>ringleaders</qex> were apprehended, tried, fined, and
imprisoned.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ringlestone</ent><br/
<hw>Rin"gle*stone`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>The ringed dotterel, or ring plover.</def> <mark>[Prov.
Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ringlet</ent><br/
<hw>Ring"let</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Ring</ets> +
<ets>-let</ets>.]</ety> <sn>1.</sn> <def>A small ring; a small circle;
specifically, a fairy ring.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>You demi-puppets, that<br/
By moonshine do the green sour <qex>ringlets</qex> make,<br/
Whereof the ewe not bites.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A curl; especially, a curl of hair.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>[Her golden tresses] in wanton <qex>ringlets</qex> waved.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ringman</ent><br/
<hw>Ring"man</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Ringmen</plw> <pr>(<?/)</pr>.</plu> <def>The ring finger.</def>
<mark>[Obs.]</mark> <rj><au>Ascham</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ringmaster</ent><br/
<hw>Ring"mas`ter</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One in charge of
the performances (as of horses) within the ring in a circus.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ringneck</ent><br/
<hw>Ring"neck`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<fld>(Zool.)</fld> <def>Any one of several species of small plovers of
the genus <gen>Aegialitis</gen>, having a ring around the neck. The ring
is black in summer, but becomes brown or gray in winter. The
semipalmated plover (<spn>Aegialitis semipalmata</spn>) and the piping
plover (<spn>Aegialitis meloda</spn>) are common North American species.
Called also <altname>ring plover</altname>, and <altname>ring-necked
plover</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>The ring-necked duck.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ring-necked</ent><br/
<hw>Ring"-necked`</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Having a well defined ring of color around the neck.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Ring-necked duck</b></col> <fld>(Zool.)</fld>, <cd>an
American scaup duck (<spn>Aythya collaris</spn>). The head, neck, and
breast of the adult male are black, and a narrow, but conspicuous, red
ring encircles the neck. This ring is absent in the female. Called also
<altname>ring-neck</altname>, <altname>ring-necked blackhead</altname>,
<altname>ringbill</altname>, <altname>tufted duck</altname>, and
<altname>black jack</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ringsail</ent><br/
<hw>Ring"sail`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Naut.)</fld>
<def>See <er>Ringtail</er>, 2.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ringstraked</ent><br/
<hw>Ring"straked`</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Ring-streaked.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Cattle <qex>ringstraked</qex>, speckled, and spotted.</q>
<rj><qau>Gen. xxx. 39.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ring-streaked</ent><br/
<hw>Ring"-streaked`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having
circular streaks or lines on the body; <as>as, <ex>ring-streaked</ex>
goats</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ringtail</ent><br/
<hw>Ring"tail`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<fld>(Zool.)</fld> <def>A bird having a distinct band of color across
the tail, as the hen harrier.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Naut.)</fld> <def>A light sail set abaft and beyong
the leech of a boom-and-gaff sail; -- called also
<altname>ringsail</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Ringtail boom</b></col> <fld>(Naut.)</fld>, <cd>a spar
which is rigged on a boom for setting a ringtail.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ring-tailed</ent><br/
<hw>Ring"-tailed`</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Having the tail crossed by conspicuous bands of color.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Ring-tailed cat</b></col> <fld>(Zool.)</fld>, <cd>the
cacomixle.</cd> -- <col><b>Ring-tailed eagle</b></col>
<fld>(Zool.)</fld>, <cd>a young golden eagle.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ringtoss</ent><br/
<hw>Ring"toss`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A game in which the
object is to toss a ring so that it will catch upon an upright
stick.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ring winding</ent><br/
<hw>Ring winding</hw>. <fld>(Elec.)</fld> <def>Armature winding in which
the wire is wound round the outer and inner surfaces alternately of an
annular or cylindrical core.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Ringworm</ent><br/
<hw>Ring"worm"</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Med.)</fld> <def>A
contagious affection of the skin due to the presence of a vegetable
parasite, and forming ring-shaped discolored patches covered with
vesicles or powdery scales. It occurs either on the body, the face, or
the scalp. Different varieties are distinguished as <spn>Tinea
circinata</spn>, <spn>Tinea tonsurans</spn>, etc., but all are caused by
the same parasite (a species of <spn>Trichophyton</spn>).</def><-- a
fungal infection --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rink</ent><br/
<hw>Rink</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Scot. <ets>renk</ets>,
<ets>rink</ets>, <ets>rynk</ets>, a course, a race; probably fr. AS.
<ets>hring</ets> a ring. See <er>Ring</er>.]</ety> <sn>1.</sn> <def>The
smooth and level extent of ice marked off for the game of
curling.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An artificial sheet of ice, generally under cover,
used for skating; also, a floor prepared for skating on with roller
skates, or a building with such a floor.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rinker</ent><br/
<hw>Rink"er</hw>, <pos>n.</pos> <def>One who skates at a rink.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rinking</ent><br/
<hw>Rink"ing</hw>, <pos>n.</pos> <def>Skating in a rink.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rinse</ent><br/
<hw>Rinse</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Rinsed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Rinsing</conjf>.]</vmorph> <ety>[OE., fr. OF. <ets>rincer</ets>,
<ets>rimser</ets>, <ets>reinser</ets>, <ets>ra<ium/ncier</ets>, F.
<ets>rincer</ets>; of uncertain origin.]</ety> <sn>1.</sn> <def>To wash
lightly; to cleanse with a second or repeated application of water after
washing.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To cleancse by the introduction of water; -- applied
especially to hollow vessels; <as>as, to <ex>rinse</ex> a
bottle</as>.</def> <ldquo/Like a glass did break i' the
<xex>rinsing</xex>.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rinse</ent><br/
<hw>Rinse</hw>, <pos>n.</pos> <def>The act of rinsing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rinser</ent><br/
<hw>Rins"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, rinses.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1244 --></p>

<p><ent>Riot</ent><br/
<hw>Ri"ot</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF. <ets>riote</ets>,
of uncertain origin; cf. OD. <ets>revot</ets>, <ets>ravot</ets>.]</ety>
<sn>1.</sn> <def>Wanton or unrestrained behavior; uproar;
tumult.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His headstrong <qex>riot</qex> hath no curb.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Excessive and exxpensive feasting; wild and loose
festivity; revelry.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Venus loveth <qex>riot</qex> and dispense.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The lamb thy <qex>riot</qex> dooms to bleed to-day.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Law)</fld> <def>The tumultuous disturbance of the
public peace by an unlawful assembly of three or more persons in the
execution of some private object.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To run riot</b></col>, <cd>to act wantonly or without
restraint.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Riot</ent><br/
<hw>Ri"ot</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Rioted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Rioting</conjf>.]</vmorph> <ety>[OF. <ets>rioter</ets>; cf. OD.
<ets>ravotten</ets>.]</ety> <sn>1.</sn> <def>To engage in riot; to act
in an unrestrained or wanton manner; to indulge in excess of luxury,
feasting, or the like; to revel; to run riot; to go to excess.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Now he exact of all, wastes in delight,<br/
<qex>Riots</qex> in pleasure, and neglects the law.</q>
<rj><qau>Daniel.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>No pulse that <qex>riots</qex>, and no blood that glows.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>To disturb the peace; to raise an
uproar or sedition. See <er>Riot</er>, <pos>n.</pos>, 3.</def>
<rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Riot</ent><br/
<hw>Ri"ot</hw>, <pos>v. t.</pos> <def>To spend or pass in
riot.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>[He] had <qex>rioted</qex> his life out.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rioter</ent><br/
<hw>Ri"ot*er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who
riots; a reveler; a roisterer.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>One who engages in a riot. See
<er>Riot</er>, <pos>n.</pos>, 3.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Riotise</ent><br/
<hw>Ri"ot*ise</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Excess; tumult;
revelry.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>His life he led in lawless <qex>riotise</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Riotour</ent><br/
<hw>Ri"ot*our</hw> <pr>(-<oomac/r)</pr>, <pos>n.</pos> <def>A
rioter.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Riotous</ent><br/
<hw>Ri"ot*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OF.
<ets>rioteux</ets>.]</ety> <sn>1.</sn> <def>Involving, or engaging in,
riot; wanton; unrestrained; luxurious.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The younger son . . . took his journey into a far country, and
there wasted his substance with <qex>riotous</qex> living.</q>
<rj><qau>Luke xv. 13.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Partaking of the nature of an unlawful assembly or
its acts; seditious.</def><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Ri"ot*ous*ly</wf>, <pos>adv.</pos> --
<wf>Ri"ot*ous*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Riotry</ent><br/
<hw>Ri"ot*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act or practice
of rioting; riot.</def> <ldquo/Electioneering <xex>riotry</xex>.<rdquo/
<rj><au>Walpole.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rip</ent><br/
<hw>Rip</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. Icel. <ets>hrip</ets>
a box or basket; perhaps akin to E. <ets>corb</ets>. Cf.
<er>Ripier</er>.]</ety> <def>A wicker fish basket.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rip</ent><br/
<hw>Rip</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Ripped</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Ripping</conjf>.]</vmorph> <ety>[Cf. AS. <ets>r<ymac/pan</ets>,
also Sw. <ets>repa</ets> to ripple flax, D. <ets>repelen</ets>, G.
<ets>reffen</ets>, <ets>riffeln</ets>, and E. <ets>raff</ets>,
<ets>raffle</ets>. Cf. <er>Raff</er>, <er>Ripple</er> of flax.]</ety>
<sn>1.</sn> <def>To divide or separate the parts of, by cutting or
tearing; to tear or cut open or off; to tear off or out by violence;
<as>as, to <ex>rip</ex> a garment by cutting the stitches; to
<ex>rip</ex> off the skin of a beast; to <ex>rip</ex> up a floor</as>;
-- commonly used with <xex>up</xex>, <xex>open</xex>,
<xex>off</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To get by, or as by, cutting or tearing.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He 'll <qex>rip</qex> the fatal secret from her heart.</q>
<rj><qau>Granville.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To tear up for search or disclosure, or for
alteration; to search to the bottom; to discover; to disclose; --
usually with <xex>up</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They <qex>ripped</qex> up all that had been done from the
beginning of the rebellion.</q> <rj><qau>Clarendon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>For brethern to debate and <qex>rip</qex> up their falling out in
the ear of a common enemy . . . is neither wise nor comely.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To saw (wood) lengthwise of the grain or
fiber.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Ripping chisel</b></col> <fld>(Carp.)</fld>, <cd>a
crooked chisel for cleaning out mortises.</cd> <au>Knight.</au> --
<col><b>Ripping iron</b></col>. <fld>(Shipbuilding)</fld> <cd>Same as
<er>Ravehook</er>.</cd> -- <col><b>Ripping saw</b></col>.
<fld>(Carp.)</fld> <cd>See <er>Ripsaw</er>.</cd> -- <col><b>To rip
out</b></col>, <cd>to rap out, to utter hastily and violently; as,
<xex>to rip out</xex> an oath.</cd> <mark>[Colloq.]</mark> <see>See
<cref>To rap out</cref>, under <er>Rap</er>, <pos>v.
t.</pos></see></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rip</ent><br/
<hw>Rip</hw>, <pos>n.</pos> <sn>1.</sn> <def>A rent made by ripping,
esp. by a seam giving way; a tear; a place torn; laceration.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <ety>[Perh. a corruption of the first syllable of
<ets>rep</ets>robate.]</ety> <def>A term applied to a mean, worthless
thing or person, as to a scamp, a debauchee, or a prostitute, or a
worn-out horse.</def> <mark>[Slang.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A body of water made rough by the meeting of
opposing tides or currents.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Riparian</ent><br/
<hw>Ri*pa"ri*an</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>riparius</ets>, fr. <ets>ripa</ets> a bank. See <er>River</er>, and
cf. <er>Arrive</er>.]</ety> <def>Of or pertaining to the bank of a
river; <as>as, <ex>riparian</ex> rights</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Riparious</ent><br/
<hw>Ri*pa"ri*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>riparius</ets>.]</ety> <def>Growing along the banks of rivers;
riparian.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rip cord</ent><br/
<hw>Rip cord</hw>. <sn>1.</sn> <fld>(Aeronautics)</fld> <def>A cord by
which the gas bag of a balloon may be ripped open for a limited distance
to release the gas quickly and so cause immediate descent.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>a cord which, when pulled, opens a
parachute.</def><br/
[<source>PJC</source>]</p>

<p><ent>Ripe</ent><br/
<hw>Ripe</hw> <pr>(r<imac/p)</pr>, <pos>n.</pos> <ety>[L.
<ets>ripa</ets>.]</ety> <def>The bank of a river.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ripe</ent><br/
<hw>Ripe</hw> <pr>(r<imac/p)</pr>, <pos>a.</pos>
<amorph>[<pos>Compar.</pos> <adjf>Riper</adjf>
<pr>(r<imac/p"<etil/r)</pr>; <pos>superl.</pos>
<adjf>Ripest</adjf>.]</amorph> <ety>[AS. <ets>r<imac/pe</ets>; akin to
OS. <ets>r<imac/pi</ets>, D. <ets>rijp</ets>, G. <ets>rief</ets>, OHG.
<ets>r<imac/ft</ets>; cf. AS. <ets>r<imac/p</ets> harvest,
<ets>r<imac/pan</ets> to reap. Cf. <er>Reap</er>.]</ety> <sn>1.</sn>
<def>Ready for reaping or gathering; having attained perfection; mature;
-- said of fruits, seeds, etc.; <as>as, <ex>ripe</ex>
grain</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>So mayst thou live, till, like <qex>ripe</qex> fruit, thou
drop<br/
Into thy mother's lap.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Advanced to the state of fitness for use; mellow;
<as>as, <ex>ripe</ex> cheese; <ex>ripe</ex> wine.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Having attained its full development; mature;
perfected; consummate.</def> <ldquo/<xex>Ripe</xex> courage.<rdquo/
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He was a scholar, and a <qex>ripe</qex> and good one.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Maturated or suppurated; ready to discharge; -- said
of sores, tumors, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Ready for action or effect; prepared.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>While things were just <qex>ripe</qex> for a war.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I am not <qex>ripe</qex> to pass sentence on the gravest public
bodies.</q> <rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Like ripened fruit in ruddiness and
plumpness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Those happy smilets,<br/
That played on her <qex>ripe</qex> lip.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>Intoxicated.</def> <mark>[Obs.]</mark>
<ldquo/Reeling <xex>ripe</xex>.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Mature; complete; finished. See
<er>Mature</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ripe</ent><br/
<hw>Ripe</hw>, <pos>v. i.</pos> <ety>[AS. <ets>r<imac/pian</ets>.]</ety>
<def>To ripen; to grow ripe.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ripe</ent><br/
<hw>Ripe</hw>, <pos>v. t.</pos> <def>To mature; to ripen.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ripely</ent><br/
<hw>Ripe"ly</hw>, <pos>adv.</pos> <def>Maturely; at the fit time.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ripen</ent><br/
<hw>Rip"en</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Ripened</conjf> <pr>(?)</pr>;<pos>p. pr. & vb. n.</pos>
<conjf>Ripening</conjf>.]</vmorph> <sn>1.</sn> <def>To grow ripe; to
become mature, as grain, fruit, flowers, and the like; <as>as, grapes
<ex>ripen</ex> in the sun</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To approach or come to perfection.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ripen</ent><br/
<hw>Rip"en</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To cause to mature;
to make ripe; <as>as, the warm days <ex>ripened</ex> the
corn</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To mature; to fit or prepare; to bring to
perfection; <as>as, to <ex>ripen</ex> the judgment</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>When faith and love, which parted from thee never,<br/
Had <qex>ripined</qex> thy iust soul to dwell with God.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ripeness</ent><br/
<hw>Ripe"ness</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS.
<ets>r<imac/pness</ets>.]</ety> <def>The state or quality of being ripe;
maturity;; completeness; perfection; <as>as, the <ex>ripeness</ex> of
grain; <ex>ripeness</ex> of manhood; <ex>ripeness</ex> of
judgment.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Time, which made them their fame outlive,<br/
To Cowley scarce did <qex>ripeness</qex> give.</q>
<rj><qau>Denham.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ripidolite</ent><br/
<hw>Ri*pid"o*lite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/<?/<?/.
<?/<?/<?/. fan + <ets>-lite</ets>.]</ety> <fld>(Min.)</fld> <def>A
translucent mineral of a green color and micaceous structure, belonging
to the chlorite group; a hydrous silicate of alumina, magnesia, and
iron; -- called also <altname>clinochlore</altname>.</def> <-- sic. note
use of "alumina", not "aluminia". Spelling must have been changing about
1890 --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ripienist</ent><br/
<hw>Ri*pi*e"nist</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Mus.)</fld>
<def>A player in the <xex>ripieno</xex> portion of an orchestra. See
<er>Ripieno</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ripieno</ent><br/
\'d8<hw>Ri*pi*e"no</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[It.]</ety>
<fld>(Mus.)</fld> <def>Filling up; supplementary; supernumerary; -- a
term applied to those instruments which only swell the mass or
<xex>tutti</xex> of an orchestra, but are not obbligato.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ripper</ent><br/
<ent>Ripler</ent><br/
<mhw>{ <hw>Rip"ler</hw> <pr>(?)</pr>, <hw>Rip"per</hw> <pr>(?)</pr>,
}</mhw> <pos>n.</pos> <ety>[Cf. <er>Rip</er> a basket, or
<er>Riparian</er>.]</ety> <fld>(O.E. Law)</fld> <def>One who brings fish
from the seacoast to markets in inland towns.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>But what's the action we are for now ?<br/
Robbing a <qex>ripper</qex> of his fish.</q> <rj><qau>Beau. &
Fl.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Riposte</ent><br/
<ent>Ripost</ent><br/
<mhw><hw>Ri*post"</hw>, <hw>Ri*poste"</hw></mhw> <pr>(?)</pr>,
<pos>n.</pos> <ety>[F. <ets>riposte</ets>.]</ety> <sn>1.</sn> <def>In
fencing, a return thrust after a parry.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A quick and sharp refort; a repartee.</def>
<rj><au>J. Morley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ripper</ent><br/
<hw>Rip"per</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who,
or that which, rips; a ripping tool.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A tool for trimming the edges of roofing
slates.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Anything huge, extreme, startling, etc.</def>
<mark>[Slang.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ripper bill</ent><br/
<ent>Ripper act</ent><br/
<mhw>{ <hw>Rip"per act</hw> <it>or</it> <hw>Rip"per bill</hw> }</mhw>.
<def>An act or a bill conferring upon a chief executive, as a governor
or mayor, large powers of appointment and removal of heads of
departments or other subordinate officials.</def> <mark>[Polit. Cant, U.
S.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Ripping cord</ent><br/
<hw>Rip"ping cord</hw>. <fld>(Aeronautics)</fld> <def>same as <er>Rip
cord</er>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Ripping panel</ent><br/
<hw>Ripping panel</hw>. <fld>(Aeronautics)</fld> <def>A long patch, on a
balloon, to be ripped off, by the <er>rip cord</er>, at landing, in
order to allow the immediate escape of gas and instant deflation of the
bag.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Ripping strip</ent><br/
<hw>Ripping strip</hw>. <def>same as <er>Ripping panel</er>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Ripple</ent><br/
<hw>Rip"ple</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From <er>Rip</er>,
<pos>v.</pos>]</ety> <def>An implement, with teeth like those of a comb,
for removing the seeds and seed vessels from flax, broom corn,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ripple</ent><br/
<hw>Rip"ple</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To remove the seeds
from (the stalks of flax, etc.), by means of a ripple.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence, to scratch or tear.</def>
<rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ripple</ent><br/
<hw>Rip"ple</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Rippled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Rippling</conjf> <pr>(?)</pr>.]</vmorph> <ety>[Cf.
<er>Rimple</er>, <er>Rumple</er>.]</ety> <sn>1.</sn> <def>To become
fretted or dimpled on the surface, as water when agitated or running
over a rough bottom; to be covered with small waves or undulations, as a
field of grain.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To make a sound as of water running gently over a
rough bottom, or the breaking of ripples on the shore.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ripple</ent><br/
<hw>Rip"ple</hw>, <pos>v. t.</pos> <def>To fret or dimple, as the
surface of running water; to cover with small waves or undulations;
<as>as, the breeze <ex>rippled</ex> the lake</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ripple</ent><br/
<hw>Rip"ple</hw>, <pos>n.</pos> <sn>1.</sn> <def>The fretting or
dimpling of the surface, as of running water; little curling
waves.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A little wave or undulation; a sound such as is made
by little waves; <as>as, a <ex>ripple</ex> of laughter</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Ripple grass</b></col>. <fld>(Bot.)</fld> <cd>See
<er>Ribwort</er>.</cd> -- <col><b>Ripple marks</b></col>, <cd>a system
of parallel ridges on sand, produced by wind, by the current of a steam,
or by the agitation of wind waves; also <fld>(Geol.)</fld>, a system of
parallel ridges on the surface of a sandstone stratum.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ripple-marked</ent><br/
<hw>Rip"ple-marked`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having ripple
marks.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ripplet</ent><br/
<hw>Rip"plet</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A small
ripple.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ripplingly</ent><br/
<hw>Rip"pling*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a rippling
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ripply</ent><br/
<hw>Rip"ply</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having ripples;
<as>as, <ex>ripply</ex> water</as>; hence, resembling the sound of
rippling water; <as>as, <ex>ripply</ex> laughter; a <ex>ripply</ex>
cove.</as></def> <rj><au>Keats.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Riprap</ent><br/
<hw>Rip"rap`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf.
<er>Rap</er>.]</ety> <fld>(Masonry)</fld> <def>A foundation or
sustaining wall of stones thrown together without order, as in deep
water or on a soft bottom, or in a river channel.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Riprap</ent><br/
<hw>Rip"rap`</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Riprapped</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Riprapping</conjf>.]</vmorph> <def>To form a riprap in or
<xex>upon</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ripsaw</ent><br/
<hw>Rip"saw`</hw> <pr>(?)</pr>, <ety>[See <er>Rip</er>, <pos>v.
t.</pos>, 4.]</ety> <fld>(Carp.)</fld> <def>A handsaw with coarse teeth
which have but a slight set, used for cutting wood in the direction of
the grain (the fiber); -- called also <altname>ripping
saw</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Riptowel</ent><br/
<hw>Rip"tow*el</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS.
<ets>r<imac/p</ets>. harvest + a word of uncertain etymology.]</ety>
<fld>(Feud. Law)</fld> <def>A gratuity given to tenants after they had
reaped their lord's corn.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ris</ent><br/
<hw>Ris</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS. <ets>hr<imac/s</ets>;
akin to D. <ets>rils</ets>, G. <ets>reis</ets>, OHG.
<ets>hr<imac/s</ets>.]</ety> <def>A bough or branch; a twig.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>As white as is the blossom upon the <qex>ris</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rise</ent><br/
<hw>Rise</hw> <pr>(r<imac/z)</pr>, <pos>v. i.</pos>
<vmorph>[<pos>imp.</pos> <conjf>Rose</conjf> <pr>(r<omac/z)</pr>;
<pos>p. p.</pos> <conjf>Risen</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Rising</conjf>.]</vmorph> <ety>[AS.
<ets>r<imac/san</ets>; akin to OS. <ets>r<imac/san</ets>, D.
<ets>rijzen</ets>, OHG. <ets>r<imac/san</ets> to rise, fall, Icel.
<ets>r<imac/sa</ets>, Goth. ur<ets>reisan</ets>, G. <ets>reise</ets>
journey. CF. <er>Arise</er>, <er>Raise</er>, <er>Rear</er>,
<pos>v.</pos>]</ety> <sn>1.</sn> <def>To move from a lower position to a
higher; to ascend; to mount up. Specifically: -- <sd>(a)</sd> To go
upward by walking, climbing, flying, or any other voluntary motion;
<as>as, a bird <ex>rises</ex> in the air; a fish <ex>rises</ex> to the
bait</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sd>(b)</sd> <def>To ascend or float in a fluid, as gases or vapors
in air, cork in water, and the like.</def><br/
[<source>1913 Webster</source>]</p>

<p><sd>(c)</sd> <def>To move upward under the influence of a projecting
force; <as>as, a bullet <ex>rises</ex> in the air</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sd>(d)</sd> <def>To grow upward; to attain a certain height; <as>as,
this elm <ex>rises</ex> to the height of seventy feet</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sd>(e)</sd> <def>To reach a higher level by increase of quantity or
bulk; to swell; <as>as, a river <ex>rises</ex> in its bed; the mercury
<ex>rises</ex> in the thermometer</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sd>(f)</sd> <def>To become erect; to assume an upright position;
<as>as, to <ex>rise</ex> from a chair or from a fall</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sd>(g)</sd> <def>To leave one's bed; to arise; <as>as, to
<ex>rise</ex> early</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He that would thrive, must <qex>rise</qex> by five.</q>
<rj><qau>Old Proverb.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(h)</sd> <def>To tower up; to be heaved up; <as>as, the Alps
<ex>rise</ex> far above the sea</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sd>(i)</sd> <def>To slope upward; as, a path, a line, or surface
<xex>rises</xex> in this direction.</def> <ldquo/A <xex>rising</xex>
ground.<rdquo/ <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(j)</sd> <def>To retire; to give up a siege.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He, <qex>rising</qex> with small honor from Gunza, . . . was
gone.</q> <rj><qau>Knolles.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(k)</sd> <def>To swell or puff up in the process of fermentation;
to become light, as dough, and the like.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To have the aspect or the effect of rising.</def>
Specifically: --<br/
[<source>1913 Webster</source>]</p>

<p><sd>(a)</sd> <def>To appear above the horizont, as the sun, moon,
stars, and the like.</def> <ldquo/He maketh his sun to <xex>rise</xex>
on the evil and the good.<rdquo/ <rj><au>Matt. v. 45.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(b)</sd> <def>To become apparent; to emerge into sight; to come
forth; to appear; <as>as, an eruption <ex>rises</ex> on the skin; the
land <ex>rises</ex> to view to one sailing toward the
shore</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sd>(c)</sd> <def>To become perceptible to other senses than sight;
<as>as, a noise <ex>rose</ex> on the air; odor <ex>rises</ex> from the
flower</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sd>(d)</sd> <def>To have a beginning; to proceed; to originate;
<as>as, rivers <ex>rise</ex> in lakes or springs</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A scepter shall <qex>rise</qex> out of Israel.</q> <rj><qau>Num.
xxiv. 17.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Honor and shame from no condition <qex>rise</qex>.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To increase in size, force, or value; to proceed
toward a climax.</def> Specifically: --<br/
[<source>1913 Webster</source>]</p>

<p><sd>(a)</sd> <def>To increase in power or fury; -- said of wind or a
storm, and hence, of passion.</def> <ldquo/High winde . . . began to
<xex>rise</xex>, high passions -- anger, hate.<rdquo/
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(b)</sd> <def>To become of higher value; to increase in
price.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Bullion is <qex>risen</qex> to six shillings . . . the ounce.</q>
<rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(c)</sd> <def>To become larger; to swell; -- said of a boil,
tumor, and the like.</def><br/
[<source>1913 Webster</source>]</p>

<p><sd>(d)</sd> <def>To increase in intensity; -- said of
heat.</def><br/
[<source>1913 Webster</source>]</p>

<p><sd>(e)</sd> <def>To become louder, or higher in pitch, as the
voice.</def><br/
[<source>1913 Webster</source>]</p>

<p><sd>(f)</sd> <def>To increase in amount; to enlarge; <as>as, his
expenses <ex>rose</ex> beyond his expectations</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>In various figurative senses.</def> Specifically:
--<br/
[<source>1913 Webster</source>]</p>

<p><sd>(a)</sd> <def>To become excited, opposed, or hostile; to go to
war; to take up arms; to rebel.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>At our heels all hell should <qex>rise</qex><br/
With blackest insurrection.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>No more shall nation against nation <qex>rise</qex>.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(b)</sd> <def>To attain to a better social position; to be
promoted; to excel; to succeed.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Some <qex>rise</qex> by sin, and some by virtue fall.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(c)</sd> <def>To become more and more dignified or forcible; to
increase in interest or power; -- said of style, thought, or discourse;
<as>as, to <ex>rise</ex> in force of expression; to <ex>rise</ex> in
eloquence; a story <ex>rises</ex> in interest</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sd>(d)</sd> <def>To come to mind; to be suggested; to
occur.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A thought <qex>rose</qex> in me, which often perplexes men of
contemplative natures.</q> <rj><qau>Spectator.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(e)</sd> <def>To come; to offer itself.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There chanced to the prince's hand to <qex>rise</qex><br/
<qex>An ancient book</qex>.</q> <rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To ascend from the grave; to come to life.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>But now is Christ <qex>risen</qex> from the dead.</q> <rj><qau>1.
Cor. xv. 20.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To terminate an official sitting; to adjourn;
<as>as, the committee <ex>rose</ex> after agreeing to the
report</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It was near nine . . . before the House <qex>rose</qex>.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>To ascend on a musical scale; to take a higher pith;
<as>as, to <ex>rise</ex> a tone or semitone</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <fld>(Print.)</fld> <def>To be lifted, or to admit of
being lifted, from the imposing stone without dropping any of the type;
-- said of a form.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To arise; mount; ascend; climb; scale.</syn>
<usage> -- <er>Rise</er>, <er>Appreciate</er>. Some in America use the
word <xex>appreciate</xex> for <ldquo/rise in value;<rdquo/ as, stocks
<xex>appreciate</xex>, money <xex>appreciates</xex>, etc. This use is
not unknown in England, but it is less common there. It is undesirable,
because <xex>rise</xex> sufficiently expresses the idea, and
<xex>appreciate</xex> has its own distinctive meaning, which ought not
to be confused with one so entirely different.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rise</ent><br/
<hw>Rise</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The act of
rising, or the state of being risen.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The distance through which anything rises; <as>as,
the <ex>rise</ex> of the thermometer was ten degrees; the <ex>rise</ex>
of the river was six feet; the <ex>rise</ex> of an arch or of a
step</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Land which is somewhat higher than the rest; <as>as,
the house stood on a <ex>rise</ex> of land</as>.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Spring; source; origin; <as>as, the <ex>rise</ex> of
a stream</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>All wickednes taketh its <qex>rise</qex> from the heart.</q>
<rj><qau>R. Nelson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Appearance above the horizon; <as>as, the
<ex>rise</ex> of the sun or of a planet</as>.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Increase; advance; augmentation, as of price, value,
rank, property, fame, and the like.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>rise</qex> or fall that may happen in his constant
revenue by a Spanish war.</q> <rj><qau>Sir W. Temple.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>Increase of sound; a swelling of the
voice.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The ordinary <qex>rises</qex> and falls of the voice.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>Elevation or ascent of the voice; upward change of
key; <as>as, a <ex>rise</ex> of a tone or semitone</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>The spring of a fish to seize food (as a fly) near
the surface of the water.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rise</ent><br/
<hw>Rise</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[See <er>Rise</er>,
<pos>v. i.</pos>]</ety> <sn>1.</sn> <def>To go up; to ascend; to climb;
<as>as, to <ex>rise</ex> a hill</as>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>To cause to rise; <as>as, to <ex>rise</ex> a fish,
or cause it to come to the surface of the water; to <ex>rise</ex> a
ship, or bring it above the horizon by approaching it; to
raise</as>.</def></p>

<p><q>Until we <qex>rose</qex> the bark we could not pretend to call it
a chase.</q> <rj><qau>W. C. Russell.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Risen</ent><br/
<hw>Ris"en</hw> <pr>(?)</pr>. <sn>1.</sn> <def><pos>p. p. & a.</pos>
from <er>Rise</er>.</def> <ldquo/Her <xex>risen</xex> Son and
Lord.<rdquo/ <rj><au>Keble.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <mark>(Obs.)</mark> <def><pos>imp. pl.</pos> of
<er>Rise</er>.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Riser</ent><br/
<hw>Ris"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who
rises; <as>as, an early <ex>riser</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Arch.)</fld> <sd>(a)</sd> <def>The upright piece of
a step, from tread to tread.</def> <specif>Hence:</specif> <sd>(b)</sd>
<def>Any small upright face, as of a seat, platform, veranda, or the
like.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Mining)</fld> <def>A shaft excavated from below
upward.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Founding)</fld> <def>A feed head. See under
<er>Feed</er>, <pos>n.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rish</ent><br/
<hw>Rish</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A rush (the plant).</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Risibility</ent><br/
<hw>Ris`i*bil"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[CF. F.
<ets>risibilit<eacute/</ets>.]</ety> <def>The quality of being risible;
<as>as, <ex>risibility</ex> is peculiar to the human
species</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A strong and obvious disposition to <qex>risibility</qex>.</q>
<rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Risible</ent><br/
<hw>Ris"i*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F., fr. L.
<ets>risibilis</ets>, fr. <ets>ridere</ets>, <ets>risum</ets>, to laugh.
Cf. <er>Ridiculous</er>.]</ety> <sn>1.</sn> <def>Having the faculty or
power of laughing; disposed to laugh.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Laughing is our busines, . . . it has been made the definition of
man that he is <qex>risible</qex>.</q> <rj><qau>Dr. H.
More.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Exciting laughter; worthy to be laughed at;
amusing.</def> <ldquo/<xex>Risible</xex> absurdities.<rdquo/
<rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I hope you find nothing <qex>risible</qex> in my complaisance.</q>
<rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Used in, or expressing, laughter; <as>as,
<ex>risible</ex> muscles</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Risible</xex> is sometimes used as a noun, in the
plural, for the feeling of amusement and for the muscles and other
organs used in laughing, collectively; as, unable to control one's
<xex>risibles</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Ludicrous; laughable; amusing; ridiculous --
<er>Risible</er>, <er>Ludicrous</er>, <er>Ridiculous</er>.</syn> <usage>
<xex>Risible</xex> differs from <xex>ludicrous</xex> as species from
genus; <xex>ludicrous</xex> expressing that which is playful and
sportive; <xex>risible</xex>, that which may excite laughter.
<xex>Risible</xex> differs from <xex>ridiculous</xex>, as the latter
implies something contemptuous, and <xex>risible</xex> does
not.</usage><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1245 --></p>

<p>--<wordforms><wf>Ris"i*ble*ness</wf><pr>(#)</pr>, <pos>n.</pos> --
<wf>Ris"i*bly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rising</ent><br/
<hw>Ris"ing</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Attaining
a higher place; taking, or moving in, an upward direction; appearing
above the horizon; ascending; <as>as, the <ex>rising</ex>
moon</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Increasing in wealth, power, or distinction; <as>as,
a <ex>rising</ex> state; a <ex>rising</ex> character.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Among the <qex>rising</qex> theologians of Germany.</q>
<rj><qau>Hare.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Growing; advancing to adult years and to the state
of active life; <as>as, the <ex>rising</ex> generation</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rising</ent><br/
<hw>Ris"ing</hw>, <pos>prep.</pos> <def>More than; exceeding; upwards
of; <as>as, a horse <ex>rising</ex> six years of age</as>.</def>
<mark>[Colloq. & Low, U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rising</ent><br/
<hw>Ris"ing</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act of one who, or
that which, rises (in any sense).</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which rises; a tumor; a boil.</def>
<rj><au>Lev. xiii. 10.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Rising main</b></col> <fld>(Waterworks)</fld>, <cd>the
pipe through which water from an engine is delivered to an elevated
reservoir.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Risk</ent><br/
<hw>Risk</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>risque</ets>;
cf. It. <ets>risco</ets>, <ets>risico</ets>, <ets>rischio</ets>, Pg.
<ets>risco</ets>, Sp. <ets>riesgo</ets>, and also Sp. <ets>risco</ets> a
steep rock; all probably fr. L. <ets>resceare</ets> to cut off; pref.
<ets>re-</ets> re- + <ets>secare</ets> to cut; -- the word having been
probably first used among sailors. See <er>Section</er>.]</ety>
<sn>1.</sn> <def>Hazard; danger; peril; exposure to loss, injury, or
destruction.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The imminent and constant <qex>risk</qex> of assassination, a
<qex>risk</qex> which has shaken very strong nerves.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Com.)</fld> <def>Hazard of loss; liabillity to loss
in property.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To run a risk</b></col>, <cd>to incur hazard; to
encounter danger.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Danger; hazard; peril; jeopardy; exposure. See
<er>Danger</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Risk</ent><br/
<hw>Risk</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Risked</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Risking</conjf>.]</vmorph> <ety>[CF. F. <ets>risquer</ets>. See
<er>Risk</er>, <pos>n.</pos>]</ety> <sn>1.</sn> <def>To expose to risk,
hazard, or peril; to venture; <as>as, to <ex>risk</ex> goods on board of
a ship; to <ex>risk</ex> one's person in battle; to <ex>risk</ex> one's
fame by a publication</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To incur the risk or danger of; <as>as, to
<ex>risk</ex> a battle</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To hazard; peril; endanger; jeopard.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Risker</ent><br/
<hw>Risk"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who risks or
hazards.</def> <rj><au>Hudibras.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Riskful</ent><br/
<hw>Risk"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Risky.</def>
<mark>[R.]</mark> <rj><au>Geddes.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Risky</ent><br/
<hw>Risk"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Attended with risk or
danger; hazardous.</def> <ldquo/A <xex>risky</xex> matter.<rdquo/
<rj><au>W. Collins.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Generalization are always <qex>risky</qex>.</q>
<rj><qau>Lowell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Risorial</ent><br/
<hw>Ri*so"ri*al</hw> <pr>(?)</pr>, <pos>a.</pos><ety>[L.
<ets>ridere</ets>, <ets>risum</ets>, to laugh.]</ety> <def>Pertaining
to, or producing, laughter; <as>as, the <ex>risorial</ex>
muscles</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Risotto</ent><br/
\'d8<hw>Ri*sot"to</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[It.]</ety>
<def>A kind of pottage.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Risquee</ent><br/
<ent>Risque</ent><br/
<mhw>{ \'d8<hw>Ris`qu<eacute/"</hw>, <pos>a. masc.</pos>,
\'d8<hw>Ris`qu<eacute/e"</hw>, <pos>a. fem.</pos> }</mhw>,
<pr>(r<esl/s`k<asl/")</pr>. <ety>[F., p.p. of <ets>risquer</ets> to
risk.]</ety> <def>Hazardous; risky; esp., fig., verging upon
impropriety; dangerously close to, or suggestive of, what is indecent or
of doubtful morality; <as>as, a <ex>risqu<eacute/</ex> story</as>.</def>
<rj><au>Henry Austin.</au></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Risse</ent><br/
<hw>Risse</hw> <pr>(?)</pr>, <mark>obs.</mark> <def><pos>imp.</pos> of
<er>Rise</er>.</def> <rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rissoid</ent><br/
<hw>Ris"soid</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL.
<ets>Rissoa</ets>, the typical genus ( fr. A. <ets>Risso</ets>, an
Italian naturalist) + <ets>-oid</ets>.]</ety> <fld>(Zool.)</fld>
<def>Any one of very numerous species of small spiral gastropods of the
genus <gen>Rissoa</gen>, or family <fam>Rissoidae</fam>, found both in
fresh and salt water.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rissole</ent><br/
\'d8<hw>Ris`sole"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr.
<ets>rissoler</ets> to fry meat till it is brown.]</ety>
<fld>(Cookery)</fld> <def>A small ball of rich minced meat or fish,
covered with pastry and fried.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rist</ent><br/
<hw>Rist</hw> <pr>(?)</pr>, <mark>obs.</mark> <def><pos>3d pers. sing.
pres.</pos> of <er>Rise</er>, contracted from <xex>riseth</xex>.</def>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rit</ent><br/
<hw>Rit</hw> <pr>(?)</pr>, <mark>obs.</mark> <def><pos>3d pers. sing.
pres.</pos> of <er>Ride</er>, contracted from <xex>rideth</xex>.</def>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ritardando</ent><br/
\'d8<hw>Ri`tar*dan"do</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[It.]</ety>
<fld>(Mus.)</fld> <def>Retarding; -- a direction for slower time;
rallentado.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rite</ent><br/
<hw>Rite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>ritus</ets>; cf.
Skr. <ets>r<imac/ti</ets> a stream, a running, way, manner,
<ets>ri</ets> to flow: cf. F. <ets>rit</ets>, <ets>rite</ets>. CF.
<er>Rivulet</er>.]</ety> <def>The act of performing divine or solemn
service, as established by law, precept, or custom; a formal act of
religion or other solemn duty; a solemn observance; a ceremony; <as>as,
the <ex>rites</ex> of freemasonry</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He looked with indifference on <qex>rites</qex>, names, and forms
of ecclesiastical polity.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Form; ceremony; observance; ordinance.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ritenuto</ent><br/
\'d8<hw>Ri`te*nu"to</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[It.]</ety>
<fld>(Mus.)</fld> <def>Held back; holding back; ritardando.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ritornello</ent><br/
<ent>Ritornelle</ent><br/
<mhw>{ <hw>Rit`or*nelle"</hw> <pr>(?)</pr>, \'d8<hw>Ri`tor*nel"lo</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[It. <ets>ritornello</ets>,
dim. of <ets>ritorno</ets> return, fr. <ets>ritornare</ets> to return:
cf. F. <ets>ritournelle</ets>.]</ety> <fld>(Mus.)</fld> <sd>(a)</sd>
<def>A short return or repetition; a concluding symphony to an air,
often consisting of the burden of the song.</def> <sd>(a)</sd> <def>A
short intermediate symphony, or instrumental passage, in the course of a
vocal piece; an interlude.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ritratto</ent><br/
\'d8<hw>Ri*trat"to</hw> <pr>(?)</pr>, <pos>n.</pos><ety>[It.]</ety>
<def>A picture.</def> <rj><au>Sterne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ritual</ent><br/
<hw>Rit"u*al</hw> <pr>(?)</pr>, <pos>a.</pos><ety>[L.
<ets>ritualis</ets>, fr. <ets>ritus</ets> a rite: cf. F.
<ets>rituel</ets>.]</ety> <def>Of or pertaining to rites or ritual;
<as>as, <ex>ritual</ex> service or sacrifices; the <ex>ritual</ex>
law.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ritual</ent><br/
<hw>Rit"u*al</hw>, <pos>n.</pos> <ety>[Cf. F. <ets>rituel</ets>.]</ety>
<sn>1.</sn> <def>A prescribed form of performing divine service in a
particular church or communion; <as>as, the Jewish
<ex>ritual</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence, the code of ceremonies observed by an
organization; <as>as, the <ex>ritual</ex> of the
freemasons</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A book containing the rites to be
observed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ritualism</ent><br/
<hw>Rit"u*al*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>ritualisme</ets>.]</ety> <sn>1.</sn> <def>A system founded upon a
ritual or prescribed form of religious worship; adherence to, or
observance of, a ritual.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Specifically :<sd>(a)</sd> The principles and
practices of those in the Church of England, who in the development of
the Oxford movement, so-called, have insisted upon a return to the use
in church services of the symbolic ornaments (altar cloths, encharistic
vestments, candles, etc.) that were sanctioned in the second year of
Edward VI., and never, as they maintain, forbidden by competennt
authority, although generally disused. <xex>Schaff-Herzog Encyc</xex>.
<sd>(b)</sd> Also, the principles and practices of those in the
Protestant Episcopal Church who sympathize with this party in the Church
of England.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ritualist</ent><br/
<hw>Rit"u*al*ist</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[CF. F.
<ets>ritualiste</ets>.]</ety> <def>One skilled un, or attached to, a
ritual; one who advocates or practices ritualism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ritualistic</ent><br/
<hw>Rit`u*al*is"tic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to,
or in accordance with, a ritual; adhering to ritualism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ritually</ent><br/
<hw>Rit"u*al*ly</hw>, <pos>adv.</pos> <def>By rites, or by a particular
rite.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rivage</ent><br/
<hw>Riv"age</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr. L.
<ets>ripa</ets> bank, shore.]</ety> <sn>1.</sn> <def>A bank, shore, or
coast.</def> <mark>[Archaic]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>From the green <qex>rivage</qex> many a fall<br/
Of diamond rillets musical.</q> <rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(O.Eng.Law)</fld> <def>A duty paid to the crown for
the passage of vessels on certain rivers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rival</ent><br/
<hw>Ri"val</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>rival</ets>
(cf. It. <ets>rivale</ets>), L. <ets>rivales</ets> two neigbors having
the same brook in common, rivals, fr. <ets>rivalis</ets> belonging to a
brook, fr. <ets>rivus</ets> a brook. Cf. <er>Rivulet</er>,
<er>Rete</er>.]</ety> <sn>1.</sn> <def>A person having a common right or
privilege with another; a partner.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>If you do meet Horatio and Marcellus,<br/
The <qex>rivals</qex> of my watch, bid them make haste.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who is in pursuit of the same object as another;
one striving to reach or obtain something which another is attempting to
obtain, and which one only can posses; a competitor; <as>as,
<ex>rivals</ex> in love; <ex>rivals</ex> for a crown.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <ldquo/<xex>Rivals</xex>, in the primary sense of the
word, are those who dwell on the banks of the same stream. But since, as
all experience shows, there is no such fruitful source of coutention as
a water right, it would continually happen that these occupants of the
opposite banks would be at strife with one another in regard of the
periods during which they severally had a right to the use of the stream
. . . And thus <xex>'rivals'</xex> . . . came to be used of any who were
on any grounds in more or less unfriendly competition with one
another.<rdquo/</note> <rj><au>Trench.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Competitor; emulator; antagonist.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rival</ent><br/
<hw>Ri"val</hw>, <pos>a.</pos> <def>Having the same pretensions or
claims; standing in competition for superiority; <as>as, rival lovers;
<ex>rival</ex> claims or pretensions.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>The strenuous conflicts and alternate victories of two
<qex>rival</qex> confederacies of statesmen.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rival</ent><br/
<hw>Ri"val</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Rivaled</conjf> <pr>(?)</pr> or <conjf>Rivalled</conjf>; <pos>p.
pr. & vb. n.</pos> <conjf>Rivaling</conjf> or
<conjf>Rivalling</conjf>.]</vmorph> <sn>1.</sn> <def>To stand in
competition with; to strive to gain some object in opposition to;
<as>as, to <ex>rival</ex> one in love</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To strive to equal or exel; to emulate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>rival</qex> thunder in its rapid course.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rival</ent><br/
<hw>Ri"val</hw>, <pos>v. i.</pos> <def>To be in rivalry.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rivaless</ent><br/
<hw>Ri"val*ess</hw>, <pos>n.</pos> <def>A female rival.</def>
<mark>[Obs.]</mark> <rj><au>Richardson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rivality</ent><br/
<hw>Ri*val"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>rivalitas</ets>: cf. F. <ets>rivalit<eacute/</ets>.]</ety>
<sn>1.</sn> <def>Rivalry; competition.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Equality, as of right or rank.</def>
<mark>[Obs.]</mark> <rj><au>hak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rivalry</ent><br/
<hw>Ri"val*ry</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Rivalries</plw> <pr>(<?/)</pr>.</plu> <def>The act of rivaling, or
the state of being a rival; a competition.</def> <ldquo/Keen contention
and eager <xex>rivalries</xex>.<rdquo/ <rj><au>Jeffrey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Emulation; competition. See
<er>Emulation</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rivalship</ent><br/
<hw>Ri"val*ship</hw>, <pos>n.</pos> <def>Rivalry.</def>
<mark>[R.]</mark> <rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rive</ent><br/
<hw>Rive</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.</pos>
<conjf>Rived</conjf> <pr>(?)</pr>; <pos>p. p.</pos> <conjf>Rived</conjf>
or <conjf>Riven</conjf> <pr>(<?/)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Riving</conjf>.]</vmorph> <ety>[Icel. <ets>r<imac/fa</ets>, akin
to Sw. <ets>rifva</ets> to pull asunder, burst, tear, Dan.
<ets>rive</ets> to rake, pluck, tear. Cf. <er>Reef</er> of land,
<er>Rifle</er> a gun, <er>Rift</er>, <er>Rivel</er>.]</ety> <def>To rend
asunder by force; to split; to cleave; <as>as, to <ex>rive</ex> timber
for rails or shingles</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I shall <qex>ryve</qex> him through the sides twain.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The scolding winds have <qex>rived</qex> the knotty oaks.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Brutus hath <qex>rived</qex> my heart.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rive</ent><br/
<hw>Rive</hw>, <pos>v. i.</pos> <def>To be split or rent
asunder.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Freestone <qex>rives</qex>, splits, and breaks in any
direction.</q> <rj><qau>Woodward.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rive</ent><br/
<hw>Rive</hw>, <pos>n.</pos> <def>A place torn; a rent; a rift.</def>
<mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rivel</ent><br/
<hw>Riv"el</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Riveled</conjf> <pr>(?)</pr>;<pos>p. pr. & vb. n.</pos>
<conjf>Riveling</conjf>.]</vmorph> <ety>[AS. <ets>gerifled</ets>,
<ets>geriflod</ets>, <ets>gerifod</ets>, wrinkled, <ets>geriflian</ets>,
<ets>gerifian</ets>, to wrinkle. See <er>Rifle</er> a gun,
<er>Rive</er>.]</ety> <def>To contract into wrinkles; to shrivel; to
shrink; <as>as, <ex>riveled</ex> fruit; <ex>riveled</ex>
flowers</as>.</def> <mark>[Obs.]</mark> <au>Pope.</au>
<ldquo/<xex>Riveled</xex> parchments.<rdquo/ <au>Walpole.</au><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rivel</ent><br/
<hw>Riv"el</hw>, <pos>n.</pos> <def>A wrinkle; a rimple.</def>
<mark>[Obs.]</mark> <rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Riven</ent><br/
<hw>Riv"en</hw> <pr>(?)</pr>, <def><pos>p. p. & a.</pos> from
<er>Rive</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>River</ent><br/
<hw>Riv"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who rives or
splits.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>River</ent><br/
<hw>Riv"er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>riv<egrave/re</ets> a river, LL. <ets>riparia</ets> river, bank of
a river, fr. L. <ets>riparius</ets> belonging to a bank or shore, fr.
<ets>ripa</ets> a bank or shore; of uncertain origin. Cf.
<er>Arrive</er>, <er>Riparian</er>.]</ety> <sn>1.</sn> <def>A large
stream of water flowing in a bed or channel and emptying into the ocean,
a sea, a lake, or another stream; a stream larger than a rivulet or
brook.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Transparent and sparkling <qex>rivers</qex>, from which it is
delightful to drink as they flow.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Fig.: A large stream; copious flow; abundance;
<as>as, <ex>rivers</ex> of blood; <ex>rivers</ex> of oil</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>River chub</b></col> <fld>(Zool.)</fld>, <cd>the
hornyhead and allied species of fresh-water fishes.</cd> --
<col><b>River crab</b></col> <fld>(Zool.)</fld>, <cd>any species of
fresh-water crabs of the genus <gen>Thelphusa</gen>, as <spn>Thelphusa
depressa</spn> of Southern Europe.</cd> -- <col><b>River
dragon</b></col>, <cd>a crocodile; -- applied by Milton to the king of
Egypt.</cd> -- <col><b>River driver</b></col>, <cd>a lumberman who
drives or conducts logs down rivers.</cd> <au>Bartlett.</au> --
<col><b>River duck</b></col> <fld>(Zool.)</fld>, <cd>any species of duck
belonging to <gen>Anas</gen>, <gen>Spatula</gen>, and allied genera, in
which the hind toe is destitute of a membranous lobe, as in the mallard
and pintail; -- opposed to <xex>sea duck</xex>.</cd> -- <col><b>River
god</b></col>, <cd>a deity supposed to preside over a river as its
tutelary divinity.</cd> -- <col><b>River herring</b></col>
<fld>(Zool.)</fld>, <cd>an alewife.</cd> -- <col><b>River hog</b></col>.
<fld>(Zool.)</fld> <sd>(a)</sd> <cd>Any species of African wild hogs of
the genus <gen>Potamoch<oe/rus</gen>. They frequent wet places along the
rivers.</cd> <sd>(b)</sd> <cd>The capybara.</cd> -- <col><b>River
horse</b></col> <fld>(Zool.)</fld>, <cd>the hippopotamus.</cd> --
<col><b>River jack</b></col> <fld>(Zool.)</fld>, <cd>an African puff
adder (<spn>Clotho nasicornis</spn>) having a spine on the nose.</cd> --
<col><b>River limpet</b></col> <fld>(Zool.)</fld>, <cd>a fresh-water,
air-breathing mollusk of the genus <gen>Ancylus</gen>, having a
limpet-shaped shell.</cd> -- <col><b>River pirate</b></col>
<fld>(Zool.)</fld>, <cd>the pike.</cd> -- <col><b>River snail</b></col>
<fld>(Zool.)</fld>, <cd>any species of fresh-water gastropods of
<gen>Paludina</gen>, <gen>Melontho</gen>, and allied genera. See
<cref>Pond snail</cref>, under <er>Pond</er>.</cd> -- <col><b>River
tortoise</b></col> <fld>(Zool.)</fld>, <cd>any one of numerous
fresh-water tortoises inhabiting rivers, especially those of the genus
<gen>Trionyx</gen> and allied genera. See
<er>Trionyx</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>River</ent><br/
<hw>Riv"er</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To hawk by the side
of a river; to fly hawks at river fowl.</def> <mark>[Obs.]</mark>
<rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rivered</ent><br/
<hw>Riv"ered</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Supplied with rivers;
<as>as, a well <ex>rivered</ex> country</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Riveret</ent><br/
<hw>Riv"er*et</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A rivulet.</def>
<mark>[Obs.]</mark> <rj><au>Drayton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Riverhood</ent><br/
<hw>Riv"er*hood</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The quality or
state of being a river.</def> <ldquo/Useful <xex>riverhood</xex>.<rdquo/
<rj><au>H. Miller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Riverling</ent><br/
<hw>Riv"er*ling</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A rivulet.</def>
<mark>[R.]</mark> <rj><au>Sylvester.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Riverside</ent><br/
<hw>Riv"er*side`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The side or bank
of a river.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rivery</ent><br/
<hw>Riv"er*y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having rivers;
<as>as, a <ex>rivery</ex> country</as>.</def>
<rj><au>Drayton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rivet</ent><br/
<hw>Riv"et</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr.
<ets>river</ets> to rivet; perh. fr. Icel. <ets>rifa</ets> to fasten
together. Cf. <er>Reef</er> part of a sail.]</ety> <def>A metallic pin
with a head, used for uniting two plates or pieces of material together,
by passing it through them and then beating or pressing down the point
so that it shall spread out and form a second head; a pin or bolt headed
or clinched at both ends.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With busy hammers closing <qex>rivets</qex> up.</q>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Rivet joint</b></col>, <it>or</it> <col><b>Riveted
joint</b></col></mcol>, <cd>a joint between two or more pieces secured
by rivets.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rivet</ent><br/
<hw>Riv"et</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Riveted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Riveting</conjf>.]</vmorph> <sn>1.</sn> <def>To fasten with a
rivet, or with rivets; <as>as, to <ex>rivet</ex> two pieces of
iron</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To spread out the end or point of, as of a metallic
pin, rod, or bolt, by beating or pressing, so as to form a sort of
head.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Hence, to fasten firmly; to make firm, strong, or
immovable; <as>as, to <ex>rivet</ex> friendship or
affection</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Rivet</qex> and nail me where I stand, ye powers!</q>
<rj><qau>Congreve.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Thus his confidence was <qex>riveted</qex> and confirmed.</q>
<rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Riveter</ent><br/
<hw>Riv"et*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
rivets.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Riveting</ent><br/
<hw>Riv"et*ing</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act of joining
with rivets; the act of spreading out and clinching the end, as of a
rivet, by beating or pressing.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The whole set of rivets, collectively.</def>
<rj><au>Tomlinsin.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Butt riveting</b></col>, <cd>riveting in which the ends
or edges of plates form a butt joint, and are fastened together by being
riveted to a narrow strip which covers the joint.</cd> -- <col><b>Chain
riveting</b></col>, <cd>riveting in which the rivets, in two or more
rows along the seam, are set one behind the other.</cd> --
<col><b>Crossed riveting</b></col>, <cd>riveting in which the rivets in
one row are set opposite the spaces between the rivets in the next
row.</cd> -- <col><b>Double riveting</b></col>, <cd>in lap riveting, two
rows of rivets along the seam; in butt riveting, four rows, two on each
side of the joint.</cd> -- <col><b>Lap riveting</b></col>, <cd>riveting
in which the ends or edges of plates overlap and are riveted
together.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><-- riveting, adj. causing to be fixed or immobilized, usu.
figurative; as, riveting debate. --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Riviere</ent><br/
\'d8<hw>Ri`vi<egrave/re"</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[F.]</ety> <def>A necklace of diamonds or other precious stones,
esp. one of several strings.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Rivose</ent><br/
<hw>Ri*vose"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From L.
<ets>rivus</ets> a brook, channel.]</ety> <def>Marked with sinuate and
irregular furrows.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rivulet</ent><br/
<hw>Riv"u*let</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Earlier
<ets>rivolet</ets>, It. <ets>rivoletto</ets>, a dim. fr.
<ets>rivolo</ets>, L. <ets>rivulus</ets>, dim. of <ets>rivus</ets> a
brook. CF. <er>Rival</er>, <er>Rite</er>.]</ety> <def>A small stream or
brook; a streamlet.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>By fountain or by shady <qex>rivulet</qex><br/
He sought them.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rixation</ent><br/
<hw>Rix*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>rixari</ets>, p. p. <ets>rixatus</ets>, to brawl, fr.
<ets>rixa</ets> a quarrel.]</ety> <def>A brawl or quarrel.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rixatrix</ent><br/
\'d8<hw>Rix*a"trix</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.]</ety>
<fld>(Old Eng. Law)</fld> <def>A scolding or quarrelsome woman; a
scold.</def> <rj><au>Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rixdaler</ent><br/
\'d8<hw>Rix"da`ler</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A Dutch silver
coin, worth about $1.00.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rix-dollar</ent><br/
<hw>Rix"-dol`lar</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sw.
<ets>riksdaler</ets>, or Dan. <ets>rigsdaler</ets>, or D.
<ets>rijksdaalder</ets>, or G. <ets>reichsthaler</ets>, literally,
dollar of the empire or realm, fr. words akin to E. <ets>rich</ets>, and
<ets>dollar</ets>. See <er>Rich</er>, <er>Dollar</er>.]</ety> <def>A
name given to several different silver coins of Denmark, Holland,
Sweden,, NOrway, etc., varying in value from about 30 cents to $1.10;
also, a British coin worth about 36 cents, used in Ceylon and at the
Cape of Good Hope. See <er>Rigsdaler</er>, <er>Riksdaler</er>, and
<er>Rixdaler</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Most of these pieces are now no longer coined, but some
remain in circulation.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rizzar</ent><br/
<hw>Riz"zar</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Etymol.
uncertain.]</ety> <def>To dry in the sun; <as>as, <ex>rizzared</ex>
haddock</as>.</def> <mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rn</ent><br/
<hw>Rn</hw>, <pos>n.</pos> <fld>(Chem.)</fld> <def>the symbol for the
chemical element <er>radon</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Roach</ent><br/
<hw>Roach</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>A
cockroach.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roach</ent><br/
<hw>Roach</hw>, <pos>n.</pos> <ety>[OE. <ets>rroche</ets>; cf. AS.
<ets>reohha</ets>, D. <ets>rog</ets>, <ets>roch</ets>, G.
<ets>roche</ets>, LG. <ets>ruche</ets>, Dan. <ets>rokke</ets> ray, Sw.
<ets>rocka</ets>, and E. <ets>ray</ets> a fish.]</ety> <sn>1.</sn>
<fld>(Zool.)</fld> <sd>(a)</sd> <def>A European fresh-water fish of the
Carp family (<spn>Leuciscus rutilus</spn>). It is silver-white, with a
greenish back.</def> <sd>(b)</sd> <def>An American chub (<spn>Semotilus
bullaris</spn>); the fallfish.</def> <sd>(c)</sd> <def>The redfin, or
shiner.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Naut.)</fld> <def>A convex curve or arch cut in the
edge of a sail to prevent chafing, or to secure a better fit.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>As sound as a roach</b></col> <ety>[<ets>roach</ets>
perhaps being a corruption of a F. <ets>roche</ets> a rock]</ety>,
<cd>perfectly sound.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roach</ent><br/
<hw>Roach</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To cause to
arch.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To cut off, as a horse's mane, so that the part left
shall stand upright.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roach-backed</ent><br/
<hw>Roach"-backed`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having a back
like that of roach; -- said of a horse whose back a convex instead of a
concave curve.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Road</ent><br/
<hw>Road</hw> <pr>(r<omac/)</pr>, <pos>n.</pos> <ety>[AS.
<ets>r<amac/d</ets> a riding, that on which one rides or travels, a
road, fr. <ets>r<imac/dan</ets> to ride. See <er>Ride</er>, and cf.
<er>Raid</er>.]</ety> <sn>1.</sn> <def>A journey, or stage of a
journey.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>With easy <qex>roads</qex> he came to Leicester.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An inroad; an invasion; a raid.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A place where one may ride; an open way or public
passage for vehicles, persons, and animals; a track for travel, forming
a means of communication between one city, town, or place, and
another.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The most villainous house in all the London <qex>road</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The word is generally applied to highways, and as a
generic term it includes <xex>highway</xex>, <xex>street</xex>, and
<xex>lane</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <ety>[Possibly akin to Icel. <ets>rei<edh/i</ets> the
rigging of a ship, E. <ets>ready</ets>.]</ety> <def>A place where ships
may ride at anchor at some distance from the shore; a roadstead; --
often in the plural; <as>as, Hampton <ex>Roads</ex></as>.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1246 --></p>

<p><q>Now strike your saile, ye jolly mariners,<br/
For we be come unto a quiet <qex>rode</qex> [road].</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<cs><p><mcol><col><b>On the road</b></col>, <it>or</it> <col><b>Uponthe
road</b></col></mcol>, <cd>traveling or passing over a road; coming or
going; traveling; on the way.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>My hat and wig will soon be here,<br/
They are <qex>upon the road</qex>.</q> <rj><qau>Cowper.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <col><b>Road agent</b></col>, <cd>a highwayman, especially on the
stage routes of the unsettled western parts of the United States; -- a
humorous euphemism.</cd> <mark>[Western U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The highway robber -- <qex>road agent</qex> he is quaintly
called.</q> <rj><qau>The century.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <col><b>Road book</b></col>, <cd>a guidebook in respect to roads
and distances.</cd> -- <col><b>road kill</b></col> <cd>See
<er>roadkill</er> in the vocabulary.</cd> -- <col><b>Road
metal</b></col>, <cd>the broken, stone used in macadamizing roads.</cd>
-- <col><b>Road roller</b></col>, <cd>a heavy roller, or combinations of
rollers, for making earth, macadam, or concrete roads smooth and
compact.</cd> -- often driven by steam. -- <col><b>Road runner</b></col>
<fld>(Zool.)</fld>, <cd>the chaparral cock.</cd> -- <col><b>Road
steamer</b></col>, <cd>a locomotive engine adapted to running on common
roads.</cd> -- <col><b>To go on the road</b></col>, <cd>to engage in the
business of a commercial traveler.</cd> <mark>[Colloq.]</mark> --
<col><b>To take the road</b></col>, <cd>to begin or engage in
traveling.</cd> -- <col><b>To take to the road</b></col>, <cd>to engage
in robbery upon the highways.</cd><br/
[<source>1913 Webster</source>]</p></cs>

<p><syn><b>Syn.</b> -- Way; highway; street; lane; pathway; route;
passage; course. See <er>Way</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roadbed</ent><br/
<hw>Road"bed`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>In railroads, the
bed or foundation on which the superstructure (ties, rails, etc.) rests;
in common roads, the whole material laid in place and ready for
travel.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>roadkill</ent><br/
<hw>road"kill</hw>, <pos>n. sing. & pl.</pos> <def>The body of an animal
killed by a vehicle on a road; <as>as, it is illegal in most places for
a restaurant to serve <ex>roadkill</ex> as food for people</as>. Also
used metaphorically; <as>as, <ldquo/<ex>roadkill</ex> on the information
superhighway<rdquo/ (a person or corporation defeated by others more
expert at using the internet)</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Roadless</ent><br/
<hw>Road"less</hw>, <pos>a.</pos> <def>Destitute of roads.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roadmaker</ent><br/
<hw>Road"mak`er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who makes
roads.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roadside</ent><br/
<hw>Road"side`</hw>, <pos>n.</pos> <def>Land adjoining a road or
highway; the part of a road or highway that borders the traveled part.
Also used ajectively.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roadstead</ent><br/
<hw>Road"stead</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Road</ets>, 4
+ <ets>stead</ets> a place.]</ety> <def>An anchorage off shore. Same as
<er>Road</er>, 4.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Moored in the neighboring <qex>roadstead</qex>.</q>
<rj><qau>Longfellow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roadster</ent><br/
<hw>Road"ster</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<fld>(Naut.)</fld> <def>A clumsy vessel that works its way from one
anchorage to another by means of the tides.</def> <rj><au>Ham. Nav.
Encyc.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A horse that is accustomed to traveling on the high
road, or is suitable for use on ordinary roads.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A sound, swift, well-fed hunter and <qex>roadster</qex>.</q>
<rj><qau>Thackeray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A bicycle or tricycle adapted for common roads
rather than for the racing track.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>One who drives much; a coach driver.</def>
<mark>[Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A hunter who keeps to the roads instead of following
the hounds across country.</def> <mark>[Eng. Slang.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roadway</ent><br/
<hw>Road"way`</hw> <pr>(r<omac/d"w<amac/`)</pr>, <pos>n.</pos> <def>A
road; especially, the part traveled by vehicles.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roam</ent><br/
<hw>Roam</hw> <pr>(r<omac/m)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Roamed</conjf> <pr>(r<omac/md)</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>Roaming</conjf>.]</vmorph> <ety>[OE.
<ets>romen</ets>, <ets>ramen</ets>; cf. AS. <ets><amac/r<aemac/man</ets>
to raise, rise, D. <ets>ramen</ets> to hit, plan, aim, OS.
<ets>r<omac/m<omac/n</ets> to strive after, OHG. <ets>r<amac/men</ets>.
But the word was probably influenced by <ets>Rome</ets>; cf. OF.
<ets>romier</ets> a pilgrim, originally, a pilgrim going to Rome, It.
<ets>romeo</ets>, Sp. <ets>romero</ets>. Cf. <er>Ramble</er>.]</ety>
<def>To go from place to place without any certain purpose or direction;
to rove; to wander.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He <qex>roameth</qex> to the carpenter's house.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Daphne <qex>roaming</qex> through a thorny wood.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To wander; rove; range; stroll; ramble.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roam</ent><br/
<hw>Roam</hw>, <pos>v. t.</pos> <def>To range or wander over.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And now wild beasts came forth the woods to <qex>roam</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roam</ent><br/
<hw>Roam</hw>, <pos>n.</pos> <def>The act of roaming; a wandering; a
ramble; <as>as, he began his <ex>roam</ex> o'er hill and
dale</as>.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roamer</ent><br/
<hw>Roam"er</hw> <pr>(r<omac/m"<etil/r)</pr>, <pos>n.</pos> <def>One who
roams; a wanderer.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roan</ent><br/
<hw>Roan</hw> <pr>(r<omac/n)</pr>, <pos>a.</pos> <ety>[F.
<ets>rouan</ets>; cf. Sp. <ets>roano</ets>, <ets>ruano</ets>, It.
<ets>rovano</ets>, <ets>roano</ets>.]</ety> <sn>1.</sn> <def>Having a
bay, chestnut, brown, or black color, with gray or white thickly
interspersed; -- said of a horse.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Give my <qex>roan</qex> a drench.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Made of the leather called roan; <as>as,
<ex>roan</ex> binding</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Roan antelope</b></col> <fld>(Zool.)</fld>, <cd>a very
large South African antelope (<spn>Hippotragus equinus</spn>). It has
long sharp horns and a stiff bright brown mane. Called also
<altname>mahnya</altname>, <altname>equine antelope</altname>, and
<altname>bastard gemsbok</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roan</ent><br/
<hw>Roan</hw>, <pos>n.</pos> <sn>1.</sn> <def>The color of a roan horse;
a roan color.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A roan horse.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A kind of leather used for slippers, bookbinding,
etc., made from sheepskin, tanned with sumac and colored to imitate
ungrained morocco.</def> <rj><au>DeColange.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Roan tree</b></col>. <fld>(Bot.)</fld> <cd>See <er>Rowan
tree</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roar</ent><br/
<hw>Roar</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Roared</conjf> <pr>(?)</pr>; <pos>p. pr. & vvb. n.</pos>
<conjf>Roaring</conjf>.]</vmorph> <ety>[OE. <ets>roren</ets>,
<ets>raren</ets>, AS. <ets>r<amac/rian</ets>; akin to G.
<ets>r<oum/hten</ets>, OHG. <ets>r<emac/r<emac/n</ets>.
<root/112.]</ety> <sn>1.</sn> <def>To cry with a full, loud, continued
sound.</def> Specifically: <sd>(a)</sd> <def>To bellow, or utter a deep,
loud cry, as a lion or other beast.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Roaring</qex> bulls he would him make to tame.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(b)</sd> <def>To cry loudly, as in pain, distress, or
anger.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Sole on the barren sands, the suffering chief<br/
<qex>Roared</qex> out for anguish, and indulged his grief.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He scorned to <qex>roar</qex> under the impressions of a finite
anger.</q> <rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To make a loud, confused sound, as winds, waves,
passing vehicles, a crowd of persons when shouting together, or the
like.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The brazen throat of war had ceased to <qex>roar</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>How oft I crossed where carts and coaches <qex>roar</qex>.</q>
<rj><qau>Gay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To be boisterous; to be disorderly.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It was a mad, <qex>roaring</qex> time, full of extravagance.</q>
<rj><qau>Bp. Burnet.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To laugh out loudly and continuously; <as>as, the
hearers <ex>roared</ex> at his jokes</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To make a loud noise in breathing, as horses having
a certain disease. See <er>Roaring</er>, 2.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Roaring boy</b></col>, <cd>a roaring, noisy fellow; --
name given, at the latter end Queen Elizabeth's reign, to the riotous
fellows who raised disturbances in the street.</cd> <ldquo/Two
<xex>roaring boys</xex> of Rome, that made all split.<rdquo/ <au>Beau. &
Fl.</au> -- <col><b>Roaring forties</b></col> <fld>(Naut.)</fld>, <cd>a
sailor's name for the stormy tract of ocean between 40<deg/ and 50<deg/
north latitude.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roar</ent><br/
<hw>Roar</hw>, <pos>v. t.</pos> <def>To cry aloud; to proclaim
loudly.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This last action will <qex>roar</qex> thy infamy.</q>
<rj><qau>Ford.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roar</ent><br/
<hw>Roar</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The sound of
roaring.</def> Specifically: <sd>(a)</sd> <def>The deep, loud cry of a
wild beast; <as>as, the <ex>roar</ex> of a lion</as>.</def> <sd>(b)</sd>
<def>The cry of one in pain, distress, anger, or the like.</def>
<sd>(c)</sd> <def>A loud, continuous, and confused sound; <as>as, the
<ex>roar</ex> of a cannon, of the wind, or the waves; the <ex>roar</ex>
of ocean</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Arm! arm! it is, it is the cannon's opening <qex>roar</qex>!</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(d)</sd> <def>A boisterous outcry or shouting, as in
mirth.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Pit, boxes, and galleries were in a constant <qex>roar</qex> of
laughter.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roarer</ent><br/
<hw>Roar"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who,
or that which, roars.</def> Specifically: <sd>(a)</sd> <def>A riotous
fellow; a roaring boy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A lady to turn <qex>roarer</qex>, and break glasses.</q>
<rj><qau>Massinger.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(b)</sd> <fld>(Far.)</fld> <def>A horse subject to roaring. See
<er>Roaring</er>, 2.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>The barn owl.</def> <mark>[Prov.
Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roaring</ent><br/
<hw>Roar"ing</hw>, <pos>n.</pos> <sn>1.</sn> <def>A loud, deep,
prolonged sound, as of a large beast, or of a person in distress, anger,
mirth, etc., or of a noisy congregation.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Far.)</fld> <def>An affection of the windpipe of a
horse, causing a loud, peculiar noise in breathing under exertion; the
making of the noise so caused. See <er>Roar</er>, <pos>v. i.</pos>,
5.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roaring forties</ent><br/
<hw>Roar"ing for"ties</hw> <pr>(?)</pr>. <fld>(Naut.)</fld> <def>The
middle latitudes of the southern hemisphere. So called from the
boisterous and prevailing westerly winds, which are especially strong in
the South Indian Ocean up to 50<deg/ S.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Roaring twenties</ent><br/
<hw>Roar"ing twen"ties</hw> <pr>(?)</pr>. <def>The decade from 1920 to
1929; -- so called because of the occurrence of a prosperous economy and
rapid changes in sociological mores as exemplified by speakeasies, the
popularity of fast cars and jazz, and the boisterous unconventional
behavior of young adults in that period. See also <er>flapper</er>,
<er>speakeasy</er>, and second <er>prohibition</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Roaringly</ent><br/
<hw>Roar"ing*ly</hw>, <pos>adv.</pos> <def>In a roaring
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roast</ent><br/
<hw>Roast</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Roasted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Roasting</conjf>.]</vmorph> <ety>[OE. <ets>rosten</ets>, OF.
<ets>rostir</ets>, F. <ets>r<ocir/tir</ets>; of German origin; cf. OHG.
<ets>r<omac/sten</ets>, G. <ets>r<oum/sten</ets>, fr. OHG.
<ets>r<omac/st</ets>, <ets>r<omac/sta</ets>, gridiron, G.
<ets>rost</ets>; cf. AS. <ets>hyrstan</ets> to roast.]</ety> <sn>1.</sn>
<def>To cook by exposure to radiant heat before a fire; <as>as, to
<ex>roast</ex> meat on a spit, or in an oven open toward the fire and
having reflecting surfaces within</as>; also, to cook in a close
oven.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To cook by surrounding with hot embers, ashes, sand,
etc.; <as>as, to <ex>roast</ex> a potato in ashes</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In eggs boiled and <qex>roasted</qex> there is scarce difference
to be discerned.</q> <rj><qau>BAcon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To dry and parch by exposure to heat; <as>as, to
<ex>roast</ex> coffee; to <ex>roast</ex> chestnuts, or
peanuts.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Hence, to heat to excess; to heat violently; to
burn.</def> <ldquo/<xex>Roasted</xex> in wrath and fire.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Metal.)</fld> <def>To dissipate by heat the
volatile parts of, as ores.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To banter severely.</def> <mark>[Colloq.]</mark>
<rj><au>Atterbury.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roast</ent><br/
<hw>Roast</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To cook meat, fish,
etc., by heat, as before the fire or in an oven.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He could <qex>roast</qex>, and seethe, and broil, and fry.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To undergo the process of being roasted.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roast</ent><br/
<hw>Roast</hw>, <pos>n.</pos> <def>That which is roasted; a piece of
meat which has been roasted, or is suitable for being roasted.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A fat swan loved he best of any <qex>roost</qex> [roast].</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To rule the roast</b></col>, <cd>to be at the head of
affairs.</cd> <ldquo/The new-made duke that <xex>rules the
roast</xex>.<rdquo/</cs><-- = to rule the roost! -->
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roast</ent><br/
<hw>Roast</hw>, <pos>a.</pos> <ety>[For <ets>roasted</ets>.]</ety>
<def>Roasted; <as>as, <ex>roast</ex> beef</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roaster</ent><br/
<hw>Roast"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who
roasts meat.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A contrivance for roasting.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A pig, or other article of food fit for
roasting.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roasting</ent><br/
<hw>Roast"ing</hw>, <def><pos>a. & n.</pos>, from <er>Roast</er>,
<pos>v.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Roasting ear</b></col>, <cd>an ear of Indian corn at that
stage of development when it is fit to be eaten roasted.</cd> --
<col><b>Roasting jack</b></col>, <cd>a machine for turning a spit on
which meat is roasted.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rob</ent><br/
<hw>Rob</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.; cf. Sp.
<ets>rob</ets>, It. <ets>rob</ets>, <ets>robbo</ets>, Pg.
<ets>robe</ets>, <ets>arrobe</ets>, Ar. <ets>rubb</ets>,
<ets>robb</ets>, Per. <ets>rub</ets>.]</ety> <def>The inspissated juice
of ripe fruit, obtained by evaporation of the juice over a fire till it
acquires the consistence of a sirup. It is sometimes mixed with honey or
sugar.</def> <altsp>[Written also <asp>rhob</asp>, and
<asp>rohob</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rob</ent><br/
<hw>Rob</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Robbed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Robbing</conjf>.]</vmorph> <ety>[OF. <ets>rober</ets>, of German
origin; cf. OHG. <ets>roub<?/n</ets>, G. <ets>rauben</ets>, and OHG.
<ets>roub</ets> robbing, booty, G. <ets>raub</ets>. <root/114. See
<er>Reave</er>,and cf. <er>Robe</er>.]</ety> <sn>1.</sn> <def>To take
(something) away from by force; to strip by stealing; to plunder; to
pillage; to steal from.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Who would <qex>rob</qex> a hermit of his weeds,<br/
His few books, or his beads, or maple dish?</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He that is <qex>robbed</qex>, not wanting what is stolen,<br/
Let him not know it, and he's not <qex>robbed</qex> at all.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To be executed for <qex>robbing</qex> a church.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>To take the property of (any one)
from his person, or in his presence, feloniously, and against his will,
by violence or by putting him in fear.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To deprive of, or withhold from, unjustly or
injuriously; to defraud; <as>as, to <ex>rob</ex> one of his rest, or of
his good name; a tree <ex>robs</ex> the plants near it of
sunlight.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>I never <qex>robbed</qex> the soldiers of their pay.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rob</ent><br/
<hw>Rob</hw>, <pos>v. i.</pos> <def>To take that which belongs to
another, without right or permission, esp. by violence.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I am accursed to <qex>rob</qex> in that thief's company.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Robalito</ent><br/
<ent>Robalo</ent><br/
<hw>Rob"a*lo</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sp.
<ets>r<oacute/balo</ets>.]</ety> <def>Any of several pikelike marine
fishes of the West Indies and tropical America constituting the family
<fam>Oxylabracidae</fam>, esp. the largest species (<spn>Oxylabrax
undecimalis</spn>, syn. <spn>Centropomus undecimalis</spn>), a valuable
food fish called also <stype>snook</stype>, the smaller species being
called <hw>Rob`a*li"to</hw> <pr>(<?/)</pr>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Roband</ent><br/
<hw>Rob"and</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Naut.)</fld> <def>See
<er>Roperand</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Robber</ent><br/
<hw>Rob"ber</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who robs; in law,
one who feloniously takes goods or money from the person of another by
violence or by putting him in fear.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Some roving <qex>robber</qex> calling to his fellows.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Thief; depredator; despoiler; plunderer;
pillager; rifler; brigang; freebooter; pirate. See
<er>Thief</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Robber crab</b></col>. <fld>(Zool.)</fld> <sd>(a)</sd>
<cd>A purse crab</cd>. <sd>(b)</sd> <cd>Any hermit crab.</cd> --
<col><b>Robber fly</b></col>. <fld>(Zool.)</fld> <cd>Same as
<cref>Hornet fly</cref>, under <er>Hornet</er>.</cd> -- <col><b>Robber
gull</b></col> <fld>(Zool.)</fld>, <cd>a jager gull.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Robbery</ent><br/
<hw>Rob"ber*y</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Robberies</plw> <pr>(#)</pr>.</plu> <ety>[OF.
<ets>roberie</ets>.]</ety> <sn>1.</sn> <def>The act or practice of
robbing; theft.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thieves for their <qex>robbery</qex> have authority<br/
When judges steal themselves.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>The crime of robbing. See
<er>Rob</er>, <pos>v. t.</pos>, 2.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Robbery</xex>, in a strict sense, differs from
<xex>theft</xex>, as it is effected by force or intimidation, whereas
<xex>theft</xex> is committed by stealth, or privately.</note><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Theft; depredation; spoliation; despoliation;
despoilment; plunder; pillage; rapine; larceny; freebooting;
piracy.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Robbin</ent><br/
<hw>Rob"bin</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Com.)</fld> <def>A
kind of package in which pepper and other dry commodities are sometimes
exported from the East Indies. The <xex>robbin</xex> of rice in Malabar
weighs about 84 pounds.</def> <rj><au>Simmonds.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Robbin</ent><br/
<hw>Rob"bin</hw>, <pos>n.</pos> <fld>(Naut.)</fld> <def>See
<er>Ropeband</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Robe</ent><br/
<hw>Robe</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr. LL.
<ets>rauba</ets> a gown, dress, garment; originally, booty, plunder. See
<er>Rob</er>, <pos>v. t.</pos>, and cf. <er>Rubbish</er>.]</ety>
<sn>1.</sn> <def>An outer garment; a dress of a rich, flowing, and
elegant style or make; hence, a dress of state, rank, office, or the
like.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Through tattered clothes small vices do appear;<br/
<qex>Robes</qex> and furred gowns hide all.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A skin of an animal, especially, a skin of the
bison, dressed with the fur on, and used as a wrap.</def>
<mark>[U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Master of the robes</b></col>, <cd>an officer of the
English royal household (when the sovereign is a king) whose duty is
supposed to consist in caring for the royal robes.</cd> --
<col><b>Mistress of the robes</b></col>, <cd>a lady who enjoys the
highest rank of the ladies in the service of the English sovereign (when
a queen), and is supposed to have the care her robes.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Robe</ent><br/
<hw>Robe</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Robed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Robing</conjf>.]</vmorph> <def>To invest with a robe or robes; to
dress; to array; <as>as, fields <ex>robed</ex> with
green</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The sage Chaldeans <qex>robed</qex> in white appeared.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Such was his power over the expression of his countenance, that he
could in an instant shake off the sternness of winter, and
<qex>robe</qex> it in the brightest smiles of spring.</q>
<rj><qau>Wirt.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Robe-de-chambre</ent><br/
\'d8<hw>Robe`-de-cham"bre</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.,
lit., a chamber gown.]</ety> <def>A dressing gown, or morning
gown.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Robertsman</ent><br/
<ent>Roberdsman</ent><br/
<mhw>{ <hw>Rob"erds*man</hw> <pr>(?)</pr>, <hw>Rob"erts*man</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos>; <plu><it>pl.</it> <plw>-men</plw>.
<pr>(<?/)</pr></plu> <fld>(Old Statutes of Eng.)</fld> <def>A bold,
stout robber, or night thief; -- said to be so called from
<xex>Robin</xex> Hood.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Robert</ent><br/
<hw>Rob"ert</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>See
<cref>Herb Robert</cref>, under <er>Herb</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Robin</ent><br/
<hw>Rob"in</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Properly a pet name
for <ets>Robert</ets>, originally meaning, famebright; F., fron OHG.
<ets>Roudperht</ets>; <ets>ruod</ets> (in comp.; akin to AS.
<ets>hr<?/<?/</ets> glory, fame, Goth. <ets>hr<?/peigs</ets> victorius)
+ <ets>beraht</ets> bright. See <er>Bright</er>, <er>Hob</er> a
clown.]</ety> <fld>(Zool.)</fld> <sd>(a)</sd> <def>A small European
singing bird (<spn>Erythacus rubecula</spn>), having a reddish breast;
-- called also <altname>robin redbreast</altname>,
<altname>robinet</altname>, and <altname>ruddock</altname>.</def>
<sd>(b)</sd> <def>An American singing bird (<spn>Merula
migratoria</spn>), having the breast chestnut, or dull red. The upper
parts are olive-gray, the head and tail blackish. Called also
<altname>robin redbreast</altname>, and <altname>migratory
thrush</altname>.</def> <sd>(c)</sd> <def>Any one of several species of
Australian warblers of the genera <gen>Petroica</gen>,
<gen>Melanadrays</gen>, and allied genera; <as>as, the scarlet-breasted
<ex>robin</ex> (<spn>Petroica mullticolor</spn>)</as>.</def>
<sd>(d)</sd> <def>Any one of several Asiatic birds; <as>as, the Indian
<ex>robins</ex></as>. See <cref>Indian robin</cref>, below.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Beach robin</b></col> <fld>(Zool.)</fld>, <cd>the robin
snipe, or knot. See <er>Knot</er>.</cd> -- <col><b>Blue-throated
robin</b></col>. <fld>(Zool.)</fld> <cd>See <er>Bluethroat</er>.</cd> --
<col><b>Canada robin</b></col> <fld>(Zool.)</fld>, <cd>the cedar
bird.</cd> -- <col><b>Golden robin</b></col> <fld>(Zool.)</fld>, <cd>the
Baltimore oriole.</cd> -- <col><b>Ground robin</b></col>
<fld>(Zool.)</fld>, <cd>the chewink.</cd> -- <col><b>Indian
robin</b></col> <fld>(Zool.)</fld>, <cd>any one of several species of
Asiatic saxoline birds of the genera <gen>Thamnobia</gen> and
<gen>Pratincola</gen>. They are mostly black, usually with some white on
the wings.</cd> -- <col><b>Magrie robin</b></col> <fld>(Zool.)</fld>,
<cd>an Asiatic singing bird (<spn>Corsycus saularis</spn>), having the
back, head, neck, and breast black glossed with blue, the wings black,
and the belly white.</cd> -- <col><b>Ragged robin</b></col>.
<fld>(Bot.)</fld> <cd>See under <er>Ragged</er>.</cd> -- <col><b>Robin
accentor</b></col> <fld>(Zool.)</fld>, <cd>a small Asiatic singing bird
(<spn>Accentor rubeculoides</spn>), somewhat resembling the European
robin.</cd> -- <col><b>Robin redbreast</b></col>. <fld>(Zool.)</fld>
<sd>(a)</sd> <cd>The European robin</cd>. <sd>(b)</sd> <cd>The American
robin</cd>. <sd>(c)</sd> <cd>The American bluebird.</cd> --
<col><b>Robin snipe</b></col>. <fld>(Zool.)</fld> <sd>(a)</sd> <cd>The
red-breasted snipe, or dowitcher</cd>. <sd>(b)</sd> <cd>The red-breasted
sandpiper, or knot.</cd> -- <col><b>Robin's plantain</b></col>.
<fld>(Bot.)</fld> <cd>See under <er>Plantain</er>.</cd> -- <col><b>Sea
robin</b></col>. <fld>(Zool.)</fld> <sd>(a)</sd> <cd>Any one of several
species of American gurnards of the genus <gen>Prionotus</gen>. They are
excellent food fishes. Called also <altname>wingfish</altname>. The name
is also applied to a European gurnard.</cd> <sd>(b)</sd> <cd>The
red-breasted merganser, or sheldrake</cd>. <mark>[Local, U.S.]</mark> --
<col><b>Water robin</b></col> <fld>(Zool.)</fld>, <cd>a redstart
(<spn>Ruticulla fuliginosa</spn>), native of India.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Robinet</ent><br/
<hw>Rob"i*net</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<fld>(Zool.)</fld> <sd>(a)</sd> <def>The chaffinch; -- called also
<altname>roberd</altname>.</def> <sd>(b)</sd> <def>The European
robin.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A military engine formerly used for throwing darts
and stones.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Robing</ent><br/
<hw>Rob"ing</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of putting on
a robe.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Robing room</b></col>, <cd>a room where official robes
are put on, as by judges, etc.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Robin Goodfellow</ent><br/
<hw>Rob"in Good"fel`low</hw> <pr>(?)</pr>. <def>A celebrated fairy;
Puck. See <er>Puck</er>.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Robinia</ent><br/
\'d8<hw>Ro*bin"i*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. So called
after Jean <etsep>Robin</etsep>, a French herbalist.]</ety>
<fld>(Bot.)</fld> <def>A genus of leguminous trees including the common
locust of North America (<spn>Robinia Pseudocacia</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roble</ent><br/
\'d8<hw>Ro"ble</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sp., oak.]</ety>
<fld>(Bot.)</fld> <def>The California white oak (<spn>Quercus
lobata</spn>).</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Roborant</ent><br/
<hw>Rob"o*rant</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>roborans</ets>, p. pr. See <er>Roborate</er>.]</ety>
<def>Strengthening.</def> -- <def2><pos>n.</pos> <fld>(Med.)</fld>
<def>A strengthening medicine; a tonic.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roborate</ent><br/
<hw>Rob"o*rate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>roboratus</ets>, p. pr. of <ets>roborare</ets> to strengthen, fr.
<ets>robur</ets>, <ets>roboris</ets>, strength.]</ety> <def>To give
strength or support to; to confirm.</def> <mark>[Obs.]</mark>
<rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roboration</ent><br/
<hw>Rob`o*ra"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL.
<ets>roboratio</ets>.]</ety> <def>The act of strengthening.</def>
<mark>[Obs.]</mark> <rj><au>Coles.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roboreous</ent><br/
<ent>Roborean</ent><br/
<mhw>{ <hw>Ro*bo"re*an</hw> <pr>(?)</pr>, <hw>Ro*bo"re*ous</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[L. <ets>roboreus</ets>.]</ety>
<def>Made of oak.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Robust</ent><br/
<hw>Ro*bust"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>robustus</ets> oaken, hard, strong, fr. <ets>robur</ets> strength,
a very hard kind of oak; cf. Skr. <ets>rabhas</ets> violence: cf. F.
<ets>robuste</ets>.]</ety> <sn>1.</sn> <def>Evincing strength;
indicating vigorous health; strong; sinewy; muscular; vigorous; sound;
<as>as, a <ex>robust</ex> body; <ex>robust</ex> youth; <ex>robust</ex>
health</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1247 --></p>

<p><sn>2.</sn> <def>Violent; rough; rude.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>While romp-loving miss<br/
Is hauled about in gallantry <qex>robust</qex>.</q>
<rj><qau>Thomson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Requiring strength or vigor; <as>as, <ex>robust</ex>
employment</as>.</def> <rj><au>Locke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Strong; lusty; sinewy; sturdy; muscular; hale;
hearty; vigorous; forceful; sound.</syn> <usage> -- <er>Robust</er>,
<er>Strong</er>. <xex>Robust</xex> means, literally, made of
<xex>oak</xex>, and hence implies great compactness and toughness of
muscle, connected with a thick-set frame and great powers of endurance.
<xex>Strong</xex> denotes the power of exerting great physical force.
The <xex>robust</xex> man can bear heat or cold, excess or privation,
and toil on through every kind of hardship; the <xex>strong</xex> man
can lift a great weight, can give a heavy blow, and a hard gripe.
<ldquo/<xex>Robust</xex>, tough sinews bred to toil.<rdquo/
<au>Cowper.</au></usage><br/
[<source>1913 Webster</source>]</p>

<p><q>Then 'gan the villain wax so fierce and <qex>strong</qex>,<br/
<qex>That nothing may sustain his furious force</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Robustious</ent><br/
<hw>Ro*bus"tious</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. L.
<ets>robusteus</ets> of oak.]</ety> <def>Robust.</def> <mark>[Obs. or
Humorous]</mark> <rj><au>W. Irving.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>In Scotland they had handled the bishops in a more
<qex>robustious</qex> manner.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Ro*bus"tious*ly</wf>, <pos>adv.</pos> --
<wf>Ro*bus"tious*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Robustly</ent><br/
<hw>Ro*bust"ly</hw>, <pos>adv.</pos> <def>In a robust manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Robustness</ent><br/
<hw>Ro*bust"ness</hw>, <pos>n.</pos> <def>The quality or state of being
robust.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roc</ent><br/
<hw>Roc</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Ar. & Per.
<ets>rokh</ets> or <ets>rukh</ets>. Cf. <er>Rook</er> a castle.]</ety>
<def>A monstrous bird of Arabian mythology.</def> <altsp>[Written also
<asp>rock</asp>, and <asp>rukh</asp>.]</altsp> <rj><au>Brande &
C.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rocaille</ent><br/
\'d8<hw>Ro`caille"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. Cf.
<er>Rock</er> a stone.]</ety> <fld>(Art)</fld> <sd>(a)</sd>
<def>Artificial rockwork made of rough stones and cement, as for
gardens.</def> <sd>(b)</sd> <def>The rococo system of scroll ornament,
based in part on the forms of shells and water-worn rocks.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Rocambole</ent><br/
<hw>Roc"am*bole</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<altsp>[Written also <asp>rokambole</asp>.]</altsp> <fld>(Bot.)</fld>
<def>A name of <spn>Allium Scorodoprasum</spn> and <spn>Allium
Ascalonium</spn>, two kinds of garlic, the latter of which is also
called <altname>shallot</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roccellic</ent><br/
<hw>Roc*cel"lic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F.
<ets>roccellique</ets>, fr. <ets>roccelle</ets> archil, It. & NL.
<ets>roccella</ets>, fr. It. <ets>rocca</ets> a rock, because archil
grows on rock.]</ety> <fld>(Chem.)</fld> <def>Pertaining to, or
designating, a dibasic acid of the oxalic series found in archil
(<spn>Roccella tinctoria</spn>, etc.), and other lichens, and extracted
as a white crystalline substance <chform>C17H32O4</chform>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roccellin</ent><br/
<hw>Roc*cel"lin</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A red dyestuff,
used as a substitute for cochineal, archil, etc. It consists of the
sodium salt of a complex azo derivative of naphtol.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roche</ent><br/
<hw>Roche</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Rock</er>.]</ety> <def>Rock.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roche alum</ent><br/
<hw>Roche" al`um</hw> <pr>(?)</pr>. <fld>(Chem.)</fld> <def>A kind of
alum occuring in small fragments; -- so called from <xex>Rocca</xex>, in
Syria, whence alum is said to have been obtained; -- also called
<altname>rock alum</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rochelime</ent><br/
<hw>Roche"lime`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>roche</ets> rock + E. <ets>lime</ets>.]</ety> <def>Lime in the lump
after it is burned; quicklime.</def> <mark>[Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rochelle</ent><br/
<hw>Ro*chelle"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A seaport town in
France.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Rochelle powders</b></col>. <cd>Same as <er>Seidlitz
powders</er>.</cd> -- <col><b>Rochelle salt</b></col>
<fld>(Chem.)</fld>, <cd>the double tartrate of sodium and potassium, a
white crystalline substance. It has a cooling, saline, slightly bitter
taste and is employed as a mild purgative. It was discovered by
Seignette, an apothecary of Rochelle, and is called also
<altname>Seignete's salt</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roche moutonnee</ent><br/
\'d8<hw>Roche" mou`ton`n<eacute/e"</hw> <pr>(?)</pr>. <ety>[F.,
sheep-shaped rock.]</ety> <fld>(Geol.)</fld> <def>See
<er>Sheepback</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rochet</ent><br/
<hw>Roch"et</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., dim. fr. OHG.
<ets>rocch</ets> coat, G. <ets>rock</ets>.]</ety> <sn>1.</sn>
<fld>(Eccl.)</fld> <def>A linen garment resembling the surplise, but
with narrower sleeves, also without sleeves, worn by bishops, and by
some other ecclesiastical dignitaries, in certain religious
ceremonies.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They see no difference between an idler with a hat and national
cockade, and an idler in a cowl or in a <qex>rochet</qex>.</q>
<rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A frock or outer garment worn in the thirteenth and
fourteenth centuries.</def> <mark>[Obs.]</mark> <rj><au>Rom. of
R.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rochet</ent><br/
<hw>Roch"et</hw>, <pos>n.</pos> <ety>[Probably corrupted fr. F.
<ets>rouget</ets> the red gurnet, from <ets>rouge</ets> red. CF.
<er>Rouge</er>.]</ety> <fld>(Zool.)</fld> <def>The red gurnard, or
gurnet. See <er>Gurnard</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roching cask</ent><br/
<hw>Roch"ing cask`</hw> <pr>(?)</pr>. <ety>[Probably from F.
<ets>roche</ets> a rock.]</ety> <def>A tank in which alum is
crystallized from a solution.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rock</ent><br/
<hw>Rock</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Roc</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rock</ent><br/
<hw>Rock</hw>, <pos>n.</pos> <ety>[OE. <ets>rocke</ets>; akin to D.
<ets>rok</ets>, <ets>rokken</ets>, G. <ets>rocken</ets>, OHG.
<ets>roccho</ets>, Dan. <ets>rok</ets>, Icel. <ets>rokkr</ets>. Cf.
<er>Rocket</er> a firework.]</ety> <def>A distaff used in spinning; the
staff or frame about which flax is arranged, and from which the thread
is drawn in spinning.</def> <rj><au>Chapman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Sad Clotho held the <qex>rocke</qex>, the whiles the thread<br/
By grisly Lachesis was spun with pain,<br/
That cruel Atropos eftsoon undid.</q> <rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rock</ent><br/
<hw>Rock</hw>, <pos>n.</pos> <ety>[OF. <ets>roke</ets>, F.
<ets>roche</ets>; cf. Armor. <ets>roc'h</ets>, and AS.
<ets>rocc</ets>.]</ety> <sn>1.</sn> <def>A large concreted mass of stony
material; a large fixed stone or crag. See <er>Stone</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Come one, come all! this <qex>rock</qex> shall fly<br/
From its firm base as soon as I.</q> <rj><qau>Sir W.
Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Geol.)</fld> <def>Any natural deposit forming a
part of the earth's crust, whether consolidated or not, including sand,
earth, clay, etc., when in natural beds.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which resembles a rock in firmness; a defense;
a support; a refuge.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The Lord is my <qex>rock</qex>, and my fortress.</q> <rj><qau>2
Sam. xxii. 2.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Fig.: Anything which causes a disaster or wreck
resembling the wreck of a vessel upon a rock.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Zool.)</fld> <def>The striped bass. See under
<er>Bass</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ This word is frequently used in the formation of
self-explaining compounds; as, <xex>rock</xex>-bound,
<xex>rock</xex>-built, <xex>rock</xex>-ribbed, <xex>rock</xex>-roofed,
and the like.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Rock alum</b></col>. <ety>[Probably so called by
confusion with F. <ets>roche</ets> a rock.]</ety> <cd>Same as <er>Roche
alum</er>.</cd> -- <col><b>Rock barnacle</b></col> <fld>(Zool.)</fld>,
<cd>a barnacle (<spn>Balanus balanoides</spn>) very abundant on rocks
washed by tides.</cd> -- <col><b>Rock bass</b></col>. <fld>(Zool.)</fld>
<sd>(a)</sd> <cd>The stripped bass</cd>. See under <er>Bass</er>.
<sd>(b)</sd> <cd>The goggle-eye.</cd> <sd>(c)</sd> <cd>The cabrilla.
Other species are also locally called <xex>rock bass</xex>.</cd> --
<col><b>Rock builder</b></col> <fld>(Zool.)</fld>, <cd>any species of
animal whose remains contribute to the formation of rocks, especially
the corals and Foraminifera.</cd> -- <col><b>Rock butter</b></col>
<fld>(Min.)</fld>, <cd>native alum mixed with clay and oxide of iron,
usually in soft masses of a yellowish white color, occuring in cavities
and fissures in argillaceous slate.</cd> -- <col><b>Rock
candy</b></col>, <cd>a form of candy consisting of crystals of pure
sugar which are very hard, whence the name.</cd> -- <col><b>Rock
cavy</b></col>. <fld>(Zool.)</fld> <cd>See <er>Moco</er>.</cd> --
<col><b>Rock cod</b></col> <fld>(Zool.)</fld> <sd>(a)</sd> <cd>A small,
often reddish or brown, variety of the cod found about rocks
andledges</cd>. <sd>(b)</sd> <cd>A California rockfish.</cd> --
<col><b>Rock cook</b></col>. <fld>(Zool.)</fld> <sd>(a)</sd> <cd>A
European wrasse (<spn>Centrolabrus exoletus</spn>)</cd>. <sd>(b)</sd>
<cd>A rockling.</cd> -- <col><b>Rock cork</b></col> <fld>(Min.)</fld>,
<cd>a variety of asbestus the fibers of which are loosely interlaced. It
resembles cork in its texture.</cd> -- <col><b>Rock crab</b></col>
<fld>(Zool.)</fld>, <cd>any one of several species of large crabs of the
genus <gen>C</gen>, as the two species of the New England coast
(<spn>Cancer irroratus</spn> and <spn>Cancer borealis</spn>). See
<xex>Illust.</xex> under <er>Cancer</er>.</cd> -- <col><b>Rock
cress</b></col> <fld>(Bot.)</fld>, <cd>a name of several plants of the
cress kind found on rocks, as <spn>Arabis petraea</spn>, <spn>Arabis
lyrata</spn>, etc.</cd> -- <col><b>Rock crystal</b></col>
<fld>(Min.)</fld>, <cd>limpid quartz. See <er>Quartz</er>, and under
<er>Crystal</er>.</cd> -- <col><b>Rock dove</b></col>
<fld>(Zool.)</fld>, <cd>the rock pigeon; -- called also <altname>rock
doo</altname>.</cd> -- <col><b>Rock drill</b></col>, <cd>an implement
for drilling holes in rock; esp., a machine impelled by steam or
compressed air, for drilling holes for blasting, etc.</cd> --
<col><b>Rock duck</b></col> <fld>(Zool.)</fld>, <cd>the harlequin
duck.</cd> -- <col><b>Rock eel</b></col>. <fld>(Zool.)</fld> <cd>See
<er>Gunnel</er>.</cd> -- <col><b>Rock goat</b></col> <fld>(Zool.)</fld>,
<cd>a wild goat, or ibex.</cd> -- <col><b>Rock hopper</b></col>
<fld>(Zool.)</fld>, <cd>a penguin of the genus <gen>Catarractes</gen>.
See under <er>Penguin</er>.</cd> -- <col><b>Rock kangaroo</b></col>.
<fld>(Zool.)</fld> <cd>See <er>Kangaroo</er>, and
<er>Petrogale</er>.</cd> -- <col><b>Rock lobster</b></col>
<fld>(Zool.)</fld>, <cd>any one of several species of large spinose
lobsters of the genera <gen>Panulirus</gen> and <gen>Palinurus</gen>.
They have no large claws. Called also <altname>spiny lobster</altname>,
and <altname>sea crayfish</altname>.</cd> -- <col><b>Rock meal</b></col>
<fld>(Min.)</fld>, <cd>a light powdery variety of calcite occuring as an
efflorescence.</cd> -- <col><b>Rock milk</b></col>. <fld>(Min.)</fld>
<cd>See <cref>Agaric mineral</cref>, under <er>Agaric</er>.</cd> --
<col><b>Rock moss</b></col>, <cd>a kind of lichen; the cudbear. See
<er>Cudbear</er>.</cd> -- <col><b>Rock oil</b></col>. <cd>See
<er>Petroleum</er>.</cd> -- <col><b>Rock parrakeet</b></col>
<fld>(Zool.)</fld>, <cd>a small Australian parrakeet (<spn>Euphema
petrophila</spn>), which nests in holes among the rocks of high cliffs.
Its general color is yellowish olive green; a frontal band and the outer
edge of the wing quills are deep blue, and the central tail feathers
bluish green.</cd> -- <col><b>Rock pigeon</b></col> <fld>(Zool.)</fld>,
<cd>the wild pigeon (<spn>Columba livia</spn>) Of Europe and Asia, from
which the domestic pigeon was derived. See <xex>Illust.</xex> under
<er>Pigeon</er>.</cd> -- <col><b>Rock pipit</b></col>.
<fld>(Zool.)</fld> <cd>See the Note under <er>Pipit</er>.</cd> --
<col><b>Rock plover</b></col>. <fld>(Zool.)</fld> <sd>(a)</sd> <cd>The
black-bellied, or whistling, plover</cd>. <sd>(b)</sd> <cd>The rock
snipe.</cd> -- <col><b>Rock ptarmigan</b></col> <fld>(Zool.)</fld>,
<cd>an arctic American ptarmigan (<spn>Lagopus rupestris</spn>), which
in winter is white, with the tail and lores black. In summer the males
are grayish brown, coarsely vermiculated with black, and have black
patches on the back.</cd> -- <col><b>Rock rabbit</b></col>
<fld>(Zool.)</fld>, <cd>the hyrax. See <er>Cony</er>, and
<er>Daman</er>.</cd> -- <col><b>Rock ruby</b></col> <fld>(Min.)</fld>,
<cd>a fine reddish variety of garnet.</cd> -- <col><b>Rock
salt</b></col> <fld>(Min.)</fld>, <cd>cloride of sodium (common salt)
occuring in rocklike masses in mines; mineral salt; salt dug from the
earth. In the United States this name is sometimes given to salt in
large crystals, formed by evaporation from sea water in large basins or
cavities.</cd> -- <col><b>Rock seal</b></col> <fld>(Zool.)</fld>,
<cd>the harbor seal. See <er>Seal</er>.</cd> -- <col><b>Rock
shell</b></col> <fld>(Zool.)</fld>, <cd>any species of Murex, Purpura,
and allied genera.</cd> -- <col><b>Rock snake</b></col>
<fld>(Zool.)</fld>, <cd>any one of several large pythons; as, the royal
<stype>rock snake</stype> (<spn>Python regia</spn>) of Africa, and the
<stype>rock snake</stype> of India (<spn>Python molurus</spn>). The
Australian rock snakes mostly belong to the allied genus
<gen>Morelia</gen>.</cd> -- <col><b>Rock snipe</b></col>
<fld>(Zool.)</fld>, <cd>the purple sandpiper (<spn>Tringa
maritima</spn>); -- called also <altname>rock bird</altname>,
<altname>rock plover</altname>, <altname>winter snipe</altname>.</cd> --
<col><b>Rock soap</b></col> <fld>(Min.)</fld>, <cd>a kind of clay having
a smooth, greasy feel, and adhering to the tongue.</cd> -- <col><b>Rock
sparrow</b></col>. <fld>(Zool.)</fld> <sd>(a)</sd> <cd>Any one of
several species of Old World sparrows of the genus <gen>Petronia</gen>,
as <spn>Petronia stulla</spn>, of Europe.</cd> <sd>(b)</sd> <cd>A North
American sparrow (<spn>Pucaea ruficeps</spn>).</cd> -- <col><b>Rock
tar</b></col>, <cd>petroleum.</cd> -- <col><b>Rock thrush</b></col>
<fld>(Zool.)</fld>, <cd>any Old World thrush of the genus
<gen>Monticola</gen>, or <gen>Petrocossyphus</gen>; <as>as, the European
<ex>rock thrush</ex> (<spn>Monticola saxatilis</spn>), and the blue
<ex>rock thrush</ex> of India (<spn>Monticola cyaneus</spn>), in which
the male is blue throughout</as>.</cd> -- <col><b>Rock tripe</b></col>
<fld>(Bot.)</fld>, <cd>a kind of lichen (<spn>Umbilicaria
Dillenii</spn>) growing on rocks in the northen parts of America, and
forming broad, flat, coriaceous, dark fuscous or blackish expansions. It
has been used as food in cases of extremity.</cd> -- <col><b>Rock
trout</b></col> <fld>(Zool.)</fld>, <cd>any one of several species of
marine food fishes of the genus <gen>Hexagrammus</gen>, family
<fam>Chiradae</fam>, native of the North Pacific coasts; -- called also
<altname>sea trout</altname>, <altname>boregat</altname>,
<altname>bodieron</altname>, and <altname>starling</altname>.</cd> --
<col><b>Rock warbler</b></col> <fld>(Zool.)</fld>, <cd>a small
Australian singing bird (<spn>Origma rubricata</spn>) which frequents
rocky ravines and water courses; -- called also <altname>cataract
bird</altname>.</cd> -- <col><b>Rock wren</b></col> <fld>(Zool.)</fld>,
<cd>any one of several species of wrens of the genus
<gen>Salpinctes</gen>, native of the arid plains of Lower California and
Mexico.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rock</ent><br/
<hw>Rock</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Rocked</conjf> <pr>(?)</pr>;<pos>p. pr. & vb. n.</pos>
<conjf>Rocking</conjf>.]</vmorph> <ety>[AS. <ets>roccian</ets>; akin to
Dan. <ets>rokke</ets> to move, to snake; cf. Icel. <ets>rukkja</ets> to
pull, move, G. <ets>r<uum/cken</ets> to move, push, pull.]</ety>
<sn>1.</sn> <def>To cause to sway backward and forward, as a body
resting on a support beneath; <as>as, to <ex>rock</ex> a cradle or
chair</as>; to cause to vibrate; to cause to reel or totter.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A rising earthquake <qex>rocked</qex> the ground.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To move as in a cradle; hence, to put to sleep by
rocking; to still; to quiet.</def> <ldquo/Sleep <xex>rock</xex> thy
brain.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Rock</xex> differs from <xex>shake</xex>, as
denoting a slower, less violent, and more uniform motion, or larger
movements. It differs from <xex>swing</xex>, which expresses a vibratory
motion of something suspended.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rock</ent><br/
<hw>Rock</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To move or be moved
backward and forward; to be violently agitated; to reel; to
totter.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>rocking</qex> town<br/
Supplants their footsteps.</q> <rj><qau>J. Philips .</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To roll or saway backward and forward upon a
support; <as>as, to <ex>rock</ex> in a rocking-chair</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rockaway</ent><br/
<hw>Rock"a*way</hw> <pr>(?)</pr>, <ety>[Probably from
<ets>Rockaway</ets> beach, where it was used.]</ety> <def>Formerly, a
light, low, four-wheeled carriage, with standing top, open at the sides,
but having waterproof curtains which could be let down when occasion
required; now, a somewhat similar, but heavier, carriage, inclosed,
except in front, and having a door at each side.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rocklay</ent><br/
<ent>Rockelay</ent><br/
<mhw>{ <hw>Rock"e*lay</hw> <pr>(?)</pr>, <hw>Rock"lay</hw> <pr>(?)</pr>
}</mhw>, <pos>n.</pos> <def>See <er>Rokelay</er>.</def>
<mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rocker</ent><br/
<hw>Rock"er</hw>, <pos>n.</pos> <sn>1.</sn> <def>One who rocks;
specifically, one who rocks a cradle.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It was I, sir, said the <qex>rocker</qex>, who had the honor, some
thirty years since, to attend on your highness in your infancy.</q>
<rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One of the curving pieces of wood or metal on which
a cradle, chair, etc., rocks.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Any implement or machine working with a rocking
motion, as a trough mounted on rockers for separating gold dust from
gravel, etc., by agitation in water.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A play horse on rockers; a rocking-horse.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A chair mounted on rockers; a
rocking-chair.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>A skate with a curved blade, somewhat resembling in
shape the rocker of a cradle.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Mach.)</fld> <def>Same as <er>Rock
shaft</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Rocker arm</b></col> <fld>(Mach.)</fld>, <cd>an arm borne
by a rock shaft.</cd></cs> <-- <col><b>To be off one's rocker</b></col>,
<cd>to be insane.</cd> --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rockered</ent><br/
<hw>Rock"ered</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Naut.)</fld>
<def>Shaped like a rocker; curved; <as>as, a <ex>rockered</ex>
keel</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rockery</ent><br/
<hw>Rock"er*y</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Gardening)</fld>
<def>A mound formed of fragments of rock, earth, etc., and set with
plants.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rocket</ent><br/
<hw>Rock"et</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>roquette</ets> (cf. Sp. <ets>ruqueta</ets>, It
<ets>ruchetta</ets>), fr. L. <ets>eruca</ets>.]</ety> <fld>(Bot.)</fld>
<sd>(a)</sd> <def>A cruciferous plant (<spn>Eruca sativa</spn>)
sometimes eaten in Europe as a salad.</def> <sd>(b)</sd>
<def>Damewort.</def> <sd>(c)</sd> <def>Rocket larkspur. See
below.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dyer's Rocket</b></col>. <fld>(Bot.)</fld> <cd>See
<cref>Dyer's broom</cref>, under <er>Broom</er>.</cd> -- <col><b>Rocket
larkspur</b></col> <fld>(Bot.)</fld>, <cd>an annual plant with showy
flowers in long racemes (<spn>Delphinium Ajacis</spn>).</cd> --
<col><b>Sea rocket</b></col> <fld>(Bot.)</fld>, <cd>either of two fleshy
cruciferous plants (<spn>Cakile maritima</spn> and <spn>Cakile
Americana</spn>) found on the seashore of Europe and America.</cd> --
<col><b>Yellow rocket</b></col> <fld>(Bot.)</fld>, <cd>a common
cruciferous weed with yellow flowers (<spn>Barbarea
vulgaris</spn>).</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rocket</ent><br/
<hw>Rock"et</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[It.
<ets>rocchetta</ets>, fr. <ets>rocca</ets> a distaff, of German origin.
Named from the resemblance in shape to a distaff. See <er>Rock</er> a
distaff.]</ety> <sn>1.</sn> <def>An artificial firework consisting of a
cylindrical case of paper or metal filled with a composition of
combustible ingredients, as niter, charcoal, and sulphur, and fastened
to a guiding stick. The rocket is projected through the air by the force
arising from the expansion of the gases liberated by combustion of the
composition. Rockets are used as projectiles for various purposes, for
signals, and also for pyrotechnic display.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A blunt lance head used in the joust.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>any flying device propelled by the reactive force of
hot gases expelled in the direction opposite its motion. The fuel used
to generate the expelled gases in rockets may be solid or liquid;
rockets propelled by liquid fuels typically have a combustible fuel
(such as hydrogen or kerosene) which is combined inside the rocket
engine with an oxidizer, such as liquid oxygen. Single liquid fuels
(called monopropellants) are also known. Since rocket engines do not
depend on a surrounding fluid medium to generate their thrust, as do
airplanes with propellers or jet engines, they may be used for
propulsion in the vacuum of space.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Congreve rocket</b></col>, <cd>a powerful form of rocket
for use in war, invented by Sir William Congreve. It may be used either
in the field or for bombardment; in the former case, it is armed with
shells or case shot; in the latter, with a combustible material inclosed
in a metallic case, which is inextinguishable when kindled, and scatters
its fire on every side.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rocket</ent><br/
<hw>Rock"et</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Rocketed</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Rocketing</conjf>.]</vmorph> <fld>(Sporting)</fld> <def>To rise
straight up; said of birds; usually in the present participle or as an
adjective.</def> <mark>[Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>An old cock pheasant came <qex>rocketing</qex> over me.</q>
<rj><qau>H. R. Haggard.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rocketer</ent><br/
<hw>Rock"et*er</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Sporting)</fld>
<def>A bird, especially a pheasant, which, being flushed, rises straight
in the air like a rocket.</def> <mark>[Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rocket scientist</ent><br/
<hw>Rock"et sci"en*tist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>a very
intelligent person; -- used mostly in the phrases: <ldquo/you don't have
to be a <ex>rocket scientist</ex> to . . .<rdquo/ and <ldquo/it doesn't
take a <ex>rocket</ex> scientist to . . .<rdquo/, meaning that the
subject that follows is easy to understand.</def><br/
[<source>PJC</source>]</p>

<p><ent>Rockfish</ent><br/
<hw>Rock"fish`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<sd>(a)</sd> <def>Any one of several California scorpaenoid food fishes
of the genus <gen>Sebastichthys</gen>, <as>as the red <ex>rockfish</ex>
(<spn>Sebastichthys ruber</spn>)</as>. They are among the most important
of California market fishes. Called also <altname>rock cod</altname>,
and <altname>garrupa</altname>.</def> <sd>(b)</sd> <def>The striped
bass. See <er>Bass</er>.</def> <sd>(c)</sd> <def>Any one of several
species of Florida and Bermuda groupers of the genus
<gen>Epinephelus</gen>.</def> <sd>(d)</sd> <def>An American fresh-water
darter; the log perch.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The term is locally applied to various other
fishes.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rockiness</ent><br/
<hw>Rock"i*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<er>Rocky</er>.]</ety> <def>The state or quality of being
rocky.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rocking</ent><br/
<hw>Rock"ing</hw>, <pos>a.</pos> <def>Having a swaying, rolling, or
back-and-forth movement; used for rocking.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Rocking shaft</b></col>. <fld>(Mach.)</fld> <cd>See
<er>Rock shaft</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rocking-chair</ent><br/
<hw>Rock"ing-chair`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A chair
mounted on rockers, in which one may rock.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rocking-horse</ent><br/
<hw>Rock"ing-horse`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The figure of
a horse, mounted upon rockers, for children to ride.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rocking-stone</ent><br/
<hw>Rock"ing-stone`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A stone, often
of great size and weight, resting upon another stone, and so exactly
poised that it can be rocked, or slightly moved, with but little
force.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rockless</ent><br/
<hw>Rock"less</hw>, <pos>a.</pos> <def>Being without rocks.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rockling</ent><br/
<hw>Rock"ling</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>Any species of small marine fishes of the genera <gen>Onos</gen>
and <gen>Rhinonemus</gen> (formerly <gen>Motella</gen>), allied to the
cod. They have three or four barbels.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rockrose</ent><br/
<hw>Rock"rose`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>A
name given to any species of the genus <gen>Helianthemum</gen>, low
shrubs or herbs with yellow flowers, especially the European
<spn>Helianthemum vulgare</spn> and the American frostweed,
<spn>Helianthemum Canadense</spn>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Cretan rockrose</b></col>, <cd>a related shrub
(<spn>Cistus Creticus</spn>), one of the plants yielding the fragrant
gum called <prod>ladanum</prod>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rock shaft</ent><br/
<hw>Rock" shaft`</hw> <pr>(?)</pr>. <ety>[Cf. <er>Rock</er>, <ets>v.
i.</ets>]</ety> <fld>(Mach.)</fld> <def>A shaft that oscillates on its
journals, instead of revolving, -- usually carrying levers by means of
which it receives and communicates reciprocating motion, as in the valve
gear of some steam engines; -- called also <altname>rocker</altname>,
<altname>rocking shaft</altname>, and <altname>way
shaft</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rock staff</ent><br/
<hw>Rock" staff`</hw> <pr>(?)</pr>. <ety>[Cf. <er>Rock</er>, <pos>v.
i.</pos>]</ety> <def>An oscillating bar in a machine, as the lever of
the bellows of a forge.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rocksucker</ent><br/
<hw>Rock"suck`er</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>A lamprey.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rockweed</ent><br/
<hw>Rock"weed`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>Any coarse seaweed growing on sea-washed rocks, especially
Fucus.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1248 --></p>

<p><ent>Rockwood</ent><br/
<hw>Rock"wood`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Min.)</fld>
<def>Ligniform asbestus; also, fossil wood.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rockwork</ent><br/
<hw>Rock"work`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<fld>(Arch.)</fld> <def>Stonework in which the surface is left broken
and rough.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Gardening)</fld> <def>A rockery.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rocky</ent><br/
<hw>Rock"y</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Full of, or
abounding in, rocks; consisting of rocks; <as>as, a <ex>rocky</ex>
mountain; a <ex>rocky</ex> shore</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Like a rock; <as>as, the <ex>rocky</ex> orb of a
shield</as>.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Fig.: Not easily impressed or affected; hard;
unfeeling; obdurate; <as>as, a <ex>rocky</ex> bosom</as>.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Rocky Mountain locust</b></col> <fld>(Zool.)</fld>,
<cd>the Western locust, or grasshopper. See <er>Grasshopper</er>.</cd>
-- <col><b>Rocky Mountain sheep</b></col>. <fld>(Zool.)</fld> <cd>See
<er>Bighorn</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rocoa</ent><br/
<hw>Ro"coa</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>rocou</ets>, <ets>roicou</ets>, Pg. & Braz,
<ets>uruc<uacute/</ets>.]</ety> <def>The orange-colored pulp covering
the seeds of the tropical plant <spn>Bixa Orellana</spn>, from which
annotto is prepared. See <er>Annoto</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rococo</ent><br/
<hw>Ro*co"co</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.; of uncertain
etymology.]</ety> <def>A florid style of ornamentation which prevailed
in Europe in the latter part of the eighteenth century.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rococo</ent><br/
<hw>Ro*co"co</hw>, <pos>a.</pos> <def>Of or pertaining to the style
called rococo; like rococo; florid; fantastic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rod</ent><br/
<hw>Rod</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[The same word as
<ets>rood</ets>. See <er>Rood</er>.]</ety> <sn>1.</sn> <def>A straight
and slender stick; a wand; hence, any slender bar, as of wood or metal
(applied to various purposes).</def> Specifically: <sd>(a)</sd> <def>An
instrument of punishment or correction; figuratively,
chastisement.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He that spareth his <qex>rod</qex> hateth his son.</q>
<rj><qau>Prov. xiii. 24.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(b)</sd> <def>A kind of sceptor, or badge of office; hence,
figuratively, power; authority; tyranny; oppression.</def> <ldquo/The
<xex>rod</xex>, and bird of peace.<rdquo/ <au>Shak.</au> <sd>(c)</sd>
<def>A support for a fishing line; a fish pole.</def> <au>Gay.</au>
<sd>(d)</sd> <fld>(Mach. & Structure)</fld> <def>A member used in
tension, as for sustaining a suspended weight, or in tension and
compression, as for transmitting reciprocating motion, etc.; a
connecting bar.</def> <sd>(e)</sd> <def>An instrument for
measuring.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A measure of length containing sixteen and a half
feet; -- called also <altname>perch</altname>, and
<altname>pole</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Black rod</b></col>. <cd>See in the Vocabulary.</cd> --
<col><b>Rods and cones</b></col> <fld>(Anat.)</fld>, <cd>the elongated
cells or elements of the sensory layer of the retina, some of which are
cylindrical, others somewhat conical.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roddy</ent><br/
<hw>Rod"dy</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Full of rods or
twigs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roddy</ent><br/
<hw>Rod"dy</hw>, <pos>a.</pos> <def>Ruddy.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rode</ent><br/
<hw>Rode</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See <er>Rud</er>.]</ety>
<def>Redness; complexion.</def> <mark>[Obs.]</mark> <ldquo/His
<xex>rode</xex> was red.<rdquo/ <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rode</ent><br/
<hw>Rode</hw>, <def><pos>imp.</pos> of <er>Ride</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rode</ent><br/
<hw>Rode</hw>, <pos>n.</pos> <def>See <er>Rood</er>, the cross.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rodent</ent><br/
<hw>Ro"dent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>rodens</ets>,
<ets>-entis</ets>, p. pr. of <ets>rodere</ets> to gnaw. See
<er>Rase</er>, <pos>v. t.</pos>, and cf. <er>Rostrum</er>.]</ety>
<sn>1.</sn> <def>Gnawing; biting; corroding; <fld>(Med.)</fld> applied
to a destructive variety of cancer or ulcer.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <sd>(a)</sd> <def>Gnawing.</def>
<sd>(b)</sd> <def>Of or pertaining to the Rodentia.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rodent</ent><br/
<hw>Ro"dent</hw>, <pos>n.</pos> <fld>(Zool.)</fld> <def>One of the
Rodentia.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rodentia</ent><br/
\'d8<hw>Ro*den"ti*a</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL. See
<er>Rodent</er>, <pos>a.</pos>]</ety> <fld>(Zool.)</fld> <def>An order
of mammals having two (rarely four) large incisor teeth in each jaw,
distant from the molar teeth. The rats, squirrels, rabbits, marmots, and
beavers belong to this order.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The incisor teeth are long, curved, and strongly
enameled on the outside, so as to keep a cutting edge. They have a
persistent pulp and grow continuously.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rodeo</ent><br/
\'d8<hw>Ro*de"o</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[SP., a going
round.]</ety> <def>A round-up. See <er>Round-up</er>.</def>
<mark>[Western U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rodge</ent><br/
<hw>Rodge</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>The
gadwall.</def> <mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rodomel</ent><br/
<hw>Rod"o*mel</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/<?/<?/ rose
+ <?/<?/<?/ honey.]</ety> <def>Juice of roses mixed with honey.</def>
<rj><au>Simmonds.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rodomont</ent><br/
<hw>Rod"o*mont</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>rodomont</ets>, It. <ets>rodomonte</ets>, fr. <ets>Rodomonte</ets>,
<ets>Rodamonte</ets>, a boasting hero in the <ldquo/Orlando
Furioso<rdquo/ of Ariosto, and the <ldquo/Orlando Innamorato<rdquo/ of
Bojardo; properly, one who rolls away mountains; Prov. It.
<ets>rodare</ets> to roll away (fr. L. <ets>rota</ets> a wheel) + It.
<ets>monte</ets> a mountain, L. <ets>mons</ets>. See <er>Rotary</er>,
<er>Mount</er>, <pos>n.</pos>]</ety> <def>A vain or blustering boaster;
a braggart; a braggadocio.</def> <rj><au>Sir T. Herbert.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rodomont</ent><br/
<hw>Rod"o*mont</hw>, <pos>a.</pos> <def>Bragging; vainly
boasting.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rodomontade</ent><br/
<hw>Rod`o*mon*tade"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr. It.
<ets>rodomontana</ets>. See <er>Rodomont</er>, <pos>n.</pos>]</ety>
<def>Vain boasting; empty bluster or vaunting; rant.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I could show that the <qex>rodomontades</qex> of Almanzor are
neither so irrational nor impossible.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rodomontade</ent><br/
<hw>Rod`o*mon*tade"</hw>, <pos>v. i.</pos> <def>To boast; to brag; to
bluster; to rant.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rodomontadist</ent><br/
<hw>Rod`o*mon*tad"ist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
boasts.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rodomontado</ent><br/
<hw>Rod`o*mon*ta"do</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Rodomontade.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rodomontador</ent><br/
<hw>Rod`o*mon*ta"dor</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A
rodomontadist.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rodsman</ent><br/
<hw>Rods"man</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Rodsmen</plw> <pr>(<?/)</pr>.</plu> <def>One who carries and holds
a leveling staff, or rod, in a surveying party.</def> <rj><au>G. W.
Cable.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rody</ent><br/
<hw>Ro"dy</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Ruddy.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roe</ent><br/
<hw>Roe</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>ro</ets>, AS.
<ets>r<amac/h</ets>; akin to D. <ets>ree</ets>, G. <ets>reh</ets>, Icel.
<ets>r<amac/</ets>, SW. <ets>r<aring/</ets>.]</ety> <fld>(Zool.)</fld>
<sd>(a)</sd> <def>A roebuck. See <er>Roebuck</er>.</def> <sd>(b)</sd>
<def>The female of any species of deer.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roe</ent><br/
<hw>Roe</hw>, <pos>n.</pos> <ety>[For <ets>roan</ets>, OE.
<ets>rowne</ets>, akin to G. <ets>rogen</ets>, OHG. <ets>rogan</ets>,
Icel. <ets>hrogn</ets>, Dan. <ets>rogn</ets>, <ets>ravn</ets>, Sw.
<ets>rom</ets>; of uncertain origin; cf. Gr. <?/<?/<?/ pebble, Skr.
<ets><?/arkar<amac/</ets> gravel.]</ety> <sn>1.</sn> <fld>(Zool.)</fld>
<def>The ova or spawn of fishes and amphibians, especially when still
inclosed in the ovarian membranes. Sometimes applied, loosely, to the
sperm and the testes of the male.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A mottled appearance of light and shade in wood,
especially in mahogany.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roebuck</ent><br/
<hw>Roe"buck`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[1st <ets>roe</ets>
+ <ets>buck</ets>.]</ety> <fld>(Zool.)</fld> <def>A small European and
Asiatic deer (<spn>Capreolus capraea</spn>) having erect, cylindrical,
branched antlers, forked at the summit. This, the smallest European
deer, is very nimble and graceful. It always prefers a mountainous
country, or high grounds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roe, Richard</ent><br/
<hw>Roe, Richard</hw>. <fld>(Law)</fld> <def>A fictious name for a
party, real or fictious, to an act or proceeding. Other names were
formerly similarly used, as <altname>John-a-Nokes</altname>, <xex>John
o'</xex>, or <xex>of the</xex>, <xex>Nokes</xex>, or <xex>Noakes</xex>,
<altname>John-a-Stiles</altname>, etc.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Roed</ent><br/
<hw>Roed</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld> <def>Filled
with roe.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roedeer</ent><br/
<hw>Roe"deer`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>The roebuck.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roentgen ray</ent><br/
<hw>Roentgen ray</hw> <def>the Anglicised spelling of
<altname>R<oum/ntgen ray</altname>. Same as <er>X ray</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Roestone</ent><br/
<hw>Roe"stone`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Min.)</fld>
<def>Same as <er>Oolite</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>rofecoxib</ent><br/
<hw>rofecoxib</hw> <fld>(Chem. & Med.)</fld> <def>A chemical substance
(<chform>C17H14O4S</chform>, molecular weight 314.36) used in medicine
as an <isa>analgesic</isa> to alleviate pain and inflammation; it is a
synthetic compound, and is marketed by <company>Merck & Co.</company>
under the trade name <altname>Vioxx</altname>, in tablets giving dosages
of 12.5 or 25 milligrams. It is classed as <isa>a non-steroidal
anti-inflammatory drug</isa> (<isa>NSAID</isa>). Chemically, it is
4-[4-(methylsulfony)phenyl]-3-phenyl-2(5H) furanone. Its chemical
structure contains two phenyl rings and a furanone ring. It is believed
to act by inhibition of prostaglandin biosynthesis, through inhibition
of the enzyme cyclooxygenase-2 (COX-2); unlike <contr>aspirin</contr>,
it does not inhibit cyclooxygenase-1.</def><br/
[<source>PJC</source>]</p>

<p><ent>Rogation</ent><br/
<hw>Ro*ga"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>rogatio</ets>, fr. <ets>rogare</ets>, <ets>rogatum</ets>, to ask,
beg, supplicate: cf. F. <ets>rogation</ets>. Cf. <er>Abrogate</er>,
<er>Arrogant</er>, <er>Probogue</er>.]</ety> <sn>1.</sn> <fld>(Rom.
Antiq.)</fld> <def>The demand, by the consuls or tribunes, of a law to
be passed by the people; a proposed law or decree.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Eccl.)</fld> <def>Litany; supplication.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He perfecteth the <qex>rogations</qex> or litanies before in
use.</q> <rj><qau>Hooker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Rogation days</b></col> <fld>(Eccl.)</fld>, <cd>the three
days which immediately precede Ascension <er>Day</er>; -- so called as
being days on which the people, walking in procession, sang litanies of
special supplication.</cd> -- <col><b>Rogation flower</b></col>
<fld>(Bot.)</fld>, <cd>a European species of milkwort (<spn>Polygala
vulgaris</spn>); -- so called from its former use for garlands in
Rogation week.</cd> <au>Dr. Prior.</au> -- <col><b>Rogation
week</b></col>, <cd>the second week before Whitsunday, in which the
Rogation days occur.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rogatory</ent><br/
<hw>Rog"a*to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Rogation</er>.]</ety> <def>Seeking information; authorized to
examine witnesses or ascertain facts; <as>as, a <ex>rogatory</ex>
commission</as>.</def> <rj><au>Woolsey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roger</ent><br/
<hw>Rog"er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From a proper name
<ets>Roger</ets>.]</ety> <def>A black flag with white skull and
crossbones, formerly used by pirates; -- called also <altname>Jolly
Roger</altname> and <altname>pirate flag</altname>.</def><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><ent>Rogue</ent><br/
<hw>Rogue</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>rogue</ets>
proud, haughty, supercilious; cf. Icel. <ets>hr<?/kr</ets> a rook,
croaker (cf. <er>Rook</er> a bird), or Armor. <ets>rok</ets>,
<ets>rog</ets>, proud, arogant.]</ety> <sn>1.</sn> <fld>(Eng.Law)</fld>
<def>A vagrant; an idle, sturdy beggar; a vagabond; a tramp.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The phrase <xex>rogues and vagabonds</xex> is applied to
a large class of wandering, disorderly, or dissolute persons. They were
formerly punished by being whipped and having the gristle of the right
ear bored with a hot iron.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A deliberately dishonest person; a knave; a
cheat.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>rogue</qex> and fool by fits is fair and wise.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>One who is pleasantly mischievous or frolicsome;
hence, often used as a term of endearment.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Ah, you sweet little <qex>rogue</qex>, you!</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>An elephant that has separated from a herd and roams
about alone, in which state it is very savage.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Hort.)</fld> <def>A worthless plant occuring among
seedlings of some choice variety.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Rogues' gallery</b></col>, <cd>a collection of portraits
of rogues or criminals, for the use of the police authorities.</cd> --
<col><b>Rogue's march</b></col>, <cd>derisive music performed in driving
away a person under popular indignation or official sentence, as when a
soldier is drummed out of a regiment.</cd> -- <col><b>Rogue's
yarn</b></col>, <cd>yarn of a different twist and color from the rest,
inserted into the cordage of the British navy, to identify it if stolen,
or for the purpose of tracing the maker in case of defect. Different
makers are required to use yarns of different colors.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rogue</ent><br/
<hw>Rogue</hw>, <pos>v. i.</pos> <def>To wander; to play the vagabond;
to play knavish tricks.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rogue</ent><br/
<hw>Rogue</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To give the name or
designation of rogue to; to decry.</def> <mark>[Obs.]</mark>
<rj><au>Cudworth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Hort.)</fld> <def>To destroy (plants that do not
come up to a required standard).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roguery</ent><br/
<hw>Rogu"er*y</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The life
of a vargant.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The practices of a rogue; knavish tricks; cheating;
fraud; dishonest practices.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>'Tis no scandal grown,<br/
For debt and <qex>roguery</qex> to quit the town.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Arch tricks; mischievousness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rogueship</ent><br/
<hw>Rogue"ship</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The quality or
state of being a rogue.</def> <mark>[Jocose]</mark> <ldquo/Your
<xex>rogueship</xex>.<rdquo/ <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roguish</ent><br/
<hw>Rogu"ish</hw>, <pos>a.</pos> <sn>1.</sn> <def>Vagrant.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>His <qex>roguish</qex> madness<br/
Allows itself to anything.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Resembling, or characteristic of, a rogue;
knavish.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Pleasantly mischievous; waggish; arch.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The most bewitching leer with her eyes, the most
<qex>roguish</qex> cast.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Rogu"ish*ly</wf>, <pos>adv.</pos> --
<wf>Rogu"ish*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roguy</ent><br/
<hw>Rogu"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Roguish.</def>
<mark>[Obs.]</mark> <rj><au>L'Estrange.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rohob</ent><br/
<hw>Ro"hob</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An inspissated juice.
See <er>Rob</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roial</ent><br/
<hw>Roi"al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Royal.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roil</ent><br/
<hw>Roil</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Roiled</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Roiling</conjf>.]</vmorph> <ety>[Cf. OE. <ets>roilen</ets> to
wander; possibly fr. OF. <ets>roeler</ets> to roll, equiv. to F.
<ets>rouler</ets>. See <er>Roll</er>, <pos>v.</pos>, and cf.
<er>Rile</er>.]</ety> <sn>1.</sn> <def>To render turbid by stirring up
the dregs or sediment of; <as>as, to <ex>roil</ex> wine, cider,
etc.</as> , in casks or bottles; to <xex>roil</xex> a spring.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To disturb, as the temper; to ruffle the temper of;
to rouse the passion of resentment in; to perplex.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That his friends should believe it, was what <qex>roiled</qex> him
[Judge Jeffreys] exceedingly.</q> <rj><qau>R. North.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Provincial in England and colloquial in the United
States. A commoner, but less approved, form is
<xex>rile</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roil</ent><br/
<hw>Roil</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To wander; to
roam.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To romp.</def> <mark>[Prov. Eng.]</mark>
<rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roily</ent><br/
<hw>Roil"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Turbid; <as>as,
<ex>roily</ex> water</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roin</ent><br/
<hw>Roin</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>See
<er>Royne</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roin</ent><br/
<hw>Roin</hw>, <pos>n.</pos> <ety>[F. <ets>rogne</ets>. See
<er>Roynish</er>.]</ety> <def>A scab; a scurf, or scurfy spot.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roinish</ent><br/
<hw>Roin"ish</hw>, <pos>a.</pos> <def>See <er>Roynish</er>.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roint</ent><br/
<hw>Roint</hw> <pr>(?)</pr>, <pos>interj.</pos> <def>See
<er>Aroint</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roist</ent><br/
<hw>Roist</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>See
<er>Roister</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roister</ent><br/
<hw>Roist"er</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[Probably fr. F.
<ets>rustre</ets> boor, a clown, clownish, fr. L. <ets>rustucus</ets>
rustic. See <er>Rustic</er>.]</ety> <def>To bluster; to swagger; to
bully; to be bold, noisy, vaunting, or turbulent.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I have a <qex>roisting</qex> challenge sent amongst<br/
The dull and factious nobles of the Greeks.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roister</ent><br/
<hw>Roist"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Roisterer</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roisterer</ent><br/
<hw>Roist"er*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A blustering,
turbulent fellow.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If two <qex>roisterers</qex> met, they cocked their hats in each
other faces.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roisterly</ent><br/
<hw>Roist"er*ly</hw>, <pos>a.</pos> <def>Blustering; violent.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roisterly</ent><br/
<hw>Roist"er*ly</hw>, <pos>adv.</pos> <def>In a roistering manner.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rokambole</ent><br/
<hw>Rok"am*bole</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Rocambole</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roke</ent><br/
<hw>Roke</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Reek</er>.]</ety> <sn>1.</sn> <def>Mist; smoke; damp</def>
<mark>[Prov. Eng.]</mark> <altsp>[Written also <asp>roak</asp>,
<asp>rook</asp>, and <asp>rouk</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A vein of ore.</def> <mark>[Pov.Eng.]</mark>
<rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rokee</ent><br/
<ent>Rokeage</ent><br/
<mhw>{ <hw>Roke"age</hw> <pr>(?)</pr>, <hw>Rok"ee</hw> <pr>(?)</pr>,
}</mhw> <pos>n.</pos> <ety>[Cf. <er>Nocake</er>.]</ety> <def>Parched
Indian corn, pounded up and mixed with sugar; -- called also
<altname>yokeage</altname>.</def> <mark>[Local, U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rokelay</ent><br/
<hw>Rok"e*lay</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf.
<er>Roquelaure</er>.]</ety> <def>A short cloak.</def> <altsp>[Written
also <asp>rockelay</asp>, <asp>rocklay</asp>, etc.]</altsp>
<mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roky</ent><br/
<hw>Rok"y</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Roke</er>.]</ety> <def>Misty; foggy; cloudy.</def> <mark>[Prov.
Eng.]</mark> <rj><au>Ray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Role</ent><br/
<mhw><hw>Role</hw>, <hw>R<ocir/le</hw></mhw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[F. See <er>Roll</er>.]</ety> <def>A part, or character, performed
by an actor in a drama; hence, a part of function taken or assumed by
any one; <as>as, he has now taken the <ex>role</ex> of
philanthropist</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Title role</b></col>, <cd>the part, or character, which
gives the title to a play, as the part of Hamlet in the play of that
name.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roll</ent><br/
<hw>Roll</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Rolled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Rolling</conjf>.]</vmorph> <ety>[OF. <ets>roeler</ets>,
<ets>roler</ets>, F. <ets>rouler</ets>, LL. <ets>rotulare</ets>, fr. L.
<ets>royulus</ets>, <ets>rotula</ets>, a little wheel, dim. of
<ets>rota</ets> wheel; akin to G. <ets>rad</ets>, and to Skr.
<ets>ratha</ets> car, chariot. Cf. <er>Control</er>, <er>Roll</er>,
<pos>n.</pos>, <er>Rotary</er>.]</ety> <sn>1.</sn> <def>To cause to
revolve by turning over and over; to move by turning on an axis; to
impel forward by causing to turn over and over on a supporting surface;
<as>as, to <ex>roll</ex> a wheel, a ball, or a barrel</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To wrap round on itself; to form into a spherical or
cylindrical body by causing to turn over and over; <as>as, to
<ex>roll</ex> a sheet of paper; to <ex>roll</ex> parchment; to
<ex>roll</ex> clay or putty into a ball.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To bind or involve by winding, as in a bandage; to
inwrap; -- often with <xex>up</xex>; <as>as, to <ex>roll</ex> up a
parcel</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To drive or impel forward with an easy motion, as of
rolling; <as>as, a river <ex>rolls</ex> its waters to the
ocean</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The flood of Catholic reaction was <qex>rolled</qex> over
Europe.</q> <rj><qau>J. A. Symonds.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To utter copiously, esp. with sounding words; to
utter with a deep sound; -- often with <xex>forth</xex>, or
<xex>out</xex>; <as>as, to <ex>roll</ex> forth some one's praises; to
<ex>roll</ex> out sentences.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Who <qex>roll'd</qex> the psalm to wintry skies.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To press or level with a roller; to spread or form
with a roll, roller, or rollers; <as>as, to <ex>roll</ex> a field; to
<ex>roll</ex> paste; to <ex>roll</ex> steel rails, etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>To move, or cause to be moved, upon, or by means of,
rollers or small wheels.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>To beat with rapid, continuous strokes, as a drum;
to sound a roll upon.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <fld>(Geom.)</fld> <def>To apply (one line or surface) to
another without slipping; to bring all the parts of (one line or
surface) into successive contact with another, in suck manner that at
every instant the parts that have been in contact are equal.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <def>To turn over in one's mind; to revolve.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Full oft in heart he <qex>rolleth</qex> up and down<br/
The beauty of these florins new and bright.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- 11. To rob, usu. a person unable to resist, as an unconscious,
drunk, or sleeping person, by removing valuables on his person; as, to
roll a drunk. --><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To roll one's self</b></col>, <cd>to wallow.</cd> --
<col><b>To roll the eye</b></col>, <cd>to direct its axis hither and
thither in quick succession.</cd> -- <col><b>To roll one's
r's</b></col>, <cd>to utter the letter <xex>r</xex> with a trill.</cd>
<mark>[Colloq.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roll</ent><br/
<hw>Roll</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To move, as a curved
object may, along a surface by rotation without sliding; to revolve upon
an axis; to turn over and over; <as>as, a ball or wheel <ex>rolls</ex>
on the earth; a body <ex>rolls</ex> on an inclined plane.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>And her foot, look you, is fixed upon a spherical stone, which
<qex>rolls</qex>, and <qex>rolls</qex>, and <qex>rolls</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To move on wheels; <as>as, the carriage
<ex>rolls</ex> along the street</as>.</def> <ldquo/The
<xex>rolling</xex> chair.<rdquo/ <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To be wound or formed into a cylinder or ball;
<as>as, the cloth <ex>rolls</ex> unevenly; the snow <ex>rolls</ex>
well.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To fall or tumble; -- with <xex>over</xex>; <as>as,
a stream <ex>rolls</ex> over a precipice</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To perform a periodical revolution; to move onward
as with a revolution; <as>as, the <ex>rolling</ex> year; ages
<ex>roll</ex> away.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To turn; to move circularly.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And his red eyeballs <qex>roll</qex> with living fire.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>To move, as waves or billows, with alternate swell
and depression.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>What different sorrows did within thee <qex>roll</qex>.</q>
<rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>To incline first to one side, then to the other; to
rock; <as>as, there is a great difference in ships about
<ex>rolling</ex></as>; in a general semse, to be tossed about.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Twice ten tempestuous nights I <qex>rolled</qex>.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>To turn over, or from side to side, while lying
down; to wallow; <as>as, a horse <ex>rolls</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <def>To spread under a roller or rolling-pin; <as>as,
the paste <ex>rolls</ex> well</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>11.</sn> <def>To beat a drum with strokes so rapid that they can
scarcely be distinguished by the ear.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>12.</sn> <def>To make a loud or heavy rumbling noise; <as>as, the
thunder <ex>rolls</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To roll about</b></col>, <cd>to gad abroad.</cd>
<mark>[Obs.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><q>Man shall not suffer his wife go <qex>roll about</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roll</ent><br/
<hw>Roll</hw>, <pos>n.</pos> <ety>[F. <ets>r<ocir/le</ets> a roll (in
sense 3), fr. L. <ets>rotulus <?/</ets> little wheel, LL., a roll, dim.
of L. <ets>rota</ets> a wheel. See <er>Roll</er>, <pos>v.</pos>, and cf.
<er>R<ocir/le</er>, <er>Rouleau</er>, <er>Roulette</er>.]</ety>
<sn>1.</sn> <def>The act of rolling, or state of being rolled; <as>as,
the <ex>roll</ex> of a ball; the <ex>roll</ex> of waves</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which rolls; a roller.</def> Specifically:
<sd>(a)</sd> <def>A heavy cylinder used to break clods.</def>
<au>Mortimer.</au> <sd>(b)</sd> <def>One of a set of revolving
cylinders, or rollers, between which metal is pressed, formed, or
smoothed, as in a rolling mill; <as>as, to pass rails through the
<ex>rolls</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which is rolled up; <as>as, a <ex>roll</ex> of
fat, of wool, paper, cloth, etc.</as></def> Specifically: <sd>(a)</sd>
<def>A document written on a piece of parchment, paper, or other
materials which may be rolled up; a scroll.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Busy angels spread<br/
The lasting <qex>roll</qex>, recording what we say.</q>
<rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1249 --></p>

<p><sd>(b)</sd> <def>Hence, an official or public document; a register;
a record; also, a catalogue; a list.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>rolls</qex> of Parliament, the entry of the petitions,
answers, and transactions in Parliament, are extant.</q> <rj><qau>Sir M.
Hale.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>roll</qex> and list of that army doth remain.</q>
<rj><qau>Sir J. Davies.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(c)</sd> <def>A quantity of cloth wound into a cylindrical form;
<as>as, a <ex>roll</ex> of carpeting; a <ex>roll</ex> of
ribbon</as>.</def> <sd>(d)</sd> <def>A cylindrical twist of
tobacco.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A kind of shortened raised biscuit or bread, often
rolled or doubled upon itself.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Naut.)</fld> <def>The oscillating movement of a
vessel from side to side, in sea way, as distinguished from the
alternate rise and fall of bow and stern called
<xex>pitching</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>A heavy, reverberatory sound; <as>as, the <ex>roll
of</ex> cannon, or of thunder</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>The uniform beating of a drum with strokes so rapid
as scarcely to be distinguished by the ear.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>Part; office; duty; role.</def> <mark>[Obs.]</mark>
<rj><au>L'Estrange.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Long roll</b></col> <fld>(Mil.)</fld>, <cd>a prolonged
roll of the drums, as the signal of an attack by the enemy, and for the
troops to arrange themselves in line.</cd> -- <col><b>Master of the
rolls</b></col>. <cd>See under <er>Master</er>.</cd> -- <col><b>Roll
call</b></col>, <cd>the act, or the time, of calling over a list names,
as among soldiers.</cd> -- <mcol><col><b>Rolls of court</b></col>,
<col><b>of parliament</b></col></mcol> (or of any public body), <cd>the
parchments or rolls on which the acts and proceedings of that body are
engrossed by the proper officer, and which constitute the records of
such public body.</cd> -- <col><b>To call the roll</b></col>, <cd>to
call off or recite a list or roll of names of persons belonging to an
organization, in order to ascertain who are present or to obtain
responses from those present.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- List; schedule; catalogue; register; inventory.
See <er>List</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rollable</ent><br/
<hw>Roll"a*ble</hw> <pr>(r<omac/l"<adot/*b'l)</pr>, <pos>a.</pos>
<def>Capable of being rolled.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roller</ent><br/
<hw>Roll"er</hw> <pr>(r<omac/l"<etil/r)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>One who, or that which, rolls; especially, a cylinder, sometimes
grooved, of wood, stone, metal, etc., used in husbandry and the
arts.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A bandage; a fillet; properly, a long and broad
bandage used in surgery.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Naut.)</fld> <def>One of series of long, heavy
waves which roll in upon a coast, sometimes in calm weather.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A long, belt-formed towel, to be suspended on a
rolling cylinder; -- called also <altname>roller
towel</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Print.)</fld> <def>A cylinder coated with a
composition made principally of glue and molassess, with which forms of
type are inked previously to taking an impression from them.</def>
<rj><au>W. Savage.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>A long cylinder on which something is rolled up;
<as>as, the <ex>roller</ex> of a map</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>A small wheel, as of a caster, a roller skate,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <fld>(Zool.)</fld> <def>Any insect whose larva rolls up
leaves; a leaf roller. see <er>Tortrix</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <ety>[CF. F. <ets>rollier</ets>.]</ety>
<fld>(Zool.)</fld> <def>Any one of numerous species of Old World
picarian birds of the family <fam>Coraciadae</fam>. The name alludes to
their habit of suddenly turning over or <ldquo/tumbling<rdquo/ in
flight.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Many of the species are brilliantly colored. The common
European species (<spn>Coracias garrula</spn>) has the head, neck, and
under parts light blue varied with green, the scapulars chestnut brown,
and the tail blue, green, and black. The broad-billed rollers of India
and Africa belong to the genus <gen>Eurystomus</gen>, as the oriental
roller (<spn>Eurystomus orientalis</spn>), and the Australian roller, or
dollar bird (<spn>Eurystomus Pacificus</spn>). The latter is dark brown
on the head and neck, sea green on the back, and bright blue on the
throat, base of the tail, and parts of the wings. It has a silvery-white
spot on the middle of each wing. The <stype>lilac-breasted
roller</stype> of Africa is <spn>Corcia caudata</spn>
<varn>caudata</varn>, a brightly colored bird of the family
<fam>Corciidae</fam> having malachite green, blue, purple-lilac, brown
and sea-green feathers from head to tail; it is a popular sight with
tourists in Africa.</note> <br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><note>Zimbabwe Menu<br/
The Lilac-breasted Roller (also lilacbreasted roller, <spn>Coracias
caudata</spn>) is a common resident in large parts of the Southern
African region including <country>Zimbabwe</country>,
<country>Zambia</country>, <country>Botswana</country>,
<country>Namibia</country>, <country>Mozambique</country> and parts of
<country>South Africa</country>.<br/
They are found in a variety of woodland types and will usually be seen
hawking for insects from a favoured position in a tall tree, telephone
pole or similar vantage point. They tend to be quite noisy when carrying
out their characteristic aerobatic display. The Lilacbreasted Roller
differs from its Racket-tailed cousin in that it has pointed tail
feathers not spatulate tips. The latter bird is less well distributed
than the Lilacbreasted and favours moist broad-leafed woodland and hill
country.</note></p>

<p><sn>10.</sn> <fld>(Zool.)</fld> <def>Any species of small ground
snakes of the family <fam>Tortricidae</fam>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Ground roller</b></col> <fld>(Zool.)</fld>, <cd>any one
of several species of Madagascar rollers belonging to
<gen>Atelornis</gen> and allied genera. They are nocturnal birds, and
feed on the ground.</cd> -- <col><b>Roller bolt</b></col>, <cd>the bar
in a carriage to which the traces are attached; a whiffletree.</cd>
<mark>[Eng.]</mark> -- <col><b>Roller gin</b></col>, <cd>a cotton gin
inn which rolls are used for separating the seeds from the fiber.</cd>
-- <col><b>Roller mill</b></col>. <cd>See under <er>Mill</er>.</cd> --
<col><b>Roller skate</b></col>, <cd>a skate which has small wheels in
the place of the metallic runner; -- designed for use in skating upon a
smooth, hard surface, other than ice.</cd></cs><-- roller blades, a type
of roller skate --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roller bearing</ent><br/
<hw>Roll"er bear"ing</hw>. <fld>(Mach.)</fld> <def>A bearing containing
friction rollers.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Roller blade</ent><br/
<hw>Roll"er blade</hw>. <ety>[from <ets>Rollerblade</ets>, a trade
name.]</ety> <def>a type of <er>roller skate</er> having more than two
wheels, aligned in a single row rather than in two rows.</def><br/
[<source>PJC</source>]</p>

<p><ent>Roller coaster</ent><br/
<hw>Roller coaster</hw>. <def>An amusement railroad of varying design in
which open cars coast by gravity over a long winding track in a closed
circuit, with steep pitches and ascents, and in some cases loops in
which the cars are briefly upside-down; typically, the cars are pulled
by a chain device to the top of the first peak, after which gravity and
momentum provide the only propulsive forces. In some cases, the cars are
suspended from a monorail rather than resting on a track, and such cars
may be made to swing outward at an angle near to the horizontal. It is a
popular amusement at many amusement parks, but is sufficiently
frightening to some people that they refuse to ride in one.</def><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><ent>Roller skate</ent><br/
<hw>Roll"er skate</hw>. <sn>1.</sn> <def>a shoe with a set of wheels
attached so that the wearer can glide over a flat surface. To move on
such a device is reverred to as to skate or to rollerskate. To
rollerskate is a form of recreation or sport.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>a metal frame of the size of a shoe, with a set of
wheels attached, and with adjustable clamps and straps that permit a
shoe to be reversibly fastened to the frame. It serves the same purpose
as the roller skate having the shoe permanently attached, but is
typically less expensive.</def><br/
[<source>PJC</source>]</p>

<p><ent>Rollerskate</ent><br/
<hw>Roll"er*skate</hw>. <def>to glide on roller skates, as one might on
ice skates.</def><br/
[<source>PJC</source>]</p>

<p><ent>Rolley</ent><br/
<hw>Roll"ey</hw> <pr>(-<ycr/)</pr>, <pos>n.</pos> <ety>[Probably fr.
<ets>roll</ets>.]</ety> <def>A small wagon used for the underground work
of a mine.</def> <rj><au>Tomlison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rollic</ent><br/
<hw>Rol"lic</hw> <pr>(r<ocr/l"l<icr/k)</pr>, <pos>v. i.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Rollicked</conjf>
<pr>(-l<icr/kt)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Rollicking</conjf>.]</vmorph> <ety>[Corrupt. fr.
<ets>frolic</ets>, under the influence of <ets>roll</ets>.]</ety>
<def>To move or play in a careless, swaggering manner, with a frolicsome
air; to frolic; to sport; commonly in the form
<xex>rollicking</xex>.</def> <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He described his friends as <qex>rollicking</qex> blades.</q>
<rj><qau>T. Hook.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rollichie</ent><br/
<ent>Rollejee</ent><br/
<ent>Rolliche</ent><br/
<mhw><hw>Rol"li*che</hw> <pr>(?)</pr>, <pos>n.</pos> [Also
<hw>Rol"le*jee</hw> <pr>(<?/)</pr>, <hw>Rol"li*chie</hw>.]</mhw>
<ety>[D. <ets>rolletje</ets> a little roll.]</ety> <def>A kind of
sausage, made in a bag of tripe, sliced and fried, famous among the
Dutch of New Amsterdam and still known, esp. in New Jersey.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Rolling</ent><br/
<hw>Roll"ing</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Rotating
on an axis, or moving along a surface by rotation; turning over and over
as if on an axis or a pivot; <as>as, a <ex>rolling</ex> wheel or
ball</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Moving on wheels or rollers, or as if on wheels or
rollers; <as>as, a <ex>rolling</ex> chair</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Having gradual, rounded undulations of surface;
<as>as, a <ex>rolling</ex> country; <ex>rolling</ex> land</as>.</def>
<mark>[U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Rolling bridge</b></col>. <cd>See the Note under
<er>Drawbridge</er>.</cd> -- <col><b>Rolling circle of a paddle
wheel</b></col>, <cd>the circle described by the point whose velocity
equals the velocity of the ship.</cd> <au>J. Bourne.</au> --
<col><b>Rolling fire</b></col> <fld>(Mil.)</fld>, <cd>a discharge of
firearms by soldiers in line, in quick succession, and in the order in
which they stand.</cd> -- <col><b>Rolling friction</b></col>, <cd>that
resistance to motion experienced by one body rolling upon another which
arises from the roughness or other quality of the surfaces in
contact.</cd> -- <col><b>Rolling mill</b></col>, <cd>a mill furnished
with heavy rolls, between which heated metal is passed, to form it into
sheets, rails, etc.</cd> -- <col><b>Rolling press</b></col>.
<sd>(a)</sd> <cd>A machine for calendering cloth by pressure between
revolving rollers</cd>. <sd>(b)</sd> <cd>A printing press with a roller,
used in copperplate printing.</cd> -- <mcol><col><b>Rolling
stock</b></col>, <it>or</it> <col><b>Rolling plant</b></col></mcol>,
<cd>the locomotives and vehicles of a railway.</cd> -- <col><b>Rolling
tackle</b></col> <fld>(Naut.)</fld>, <cd>tackle used to steady the yards
when the ship rolls heavily.</cd> <au>R. H. Dana, Jr.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rolling-pin</ent><br/
<hw>Roll"ing-pin`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A cylindrical
piece of wood or other material, with which paste or dough may be rolled
out and reduced to a proper thickness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rollway</ent><br/
<hw>Roll"way`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A place prepared for
rolling logs into a stream.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rolly-poly</ent><br/
<hw>Roll"y-po`ly</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A kind of pudding
made of paste spread with fruit, rolled into a cylindrical form, and
boiled or steamed.</def> -- <def2><pos>a.</pos> <def>Shaped like a
rolly-poly; short and stout.</def></def2> <altsp>[Written also
<asp>roly-poly</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rolly-pooly</ent><br/
<hw>Roll"y-pool`y</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Etymol.
uncertain.]</ety> <def>A game in which a ball, rolling into a certain
place, wins.</def> <altsp>[Written also
<asp>rouly-pouly</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rolodex</ent><br/
<hw>Rol"o*dex</hw> <pr>(r<ocir/l"<osl/*d<ecr/ks)</pr>, <pos>a.</pos>
<ety>[Trade Mark of <corpn>Newell Office Products</corpn>.]</ety> <def>A
trade name for a type of <isa>card file</isa>; <as>as, a
<ex>Rolodex(R)</ex> card file</as>. Also used informally and improperly
as a noun meaning <altname>Rolodex(R) card file</altname>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Roly-poly</ent><br/
<hw>Ro"ly-po`ly</hw> <pr>(?)</pr>, <pos>n. & a.</pos>
<def>Rolly-poly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Romage</ent><br/
<hw>Rom"age</hw> <pr>(?)</pr>, <pos>n. & v.</pos> <def>See
<er>Rummage</er>.</def> <mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Romaic</ent><br/
<hw>Ro*ma"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[NGr. <?/<?/<?/<?/:
cf. F. <ets>roma<ium/que</ets>. See <er>Roman</er>.]</ety> <def>Of or
relating to modern Greece, and especially to its language.</def> --
<def2><pos>n.</pos> <def>The modern Greek language, now usually called
by the Greeks <altname>Hellenic</altname> or
<altname>Neo-Hellenic</altname>.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The Greeks at the time of the capture of Constantinople
were proud of being <grk>"Romai^oi</grk>, or Romans . . . Hence the term
<xex>Romaic</xex> was the name given to the popular language. . . . The
Greek language is now spoken of as the Hellenic language.</note>
<rj><au>Encyc. Brit.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Romajikai</ent><br/
<hw>Ro"ma*ji*ka`i</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Jap.
<ets>r<omac/majikai</ets>, Roman character association.]</ety> <def>An
association, including both Japanese and Europeans, having for its
object the changing of the Japanese method of writing by substituting
Roman letters for Japanese characters. Laso known as <altname>Hyojun
Romajikai</altname>.</def><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><ent>Roman</ent><br/
<hw>Ro"man</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>Romanus</ets>,
fr. <ets>Roma</ets> Rome: cf. F. <ets>romain</ets>. Cf. <er>Romaic</er>,
<er>Romance</er>, <er>Romantic</er>.]</ety> <sn>1.</sn> <def>Of or
pertaining to Rome, or the Roman people; like or characteristic of Rome,
the Roman people, or things done by Romans; <as>as, <ex>Roman</ex>
fortitude; a <ex>Roman</ex> aqueduct; <ex>Roman</ex> art</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of or pertaining to the Roman Catholic religion;
professing that religion.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Print.)</fld> <sd>(a)</sd> <def>Upright; erect; --
said of the letters or kind of type ordinarily used, as distinguished
from <xex>Italic</xex> characters.</def> <sd>(b)</sd> <def>Expressed in
letters, not in figures, as I., IV., i., iv., etc.; -- said of numerals,
as distinguished from the <xex>Arabic</xex> numerals, 1, 4,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Roman alum</b></col> <fld>(Chem.)</fld>, <cd>a cubical
potassium alum formerly obtained in large quantities from Italian
alunite, and highly valued by dyers on account of its freedom from
iron.</cd> -- <col><b>Roman balance</b></col>, <cd>a form of balance
nearly resembling the modern steelyard. See the Note under
<er>Balance</er>, <pos>n.</pos>, 1.</cd> -- <col><b>Roman
candle</b></col>, <cd>a kind of firework (generally held in the hand),
characterized by the continued emission of shower of sparks, and the
ejection, at intervals, of brilliant balls or stars of fire which are
thrown upward as they become ignited.</cd> -- <col><b>Roman
Catholic</b></col>, <cd>of, pertaining to, or the religion of that
church of which the pope is the spiritual head; <as>as, a <ex>Roman
Catholic</ex> priest; the <ex>Roman Catholic</ex> Church</as>.</cd> --
<col><b>Roman cement</b></col>, <cd>a cement having the property of
hardening under water; a species of hydraulic cement.</cd> --
<col><b>Roman law</b></col>. <cd>See under <er>Law</er>.</cd> --
<col><b>Roman nose</b></col>, <cd>a nose somewhat aquiline.</cd> --
<col><b>Roman ocher</b></col>, <cd>a deep, rich orange color,
transparent and durable, used by artists.</cd> <au>Ure.</au> --
<col><b>Roman order</b></col> <fld>(Arch.)</fld>, <cd>the composite
order. See <er>Composite</er>, <pos>a.</pos>, 2.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roman</ent><br/
<hw>Ro"man</hw>, <pos>n.</pos> <sn>1.</sn> <def>A native, or permanent
resident, of Rome; a citizen of Rome, or one upon whom certain rights
and privileges of a Roman citizen were conferred.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Roman type, letters, or print, collectively; -- in
distinction from <xex>Italics</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roman calendar</ent><br/
<hw>Roman calendar</hw>. <def>The calendar of the ancient Romans, from
which our modern calendars are derived. It is said to have consisted
originally of ten months, <xex>Martius</xex>, <xex>Aprilis</xex>,
<xex>Maius</xex>, <xex>Junius</xex>, <xex>Quintilis</xex>,
<xex>Sextilis</xex>, September, October, November, and December, having
a total of 304 days. Numa added two months, <xex>Januarius</xex> at the
beginning of the year, and <xex>Februarius</xex> at the end, making in
all 355 days. He also ordered an intercalary month,
<xex>Mercedinus</xex>, to be inserted every second year. Later the order
of the months was changed so that January should come before February.
Through abuse of power by the pontiffs to whose care it was committed,
this calendar fell into confusion. It was replaced by the Julian
calendar. In designating the days of the month, the Romans reckoned
backward from three fixed points, the <xex>calends</xex>, the
<xex>nones</xex>, and the <xex>ides</xex>. The calends were always the
first day of the month. The ides fell on the 15th in March, May, July
(Quintilis), and October, and on the 13th in other months. The nones
came on the eighth day (the <xex>ninth</xex>, counting the ides) before
the ides. Thus, Jan. 13 was called the ides of January, Jan. 12, the day
before the ides, and Jan. 11, the <xex>third</xex> day before the ides
(since the ides count as one), while Jan. 14 was the 19th day before the
calends of February.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Romance</ent><br/
<hw>Ro*mance"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>romance</ets>, <ets>romant</ets>, <ets>romaunt</ets>, OF.
<ets>romanz</ets>, <ets>romans</ets>, <ets>romant</ets>,
<ets>roman</ets>, F. <ets>roman</ets>, <ets>romance</ets>, fr. LL.
<ets>Romanice</ets> in the Roman language, in the vulgar tongue, <it>i.
e.</it>, in the vulgar language which sprang from Latin, the language of
the Romans, and hence applied to fictitious compositions written in this
vulgar tongue; fr. L. <ets>Romanicus</ets> Roman, fr.
<ets>Romanus</ets>. See <er>Roman</er>, and cf. <er>Romanic</er>,
<er>Romaunt</er>, <er>Romansch</er>, <er>Romanza</er>.]</ety>
<sn>1.</sn> <def>A species of fictitious writing, originally composed in
meter in the Romance dialects, and afterward in prose, such as the tales
of the court of Arthur, and of Amadis of Gaul; hence, any fictitious and
wonderful tale; a sort of novel, especially one which treats of
surprising adventures usually befalling a hero or a heroine; a tale of
extravagant adventures, of love, and the like.</def>
<ldquo/<xex>Romances</xex> that been royal.<rdquo/
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Upon these three columns -- chivalry, gallantry, and religion --
repose the fictions of the Middle Ages, especially those known as
<qex>romances</qex>. These, such as we now know them, and such as
display the characteristics above mentioned, were originally metrical,
and chiefly written by nations of the north of France.</q>
<rj><qau>Hallam.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An adventure, or series of extraordinary events,
resembling those narrated in romances; <as>as, his courtship, or his
life, was a <ex>romance</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A dreamy, imaginative habit of mind; a disposition
to ignore what is real; <as>as, a girl full of
<ex>romance</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The languages, or rather the several dialects, which
were originally forms of popular or vulgar Latin, and have now developed
into Italian. Spanish, French, etc. (called the <xex>Romanic
languages</xex>).</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Mus.)</fld> <def>A short lyric tale set to music; a
song or short instrumental piece in ballad style; a romanza.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>a love affair, esp. one in which the lovers display
their deep affection openly, by romantic gestures.</def><br/
[<source>PJC</source>]</p>

<p><syn><b>Syn.</b> -- Fable; novel; fiction; tale.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Romance</ent><br/
<hw>Ro*mance"</hw>, <pos>a.</pos> <def>Of or pertaining to the language
or dialects known as <xex>Romance</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Romance</ent><br/
<hw>Ro*mance"</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Romanced</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Romancing</conjf> <pr>(?)</pr>.]</vmorph> <def>To write or tell
romances; to indulge in extravagant stories.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A very brave officer, but apt to <qex>romance</qex>.</q>
<rj><qau>Walpole.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Romancer</ent><br/
<hw>Ro*man"cer</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
romances.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Romancist</ent><br/
<hw>Ro*man"cist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A romancer.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Romancy</ent><br/
<hw>Ro*man"cy</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Romantic.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Romanesque</ent><br/
<hw>Ro`man*esque"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F.
<ets>romanesque</ets>; cf. It. <ets>romanesco</ets>.]</ety> <sn>1.</sn>
<fld>(Arch.)</fld> <def>Somewhat resembling the Roman; -- applied
sometimes to the debased style of the later Roman empire, but esp. to
the more developed architecture prevailing from the 8th century to the
12th.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of or pertaining to romance or fable;
fanciful.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Romanesque style</b></col> <fld>(Arch.)</fld>, <cd>that
which grew up from the attempts of barbarous people to copy Roman
architecture and apply it to their own purposes. This term is loosely
applied to all the styles of Western Europe, from the fall of the
Western Roman Empire to the appearance of Gothic
architecture.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Romanesque</ent><br/
<hw>Ro`man*esque"</hw>, <pos>n.</pos> <def>Romanesque style.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Romanic</ent><br/
<hw>Ro*man"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>Romanicus</ets>. See <er>Romance</er>, <pos>n.</pos>]</ety>
<sn>1.</sn> <def>Of or pertaining to Rome or its people.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of or pertaining to any or all of the various
languages which, during the Middle Ages, sprung out of the old Roman, or
popular form of Latin, as the Italian, Spanish, Portuguese, French,
Provencal, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Related to the Roman people by descent; -- said
especially of races and nations speaking any of the Romanic
tongues.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Romanic spelling</b></col>, <cd>spelling by means of the
letters of the Roman alphabet, as in English; -- contrasted with
<xex>phonetic spelling</xex>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Romanish</ent><br/
<hw>Ro"man*ish</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to
Romanism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Romanism</ent><br/
<hw>Ro"man*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The tenets of the
Church of Rome; the Roman Catholic religion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Romanist</ent><br/
<hw>Ro"man*ist</hw>, <pos>n.</pos> <def>One who adheres to
Romanism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Romanize</ent><br/
<hw>Ro"man*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Romanized</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Romanizing</conjf> <pr>(?)</pr>.]</vmorph> <sn>1.</sn>
<def>To Latinize; to fill with Latin words or idioms.</def>
<mark>[R.]</mark> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To convert to the Roman Catholic religion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Romanize</ent><br/
<hw>Ro"man*ize</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To use Latin
words and idioms.</def> <ldquo/Apishly <xex>Romanizing</xex>.<rdquo/
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To conform to Roman Catholic opinions, customs, or
modes of speech.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Romanizer</ent><br/
<hw>Ro"man*i`zer</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
Romanizes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Romansch</ent><br/
<hw>Ro*mansch"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Grisons
<ets>rumansch</ets>, <ets>rumonsch</ets>, <ets>romonsch</ets>. See
<er>Romance</er>.]</ety> <def>The language of the Grisons in
Switzerland, a corruption of the Latin.</def> <altsp>[Written also
<asp>Romansch</asp>, and <asp>Rumonsch</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Romant</ent><br/
<hw>Ro*mant"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A romaunt.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Romantic</ent><br/
<hw>Ro*man"tic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F.
<ets>romantique</ets>, fr. OF. <ets>romant</ets>. See
<er>Romance</er>.]</ety> <sn>1.</sn> <def>Of or pertaining to romance;
involving or resembling romance; hence, fanciful; marvelous;
extravagant; unreal; <as>as, a <ex>romantic</ex> tale; a
<ex>romantic</ex> notion; a <ex>romantic</ex>
undertaking.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Can anything in nature be imagined more profane and impious, more
absurd, and undeed <qex>romantic</qex>, than such a persuasion?</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Zeal for the good of one's country a party of men have represented
as chimerical and <qex>romantic</qex>.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Entertaining ideas and expectations suited to a
romance; <as>as, a <ex>romantic</ex> person; a <ex>romantic</ex>
mind.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Of or pertaining to the style of the Christian and
popular literature of the Middle Ages, as opposed to the classical
antique; of the nature of, or appropriate to, that style; <as>as, the
<ex>romantic</ex> school of poets</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Characterized by strangeness or variety; suggestive
of adventure; suited to romance; wild; picturesque; -- applied to
scenery; <as>as, a <ex>romantic</ex> landscape</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Sentimental; fanciful; fantastic; fictitious;
extravagant; wild; chimerical. See <er>Sentimental</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>The romantic drama</b></col>. <cd>See under
<er>Drama</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Romantical</ent><br/
<hw>Ro*man"tic*al</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Romantic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Romanticaly</ent><br/
<hw>Ro*man"tic*al*y</hw>, <pos>adv.</pos> <def>In a romantic
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Romanticism</ent><br/
<hw>Ro*man"ti*cism</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[CF. It.
<ets>romanticismo</ets>, F. <ets>romantisme</ets>,
<ets>romanticisme</ets>.]</ety> <def>A fondness for romantic
characteristics or peculiarities; specifically, in modern literature, an
aiming at romantic effects; -- applied to the productions of a school of
writers who sought to revive certain medieval forms and methods in
opposition to the so-called classical style.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He [Lessing] may be said to have begun the revolt from
pseudo-classicism in poetry, and to have been thus unconsciously the
founder of <qex>romanticism</qex>.</q> <rj><qau>Lowell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Romanticist</ent><br/
<hw>Ro*man"ti*cist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
advocates romanticism in modern literature.</def> <rj><au>J. R.
Seeley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Romanticly</ent><br/
<hw>Ro*man"tic*ly</hw> <pr>(?)</pr>, <pos>adv.</pos>
<def>Romantically.</def> <mark>[R.]</mark> <rj><au>Strype.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Romanticness</ent><br/
<hw>Ro*man"tic*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state or
quality of being romantic; widness; fancifulness.</def>
<rj><au>Richardson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Romany</ent><br/
<hw>Rom"a*ny</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gypsy
<ets>romano</ets>, <ets>romani</ets>, adj., gypsy; cf. <ets>rom</ets>
husband.]</ety> <sn>1.</sn> <def>A gypsy.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The language spoken among themselves by the
gypsies.</def> <altsp>[Written also <asp>Rommany</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Romanza</ent><br/
\'d8<hw>Ro*man"za</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[It.]</ety>
<def>See <er>Romance</er>, 5.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Romaunt</ent><br/
<hw>Ro*maunt"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Romance</er>.]</ety> <def>A romantic story in verse; <as>as, the
<ldquo/<ex>Romaunt</ex> of the Rose</as>.<rdquo/</def><br/
[<source>1913 Webster</source>]</p>

<p><q>O, hearken, loving hearts and bold,<br/
Unto my wild <qex>romaunt</qex>.</q> <rj><qau>Mrs.
Browning.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Romble</ent><br/
<hw>Rom"ble</hw> <pr>(?)</pr>, <pos>v. & n.</pos> <def>Rumble.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rombowline</ent><br/
<hw>Rom*bow"line</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Etymol.
uncertain.]</ety> <fld>(Naut.)</fld> <def>Old, condemned canvas, rope,
etc., unfit for use except in chafing gear.</def> <altsp>[Written also
<asp>rumbowline</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Romeite</ent><br/
<ent>Romeine</ent><br/
<mhw>{ <hw>Ro"me*ine</hw> <pr>(?)</pr>, <hw>Ro"me*ite</hw> <pr>(?)</pr>,
}</mhw> <pos>n.</pos> <ety>[F. <ets>rom<eacute/ine</ets>. So calledafter
the French mineralogist <ets>Rom<eacute/</ets> L'Isle.]</ety>
<fld>(Min.)</fld> <def>A mineral of a hyacinth or honey-yellow color,
occuring in square octahedrons. It is an antimonate of
calcium.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Romekin</ent><br/
<hw>Rome"kin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[CF.
<er>Rummer</er>.]</ety> <def>A drinking cup.</def> <altsp>[Written also
<asp>romkin</asp>.]</altsp> <mark>[Obs.]</mark>
<rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rome scot</ent><br/
<ent>Rome penny</ent><br/
<mhw>{ <hw>Rome" pen`ny</hw> <pr>(?)</pr>, <it>or</it> <hw>Rome"
scot`</hw> <pr>(?)</pr> }</mhw>. <def>See <cref>Peter pence</cref>,
under <er>Peter</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Romeward</ent><br/
<hw>Rome"ward</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>Toward Rome, or
toward the Roman Catholic Church.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Romeward</ent><br/
<hw>Rome"ward</hw>, <pos>a.</pos> <def>Tending or directed toward Rome,
or toward the Roman Catholic Church.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To analyze the crisis in its Anglican rather than in its
<qex>Romeward</qex> aspect.</q> <rj><qau>Gladstone.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Romic</ent><br/
<hw>Rom"ic</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A method of notation
for all spoken sounds, proposed by Mr. Sweet; -- so called because it is
based on the common <xex>Roman</xex>-letter alphabet. It is like the
palaeotype of Mr. Ellis in the general plan, but simpler.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Romish</ent><br/
<hw>Rom"ish</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Belonging or relating
to Rome, or to the Roman Catholic Church; -- frequently used in a
disparaging sense; <as>as, the <ex>Romish</ex> church; the
<ex>Romish</ex> religion, ritual, or ceremonies.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Romist</ent><br/
<hw>Rom"ist</hw>, <pos>n.</pos> <def>A Roman Catholic.</def>
<mark>[R.]</mark> <rj><au>South.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Romp</ent><br/
<hw>Romp</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Romped</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Romping</conjf>.]</vmorph> <ety>[A variant of <ets>ramp</ets>.
See <er>Ramp</er> to leap, <er>Rampallian</er>.]</ety> <sn>1.</sn>
<def>To play rudely and boisterously; to leap and frisk about in
play.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To go rapidly and without strained effort.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>To win easily; -- often used with <ptcl>over</ptcl>,
in sports games; <as>as, the <org>Yankees</org> <ex>romped</ex> over the
<org>Boston Red Sox</org>, 10-2.</as></def><br/
[<source>PJC</source>]</p>

<p><ent>Romp</ent><br/
<hw>Romp</hw>, <pos>n.</pos> <sn>1.</sn> <def>A girl who indulges in
boisterous play.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1250 --></p>

<p><sn>2.</sn> <def>Rude, boisterous play or frolic; rough
sport.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>While <qex>romp</qex>-loving miss<br/
Is hauled about in gallantry robust.</q>
<rj><qau>Thomson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Romping</ent><br/
<hw>Romp"ing</hw> <pr>(r<ocr/mp"<icr/ng)</pr>, <pos>a.</pos>
<def>Inclined to romp; indulging in romps.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A little <qex>romping</qex> girl from boarding school.</q>
<rj><qau>W. Irving.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rompingly</ent><br/
<hw>Romp"ing*ly</hw>, <pos>adv.</pos> <def>In a romping
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rompish</ent><br/
<hw>Romp"ish</hw>, <pos>a.</pos> <def>Given to rude play; inclined to
romp; frolicsome.</def><br/
[<source>1913 Webster</source>]</p>

<p>--- <wordforms><wf>Romp"ish</wf>, <pos>adv.</pos> --
<wf>Romp"ish*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rompu</ent><br/
<hw>Rom"pu</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F. <ets>rompu</ets>,
p. p. of <ets>rompre</ets> to breeak, L. <ets>rumpere</ets>. See
<er>Rupture</er>.]</ety> <fld>(Her.)</fld> <def>Broken, as an ordinary;
cut off, or broken at the top, as a chevron, a bend, or the
like.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roncador</ent><br/
<hw>Ron`ca*dor"</hw> <pr>(r<ocr/<nsm/`k<adot/*d<omac/r")</pr>,
<pos>n.</pos> <ety>[Sp., a snorer, fr. <ets>roncar</ets> to snore. So
called in allusion to the grunting noise made by them on being taken
from the water. ]</ety> <fld>(Zool.)</fld> <def>Any one of several
species of <state>California</state> sciaenoid food fishes, especially
<spn>Roncador Stearnsi</spn>, which is an excellent market fish, and the
red roncador (<spn>Corvina saturna</spn> syn. <spn>Johnius
saturna</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ronchil</ent><br/
<hw>Ron"chil</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. Sp.
<ets>ronquillo</ets> slightly hoarse.]</ety> <fld>(Zool.)</fld> <def>An
American marine food fish (<spn>Bathymaster signatus</spn>) of the North
Pacific coast, allied to the tilefish.</def> <altsp>[Written also
<asp>ronquil</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ronco</ent><br/
<hw>Ron"co</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sp. <ets>ronco</ets>
hoarse.]</ety> <fld>(Zool.)</fld> <def>See <er>Croaker</er>,
<pos>n.</pos>, 2. <sd>(a)</sd>.</def> <mark>[Texas]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rondache</ent><br/
\'d8<hw>Ron`dache"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<fld>(Anc. Armor.)</fld> <def>A circular shield carried by foot
soldiers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ronde</ent><br/
\'d8<hw>Ronde</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<fld>(Print.)</fld> <def>A kind of script in which the heavy strokes are
nearly upright, giving the characters when taken together a round
look.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rondeau</ent><br/
<hw>Ron*deau"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. See
<er>Roundel</er>.]</ety> <altsp>[Written also <asp>rondo</asp>.]</altsp>
<sn>1.</sn> <def>A species of lyric poetry so composed as to contain a
refrain or repetition which recurs according to a fixed law, and a
limited number of rhymes recurring also by rule.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ When the <xex>rondeau</xex> was called the
<xex>rondel</xex> it was mostly written in fourteen octosyllabic lines
of two rhymes, as in the <xex>rondels</xex> of Charles d'Orleans. . . .
In the 17th century the approved form of the <xex>rondeau</xex> was a
structure of thirteen verses with a refrain.</note> <rj><au>Encyc.
Brit.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mus.)</fld> <def>See <er>Rondo</er>, 1.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rondel</ent><br/
<hw>Ron"del</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. <er>Rondeau</er>,
<er>Roundel</er>.]</ety> <sn>1.</sn> <fld>(Fort.)</fld> <def>A small
round tower erected at the foot of a bastion.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <ety>[F.]</ety> <sd>(a)</sd> <def>Same as
<er>Rondeau</er>.</def> <sd>(b)</sd> <def>Specifically, a particular
form of rondeau containing fourteen lines in two rhymes, the refrain
being a repetition of the first and second lines as the seventh and
eighth, and again as the thirteenth and fourteenth.</def> <rj><au>E. W.
Gosse.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rondeletia</ent><br/
\'d8<hw>Ron`de*le"ti*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. So
named after William <etsep>Rondelet</etsep>, a French naturalist.]</ety>
<fld>(Bot.)</fld> <def>A tropical genus of rubiaceous shrubs which often
have brilliant flowers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rondle</ent><br/
<hw>Ron"dle</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf.
<er>Rondel</er>.]</ety> <sn>1.</sn> <def>A rondeau.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A round mass, plate, or disk; especially
<fld>(Metal.)</fld>, the crust or scale which forms upon the surface of
molten metal in the crucible.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rondo</ent><br/
<hw>Ron"do</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[It.
<ets>rond<ograve/</ets>, fr. F. <ets>rondeau</ets>. See
<er>Rondeau</er>.]</ety> <sn>1.</sn> <fld>(Mus.)</fld> <def>A
composition, vocal or instrumental, commonly of a lively, cheerful
character, in which the first strain recurs after each of the other
strains.</def> <ldquo/The <xex>Rondo</xex>-form was the earliest and
most frequent definite mold for musical construction.<rdquo/
<rj><au>Grove.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Poetry)</fld> <def>See <er>Rondeau</er>,
1.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rondure</ent><br/
<hw>Ron"dure</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>rondeur</ets> roundness.]</ety> <sn>1.</sn> <def>A round; a
circle.</def> <mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Roundness; plumpness.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>High-kirtled for the chase, and what was shown<br/
Of maiden <qex>rondure</qex>, like the rose half-blown.</q>
<rj><qau>Lowell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rong</ent><br/
<hw>Rong</hw> <pr>(?)</pr>, <mark>obs.</mark> <def><pos>imp. & p.
p.</pos> of <er>Ring</er>.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rong</ent><br/
<hw>Rong</hw>, <pos>n.</pos> <def>Rung (of a ladder).</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rongeur</ent><br/
\'d8<hw>Ron`geur"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr.
<ets>ronger</ets> to gnaw.]</ety> <fld>(Surg.)</fld> <def>An instrument
for removing small rough portions of bone.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>ronin</ent><br/
\'d8<hw>ro"nin"</hw> <pr>(r<omac/"n<icr/n)</pr>, <pos>n.</pos>
<ety>[Jap. <ets>r<omac/-nin</ets>, fr. Chin. <ets>lang</ets> profligate,
lawless + <ets>j<ecir/n</ets> (old sound <ets>n<imac/n</ets>)
man.]</ety> <def>In Japan, under the feudal system, a samurai who had
renounced his clan or who had been discharged or ostracized and had
become a wanderer without a lord; an outcast; an outlaw.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Ronyon</ent><br/
<ent>Ronion</ent><br/
<mhw>{ <hw>Ron"ion</hw>, <hw>Ron"yon</hw> }</mhw> <pr>(?)</pr>,
<pos>n.</pos> <ety>[F. <ets>rogne</ets> scab, mange.]</ety> <def>A mangy
or scabby creature.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><ldquo/Aroint thee, with!<rdquo/ the rump-fed <qex>ronyon</qex>
cries.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ronnen</ent><br/
<ent>Ronne</ent><br/
<hw>Ron"ne</hw> <pr>(?)</pr>, <def><pos>obs. imp. pl.</pos></def>, and
<hw>Ron"nen</hw> <pr>(<?/)</pr>, <def><pos>obs. p. p.</pos> of
<er>Renne</er>, to run.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ront</ent><br/
<hw>Ront</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Runt</er>.]</ety> <def>A runt.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roentgen</ent><br/
<mhw><hw>R<oum/nt"gen</hw>, <hw>Roent"gen</hw></mhw> <pr>(?)</pr>,
<pos>a.</pos> <def>Of or pertaining to the German physicist
<person>Wilhelm Konrad R<oum/ntgen</person>, or the rays discovered by
him; <as>as, <ex>R<oum/ntgen</ex> apparatus</as>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Roentgenize</ent><br/
<hw>R<oum/nt"gen*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<fld>(Physics)</fld> <def>To render (air or other gas) conducting by the
passage of R<oum/ntgen rays.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Roentgen ray</ent><br/
<mhw><hw>R<oum/ntgen ray</hw>, <hw>Roentgen ray</hw></mhw>. <ety>[see
<er>R<oum/ntgen</er>.]</ety> <fld>(Physics)</fld> <def>An
<er>X-ray</er>; originally, the term was applied to any of the rays
produced when cathode rays strike upon surface of a solid (as the wall
of the vacuum tube), but now it refers specifically to electromagnetic
radiation having wavelengths from 10<exp>-3</exp> nm to 10 nm,
immediately below ultraviolet radiation on the wavelength scale.
R<oum/ntgen rays are noted for their penetration of opaque substances,
as wood and flesh, their action on photographic plates, and their
fluorescent effects. They were called <altname>X rays</altname> by their
discoverer, <person>W. K. R<oum/ntgen</person>. They are one of the
forms of <isa>ionizing radiation</isa>, which can have damaging effects
on living cells. They also ionize gases, but cannot be reflected, or
polarized, or deflected by a magnetic field. They are used in examining
opaque objects, especially in medicine for visualizing organs and other
objects inside the human body, as for locating fractures or bullets, and
examining internal organs for abnormalities.</def><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><ent>Rood</ent><br/
<hw>Rood</hw> <pr>(r<oomac/d)</pr>, <pos>n.</pos> <ety>[AS.
<ets>r<omac/d</ets> a cross; akin to OS. <ets>r<omac/da</ets>, D.
<ets>roede</ets> rod, G. <ets>ruthe</ets>, <ets>rute</ets>, OHG.
<ets>ruota</ets>. Cf. <er>Rod</er> a measure.]</ety> <sn>1.</sn> <def>A
representation in sculpture or in painting of the cross with Christ
hanging on it.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Generally, the Trinity is represented, the Father as an
elderly man fully clothed, with a nimbus around his head, and holding
the cross on which the Son is represented as crucified, the Holy Spirit
descending in the form of a dove near the Son's head. Figures of the
Virgin Mary and of St. John are often placed near the principal
figures.</note><br/
[<source>1913 Webster</source>]</p>

<p><q>Savior, in thine image seen<br/
Bleeding on that precious <qex>rood</qex>.</q>
<rj><qau>Wordsworth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A measure of five and a half yards in length; a rod;
a perch; a pole.</def> <mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The fourth part of an acre, or forty square
rods.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>By the rood</b></col>, <cd>by the cross; -- a phrase
formerly used in swearing.</cd> <ldquo/No, <xex>by the rood</xex>, not
so.<rdquo/ <au>Shak.</au> -- <col><b>Rood beam</b></col>
<fld>(Arch.)</fld>, <cd>a beam across the chancel of a church,
supporting the rood.</cd> -- <col><b>Rood loft</b></col>
<fld>(Arch.)</fld>, <cd>a loft or gallery, in a church, on which the
rood and its appendages were set up to view.</cd> <au>Gwilt.</au> --
<col><b>Rood screen</b></col> <fld>(Arch.)</fld>, <cd>a screen, between
the choir and the body of the church, over which the rood was
placed.</cd> <au>Fairholt.</au> -- <col><b>Rood tower</b></col>
<fld>(Arch.)</fld>, <cd>a tower at the intersection of the nave and
transept of a church; -- when crowned with a spire it was called also
<stype>rood steeple</stype>.</cd> <au>Weale.</au> -- <col><b>Rood
tree</b></col>, <cd>the cross.</cd> <mark>[Obs.]</mark> <ldquo/Died upon
the <xex>rood tree</xex>.<rdquo/ <au>Gower.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roodebok</ent><br/
<hw>Roo"de*bok</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[D. <ets>rood</ets>
red + <ets>bok</ets> buck.]</ety> <fld>(Zool.)</fld> <def>The
pallah.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roody</ent><br/
<hw>Rood"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Rank in growth.</def>
<mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roof</ent><br/
<hw>Roof</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>rof</ets>, AS.
<ets>hr<?/f</ets> top, roof; akin to D. <ets>roef</ets> cabin, Icel.
<ets>hr<?/f</ets> a shed under which ships are built or kept; cf. OS.
<ets>hr<?/st</ets> roof, Goth. <ets>hr<?/t</ets>. Cf.
<er>Roost</er>.]</ety> <sn>1.</sn> <fld>(Arch.)</fld> <def>The cover of
any building, including the roofing (see <er>Roofing</er>) and all the
materials and construction necessary to carry and maintain the same upon
the walls or other uprights. In the case of a building with vaulted
ceilings protected by an outer roof, some writers call the vault the
<xex>roof</xex>, and the outer protection the <xex>roof mask</xex>. It
is better, however, to consider the vault as the ceiling only, in cases
where it has farther covering.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which resembles, or corresponds to, the
covering or the ceiling of a house; <as>as, the <ex>roof</ex> of a
cavern; the <ex>roof</ex> of the mouth.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>The flowery <qex>roof</qex><br/
Showered roses, which the morn repaired.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Mining.)</fld> <def>The surface or bed of rock
immediately overlying a bed of coal or a flat vein.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Bell roof</b></col>, <col><b>French
roof</b></col></mcol>, <cd>etc. <fld>(Arch.)</fld> See under
<er>Bell</er>, <er>French</er>, etc.</cd> -- <col><b>Flat
roof</b></col>. <fld>(Arch.)</fld> <sd>(a)</sd> <cd>A roof actually
horizontal and level, as in some Oriental buildings</cd>. <sd>(b)</sd>
<cd>A roof nearly horizontal, constructed of such material as allows the
water to run off freely from a very slight inclination.</cd> --
<col><b>Roof plate</b></col>. <fld>(Arch.)</fld> <cd>See <er>Plate</er>,
<pos>n.</pos>, 10.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roof</ent><br/
<hw>Roof</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Roofed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Roofing</conjf>.]</vmorph> <sn>1.</sn> <def>To cover with a
roof.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I have not seen the remains of any Roman buildings that have not
been <qex>roofed</qex> with vaults or arches.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To inclose in a house; figuratively, to
shelter.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Here had we now our country's honor <qex>roofed</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roofer</ent><br/
<hw>Roof"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who puts on
roofs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roofing</ent><br/
<hw>Roof"ing</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act of covering
with a roof.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The materials of which a roof is composed; materials
for a roof.</def> <rj><au>Gwilt.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Hence, the roof itself; figuratively, shelter.</def>
<ldquo/Fit <xex>roofing</xex> gave.<rdquo/
<rj><au>Southey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Mining)</fld> <def>The wedging, as of a horse or
car, against the top of an underground passage.</def>
<rj><au>Raymond.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roofless</ent><br/
<hw>Roof"less</hw>, <pos>a.</pos> <sn>1.</sn> <def>Having no roof;
<as>as, a <ex>roofless</ex> house</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Having no house or home; shelterless;
homeless.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rooflet</ent><br/
<hw>Roof"let</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A small roof,
covering, or shelter.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rooftree</ent><br/
<hw>Roof"tree`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The beam in the
angle of a roof; hence, the roof itself.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Now for me the woods may wither, now for me the
<qex>rooftree</qex> fall.</q> <rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roofy</ent><br/
<hw>Roof`y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having roofs.</def>
<mark>[R.]</mark> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rook</ent><br/
<hw>Rook</hw> <pr>(r<oocr/k)</pr>, <pos>n.</pos> <def>Mist; fog. See
<er>Roke</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rook</ent><br/
<hw>Rook</hw>, <pos>v. i.</pos> <def>To squat; to ruck.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rook</ent><br/
<hw>Rook</hw>, <pos>n.</pos> <ety>[F. <ets>roc</ets> (cf. Sp.
<ets>roque</ets>), fr. Per. & Ar. <ets>rokh</ets>, or <ets>rukh</ets>,
the rook or castle at chess, also the bird <ets>roc</ets> (in this sense
perhaps a different word); cf. Hind. <ets>rath</ets> a war chariot, the
castle at chess, Skr. <ets>ratha</ets> a car, a war car. Cf.
<er>Roll</er>.]</ety> <fld>(Chess)</fld> <def>One of the four pieces
placed on the corner squares of the board; a castle.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rook</ent><br/
<hw>Rook</hw>, <pos>n.</pos> <ety>[AS. <ets>hr<omac/c</ets>; akin to
OHG. <ets>hruoh</ets>, <ets>ruoh</ets>, <ets>ruoho</ets>, Icel.
<ets>hr<omac/kr</ets>, Sw. <ets>roka</ets>, Dan. raage; cf. Goth.
<ets>hrukjan</ets> to crow.]</ety> <sn>1.</sn> <fld>(Zool.)</fld> <def>A
European bird (<spn>Corvus frugilegus</spn>) resembling the crow, but
smaller. It is black, with purple and violet reflections. The base of
the beak and the region around it are covered with a rough, scabrous
skin, which in old birds is whitish. It is gregarious in its habits. The
name is also applied to related Asiatic species.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>The rook</qex> . . . should be treated as the farmer's
friend.</q> <rj><qau>Pennant.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A trickish, rapacious fellow; a cheat; a
sharper.</def> <rj><au>Wycherley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rook</ent><br/
<hw>Rook</hw>, <pos>v. t. & i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Rooked</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Rooking</conjf>.]</vmorph> <def>To cheat; to defraud by
cheating.</def> <ldquo/A band of <xex>rooking</xex> officials.<rdquo/
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rookery</ent><br/
<hw>Rook"er*y</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Rookeries</plw> <pr>(<?/)</pr>.</plu> <sn>1.</sn> <def>The breeding
place of a colony of rooks; also, the birds themselves.</def>
<rj><au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A breeding place of other gregarious birds, as of
herons, penguins, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The breeding ground of seals, esp. of the fur
seals.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A dilapidated building with many rooms and
occupants; a cluster of dilapidated or mean buildings.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A brothel.</def> <mark>[Low]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rooky</ent><br/
<hw>Rook"y</hw> <pr>(-<ycr/)</pr>, <pos>a.</pos> <ety>[See
<er>Roky</er>.]</ety> <def>Misty; gloomy.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Light thickens, and the crow<br/
Makes wing to the <qex>rooky</qex> wood.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Some make this Shakespearean word mean <ldquo/abounding
in rooks.<rdquo/</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Room</ent><br/
<hw>Room</hw> <pr>(r<oomac/m)</pr>, <pos>n.</pos> <ety>[OE.
<ets>roum</ets>, <ets>rum</ets>, space, AS. <ets>r<umac/m</ets>; akin to
OS., OFries. & Icel. <ets>r<umac/m</ets>, D. <ets>ruim</ets>, G.
<ets>raum</ets>, OHG. <ets>r<umac/m</ets>, Sw. & Dan. <ets>rum</ets>,
Goth. <ets>r<umac/ms</ets>, and to AS. <ets>r<umac/m</ets>, adj.,
spacious, D. <ets>ruim</ets>, Icel. <ets>r<umac/mr</ets>, Goth.
<ets>r<umac/ms</ets>; and prob. to L. <ets>rus</ets> country (cf.
<er>Rural</er>), Zend <ets>rava<ndot/h</ets> wide, free, open,
<ets>ravan</ets> a plain.]</ety> <sn>1.</sn> <def>Unobstructed spase;
space which may be occupied by or devoted to any object; compass; extent
of place, great or small; <as>as, there is not <ex>room</ex> for a
house; the table takes up too much <ex>room</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Lord, it is done as thou hast commanded, and yet there is
<qex>room</qex>.</q> <rj><qau>Luke xiv. 22.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>There was no <qex>room</qex> for them in the inn.</q>
<rj><qau>Luke ii. 7.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A particular portion of space appropriated for
occupancy; a place to sit, stand, or lie; a seat.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If he have but twelve pence in his purse, he will give it for the
best <qex>room</qex> in a playhouse.</q>
<rj><qau>Overbury.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>When thou art bidden of any man to a wedding, sit not down in the
highest <qex>room</qex>.</q> <rj><qau>Luke xiv. 8.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Especially, space in a building or ship inclosed or
set apart by a partition; an apartment or chamber.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I found the prince in the next <qex>room</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Place or position in society; office; rank; post;
station; also, a place or station once belonging to, or occupied by,
another, and vacated.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>When he heard that Archelaus did reign in Judea in the
<qex>room</qex> of his father Herod.</q> <rj><qau>Matt. ii.
22.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Neither that I look for a higher <qex>room</qex> in heaven.</q>
<rj><qau>Tyndale.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Let Bianca take her sister's <qex>room</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Possibility of admission; ability to admit;
opportunity to act; fit occasion; <as>as, to leave <ex>room</ex> for
hope</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There was no prince in the empire who had <qex>room</qex> for such
an alliance.</q> <rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<cs><p><col><b>Room and space</b></col> <fld>(Shipbuilding)</fld>,
<cd>the distance from one side of a rib to the corresponding side of the
next rib; <xex>space</xex> being the distance between two ribs, in the
clear, and <xex>room</xex> the width of a rib.</cd> -- <col><b>To give
room</b></col>, <cd>to withdraw; to leave or provide space unoccupied
for others to pass or to be seated.</cd> -- <col><b>To make
room</b></col>, <cd>to open a space, way, or passage; to remove
obstructions; to give room.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Make room</qex>, and let him stand before our face.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p></cs>

<p><syn><b>Syn.</b> -- Space; compass; scope; latitude.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Room</ent><br/
<hw>Room</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Roomed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Rooming</conjf>.]</vmorph> <def>To occupy a room or rooms; to
lodge; <as>as, they arranged to <ex>room</ex> together</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Room</ent><br/
<hw>Room</hw>, <pos>a.</pos> <ety>[AS. <ets>r<umac/m</ets>.]</ety>
<def>Spacious; roomy.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>No <qex>roomer</qex> harbour in the place.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roomage</ent><br/
<hw>Room"age</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From <er>Room</er>.
CF. <er>Rummage</er>.]</ety> <def>Space; place; room.</def>
<mark>[Obs.]</mark> <rj><au>Sir H. Wotton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roomer</ent><br/
<hw>Room"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A lodger.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roomer</ent><br/
<hw>Room"er</hw> <pr>(?)</pr>, <pos>adv.</pos> <ety>[See <er>Room</er>,
<pos>a.</pos>]</ety> <def>At a greater distance; farther off.</def>
<mark>[Obs.]</mark> <rj><au>Sir J. Harrington.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roomful</ent><br/
<hw>Room"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Abounding with room
or rooms; roomy.</def> <ldquo/A <xex>roomful</xex> house.<rdquo/
<mark>[R.]</mark> <rj><au>Donne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roomful</ent><br/
<hw>Room"ful</hw>, <pos>n.</pos>; <plu><it>pl.</it> <plw>Roomfuls</plw>
<pr>(<?/)</pr>.</plu> <def>As much or many as a room will hold; <as>as,
a <ex>roomful</ex> of men</as>.</def> <rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roomily</ent><br/
<hw>Room"i*ly</hw> <pr>(?)</pr>, <pos>adv.</pos>
<def>Spaciously.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roominess</ent><br/
<hw>Room"i*ness</hw>, <pos>n.</pos> <def>The quality or state of being
roomy; spaciousness; <as>as, the <ex>roominess</ex> of a
hall</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roomless</ent><br/
<hw>Room"less</hw>, <pos>a.</pos> <def>Being without room or
rooms.</def> <rj><au>Udall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roommate</ent><br/
<hw>Room"mate`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One of two or more
occupying the same room or rooms; one who shares the occupancy of a room
or rooms; a chum.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roomsome</ent><br/
<hw>Room"some</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Roomy.</def>
<mark>[Obs.]</mark> <rj><au>Evelyn.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roomth</ent><br/
<hw>Roomth</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Room; space.</def>
<mark>[Obs.]</mark> <rj><au>Drayton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roomthy</ent><br/
<hw>Roomth"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Roomy;
spacious.</def> <mark>[Obs.]</mark> <rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roomy</ent><br/
<hw>Room"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having ample room;
spacious; large; <as>as, a <ex>roomy</ex> mansion; a <ex>roomy</ex>
deck.</as></def> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roon</ent><br/
<hw>Roon</hw> <pr>(?)</pr>, <pos>a. & n.</pos> <def>Vermilion red;
red.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Her face was like the lily <qex>roon</qex>.</q> <rj><qau>J. R.
Drake.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roop</ent><br/
<hw>Roop</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See <er>Roup</er>.</def>
<mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roorbach</ent><br/
<ent>Roorback</ent><br/
<mhw>{ <hw>Roor"back</hw>, <hw>Roor"bach</hw> }</mhw> <pr>(?)</pr>,
<pos>n.</pos> <def>A defamatory forgery or falsehood published for
purposes of political intrigue.</def> <mark>[U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The word originated in the election canvass of 1844,
when such a forgery was published, to the detriment of James K. Polk, a
candidate for President, purporting to be an extract from the
<ldquo/Travels of Baron <xex>Roorbach</xex>.<rdquo/</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roosa oil</ent><br/
<hw>Roo"sa oil`</hw> <pr>(?)</pr>. <def>The East Indian name for grass
oil. See under <er>Grass</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roost</ent><br/
<hw>Roost</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Roast.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roost</ent><br/
<hw>Roost</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>See <er>Roust</er>,
<pos>v. t.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roost</ent><br/
<hw>Roost</hw>, <pos>n.</pos> <ety>[AS. <ets>hr<omac/st</ets>; akin to
OD. <ets>roest</ets> roost, <ets>roesten</ets> to roost, and probably to
E. <ets>roof</ets>. Cf. <er>Roof</er>.]</ety> <sn>1.</sn> <def>The pole
or other support on which fowls rest at night; a perch.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He clapped his wings upon his <qex>roost</qex>.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A collection of fowls roosting together.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>At roost</b></col>, <cd>on a perch or roost; hence,
retired to rest.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roost</ent><br/
<hw>Roost</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Roosted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Roosting</conjf>.]</vmorph> <sn>1.</sn> <def>To sit, rest, or
sleep, as fowls on a pole, limb of a tree, etc.; to perch.</def>
<rj><au>Wordsworth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Fig.; To lodge; to rest; to sleep.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>O, let me where thy roof my soul hath hid,<br/
O, let me <qex>roost</qex> and nestle there.</q>
<rj><qau>Herbert.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roostcock</ent><br/
<hw>Roost"cock`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The male of the
domestic fowl; a cock.</def> <mark>[Prov. Eng.]</mark>
<rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rooster</ent><br/
<hw>Roost"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The male of the
domestic fowl; a cock.</def> <mark>[U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Nor, when they [the Skinners and Cow Boys] wrung the neck of a
<qex>rooster</qex>, did they trouble their heads whether he crowed for
Congress or King George.</q> <rj><qau>W. Irving.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Root</ent><br/
<hw>Root</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[AS.
<ets>wr<omac/tan</ets>; akin to <ets>wr<omac/t</ets> a snout, trunk, D.
<ets>wroeten</ets> to root, G. <ets>r<uum/ssel</ets> snout, trunk,
proboscis, Icel. <ets>r<omac/ta</ets> to root, and perhaps to L.
<ets>rodere</ets> to gnaw (E. <ets>rodent</ets>) or to E.
<ets>root</ets>, n.]</ety> <sn>1.</sn> <def>To turn up the earth with
the snout, as swine.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence, to seek for favor or advancement by low arts
or groveling servility; to fawn servilely.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Root</ent><br/
<hw>Root</hw>, <pos>v. t.</pos> <def>To turn up or to dig out with the
snout; <as>as, the swine <ex>roots</ex> the earth</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Root</ent><br/
<hw>Root</hw>, <pos>n.</pos> <ety>[Icel. <ets>r<omac/t</ets> (for
<ets>vr<omac/t</ets>); akin to E. <ets>wort</ets>, and perhaps to
<ets>root</ets> to turn up the earth. See <er>Wort</er>.]</ety>
<sn>1.</sn> <fld>(Bot.)</fld> <sd>(a)</sd> <def>The underground portion
of a plant, whether a true root or a tuber, a bulb or rootstock, as in
the potato, the onion, or the sweet flag.</def> <sd>(b)</sd> <def>The
descending, and commonly branching, axis of a plant, increasing in
length by growth at its extremity only, not divided into joints,
leafless and without buds, and having for its offices to fix the plant
in the earth, to supply it with moisture and soluble matters, and
sometimes to serve as a reservoir of nutriment for future growth. A true
root, however, may never reach the ground, but may be attached to a
wall, etc., as in the ivy, or may hang loosely in the air, as in some
epiphytic orchids.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1251 --></p>

<p><sn>2.</sn> <def>An edible or esculent root, especially of such
plants as produce a single root, as the beet, carrot, etc.; <as>as, the
<ex>root</ex> crop</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which resembles a root in position or function,
esp. as a source of nourishment or support; that from which anything
proceeds as if by growth or development; <as>as, the <ex>root</ex> of a
tooth, a nail, a cancer, and the like</as>.</def> Specifically:
<sd>(a)</sd> <def>An ancestor or progenitor; and hence, an early race; a
stem.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They were the <qex>roots</qex> out of which sprang two distinct
people.</q> <rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(b)</sd> <def>A primitive form of speech; one of the earliest
terms employed in language; a word from which other words are formed; a
radix, or radical.</def> <sd>(c)</sd> <def>The cause or occasion by
which anything is brought about; the source.</def> <ldquo/She herself .
. . is <xex>root</xex> of bounty.<rdquo/ <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The love of money is a <qex>root</qex> of all kinds of evil.</q>
<rj><qau>1 Tim. vi. 10 (rev. Ver.)</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(d)</sd> <fld>(Math.)</fld> <def>That factor of a quantity which
when multiplied into itself will produce that quantity; <as>thus, 3 is a
<ex>root</ex> of 9, because 3 multiplied into itself produces 9; 3 is
the cube <ex>root</ex> of 27</as>.</def> <sd>(e)</sd> <fld>(Mus.)</fld>
<def>The fundamental tone of any chord; the tone from whose harmonics,
or overtones, a chord is composed.</def> <rj><au>Busby.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(f)</sd> <def>The lowest place, position, or part.</def>
<ldquo/Deep to the <xex>roots</xex> of hell.<rdquo/ <au>Milton.</au>
<ldquo/The <xex>roots</xex> of the mountains.<rdquo/
<au>Southey.</au><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Astrol.)</fld> <def>The time which to reckon in
making calculations.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>When a <qex>root</qex> is of a birth yknowe [known].</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Aerial roots</b></col>. <fld>(Bot.)</fld> <sd>(a)</sd>
<cd>Small roots emitted from the stem of a plant in the open air, which,
attaching themselves to the bark of trees, etc., serve to support the
plant.</cd> <sd>(b)</sd> <cd>Large roots growing from the stem, etc.,
which descend and establish themselves in the soil. See
<xex>Illust.</xex> of <er>Mangrove</er>.</cd> -- <col><b>Multiple
primary root</b></col> <fld>(Bot.)</fld>, <cd>a name given to the
numerous roots emitted from the radicle in many plants, as the
squash.</cd> -- <col><b>Primary root</b></col> <fld>(Bot.)</fld>,
<cd>the central, first-formed, main root, from which the rootlets are
given off.</cd> -- <col><b>Root and branch</b></col>, <cd>every part;
wholly; completely; <as>as, to destroy an error <ex>root and
branch</ex></as>.</cd> -- <col><b>Root-and-branch men</b></col>,
<cd>radical reformers; -- a designation applied to the English
Independents (1641). See Citation under <er>Radical</er>, <pos>n.</pos>,
2.</cd> -- <col><b>Root barnacle</b></col> <fld>(Zool.)</fld>, <cd>one
of the Rhizocephala.</cd> -- <col><b>Root hair</b></col>
<fld>(Bot.)</fld>, <cd>one of the slender, hairlike fibers found on the
surface of fresh roots. They are prolongations of the superficial cells
of the root into minute tubes.</cd> <au>Gray.</au> -- <col><b>Root
leaf</b></col> <fld>(Bot.)</fld>, <cd>a radical leaf.</cd> See
<er>Radical</er>, <pos>a.</pos>, 3 <sd>(b)</sd>. -- <col><b>Root
louse</b></col> <fld>(Zool.)</fld>, <cd>any plant louse, or aphid, which
lives on the roots of plants, as the Phylloxera of the grapevine.</cd>
See <er>Phylloxera</er>. -- <col><b>Root of an equation</b></col>
<fld>(Alg.)</fld>, <cd>that value which, substituted for the unknown
quantity in an equation, satisfies the equation.</cd> -- <col><b>Root of
a nail</b></col> <sd>(Anat.)</sd>, <cd>the part of a nail which is
covered by the skin.</cd> -- <col><b>Root of a tooth</b></col>
<fld>(Anat.)</fld>, <cd>the part of a tooth contained in the socket and
consisting of one or more fangs.</cd> -- <col><b>Secondary
roots</b></col> <fld>(Bot.)</fld>, <cd>roots emitted from any part of
the plant above the radicle.</cd> -- <mcol><col><b>To strike
root</b></col>, <col><b>To take root</b></col></mcol>, <cd>to send forth
roots; to become fixed in the earth, etc., by a root; hence, in general,
to become planted, fixed, or established; to increase and spread; as, an
opinion <xex>takes root</xex>.</cd> <ldquo/The bended twigs <xex>take
root</xex>.<rdquo/ <au>Milton.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Root</ent><br/
<hw>Root</hw> <pr>(r<oomac/t)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Rooted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Rooting</conjf>.]</vmorph> <sn>1.</sn> <def>To fix the root; to
enter the earth, as roots; to take root and begin to grow.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In deep grounds the weeds <qex>root</qex> deeper.</q>
<rj><qau>Mortimer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To be firmly fixed; to be established.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If any irregularity chanced to intervene and to cause
misappehensions, he gave them not leave to <qex>root</qex> and fasten by
concealment.</q> <rj><qau>Bp. Fell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Root</ent><br/
<hw>Root</hw>, <pos>v. i.</pos> <ety>[Cf. <er>Rout</er> to roar.]</ety>
<def>To shout for, or otherwise noisly applaud or encourage, a
contestant, as in sports; hence, to wish earnestly for the success of
some one or the happening of some event, with the superstitious notion
that this action may have efficacy; -- usually with <xex>for</xex>;
<as>as, the crowd <ex>rooted</ex> for the home team</as>.</def>
<mark>[Slang or Cant, U. S.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Root</ent><br/
<hw>Root</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To plant and fix deeply
in the earth, or as in the earth; to implant firmly; hence, to make deep
or radical; to establish; -- used chiefly in the participle; <as>as,
<ex>rooted</ex> trees or forests; <ex>rooted</ex>
dislike.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To tear up by the root; to eradicate; to extirpate;
-- with <xex>up</xex>, <xex>out</xex>, or <xex>away</xex>.</def>
<ldquo/I will go <xex>root</xex> away the noisome weeds.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The Lord <qex>rooted</qex> them out of their land . . . and cast
them into another land.</q> <rj><qau>Deut. xxix. 28.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rootcap</ent><br/
<hw>Root"cap`</hw> <pr>(r<oomac/t"k<acr/p`)</pr>, <pos>n.</pos>
<fld>(Bot.)</fld> <def>A mass of parenchymatous cells which covers and
protects the growing cells at the end of a root; a pileorhiza.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rooted</ent><br/
<hw>Root"ed</hw>, <pos>a.</pos> <def>Having taken root; firmly
implanted; fixed in the heart.</def> <ldquo/A <xex>rooted</xex>
sorrow.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Root"ed*ly</wf>, <pos>adv.</pos> --
<wf>Root"ed*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rooter</ent><br/
<hw>Rooter</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who, or
that which, roots; one that tears up by the roots.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who roots, or applauds.</def> <mark>[Slang, U.
S.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Rootery</ent><br/
<hw>Root"er*y</hw>, <pos>n.</pos> <def>A pile of roots, set with plants,
mosses, etc., and used as an ornamental object in gardening.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rootless</ent><br/
<hw>Root"less</hw>, <pos>a.</pos> <def>Destitute of roots.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rootlet</ent><br/
<hw>Root"let</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A radicle; a little
root.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rootstock</ent><br/
<hw>Root"stock`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>A perennial underground stem, producing leafly stems or flower
stems from year to year; a rhizome.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rooty</ent><br/
<hw>Root"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Full of roots; <as>as,
<ex>rooty</ex> ground</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ropalic</ent><br/
<hw>Ro*pal"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>See
<er>Rhopalic</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rope</ent><br/
<hw>Rope</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS. <ets>r<amac/p</ets>;
akin to D. <ets>reep</ets>, G. <ets>reif</ets> ring hoop, Icel.
<ets>reip</ets> rope, Sw. <ets>rep</ets>, Dan. <ets>reb</ets>,
<ets>reeb</ets> Goth. skauda<ets>raip</ets> latchet.]</ety> <sn>1.</sn>
<def>A large, stout cord, usually one not less than an inch in
circumference, made of strands twisted or braided together. It differs
from <xex>cord</xex>, <xex>line</xex>, and <xex>string</xex>, only in
its size. See <er>Cordage</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A row or string consisting of a number of things
united, as by braiding, twining, etc.; <as>as, a <ex>rope</ex> of
onions</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <pluf>pl.</pluf> <def>The small intestines; <as>as, the
<ex>ropes</ex> of birds</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Rope ladder</b></col>, <cd>a ladder made of ropes.</cd>
-- <col><b>Rope mat</b></col>., <cd>a mat made of cordage, or strands of
old rope.</cd> -- <col><b>Rope of sand</b></col>, <cd>something of no
cohession or fiber; a feeble union or tie; something not to be relied
upon.</cd> -- <col><b>Rope pump</b></col>, <cd>a pump in which a rapidly
running endless rope raises water by the momentum communicated to the
water by its adhesion to the rope.</cd> -- <col><b>Rope
transmission</b></col> <fld>(Mach.)</fld>, <cd>a method of transmitting
power, as between distant places, by means of endless ropes running over
grooved pulleys.</cd> -- <col><b>Rope's end</b></col>, <cd>a piece of
rope; especially, one used as a lash in inflicting punishment.</cd> --
<col><b>To give one rope</b></col>, <cd>to give one liberty or license;
to let one go at will uncheked.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rope</ent><br/
<hw>Rope</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Roped</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Roping</conjf>.]</vmorph> <def>To be formed into rope; to draw
out or extend into a filament or thread, as by means of any glutinous or
adhesive quality.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Let us not hang like <qex>roping</qex>icicles<br/
Upon our houses' thatch.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rope</ent><br/
<hw>Rope</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To bind, fasten, or tie
with a rope or cord; <as>as, to <ex>rope</ex> a bale of
goods</as>.</def> Hence: --<br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To connect or fasten together, as a party of
mountain climbers, with a rope.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To partition, separate, or divide off, by means of a
rope, so as to include or exclude something; <as>as, to <ex>rope
in</ex>, <ex>or rope</ex> off, a plot of ground; to <ex>rope</ex> out a
crowd</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To lasso (a steer, horse).</def> <mark>[Colloq.
U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To draw, as with a rope; to entice; to inveigle; to
decoy; <as>as, to <ex>rope in customers or voters</ex></as>.</def>
<mark>[Slang, U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To prevent from winning (as a horse), by pulling or
curbing.</def> <mark>[Racing Slang, Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ropeband</ent><br/
<hw>Rope"band`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Naut.)</fld>
<def>A small piece of spun yarn or marline, used to fasten the head of
the sail to the spar.</def> <altsp>[Written also <asp>roband</asp>, and
<asp>robbin</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ropedancer</ent><br/
<hw>Rope"dan`cer</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who dances,
walks, or performs acrobatic feats, on a rope extended through the air
at some height.</def> -- <wordforms><wf>Rope"dan`cing</wf>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roper</ent><br/
<hw>Rop"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A maker of
ropes.</def> <rj><au>P. Plowman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who ropes goods; a packer.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>One fit to be hanged.</def> <mark>[Old Slang]</mark>
<rj><au>Douce.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ropery</ent><br/
<hw>Rop"er*y</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A place
where ropes are made.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Tricks deserving the halter; roguery.</def>
<mark>[Obs.]</mark> <ldquo/Saucy merchant . . . so full of his
<xex>ropery</xex>.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rope's-end</ent><br/
<hw>Rope's"-end`</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To punish with
a rope's end.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ropewalk</ent><br/
<hw>Rope"walk`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>A long, covered
walk, or a low, level building, where ropes are manufactured.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ropewalker</ent><br/
<hw>Rope"walk`er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A
ropedancer.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rope-yarn</ent><br/
<hw>Rope"-yarn`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>the yarn or thread
of any stuff of which the strands of a rope are made.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ropily</ent><br/
<hw>Rop"i*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a ropy manner;
in a viscous or glutinous manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ropiness</ent><br/
<hw>Rop"i*ness</hw>, <pos>n.</pos> <def>Quality of being ropy;
viscosity.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ropish</ent><br/
<hw>Rop"ish</hw>, <pos>a.</pos> <def>Somewhat ropy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ropy</ent><br/
<hw>Rop"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>capable of being drawn
into a thread, as a glutinous substance; stringy; viscous; tenacious;
glutinous; <as>as <ex>ropy</ex> sirup; <ex>ropy</ex>
lees</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roque</ent><br/
<hw>Roque</hw> <pr>(r<omac/k)</pr>, <pos>n.</pos> <ety>[Abbr. fr.
<er>Croquet</er>.]</ety> <def>A form of croquet modified for greater
accuracy of play. The court has a wood border often faced with rubber,
used as a cushion in bank shots. The balls are 3<frac14/ in. in
diameter, the cage (center arches or wickets) 3<frac38/ in. wide, the
other arches 3<frac12/ in. wide.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Roquefort</ent><br/
<ent>Roquefort cheese</ent><br/
<mhw>{ <hw>Roque`fort" cheese</hw>, <it>or</it> <hw>Roque`fort"</hw>
}</mhw> <pr>(?)</pr>, <pos>n.</pos> <def>A highly flavored blue-molded
cheese, made at <etsep>Roquefort</etsep>, department of Aveyron, France.
It is made from milk of ewes, sometimes with cow's milk added, and is
cured in caves. Improperly, a cheese made in imitation of it.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Roquelaure</ent><br/
<hw>Roq"ue*laure</hw> <pr>(?; 277)</pr>, <pos>n.</pos> <ety>[F.; so
called after Duc de <etsep>Roquelaure</etsep>, in the reign of Louis
XIV.]</ety> <def>A cloak reaching about to, or just below, the knees,
worn in the 18th century.</def> <altsp>[Written also
<asp>roquelo</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roquet</ent><br/
<hw>Ro*quet"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Etymol.
uncertain]</ety> <fld>(Croquet)</fld> <def>To hit, as another's ball,
with one's own ball.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roquet</ent><br/
<hw>Ro*quet"</hw>, <pos>v. i.</pos> <def>To hit another's ball with
one's own.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roral</ent><br/
<hw>Ro"ral</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>ros</ets>,
<ets>roris</ets>, dew.]</ety> <def>Of or pertaining to dew; consisting
of dew; dewy.</def> <mark>[R.]</mark> <rj><au>M. Green.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roration</ent><br/
<hw>Ro*ra"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>roratio</ets>, fr. <ets>rorare</ets> to drop dew, fr.
<ets>ros</ets> dew.]</ety> <def>A falling of dew.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roric</ent><br/
<hw>Ro"ric</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>ros</ets>,
<ets>roris</ets>, dew.]</ety> <def>Of or pertaining to dew; resembling
dew; dewy.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Roric figures</b></col> <fld>(Physics)</fld>, <cd>figures
which appear upon a polished surface, as glass, when objects which have
been near to, or in contact with, the surface are removed and the
surface breathed upon; -- called also <altname>Moser's
images</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rorid</ent><br/
<hw>Ro"rid</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>roridus</ets>,
fr. <ets>ros</ets>, <ets>roris</ets>, dew.]</ety> <def>Dewy;
bedewed.</def> <mark>[R.]</mark> <rj><au>T. Granger.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roriferous</ent><br/
<hw>Ro*rif"er*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>rorifer</ets>; <ets>ros</ets>, <ets>roris</ets>, dew +
<ets>ferre</ets> to bear: cf. F. <ets>rorif<egrave/re</ets>.]</ety>
<def>generating or producing dew.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rorifluent</ent><br/
<hw>Ro*rif"lu*ent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>ros</ets>, <ets>roris</ets>, dew + <ets>fluens</ets>, p. pr. of
<ets>fluere</ets> to flow.]</ety> <def>Flowing with dew.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rorqual</ent><br/
<hw>Ror"qual</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Norw.
<ets>rorqualus</ets> a whale with folds.]</ety> <fld>(Zool.)</fld>
<def>A very large North Atlantic whalebone whale (<spn>Physalus
antiquorum</spn>, or <spn>Balaenoptera physalus</spn>). It has a dorsal
fin, and strong longitudinal folds on the throat and belly. Called also
<altname>razorback</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ It is one of the largest of the whales, somethimes
becoming nearly one hundred feet long, but it is more slender than the
right whales, and is noted for its swiftness. The name is sometimes
applied to other related species of finback whales.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rorulent</ent><br/
<hw>Ro"ru*lent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>rorulentus</ets>, from <ets>ros</ets>, <ets>roris</ets>,
dew.]</ety> <sn>1.</sn> <def>Full of, or abounding in, dew.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>Having the surface appearing as
if dusty, or covered with fine dew.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rory</ent><br/
<hw>Ro"ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>ros</ets>,
<ets>roris</ets>, dew.]</ety> <def>Dewy.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>And shook his wings with <qex>rory</qex> May-dew wet.</q>
<rj><qau>Fairfax.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rosaceous</ent><br/
<hw>Ro*sa"ceous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>rosaceus</ets>, fr. <ets>rosa</ets> rose.]</ety> <sn>1.</sn>
<fld>(Bot.)</fld> <sd>(a)</sd> <def>Of or pertaining to a natural order
of plants (<ord>Rosaceae</ord>) of which the rose is the type. It
includes also the plums and cherries, meadowsweet, brambles, the
strawberry, the hawthorn, applies, pears, service trees, and
quinces.</def> <sd>(b)</sd> <def>Like a rose in shape or appearance;
<as>as, a <ex>rosaceous</ex> corolla</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of a pure purpish pink color.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rosacic</ent><br/
<hw>Ro*sac"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Rosaceous</er>.]</ety> <fld>(Old med. Chem.)</fld> <def>Pertaining
to, or designating, an acid (called also <xex>lithic acid</xex>) found
in certain red precipitates of urine. See <er>Uric</er>.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rosalgar</ent><br/
<hw>Ro*sal"gar</hw> <pr>(?)</pr>, <pos>n.</pos> <def>realgar.</def>
<mark>[Obs.]</mark> <rj><au>chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rosalia</ent><br/
\'d8<hw>Ro*sa"li*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>rosalie</ets>.]</ety> <fld>(Mus.)</fld> <def>A form of melody in
which a phrase or passage is successively repeated, each time a step or
half step higher; a melodic sequence.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rosaniline</ent><br/
<hw>Ros*an"i*line</hw> <pr>(? <or/ ?)</pr>, <pos>n.</pos>
<ety>[<ets>Rose</ets> + <ets>aniline</ets>.]</ety> <fld>(Chem.)</fld>
<def>A complex nitrogenous base, <chform>C20H21N3O</chform>, obtained by
oxidizing a mixture of aniline and toluidine, as a colorless crystalline
substance which forms red salts. These salts are essential components of
many of the socalled aniline dyes, as <xex>fuchsine</xex>, <xex>aniline
red</xex>, etc. By extension, any one of the series of substances
derived from, or related to, rosaniline proper.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rosarian</ent><br/
<hw>Ro*sa"ri*an</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A cultivator of
roses.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rosary</ent><br/
<hw>Ro"sa*ry</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Rosaries</plw> <pr>(#)</pr>.</plu> <ety>[LL. <ets>rosarium</ets> a
string of beads, L. <ets>rosarium</ets> a place planted with roses,
<ets>rosa</ets> a rose: cf. F. <ets>rosaire</ets>. See
<er>Rose</er>.]</ety> <sn>1.</sn> <def>A bed of roses, or place where
roses grow.</def> <ldquo/Thick <xex>rosaries</xex> of scented
thorn.<rdquo/ <rj><au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(R.C.Ch.)</fld> <def>A series of prayers (see Note
below) arranged to be recited in order, on beads; also, a string of
beads by which the prayers are counted.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His idolized book, and the whole <qex>rosary</qex> of his
prayers.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ A <xex>rosary</xex> consists of fifteen decades. Each
decade contains ten <xex>Ave Marias</xex> marked by small beads,
preceded by a <xex>Paternoster</xex>, marked by a larger bead, and
concluded by a <xex>Gloria Patri</xex>. Five decades make a
<xex>chaplet</xex>, a third part of the rosary.</note> <rj><au>Bp.
Fitzpatrick.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A chapelet; a garland; a series or collection, as of
beautiful thoughts or of literary selections.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Every day propound to yourself a <qex>rosary</qex> or chaplet of
good works to present to God at night.</q> <rj><qau>Jer.
Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A coin bearing the figure of a rose, fraudulently
circulated in Ireland in the 13th century for a penny.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Rosary shell</b></col> <fld>(Zool.)</fld>, <cd>any marine
gastropod shell of the genus <gen>Monodonta</gen>. They are top-shaped,
bright-colored and pearly.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roscid</ent><br/
<hw>Ros"cid</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>roscidus</ets>, fr. <ets>ros</ets>, <ets>roris</ets>, dew.]</ety>
<def>Containing, or consisting of, dew; dewy.</def> <mark>[R.]</mark>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roscoelite</ent><br/
<hw>Ros"coe*lite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From an English
chemist, H.E. <ets>Roscoe</ets> + <ets>-lite</ets>.]</ety>
<fld>(Min.)</fld> <def>A green micaceous mineral occurring in minute
scales. It is essentially a silicate of aluminia and potash containing
vanadium.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rose</ent><br/
<hw>Rose</hw> <pr>(?)</pr>, <def><pos>imp.</pos> of
<er>Rise</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rose</ent><br/
<hw>Rose</hw>, <pos>n.</pos> <ety>[AS. <ets>rose</ets>, L.
<ets>rosa</ets>, probably akin to Gr. <?/, Armor. <ets>vard</ets>, OPer.
<ets>vareda</ets>; and perhaps to E. <ets>wort</ets>: cf. F.
<ets>rose</ets>, from the Latin. Cf. <er>Copperas</er>,
<er>Rhododendron</er>.]</ety> <sn>1.</sn> <def>A flower and shrub of any
species of the genus <gen>Rosa</gen>, of which there are many species,
mostly found in the morthern hemispere</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Roses are shrubs with pinnate leaves and usually prickly
stems. The flowers are large, and in the wild state have five petals of
a color varying from deep pink to white, or sometimes yellow. By
cultivation and hybridizing the number of petals is greatly increased
and the natural perfume enhanced. In this way many distinct classes of
roses have been formed, as the <xex>Banksia</xex>, <xex>Baurbon</xex>,
<xex>Boursalt</xex>, <xex>China</xex>, <xex>Noisette</xex>, <xex>hybrid
perpetual</xex>, etc., with multitudes of varieties in nearly every
class.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A knot of ribbon formed like a rose; a rose knot; a
rosette, esp. one worn on a shoe.</def> <rj><au>Sha.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Arch.)</fld> <def>A rose window. See <cref>Rose
window</cref>, below.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A perforated nozzle, as of a pipe, spout, etc., for
delivering water in fine jets; a rosehead; also, a strainer at the foot
of a pump.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Med.)</fld> <def>The erysipelas.</def>
<rj><au>Dunglison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>The card of the mariner's compass; also, a circular
card with radiating lines, used in other instruments.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>The color of a rose; rose-red; pink.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>A diamond. See <cref>Rose diamond</cref>,
below.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Cabbage rose</b></col>, <col><b>China
rose</b></col></mcol>, <cd>etc. See under <er>Cabbage</er>,
<er>China</er>, etc.</cd> -- <col><b>Corn rose</b></col>
<fld>(Bot.)</fld> <cd>See <cref>Corn poppy</cref>, under
<er>Corn</er>.</cd> -- <col><b>Infantile rose</b></col>
<fld>(Med.)</fld>, <cd>a variety of roseola.</cd> -- <col><b>Jamaica
rose</b></col>. <fld>(Bot.)</fld> <cd>See under <er>Jamaica</er>.</cd>
-- <col><b>Rose acacia</b></col> <fld>(Bot.)</fld>, <cd>a low American
leguminous shrub (<spn>Robinia hispida</spn>) with handsome clusters of
rose-colored blossoms.</cd> -- <col><b>Rose aniline</b></col>.
<fld>(Chem.)</fld> <cd>Same as <er>Rosaniline</er>.</cd> -- <col><b>Rose
apple</b></col> <fld>(Bot.)</fld>, <cd>the fruit of the tropical
myrtaceous tree <spn>Eugenia Jambos</spn>. It is an edible berry an inch
or more in diameter, and is said to have a very strong roselike
perfume.</cd> -- <col><b>Rose beetle</b></col>. <fld>(Zool.)</fld>
<sd>(a)</sd> <cd>A small yellowish or buff longlegged beetle
(<spn>Macrodactylus subspinosus</spn>), which eats the leaves of various
plants, and is often very injurious to rosebushes, apple trees,
grapevines, etc. Called also <altname>rose bug</altname>, and
<altname>rose chafer</altname>.</cd> <sd>(b)</sd> <cd>The European
chafer.</cd> -- <col><b>Rose bug</b></col>. <fld>(Zool.)</fld> <cd>same
as <cref>Rose beetle</cref>, <cref>Rose chafer</cref>.</cd> --
<col><b>Rose burner</b></col>, <cd>a kind of gas-burner producing a
rose-shaped flame.</cd> -- <col><b>Rose camphor</b></col>
<fld>(Chem.)</fld>, <cd>a solid odorless substance which separates from
rose oil.</cd> -- <col><b>Rose campion</b></col>. <fld>(Bot.)</fld>
<cd>See under <er>Campion</er>.</cd> -- <col><b>Rose catarrh</b></col>
<fld>(Med.)</fld>, <cd>rose cold.</cd> -- <col><b>Rose chafer</b></col>.
<fld>(Zool.)</fld> <sd>(a)</sd> <cd>A common European beetle
(<spn>Cetonia aurata</spn>) which is often very injurious to rosebushes;
-- called also <altname>rose beetle</altname>, and <altname>rose
fly</altname>. <sd>(b)</sd> The rose beetle <sd>(a)</sd>.</cd> --
<col><b>Rose cold</b></col> <fld>(Med.)</fld>, <cd>a variety of hay
fever, sometimes attributed to the inhalation of the effluvia of roses.
See <cref>Hay fever</cref>, under <er>Hay</er>.</cd> -- <col><b>Rose
color</b></col>, <cd>the color of a rose; pink; hence, a beautiful hue
or appearance; fancied beauty, attractiveness, or promise.</cd> <-- p.
1252 --> -- <mcol><col><b>Rose de Pompadour</b></col>, <col><b>Rose du
Barry</b></col></mcol>, <cd>names succesively given to a delicate rose
color used on S<egrave/vres porcelain.</cd> -- <col><b>Rose
diamond</b></col>, <cd>a diamond, one side of which is flat, and the
other cut into twenty-four triangular facets in two ranges which form a
convex face pointed at the top. Cf. <er>Brilliant</er>,
<pos>n.</pos></cd> -- <col><b>Rose ear</b></col>. <cd>See under
<er>Ear</er>.</cd> -- <col><b>Rose elder</b></col> <fld>(Bot.)</fld>,
<cd>the Guelder-rose.</cd> -- <col><b>Rose engine</b></col>, <cd>a
machine, or an appendage to a turning lathe, by which a surface or wood,
metal, etc., is engraved with a variety of curved lines.</cd>
<au>Craig.</au> -- <col><b>Rose family</b></col> <fld>(Bot.)</fld>
<cd>the <spn>Roseceae</spn>.</cd> See <er>Rosaceous</er>. --
<col><b>Rose fever</b></col> <fld>(Med.)</fld>, <cd>rose cold.</cd> --
<col><b>Rose fly</b></col> <fld>(Zool.)</fld>, <cd>a rose betle, or rose
chafer.</cd> -- <col><b>Rose gall</b></col> <fld>(Zool.)</fld>, <cd>any
gall found on rosebushes.</cd> See <er>Bedeguar</er>. -- <col><b>Rose
knot</b></col>, <cd>a ribbon, or other pliade band plaited so as to
resemble a rose; a rosette.</cd> -- <mcol><col><b>Rose lake</b></col>,
<col><b>Rose madder</b></col></mcol>, <cd>a rich tint prepared from lac
and madder precipitated on an earthy basis.</cd> <au>Fairholt.</au> --
<col><b>Rose mallow</b></col>. <fld>(Bot.)</fld> <sd>(a)</sd> <cd>A name
of several malvaceous plants of the genus <gen>Hibiscus</gen>, with
large rose-colored flowers.</cd> <sd>(b)</sd> <cd>the hollyhock</cd>. --
<col><b>Rose nail</b></col>, <cd>a nail with a convex, faceted
head.</cd> -- <col><b>Rose noble</b></col>, <cd>an ancient English gold
coin, stamped with the figure of a rose, first struck in the reign of
Edward III., and current at 6s. 8d.</cd> <au>Sir W. Scott.</au> --
<col><b>Rose of China</b></col>. <fld>(Bot.)</fld> <cd>See <cref>China
rose</cref> <sd>(b)</sd>, under <er>China</er>.</cd> -- <col><b>Rose of
Jericho</b></col> <fld>(Bot.)</fld>, <cd>a Syrian cruciferous plant
(<spn>Anastatica Hierochuntica</spn>) which rolls up when dry, and
expands again when moistened; -- called also <altname>resurrection
plant</altname>.</cd> -- <col><b>Rose of Sharon</b></col>
<fld>(Bot.)</fld>, <cd>an ornamental malvaceous shrub (<spn>Hibiscus
Syriacus</spn>). In the Bible the name is used for some flower not yet
identified, perhaps a Narcissus, or possibly the great lotus
flower.</cd> -- <col><b>Rose oil</b></col> <fld>(Chem.)</fld>, <cd>the
yellow essential oil extracted from various species of rose blossoms,
and forming the chief part of attar of roses.</cd> -- <col><b>Rose
pink</b></col>, <cd>a pigment of a rose color, made by dyeing chalk or
whiting with a decoction of Brazil wood and alum; also, the color of the
pigment.</cd> -- <col><b>Rose quartz</b></col> <fld>(Min.)</fld>, <cd>a
variety of quartz which is rose-red.</cd> -- <col><b>Rose
rash</b></col>. <fld>(Med.)</fld> <cd>Same as <er>Roseola</er>.</cd> --
<col><b>Rose slug</b></col> <fld>(Zool.)</fld>, <cd>the small green
larva of a black sawfly (<spn>Selandria rosae</spn>). These larvae feed
in groups on the parenchyma of the leaves of rosebushes, and are often
abundant and very destructive.</cd> -- <col><b>Rose window</b></col>
<fld>(Arch.)</fld>, <cd>a circular window filled with ornamental
tracery. Called also <altname>Catherine wheel</altname>, and
<altname>marigold window</altname>. Cf. <cref>wheel window</cref>, under
<er>Wheel</er>.</cd> -- <col><b>Summer rose</b></col> <fld>(Med.)</fld>,
<cd>a variety of roseola. See <er>Roseola</er>.</cd> -- <col><b>Under
the rose</b></col> <ety>[a translation of L. <ets>sub rosa</ets>]</ety>,
<cd>in secret; privately; in a manner that forbids disclosure; -- the
rose being among the ancients the symbol of secrecy, and hung up at
entertainments as a token that nothing there said was to be
divulged.</cd> -- <col><b>Wars of the Roses</b></col> <fld>(Eng.
Hist.)</fld>, <cd>feuds between the Houses of York and Lancaster, the
<xex>white rose</xex> being the badge of the House of York, and the
<xex>red rose</xex> of the House of Lancaster.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rose</ent><br/
<hw>Rose</hw> <pr>(?)</pr>, <pos>v. t.</pos> <sn>1.</sn> <def>To render
rose-colored; to redden; to flush.</def> <mark>[Poetic]</mark> <ldquo/A
maid yet <xex>rosed</xex> over with the virgin crimson of
modesty.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To perfume, as with roses.</def>
<mark>[Poetic]</mark> <rj><au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roseal</ent><br/
<hw>Ro"se*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>roseus</ets>, fr. <ets>rosa</ets> a rose.]</ety> <def>resembling a
rose in smell or color.</def> <mark>[Obs.]</mark> <rj><au>Sir T.
Elyot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roseate</ent><br/
<hw>Ro"se*ate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. L.
<ets>roseus</ets>, <ets>rosatus</ets>, prepared from roses. See
<er>Roseal</er>, <er>Rose</er>.]</ety> <sn>1.</sn> <def>Full of roses;
rosy; <as>as, <ex>roseate</ex> bowers</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>resembling a rose in color or fragrance; esp.,
tinged with rose color; blooming; <as>as, <ex>roseate</ex> beauty; her
<ex>roseate</ex> lips</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Roseate tern</b></col> <fld>(Zool.)</fld>, <cd>an
American and European tern (<spn>Sterna Dougalli</spn>) whose breast is
roseate in the breeding season.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rosebay</ent><br/
<hw>Rose"bay`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<sd>(a)</sd> <def>the oleander.</def> <mark>[Obs.]</mark> <sd>(b)</sd>
<def>Any shrub of the genus <gen>Rhododendron</gen>.</def>
<mark>[U.S.]</mark> <sd>(c)</sd> <def>An herb (<spn>Epilobium
spicatum</spn>) with showy purple flowers, common in Europe and North
America; -- called also <altname>great willow herb</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rosebud</ent><br/
<hw>Rose"bud`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The flower of a rose
before it opens, or when but partially open.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rosebush</ent><br/
<hw>Rose"bush`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The bush or shrub
which bears roses.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rose-colored</ent><br/
<hw>Rose"-col`ored</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Having the color of a pink rose; rose-pink; of a delicate pink
color.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Uncommonly beautiful; hence, extravagantly fine or
pleasing; alluring; <as>as, <ex>rose-colored</ex>
anticipations</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rose-cut</ent><br/
<hw>Rose"-cut`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Cut flat on the
reverse, and with a convex face formed of triangular facets in rows; --
said of diamonds and other precious stones. See <cref>Rose
diamond</cref>, under <er>Rose</er>. Cf. <er>Brilliant</er>,
<pos>n.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rosedrop</ent><br/
<hw>Rose"drop`</hw>, <pos>n.</pos> <sn>1.</sn> <def>A lozenge having a
rose flavor.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A kind of earring.</def>
<rj><au>Simmonds.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Med.)</fld> <def>A ruddy eruption upon the nose
caused by drinking ardent spirits; a grog blossom.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rosefinch</ent><br/
<hw>Rose"finch</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>Any one of numerous species of Asiatic finches of the genera
<gen>Carpodacus</gen>, and <gen>Propasser</gen>, and allied genera, in
which the male is more or less colored with rose red.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rosefish</ent><br/
<hw>Rose"fish`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>A large marine scorpaenoid food fish (<spn>Sebastes marinus</spn>)
found on the northern coasts of Europe and America. called also
<altname>red perch</altname>, <altname>hemdurgan</altname>,
<altname>Norway haddok</altname>, and also, erroneously,
<altname>snapper</altname>, <altname>bream</altname>, and
<altname>bergylt</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ When full grown it is usually bright rose-red or
orange-red; the young are usually mottled with red and ducky
brown.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rosehead</ent><br/
<hw>Rose"head`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>See
<er>Rose</er>, <pos>n.</pos>, 4.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A many-sided pyramidal head upon a nail; also a nail
with such a head.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roseine</ent><br/
<hw>Ro"se*ine</hw> <pr>(? <or/ ?)</pr>, <pos>n.</pos> <def>See
<er>Magenta</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roselite</ent><br/
<hw>Ro"se*lite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From the German
mineralogist G. <ets>Rose</ets> + <ets>-lite</ets>.]</ety>
<fld>(Min.)</fld> <def>A hydrous arsenite of cobalt, occuring in small
red crystals, allied to erythrite.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rosella</ent><br/
\'d8<hw>Ro"sel"la</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., dim. of L.
<ets>rosa</ets> rose.]</ety> <fld>(Zool.)</fld> <def>A beautiful
Australian parrakeet (<spn>Platycercus eximius</spn>) often kept as a
cage bird. The head and back of the neck are scarlet, the throat is
white, the back dark green varied with lighter green, and the breast
yellow.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roselle</ent><br/
<hw>Ro*selle"</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>a
malvaceous plant (<spn>Hibiscus Sabdariffa</spn>) cultivated in the east
and West Indies for its fleshy calyxes, which are used for making tarts
and jelly and an acid drink.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rosemaloes</ent><br/
<hw>Rose`mal"oes</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From the native
name; cf. Malay <ets>rasam<amac/la</ets> the name of the tree.]</ety>
<def>The liquid storax of the East Indian <spn>Liquidambar
orientalis</spn>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rosemary</ent><br/
<hw>Rose"ma*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>rosmarine</ets>, L. <ets>rosmarinus</ets>; <ets>ros</ets> dew (cf.
Russ. <ets>rosa</ets>, Lith. <ets>rasa</ets>, Skr. <ets>rasa</ets>
juice) + <ets>marinus</ets> marine: cf. F. <ets>romarin</ets>. In
English the word has been changed as if it meant the <ets>rose of
Mary</ets>. See <er>Marine</er>.]</ety> <def>A labiate shrub
(<spn>Rosmarinus officinalis</spn>) with narrow grayish leaves, growing
native in the southern part of France, Spain, and Italy, also in Asia
Minor and in China. It has a fragrant smell, and a warm, pungent,
bitterish taste. It is used in cookery, perfumery, etc., and is an
emblem of fidelity or constancy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There's <qex>rosemary</qex>, that's for remembrance.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Marsh rosemary</b></col>. <sd>(a)</sd> <cd>A little shrub
<fld>(Andromeda polifolia)</fld> growing in cold swamps and having
leaves like those of the rosemary</cd>. <sd>(b)</sd> <cd>See under
<er>Marsh</er>.</cd> -- <col><b>Rosemary pine</b></col>, <cd>the
loblolly pine. See under <er>Loblolly</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rosen</ent><br/
<hw>Ros"en</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Consisting of roses;
rosy.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rosenmuller's organ</ent><br/
<ent>Rosenmueller's organ</ent><br/
<hw>Ro"sen*m<uum/l`ler's or"gan</hw> <pr>(?)</pr>. <ety>[So named from
its first describer, J. C. <etsep>Rosenm<uum/ller</etsep>, a German
anatomist.]</ety> <fld>(Anat.)</fld> <def>The parovarium.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roseo-</ent><br/
<hw>Ro"se*o-</hw> <pr>(?)</pr>. <fld>(Chem.)</fld> <def>A prefix (also
used adjectively) signifying <xex>rose-red</xex>; specifically used to
designate certain rose-red compounds (called <xex>roseo-cobaltic
compounds</xex>) of cobalt with ammonia. Cf. <er>Luteo</er>-.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roseola</ent><br/
\'d8<hw>Ro*se"o*la</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., dim. of
L. <ets>rosa</ets> a rose.]</ety> <fld>(med.)</fld> <def>A rose-colored
efflorescence upon the skin, occurring in circumscribed patches of
little or no elevation and often alternately fading and reviving; also,
an acute specific disease which is characterized by an eruption of this
character; -- called also <altname>rose rash</altname>.</def> --
<wordforms><wf>Ro*se"o*lous</wf> <pr>(#)</pr>,
<pos>a.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rose-pink</ent><br/
<hw>Rose"-pink`</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Having
a pink color like that of the rose, or like the pigment called <xex>rose
pink</xex>. See <cref>Rose pink</cref>, under <er>Rose</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Disposed to clothe everything with roseate hues;
hence, sentimental.</def> <ldquo/<xex>Rose-pink</xex> piety.<rdquo/
<rj><au>C. Kingsley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roser</ent><br/
<hw>Ros"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A rosier; a
rosebush.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rose-red</ent><br/
<hw>Rose"-red`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Red as a rose;
specifically <fld>(Zool.)</fld>, of a pure purplish red color.</def>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rose-rial</ent><br/
<hw>Rose"-ri`al</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Rose</er>, and <er>Royal</er>.]</ety> <def>A name of several English
gold coins struck in different reigns and having having different
values; a rose noble.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roseroot</ent><br/
<hw>Rose"root`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>A
fleshy-leaved herb (<spn>Rhodiola rosea</spn>); rosewort; -- so called
because the roots have the odor of roses.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rosery</ent><br/
<hw>Ros"er*y</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A place where roses
are cultivated; a nursery of roses. See <er>Rosary</er>, 1.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roset</ent><br/
<hw>Ro"set</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>rosette</ets>.
See <er>Rosette</er>.]</ety> <def>A red color used by painters.</def>
<rj><au>Peacham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ro-setta stone</ent><br/
<hw>Ro-set"ta stone`</hw> <pr>(?)</pr>. <def>A stone found at
<xex>Rosetta</xex>, in Egypt, bearing a trilingual inscription, by aid
of which, with other inscriptions, a key was obtained to the
hieroglyphics of ancient Egypt.</def> <rj><au>Brande & C.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rosetta wood</ent><br/
<hw>Ro*set"ta wood`</hw> <pr>(?)</pr>. <def>An east Indian wood of a
reddish orange color, handsomely veined with darker marks. It is
occasionally used for cabinetwork.</def> <rj><au>Ure.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rosette</ent><br/
<hw>Ro*sette</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., dim. of
<ets>rose</ets> a rose. Cf. <er>Roset</er>.]</ety> <sn>1.</sn> <def>An
imitation of a rose by means of ribbon or other material, -- used as an
ornament or a badge.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Arch.)</fld> <def>An ornament in the form of a rose
or roundel, -much used in decoration.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A red color. See <er>Roset</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A rose burner. See under <er>Rose</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Zool.)</fld> <sd>(a)</sd> <def>Any structure having
a flowerlike form; especially, the group of five broad ambulacra on the
upper side of the spatangoid and clypeastroid sea urchins. See
<xex>Illust.</xex> of <er>Spicule</er>, and <cref>Sand dollar</cref>,
under <er>Sand</er>.</def> <sd>(b)</sd> <def>A flowerlike color marking;
<as>as, the <ex>rosettes</ex> on the leopard</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rose water</ent><br/
<hw>Rose" wa`ter</hw> <pr>(?)</pr>. <def>Water tinctured with roses by
distillation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rose-water</ent><br/
<hw>Rose"-wa`ter</hw>, <pos>a.</pos> <def>Having the odor of rose water;
hence, affectedly nice or delicate; sentimental.</def>
<ldquo/<xex>Rose-water</xex> philanthropy.<rdquo/
<rj><au>Carlyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rosewood</ent><br/
<hw>Rose"wood</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A valuable cabinet
wood of a dark red color, streaked and variegated with black, obtained
from several tropical leguminous trees of the genera
<gen>Dalbergia</gen> and <gen>Machaerium</gen>. The finest kind is from
Brazil, and is said to be from the <spn>Dalbergia nigra</spn>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>African rosewood</b></col>, <cd>the wood of the
leguminous tree <spn>Pterocarpus erinaceus</spn>.</cd> --
<col><b>Jamaica rosewood</b></col>, <cd>the wood of two West Indian
trees (<spn>Amyris balsamifera</spn>, and <spn>Linocieria
ligustrina</spn>).</cd> -- <col><b>New South Wales rosewood</b></col>,
<cd>the wood of <spn>Trichilia glandulosa</spn>, a tree related to the
margosa.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roseworm</ent><br/
<hw>Rose"worm`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>The larva of any one of several species of lepidopterous insects
which feed upon the leaves, buds, or blossoms of the rose, especially
<spn>Cacaecia rosaceana</spn>, which rolls up the leaves for a nest, and
devours both the leaves and buds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rosewort</ent><br/
<hw>Rose"wort`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<sd>(a)</sd> <def>Roseroot.</def> <sd>(b)</sd> <def>Any plant nearly
related to the rose.</def> <rj><au>Lindley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rosicrucian</ent><br/
<hw>Ros`i*cru"cian</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[The name is
probably due to a German theologian, <person>Johann Valentin
Andre<aum/</person>, who in anonymous pamphlets called himself a knight
of the <ets>Rose Cross</ets> (G. <ets>Rosenkreuz</ets>), using a seal
with a St. Andrew's cross and four roses.)]</ety> <def>One who, in the
17th century and the early part of the 18th, claimed to belong to a
secret society of philosophers deeply versed in the secrets of nature,
-- the alleged society having existed, it was stated, several hundred
years.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The Rosicrucians also called <xex>brothers of the Rosy
Cross</xex>, <xex>Rosy-cross Knights</xex>, <xex>Rosy-cross
philosophers</xex>, etc. Among other pretensions, they claimed to be
able to transmute metals, to prolong life, to know what is passing in
distant places, and to discover the most hidden things by the
application of the Cabala and science of numbers.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rosicrucian</ent><br/
<hw>Ros`i*cru"cian</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or
pertaining to the Rosicrucians, or their arts.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rosied</ent><br/
<hw>Ros"ied</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Decorated with roses,
or with the color of roses.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rosier</ent><br/
<hw>Ro"sier</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr. L.
<ets>rosarius</ets> of roses. Cf. <er>Rosary</er>.]</ety> <def>A
rosebush; roses, collectively.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Crowned with a garland of sweet <qex>rosier</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rosily</ent><br/
<hw>Ros"i*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a rosy
manner.</def> <rj><au>M. Arnold.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rosin</ent><br/
<hw>Ros"in</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[A variant of
<ets>resin</ets>.]</ety> <def>The hard, amber-colored resin left after
distilling off the volatile oil of turpentine; colophony.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Rosin oil</b></col>, <cd>an oil obtained from the resin
of the pine tree, -- used by painters and for lubricating machinery,
etc.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rosin</ent><br/
<hw>Ros"in</hw>, <pos>v. t.</pos> <def>To rub with rosin, as musicians
rub the bow of a violin.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Or with the <qex>rosined</qex> bow torment the string.</q>
<rj><qau>Gay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rosiness</ent><br/
<hw>Ros"i*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The quality of
being rosy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rosinweed</ent><br/
<hw>Ros"in*weed`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<sd>(a)</sd> <def>The compass plant. See under <er>Compass</er>.</def>
<sd>(b)</sd> <def>A name given in California to various composite plants
which secrete resins or have a resinous smell.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rosiny</ent><br/
<hw>Ros"in*y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>like rosin, or having
its qualities.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rosland</ent><br/
<hw>Ros"land</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[W. <ets>rhos</ets> a
meadow, a moor + E. <ets>land</ets>.]</ety> <def>heathy land; land full
of heather; moorish or watery land.</def> <mark>[prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rosmarine</ent><br/
<hw>Ros"ma*rine`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. See
<er>Rosemary</er>.]</ety> <sn>1.</sn> <def>Dew from the sea; sea
dew.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>That purer brine<br/
And wholesome dew called <qex>rosmarine</qex>.</q> <rj><qau>B.
Jonson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Rosemary.</def> <mark>[Obs.]</mark>
<au>Spenser.</au> <ldquo/Biting on anise seed and
<xex>rosmarine</xex>.<rdquo/ <au>Bp. Hall.</au><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rosmarine</ent><br/
<hw>Ros"ma*rine</hw>, <pos>n.</pos> <ety>[Norw. <ets>rosmar</ets> a
walrus; <ets>ros</ets> a horse (akin to E. <ets>horse</ets>) +
(probably) <ets>mar</ets> the sea.]</ety> <def>A fabulous sea animal
which was reported to climb by means of its teeth to the tops of rocks
to feed upon the dew.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And greedly <qex>rosmarines</qex> with visages deforme.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rosolic</ent><br/
<hw>Ro*sol"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Rose</ets> +
carbo<ets>lic</ets>.]</ety> <fld>(Chem.)</fld> <def>Pertaining to, or
designating, a complex red dyestuff (called <xex>rosolic acid</xex>)
which is analogous to rosaniline and aurin. It is produced by oxidizing
a mixture of phenol and cresol, as a dark red amorphous mass,
<chform>C20H16O3</chform>, which forms weak salts with bases, and stable
ones with acids. Called also <altname>methyl aurin</altname>, and,
formerly, <altname>corallin</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ross</ent><br/
<hw>Ross</hw> <pr>(?)</pr>; 115), <pos>n.</pos> <ety>[Etymol.
uncertain.]</ety> <def>The rough, scaly matter on the surface of the
bark of trees.</def> <mark>[Prov. Eng. & Local, U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ross</ent><br/
<hw>Ross</hw>, <pos>v. t.</pos> <def>To divest of the ross, or rough,
scaly surface; <as>as, to <ex>ross</ex> bark</as>.</def> <mark>[Local,
U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rossel</ent><br/
<hw>Ros"sel</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Light land;
rosland.</def> <mark>[Obs. or Prov. Eng.]</mark>
<rj><au>Mortimer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rosselly</ent><br/
<hw>Ros"sel*ly</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Loose; light.</def>
<mark>[Obs.]</mark> <rj><au>Mortimer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rost</ent><br/
<hw>Rost</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See <er>Roust</er>.</def>
<mark>[Scot.]</mark> <rj><au>Jamieson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rostel</ent><br/
<hw>Ros"tel</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>rostellum</ets>, dim. of <ets>rostrum</ets> a beak: cf. F.
<ets>rostelle</ets>.]</ety> <def>same as <er>Rostellum</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rostellar</ent><br/
<hw>Ros*tel"lar</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to a
rostellum.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rostellate</ent><br/
<hw>Ros"tel*late</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[NL.
<ets>rostellatus</ets>.]</ety> <def>Having a rostellum, or small beak;
terminating in a beak.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rostelliform</ent><br/
<hw>Ros*tel"li*form</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having the
form of a rostellum, or small beak.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rostellum</ent><br/
\'d8<hw>Ros*tel"lum</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Rostella</plw> <pr>(#)</pr>.</plu> <ety>[L. See
<er>Rostel</er>.]</ety> <def>A small beaklike process or extension of
some part; a small rostrum; <as>as, the <ex>rostellum</ex> of the stigma
of violets, or of the operculum of many mosses; the <ex>rostellum</ex>
on the head of a tapeworm.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roster</ent><br/
<hw>Ros"ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Perhaps a corruption
of <ets>register</ets>; or cf. <ets>roll</ets>.]</ety> <fld>(Mil.)</fld>
<def>A register or roll showing the order in which officers, enlisted
men, companies, or regiments are called on to serve.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rostra</ent><br/
<hw>Ros"tra</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <def>See
<er>Rostrum</er>, 2.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rostral</ent><br/
<hw>Ros"tral</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>rostralis</ets>, fr. <ets>rostrum</ets> a beak; cf. F.
<ets>rostral</ets>.]</ety> <def>Of or pertaining to the beak or snout of
an animal, or the beak of a ship; resembling a rostrum, esp., the rostra
at Rome, or their decorations.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>[Monuments] adorned with <qex>rostral</qex> crowns and naval
ornaments.</q> <rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rostrated</ent><br/
<ent>Rostrate</ent><br/
<mhw>{ <hw>Ros"trate</hw> <pr>(?)</pr>, <hw>Ros"tra*ted</hw>
<pr>(?)</pr> }</mhw>, <pos>a.</pos> <ety>[L. <ets>rostratus</ets>, fr.
<ets>rostrum</ets> a beak. See <er>Rostrum</er>.]</ety> <sn>1.</sn>
<def>Having a process resembling the beak of a bird; beaked;
rostellate.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Furnished or adorned with beaks; <as>as,
<ex>rostrated</ex> galleys</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rostrifera</ent><br/
\'d8<hw>Ros*trif"e*ra</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
fr. L. <ets>rostrum</ets> beak + <ets>ferre</ets> to bear.]</ety>
<fld>(Zool.)</fld> <def>A division of pectinibranchiate gastropods,
having the head prolonged into a snout which is not
retractile.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rostriform</ent><br/
<hw>Ros"tri*form</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>rostrum</ets> a beak + <ets>-form</ets>: cf. F.
<ets>rostrifarme</ets>.]</ety> <def>Having the form of a beak.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rostrulum</ent><br/
\'d8<hw>Ros"tru*lum</hw> <pr>(-tr<usdot/*l<ucr/m)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Rostrula</plw> <pr>(#)</pr>.</plu> <ety>[NL.,
dim. of L. <ets>rostrum</ets> a beak.]</ety> <def>A little rostrum, or
beak, as of an insect.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rostrum</ent><br/
<hw>Ros"trum</hw> <pr>(-tr<ucr/m)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
L. <plw>Rostra</plw> <pr>(#)</pr>, E. <plw>Rostrums</plw>
<pr>(#)</pr>.</plu> <ety>[L., beak, ship's beak, fr. <ets>rodere</ets>,
<ets>rosum</ets>, to gnaw. See <er>Rodent</er>.]</ety> <sn>1.</sn>
<def>The beak or head of a ship.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1253 --></p>

<p><sn>2.</sn> <pluf>pl.</pluf> (<er>Rostra</er>) <fld>(Rom.
Antiq.)</fld> <def>The Beaks; the stage or platform in the forum where
orations, pleadings, funeral harangues, etc., were delivered; -- so
called because after the Latin war, it was adorned with the beaks of
captured vessels; later, applied also to other platforms erected in Rome
for the use of public orators.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Hence, a stage for public speaking; the pulpit or
platform occupied by an orator or public speaker.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Myself will mount the <qex>rostrum</qex> in his favor.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Zool.)</fld> <sd>(a)</sd> <def>Any beaklike
prolongation, esp. of the head of an animal, as the beak of birds.</def>
<sd>(b)</sd> <def>The beak, or sucking mouth parts, of Hemiptera.</def>
<sd>(c)</sd> <def>The snout of a gastropod mollusk. See
<xex>Illust.</xex> of <er>Littorina</er>.</def> <sd>(d)</sd> <def>The
anterior, often spinelike, prolongation of the carapace of a crustacean,
as in the lobster and the prawn.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Bot.)</fld> <def>Same as
<er>Rostellum</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Old Chem.)</fld> <def>The pipe to convey the
distilling liquor into its receiver in the common alembic.</def>
<rj><au>Quincy.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Surg.)</fld> <def>A pair of forceps of various
kinds, having a beaklike form.</def> <mark>[Obs.]</mark>
<rj><au>Coxe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rosulate</ent><br/
<hw>Ro"su*late</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[NL.
<ets>rosulatus</ets>, fr. L. <ets>rosa</ets> a rose.]</ety>
<fld>(Bot.)</fld> <def>Arranged in little roselike clusters; -- said of
leaves and bracts.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rosy</ent><br/
<hw>Ros"y</hw> <pr>(?)</pr>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Rosier</adjf> <pr>(?)</pr>; <pos>superl.</pos>
<adjf>Rosiest</adjf>.]</amorph> <def>Resembling a rose in color, form,
or qualities; blooming; red; blushing; also, adorned with
roses.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A smile that glowed<br/
Celestial <qex>rosy</qex>-red, love's proper hue.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>While blooming youth and gay delight<br/
Sit thy <qex>rosy</qex> cheeks confessed.</q>
<rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Rosy</xex> is sometimes used in the formation of
self-explaining compounde; as, <xex>rosy</xex>-bosomed,
<xex>rosy</xex>-colored, <xex>rosy</xex>-crowned,
<xex>rosy</xex>-fingered, <xex>rosy</xex>-tinted.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Rosy cross</b></col>. <cd>See the Note under
<er>Rosicrucian</er>, <pos>n.</pos></cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rot</ent><br/
<hw>Rot</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Rotted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Rotting</conjf>.]</vmorph> <ety>[OE. <ets>rotien</ets>, AS.
<ets>rotian</ets>; akin to D. <ets>rotten</ets>, Prov. G.
<ets>rotten</ets>, OHG. <ets>rozz<?/n</ets>, G. <ets>r<oum/sten</ets> to
steep flax, Icel. <ets>rotna</ets> to rot, Sw. <ets>ruttna</ets>, Dan.
<ets>raadne</ets>, Icel. <ets>rottin</ets> rotten. <root/117. Cf.
<er>Ret</er>, <er>Rotten</er>.]</ety> <sn>1.</sn> <def>To undergo a
process common to organic substances by which they lose the cohesion of
their parts and pass through certain chemical changes, giving off
usually in some stages of the process more or less offensive odors; to
become decomposed by a natural process; to putrefy; to decay.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Fixed like a plant on his peculiar spot,<br/
To draw nutrition, propagate, and <qex>rot</qex>.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Figuratively: To perish slowly; to decay; to die; to
become corrupt.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Four of the sufferers were left to <qex>rot</qex> in irons.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Rot</qex>, poor bachelor, in your club.</q>
<rj><qau>Thackeray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To putrefy; corrupt; decay; spoil.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rot</ent><br/
<hw>Rot</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To make putrid; to cause
to be wholly or partially decomposed by natural processes; <as>as, to
<ex>rot</ex> vegetable fiber</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To expose, as flax, to a process of maceration,
etc., for the purpose of separating the fiber; to ret.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rot</ent><br/
<hw>Rot</hw>, <pos>n.</pos> <sn>1.</sn> <def>Process of rotting; decay;
putrefaction.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>A disease or decay in fruits,
leaves, or wood, supposed to be caused by minute fungi. See <cref>Bitter
rot</cref>, <cref>Black rot</cref>, etc., below.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <ety>[Cf. G. <ets>rotz</ets> glanders.]</ety> <def>A
fatal distemper which attacks sheep and sometimes other animals. It is
due to the presence of a parasitic worm in the liver or gall bladder.
See 1st <er>Fluke</er>, 2.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His cattle must of <qex>rot</qex> and murrain die.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Bitter rot</b></col> <fld>(Bot.)</fld>, <cd>a disease of
apples, caused by the fungus <spn>Glaeosporium fructigenum</spn>.</cd>
<au>F. L. Scribner.</au> -- <col><b>Black rot</b></col>
<fld>(Bot.)</fld>, <cd>a disease of grapevines, attacking the leaves and
fruit, caused by the fungus <spn>Laestadia Bidwellii</spn>.</cd> <au>F.
L. Scribner.</au> -- <col><b>Dry rot</b></col> <fld>(Bot.)</fld> <cd>See
under <er>Dry</er>.</cd> -- <col><b>Grinder's rot</b></col>
<fld>(Med.)</fld> <cd>See under <er>Grinder</er>.</cd> -- <col><b>Potato
rot</b></col>. <fld>(Bot.)</fld> <cd>See under <er>Potato</er>.</cd> --
<col><b>White rot</b></col> <fld>(Bot.)</fld>, <cd>a disease of grapes,
first appearing in whitish pustules on the fruit, caused by the fungus
<spn>Coniothyrium diplodiella</spn>.</cd> <au>F. L.
Scribner.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rota</ent><br/
\'d8<hw>Ro"ta</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>rota</ets>
wheel. The name is said to allude to the design of the floor of the room
in which the court used to sit, which was that of a wheel. See
<er>Rotary</er>.]</ety> <sn>1.</sn> <def>An ecclesiastical court of
Rome, called also <altname>Rota Romana</altname>, that takes cognizance
of suits by appeal. It consists of twelve members.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Eng. Hist.)</fld> <def>A short-lived political club
established in 1659 by J.Harrington to inculcate the democratic doctrine
of election of the principal officers of the state by ballot, and the
annual retirement of a portion of Parliament.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rota</ent><br/
<hw>Ro"ta</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Mus.)</fld> <def>A
species of zither, played like a guitar, used in the Middle Ages in
church music; -- written also <asp>rotta</asp>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rotacism</ent><br/
<hw>Ro"ta*cism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Rhotacism</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rotal</ent><br/
<hw>Ro"tal</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Relating to wheels or
to rotary motion; rotary.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rotalite</ent><br/
<hw>Ro"ta*lite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>rota</ets>
wheel + <ets>-lite</ets>.]</ety> <fld>(Paleon.)</fld> <def>Any fossil
foraminifer of the genus <gen>Rotalia</gen>, abundant in the chalk
formation. See <xex>Illust.</xex> under <er>Rhizopod</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rotary</ent><br/
<hw>Ro"ta*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>rota</ets> a
wheel. See <er>Roll</er>, <pos>v.</pos>, and cf. <er>barouche</er>,
<er>Rodomontade</er>, <er>Rou<eacute/</er>, <er>Round</er>,
<pos>a.</pos>, <er>Rowel</er>.]</ety> <def>Turning, as a wheel on its
axis; pertaining to, or resembling, the motion of a wheel on its axis;
rotatory; <as>as, <ex>rotary</ex> motion</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Rotary engine</b></col>, <cd>steam engine in which the
continuous rotation of the shaft is produced by the direct action of the
steam upon rotating devices which serve as pistons, instead of being
derived from a reciprocating motion, as in the ordinary engine; a steam
turbine; -- called also <altname>rotatory engine</altname>.</cd> --
<col><b>Rotary pump</b></col>, <cd>a pump in which the fluid is impelled
by rotating devices which take the place of reciprocating buckets or
pistons.</cd> -- <col><b>Rotary shears</b></col>, <cd>shears, as for
cloth, metal, etc., in which revolving sharp-edged or sharp-cornered
wheels do the cutting.</cd> -- <col><b>Rotary valve</b></col>, <cd>a
valve acting by continuous or partial rotation, as in the four-way
cock.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rotascope</ent><br/
<hw>Ro"ta*scope</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>rota</ets> a wheel + <ets>-scope</ets>.]</ety> <def>Same as
<er>Gyroscope</er>, 1.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rotate</ent><br/
<hw>Ro"tate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>rotatus</ets>, p. p. of <ets>rotare</ets> to turn round like a
wheel, fr. <ets>rota</ets> wheel. See <er>Rotary</er>, and cf.
<er>Roue</er>.]</ety> <def>Having the parts spreading out like a wheel;
wheel-shaped; <as>as, a <ex>rotate</ex> spicule or scale; a
<ex>rotate</ex> corolla, <it>i.e.</it>, a monopetalous corolla with a
flattish border, and no tube or a very short one.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rotate</ent><br/
<hw>Ro"tate</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Rotated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Rotating</conjf>.]</vmorph> <sn>1.</sn> <def>To turn, as a wheel,
round an axis; to revolve.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To perform any act, function, or operation in turn,
to hold office in turn; <as>as, to <ex>rotate</ex> in
office</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rotate</ent><br/
<hw>Ro"tate</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To cause to turn
round or revolve, as a wheel around an axle.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To cause to succeed in turn; esp., to cause to
succeed some one, or to be succeeded by some one, in office.</def>
<mark>[Colloq.]</mark> <ldquo/Both, after a brief service, were
<xex>rotated</xex> out of office.<rdquo/ <rj><au>Harper's
Mag.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rotated</ent><br/
<hw>Ro"ta*ted</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Turned round, as a
wheel; also, wheel-shaped; rotate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rotation</ent><br/
<hw>Ro*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>rotatio</ets>: cf. F. <ets>rotation</ets>.]</ety> <sn>1.</sn>
<def>The act of turning, as a wheel or a solid body on its axis, as
distinguished from the progressive motion of a revolving round another
body or a distant point; thus, the daily turning of the earth on its
axis is a <xex>rotation</xex>; its annual motion round the sun is a
<xex>revolution</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Any return or succesion in a series.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Moment of rotation</b></col>. <cd>See <cref>Moment of
inertia</cref>, under <er>Moment</er>.</cd> -- <col><b>Rotation in
office</b></col>, <cd>the practice of changing public officers at
frequent intervals by discharges and substitutions.</cd> --
<col><b>Rotation of crops</b></col>, <cd>the practices of cultivating an
orderly succession of different crops on the same land.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rotation</ent><br/
<hw>Ro*ta"tion</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to, or
resulting from, rotation; of the nature of, or characterized by,
rotation; <as>as, <ex>rotational</ex> velocity</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rotative</ent><br/
<hw>Ro"ta*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>rotatif</ets>.]</ety> <def>turning, as a wheel; rotary;
rotational.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This high <qex>rotative</qex> velocity of the sun must cause an
equatorial rise of the solar atmosphere.</q>
<rj><qau>Siemens.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Rotative engine</b></col>, <cd>a steam engine in which
the reciprocating motion of the piston is transformed into a continuous
rotary motion, as by means of a connecting rod, a working beam and
crank, or an oscillating cylinder.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rotator</ent><br/
<hw>Ro*ta"tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.]</ety>
<sn>1.</sn> <fld>(Anat.)</fld> <def>that which gives a rotary or rolling
motion, as a muscle which partially rotates or turns some part on its
axis.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Metal.)</fld> <def>A revolving reverberatory
furnace.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rotatoria</ent><br/
\'d8<hw>Ro`ta*to"ri*a</hw> <pr>(?)</pr>, <pos>n. pl.</pos>
<ety>[NL.]</ety> <fld>(Zool.)</fld> <def>Same as
<er>Rotifera</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rotatory</ent><br/
<hw>Ro"ta*to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>rotatoire</ets>. See <er>Rotate</er>, <er>Rotary</er>.]</ety>
<sn>1.</sn> <def>Turning as on an axis; rotary.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Going in a circle; following in rotation or
succession; <as>as, <ex>rotatory</ex> assembles</as>.</def>
<rj><au>Burke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Opt.)</fld> <def>Producing rotation of the plane of
polarization; <as>as, the <ex>rotatory</ex> power of bodies on
light</as>. See the Note under <er>polarization</er>.</def>
<rj><au>Nichol.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rotatory</ent><br/
<hw>Ro"ta*to*ry</hw>, <pos>n.</pos> <fld>(Zool.)</fld> <def>A
rotifer.</def> <mark>[R.]</mark> <rj><au>Kirby.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rotche</ent><br/
<hw>Rotche</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>A
very small arctic sea bird (<spn>Mergulus alle</spn>, or <spn>Alle
alle</spn>) common on both coasts of the Atlantic in winter; -- called
also <altname>little auk</altname>, <altname>dovekie</altname>,
<altname>rotch</altname>, <altname>rotchie</altname>, and <altname>sea
dove</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rotchet</ent><br/
<hw>Rotch"et</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>The European red gurnard (<spn>Trigla pini</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rote</ent><br/
<hw>Rote</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A root.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rote</ent><br/
<hw>Rote</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>rote</ets>,
probably of German origin; cf. MHG. <ets>rotte</ets>, OHG.
<ets>rota</ets>, <ets>hrota</ets>, LL. <ets>chrotta</ets>. Cf.
<er>Crowd</er> a kind of violin.]</ety> <fld>(Mus.)</fld> <def>A kind of
guitar, the notes of which were produced by a small wheel or wheel-like
arrangement; an instrument similar to the hurdy-gurdy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Well could he sing and play on a <qex>rote</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>extracting mistuned dirges from their harps, crowds, and
<qex>rotes</qex>.</q> <rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rote</ent><br/
<hw>Rote</hw>, <pos>n.</pos> <ety>[Cf. <er>Rut</er> roaring.]</ety>
<def>The noise produced by the surf of the sea dashing upon the shore.
See <er>Rut</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rote</ent><br/
<hw>Rote</hw>, <pos>n.</pos> <ety>[OF. <ets>rote</ets>, F.
<ets>route</ets>, road, path. See <er>Route</er>, and cf. <er>Rut</er> a
furrow, <er>Routine</er>.]</ety> <def>A frequent repetition of forms of
speech without attention to the meaning; mere repetition; <as>as, to
learn rules by <ex>rote</ex></as>.</def> <rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>till he the first verse could [<it>i. e.</it>, knew] all by
<qex>rote</qex>.</q> <rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Thy love did read by <qex>rote</qex>, and could not spell.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rote</ent><br/
<hw>Rote</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Roted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Roting</conjf>.]</vmorph> <def>To learn or repeat by rote.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rote</ent><br/
<hw>Rote</hw>, <pos>v. i.</pos> <def>To go out by rotation or
succession; to rotate.</def> <mark>[Obs.]</mark> <-- = rotate out? -->
<rj><au>Z. Grey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rotella</ent><br/
<hw>Ro*tel"la</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., dim. of
<ets>rota</ets> wheel; cf. LL. <ets>rotella</ets> a little whell.]</ety>
<fld>(Zool.)</fld> <def>Any one of numerous species of small, polished,
brightcolored gastropods of the genus <gen>Rotella</gen>, native of
tropical seas.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>rotenone</ent><br/
<hw>ro"te*none</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A chemical
substance (<chform>C23H22O6</chform>) extracted from the root of the
<prodby>derris</prodby> (<spn>Derris elliptica</spn>, <spn>Derris
malaccensis</spn>, and other species), used in treatment of scabies and
as an insecticide for external infestation by chiggers in human
medicine, and in veterinary medicine for the treatment of infestations
with fleas, ticks, and lice.</def><br/
[<source>PJC</source>]</p>

<p><ent>rotgut</ent><br/
<hw>rot"gut</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>Bad small
beer.</def> <mark>[Slang]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Any bad spirituous liquor, especially when
adulterated so as to be very deleterious.</def> <mark>[Slang]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rother</ent><br/
<hw>Roth"er</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[AS.
<ets>hry<edh/er</ets>; cf. D. <ets>rund</ets>.]</ety> <fld>(Zool.)</fld>
<def>Bovine.</def> -- <def2><pos>n.</pos> <def>A bovine
beast.</def></def2> <mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Rother beasts</b></col>, <cd>cattle of the bovine genus;
black cattle.</cd> <mark>[Obs.]</mark> <au>Golding.</au> --
<col><b>Rother soil</b></col>, <cd>the dung of rother
beasts.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rother</ent><br/
<hw>Roth"er</hw>, <pos>n.</pos> <ety>[OE. See <er>Rudder</er>.]</ety>
<def>A rudder.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Rother nail</b></col>, <cd>a nail with a very full head,
used for fastening the rudder irons of ships; -- so called by
shipwrights.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rotifer</ent><br/
<hw>Ro"ti*fer</hw> <pr>(?; 277)</pr>, <pos>n.</pos> <ety>[NL. see
<er>Rotifera</er>.]</ety> <fld>(Zool.)</fld> <def>One of the Rotifera.
See <xex>Illust.</xex> in Appendix.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rotifera</ent><br/
\'d8<hw>Ro*tif"e*ra</hw> <pr>(?)</pr>, <pos>n.</pos>;
<plu><it>pl.</it></plu> <ety>[NL., from L. <ets>rota</ets> <?/ wheel +
<ets>ferre</ets> to bear.]</ety> <fld>(Zool.)</fld> <def>An order of
minute worms which usually have one or two groups of vibrating cilia on
the head, which, when in motion, often give an appearance of rapidly
revolving wheels. The species are very numerous in fresh waters, and are
very diversified in form and habits.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rotiform</ent><br/
<hw>Ro"ti*form</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>rota</ets>
wheel + <ets>-form</ets>.]</ety> <sn>1.</sn> <def>Wheel-shaped; <as>as,
<ex>rotiform</ex> appendages</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>Same as <er>Rotate</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rotograph</ent><br/
<hw>Ro"to*graph</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Photography)</fld> <def>A photograph printed by a process in which
a strip or roll of sensitized paper is automatically fed over the
negative so that a series of prints are made, and are then developed,
fixed, cut apart, and washed at a very rapid rate.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Rotor</ent><br/
<hw>Ro"tor</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Elec.)</fld> <def>The
rotating part of a generator or motor. Contrasted with
<contr>stator</contr>, the stationary part.</def><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><ent>Rotta</ent><br/
<hw>Rot"ta</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Mus.)</fld> <def>See
<er>Rota</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rotten</ent><br/
<hw>Rot"ten</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Icel.
<ets>rotinn</ets>; akin to Sw. <ets>rutten</ets>, Dan.
<ets>radden</ets>. See <er>Rot</er>.]</ety> <def>Having rotted; putrid;
decayed; <as>as, a <ex>rotten</ex> apple; <ex>rotten</ex>
meat</as>.</def> Hence: <sd>(a)</sd> <def>Offensive to the smell; fetid;
disgusting.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>You common cry of curs! whose breath I hate<br/
As reek of the <qex>rotten</qex> fens.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(b)</sd> <def>Not firm or trusty; unsound; defective;
treacherous; unsafe; <as>as, a <ex>rotten</ex> plank, bone,
stone</as>.</def> <ldquo/The deepness of the <xex>rotten</xex>
way.<rdquo/ <rj><au>Knolles.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Rotten borough</b></col>. <cd>See under
<er>Borough</er>.</cd> -- <col><b>Rotten stone</b></col>
<fld>(Min.)</fld>, <cd>a soft stone, called also Tripoli (from the
country from which it was formerly brought), used in all sorts of finer
grinding and polishing in the arts, and for cleaning metallic
substances. The name is also given to other friable siliceous stones
applied to like uses.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Putrefied; decayed; carious; defective; unsound;
corrupt; deceitful; treacherous.</syn><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Rot"ten*ly</wf>, <pos>adv.</pos> --
<wf>Rot"ten*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rotula</ent><br/
\'d8<hw>Rot"u*la</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., a little
wheel; cf. It. <ets>rotula</ets>.]</ety> <fld>(Anat.)</fld> <def>The
patella, or kneepan.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rotular</ent><br/
<hw>Rot"u*lar</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>rotula</ets>, dim. of <ets>rota</ets> wheel.]</ety>
<fld>(Anat.)</fld> <def>Of or pertaining to the rotula, or
kneepan.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rotund</ent><br/
<hw>Ro*tund"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>rotundus</ets>. See <er>Round</er>, and cf.
<er>Rotunda</er>.]</ety> <sn>1.</sn> <def>Round; circular;
spherical.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence, complete; entire.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Bot.)</fld> <def>orbicular, or nearly so.</def>
<rj><au>Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rotund</ent><br/
<hw>Ro*tund"</hw>, <pos>n.</pos> <def>A rotunda.</def>
<mark>[Obs.]</mark> <rj><au>Burke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rotunda</ent><br/
<hw>Ro*tun"da</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. It.
<ets>rotonda</ets>, F. <ets>rotonde</ets>; both fr. L.
<ets>rotundus</ets> round. See <er>Rotund</er>, <pos>a.</pos>]</ety>
<fld>(Arch.)</fld> <def>A round building; especially, one that is round
both on the outside and inside, like the Pantheon at Rome. Less
properly, but very commonly, used for a large round room; <as>as, the
<ex>rotunda</ex> of the Capitol at Washington</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rotundate</ent><br/
<hw>Ro*tund"ate</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Rounded;
especially, rounded at the end or ends, or at the corners.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rotundifolious</ent><br/
<hw>Ro*tund`i*fo"li*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>rotundus</ets> round + <ets>folium</ets> a leaf.]</ety>
<fld>(Bot.)</fld> <def>Having round leaves.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rotundity</ent><br/
<hw>Ro*tund"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>rotunditas</ets>: cf. F. <ets>rotondit<eacute/</ets>.]</ety>
<sn>1.</sn> <def>The state or quality of being rotu<?/; roundness;
sphericity; circularity.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Smite flat the thick <qex>rotundity</qex> o'the world!</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence, completeness; entirety; roundness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>For the more <qex>rotundity</qex> of the number and grace of the
matter, it passeth for a full thousand.</q>
<rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A boldness and <qex>rotundity</qex> of speech.</q>
<rj><qau>Hawthorne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rotundness</ent><br/
<hw>Ro*tund"ness</hw>, <pos>n.</pos> <def>Roundness;
rotundity.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rotundo</ent><br/
<hw>Ro*tun"do</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Rotunda</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roture</ent><br/
\'d8<hw>Ro`ture</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<sn>1.</sn> <def>The condition of being a roturier.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <fld>(Fr. & Canadian Law)</fld> <def>A feudal tenure of
lands by one who has no privileges of nobility, but is permitted to
discharge all his obligations to his feudal lord or superior by a
payment of rent in money or kind and without rendering any personal
services.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Roturer</ent><br/
<hw>Ro*tur"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A roturier.</def>
<mark>[Obs.]</mark> <rj><au>Howell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roturier</ent><br/
\'d8<hw>Ro`tu`rier"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<def>A person who is not of noble birth; specif., a freeman who during
the prevalence of feudalism held allodial land.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roty</ent><br/
<hw>Rot"y</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[See
<er>Rot</er>.]</ety> <def>To make rotten.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Well bet is rotten apple out of hoard,<br/
Than that it <qex>roty</qex> all the remenant.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rouble</ent><br/
\'d8<hw>Rou"ble</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A coin. See
<er>Ruble</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rouche</ent><br/
<hw>Rouche</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Ruche</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roue</ent><br/
\'d8<hw>Rou`<eacute/"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.,
properly p. p. of <ets>rouer</ets> to break upon the wheel, fr.
<ets>roue</ets> a wheel, L. <ets>rota</ets>. See <er>Rotate</er>,
<er>Rotary</er>.]</ety> <def>One devoted to a life of sensual pleasure;
a debauchee; a rake.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rouet</ent><br/
\'d8<hw>Rou`et"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety> <def>A
small wheel formerly fixed to the pan of firelocks for discharging
them.</def> <rj><au>Crabb.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rouge</ent><br/
<hw>Rouge</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F., fr. L.
<ets>rubeus</ets> red, akin to <ets>rubere</ets> to be red,
<ets>ruber</ets> red. See <er>Red</er>.]</ety> <def>red.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><cs>\'d8<col><b>Rouge et noir</b></col> <pr>(<?/)</pr> <ety>[F., red
and black]</ety>, <cd>a game at cards in which persons play against the
owner of the bank; -- so called because the table around which the
players sit has certain compartments colored red and black, upon which
the stakes are deposited.</cd> <rj><au>Hoyle.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rouge</ent><br/
<hw>Rouge</hw>, <pos>n.</pos> <ety>[F.]</ety> <sn>1.</sn>
<fld>(Chem.)</fld> <def>A red amorphous powder consisting of ferric
oxide. It is used in polishing glass, metal, or gems, and as a cosmetic,
etc. Called also <altname>crocus</altname>, <altname>jeweler's
rouge</altname>, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A cosmetic used for giving a red color to the cheeks
or lips. The best is prepared from the dried flowers of the safflower,
but it is often made from carmine.</def> <rj><au>Ure.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rouge</ent><br/
<hw>Rouge</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Rouged</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Rouging</conjf> .]</vmorph> <def>To paint the face or cheeks with
rouge.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rouge</ent><br/
<hw>Rouge</hw>, <pos>v. t.</pos> <def>To tint with rouge; <as>as, to
<ex>rouge</ex> the face or the cheeks</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rougecroix</ent><br/
<hw>Rouge`croix"</hw> <pr>(? <or/ ?)</pr>, <pos>n.</pos> <ety>[F.,
literally, red cross.]</ety> <fld>(Her.)</fld> <def>One of the four
pursuivants of the English college of arms.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rouge dragon</ent><br/
<hw>Rouge" drag`on</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., literally,
red dragon.]</ety> <fld>(Her.)</fld> <def>One of the four pursuivants of
the English college of arms.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1254 --></p>

<p><ent>Rough</ent><br/
<hw>Rough</hw> <pr>(?)</pr>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Rougher</adjf> <pr>(?)</pr>; <pos>superl.</pos>
<adjf>Roughest</adjf>.]</amorph> <ety>[OE. <ets>rou<?/</ets>,
<ets>rou</ets>, <ets>row</ets>, <ets>rugh</ets>, <ets>ruh</ets>, AS.
<ets>r<?/h</ets>; akin to LG. <ets>rug</ets>, D. <ets>rug</ets>, D.
<ets>ruig</ets>, <ets>ruw</ets>, OHG. <ets>r<?/h</ets>, G.
<ets>rauh</ets>, <ets>rauch</ets>; cf. Lith. <ets>raukas</ets> wrinkle,
<ets>rukti</ets> to wrinkle. <root/ 18. Cf. <er>Rug</er>,
<pos>n.</pos>]</ety> <sn>1.</sn> <def>Having inequalities, small ridges,
or points, on the surface; not smooth or plain; <as>as, a <ex>rough</ex>
board; a <ex>rough</ex> stone; <ex>rough</ex> cloth</as>.</def>
Specifically: <sd>(a)</sd> <def>Not level; having a broken surface;
uneven; -- said of a piece of land, or of a road.</def> <ldquo/Rough,
uneven ways.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(b)</sd> <def>Not polished; uncut; -- said of a gem; <as>as, a
<ex>rough</ex> diamond</as>.</def> <sd>(c)</sd> <def>Tossed in waves;
boisterous; high; -- said of a sea or other piece of water.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>More unequal than the <qex>roughest</qex> sea.</q> <rj><qau>T.
Burnet.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(d)</sd> <def>Marked by coarseness; shaggy; ragged; disordered;
-- said of dress, appearance, or the like; <as>as, a <ex>rough</ex>
coat</as>.</def> <ldquo/A visage <xex>rough</xex>.<rdquo/
<au>Dryden.</au> <ldquo/<xex>Rough</xex>satyrs.<rdquo/
<au>Milton.</au><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence, figuratively, lacking refinement, gentleness,
or polish.</def> <specif>Specifically:</specif> <sd>(a)</sd> <def>Not
courteous or kind; harsh; rude; uncivil; <as>as, a <ex>rough</ex>
temper</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A fiend, a fury, pitiless and <qex>rough</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A surly boatman, <qex>rough</qex> as wayes or winds.</q>
<rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(b)</sd> <def>Marked by severity or violence; harsh; hard;
<as>as, <ex>rough</ex> measures or actions</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>On the <qex>rough</qex> edge of battle.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A quicker and <qex>rougher</qex> remedy.</q>
<rj><qau>Clarendon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Kind words prevent a good deal of that perverseness which
<qex>rough</qex> and imperious usage often produces.</q>
<rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(c)</sd> <def>Loud and hoarse; offensive to the ear; harsh;
grating; -- said of sound, voice, and the like; <as>as, a <ex>rough</ex>
tone; <ex>rough</ex> numbers</as>.</def> <rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(d)</sd> <def>Austere; harsh to the taste; <as>as, <ex>rough</ex>
wine</as>.</def> <sd>(e)</sd> <def>Tempestuous; boisterous; stormy;
<as>as, <ex>rough</ex> weather; a <ex>rough</ex> day</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He stayeth his <qex>rough</qex> wind.</q> <rj><qau>Isa. xxvii.
8.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Time and the hour runs through the <qex>roughest</qex> day.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(f)</sd> <def>Hastily or carelessly done; wanting finish;
incomplete; <as>as, a <ex>rough</ex> estimate; a <ex>rough</ex>
draught</as>.</def><br/
[<source>1913 Webster</source>]</p>

<cs><p><col><b>Rough diamond</b></col>, <cd>an uncut diamond; hence,
colloquially, a person of intrinsic worth under a rude exterior.</cd><--
= diamond in the rough --> -- <col><b>Rough and ready</b></col>.
<sd>(a)</sd> <cd>Acting with offhand promptness and efficiency</cd>.
<ldquo/The <xex>rough and ready</xex> understanding.<rdquo/
<rj><au>Lowell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(b)</sd> <def>Produced offhand.</def> <ldquo/Some <xex>rough and
ready</xex> theory.<rdquo/ <rj><au>Tylor.</au></rj><br/
[<source>1913 Webster</source>]</p></cs>

<p><ent>Rough</ent><br/
<hw>Rough</hw>, <pos>n.</pos> <sn>1.</sn> <def>Boisterous weather.</def>
<mark>[Obs.]</mark> <rj><au>Fletcher.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A rude fellow; a coarse bully; a rowdy.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>In the rough</b></col>, <cd>in an unwrought or rude
condition; unpolished; <as>as, a diamond or a sketch <ex>in the
rough</ex></as>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><q>Contemplating the people <qex>in the rough</qex>.</q>
<rj><qau>Mrs. Browning.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rough</ent><br/
<hw>Rough</hw>, <pos>adv.</pos> <def>In a rough manner; rudely;
roughly.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Sleeping <qex>rough</qex> on the trenches, and dying stubbornly in
their boats.</q> <rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rough</ent><br/
<hw>Rough</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To render rough; to
roughen.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To break in, as a horse, especially for military
purposes.</def> <rj><au>Crabb.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To cut or make in a hasty, rough manner; -- with
<xex>out</xex>; <as>as, to <ex>rough</ex> out a carving, a
sketch</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Roughing rolls</b></col>, <cd>rolls for reducing, in a
rough manner, a bloom of iron to bars.</cd> -- <col><b>To rough
it</b></col>, <cd>to endure hard conditions of living; to live without
ordinary comforts.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roughcast</ent><br/
<hw>Rough`cast"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <sn>1.</sn> <def>To
form in its first rudiments, without revision, correction, or
polish.</def> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To mold without nicety or elegance; to form with
asperities and inequalities.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To plaster with a mixture of lime and shells or
pebbles; <as>as, to <ex>roughcast</ex> a building</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roughcast</ent><br/
<hw>Rough"cast`</hw>, <pos>n.</pos> <sn>1.</sn> <def>A rude model; the
rudimentary, unfinished form of a thing.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A kind of plastering made of lime, with a mixture of
shells or pebbles, used for covering buildings.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roughcaster</ent><br/
<hw>Rough"cast`er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
roughcasts.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roughdraw</ent><br/
<hw>Rough"draw`</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To draw or
delineate rapidly and by way of a first sketch.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roughdry</ent><br/
<hw>Rough"dry`</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>in laundry work,
to dry without smoothing or ironing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roughen</ent><br/
<hw>Rough"en</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Roughened</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Roughening</conjf>.]</vmorph> <ety>[From
<er>Rough</er>.]</ety> <def>To make rough.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roughen</ent><br/
<hw>Rough"en</hw>, <pos>v. i.</pos> <def>To grow or become
rough.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rough-footed</ent><br/
<hw>Rough"-foot`ed</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Feather-footed; <as>as, a <ex>rough-footed</ex> dove</as>.</def>
<mark>[R.]</mark> <rj><au>Sherwood.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rough-grained</ent><br/
<hw>Rough"-grained</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having a rough
grain or fiber; hence, figuratively, having coarse traits of character;
not polished; brisque.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roughhead</ent><br/
<hw>Rough"head`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>The redfin.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roughhew</ent><br/
<hw>Rough"hew`</hw> <pr>(?)</pr>, <pos>v. t.</pos> <sn>1.</sn> <def>To
hew coarsely, without smoothing; <as>as, to <ex>roughhew</ex>
timber</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To give the first form or shape to; to form rudely;
to shape approximately and rudely; to roughcast.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There's a divinity that shapes our ends,<br/
<qex>Roughhew</qex> them how we will.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roughhewer</ent><br/
<hw>Rough"hew`er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
roughhews.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roughhewn</ent><br/
<hw>Rough"hewn`</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Hewn
coarsely without smoothing; unfinished; not polished.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of coarse manners; rude; uncultivated;
rough-grained.</def> <ldquo/A <xex>roughhewn</xex> seaman.<rdquo/
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roughing-in</ent><br/
<hw>Rough"ing-in`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The first coat
of plaster laid on brick; also, the process of applying it.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roughings</ent><br/
<hw>Rough"ings</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <def>Rowen.</def>
<mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roughish</ent><br/
<hw>Rough"ish</hw>, <pos>a.</pos> <def>Somewhat rough.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roughleg</ent><br/
<hw>Rough"leg`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>Any one of several species of large hawks of the genus
<gen>Archibuteo</gen>, having the legs feathered to the toes. Called
also <altname>rough-legged hawk</altname>, and <altname>rough-legged
buzzard</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The best known species is <spn>Archibuteo lagopus</spn>
of Northern Europe, with its darker American variety
(<spn>Sancti-johannis</spn>). The latter is often nearly or quite black.
The ferruginous roughleg (<spn>Archibuteo ferrugineus</spn>) inhabits
Western North America.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rough-legged</ent><br/
<hw>Rough"-legged`</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Having the legs covered with feathers; -- said of a bird.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>rough-legged hawk</b></col>. <fld>(Zool.)</fld> <cd>See
<er>Roughleg</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roughly</ent><br/
<hw>Rough"ly</hw>, <pos>adv.</pos> <def>In a rough manner; unevenly;
harshly; rudely; severely; austerely.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roughness</ent><br/
<hw>Rough"ness</hw>, <pos>n.</pos> <def>The quality or state of being
rough.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roughrider</ent><br/
<hw>Rough"rid`er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One
who breaks horses; especially <fld>(Mil.)</fld>, a noncommissioned
officer in the British cavalry, whose duty is to assist the riding
master.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An officer or enlisted man in the 1st U. S.
Volunteer Cavalry, a regiment raised for the Spanish war of 1898,
composed mostly of Western cowboys and hunters and Eastern college
athletes and sportsmen, largely organized, and later commanded, by
Theodore Roosevelt. Sometimes, locally, a member of any of various
volunteer cavalry commands raised in 1898.</def>
<mark>[Colloq.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Roughscuff</ent><br/
<hw>Rough"scuff</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Rough</ets>
+ <ets>scuff</ets>.]</ety> <def>A rough, coarse fellow; collectively,
the lowest class of the people; the rabble; the riffraff.</def>
<mark>[Colloq. U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roughsetter</ent><br/
<hw>Rough"set`ter</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A mason who
builds rough stonework.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roughshod</ent><br/
<hw>Rough"shod</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Shod with shoes
armed with points or calks; <as>as, a <ex>roughshod</ex>
horse</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To ride roughshod</b></col>, <cd>to pursue a course
regardless of the pain or distress it may cause others.</cd></cs> <--
usu. with "over" --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roughstrings</ent><br/
<hw>Rough"strings`</hw> <pr>(?)</pr>, <pos>n. pl.</pos>
<fld>(Capr.)</fld> <def>Pieces of undressed timber put under the steps
of a wooden stair for their support.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rought</ent><br/
<hw>Rought</hw> <pr>(?)</pr>, <mark>obs.</mark> <def><pos>imp.</pos> of
<er>Reach</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rought</ent><br/
<hw>Rought</hw>, <mark>obs.</mark> <def><pos>imp.</pos> of
<er>Reck</er>, to care.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roughtail</ent><br/
<hw>Rough"tail`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>Any species of small ground snakes of the family
<fam>Uropeltidae</fam>; -- so called from their <xex>rough
tails</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roughwork</ent><br/
<hw>Rough"work`</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To work over
coarsely, without regard to nicety, smoothness, or finish.</def>
<rj><au>Moxon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roughwrought</ent><br/
<hw>Rough"wrought`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Wrought in a
rough, unfinished way; worked over coarsely.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rouk</ent><br/
<hw>Rouk</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>See 5th <er>Ruck</er>,
and <er>Roke</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roulade</ent><br/
\'d8<hw>Rou`lade"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<fld>(Mus.)</fld> <def>A smoothly running passage of short notes (as
semiquavers, or sixteenths) uniformly grouped, sung upon one long
syllable, as in Handel's oratorios.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rouleau</ent><br/
\'d8<hw>Rou`leau"</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it> F.
<plw>Rouleaux</plw> <pr>(F. <?/; E. <?/)</pr>, E. <plw>Rouleaus</plw>
<pr>(#)</pr>.</plu> <ety>[F., a roll, dim. fr. fr. <ets>r<ocir/le</ets>,
formerly also spelt <ets>roulle</ets>. See <er>Roll</er>.]</ety> <def>A
little roll; a roll of coins put up in paper, or something resembling
such a roll.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roulette</ent><br/
<hw>Rou*lette"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., properly, a
little wheel or ball. See <er>Rouleau</er>, <er>Roll</er>.]</ety>
<sn>1.</sn> <def>A game of chance, in which a small ball is made to move
round rapidly on a circle divided off into numbered red and black
spaces, the one on which it stops indicating the result of a variety of
wagers permitted by the game.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Fine Arts)</fld> <sd>(a)</sd> <def>A small toothed
wheel used by engravers to roll over a plate in order to order to
produce rows of dots.</def> <sd>(b)</sd> <def>A similar wheel used to
roughen the surface of a plate, as in making alterations in a
mezzotint.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Geom.)</fld> <def>the curve traced by any point in
the plane of a given curve when the latter rolls, without sliding, over
another fixed curve. See <er>Cycloid</er>, and
<er>Epycycloid</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A small toothed wheel used to make short incisions
in paper, as a sheet of postage stamps to facilitate their
separation.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Roulette</ent><br/
<hw>Rou*lette"</hw>, <pos>v. t.</pos> <def>To make short incisions in
with a roulette; to separate by incisions made with a roulette; <as>as,
to <ex>roulette</ex> a sheet of postage stamps</as>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Rouly-pouly</ent><br/
<hw>Rou"ly-pou`ly</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Rolly-pooly</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roumanian</ent><br/
<hw>Rou*ma"ni*an</hw> <pr>(?)</pr>, <pos>a.</pos> <altsp>[Written also
<asp>Rumanian</asp> and <asp>Romanian</asp>.]</altsp> <ety>[From
<ets>Roumania</ets>, the name of the country, Roumanian
<ets>Rom<acir/nia</ets>, fr. <ets>Rom<acir/n</ets> Roumanian, L.
<ets>Romanus</ets> Roman.]</ety> <def>Of or pertaining to
Roumania.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Roumanian</ent><br/
<hw>Rou*ma"ni*an</hw>, <pos>n.</pos> <def>An inhabitant of Roumania;
also, the language of Roumania, one of the Romance or Romanic languages
descended from Latin, but containing many words from other languages, as
Slavic, Turkish, and Greek.</def> <altsp>[Written also
<asp>Rumanian</asp> and <asp>Romanian</asp>.]</altsp> <br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Rown</ent><br/
<ent>Roun</ent><br/
<mhw>{ <hw>Roun</hw>, <hw>Rown</hw> <pr>(?)</pr> }</mhw>, <pos>v. i. &
t.</pos> <ety>[AS. <ets>r<umac/nian</ets>, fr. <ets>r<umac/n</ets> a
rune, secret, mystery; akin to G. <ets>raunen</ets> to whisper. See
<er>Rune</er>.]</ety> <def>To whisper.</def> <mark>[obs.]</mark>
<rj><au>Gower.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Another <qex>rouned</qex> to his fellow low.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rounce</ent><br/
<hw>Rounce</hw> <pr>(rouns)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>ronce</ets> bramble, brier, thorn, <ets>ranche</ets> a round, step,
rack, or E. <ets>round</ets>.]</ety> <fld>(Print.)</fld> <def>The handle
by which the bed of a hand press, holding the form of type, etc., is run
in under the platen and out again; -- sometimes applied to the whole
apparatus by which the form is moved under the platen.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rounceval</ent><br/
<hw>Roun"ce*val</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F.
<ets>Ronceval</ets>, <ets>Roncevaux</ets>, a town at the foot of the
foot of the Pyrenees, Sp. <ets>Roncesvalles</ets>.]</ety> <def>Large;
strong; -- from the gigantic bones shown at Roncesvalles, and alleged to
be those of old heroes.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rounceval</ent><br/
<hw>Roun"ce*val</hw>, <pos>n.</pos> <def>A giant; anything large; a kind
of pea called also <altname>marrowfat</altname>.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rouncy</ent><br/
<hw>Roun"cy</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A common hackney
horse; a nag.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>he rode upon a <qex>rouncy</qex> as he could.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Round</ent><br/
<hw>Round</hw> <pr>(?)</pr>, <pos>v. i. & t.</pos> <ety>[From
<er>Roun</er>.]</ety> <def>To whisper.</def> <mark>[obs.]</mark>
<rj><au>Shak. Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The Bishop of Glasgow <qex>rounding</qex> in his ear, <ldquo/Ye
are not a wise man,<rdquo/ . . . he <qex>rounded</qex> likewise to the
bishop, and said, <ldquo/Wherefore brought ye me here?<rdquo/</q>
<rj><qau>Calderwood.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Round</ent><br/
<hw>Round</hw>, <pos>a.</pos> <ety>[OF. <ets>roond</ets>,
<ets>roont</ets>, <ets>reond</ets>, F. <ets>rond</ets>, fr. L.
<ets>rotundus</ets>, fr. <ets>rota</ets> wheel. See <er>Rotary</er>, and
cf. <er>Rotund</er>, <er>roundel</er>, <er>Rundlet</er>.]</ety>
<sn>1.</sn> <def>Having every portion of the surface or of the
circumference equally distant from the center; spherical; circular;
having a form approaching a spherical or a circular shape; orbicular;
globular; <as>as, a <ex>round</ex> ball</as>.</def> <ldquo/The big,
<xex>round</xex> tears.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Upon the firm opacous globe<br/
Of this <qex>round</qex> world.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Having the form of a cylinder; cylindrical; <as>as,
the barrel of a musket is <ex>round</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Having a curved outline or form; especially, one
like the arc of a circle or an ellipse, or a portion of the surface of a
sphere; rotund; bulging; protuberant; not angular or pointed; <as>as, a
<ex>round</ex> arch; <ex>round</ex> hills.</as></def> <ldquo/Their
<xex>round</xex> haunches gored.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Full; complete; not broken; not fractional;
approximately in even units, tens, hundreds, thousands, etc.; -- said of
numbers.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Pliny put a <qex>round</qex> number near the truth, rather than
the fraction.</q> <rj><qau>Arbuthnot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Not inconsiderable; large; hence, generous; free;
<as>as, a <ex>round</ex> price</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Three thousand ducats; 'tis a good <qex>round</qex> sum.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Round</qex> was their pace at first, but slackened soon.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Uttered or emitted with a full tone; <as>as, a
<ex>round</ex> voice; a <ex>round</ex> note.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Phonetics)</fld> <def>Modified, as a vowel, by
contraction of the lip opening, making the opening more or less round in
shape; rounded; labialized; labial. See <xex>Guide to
Pronunciation</xex>, <sect/ 11.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>Outspoken; plain and direct; unreserved;
unqualified; not mincing; <as>as, a <ex>round</ex> answer; a
<ex>round</ex> oath.</as></def> <ldquo/The <xex>round</xex>
assertion.<rdquo/ <rj><au>M. Arnold.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Sir Toby, I must be <qex>round</qex> with you.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>Full and smoothly expanded; not defective or abrupt;
finished; polished; -- said of style, or of authors with reference to
their style.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>In his satires Horace is quick, <qex>round</qex>, and
pleasant.</q> <rj><qau>Peacham.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <def>Complete and consistent; fair; just; -- applied to
conduct.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Round</qex> dealing is the honor of man's nature.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>At a round rate</b></col>, <cd>rapidly.</cd>
<au>Dryden.</au> -- <col><b>In round numbers</b></col>,
<cd>approximately in even units, tens, hundreds, etc.; <as>as, a bin
holding 99 or 101 bushels may be said to hold <ex>in round numbers</ex>
100 bushels</as>.</cd> -- <col><b>Round bodies</b></col>
<fld>(Geom.)</fld>, <cd>the sphere right cone, and right cylinder.</cd>
-- <col><b>Round clam</b></col> <fld>(Zool.)</fld>, <cd>the quahog.</cd>
-- <col><b>Round dance</b></col> <cd>one which is danced by couples with
a whirling or revolving motion, as the waltz, polka, etc.</cd> --
<col><b>Round game</b></col>, <cd>a game, as of cards, in which each
plays on his own account.</cd> -- <col><b>Round hand</b></col>, <cd>a
style of penmanship in which the letters are formed in nearly an upright
position, and each separately distinct; -- distinguished from
<xex>running hand</xex>.</cd> -- <col><b>Round robin</b></col>.
<ety>[Perhaps F. <ets>round</ets> round + <ets>ruban</ets>
ribbon.]</ety> <sd>(a)</sd> <cd>A written petition, memorial,
remonstrance, protest, etc., the signatures to which are made in a
circle so as not to indicate who signed first.</cd> <ldquo/No <xex>round
robins</xex> signed by the whole main deck of the Academy or the
Porch.<rdquo/ <au>De Quincey.</au> <sd>(b)</sd> <fld>(Zool.)</fld>
<cd>The cigar fish.</cd> -- <col><b>Round shot</b></col>, <cd>a solid
spherical projectile for ordnance.</cd> -- <col><b>Round
Table</b></col>, <cd>the table about which sat King Arthur and his
knights. See <cref>Knights of the Round Table</cref>, under
<er>Knight</er>.</cd> -- <col><b>Round tower</b></col>, <cd>one of
certain lofty circular stone towers, tapering from the base upward, and
usually having a conical cap or roof, which crowns the summit, -- found
chiefly in Ireland. They are of great antiquity, and vary in heigh from
thirty-five to one hundred and thiry feet.</cd> -- <col><b>Round
trot</b></col>, <cd>one in which the horse throws out his feet roundly;
a full, brisk, quick trot.</cd> <au>Addison.</au> -- <col><b>Round
turn</b></col> <fld>(Naut.)</fld>, <cd>one turn of a rope round a
timber, a belaying pin, etc.</cd> -- <col><b>To bring up with a round
turn</b></col>, <cd>to stop abruptly.</cd>
<mark>[Colloq.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Circular; spherical; globular; globase;
orbicular; orbed; cylindrical; full; plump; rotund.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Round</ent><br/
<hw>Round</hw> <pr>(round)</pr>, <pos>n.</pos> <sn>1.</sn> <def>Anything
round, as a circle, a globe, a ring. <ldquo/The golden
<xex>round</xex><rdquo/ [the crown].</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>In labyrinth of many a <qex>round</qex> self-rolled.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A series of changes or events ending where it began;
a series of like events recurring in continuance; a cycle; a periodical
revolution; <as>as, the <ex>round</ex> of the seasons; a <ex>round</ex>
of pleasures.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <specif>Hence:</specif> <def>A course ending where it
began; a circuit; a beat; especially, one freguently or regulary
traversed; also, the act of traversing a circuit; <as>as, a watchman's
<ex>round</ex>; the <ex>rounds</ex> of the postman</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A series of duties or tasks which must be performed
in turn, and then repeated.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>the trivial <qex>round</qex>, the common task.</q>
<rj><qau>Keble.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <specif>Hence:</specif> <fld>(Mining, Tunneling)</fld>
<def>One work cycle, consisting of drilling blast holes, loading them
with explosive, blasting, mucking out, and, if necessary, installing
temporary support.</def><br/
[<source>RH</source>]</p>

<p><q> . . . <company>Inco</company> is still much more advanced than
other mining companies. He says that the LKAB mine in
<country>Sweden</country> is the closest rival. He predicts that, by
2008, <company>Inco</company> can reach a new productivity plateau,
doubling the current mining productivity from 3,350 tonnes to 6,350
tonnes per person per year. Another aim is to triple the mine cycle rate
(the time to drill, blast and muck a <qex>round</qex>) from one cycle to
three complete cycles per 24 hours.</q>
<qau>https://web.archive.org/web/20010728040054/http://www.canadianminingjournal.com/issues/apr00/page10.asp</qau><br/
[<source>PJC</source>]</p>

<p><sn>6.</sn> <def>A course of action or conduct performed by a number
of persons in turn, or one after another, as if seated in a
circle.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Women to cards may be compared: we play<br/
A <qex>round</qex> or two; which used, we throw away.</q>
<rj><qau>Granville.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The feast was served; the bowl was crowned;<br/
To the king's pleasure went the mirthful <qex>round</qex>.</q>
<rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <specif>Hence:</specif> <def>A complete set of plays in a
game or contest covering a standard number of individual plays or parts;
<as>as, a <ex>round</ex> of golf; a <ex>round</ex> of
tennis</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>8.</sn> <specif>Hence:</specif> <def>One set of games in a
tournament.</def><br/
[<source>PJC</source>]</p>

<p><sn>9.</sn> <def>The time during which prize fighters or boxers are
in actual contest without an intermission, as prescribed by their rules;
a bout.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <def>A circular dance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Come, knit hands, and beat the ground,<br/
In a light fantastic <qex>round</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>11.</sn> <def>That which goes round a whole circle or company;
<as>as, a <ex>round</ex> of applause</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>12.</sn> <def>Rotation, as in office; succession.</def>
<rj><au>Holyday.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>13.</sn> <def>The step of a ladder; a rundle or rung; also, a
crosspiece which joins and braces the legs of a chair.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>All the <qex>rounds</qex> like Jacob's ladder rise.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>14.</sn> <fld>(Mil.)</fld> <sd>(a)</sd> <def>A walk performed by
a guard or an officer round the rampart of a garrison, or among
sentinels, to see that the sentinels are faithful and all things safe;
also, the guard or officer, with his attendants, who performs this duty;
-- usually in the plural.</def> <sd>(b)</sd> <def>A general discharge of
firearms by a body of troops in which each soldier fires once.</def>
<sd>(c)</sd> <def>One piece of ammunition for a firearm, used by
discharging one piece at a time; <as>as, each soldier carried a hundred
<ex>rounds</ex> of ammunition</as>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>15.</sn> <fld>(Mus.)</fld> <def>A short vocal piece, resembling a
catch in which three or four voices follow each other round in a species
of canon in the unison.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>16.</sn> <def>A brewer's vessel in which the fermentation is
concluded, the yeast escaping through the bunghole.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>17.</sn> <def>A vessel filled, as for drinking; <as>as, to drink
a <ex>round</ex> od ale together</as>.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>18.</sn> <def>An assembly; a group; a circle; <as>as, a
<ex>round</ex> of politicians</as>.</def> <rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>19.</sn> <fld>(Naut.)</fld> <def>See <er>Roundtop</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>20.</sn> <def>Same as <cref>Round of beef</cref>,
below.</def><br/
[<source>1913 Webster</source>]</p>

<cs><p><col><b>Gentlemen of the round</b></col>. <sd>(a)</sd>
<cd>Gentlemen soldiers of low rank who made the rounds. See 10
<sd>(a)</sd>, above.</cd> <sd>(b)</sd> <cd>Disbanded soldiers who lived
by begging.</cd> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Worm-eaten <qex>gentlemen of the round</qex>, such as have vowed
to sit on the skirts of the city, let your provost and his half dozen of
halberdiers do what they can.</q> <rj><qau>B. Jonson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <col><b>Round of beef</b></col>, <cd>the part of the thigh below
the aitchbone, or between the rump and the leg.</cd> See
<xex>Illust.</xex> of <er>beef</er>. -- <col><b>Round steak</b></col>,
<cd>a beefsteak cut from the round.</cd> -- <col><b>Sculpture in the
round</b></col>, <cd>sculpture giving the full form, as of man;
statuary, distinguished from relief.</cd><br/
[<source>1913 Webster</source>]</p></cs>

<p><-- p. 1255 --></p>

<p><ent>Round</ent><br/
<hw>Round</hw>, <pos>adv.</pos> <sn>1.</sn> <def>On all sides;
around.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Round</qex> he throws his baleful eyes.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Circularly; in a circular form or manner; by
revolving or reversing one's position; <as>as, to turn one's head
<ex>round</ex>; a wheel turns <ex>round</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>In circumference; <as>as, a ball is ten inches
<ex>round</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>From one side or party to another; as to come or
turn <xex>round</xex>, -- that is, to change sides or
opinions.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>By or in a circuit; by a course longer than the
direct course; back to the starting point.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Through a circle, as of friends or houses.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The invitations were sent <qex>round</qex> accordingly.</q>
<rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>Roundly; fully; vigorously.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>All round</b></col>, <cd>over the whole place; in every
direction.</cd> -- <col><b>All-round</b></col>, <cd>of general capacity;
<as>as, an <ex>all-round</ex> man</as>.</cd> <mark>[Colloq.]</mark> --
<col><b>To bring one round</b></col>. <sd>(a)</sd> <cd>To cause one to
change his opinions or line of conduct</cd>. <sd>(b)</sd> <cd>To restore
one to health</cd>. <mark>[Colloq.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Round</ent><br/
<hw>Round</hw> <pr>(?)</pr>, <pos>prep.</pos> <def>On every side of, so
as to encompass or encircle; around; about; <as>as, the people atood
<ex>round</ex> him; to go <ex>round</ex> the city; to wind a cable
<ex>round</ex> a windlass</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The serpent Error twines <qex>round</qex> human hearts.</q>
<rj><qau>Cowper.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Round about</b></col>, <cd>an emphatic form for
<xex>round</xex> or <xex>about</xex>.</cd> <ldquo/Moses . . . set them
[The elders] <xex>round about</xex> the tabernacle.<rdquo/ <au>Num. xi.
24.</au> -- <col><b>To come round</b></col>, <cd>to gain the consent of,
or circumvent, (a person) by flattery or deception.</cd>
<mark>[Colloq.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Round</ent><br/
<hw>Round</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Rounded</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Rounding</conjf>.]</vmorph> <sn>1.</sn> <def>To make circular,
spherical, or cylindrical; to give a round or convex figure to; <as>as,
to <ex>round</ex> a silver coin; to <ex>round</ex> the edges of
anything</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Worms with many feet, which <qex>round</qex> themselves into
balls, are bred chiefly under logs of timber.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The figures on our modern medals are raised and <qex>rounded</qex>
to a very great perfection.</q> <rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To surround; to encircle; to encompass.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The inclusive verge<br/
Of golden metal that must <qex>round</qex> my brow.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To bring to fullness or completeness; to complete;
hence, to bring to a fit conclusion.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We are such stuff<br/
As dreams are made on, and our little life<br/
Is <qex>rounded</qex> with a sleep.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To go round wholly or in part; to go about (a corner
or point); <as>as, to <ex>round</ex> a corner; to <ex>round</ex> Cape
Horn</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To make full, smooth, and flowing; <as>as, to
<ex>round</ex> periods in writing</as>.</def>
<rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To round in</b></col> <fld>(Naut.)</fld> <cd>To haul up;
usually, to haul the slack of (a rope) through its leading block, or to
haul up (a tackle which hangs loose) by its fall.</cd> <au>Totten.</au>
<sd>(b)</sd> <cd>To collect together (cattle) by riding around them, as
on cattle ranches<-- round up --></cd>. <mark>[Western
U.S.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Round</ent><br/
<hw>Round</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To grow round or full;
hence, to attain to fullness, completeness, or perfection.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The queen your mother <qex>rounds</qex> apace.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>So <qex>rounds</qex> he to a separate mind,<br/
From whence clear memory may begin.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To go round, as a guard.</def>
<mark>[Poetic]</mark><-- = make the rounds --><br/
[<source>1913 Webster</source>]</p>

<p><q>They . . . nightly <qex>rounding</qex> walk.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To go or turn round; to wheel about.</def>
<rj><au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To round to</b></col> <fld>(Naut.)</fld>, <cd>to turn the
head of a ship toward the wind.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roundabout</ent><br/
<hw>Round"a*bout`</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Circuitous; going round; indirect; <as>as, <ex>roundabout</ex>
speech</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We have taken a terrible <qex>roundabout</qex> road.</q>
<rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Encircling; enveloping; comprehensive.</def>
<ldquo/Large, sound, <xex>roundabout</xex> sense.<rdquo/
<rj><au>Locke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roundabout</ent><br/
<hw>Round"a*bout`</hw>, <pos>n.</pos> <sn>1.</sn> <def>A large
horizontal wheel or frame, commonly with wooden horses, etc., on which
children ride; a merry-go-round; a carousel.</def>
<mark>[British]</mark> <rj><au>Smart.</au></rj><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>A dance performed in a circle.</def>
<rj><au>Goldsmith.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A short, close jacket worn by boys, sailors,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A state or scene of constant change, or of recurring
labor and vicissitude.</def> <rj><au>Cowper.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>a <er>traffic circle</er>.</def> <mark>[Chiefly
British]</mark><br/
[<source>PJC</source>]</p>

<p><ent>Roundaboutness</ent><br/
<hw>Round"a*bout`ness</hw>, <pos>n.</pos> <def>The quality of being
roundabout; circuitousness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Round-arm</ent><br/
<hw>Round"-arm`</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Cricket)</fld>
<def>Applied to the method delivering the ball in bowling, by swinging
the arm horizontally.</def> <rj><au>R. A. Proctor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Round-backed</ent><br/
<hw>Round"-backed`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having a round
back or shoulders; round-shouldered.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rounded</ent><br/
<hw>Round"ed</hw>, <pos>a.</pos> <fld>(Phonetics)</fld> <def>Modified by
contraction of the lip opening; labialized; labial. See <xex>Guide to
Pronunciation</xex>, <sect/ 11.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roundel</ent><br/
<hw>Roun"del</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>rondel</ets> a roundelay, F. <ets>rondel</ets>, <ets>rondeau</ets>,
a dim. fr. <ets>rond</ets>; for sense 2, cf. F. <ets>rondelle</ets> a
round, a round shield. See <er>Round</er>, <pos>a.</pos>, and cf.
<er>Rondel</er>, <er>Rondelay</er>.]</ety> <sn>1.</sn> <fld>(Mus.)</fld>
<def>A rondelay.</def> <ldquo/Sung all the <xex>roundel</xex>
lustily.<rdquo/ <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Come, now a <qex>roundel</qex> and a fairy song.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Anything having a round form; a round figure; a
circle.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The Spaniards, casting themselves into <qex>roundels</qex>, . . .
made a flying march to Calais.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p>Specifically: <sd>(a)</sd> <def>A small circular shield, sometimes
not more than a foot in diameter, used by soldiers in the fourteenth and
fifteenth centuries.</def> <sd>(b)</sd> <fld>(Her.)</fld> <def>A
circular spot; a sharge in the form of a small circle.</def>
<sd>(c)</sd> <fld>(Fort.)</fld> <def>A bastion of a circular
form.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roundelay</ent><br/
<hw>Round"e*lay</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>rondelet</ets>, dim. of <ets>rondel</ets>. See <er>Roundel</er>,
<er>Roundeau</er>, and cf. <er>Roundlet</er>, <er>Rundlet</er>.]</ety>
<sn>1.</sn> <fld>(Poetry)</fld> <def>See <er>Rondeau</er>, and
<er>Rondel</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mus.)</fld> <sd>(a)</sd> <def>A tune in which a
simple strain is often repeated; a simple rural strain which is short
and lively.</def> <au>Spenser.</au> <au>Tennyson.</au> <sd>(b)</sd>
<def>A dance in a circle.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Anything having a round form; a roundel.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rounder</ent><br/
<hw>Round"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who
rounds; one who comes about frequently or regularly.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A tool for making an edge or surface
round.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <pluf>pl.</pluf> <def>An English game somewhat resembling
baseball; also, another English game resembling the game of fives, but
played with a football.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Now we play <qex>rounders</qex>, and then we played prisoner's
base.</q> <rj><qau>Bagehot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roundfish</ent><br/
<hw>Round"fish</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<sd>(a)</sd> <def>Any ordinary market fish, exclusive of flounders,
sole, halibut, and other <xex>flatfishes</xex>.</def> <sd>(b)</sd>
<def>A lake whitefish (<spn>Coregonus quadrilateralis</spn>), less
compressed than the common species. It is very abundant in British
America and Alaska.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roundhead</ent><br/
<hw>Round"head`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Eng. Hist.)</fld>
<def>A nickname for a Puritan. See <xex>Roundheads</xex>,
<xex>the</xex>, in the Dictionary of Noted Names in Fiction.</def>
<rj><au>Toone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roundheaded</ent><br/
<hw>Round"head`ed</hw>, <pos>a.</pos> <def>Having a round head or
top.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roundhouse</ent><br/
<hw>Round"house`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A
constable's prison; a lockup, watch-house, or station house.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Naut.)</fld> <sd>(a)</sd> <def>A cabin or apartment
on the after part of the quarter-deck, having the poop for its roof; --
sometimes called the <altname>coach</altname>.</def> <sd>(b)</sd> <def>A
privy near the bow of the vessel.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A house for servicing and repair of locomotive
engines, built circularly around a turntable bearing railroad tracks,
with several tracks leading in and out.</def><br/
[<source>1913 Webster</source> + <source>PJC</source>]</p>

<p><ent>Rounding</ent><br/
<hw>Round"ing</hw>, <pos>a.</pos> <def>Round or nearly round; becoming
round; roundish.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rounding</ent><br/
<hw>Round"ing</hw>, <pos>n.</pos> <sn>1.</sn> <fld>(Naut.)</fld>
<def>Small rope, or strands of rope, or spun yarn, wound round a rope to
keep it from chafing; -- called also
<altname>service</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Phonetics)</fld> <def>Modifying a speech sound by
contraction of the lip opening; labializing; labialization. See
<xex>Guide to Pronunciation</xex>, <sect/ 11.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roundish</ent><br/
<hw>Round"ish</hw>, <pos>a.</pos> <def>Somewhat round; <as>as, a
<ex>roundish</ex> seed; a <ex>roundish</ex> figure</as>.</def> --
<wordforms><wf>Round"ish*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roundlet</ent><br/
<hw>Round"let</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A little
circle.</def> <rj><au>J. Gregory.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roundly</ent><br/
<hw>Round"ly</hw>, <pos>adv.</pos> <sn>1.</sn> <def>In a round form or
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Openly; boldly; peremptorily; plumply.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He affirms everything <qex>roundly</qex>.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Briskly; with speed.</def>
<rj><au>locke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Two of the outlaws walked <qex>roundly</qex> forward.</q>
<rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Completely; vigorously; in earnest.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Without regard to detail; in gross; comprehensively;
generally; <as>as, to give numbers <ex>roundly</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In speaking <qex>roundly</qex> of this period.</q> <rj><qau>H.
Morley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roundness</ent><br/
<hw>Round"ness</hw>, <pos>n.</pos> <sn>1.</sn> <def>The quality or state
of being round in shape; <as>as, the <ex>roundness</ex> of the globe, of
the orb of the sun, of a ball, of a bowl, a column, etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Fullness; smoothness of flow; <as>as, the
<ex>roundness</ex> of a period; the <ex>roundness</ex> of a note;
<ex>roundness</ex> of tone</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Openess; plainess; boldness; positiveness; <as>as,
the <ex>roundness</ex> of an assertion</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Circularity; sphericity; globosity; globularity;
globularness; orbicularness; cylindricity; fullness; plumpness;
rotundity.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roundridge</ent><br/
<hw>Round"ridge`</hw> <pr>(?)</pr>, <pos>v. t.</pos> <fld>(Agric.)</fld>
<def>To form into round ridges by plowing.</def> <rj><au>B.
Edwards.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>round-robin</ent><br/
<ent>round robin</ent><br/
<mhw><hw>round" rob"in</hw>, <hw>round"-rob"in</hw></mhw> <pr>(round"
r<ocr/b"<icr/n)</pr>, <pos>n.</pos> <sn>1.</sn> <def>Any series or
sequence of actions.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>A document circulated from one person to another in
a group, often with comments added by each recipient.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>A petition or similar document, in which the
signatures are arranged in circular form in order to conceal the order
of signing.</def><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <fld>(Sports)</fld> <def>A tournament in which each
contestant plays against every other contestant at least once; a failure
to win any contest does not result in elimination from the tournament.
Contrasted with <contr>elimination tournament</contr></def><br/
[<source>PJC</source>]</p>

<p><ent>Round-shouldered</ent><br/
<hw>Round"-shoul`dered</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having the
shoulders stooping or projecting; round-backed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roundsman</ent><br/
<hw>Rounds"man</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Roundsmen</plw> <pr>(<?/)</pr>.</plu> <def>A patrolman; also, a
policeman who acts as an inspector over the rounds of the
patrolmen.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roundtop</ent><br/
<hw>Round"top`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Naut.)</fld>
<def>A top; a platform at a masthead; -- so called because formerly
round in shape.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Round-up</ent><br/
<hw>Round"-up`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The act
of collecting or gathering together scattered cattle by riding around
them and driving them in.</def> <mark>[Western U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A rounding up, or upward curvature or convexity, as
in the deck of a vessel.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>A gathering in of scattered persons or things;
<as>as, a <ex>round-up</ex> of criminals</as>.</def> <mark>[Colloq., U.
S.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Round up</ent><br/
<hw>Round up"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>to collect or
gather together scattered animals, persons, or things.</def>
<ldquo/<ex>Round up</ex> the usual suspects.<rdquo/
<au>[Casablanca]</au><br/
[<source>PJC</source>]</p>

<p><ent>Roundure</ent><br/
<hw>Roun"dure</hw> <pr>(?; 135)</pr>, <pos>n.</pos> <ety>[Cf.
<er>Rondure</er>.]</ety> <def>Roundness; a round or circle.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roundworm</ent><br/
<hw>Round"worm`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>A nematoid worm.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roundy</ent><br/
<hw>Round"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Round.</def>
<mark>[Obs.]</mark> <rj><au>Sir P. Sidney.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roup</ent><br/
<hw>Roup</hw> <pr>(?)</pr>, <pos>v. i. & t.</pos> <ety>[Cf. AS. hr<?/pan
to cry out, G. <ets>rufen</ets>, Goth. <ets>hr<?/pian</ets>. Cf.
<er>Roop</er>.]</ety> <def>To cry or shout; hence, to sell by
auction.</def> <mark>[Scot.]</mark> <rj><au>Jamieson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roup</ent><br/
<hw>Roup</hw>, <pos>n.</pos> <sn>1.</sn> <def>An outcry; hence, a sale
of gods by auction.</def> <mark>[Scot.]</mark>
<rj><au>Jamieson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>roup</qex>, that is, the sale of his crops, was over.</q>
<rj><qau>J. C. Shairp.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A disease in poultry. See <er>Pip</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rousant</ent><br/
<hw>Rous"ant</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(her.)</fld>
<def>Rising; -- applied to a bird in the attitude of rising; also,
sometmes, to a bird in profile with wings addorsed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rouse</ent><br/
<hw>Rouse</hw> <pr>(rouz <it>or</it> rous)</pr>, <pos>v. i. & t.</pos>
<ety>[Perhaps the same word as <ets>rouse</ets> to start up,
<ldquo/buckle to.<rdquo/]</ety> <fld>(Naut.)</fld> <def>To pull or haul
strongly and all together, as upon a rope, without the assistance of
mechanical appliances.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rouse</ent><br/
<hw>Rouse</hw> <pr>(rouz)</pr>, <pos>n.</pos> <ety>[Cf. D.
<ets>roes</ets> drunkeness, icel. <ets>r<umac/ss</ets>, Sw.
<ets>rus</ets>, G. <ets>rauchen</ets>, and also E. <ets>rouse</ets>,
v.t., <ets>rush</ets>, v.i. Cf. <er>Row</er> a disturbance.]</ety>
<sn>1.</sn> <def>A bumper in honor of a toast or health.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A carousal; a festival; a drinking frolic.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Fill the cup, and fill the can,<br/
Have a <qex>rouse</qex> before the morn.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rouse</ent><br/
<hw>Rouse</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Roused</conjf> <pr>(rouzd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Rousing</conjf>.]</vmorph> <ety>[Probably of Scan. origin; cf.
Sw. <ets>rusa</ets> to rush, Dan. <ets>ruse</ets>, AS.
<ets>hre<oacute/san</ets> to fall, rush. Cf. <er>Rush</er>,
<pos>v.</pos>]</ety> <sn>1.</sn> <def>To cause to start from a covert or
lurking place; <as>as, to <ex>rouse</ex> a deer or other animal of the
chase</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Like wild boars late <qex>roused</qex> out of the brakes.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Rouse</qex> the fleet hart, and cheer the opening hound.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To wake from sleep or repose; <as>as, to
<ex>rouse</ex> one early or suddenly</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To excite to lively thought or action from a state
of idleness, languor, stupidity, or indifference; <as>as, to
<ex>rouse</ex> the faculties, passions, or emotions</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>rouse</qex> up a people, the most phlegmatic of any in
Christendom.</q> <rj><qau>Atterbury.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To put in motion; to stir up; to agitate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Blustering winds, which all night long<br/
Had <qex>roused</qex> the sea.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To raise; to make erect.</def> <mark>[Obs.]</mark>
<rj><au>Spenser. Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rouse</ent><br/
<hw>Rouse</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To get or start up; to
rise.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Night's black agents to their preys do <qex>rouse</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To awake from sleep or repose.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Morpheus <qex>rouses</qex> from his bed.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To be exited to thought or action from a state of
indolence or inattention.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rouser</ent><br/
<hw>Rous"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who,
or that which, rouses.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Something very exciting or great.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Brewing)</fld> <def>A stirrer in a copper for
boiling wort.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rousing</ent><br/
<hw>Rous"ing</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Having
power to awaken or excite; exciting.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I begin to feel<br/
Some <qex>rousing</qex> motions in me.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Very great; violent; astounding; <as>as, a
<ex>rousing</ex> fire; a <ex>rousing</ex> lie</as>.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rousingly</ent><br/
<hw>Rous"ing*ly</hw>, <pos>adv.</pos> <def>In a rousing
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roussette</ent><br/
<hw>Rous*sette"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.; -- so called
in allusion to the color. See <er>Russet</er>.]</ety> <sn>1.</sn>
<fld>(Zool.)</fld> <def>A fruit bat, especially the large species
(<spn>Pieropus vulgaris</spn>) inhabiting the islands of the Indian
ocean. It measures about a yard across the expanded wings.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>Any small shark of the genus
<gen>Scyllium</gen>; -- called also <altname>dogfish</altname>. See
<er>Dogfish</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roust</ent><br/
<hw>Roust</hw> <pr>(roust)</pr>, <pos>v. t.</pos> <def>To rouse; to
disturb; <as>as, to <ex>roust</ex> one out</as>.</def> <mark>[Prov. Eng.
& Local, U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roust</ent><br/
<hw>Roust</hw>, <pos>n.</pos> <ety>[Cf. Icel. <ets>r<oum/st</ets> an
estuary.]</ety> <def>A strong tide or current, especially in a narrow
channel.</def> <altsp>[Written also <asp>rost</asp>, and
<asp>roost</asp>.]</altsp> <rj><au>Jamieson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roustabout</ent><br/
<hw>Roust"a*bout`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Etymol.
uncertain.]</ety> <def>A laborer, especially a deck hand, on a river
steamboat, who moves the cargo, loads and unloads wood, and the like; in
an opprobrious sense, a shiftless vagrant who lives by chance
jobs.</def> <mark>[Western U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rout</ent><br/
<hw>Rout</hw> <pr>(rout)</pr>, <pos>v. i.</pos> <ety>[AS.
<ets>hr<umac/tan</ets>.]</ety> <def>To roar; to bellow; to snort; to
snore loudly.</def> <mark>[Obs. or Scot.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rout</ent><br/
<hw>Rout</hw>, <pos>n.</pos> <def>A bellowing; a shouting; noise;
clamor; uproar; disturbance; tumult.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>This new book the whole world makes such a <qex>rout</qex>
about.</q> <rj><qau>Sterne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><ldquo/My child, it is not well,<rdquo/ I said,<br/
<ldquo/Among the graves to shout;<br/
To laugh and play among the dead,<br/
And make this noisy <qex>rout</qex>.<rdquo/</q>
<rj><qau>Trench.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rout</ent><br/
<hw>Rout</hw>, <pos>v. t.</pos> <ety>[A variant of
<ets>root</ets>.]</ety> <def>To scoop out with a gouge or other tool; to
furrow.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To rout out</b></col> <sd>(a)</sd> <cd>To turn up to
view, as if by rooting; to discover; to find</cd>. <sd>(b)</sd> <cd>To
turn out by force or compulsion; as, <xex>to rout</xex> people
<xex>out</xex> of bed.</cd> <mark>[Colloq.]</mark></cs> <-- = to root
out, roust out of? --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rout</ent><br/
<hw>Rout</hw>, <pos>v. i.</pos> <def>To search or root in the ground, as
a swine.</def> <rj><au>Edwards.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rout</ent><br/
<hw>Rout</hw>, <pos>n.</pos> <ety>[OF. <ets>route</ets>, LL.
<ets>rupta</ets>, properly, a breaking, fr. L. <ets>ruptus</ets>, p. p.
of <ets>rumpere</ets> to break. See <er>Rupture</er>, <er>reave</er>,
and cf. <er>Rote</er> repetition of forms, <er>Route</er>. In some
senses this word has been confused with <ets>rout</ets> a bellowing, an
uproar.]</ety> <altsp>[Formerly spelled also <asp>route</asp>.]</altsp>
<sn>1.</sn> <def>A troop; a throng; a company; an assembly; especially,
a traveling company or throng.</def> <mark>[Obs.]</mark> <ldquo/A
<xex>route</xex> of ratones [rats].<rdquo/ <au>Piers Plowman.</au>
<ldquo/A great solemn <xex>route</xex>.<rdquo/ <au>Chaucer.</au><br/
[<source>1913 Webster</source>]</p>

<p><q>And ever he rode the hinderest of the <qex>route</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>rout</qex> of people there assembled were.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A disorderly and tumultuous crowd; a mob; hence, the
rabble; the herd of common people.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>the endless <qex>routs</qex> of wretched thralls.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The ringleader and head of all this <qex>rout</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Nor do I name of men the common <qex>rout</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The state of being disorganized and thrown into
confusion; -- said especially of an army defeated, broken in pieces, and
put to flight in disorder or panic; also, the act of defeating and
breaking up an army; <as>as, the <ex>rout</ex> of the enemy was
complete</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>thy army . . . <br/
Dispersed in <qex>rout</qex>, betook them all to fly.</q>
<rj><qau>Daniel.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To these giad conquest, murderous <qex>rout</qex> to those.</q>
<rj><qau>pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Law)</fld> <def>A disturbance of the peace by
persons assembled together with intent to do a thing which, if executed,
would make them rioters, and actually making a motion toward the
executing thereof.</def> <rj><au>Wharton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A fashionable assembly, or large evening
party.</def> <ldquo/At <xex>routs</xex> and dances.<rdquo/
<rj><au>Landor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To put to rout</b></col>, <cd>to defeat and throw into
confusion; to overthrow and put to flight.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rout</ent><br/
<hw>Rout</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Routed</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Routing</conjf>.]</vmorph> <def>To break the ranks of, as troops,
and put them to flight in disorder; to put to rout.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That party . . . that charged the Scots, so totally
<qex>routed</qex> and defeated their whole army, that they fied.</q>
<rj><qau>Clarendon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To defeat; discomfit; overpower;
overthrow.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rout</ent><br/
<hw>Rout</hw>, <pos>v. i.</pos> <def>To assemble in a crowd, whether
orderly or disorderly; to collect in company.</def> <mark>[obs.]</mark>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>In all that land no Christian[s] durste <qex>route</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rout cake</ent><br/
<hw>Rout" cake`</hw> <pr>(?)</pr>. <def>A kind of rich sweet cake made
for routs, or evening parties.</def></p>

<p><q>Twenty-four little <qex>rout cakes</qex> that were lying neglected
in a plate.</q> <rj><qau>Thackeray.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Route</ent><br/
<hw>Route</hw> <pr>(r<oomac/t <or/ rout; 277)</pr>, <pos>n.</pos>
<ety>[OE. & F. <ets>route</ets>, OF. <ets>rote</ets>, fr. L.
<ets>rupta</ets> (sc. <ets>via</ets>), fr. <ets>ruptus</ets>, p. p. of
<ets>rumpere</ets> to break; hence, literally, a broken or beaten way or
path. See <er>Rout</er>, and cf. <er>Rut</er> a track.]</ety> <def>The
course or way which is traveled or passed, or is to be passed; a
passing; a course; a road or path; a march.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Wide through the furzy field their <qex>route</qex> they take.</q>
<rj><qau>Gay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Router</ent><br/
<hw>Rout"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<fld>(Carp.)</fld> <sd>(a)</sd> <def>A plane made like a spokeshave, for
working the inside edges of circular sashes.</def> <sd>(b)</sd> <def>A
plane with a hooked tool protruding far below the sole, for smoothing
the bottom of a cavity.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mach.)</fld> <def>A machine with a rapidly
revolving vertical spindle and cutter for scooping out the surface of
wood or metal, as between and around the engraved parts of an
electrotype.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Routhe</ent><br/
<hw>Routhe</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Ruth; sorrow.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Routinary</ent><br/
<hw>Rou"ti*na*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Involving, or
pertaining to, routine; ordinary; customary.</def> <mark>[R.]</mark>
<rj><au>Emerson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Routine</ent><br/
<hw>Rou*tine"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr.
<ets>route</ets> a path, way, road. See <er>Route</er>,
<er>Rote</er>repetition.]</ety> <sn>1.</sn> <def>A round of business,
amusement, or pleasure, daily or frequently pursued; especially, a
course of business or offical duties regularly or frequently
returning.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Any regular course of action or procedure rigidly
adhered to by the mere force of habit.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Routinism</ent><br/
<hw>Rou*tin""ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>the practice of
doing things with undiscriminating, mechanical regularity.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Routinist</ent><br/
<hw>Rou*tin"ist</hw>, <pos>n.</pos> <def>One who habituated to a
routine.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Routish</ent><br/
<hw>Rout"ish</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Uproarious;
riotous.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Routously</ent><br/
<hw>Rout"ous*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <fld>(Law)</fld>
<def>With that violation of law called a rout. See 5th <er>Rout</er>,
4.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roux</ent><br/
\'d8<hw>Roux</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. beurre
<ets>roux</ets> brown butter.]</ety> <fld>(Cookery)</fld> <def>A
thickening, made of flour, for soups and gravies.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1256 --></p>

<p><ent>Rove</ent><br/
<hw>Rove</hw> <pr>(r<omac/v)</pr>, <pos>v. t.</pos> <ety>[perhaps fr. or
akin to <ets>reeve</ets>.]</ety> <sn>1.</sn> <def>To draw through an eye
or aperture.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To draw out into flakes; to card, as wool.</def>
<rj><au>Jamieson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To twist slightly; to bring together, as slivers of
wool or cotton, and twist slightly before spinning.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rove</ent><br/
<hw>Rove</hw> <pr>(r<omac/v)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A
copper washer upon which the end of a nail is clinched in boat
building.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A roll or sliver of wool or cotton drawn out and
slighty twisted, preparatory to further process; a roving.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rove</ent><br/
<hw>Rove</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Roved</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Roving</conjf>.]</vmorph> <ety>[Cf. D. <ets>rooven</ets> to rob;
akin to E. <ets>reave</ets>. See <er>Reave</er>, <er>Rob</er>.]</ety>
<sn>1.</sn> <def>To practice robbery on the seas; to wander about on the
seas in piracy.</def> <mark>[Obs.]</mark> <rj><au>Hakluyt.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence, to wander; to ramble; to rauge; to go, move,
or pass without certain direction in any manner, by sailing, walking,
riding, flying, or otherwise.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>For who has power to walk has power to <qex>rove</qex>.</q>
<rj><qau>Arbuthnot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Archery)</fld> <def>To shoot at rovers; hence, to
shoot at an angle of elevation, not at point-blank (rovers usually being
beyond the point-blank range).</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Fair Venus' son, that with thy cruel dart<br/
At that good knight so cunningly didst <qex>rove</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- To wander; roam; range; ramble stroll.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rove</ent><br/
<hw>Rove</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To wander over or
through.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Roving</qex> the field, I chanced<br/
A goodly tree far distant to behold.</q> <rj><qau>milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To plow into ridges by turning the earth of two
furrows together.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rove</ent><br/
<hw>Rove</hw>, <pos>n.</pos> <def>The act of wandering; a
ramble.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In thy nocturnal <qex>rove</qex> one moment halt.</q>
<rj><qau>Young.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Rove beetle</b></col> <fld>(Zool.)</fld>, <cd>any one of
numerous species of beetles of the family <fam>Staphylinidae</fam>,
having short elytra beneath which the wings are folded transversely.
They are rapid runners, and seldom fly.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rover</ent><br/
<hw>Rov"er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[D. <ets>roover</ets> a
robber. See <er>Rove</er>, <pos>v. i.</pos>]</ety> <sn>1.</sn> <def>One
who practices robbery on the seas; a pirate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Yet Pompey the Great deserveth honor more justly for scouring the
seas, and taking from the <qex>rovers</qex> 846 sail of ships.</q>
<rj><qau>Holland.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who wanders about by sea or land; a wanderer; a
rambler.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Hence, a fickle, inconstant person.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Croquet)</fld> <def>A ball which has passed through
all the hoops and would go out if it hit the stake but is continued in
play; also, the player of such a ball.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Archery)</fld> <sd>(a)</sd> <def>Casual marks at
uncertain distances.</def> <rj><au>Encyc. Brit.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(b)</sd> <def>A sort of arrow.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>All sorts, flights, <qex>rovers</qex>, and butt shafts.</q>
<rj><qau>B. Jonson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<cs><p><col><b>At rovers</b></col>, <cd>at casual marks; hence, at
random; <as>as, shooting <ex>at rovers</ex></as>. See def. 5
<sd>(a)</sd> above.</cd> <au>Addison.</au><br/
[<source>1913 Webster</source>]</p>

<p><q>Bound down on every side with many bands because it shall not run
<qex>at rovers</qex>.</q> <rj><qau>Robynson (More's Utopia).</qau></rj>
<br/
[<source>1913 Webster</source>]</p></cs>

<p><ent>Roving</ent><br/
<hw>Rov"ing</hw>, <pos>n.</pos> <sn>1.</sn> <def>The operatin of forming
the rove, or slightly twisted sliver or roll of wool or cotton, by means
of a machine for the purpose, called a <xex>roving frame</xex>, or
<xex>roving machine</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A roll or sliver of wool or cotton drawn out and
slightly twisted; a rove. See 2d <er>Rove</er>, 2.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Roving frame</b></col>, <col><b>Roving
machine</b></col></mcol>, <cd>a machine for drawing and twisting roves
and twisting roves and winding them on bobbin for the spinning
machine.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roving</ent><br/
<hw>Rov"ing</hw>, <pos>n.</pos> <def>The act of one who roves or
wanders.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rovingly</ent><br/
<hw>Rov"ing*ly</hw>, <pos>adv.</pos> <def>In a wandering
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rovingness</ent><br/
<hw>Rov"ing*ness</hw>, <pos>n.</pos> <def>The state of roving.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Row</ent><br/
<hw>Row</hw> <pr>(?)</pr>, <pos>a. & adv.</pos> <ety>[See
<er>Rough</er>.]</ety> <def>Rough; stern; angry.</def>
<mark>[Obs.]</mark> <ldquo/Lock he never so <xex>row</xex>.<rdquo/
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Row</ent><br/
<hw>Row</hw>, <pos>n.</pos> <ety>[Abbrev. fr. <ets>rouse</ets>,
n.]</ety> <def>A noisy, turbulent quarrel or disturbance; a brawl.</def>
<mark>[Colloq.]</mark> <rj><au>Byron.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Row</ent><br/
<hw>Row</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>rowe</ets>,
<ets>rawe</ets>, <ets>rewe</ets>, AS. <ets>r<amac/w</ets>,
<ets>r<?/w</ets>; probably akin to D. <ets>rij</ets>, G.
<ets>reihe</ets>; cf. Skr. <ets>r<?/kh<amac/</ets> a line,
stroke.]</ety> <def>A series of persons or things arranged in a
continued line; a line; a rank; a file; <as>as, a <ex>row</ex> of trees;
a <ex>row</ex> of houses or columns</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And there were windows in three <qex>rows</qex>.</q> <rj><qau>1
Kings vii. 4.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The bright seraphim in burning <qex>row</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Row culture</b></col> <fld>(Agric.)</fld>, <cd>the
practice of cultivating crops in drills.</cd> -- <col><b>Row of
points</b></col> <fld>(Geom.)</fld>, <cd>the points on a line, infinite
in number, as the points in which a pencil of rays is intersected by a
line.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Row</ent><br/
<hw>Row</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Rowed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Rowing</conjf>.]</vmorph> <ety>[AS. <ets>r<?/wan</ets>; akin to
D. <ets>roeijen</ets>, MHG. <ets>r<uum/ejen</ets>, Dan. <ets>roe</ets>,
Sw. <ets>ro</ets>, Icel. <ets>r<?/a</ets>, L. <ets>remus</ets> oar, Gr.
<?/, Skr. <ets>aritra</ets>. <root/8. Cf. <er>Rudder</er>.]</ety>
<sn>1.</sn> <def>To propel with oars, as a boat or vessel, along the
surface of water; <as>as, to <ex>row</ex> a boat</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To transport in a boat propelled with oars; <as>as,
to <ex>row</ex> the captain ashore in his barge</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Row</ent><br/
<hw>Row</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To use the oar; <as>as,
to <ex>row</ex> well</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To be moved by oars; <as>as, the boat <ex>rows</ex>
easily</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Row</ent><br/
<hw>Row</hw>, <pos>n.</pos> <def>The act of rowing; excursion in a
rowboat.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rowable</ent><br/
<hw>Row"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>That may be rowed,
or rowed upon.</def> <ldquo/That long barren fen, once
<xex>rowable</xex>.<rdquo/ <rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rowan</ent><br/
<hw>Row"an</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Rowan tree.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Rowan barry</b></col>, <cd>a barry of the rowan
tree.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rowan tree</ent><br/
<hw>Row"an tree`</hw> <pr>(?)</pr>. <ety>[Cf. Sw. <ets>r<oum/nn</ets>,
Dan. <ets>r<oum/nne</ets>, Icel. <ets>reynir</ets>, and L.
<ets>ornus</ets>.]</ety> <fld>(Bot.)</fld> <def>A european tree
(<spn>Pyrus aucuparia</spn>) related to the apple, but with pinnate
leaves and flat corymbs of small white flowers followed by little bright
red berries. Called also <altname>roan tree</altname>, and
<altname>mountain ash</altname>. The name is also applied to two
American trees of similar habit (<spn>Pyrus Americana</spn>, and
<spn>Pyrus sambucifolia</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rowboat</ent><br/
<hw>Row"boat`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A boat designed to
be propelled by oars instead of sails.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rowdy</ent><br/
<hw>Row"dy</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Rowdies</plw> <pr>(#)</pr>.</plu> <ety>[From <er>Rout</er>, or Row
a brawl.]</ety> <def>One who engages in rows, or noisy quarrels; a
ruffianly fellow.</def> <rj><au>M. Arnold.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rowdydow</ent><br/
<hw>Row"dy*dow</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Hubbub;
uproar.</def> <mark>[Vulgar]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rowdydowdy</ent><br/
<hw>Row"dy*dow`dy</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Uproarious.</def> <mark>[Vulgar]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rowdyish</ent><br/
<hw>Row"dy*ish</hw>, <pos>a.</pos> <def>Resembling a rowdy in temper or
conduct; characteristic of a rowdy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rowdyism</ent><br/
<hw>Row"dy*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>the conduct of a
rowdy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rowed</ent><br/
<hw>Rowed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Formed into a row, or
rows; having a row, or rows; <as>as, a twelve-<ex>rowed</ex> ear of
corn</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rowel</ent><br/
<hw>Row"el</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF. <ets>roele</ets>,
<ets>rouele</ets>, properly, a little wheel, F. <ets>rouelle</ets>
collop, slice, LL. <ets>rotella</ets> a little wheel, dim. of L.
<ets>rota</ets> a wheel. See <er>Roll</er>, and cf.
<er>Rota</er>.]</ety> <sn>1.</sn> <def>The little wheel of a spur, with
sharp points.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With sounding whip, and <qex>rowels</qex> dyed in blood.</q>
<rj><qau>Cowper.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A little flat ring or wheel on horses'
bits.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The iron <qex>rowels</qex> into frothy foam he bit.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Far.)</fld> <def>A roll of hair, silk, etc., passed
through the flesh of horses, answering to a seton in human
surgery.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rowel</ent><br/
<hw>Row"el</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Roweled</conjf> <pr>(?)</pr> or <conjf>Rowelled</conjf>; <pos>p.
pr. & vb. n.</pos> <conjf>Roweling</conjf> or
<conjf>Rowelling</conjf>.]</vmorph> <fld>(Far.)</fld> <def>To insert a
rowel, or roll of hair or silk, into (as the flesh of a horse).</def>
<rj><au>Mortimer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rowel bone</ent><br/
<hw>Row"el bone`</hw> <pr>(?)</pr>. <def>See <er>rewel bone</er>.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rowen</ent><br/
<hw>Row"en</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. E.
<ets>rough</ets>, OE. <ets>row</ets>, <ets>rowe</ets>.]</ety> [Called
also <altname>rowet</altname>, <altname>rowett</altname>,
<altname>rowings</altname>, <altname>roughings</altname>.] <sn>1.</sn>
<def>A stubble field left unplowed till late in the autumn, that it may
be cropped by cattle.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Turn your cows, that give milk, into your <qex>rowens</qex> till
snow comes.</q> <rj><qau>Mortimer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The second growth of grass in a season;
aftermath.</def> <mark>[Prov. Eng. & Local, U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rower</ent><br/
<hw>Row"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who rows with an
oar.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rowett</ent><br/
<hw>Row"ett</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Rowen</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rowlock</ent><br/
<hw>Row"lock</hw> <pr>(r<omac/"l<ocr/k <it>colloq.</it>
r<ucr/l"<ucr/k)</pr>, <pos>n.</pos> <ety>[For <ets>oarlock</ets>; AS.
<ets><amac/rloc</ets>, where the second part is akin to G.
<ets>loch</ets> a hole, E. <ets>lock</ets> a fastening. See
<er>Oar</er>, and <er>Lock</er>.]</ety> <sn>1.</sn> <fld>(Naut.)</fld>
<def>A contrivance or arrangement serving as a fulcrum for an oar in
rowing. It consists sometimes of a notch in the gunwale of a boat,
sometimes of a pair of pins between which the oar rests on the edge of
the gunwale, sometimes of a single pin passing through the oar, or of a
metal fork or stirrup pivoted in the gunwale and suporting the oar; same
as <er>oarlock</er>.</def> <mark>[Chiefly Brit.]</mark> <br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>One of the rings of masonry included in an arch
having more than one ring.</def><br/
[<source>PJC</source>]</p>

<p><ent>Rown</ent><br/
<hw>Rown</hw> <pr>(?)</pr>, <pos>v. i. & t.</pos> <def>see
<er>Roun</er>.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rowport</ent><br/
<hw>Row"port</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Naut.)</fld> <def>An
opening in the side of small vessels of war, near the surface of the
water, to facilitate rowing in calm weather.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roxburgh</ent><br/
<hw>Rox"burgh</hw> <pr>(?; Scot. <?/)</pr>, <pos>n.</pos> <ety>[From the
third duke of <etsep>Roxburgh</etsep> (Scotland), a noted book collector
who had his books so bound.]</ety> <def>A style of bookbinding in which
the back is plain leather, the sides paper or cloth, the top gilt-edged,
but the front and bottom left uncut.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roy</ent><br/
<hw>Roy</hw> <pr>(roi)</pr>, <pos>n.</pos> <ety>[F.
<ets>roi</ets>.]</ety> <def>A king.</def> <mark>[obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roy</ent><br/
<hw>Roy</hw>, <pos>a.</pos> <def>Royal.</def> <mark>[Obs.]</mark>
<rj><au>Chapman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Royal</ent><br/
<hw>Roy"al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OE. <ets>roial</ets>,
<ets>riall</ets>, <ets>real</ets>, OF. <ets>roial</ets>.
<ets>reial</ets>, F. <ets>royal</ets>, fr. L. <ets>regalis</ets>, fr.
<ets>rex</ets>, <ets>regis</ets>, king. See <er>Rich</er>, and cf.
<er>regal</er>, <er>real</er> a coin, <er>Rial</er>.]</ety> <sn>1.</sn>
<def>Kingly; pertaining to the crown or the sovereign; suitable for a
king or queen; regal; <as>as, <ex>royal</ex> power or prerogative;
<ex>royal</ex> domains; the <ex>royal</ex> family; <ex>royal</ex>
state</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Noble; generous; magnificent; princely.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>How doth that <qex>royal</qex> merchant, good Antonio?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Under the patronage of royality; holding a charter
granted by the sovereign; <as>as, the <ex>Royal</ex> Academy of Arts;
the <ex>Royal</ex> Society</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Battle royal</b></col>. <cd>See under
<er>Battle</er>.</cd> -- <col><b>Royal bay</b></col> <fld>(Bot.)</fld>,
<cd>the classic laurel (<spn>Laurus nobilis</spn>.)</cd> --
<col><b>Royal eagle</b></col>. <fld>(Zool.)</fld> <cd>See <cref>Golden
eagle</cref>, under <er>Golden</er>.</cd> -- <col><b>Royal
fern</b></col> <fld>(Bot.)</fld>, <cd>the handsome fern <spn>Osmunda
regalis</spn>. See <er>Osmund</er>.</cd> -- <col><b>Royal mast</b></col>
<fld>(Naut.)</fld>, <cd>the mast next above the topgallant mast and
usually the highest on a square-rigged vessel. The <xex>royal yard</xex>
and <xex>royal sail</xex> are attached to the <xex>royal
mast</xex>.</cd> -- <col><b>Royal metal</b></col>, <cd>an old name for
gold.</cd> -- <col><b>Royal palm</b></col> <fld>(Bot.)</fld>, <cd>a
magnificent West Indian palm tree (<spn>Oreodoxa regia</spn>), lately
discovered also in Florida.</cd> -- <col><b>Royal pheasant</b></col>.
<cd>See <er>Curassow</er>.</cd> -- <col><b>Royal purple</b></col>,
<cd>an intense violet color, verging toward blue.</cd> -- <col><b>Royal
tern</b></col> <fld>(Zool.)</fld>, <cd>a large, crested American tern
(<spn>Sterna maxima</spn>).</cd> -- <col><b>Royal tiger</b></col>.
<fld>(Zool.)</fld> <cd>See <er>Tiger</er>.</cd> -- <col><b>Royal
touch</b></col>, <cd>the touching of a diseased person by the hand of a
king, with the view of restoring to health; -- formerly extensively
practiced, particularly for the scrofula, or king's evil.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Kingly; regal; monarchical; imperial; kinglike;
princely; august; majestic; superb; splendid; illustrious; noble;
magnanimous.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Royal</ent><br/
<hw>Roy"al</hw>, <pos>n.</pos> <sn>1.</sn> <def>Printing and writing
papers of particular sizes. See under <er>paper</er>,
<pos>n.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Naut.)</fld> <def>A small sail immediately above
the topgallant sail.</def> <rj><au>Totten.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <def>One of the upper or distal
branches of an antler, as the third and fourth tynes of the antlers of a
stag.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Gun.)</fld> <def>A small mortar.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Mil.)</fld> <def>One of the soldiers of the first
regiment of foot of the British army, formerly called the
<xex>Royals</xex>, and supposed to be the oldest regular corps in
Europe; -- now called the <xex>Royal Scots</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>An old English coin. See <er>Rial</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Auction Bridge)</fld> <def>A royal spade.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Royalet</ent><br/
<hw>Roy"al*et</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A petty or powerless
king.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>there were at this time two other <qex>royalets</qex>, as only
kings by his leave.</q> <rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Royalism</ent><br/
<hw>Roy"al*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>royalisme</ets>.]</ety> <def>the principles or conduct of
royalists.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Royalist</ent><br/
<hw>Roy"al*ist</hw>, <pos>n.</pos> <ety>[Cf. F.
<ets>royaliste</ets>.]</ety> <def>An adherent of a king (as of Charles
I. in England, or of the Bourbons in france); one attached to
monarchical government.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Where Ca'ndish fought, the <qex>Royalists</qex> prevailed.</q>
<rj><qau>Waller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Royalization</ent><br/
<hw>Roy`al*i*za"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
making loyal to a king.</def> <mark>[R.]</mark>
<rj><au>Saintsbury.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Royalize</ent><br/
<hw>Roy"al*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>to make
royal.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Royally</ent><br/
<hw>Roy"al*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a royal or
kingly manner; like a king; as becomes a king.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His body shall be <qex>royally</qex> interred.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Royal spade</ent><br/
<hw>Royal spade</hw>. <fld>(Auction Bridge)</fld> <def>A spade when
spades are trumps under the condition that every trick over six taken by
the successful bidder has a score value of 9; -- usually in
<pluf>pl.</pluf></def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Royalty</ent><br/
<hw>Roy"al*ty</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Royalties</plw> <pr>(#)</pr>.</plu> <ety>[OF.
<ets>roialt<eacute/</ets>, <ets>royault<eacute/</ets>, F.
<ets>royaut<eacute/</ets>. See <er>Royal</er>, and cf.
<er>Regality</er>.]</ety> <sn>1.</sn> <def>The state of being royal; the
condition or quality of a royal person; kingship; kingly office;
sovereignty.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Royalty</qex> by birth was the sweetest way of majesty.</q>
<rj><qau>Holyday.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The person of a king or sovereign; majesty; <as>as,
in the presence of <ex>royalty</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>For thus his <qex>royalty</qex> doth speak.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>An emblem of royalty; -- usually in the plural,
meaning <xex>regalia</xex>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Wherefore do I assume<br/
These <qex>royalties</qex>, and not refuse to reign?</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Kingliness; spirit of regal authority.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In his <qex>royalty</qex> of nature<br/
Reigns that which would be fear'd.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Domain; province; sphere.</def> <rj><au>Sir W.
Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>That which is due to a sovereign, as a seigniorage
on gold and silver coined at the mint, metals taken from mines, etc.;
the tax exacted in lieu of such share; imperiality.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>A share of the product or profit (as of a mine,
forest, etc.), reserved by the owner for permitting another to use the
property.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>Hence <fld>(Com.)</fld>, a duty paid by a
manufacturer to the owner of a patent or a copyright at a certain rate
for each article manufactured; or, a percentage paid to the owner of an
article by one who hires the use of it.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Royne</ent><br/
<hw>Royne</hw> <pr>(roin)</pr>, <pos>v. t.</pos> <ety>[F.
<ets>rogner</ets>, OF. <ets>rooignier</ets>, to clip, pare, scare, fr.
L. <ets>rotundus</ets> round See <er>Rotund</er>.]</ety> <def>To bite;
to gnaw.</def> <altsp>[Written also <asp>roin</asp>.]</altsp>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roynish</ent><br/
<hw>Royn"ish</hw>, <pos>a.</pos> <ety>[F. <ets>rogneux</ets>, from
<ets>rogne</ets> scab, mange, itch.]</ety> <def>Mangy; scabby; hence,
mean; paltry; troublesome.</def> <altsp>[Written also
<asp>roinish</asp>.]</altsp> <mark>[Obs.]</mark> <ldquo/The
<xex>roynish</xex> clown.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roysterer</ent><br/
<ent>Royster</ent><br/
<mhw>{ <hw>Roys"ter</hw> <pr>(?)</pr>, <hw>Roys"ter*er</hw> <pr>(?)</pr>
}</mhw>, <pos>n.</pos> <def>same as <er>Roister</er>,
<er>Roisterer</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Royston crow</ent><br/
<hw>Roys"ton crow`</hw> <pr>(?)</pr>. <ety>[So called from
<ets>Royston</ets>, a town in England.]</ety> <fld>(Zool.)</fld>
<def>See <cref>Hooded crow</cref>, under <er>Hooded</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roytelet</ent><br/
<hw>Roy"te*let</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>roitelet</ets>, dim. of <ets>roi</ets> king.]</ety> <def>A little
king.</def> <mark>[Archaic]</mark> <rj><au>Heylin.
Bancroft.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Roytish</ent><br/
<hw>Roy"tish</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Prob. for
<ets>riotish</ets>, from <ets>riot</ets>, like Scot. <ets>roytous</ets>
for <ets>riotous</ets>.]</ety> <def>Wild; irregular.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rub</ent><br/
<hw>Rub</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Rubbed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Rubbing</conjf>.]</vmorph> <ety>[Probably of Celtic origin; cf.
W. <ets>rhwbiaw</ets>, gael. <ets>rub</ets>.]</ety> <sn>1.</sn> <def>To
subject (a body) to the action of something moving over its surface with
pressure and friction, especially to the action of something moving back
and forth; <as>as, to <ex>rub</ex> the flesh with the hand; to
<ex>rub</ex> wood with sandpaper</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It shall be expedient, after that body is cleaned, to
<qex>rub</qex> the body with a coarse linen cloth.</q> <rj><qau>Sir T.
Elyot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To move over the surface of (a body) with pressure
and friction; to graze; to chafe; <as>as, the boat <ex>rubs</ex> the
ground</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To cause (a body) to move with pressure and friction
along a surface; <as>as, to <ex>rub</ex> the hand over the
body</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Two bones <qex>rubbed</qex> hard against one another.</q>
<rj><qau>Arbuthnot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To spread a substance thinly over; to
smear.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The smoothed plank, . . .<br/
New <qex>rubbed</qex> with balm.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To scour; to burnish; to polish; to brighten; to
cleanse; -- often with <xex>up</xex> or <xex>over</xex>; <as>as, to
<ex>rub</ex> up silver</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The whole business of our redemption is to <qex>rub</qex> over the
defaced copy of the creation.</q> <rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To hinder; to cross; to thwart.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>'T is the duke's pleasure,<br/
Whose disposition, all the world well knows,<br/
Will not be <qex>rubbed</qex> nor stopped.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To rub down</b></col>. <sd>(a)</sd> <cd>To clean by
rubbing; to comb or curry; as, <xex>to down</xex> a horse</cd>.
<sd>(b)</sd> <cd>To reduce or remove by rubbing; as, <xex>to rub
down</xex> the rough points.</cd> -- <col><b>To rub off</b></col>,
<cd>to clean anything by rubbing; to separate by friction; <as>as,
<ex>to rub off</ex> rust</as>.</cd> -- <col><b>To rub out</b></col>,
<cd>to remove or separate by friction; to erase; to obliterate; <as>as,
<ex>to rub out</ex> a mark or letter; <ex>to rub out</ex> a
stain</as>.</cd> -- <col><b>To rub up</b></col>. <sd>(a)</sd> <cd>To
burnish; to polish; to clean</cd>. <sd>(b)</sd> <cd>To excite; to
awaken; to rouse to action; <as>as, <ex>to rub up</ex> the
memory</as>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rub</ent><br/
<hw>Rub</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To move along the
surface of a body with pressure; to grate; <as>as, a wheel <ex>rubs</ex>
against the gatepost</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To fret; to chafe; <as>as, to <ex>rub</ex> upon a
sore</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To move or pass with difficulty; <as>as, to
<ex>rub</ex> through woods, as huntsmen; to <ex>rub</ex> through the
world</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>To rub along</b></col> or
<col><b>on</b></col></mcol>, <cd>to go on with difficulty; <as>as, they
manage, with strict economy, <ex>to rub along</ex></as>.</cd>
<mark>[Colloq.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rub</ent><br/
<hw>Rub</hw>, <pos>n.</pos> <ety>[Cf. W. <ets>rhwb</ets>. See Rub,
v,t,]</ety> <sn>1.</sn> <def>The act of rubbing; friction.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which rubs; that which tends to hinder or
obstruct motion or progress; hindrance; obstruction, an impediment;
especially, a difficulty or obstruction hard to overcome; a
pinch.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Every <qex>rub</qex> is smoothed on our way.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To sleep, perchance to dream; ay, there's the <qex>rub</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Upon this <qex>rub</qex>, the English ambassadors thought fit to
demur.</q> <rj><qau>Hayward.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>One knows not, certainly, what other <qex>rubs</qex> might have
been ordained for us by a wise Providence.</q> <rj><qau>W.
Besant.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Inequality of surface, as of the ground in the game
of bowls; unevenness.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Something grating to the feelings; sarcasm; joke;
<as>as, a hard <ex>rub</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Imperfection; failing; fault.</def>
<mark>[Obs.]</mark> <rj><au>Beau. & Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>A chance.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Flight shall leave no Greek a <qex>rub</qex>.</q>
<rj><qau>Chapman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>A stone, commonly flat, used to sharpen cutting
tools; a whetstone; -- called also
<altname>rubstone</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Rub iron</b></col>, <cd>an iron guard on a wagon body,
against which a wheel rubs when cramped too much.</cd> -- <col><b>Rub of
the green</b></col> <fld>(Golf)</fld>, <cd>anything happening to a ball
in motion, such as its being deflected or stopped by any agency outside
the match, or by the fore caddie.</cd></cs><br/
[<source>1913 Webster</source> + <source>Webster 1913 Suppl.</source>]</p>

<p><ent>Ruba-dub</ent><br/
<hw>Rub"a-dub</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The sound of a drum
when continuously beaten; hence, a clamorous, repeated sound; a
clatter.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>rubadub</qex> of the abolition presses.</q> <rj><qau>D.
Webster.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rubaiyat</ent><br/
\'d8<hw>Ru*bai*yat"</hw> <pr>(?)</pr>, <pos>n. pl.</pos>;
<sing><it>sing.</it> <singw>Rubai</singw> <pr>(<?/)</pr></sing>.
<ety>[Ar. <ets>rub<amac/'iy<amac/h</ets> quatrian, pl. of
<ets>rub<amac/'iy</ets> having four radicals, fr. <ets>rub<amac/'</ets>
four.]</ety> <def>Quatrians; <as>as, the <ex>Rubaiyat</ex> of
<person>Omar Khayyam</person></as>. Sometimes in <pluf>pl.</pluf>
construed as <pos>sing.</pos>, a poem in such stanzas.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><-- p. 1257 --></p>

<p><ent>Rubato</ent><br/
\'d8<hw>Ru*ba"to</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[It.]</ety>
<def>Robbed; borrowed.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs>\'d8<col><b>Temple rubato</b></col>. <ety>[It.]</ety>
<fld>(Mus.)</fld> <cd>Borrowed time; -- a term applied to a style of
performance in which some tones are held longer than their legitimate
time, while others are proportionally curtailed.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rubbage</ent><br/
<hw>Rub"bage</hw> <pr>(?; 48)</pr>, <pos>n.</pos> <def>Rubbish.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rubber</ent><br/
<hw>Rub"ber</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who,
or that which, rubs.</def> Specifically: <sd>(a)</sd> <def>An instrument
or thing used in rubbing, polishing, or cleaning.</def> <sd>(b)</sd>
<def>A coarse file, or the rough part of a file.</def> <sd>(c)</sd>
<def>A whetstone; a rubstone.</def> <sd>(d)</sd> <def>An eraser, usually
made of caoutchouc or a synthetic rubber[4].</def> <sd>(e)</sd> <def>The
cushion of an electrical machine.</def> <sd>(f)</sd> <def>One who
performs massage, especially in a Turkish bath.</def> <sd>(g)</sd>
<def>Something that chafes or annoys; hence, something that grates on
the feelings; a sarcasm; a rub.</def> <rj><au>Thackeray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>In some games, as bridge or whist, the odd game, as
the third or the fifth, which decides the winner when there is a tie
between the players; <as>as, to play the <ex>rubber</ex></as>; also, a
contest determined by the winning of two out of three games; <as>as, to
play a <ex>rubber</ex> of whist</as>.</def> <au>Beaconsfield.</au>
<ldquo/A <xex>rubber</xex> of cribbage.<rdquo/ <au>Dickens.</au><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>India rubber; caoutchouc; gum elastic; -- also
called <altname>natural rubber</altname>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>4.</sn> <def>Any substance, whether natural or synthetic,
resembling India rubber with respect to its elasticity[1].</def><br/
[<source>PJC</source>]</p>

<p><sn>5.</sn> <def>A low-cut overshoe made of natural or synthetic
rubber[4], serving to keep the feet and shoes dry when walking in the
rain or on a wet surface; -- usually used in the plural.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>A <er>condom</er>.</def> <mark>[Slang]</mark><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Antimony rubber</b></col>, <cd>an elastic durable variety
of vulcanized caoutchouc of a red color. It contains antimony sulphide
as an important constituent.</cd> -- <col><b>Hard rubber</b></col>,
<cd>a kind of vulcanized caoutchouc which nearly resembles horn in
texture, rigidity, etc.</cd> -- <col><b>India rubber</b></col>,
<cd>caoutchouc. See <er>Caoutchouc</er>.</cd> -- <col><b>Rubber
cloth</b></col>, <cd>cloth covered with caoutchouc for excluding water
or moisture.</cd> -- <col><b>Rubber dam</b></col>
<fld>(Dentistry)</fld>, <cd>a shield of thin sheet rubber clasped around
a tooth to exclude saliva from the tooth.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>rubber band</ent><br/
<hw>rub"ber band"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A closed loop of
rubber usually having a thin rectangular cross-section; also called
<altname>elastic band</altname>; -- it varies in length from the
circumference of a finger to several inches, and is usually used to hold
several objects together temporarily, by the tension exerted when the
band is stretched and fitted around the objects to be held; <as>as, to
hold a pack of cards together with a <er>rubber
band</er></as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Rubberize</ent><br/
<hw>Rub"ber*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To coat or
impregnate with rubber or a rubber solution or preparation, as
silk.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Rubbidge</ent><br/
<hw>Rub"bidge</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Rubbish.</def>
<mark>[Obs.]</mark> <rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rubbing</ent><br/
<hw>Rub"bing</hw>, <def><pos>a. & n.</pos> from <er>Rub</er>,
<pos>v.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rubbish</ent><br/
<hw>Rub"bish</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>robows</ets>, <ets>robeux</ets>, rubble, originally an Old French
plural from an assumed dim. of <ets>robe</ets>, probably in the sense of
trash; cf. It. <ets>robaccia</ets> trash, <ets>roba</ets> stuff, goods,
wares, robe. Thus, etymologically <ets>rubbish</ets> is the pl. of
<ets>rubble</ets>. See <er>Robe</er>, and cf. <er>Rubble</er>.]</ety>
<def>Waste or rejected matter; anything worthless; valueless stuff;
trash; especially, fragments of building materials or fallen buildings;
ruins; d<eacute/bris.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>What <qex>rubbish</qex> and what offal!</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>he saw the town's one half in <qex>rubbish</qex> lie.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Rubbish pulley</b></col>. <cd>See <cref>Gin block</cref>,
under <er>Gin</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rubbish</ent><br/
<hw>Rub"bish</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining to
rubbish; of the quality of rubbish; trashy.</def> <rj><au>De
Quincey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rubble</ent><br/
<hw>Rub"ble</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From an assumed Old
French dim. of <ets>robe</ets> See <er>Rubbish</er>.]</ety> <sn>1.</sn>
<def>Water-worn or rough broken stones; broken bricks, etc., used in
coarse masonry, or to fill up between the facing courses of
walls.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Inside [the wall] there was <qex>rubble</qex> or mortar.</q>
<rj><qau>Jowett (Thucyd.).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Rough stone as it comes from the quarry; also, a
quarryman's term for the upper fragmentary and decomposed portion of a
mass of stone; brash.</def> <rj><au>Brande & C.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Geol.)</fld> <def>A mass or stratum of fragments or
rock lying under the alluvium, and derived from the neighboring
rock.</def> <rj><au>Lyell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <pluf>pl.</pluf> <def>The whole of the bran of wheat
before it is sorted into pollard, bran, etc.</def> <mark>[Prov.
Eng.]</mark> <rj><au>Simmonds.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Coursed rubble</b></col>, <cd>rubble masonry in which
courses are formed by leveling off the work at certain
heights.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rubblestone</ent><br/
<hw>Rub"ble*stone`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Rubble</er>, 1 and 2.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rubblework</ent><br/
<hw>Rub"ble*work`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Masonry
constructed of unsquared stones that are irregular in size and
shape.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rubbly</ent><br/
<hw>Rub"bly</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Relating to, or
containing, rubble.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rubedinous</ent><br/
<hw>Ru*bed"i*nous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>rubedo</ets> redness, fr. <ets>rubere</ets> to be red.]</ety>
<def>Reddish.</def> <mark>[R.]</mark> <rj><au>M. Stuart.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rubefacient</ent><br/
<hw>Ru`be*fa"cient</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>rubefaciens</ets>, p. pr. of <ets>rubefacere</ets> to make red;
<ets>rubere</ets> to be red + <ets>facere</ets> to make.]</ety>
<def>Making red.</def> -- <def2><pos>n.</pos> <fld>(Med.)</fld> <def>An
external application which produces redness of the
skin.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rubefaction</ent><br/
<hw>Ru`be*fac"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act or
process of making red.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>rubelet</ent><br/
<hw>ru"be*let</hw> <pr>(r<udd/"b<esl/*l<ecr/t)</pr>, <pos>n.</pos>
<def>A little ruby.</def> <rj><au>Herrick.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>rubella</ent><br/
\'d8<hw>ru*bel"la</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. L.
<ets>rubellus</ets> reddish.]</ety> <fld>(Med.)</fld> <def>An acute but
mild viral infection characterized by a dusky red cutaneous eruption
resembling that of measles, but attended by only mild respiratory
problems or fever; -- called also <altname>German measles</altname>. The
infective virus is called <causedby>Rubella virus</causedby>, or
<gen>Rubivirus</gen>. If contracted by a woman during the first several
months of pregnancy, <ex>rubella</ex> may cause serious abnormalities in
the fetus.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>rubella virus</ent><br/
<hw>ru*bel"la vi"rus</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The virus
that causes <causes>rubella</causes>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Rubelle</ent><br/
<hw>Ru*belle"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>rubellus</ets> reddish.]</ety> <def>A red color used in
enameling.</def> <rj><au>Weale.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rubellite</ent><br/
<hw>Ru"bel*lite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>rubellus</ets> reddish, dim. of <ets>ruber</ets> red.]</ety>
<fld>(Min.)</fld> <def>A variety of tourmaline varying in color from a
pale rose to a deep ruby, and containing lithium.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rubeola</ent><br/
\'d8<hw>Ru*be"o*la</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. L.
<ets>ruber</ets> red.]</ety> <fld>(Med.)</fld> <sd>(a)</sd> <def>the
measles.</def> <sd>(b)</sd> <def>Rubella.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruberythrinic</ent><br/
<hw>Ru`ber*y*thrin"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>ruber</ets> red + <ets>erythrin</ets>.]</ety> <fld>(Chem.)</fld>
<def>Pertaining to, or designating, an acid extracted from madder root.
It is a yellow crystalline substance from which alizarin is
obtained.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rubescence</ent><br/
<hw>Ru*bes"cence</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The quality or
state of being rubescent; a reddening; a flush.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rubescent</ent><br/
<hw>Ru*bes"cent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>rubescens</ets>, <ets>-entis</ets>, p. pr. of <ets>rubescere</ets>
to grow red, v. incho from <ets>rubere</ets> to be red: cf. F.
<ets>rubescent</ets>. See <er>Ruby</er>.]</ety> <def>Growing or becoming
red; tending to redness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rubiaceous</ent><br/
<hw>Ru`bi*a"ceous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>rubia</ets> madder, fr. <ets>rubeus</ets> red.]</ety>
<fld>(Bot.)</fld> <def>Of or pertaining to a very large natural order of
plants (<spn>Rubiaceae</spn>) named after the madder (<spn>Rubia
tinctoria</spn>), and including about three hundred and seventy genera
and over four thousand species. Among them are the coffee tree, the
trees yielding peruvian bark and quinine, the madder, the quaker ladies,
and the trees bearing the edible fruits called genipap and Sierre Leone
peach, besides many plants noted for the beauty or the fragrance of
their blossoms.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rubiacin</ent><br/
<hw>Ru"bi*a*cin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>rubia</ets> madder, fr. <ets>rubeus</ets> red.]</ety>
<fld>(Chem)</fld> <def>A substance found in madder root, and probably
identical with ruberythrinic acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rubian</ent><br/
<hw>Ru"bi*an</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>rubia</ets>
madder, fr. <ets>rubeus</ets> red.]</ety> <fld>(Chem.)</fld> <def>One of
several color-producing glycosides found in madder root.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rubianic</ent><br/
<hw>Ru`bi*an"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Chem.)</fld>
<def>pertaining to, or derived from, rubian; specifically, designating
an acid called also <altname>ruberythrinic</altname> acid.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rubible</ent><br/
<hw>Ru"bi*ble</hw> <pr>(r<udd/"b<icr/*b'l)</pr>, <pos>n.</pos> <def>A
ribble.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rubican</ent><br/
<hw>Ru"bi*can</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F.]</ety>
<def>Colored a prevailing red, bay, or black, with flecks of white or
gray especially on the flanks; -- said of horses.</def>
<rj><au>Smart.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rubicelle</ent><br/
<hw>Ru"bi*celle</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>rubacelle</ets>, <ets>rubicelle</ets>, fr. L. <ets>rubeus</ets>
red, reddish.]</ety> <fld>(Min.)</fld> <def>A variety of ruby of a
yellowish red color, from Brazil.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rubicon</ent><br/
<hw>Ru"bi*con</hw> <pr>(?)</pr>, <pos>prop. n.</pos> <fld>(Anc.
geog.)</fld> <def>A small river which separated Italy from Cisalpine
Gaul, the province alloted to <person>Julius Caesar</person>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ By leading an army across this river, contrary to the
prohibition of the civil government at Rome, <persfn>Caesar</persfn>
precipitated the civil war which resulted in the death of
P<persfn>ompey</persfn> and the overthrow of the senate; hence, the
phrase <col><b>to pass the Rubicon</b></col> or <col><b>cross the
Rubicon</b></col> signifies to take the decisive step by which one is
committed to a hazardous enterprise from which there is no
retreat.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rubicund</ent><br/
<hw>Ru"bi*cund</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>rubicundus</ets>, fr. <ets>rubere</ets> to be red, akin to
<ets>ruber</ets> red. See <er>Red</er>.]</ety> <def>Inclining to
redness; ruddy; red.</def> <ldquo/His <xex>rubicund</xex> face.<rdquo/
<rj><au>Longfellow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rubicundity</ent><br/
<hw>Ru`bi*cun"di*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL.
<ets>rubicunditas</ets>.]</ety> <def>The quality or state of being
rubicund; ruddiness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To parade your <qex>rubicundity</qex> and gray hairs.</q>
<rj><qau>Walpole.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rubidic</ent><br/
<hw>Ru*bid"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Chem.)</fld>
<def>Of or pertaining to rubidium; containing rubidium.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rubidine</ent><br/
<hw>Ru"bi*dine</hw> <pr>(? <or/ ?)</pr>, <pos>n.</pos>
<fld>(Chem.)</fld> <def>A nitrogenous base homologous with pyridine,
obtained from coal tar as an oily liquid, <chform>C11H17N</chform>;
also, any one of the group od metameric compounds of which rubidine is
the type.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rubidium</ent><br/
<hw>Ru*bid"i*um</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. L.
<ets>rubidus</ets> red, fr. <ets>rubere</ets> to be red. So called from
two <ets>dark red</ets> spectroscopic lines by means of which it was
discovered in the lepidolite from Rozena, Moravia. See
<er>Rubicund</er>.]</ety> <fld>(Chem.)</fld> <def>A rare metallic
element of the alkali metal series, atomic number 37. It occurs quite
widely, but in small quantities, and always combined. It is isolated as
a soft yellowish white metal, analogous to potassium in most of its
properties. Symbol Rb. Atomic weight, 85.48.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rubific</ent><br/
<hw>Ru*bif"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>ruber</ets>
red + <ets>facere</ets> to make.]</ety> <def>Making red; <as>as,
<ex>rubific</ex> rays</as>.</def> <rj><au>Grew.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rubification</ent><br/
<hw>Ru`bi*fi*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>rubification</ets>.]</ety> <def>The act of making red.</def>
<rj><au>Howell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rubiform</ent><br/
<hw>Ru"bi*form</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>ruber</ets> red + <ets>-form</ets>.]</ety> <def>Having the nature
or quality of red; <as>as, the <ex>rubiform</ex> rays of the
sun</as>.</def> <mark>[R.]</mark> <rj><au>Sir I. newton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rubify</ent><br/
<hw>Ru"bi*fy</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Cf. F.
<ets>rub<eacute/fier</ets>. See <er>Rubific</er>.]</ety> <def>To
redden.</def> <mark>[R.]</mark> <ldquo/Waters
<xex>rubifying</xex>.<rdquo/ <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rubiginous</ent><br/
<ent>Rubiginose</ent><br/
<mhw>{ <hw>Ru*big"i*nose`</hw> <pr>(?)</pr>, <hw>Ru*big"i*nous</hw>
<pr>(?)</pr> }</mhw>, <pos>a.</pos> <ety>[L. <ets>rubiginosus</ets>, fr.
<ets>rubigo</ets>, <ets>robigo</ets>, rust: cf. F.
<ets>rubigineux</ets>.]</ety> <fld>(Bot.)</fld> <def>Having the
appearance or color of iron rust; rusty-looking.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rubigo</ent><br/
\'d8<hw>Ru*bi"go</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>rubigo</ets>, <ets>robigo</ets>, rust of metals, rust,
blight.]</ety> <fld>(bot.)</fld> <def>same as <er>Rust</er>,
<pos>n.</pos>, 2.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rubin</ent><br/
<hw>Ru"bin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. LL.
<ets>rubinus</ets>, It. <ets>rubino</ets>. See <er>Ruby</er>.]</ety>
<def>A ruby.</def> <mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rubious</ent><br/
<hw>Ru"bi*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>rubeus</ets>, fr. <ets>rubere</ets> to be red. See
<er>Rouge</er>.]</ety> <def>Red; ruddy.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rubiretin</ent><br/
<hw>Ru`bi*re"tin</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Rubi</ets>an + Gr. <?/ resin.]</ety> <fld>(Chem.)</fld>
<def>One of the red dye products extracted from madder root, and
probably identical with ruberythrinic acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruble</ent><br/
<hw>Ru"ble</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Russ.
<ets>ruble</ets>.]</ety> <def>The unit of monetary value in Russia. <--
and, 1917-1992, in the Soviet Union --> It is divided into 100 copecks,
and in the gold coin of the realm (as in the five and ten ruble pieces)
is worth about 77 cents. The silver ruble is a coin worth about 60
cents.</def> <altsp>[Written also <asp>rouble</asp>.]</altsp><-- After
the severe inflation of 1992-1996, the ruble is now exchanged at 5000
rubles to the dollar. The Kopeck is no longer minted or used in trade,
the smallest coin (1996) being the ruble. --><br/
[<source>1913 Webster</source>]</p>

<-- ##?? rubout -->

<p><ent>Rubric</ent><br/
<hw>Ru"bric</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>rubriche</ets>, OF. <ets>rubriche</ets>, F. <ets>rubrique</ets> ( cf. it. <ets>rubrica</ets>), fr. L. <ets>rubrica</ets> red earth for coloring, red chalk, the title of a law (because written in red), fr. <ets>ruber</ets> red. See <er>red</er>.]</ety> <def>That part of any work in the early manuscripts and typography which was colored red, to distinguish it from other portions.</def> Hence, specifically: <sd>(a)</sd> <def>A titlepage, or part of it, especially that giving the date and place of printing; also, the initial letters, etc., when printed in red.</def> <sd>(b)</sd> <fld>(Law books)</fld> <def>The title of a statute; -- so called as being anciently written in red letters.</def> <au>Bell.</au> <sd>(c)</sd> <fld>(Liturgies)</fld> <def>The directions and rules for the conduct of service, formerly written or printed in red; hence, also, an ecclesiastical or episcopal injunction; -- usually in the plural.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>All the clergy in England solemnly pledge themselves to observe the <qex>rubrics</qex>.</q> <rj><qau>Hook.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(d)</sd> <def>Hence, that which is established or settled, as by authority; a thing definitely settled or fixed.</def>  <rj><au>Cowper.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Nay, as a duty, it had no place or rubric in human conceptions before Christianity.</q> <rj><qau>De Quincey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- category, class, classification
  under the rubric of, (See def. (b)) in the category of --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rubric</ent><br/
<hw>Ru"bric</hw>, <pos>v. t.</pos> <def>To adorn ith red; to redden; to
rubricate.</def> <mark>[R.]</mark> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rubrical</ent><br/
<ent>Rubric</ent><br/
<mhw>{ <hw>Ru"bric</hw> <pr>(?)</pr>, <hw>Ru"bric*al</hw> <pr>(?)</pr>
}</mhw>, <pos>a.</pos> <sn>1.</sn> <def>Colored in, or marked with, red;
placed in rubrics.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>What though my name stood <qex>rubric</qex> on the walls<br/
Or plaistered posts, with claps, in capitals?</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of or pertaining to the rubric or rubrics.</def>
<ldquo/<xex>Rubrical</xex> eccentricities.<rdquo/ <rj><au>C.
Kingsley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rubricate</ent><br/
<hw>Ru"bri*cate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>rubricatus</ets> p. p. of <ets>rubricare</ets> to color red. See
<er>Rubric</er>, <pos>n.</pos>]</ety> <def>Marked with red.</def>
<rj><au>Sp<?/lmman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rubricate</ent><br/
<hw>Ru"bri*cate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To mark or
distinguished with red; to arrange as in a rubric; to establish in a
settled and unchangeable form.</def> <rj><au>Foxe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A system . . . according to which the thoughts of men were to be
classed and <qex>rubricated</qex> forever after.</q>
<rj><qau>Hare.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rubricist</ent><br/
<ent>Rubrician</ent><br/
<mhw>{ <hw>Ru*bri"cian</hw> <pr>(?)</pr>, <hw>Ru"bri*cist</hw>
<pr>(?)</pr> }</mhw>, <pos>n.</pos> <def>One skilled in, or tenaciously
adhering to, the rubric or rubrics.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rubricity</ent><br/
<hw>Ru*bric"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Redness.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rubstone</ent><br/
<hw>Rub"stone`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A stone for
scouring or rubbing; a whetstone; a rub.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rubus</ent><br/
\'d8<hw>Ru"bus</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.]</ety>
<fld>(Bot.)</fld> <def>A genus of rosaceous plants, including the
raspberry and blackberry.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruby</ent><br/
<hw>Ru"by</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Rubies</plw> <pr>(#)</pr>.</plu> <ety>[F. <ets>rubis</ets> (cf. Pr.
<ets>robi</ets>), LL. <ets>rubinus</ets>, <ets>robinus</ets>, fr. L.
<ets>rubeus</ets> red, reddish, akin to <ets>ruber</ets>. See
<er>Rouge</er>, <er>red</er>.]</ety> <sn>1.</sn> <fld>(Min.)</fld>
<def>A precious stone of a carmine red color, sometimes verging to
violet, or intermediate between carmine and hyacinth red. It is a red
crystallized variety of corundum.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Besides the true or <xex>Oriental ruby</xex> above
defined, there are the <xex>balas ruby</xex>, or <xex>ruby spinel</xex>,
a red variety of spinel, and the <xex>rock</xex> ruby, a red variety of
garnet.</note> <-- artificially produced variants are used in jewelry
and in lasers. --><br/
[<source>1913 Webster</source>]</p>

<p><q>Of <qex>rubies</qex>, sapphires, and pearles white.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The color of a ruby; carmine red; a red
tint.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The natural <qex>ruby</qex> of your cheeks.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which has the color of the ruby, as red wine.
Hence, a red blain or carbuncle.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Print.)</fld> <def>See <er>Agate</er>,
<pos>n.</pos>, 2.</def> <mark>[Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Zool.)</fld> <def>Any species of South American
humming birds of the genus <gen>Clytolaema</gen>. The males have a
ruby-colored throat or breast.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Ruby of arsenic</b></col>, <col><b>Ruby of
sulphur</b></col></mcol> <fld>(Chem.)</fld>, <cd>a glassy substance of a
red color and a variable composition, but always consisting chiefly of
the disulphide of arsenic; -- called also <altname>ruby
sulphur</altname>.</cd> -- <col><b>Ruby of zinc</b></col>
<fld>(Min.)</fld>, <cd>zinc sulphide; the mineral zinc blende or
sphalerite.</cd> -- <col><b>Ruby silver</b></col> <fld>(Min.)</fld>,
<cd>red silver. See under <er>Red</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruby</ent><br/
<hw>Ru"by</hw>, <pos>a.</pos> <def>Ruby-colored; red; <as>as,
<ex>ruby</ex> lips</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruby</ent><br/
<hw>Ru"by</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Rubied</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Rubying</conjf>.]</vmorph> <def>To make red; to redden.</def>
<mark>[R.]</mark> <rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rubytail</ent><br/
<hw>Ru"by*tail`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>A European gold wasp (<spn>Chrysis ignita</spn>) which has the
under side of the abdomen bright red, and the other parts deep bluish
green with a metallic luster. The larva is parasitic in the nests of
other wasps and of bees.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruby-tailed</ent><br/
<hw>Ru"by-tailed`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having the tail,
or lower part of the body, bright red.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rubythroat</ent><br/
<hw>Ru"by*throat`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>Any one of numerous species of humming birds belonging to
<spn>Trochilus</spn>, <spn>Calypte</spn>, <spn>Stellula</spn>, and
allies, in which the male has on the throat a brilliant patch of red
feathers having metallic reflections; esp., the common humming bird of
the Eastern United States (<spn>Trochilus colubris</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rubywood</ent><br/
<hw>Ru"by*wood`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>red sandalwood.
See under <er>Sandalwood</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rucervine</ent><br/
<hw>Ru*cer"vine</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[NL.
<ets>Rucervus</ets>, the genus, fr. NL. <ets>Ru</ets>sa a certain genus
of deer (Malay <ets>r<?/sa</ets> deer) + <ets>Cervus</ets>.]</ety>
<fld>(Zool.)</fld> <def>Of, like, or pertaining to, a deer of the genus
<gen>Rucervus</gen>, which includes the swamp deer of India.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruche</ent><br/
<hw>Ruche</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>ruche</ets>
ruche, beehive, OF. <ets>rusche</ets> a beehive, which was formerly made
of the bark of trees; cf. W. <ets>rhisg</ets>, <ets>rhisgl</ets>, bark,
gael. <ets>rusg</ets> bark, rind.]</ety> <sn>1.</sn> <def>A plaited,
quilled, or goffered strip of lace, net, ribbon, or other material, --
used in place of collars or cuffs, and as a trimming for women's dresses
and bonnets.</def> <altsp>[Written also <asp>rouche</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A pile of arched tiles, used to catch and retain
oyster spawn.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruching</ent><br/
<hw>Ruch"ing</hw>, <pos>n.</pos> <def>A ruche, or ruches
collectively.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruck</ent><br/
<hw>Ruck</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A roc.</def> <mark>[Obs.
or prov. Eng.]</mark> <rj><au>Drayton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruck</ent><br/
<hw>Ruck</hw>, <pos>v. t. & i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Rucked</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Rucking</conjf>.]</vmorph> <ety>[Icel <ets>hrukkast</ets> to
wrinkle, <ets>hrukka</ets> wrinkle, fold.]</ety> <def>To draw into
wrinkles or unsightly folds; to crease; <as>as, to <ex>ruck</ex> up a
carpet</as>.</def> <rj><au>Smart.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruck</ent><br/
<hw>Ruck</hw>, <pos>n.</pos> <ety>[Icel. <ets>hrukka</ets>. Cf.
<er>Ruck</er>, <pos>v. t.</pos>]</ety> <def>A wrinkle or crease in a
piece of cloth, or in needlework.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruck</ent><br/
<hw>Ruck</hw>, <pos>v. i.</pos> <ety>[Cf. Dan. <ets>ruge</ets> to brood,
to hatch.]</ety> <def>To cower; to huddle together; to squat; to sit, as
a hen on eggs.</def> <mark>[Obs. or Prov. Eng.]</mark> <rj><au>Gower.
South.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The sheep that <qex>rouketh</qex> in the fold.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruck</ent><br/
<hw>Ruck</hw>, <pos>n.</pos> <ety>[Cf. <er>Ruck</er>.]</ety> <sn>1.</sn>
<def>A heap; a rick.</def> <mark>[Prov Eng. & Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The common sort, whether persons or things; <as>as,
the <ex>ruck</ex> in a horse race</as>.</def> <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>ruck</qex> in society as a whole.</q> <rj><qau>Lond. Sat.
Rev.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ructation</ent><br/
<hw>Ruc*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>ructatio</ets>, fr. <ets>ructare</ets> to belch: cf. F.
<ets>ructation</ets>.]</ety> <def>The act of belching wind.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruction</ent><br/
<hw>Ruc"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An uproar; a quarrel;
a noisy outbreak.</def> <mark>[Prov. Eng. & Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rud</ent><br/
<hw>Rud</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS. <ets>rudu</ets>, akin
to <ets>re<aacute/d</ets> red. <root/113. See <er>Red</er>, and cf.
<er>Ruddy</er>.]</ety> <sn>1.</sn> <def>Redness; blush.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Ruddle; red ocher.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <def>The rudd.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rud</ent><br/
<hw>Rud</hw>, <pos>v. t.</pos> <def>To make red.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rudbeckia</ent><br/
\'d8<hw>Rud*beck"i*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. So named
after Olaf <etsep>Rudebeck</etsep>, a Swedish botanist.]</ety>
<fld>(Bot.)</fld> <def>A genus of composite plants, the coneflowers,
consisting of perennial herbs with showy pedunculate heads, having a
hemispherical involucre, sterile ray flowers, and a conical chaffy
receptacle. There are about thirty species, exclusively North American.
<spn>Rudbeckia hirta</spn>, the <stype>black-eyed Susan</stype>, is a
common weed in meadows.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Rudd</ent><br/
<hw>Rudd</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See <er>Rud</er>,
<pos>n.</pos>]</ety> <fld>(Zool.)</fld> <def>A fresh-water European fish
of the Carp family (<spn>Leuciscus erythrophthalmus</spn>). It is about
the size and shape of the roach, but it has the dorsal fin farther back,
a stouter body, and red irises. Called also <altname>redeye</altname>,
<altname>roud</altname>, <altname>finscale</altname>, and
<altname>shallow</altname>. A blue variety is called
<stype>azurine</stype>, or <stype>blue roach</stype>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rudder</ent><br/
<hw>Rud"der</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A riddle or
sieve.</def> <mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1258 --></p>

<p><ent>Rudder</ent><br/
<hw>Rud"der</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>rother</ets>, AS. <ets>r<omac/<edh/er</ets> a paddle; akin to D.
<ets>roer</ets> rudder, oar, G. <ets>ruder</ets>, OHG.
<ets>roadar</ets>, Sw. <ets>roder</ets>, <ets>ror</ets>, Dan.
<ets>roer</ets>, <ets>ror</ets>. <root/ 8. See <er>Row</er> to propel
with an oar, and cf. <er>Rother</er>. ]</ety> <sn>1.</sn>
<fld>(Naut.)</fld> <def>The mechanical appliance by means of which a
vessel is guided or steered when in motion. It is a broad and flat blade
made of wood or iron, with a long shank, and is fastened in an upright
position, usually by one edge, to the sternpost of the vessel in such a
way that it can be turned from side to side in the water by means of a
tiller, wheel, or other attachment.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Fig.: That which resembles a rudder as a guide or
governor; that which guides or governs the course.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>For rhyme the <qex>rudder</qex> is of verses.</q>
<rj><qau>Hudibras.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>In an aircraft, a surface the function of which is
to exert a turning moment about an axis of the craft.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><cs><col><b>Balance rudder</b></col> <fld>(Naut.)</fld>, <cd>a rudder
pivoted near the middle instead of at the edge, -- common on
sharpies.</cd> -- <col><b>Drop rudder</b></col> <fld>(Naut.)</fld>,
<cd>a rudder extending below the keel so as to be more effective in
steering.</cd> -- <col><b>Rudder chain</b></col> <fld>(Naut.)</fld>,
<cd>one of the loose chains or ropes which fasten the rudder to the
quarters to prevent its loss in case it gets unshipped, and for
operating it in case the tiller or the wheel is broken.</cd> --
<col><b>Rudder coat</b></col> <fld>(Naut.)</fld>, <cd>a covering of
tarred canvas used to prevent water from entering the rudderhole.</cd>
-- <col><b>Rudder fish</b></col>. <fld>(Zool.)</fld> <sd>(a)</sd>
<cd>The pilot fish</cd>. <sd>(b)</sd> <cd>The amber fish (<spn>Seriola
zonata</spn>), which is bluish having six broad black bands</cd>.
<sd>(c)</sd> <cd>A plain greenish black American fish (<spn>Leirus
perciformis</spn>); -- called also <altname>black rudder fish</altname>,
<altname>logfish</altname>, and <altname>barrel fish</altname>. The name
is also applied to other fishes which follow vessels.</cd> --
<col><b>Rudder pendants</b></col> <fld>(Naut.)</fld>, <cd>ropes
connected with the rudder chains.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rudderhead</ent><br/
<hw>Rud"der*head`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Naut.)</fld>
<def>The upper end of the rudderpost, to which the tiller is
attached.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rudderhole</ent><br/
<hw>Rud"der*hole</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Naut.)</fld>
<def>The hole in the deck through which the rudderpost passes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rudderless</ent><br/
<hw>Rud"der*less</hw>, <pos>a.</pos> <def>Without a rudder.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rudderpost</ent><br/
<hw>Rud"der*post</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Naut.)</fld>
<def>The shank of a rudder, having the blade at one end and the
attachments for operating it at the other.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rudderstock</ent><br/
<hw>Rud"der*stock`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Naut.)</fld>
<def>The main part or blade of the rudder, which is connected by hinges,
or the like, with the sternpost of a vessel.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruddied</ent><br/
<hw>Rud"died</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Made ruddy or
red.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruddily</ent><br/
<hw>Rud"di*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a ruddy
manner.</def> <rj><au>Byron.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruddiness</ent><br/
<hw>Rud"di*ness</hw>, <pos>n.</pos> <def>The quality or state of being
ruddy; <as>as, the <ex>ruddiness</ex> of the cheeks or the
sky</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruddle</ent><br/
<hw>Rud"dle</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To raddle or
twist.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruddle</ent><br/
<hw>Rud"dle</hw>, <pos>n.</pos> <def>A riddle or sieve.</def>
<mark>[Obs.]</mark> <rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruddle</ent><br/
<hw>Rud"dle</hw>, <pos>n.</pos> <ety>[See <er>Rud</er>; cf.
<er>Reddle</er>.]</ety> <fld>(Min.)</fld> <def>A species of red earth
colored by iron sesquioxide; red ocher.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruddle</ent><br/
<hw>Rud"dle</hw>, <pos>v. t.</pos> <def>To mark with ruddle; to raddle;
to rouge.</def> <ldquo/Their <xex>ruddled</xex> cheeks.<rdquo/
<rj><au>Thackeray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A fair sheep newly <qex>ruddled</qex>.</q> <rj><qau>Lady M. W.
Montagu.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruddock</ent><br/
<hw>Rud"dock</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS.
<ets>ruddic</ets>; cf. W. <ets>rhuddog</ets> the redbreast. <root/113.
See <er>Rud</er>, <pos>n.</pos>]</ety> <altsp>[Written also
<asp>raddock</asp>.]</altsp> <sn>1.</sn> <fld>(Zool.)</fld> <def>The
European robin.</def> <ldquo/The tame <xex>ruddock</xex> and the coward
kite.<rdquo/ <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A piece of gold money; -- probably because the gold
of coins was often reddened by copper alloy. Called also <altname>red
ruddock</altname>, and <altname>golden ruddock</altname>.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Great pieces of gold . . . red <qex>ruddocks</qex>.</q>
<rj><qau>Florio.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruddy</ent><br/
<hw>Rud"dy</hw> <pr>(?)</pr>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Ruddier</adjf> <pr>(?)</pr>; <pos>superl.</pos>
<adjf>Ruddiest</adjf>.]</amorph> <ety>[AS. <ets>rudig</ets>. See
<er>Rud</er>, <pos>n.</pos>]</ety> <sn>1.</sn> <def>Of a red color; red,
or reddish; <as>as, a <ex>ruddy</ex> sky; a <ex>ruddy</ex>
flame</as>.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>They were more <qex>ruddy</qex> in body than rubies.</q>
<rj><qau>Lam. iv. 7.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of a lively flesh color, or the color of the human
skin in high health; <as>as, <ex>ruddy</ex> cheeks or lips</as>.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Ruddy duck</b></col> <fld>(Zool.)</fld>, <cd>an American
duck (<spn>Erismatura rubida</spn>) having a broad bill and a
wedge-shaped tail composed of stiff, sharp feathers. The adult male is
rich brownish red on the back, sides, and neck, black on the top of the
head, nape, wings, and tail, and white on the cheeks. The female and
young male are dull brown mixed with blackish on the back; grayish
below. Called also <altname>dunbird</altname>,
<altname>dundiver</altname>, <altname>ruddy diver</altname>,
<altname>stifftail</altname>, <altname>spinetail</altname>,
<altname>hardhead</altname>, <altname>sleepy duck</altname>,
<altname>fool duck</altname>, <altname>spoonbill</altname>, etc.</cd> --
<col><b>Ruddy plover</b></col> <fld>(Zool.)</fld> <cd>the
sanderling.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruddy</ent><br/
<hw>Rud"dy</hw>, <pos>v. t.</pos> <def>To make ruddy.</def>
<mark>[R.]</mark> <rj><au>Sir W. Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rude</ent><br/
<hw>Rude</hw> <pr>(?)</pr>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Ruder</adjf> <pr>(?)</pr>; <pos>superl.</pos>
<adjf>Rudest</adjf>.]</amorph> <ety>[F., fr. L. <ets>rudis</ets>.]</ety>
<sn>1.</sn> <def>Characterized by roughness; umpolished; raw; lacking
delicacy or refinement; coarse.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Such gardening tools as art, yet <qex>rude</qex>, . . . had
formed.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> Hence, specifically: <sd>(a)</sd> <def>Unformed by taste
or skill; not nicely finished; not smoothed or polished; -- said
especially of material things; <as>as, <ex>rude</ex>
workmanship</as>.</def> <ldquo/<xex>Rude</xex> was the cloth.<rdquo/
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Rude</qex> and unpolished stones.</q> <rj><qau>Bp.
Stillingfleet.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The heaven-born child<br/
All meanly wrapt in the <qex>rude</qex> manger lies.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(b)</sd> <def>Of untaught manners; unpolished; of low rank;
uncivil; clownish; ignorant; raw; unskillful; -- said of persons, or of
conduct, skill, and the like.</def> <ldquo/Mine ancestors were
<xex>rude</xex>.<rdquo/ <-- impolite. --> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He was but <qex>rude</qex> in the profession of arms.</q>
<rj><qau>Sir H. Wotton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>the <qex>rude</qex> forefathers of the hamlet sleep.</q>
<rj><qau>Gray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(c)</sd> <def>Violent; tumultuous; boisterous; inclement; harsh;
severe; -- said of the weather, of storms, and the like; <as>as, the
<ex>rude</ex> winter</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>[Clouds] pushed with winds, <qex>rude</qex> in their shock.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>rude</qex> agitation [of water] breaks it into foam.</q>
<rj><qau>Boyle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(d)</sd> <def>Barbarous; fierce; bloody; impetuous; -- said of
war, conflict, and the like; as, the <xex>rude</xex> shock of
armies.</def> <sd>(e)</sd> <def>Not finished or complete; inelegant;
lacking chasteness or elegance; not in good taste; unsatisfactory in
mode of treatment; -- said of literature, language, style, and the
like.</def> <ldquo/The <xex>rude</xex> Irish books.<rdquo/
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Rude</qex> am I in my speech.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Unblemished by my <qex>rude</qex> translation.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Impertinent; rough; uneven; shapeless;
unfashioned; rugged; artless; unpolished; uncouth; inelegant; rustic;
coarse; vulgar; clownish; raw; unskillful; untaught; illiterate;
ignorant; uncivil; impolite; saucy; impudent; insolent; surly; currish;
churlish; brutal; uncivilized; barbarous; savage; violent; fierce;
tumultuous; turbulent; impetuous; boisterous; harsh; inclement; severe.
See <er>Impertiment</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Rude"ly</wf> <pr>(#)</pr>, <pos>adv.</pos> --
<wf>Rude"ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rudenture</ent><br/
<hw>Ru"den*ture</hw> <pr>(?; 135)</pr>, <pos>n.</pos> <ety>[F., fr. L.
<ets>rudens</ets> a rope.]</ety> <fld>(Arch.)</fld> <def>Cabling. See
<er>Cabling</er>.</def> <rj><au>gwilt.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruderary</ent><br/
<hw>Ru"de*ra*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>ruderarius</ets>, fr. <ets>rudus</ets>, <ets>ruderis</ets>, stones
crushed and mixed with lime, old rubbish.]</ety> <def>Of or pertaining
to rubbish..</def> <mark>[Obs.]</mark> <rj><au>Bailey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rudesby</ent><br/
<hw>Rudes"by</hw> <pr>(r<udd/dz"b<ycr/)</pr>, <pos>n.</pos>
<ety>[Etymol. uncertain.]</ety> <def>An uncivil, turbulent fellow.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rudesheimer</ent><br/
<ent>Ruedesheimer</ent><br/
<hw>R<uum/"des*heim`er</hw>
<pr>(r<usdot/"d<ecr/s*h<imac/m`<etil/r)</pr>, <pos>prop. n.</pos> <def>A
German wine made near <city><etsep>R<uum/desheim</etsep></city>, on the
Rhine.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rudiment</ent><br/
<hw>Ru"di*ment</hw> <pr>(r<udd/"d<icr/*m<eit/nt)</pr>, <pos>n.</pos>
<ety>[L. <ets>rudimentum</ets>, fr. <ets>rudis</ets> unwrought,
ignorant, rude: cf. F. <ets>rudiment</ets>. See <er>Rude</er>.]</ety>
<sn>1.</sn> <def>That which is unformed or undeveloped; the principle
which lies at the bottom of any development; an unfinished
beginning.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>but I will bring thee where thou soon shalt quit<br/
Those <qex>rudiments</qex>, and see before thine eyes<br/
The monarchies of the earth.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>the single leaf is the <qex>rudiment</qex> of beauty in
landscape.</q> <rj><qau>I. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence, an element or first principle of any art or
science; a beginning of any knowledge; a first step.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This boy is forest-born,<br/
And hath been tutored in the <qex>rudiments</qex><br/
of many desperate studies.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>There he shall first lay down the <qex>rudiments</qex><br/
Of his great warfare.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Biol.)</fld> <def>An imperfect organ or part, or
one which is never developed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rudiment</ent><br/
<hw>Ru"di*ment</hw>, <pos>v. t.</pos> <def>To furnish with first
principles or rules; to insrtuct in the rudiments.</def>
<rj><au>Gayton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rudimental</ent><br/
<hw>Ru`di*men"tal</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Rudimentary.</def> <rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rudimentary</ent><br/
<hw>Ru`di*men"ta*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>rudimentaire</ets>.]</ety> <sn>1.</sn> <def>Of or pertaining to
rudiments; consisting in first principles; elementary; initial; <as>as,
<ex>rudimental</ex> essays</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Biol.)</fld> <def>Very imperfectly developed; in an
early stage of development; embryonic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rudish</ent><br/
<hw>Rud"ish</hw> <pr>(r<udd/d"<icr/sh)</pr>, <pos>a.</pos> <def>Somewhat
rude.</def> <rj><au>Foote.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rudistes</ent><br/
<hw>Ru*dis"tes</hw> <pr>(r<udd/*d<icr/s"t<emac/z)</pr>, <pos>n.
pl.</pos> <ety>[NL., fr. L. <ets>rudis</ets> rough.]</ety>
<fld>(Paleon.)</fld> <def>An extinct order or suborder of bivalve
mollusks characteristic of the Cretaceous period; -- called also
<altname>Rudista</altname>. See <xex>Illust.</xex> under
<er>Hippurite</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rudity</ent><br/
<hw>Ru"di*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>ruditas</ets> ignorance, fr. <ets>rudis</ets> rude,
illiterate.]</ety> <def>Rudeness; ignorance.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rudmasday</ent><br/
<hw>Rud"mas*day</hw> <pr>(r<oomac/d"m<adot/s*d<amac/`)</pr>,
<pos>n.</pos> <ety>[See <er>Rood</er>, <er>Mass</er>,
<er>Day</er>.]</ety> <fld>(R.C.Ch.)</fld> <def>Either of the feasts of
the Holy Cross, occuring on May 3 and September 14, annually.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rudolphine</ent><br/
<hw>Ru*dolph"ine</hw> <pr>(r<usdot/*d<ocr/lf"<icr/n)</pr>, <pos>a.</pos>
<def>Pertaining to, or designating, a set of astronomical tables
computed by <persfn>Kepler</persfn>, and founded on the observations of
<person>Tycho Brahe</person>; -- so named from
<person><etsep>Rudolph</etsep> II.</person>, emperor of
Germany.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rue</ent><br/
<hw>Rue</hw> <pr>(r<udd/)</pr>, <pos>n.</pos> <ety>[F. <ets>rue</ets>,
L. <ets>ruta</ets>, akin to Gr. <grk>"ryth`</grk>; cf. AS.
<ets>r<umac/de</ets>.]</ety> <sn>1.</sn> <fld>(Bot.)</fld> <def>A
perennial suffrutescent plant (<spn>Ruta graveolens</spn>), having a
strong, heavy odor and a bitter taste; herb of grace. It is used in
medicine.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Then purged with euphrasy and <qex>rue</qex><br/
The visual nerve, for he had much to see.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>They [the exorcists] are to try the devil by holy water, incense,
sulphur, <qex>rue</qex>, which from thence, as we suppose, came to be
called herb of grace.</q> <rj><qau>Jer. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Fig.: Bitterness; disappointment; grief;
regret.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Goat's rue</b></col>. <cd>See under <er>Goat</er>.</cd>
-- <col><b>Rue anemone</b></col>, <cd>a pretty springtime flower
(<spn>Thalictrum anemonides</spn>) common in the United States.</cd> --
<col><b>Wall rue</b></col>, <cd>a little fern (<spn>Asplenium
Ruta-muraria</spn>) common on walls in Europe.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rue</ent><br/
<hw>Rue</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Rued</conjf> <pr>(r<udd/d)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Ruing</conjf>.]</vmorph> <ety>[OE. <ets>rewen</ets>,
<ets>reouwen</ets>, to grive, make sorry, AS. <ets>hre<oacute/wan</ets>;
akin to OS. <ets>hrewan</ets>, D. <ets>rouwen</ets>, OHG.
<ets>hriuwan</ets>, G. <ets>reuen</ets>, Icel. <ets>hryggr</ets>
grieved, <ets>hryg<edh/</ets> sorrow. <root/ 18. Cf.
<er>Ruth</er>.]</ety> <sn>1.</sn> <def>To lament; to regret extremely;
to grieve for or over.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I wept to see, and <qex>rued</qex> it from my heart.</q>
<rj><qau>Chapmen.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Thy will<br/
Chose freely what it now so justly <qex>rues</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To cause to grieve; to afflict.</def>
<mark>[Obs.]</mark> <ldquo/God wot, it <xex>rueth</xex> me.<rdquo/
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To repent of, and withdraw from, as a bargain; to
get released from.</def> <mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rue</ent><br/
<hw>Rue</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To have
compassion.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>God so wisly [<it>i. e.</it>, truly] on my soul
<qex>rue</qex>.</q> <rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Which stirred men's hearts to <qex>rue</qex> upon them.</q>
<rj><qau>Ridley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To feel sorrow and regret; to repent.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Work by counsel and thou shalt not <qex>rue</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Old year, we'll dearly <qex>rue</qex> for you.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rue</ent><br/
<hw>Rue</hw>, <pos>n.</pos> <ety>[AS. <ets>hre<oacute/w</ets>. See
<er>Rue</er>, <pos>v. t.</pos>]</ety> <def>Sorrow; repetance.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rueful</ent><br/
<hw>Rue"ful</hw> <pr>(r<udd/"f<usdot/l)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Causing one to rue or lament; woeful; mournful;
sorrowful.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Expressing sorrow.</def> <ldquo/<xex>Rueful</xex>
faces.<rdquo/ <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Two <qex>rueful</qex> figures, with long black cloaks.</q>
<rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Rue"ful*ly</wf>, adv. -- <wf>Rue"ful*ness</wf>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruell bone</ent><br/
<hw>Ru"ell bone`</hw> <pr>(r<udd/"<ecr/l b<omac/n`)</pr>. <def>See
<er>rewel bone</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruelle</ent><br/
<hw>Ru*elle"</hw> <pr>(r<usdot/*<ecr/l")</pr>, <pos>n.</pos> <ety>[F.
<ets>ruelle</ets> a narrow street, a lane, ruelle, fr. <ets>rue</ets> a
street.]</ety> <def>A private circle or assembly at a private house; a
circle.</def> <mark>[Obs.]</mark> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rufescent</ent><br/
<hw>Ru*fes"cent</hw> <pr>(r<usdot/*f<ecr/s"s<eit/nt)</pr>, <pos>a.</pos>
<ety>[L. <ets>rufescens</ets>, p. pr. of <ets>rufescere</ets> to become
reddish, fr. <ets>rufus</ets> red: cf. F. <ets>rufescent</ets>.]</ety>
<def>Reddish; tinged with red.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruff</ent><br/
<hw>Ruff</hw> <pr>(r<ucr/f)</pr>, <pos>n.</pos> <ety>[F.
<ets>ronfle</ets>; cf. It. <ets>ronfa</ets>, Pg. <ets>rufa</ets>,
<ets>rifa</ets>.]</ety> <fld>(Card Playing)</fld> <sd>(a)</sd> <def>A
game similar to whist, and the predecessor of it.</def>
<rj><au>Nares.</au></rj> <sd>(b)</sd> <def>The act of trumping,
especially when one has no card of the suit led.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruff</ent><br/
<hw>Ruff</hw>, <pos>v. i. & t.</pos> <fld>(Card Playing)</fld> <def>To
trump.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruff</ent><br/
<hw>Ruff</hw>, <pos>n.</pos> <ety>[Of uncertain origin: cf. Icel.
<ets>r<umac/finn</ets> rough, uncombed, Pr. <ets>ruf</ets> rude, rough,
Sp. <ets>rufo</ets> frizzed, crisp, curled, G. <ets>raufen</ets> to
pluck, fight, <ets>rupfen</ets> to pluck, pull, E. <ets>rough</ets>.
<root/18. Cf. <er>Ruffle</er> to wrinkle.]</ety> <sn>1.</sn> <def>A
muslin or linen collar plaited, crimped, or fluted, worn formerly by
both sexes, now only by women and children.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Here to-morrow with his best <qex>ruff</qex> on.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>His gravity is much lessened since the late proclamation came out
against <qex>ruffs</qex>; . . . they were come to that height of excess
herein, that twenty shillings were used to be paid for starching of a
<qex>ruff</qex>.</q> <rj><qau>Howell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Something formed with plaits or flutings, like the
collar of this name.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I reared this flower; . . . <br/
Soft on the paper <qex>ruff</qex> its leaves I spread.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>An exhibition of pride or haughtiness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>How many princes . . . in the <qex>ruff</qex> of all their glory,
have been taken down from the head of a conquering army to the wheel of
the victor's chariot!</q> <rj><qau>L'Estrange.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Wanton or tumultuous procedure or conduct.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>To ruffle it out in a riotous <qex>ruff</qex>.</q>
<rj><qau>Latimer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Mil.)</fld> <def>A low, vibrating beat of a drum,
not so loud as a roll; a ruffle.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Mach.)</fld> <def>A collar on a shaft ot other
piece to prevent endwise motion. See <xex>Illust.</xex> of
<er>Collar</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Zool.)</fld> <def>A set of lengthened or otherwise
modified feathers round, or on, the neck of a bird.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <fld>(Zool.)</fld> <sd>(a)</sd> <def>A limicoline bird of
Europe and Asia (<spn>Pavoncella pugnax</spn>, syn. <spn>Philomachus
pugnax</spn>) allied to the sandpipers. The males during the breeding
season have a large ruff of erectile feathers, variable in their colors,
on the neck, and yellowish naked tubercles on the face. They are
polygamous, and are noted for their pugnacity in the breeding season.
The female is called <stype>reeve</stype>, or
<stype>rheeve</stype>.</def> <sd>(b)</sd> <def>A variety of the domestic
pigeon, having a ruff of its neck.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruff</ent><br/
<hw>Ruff</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Ruffed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Ruffing</conjf>.]</vmorph> <sn>1.</sn> <def>To ruffle; to
disorder.</def> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mil.)</fld> <def>To beat with the ruff or ruffle,
as a drum.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Hawking)</fld> <def>To hit, as the prey, without
fixing it.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Card Playing)</fld> <def>To play a trump card at
bridge; <as>as, he <ex>ruffed</ex> his partner's ace</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Ruffe</ent><br/
<ent>Ruff</ent><br/
<mhw>{ <hw>Ruff</hw>, <hw>Ruffe</hw> }</mhw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[OE. <ets>ruffe</ets>.]</ety> <fld>(Zool.)</fld> <def>A small
freshwater European perch (<spn>Acerina vulgaris</spn>); -- called also
<altname>pope</altname>, <altname>blacktail</altname>, and
<altname>stone perch</altname>, or <altname>striped
perch</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruffed</ent><br/
<hw>Ruffed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Furnished with a
ruff.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Ruffed grouse</b></col> <fld>(Zool.)</fld>, <cd>a North
American grouse (<spn>Bonasa umbellus</spn>) common in the wooded
districts of the <geog>Northern United States</geog>. The male has a
ruff of brown or black feathers on each side of the neck, and is noted
for the loud drumming sound he makes during the breeding season. Called
also <altname>tippet grouse</altname>, <altname>partridge</altname>,
<altname>birch partridge</altname>, <altname>pheasant</altname>,
<altname>drummer</altname>, and <altname>white-flesher</altname>.</cd>
-- <col><b>ruffed lemur</b></col> <fld>(Zool.)</fld>, <cd>a species of
lemur (<spn>lemur varius</spn>) having a conspicuous ruff on the sides
of the head. Its color is varied with black and white. Called also
<altname>ruffed maucaco</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruffian</ent><br/
<hw>Ruf"fian</hw> <pr>(r<ucr/f"y<ait/n <it>or</it>
r<ucr/f"f<icr/*<ait/n; 277)</pr>, <pos>n.</pos> <ety>[F.
<ets>rufien</ets>, OF. <ets>ruffien</ets>, <ets>ruffian</ets>, pimp,
libertine, rake; cf. Pr. & Sp. <ets>rufian</ets>, It.
<ets>ruffiano</ets>; all perhaps of German or Dutch origin; cf. G.
<ets>raufen</ets> to pluck, scuffle, fight, OD. <ets>roffen</ets> to
pander. Cf. <ets>Ruffle</ets> to grow turbulent.]</ety> <sn>1.</sn>
<def>A pimp; a pander; also, a paramour.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He [her husband] is no sooner abroad than she is instantly at
home, reveling with her <qex>ruffians</qex>.</q> <rj><qau>Bp.
Reynolds.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A boisterous, cruel, brutal fellow; a desperate
fellow ready for murderous or cruel deeds; a cutthroat.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Wilt thou on thy deathbed play the <qex>ruffian</qex>?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <specif>Hence:</specif> <def>A tough, lawless or bullying
person.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruffian</ent><br/
<hw>Ruf"fian</hw>, <pos>a.</pos> <def>Brutal; cruel; savagely
boisterous; murderous; <as>as, <ex>ruffian</ex> rage</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruffian</ent><br/
<hw>Ruf"fian</hw>, <pos>v. i.</pos> <def>To play the ruffian; to rage;
to raise tumult.</def> <mark>[R.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruffianage</ent><br/
<hw>Ruf"fian*age</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Ruffians,
collectively; a body of ruffians.</def> <ldquo/The vilest
<xex>ruffianage</xex>.<rdquo/ <rj><au>Sir F. Palgrave.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruffianish</ent><br/
<hw>Ruf"fian*ish</hw>, <pos>a.</pos> <def>Having the qualities or
manners of a ruffian; ruffianly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruffianlike</ent><br/
<hw>Ruf"fian*like`</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Ruffianly.</def> <rj><au>Fulke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruffianly</ent><br/
<hw>Ruf"fian*ly</hw>, <pos>a.</pos> <def>Like a ruffian; bold in crimes;
characteristic of a ruffian; violent; brutal.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruffianous</ent><br/
<hw>Ruf"fian*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Ruffianly.</def>
<mark>[Obs.]</mark> <rj><au>Chapman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruffin</ent><br/
<hw>Ruf"fin</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<ets>Ruffian</ets>.]</ety> <def>Disordered.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>His <qex>ruffin</qex> rainment all was stained with blood.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1259 --></p>

<p><ent>Ruffle</ent><br/
<hw>Ruf"fle</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Ruffled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Ruffling</conjf> <pr>(?)</pr>.]</vmorph> <ety>[From <er>Ruff</er>
a plaited collar, a drum beat, a tumult: cf. OD. <ets>ruyffelen</ets> to
wrinkle.]</ety> <sn>1.</sn> <def>To make into a ruff; to draw or
contract into puckers, plaits, or folds; to wrinkle.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To furnish with ruffles; <as>as, to <ex>ruffle</ex>
a shirt</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To oughen or disturb the surface of; to make uneven
by agitation or commotion.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The fantastic revelries . . . that so often <qex>ruffled</qex> the
placid bosom of the Nile.</q> <rj><qau>I. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>She smoothed the <qex>ruffled</qex> seas.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To erect in a ruff, as feathers.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>[the swan] <qex>ruffles</qex> her pure cold plume.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Mil.)</fld> <def>To beat with the ruff or ruffle,
as a drum.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To discompose; to agitate; to disturb.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>These <qex>ruffle</qex> the tranquillity of the mind.</q>
<rj><qau>Sir W. Hamilton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>But, ever after, the small violence done<br/
Rankled in him and <qex>ruffled</qex> all his heart.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>To throw into disorder or confusion.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Where best<br/
He might the <qex>ruffled</qex> foe infest.</q>
<rj><qau>Hudibras.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>To throw together in a disorderly manner.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I <qex>ruffled</qex> up falen leaves in heap.</q>
<rj><qau>Chapman</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To ruffle the feathers of</b></col>, <cd>to exite the
resentment of; to irritate.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruffle</ent><br/
<hw>Ruf"fle</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[Perhaps of
different origin from <ets>ruffle</ets> to wrinkle; cf. OD.
<ets>roffeln</ets>, <ets>roffen</ets>, to pander, LG.
<ets>raffein</ets>, Dan. <ets>ruffer</ets> a pimp. Cf.
<er>Rufflan</er>.]</ety> <sn>1.</sn> <def>To grow rough, boisterous, or
turbulent.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The night comes on, and the bleak winds<br/
Do sorely <qex>ruffle</qex>.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To become disordered; to play loosely; to
flutter.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>On his right shoulder his thick mane reclined,<br/
<qex>Ruffles</qex> at speed, and dances in the wind.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To be rough; to jar; to be in contention; hence, to
put on airs; to swagger.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They would <qex>ruffle</qex> with jurors.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Gallants who <qex>ruffled</qex> in silk and embroidery.</q>
<rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruffle</ent><br/
<hw>Ruf"fle</hw>, <pos>n.</pos> <ety>[See <er>Ruffle</er>, <pos>v. t. &
i.</pos>]</ety> <sn>1.</sn> <def>That which is ruffled; specifically, a
strip of lace, cambric, or other fine cloth, plaited or gathered on one
edge or in the middle, and used as a trimming; a frill.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A state of being ruffled or disturbed; disturbance;
agitation; commotion; <as>as, to put the mind in a
<ex>ruffle</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Mil.)</fld> <def>A low, vibrating beat of a drum,
not so loud as a roll; -- called also <altname>ruff</altname>.</def>
<rj><au>H. L. Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Zool.)</fld> <def>The connected series of large egg
capsules, or oothecae, of any one of several species of American marine
gastropods of the genus <gen>Fulgur</gen>. See
<er>Ootheca</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Ruffle of a boot</b></col>, <cd>the top turned down, and
scalloped or plaited.</cd> <rj><au>Halliwell.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruffleless</ent><br/
<hw>Ruf"fle*less</hw>, <pos>a.</pos> <def>Having no ruffle.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rufflement</ent><br/
<hw>Ruf"fle*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
ruffling.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruffler</ent><br/
<hw>Ruf"fler</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who
ruffles; a swaggerer; a bully; a ruffian.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Assaults, if not murders, done at his own doors by that crew of
<qex>rufflers</qex>.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which ruffles; specifically, a sewing machine
attachment for making ruffles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rufigallic</ent><br/
<hw>Ru`fi*gal"lic</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Rufi</ets>opin + <ets>gallic</ets>.]</ety> <fld>(Chem.)</fld>
<def>Pertaining to, or designating, an acid which is obtained from
gallic acid as a brown or red crystalline substance, and is related to
rufiopin and anthracene.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rufiopin</ent><br/
<hw>Ru`fi*o"pin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>rufus</ets> reddish + <ets>op</ets>ianic.]</ety> <fld>(Chem.)</fld>
<def>A yellowish red crystalline substance related to anthracene, and
obtained from opianic acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rufol</ent><br/
<hw>Ru"fol</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>rufus</ets>
reddish + <ets>-ol</ets>.]</ety> <fld>(Chem.)</fld> <def>A phenol
derivative of anthracene obtained as a white crystalline substance,
which on oxidation produces a red dyestuff related to
anthraquinone.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rufous</ent><br/
<hw>Ru"fous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>rufus</ets>.]</ety> <def>Reddish; of a yellowish red or brownish
red color; tawny.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruft</ent><br/
<hw>Ruft</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Med.)</fld>
<def>Eructation; belching.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rufterhood</ent><br/
<hw>Ruf"ter*hood</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf.
<er>Ruff</er> a plaited collar.]</ety> <fld>(Falconry)</fld> <def>A kind
of hood for a hawk.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rug</ent><br/
<hw>Rug</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. Sw. <ets>rugg</ets>
entanglend hair, <ets>ruggig</ets> rugged, shaggy, probably akin to E.
<ets>rough</ets>. See <er>Rough</er>, <pos>a.</pos>]</ety> <sn>1.</sn>
<def>A kind of coarse, heavy frieze, formerly used for
garments.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They spin the choicest <qex>rug</qex> in Ireland. A friend of mine
. . . repaired to Paris Garden clad in one of these Waterford
<qex>rugs</qex>. The mastiffs, . . . deeming he had been a bear, would
fain have baited him.</q> <rj><qau>Holinshed.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A piece of thick, nappy fabric, commonly made of
wool, -- used for various purposes, as for covering and ornamenting part
of a bare floor, for hanging in a doorway as a poti<egrave/re, for
protecting a portion of carpet, for a wrap to protect the legs from
cold, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A rough, woolly, or shaggy dog.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Rug gown</b></col>, <cd>a gown made of rug, of or coarse,
shaggy cloth.</cd> <rj><au>B. Johnson.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rug</ent><br/
<hw>Rug</hw>, <pos>v. t.</pos> <def>To pull roughly or hastily; to
plunder; to spoil; to tear.</def> <mark>[Scot.]</mark> <rj><au>Sir W.
Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruga</ent><br/
\'d8<hw>Ru"ga</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Rugae</plw> <pr>(#)</pr>.</plu> <ety>[L.]</ety> <fld>(Nat.
Hist.)</fld> <def>A wrinkle; a fold; <as>as, the <ex>rugae</ex> of the
stomach</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rugate</ent><br/
<hw>Ru"gate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>rugatus</ets>, p. p. of <ets>rugare</ets> to wrinkle, fr.
<ets>ruga</ets> a wrinkle.]</ety> <def>Having alternate ridges and
depressions; wrinkled.</def> <rj><au>Dana.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rugged</ent><br/
<hw>Rug"ged</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See <er>Rug</er>,
<pos>n.</pos>]</ety> <sn>1.</sn> <def>Full of asperities on the surface;
broken into sharp or irregular points, or otherwise uneven; not smooth;
rough; <as>as, a <ex>rugged</ex> mountain; a <ex>rugged</ex>
road</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>rugged</qex> bark of some broad elm.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Not neat or regular; uneven.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His well-proportioned beard made rough and <qex>rugged</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Rough with bristles or hair; shaggy.</def>
<ldquo/The <xex>rugged</xex> Russian bear.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Harsh; hard; crabbed; austere; -- said of temper,
character, and the like, or of persons.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Neither melt nor endear him, but leave him as hard,
<qex>rugged</qex>, and unconcerned as ever.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Stormy; turbulent; tempestuous; rude.</def>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Rough to the ear; harsh; grating; -- said of sound,
style, and the like.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Through the harsh cadence of a <qex>rugged</qex> line.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>Sour; surly; frowning; wrinkled; -- said of looks,
etc.</def> <ldquo/Sleek o'er your <xex>rugged</xex> looks.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>Violent; rude; boisterrous; -- said of conduct,
manners, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>Vigorous; robust; hardy; -- said of health,
physique, etc.</def> <mark>[Colloq. U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Rough; uneven; wrinkled; cragged; coarse; rude;
harsh; hard; crabbed; severe; austere; surly; sour; frowning; violent;
boisterous; tumultuous; turbulent; stormy; tempestuous;
inclement.</syn><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Rug"ged*ly</wf> <pr>(#)</pr>, <pos>adv.</pos> --
<wf>Rug"ged*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rugging</ent><br/
<hw>Rug"ging</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A coarse kind of
woolen cloth, used for wrapping, blanketing, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rug-gowned</ent><br/
<hw>Rug"-gowned</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Wearing a coarse
gown or shaggy garment made of rug.</def> <rj><au>Beau. &
Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruggy</ent><br/
<hw>Rug"gy</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Rugged; rough.</def>
<mark>[Obs.]</mark> <ldquo/With <xex>ruggy</xex>, ashy hairs.<rdquo/
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rug-headed</ent><br/
<hw>Rug"-head`ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having shaggy
hair; shock-headed.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Those rough <qex>rug-headed</qex> kerns.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rugin</ent><br/
<hw>Rug"in</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A nappy cloth.</def>
<mark>[Obs.]</mark> <rj><au>Wiseman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rugine</ent><br/
<hw>Ru"gine</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<fld>(Surg.)</fld> <def>An instrument for scraping the periosteum from
bones; a raspatory.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rugine</ent><br/
<hw>Ru"gine</hw>, <pos>v. t.</pos> <ety>[F. <ets>ruginer</ets> to
scrape.]</ety> <def>To scrape or rasp, as a bone; to scale.</def>
<mark>[R.]</mark> <rj><au>Wiseman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rugosa</ent><br/
\'d8<hw>Ru*go"sa</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL. See
<er>Rugose</er>.]</ety> <fld>(Paleon.)</fld> <def>An extinct tribe of
fossil corals, including numerous species, many of them of large size.
They are characteristic of the Paleozoic formations. The radiating
septs, when present, are usually in multiples of four. See
<er>Cyathophylloid</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rugose</ent><br/
<hw>Ru*gose"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>rugosus</ets>, r. <ets>ruga</ets> a wrinkle.]</ety> <def>Wrinkled;
full of wrinkles;</def> <specif>specifically</specif> <fld>(Bot.)</fld>,
<def>having the veinlets sunken and the spaces between them elevated, as
the leaves of the sage and horehound.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rugosity</ent><br/
<hw>Ru*gos"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>rugositas</ets>: cf. F. <ets>rugosit<eacute/</ets>.]</ety> <def>The
quality or state of being rugose.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rugous</ent><br/
<hw>Ru"gous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>rugueux</ets>.]</ety> <def>Wrinkled; rugose.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rugulose</ent><br/
<hw>Ru`gu*lose"</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Somewhat
rugose.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruhmkorff's coil</ent><br/
<hw>Ruhm"korff's coil`</hw> <pr>(?)</pr>. <ety>[So called from its
inventor, <ets>Ruhmkorff</ets>, a german physicist.]</ety>
<fld>(Elec.)</fld> <def>See <cref>Induction coil</cref>, under
<er>Induction</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruin</ent><br/
<hw>Ru"in</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>ruine</ets>,
F. <ets>ruine</ets>, fr. L. <ets>ruina</ets>, fr. ruere, rutum, to fall
with violence, to rush or tumble down.]</ety> <sn>1.</sn> <def>The act
of falling or tumbling down; fall.</def> <mark>[Obs.]</mark> <ldquo/His
<xex>ruin</xex> startled the other steeds.<rdquo/
<rj><au>Chapman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Such a change of anything as destroys it, or
entirely defeats its object, or unfits it for use; destruction;
overthrow; <as>as, the <ex>ruin</ex> of a ship or an army; the
<ex>ruin</ex> of a constitution or a government; the <ex>ruin</ex> of
health or hopes</as>.</def> <ldquo/<xex>Ruin</xex> seize thee, ruthless
king!<rdquo/ <rj><au>Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which is fallen down and become worthless from
injury or decay; <as>as, his mind is a <ex>ruin</ex></as>; especially,
in the plural, the remains of a destroyed, dilapidated, or desolate
house, fortress, city, or the like.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The Veian and the Gabian towers shall fall,<br/
And one promiscuous ruin cover all;<br/
Nor, after length of years, a stone betray<br/
The place where once the very <qex>ruins</qex> lay.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The labor of a day will not build up a virtuous habit on the
<qex>ruins</qex> of an old and vicious character.</q>
<rj><qau>Buckminster.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The state of being dcayed, or of having become
ruined or worthless; <as>as, to be in <ex>ruins</ex>; to go to
<ex>ruin</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>That which promotes injury, decay, or
destruction.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The errors of young men are the <qex>ruin</qex> of business.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Destruction; downfall; perdition; fall;
overthrow; subversion; defeat; bane; pest; mischief.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruin</ent><br/
<hw>Ru"in</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Ruined</conjf> <pr>(?)</pr>;<pos>p. pr. & vb. n.</pos>
<conjf>Ruining</conjf>.]</vmorph> <ety>[Cf. F. <ets>ruiner</ets>, LL.
<ets>ruinare</ets>. See <er>Ruin</er>, <pos>n.</pos>]</ety> <def>To
bring to ruin; to cause to fall to pieces and decay; to make to perish;
to bring to destruction; to bring to poverty or bankruptcy; to impair
seriously; to damage essentially; to overthrow.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>this mortal house I'll <qex>ruin</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>By thee raised, I <qex>ruin</qex> all my foes.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The eyes of other people are the eyes that <qex>ruin</qex> us.</q>
<rj><qau>Franklin.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>By the fireside there are old men seated,<br/
Seeling <qex>ruined</qex> cities in the ashes.</q>
<rj><qau>Longfellow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruin</ent><br/
<hw>Ru"in</hw>, <pos>v. i.</pos> <def>To fall to ruins; to go to ruin;
to become decayed or dilapidated; to perish.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Though he his house of polished marble build,<br/
Yet shall it <qex>ruin</qex> like the moth's frail cell.</q>
<rj><qau>Sandys.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>If we are idle, and disturb the industrious in their business, we
shall <qex>ruin</qex> the faster.</q> <rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruinable</ent><br/
<hw>Ru"in*a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of being
ruined.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruinate</ent><br/
<hw>Ru"in*ate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[LL.
<ets>ruinatus</ets>, p. p. of <ets>ruinare</ets> to ruin. See
<er>Ruin</er>.]</ety> <sn>1.</sn> <def>To demolish; to subvert; to
destroy; to reduce to poverty; to ruin.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I will not <qex>ruinate</qex> my father's house.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Ruinating</qex> thereby the health of their bodies.</q>
<rj><qau>Burton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To cause to fall; to cast down.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>On the other side they saw that perilous rock<br/
Threatening itself on them to <qex>ruinate</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruinate</ent><br/
<hw>Ru"in*ate</hw>, <pos>v. i.</pos> <def>To fall; to tumble.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruinate</ent><br/
<hw>Ru"in*ate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>ruinatus</ets>, p. p.]</ety> <def>Involved in ruin;
ruined.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>My brother Edward lives in pomp and state,<br/
I in a mansion here all <qex>ruinate</qex>.</q> <rj><qau>J.
Webster.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruination</ent><br/
<hw>Ru`in*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL.
<ets>ruinatio</ets>.]</ety> <def>The act of ruining, or the state of
being ruined.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruiner</ent><br/
<hw>Ru"in*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, ruins.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruiniform</ent><br/
<hw>Ru"in*i*form</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Ruin</ets>
+ <ets>-form</ets>: cf. F. <ets>ruiniforme</ets>.]</ety> <def>Having the
appearance of ruins, or of the ruins of houses; -- said of certain
minerals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruinous</ent><br/
<hw>Ru"in*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>ruinosus</ets>: cf. F. <ets>ruineux</ets>. See
<er>Ruin</er>.]</ety> <sn>1.</sn> <def>Causing, or tending to cause,
ruin; destructive; baneful; pernicious; <as>as, a <ex>ruinous</ex>
project</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>After a night of storm so <qex>ruinous</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Characterized by ruin; ruined; dilapidated; <as>as,
an edifice, bridge, or wall in a <ex>ruinous</ex> state</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Composed of, or consisting in, ruins.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Behold, Damascus . . . shall be a <qex>ruinous</qex> heap.</q>
<rj><qau>Isa. xvii. 1.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Dilapidated; decayed; demolished; pernicious;
destructive; baneful; wasteful; mischievous.</syn><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Ru"in*ous*ly</wf> <pr>(#)</pr>, <pos>adv.</pos> --
<wf>Ru"in*ous*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rukh</ent><br/
<hw>Rukh</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Srr <er>Roc</er>.]</ety>
<sn>1.</sn> <def>The roc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>A large bird, supposed by some to
be the same as the extinct Epiornis of Madagascar.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rulable</ent><br/
<hw>Rul"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>That may be ruled;
subject to rule; accordant or conformable to rule.</def>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rule</ent><br/
<hw>Rule</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>reule</ets>,
<ets>riule</ets>, OF. <ets>riule</ets>, <ets>reule</ets>, F.
<ets>r<eacute/gle</ets>, fr. L. <ets>regula</ets> a ruler, rule, model,
fr. <ets>regere</ets>, <ets>rectum</ets>, to lead straight, to direct.
See <er>Right</er>, <pos>a.</pos>, and cf. <er>Regular</er>.]</ety>
<sn>1.</sn> <def>That which is prescribed or laid down as a guide for
conduct or action; a governing direction for a specific purpose; an
authoritative enactment; a regulation; a prescription; a precept;
<as>as, the <ex>rules</ex> of various societies; the <ex>rules</ex>
governing a school; a <ex>rule</ex> of etiquette or propriety; the
<ex>rules</ex> of cricket</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We profess to have embraced a religion which contains the most
exact <qex>rules</qex> for the government of our lives.</q>
<rj><qau>Tillotson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> Hence: <sd>(a)</sd> <def>Uniform or established course of
things.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>'T is against the <qex>rule</qex> of nature.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(b)</sd> <def>Systematic method or practice; as, my
<xex>ule</xex> is to rise at six o'clock.</def> <sd>(c)</sd>
<def>Ordibary course of procedure; usual way; comon state or condition
of things; <as>as, it is a <ex>rule</ex> to which there are many
exeptions</as>.</def> <sd>(d)</sd> <def>Conduct in general;
behavior.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>This uncivil <qex>rule</qex>; she shall know of it.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The act of ruling; administration of law;
government; empire; authority; control.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Obey them that have the <qex>rule</qex> over you.</q>
<rj><qau>Heb. xiii. 17.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>His stern <qex>rule</qex> the groaning land obeyed.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Law)</fld> <def>An order regulating the practice of
the courts, or an order made between parties to an action or a
suit.</def> <rj><au>Wharton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Math.)</fld> <def>A determinate method prescribed
for performing any operation and producing a certain result; <as>as, a
<ex>rule</ex> for extracting the cube root</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Gram.)</fld> <def>A general principle concerning
the formation or use of words, or a concise statement thereof; thus, it
is a <xex>rule</xex> in England, that <xex>s</xex> or <xex>es</xex> ,
added to a noun in the singular number, forms the plural of that noun;
but <ldquo/man<rdquo/ forms its plural <ldquo/men<rdquo/, and is an
exception to the <xex>rule</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <sd>(a)</sd> <def>A straight strip of wood, metal, or the
like, which serves as a guide in drawing a straight line; a ruler.</def>
<sd>(b)</sd> <def>A measuring instrument consisting of a graduated bar
of wood, ivory, metal, or the like, which is usually marked so as to
show inches and fractions of an inch, and jointed so that it may be
folded compactly.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A judicious artist will use his eye, but he will trust only to his
<qex>rule</qex>.</q> <rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <fld>(Print.)</fld> <sd>(a)</sd> <def>A thin plate of
metal (usually brass) of the same height as the type, and used for
printing lines, as between columns on the same page, or in tabular
work.</def> <sd>(b)</sd> <def>A composing rule. See under
<er>Conposing</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>As a rule</b></col>, <cd>as a general thing; in the main;
usually; <as>as, he behaves well, <ex>as a rule</ex></as>.</cd> --
<mcol><col><b>Board rule</b></col>, <col><b>Caliber rule</b></col>,
etc.</mcol> <cd>See under <er>Board</er>, <er>Caliber</er>, etc.</cd> --
<col><b>Rule joint</b></col>, <cd>a knuckle joint having shoulders that
abut when the connected pieces come in line with each other, and thus
permit folding in one direction only.</cd> -- <col><b>Rule of the
road</b></col> <fld>(Law)</fld>, <cd>any of the various regulations
imposed upon travelers by land or water for their mutual convenience or
safety. In the United States it is a rule of the road that land
travelers passing in opposite directions shall turn out each to his own
right, and generally that overtaking persons or vehicles shall turn out
to the left; in England the rule for vehicles (but not for pedestrians)
is the opposite of this.</cd> -- <col><b>Rule of three</b></col>
<fld>(Arith.)</fld>, <cd>that rule which directs, when three terms are
given, how to find a fourth, which shall have the same ratio to the
third term as the second has to the first; proportion. See
<er>Proportion</er>, 5 <sd>(b)</sd>.</cd> -- <col><b>Rule of
thumb</b></col>, <cd>any rude process or operation, like that of using
the thumb as a rule in measuring; hence, judgment and practical
experience as distinguished from scientific knowledge.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rule</ent><br/
<hw>Rule</hw>, <pos>n.</pos> <cs></cs><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><syn><b>Syn.</b> -- regulation; law; precept; maxim; guide; canon;
order; method; direction; control; government; sway; empire.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rule</ent><br/
<hw>Rule</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Ruled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Ruling</conjf>.]</vmorph> <ety>[Cf. <ets>OF</ets>.
<ets>riuler</ets>, <ets>ruiler</ets>, L. <ets>regulare</ets>. See
<er>Rule</er>, <pos>n.</pos>, and cf. <er>Regulate</er>.]</ety>
<sn>1.</sn> <def>To control the will and actions of; to exercise
authority or dominion over; to govern; to manage.</def>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A bishop then must be blameless; . . . one that <qex>ruleth</qex>
well his own house, having his children in subjection.</q> <rj><qau>1
Tim. iii. 2, 4.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To control or direct by influence, counsel, or
persuasion; to guide; -- used chiefly in the passive.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I think she will be <qex>ruled</qex><br/
In all respects by me.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To establish or settle by, or as by, a rule; to fix
by universal or general consent, or by common practice.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That's are <qex>ruled</qex> case with the schoolmen.</q>
<rj><qau>Atterbury.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Law)</fld> <def>To require or command by rule; to
give as a direction or order of court.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To mark with lines made with a pen, pencil, etc.,
guided by a rule or ruler; to print or mark with lines by means of a
rule or other contrivance effecting a similar result; <as>as, to
<ex>rule</ex> a sheet of paper of a blank book</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Ruled surface</b></col> <fld>(Geom.)</fld>, <cd>any
surface that may be described by a straight line moving according to a
given law; -- called also a <altname>scroll</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rule</ent><br/
<hw>Rule</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To have power or
command; to exercise supreme authority; -- often followed by
<xex>over</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>By me princes <qex>rule</qex>, and nobles.</q> <rj><qau>Prov.
viii. 16.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>We subdue and <qex>rule</qex> over all other creatures.</q>
<rj><qau>Ray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>To lay down and settle a rule or
order of court; to decide an incidental point; to enter a rule.</def>
<rj><au>Burril. Bouvier.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Com.)</fld> <def>To keep within a (certain) range
for a time; to be in general, or as a rule; <as>as, prices
<ex>ruled</ex> lower yesterday than the day before</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruleless</ent><br/
<hw>Rule"less</hw>, <pos>a.</pos> <def>Destitute of rule; lawless.</def>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rule-monger</ent><br/
<hw>Rule"-mon`ger</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A stickler for
rules; a slave of rules</def> <mark>[R.]</mark>
<rj><au>Hare.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1260 --></p>

<p><ent>Ruler</ent><br/
<hw>Rul"er</hw> <pr>(r<udd/l"<etil/r)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>One who rules; one who exercises sway or authority; a
governor.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And he made him <qex>ruler</qex> over all the land.</q>
<rj><qau>Gen. xli. 43.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A prince and <qex>ruler</qex> of the land.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A straight or curved strip of wood, metal, etc.,
with a smooth edge, used for guiding a pen or pencil in drawing lines.
Cf. <er>Rule</er>, <pos>n.</pos>, 7 <sd>(a)</sd><-- usu. marked with
graduations so that it can be used to measure distances -->.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Parallel ruler</b></col>. <cd>See under
<er>Parallel</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruling</ent><br/
<hw>Rul"ing</hw>, <pos>a.</pos> <sn>1.</sn> <def>Predominant; chief;
reigning; controlling; <as>as, a <ex>ruling</ex> passion; a
<ex>ruling</ex> sovereign</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Used in marking or engraving lines; <as>as, a
<ex>ruling</ex> machine or pen</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Predominant; chief; controlling; directing;
guiding; governing; prevailing; prevalent.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruling</ent><br/
<hw>Rul"ing</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act of one who
rules; ruled lines.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>A decision or rule of a judge or a
court, especially an oral decision, as in excluding evidence.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rulingly</ent><br/
<hw>Rul"ing*ly</hw>, <pos>adv.</pos> <def>In a ruling manner; so as to
rule.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rullichies</ent><br/
<hw>Rul"li*chies</hw> <pr>(r<ucr/l"l<icr/*ch<icr/z)</pr>, <pos>n.
pl.</pos> <ety>[Cf. D. <ets>rolletje</ets> a little roll.]</ety>
<def>Chopped meat stuffed into small bags of tripe. They are cut in
slices and fried.</def> <mark>[Local, New York]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruly</ent><br/
<hw>Rul"y</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From
<er>Rule</er>.]</ety> <def>Orderly; easily restrained; -- opposed to
<ant>unruly</ant>.</def> <mark>[Obs.]</mark>
<rj><au>Gascoigne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rum</ent><br/
<hw>Rum</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[probably shortened from
Prov. E. <ets>rumbullion</ets> a great tumult, formerly applied in the
island of Barbadoes to an intoxicating liquor.]</ety> <def>A kind of
intoxicating liquor distilled from cane juice, or from the scummings of
the boiled juice, or from treacle or molasses, or from the lees of
former distillations. Also, sometimes used colloquially as a generic or
a collective name for intoxicating liquor.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Rum bud</b></col>, <cd>a grog blossom.</cd>
<mark>[Colloq.]</mark> -- <col><b>Rum shrub</b></col>, <cd>a drink
composed of rum, water, sugar, and lime juice or lemon juice, with some
flavoring extract.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rum</ent><br/
<hw>Rum</hw>, <pos>a.</pos> <ety>[Formerly <ets>rome</ets>, a slang word
for good; possibly of Gypsy origin; cf. Gypsy <ets>rom</ets> a husband,
a gypsy.]</ety> <def>Old-fashioned; queer; odd; <as>as, a <ex>rum</ex>
idea; a <ex>rum</ex> fellow</as>.</def> <mark>[Slang]</mark>
<rj><au>Dickens.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rum</ent><br/
<hw>Rum</hw>, <pos>n.</pos> <def>A queer or odd person or thing; a
country parson.</def> <mark>[Slang, Obs.]</mark>
<rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rumble</ent><br/
<hw>Rum"ble</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[OE.
<ets>romblen</ets>, akin to D. <ets>rommelen</ets>, G.
<ets>rumpeln</ets>, Dan. <ets>rumle</ets>; cf. Icel. <ets>rymja</ets> to
roar.]</ety> <sn>1.</sn> <def>To make a low, heavy, continued sound;
<as>as, the thunder <ex>rumbles</ex> at a distance</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In the mean while the skies 'gan <qex>rumble</qex> sore.</q>
<rj><qau>Surrey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The people cried and <qex>rombled</qex> up and down.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To murmur; to ripple.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>rumble</qex> gently down with murmur soft.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><--3. to engage in a fight, usu. between street gangs.--><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rumble</ent><br/
<hw>Rum"ble</hw>, <pos>n.</pos> <sn>1.</sn> <def>A noisy report;
rumor.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Delighting ever in <qex>rumble</qex> that is new.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A low, heavy, continuous sound like that made by
heavy wagons or the reverberation of thunder; a confused noise; <as>as,
the <ex>rumble</ex> of a railroad train</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Clamor and <qex>rumble</qex>, and ringing and clatter.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Merged in the <qex>rumble</qex> of awakening day.</q> <rj><qau>H.
James.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A seat for servants, behind the body of a
carriage.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Kit, well wrapped, . . . was in the <qex>rumble</qex> behind.</q>
<rj><qau>Dickens.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A rotating cask or box in which small articles are
smoothed or polished by friction against each other.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- <col><b>rumble seat</b></col>, <cd>a seat in the rear of an
automobile, outside the passenger cabin, which folds out from the
body.</cd> --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rumble</ent><br/
<hw>Rum"ble</hw>, <pos>v. t.</pos> <def>To cause to pass through a
rumble, or shaking machine. See <er>Rumble</er>, <pos>n.</pos>,
4.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rumbler</ent><br/
<hw>Rum"bler</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, rumbles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rumbling</ent><br/
<hw>Rum"bling</hw> <pr>(?)</pr>, <def><pos>a. & n.</pos> from
<er>Rumble</er>, <pos>v. i.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rumblingly</ent><br/
<hw>Rum"bling*ly</hw>, <pos>adv.</pos> <def>In a rumbling
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rumbo</ent><br/
<hw>Rum"bo</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Grog.</def>
<mark>[Obs.]</mark> <rj><au>Sir W. Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rumbowline</ent><br/
<hw>Rum*bow"line</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Naut.)</fld>
<def>Same as <er>Rombowline</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rumen</ent><br/
\'d8<hw>Ru"men</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>rumen</ets>, <ets>- inis</ets>, the throat.]</ety> <sn>1.</sn>
<fld>(Anat.)</fld> <def>The first stomach of ruminants; the paunch; the
fardingbag. See <xex>Illust.</xex> below. <-- ! PCP --></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The cud of a ruminant.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rumicin</ent><br/
<hw>Ru"mi*cin</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld> <def>A
yellow crystalline substance found in the root of yellow dock
(<spn>Rumex crispus</spn>) and identical with <altname>chrysophanic
acid</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruminal</ent><br/
<hw>Rumi*nal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>ruminalis</ets>.]</ety> <fld>(Zool.)</fld> <def>Ruminant;
ruminating.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruminant</ent><br/
<hw>Ru"mi*nant</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>ruminans</ets>, <ets>-antis</ets>, p. pr.: cf. F.
<ets>ruminant</ets>. See <er>Ruminate</er>.]</ety> <fld>(Zool.)</fld>
<def>Chewing the cud; characterized by chewing again what has been
swallowed; of or pertaining to the Ruminantia.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruminant</ent><br/
<hw>Ru"mi*nant</hw>, <pos>n.</pos> <fld>(Zool.)</fld> <def>A ruminant
animal; one of the Ruminantia.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruminantia</ent><br/
\'d8<hw>Ru`mi*nan"ti*a</hw> <pr>(?)</pr>, <pos>n. pl.</pos>
<ety>[NL.]</ety> <fld>(Zool.)</fld> <def>A division of Artiodactyla
having four stomachs. This division includes the camels, deer,
antelopes, goats, sheep, neat cattle, and allies.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- Letters refer to the Illustration, "Stomach of a ruminant."
--><br/
<note><hand/ The vegetable food, after the first mastication, enters the
first stomach (<xex>r</xex>). It afterwards passes into the second
(<xex>n</xex>), where it is moistened, and formed into pellets which the
animal has the power of bringing back to the mouth to be chewed again,
after which it is swallowed into the third stomach (<xex>m</xex>),
whence it passes to the fourth (<xex>s</xex>), where it is finally
digested.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruminantly</ent><br/
<hw>Ru"mi*nant*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a ruminant
manner; by ruminating, or chewing the cud.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruminate</ent><br/
<hw>Ru"mi*nate</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Ruminated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Ruminating</conjf>.]</vmorph> <ety>[L.
<ets>ruminatus</ets>, p. p. of <ets>ruminari</ets>, <ets>ruminare</ets>,
fr. <ets>rumen</ets>, <ets>-inis</ets>, throat, akin to
<ets>ructare</ets> to belch, <ets>erugere</ets> to belch out, Gr. <?/,
AS. <ets>roccettan</ets>.]</ety> <sn>1.</sn> <def>To chew the cud; to
chew again what has been slightly chewed and swallowed.</def>
<ldquo/Cattle free to <xex>ruminate</xex>.<rdquo/
<rj><au>Wordsworth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <mark>Fig.:</mark> <def>To think again and again; to
muse; to meditate; to ponder; to reflect.</def>
<rj><au>Cowper.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Apart from the hope of the gospel, who is there that
<qex>ruminates</qex> on the felicity of heaven?</q> <rj><qau>I.
Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruminate</ent><br/
<hw>Ru"mi*nate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <sn>1.</sn> <def>To
chew over again.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <mark>Fig.:</mark> <def>To meditate or ponder over; to
muse on.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Mad with desire, she <qex>ruminates</qex> her sin.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>What I know<br/
Is <qex>ruminated</qex>, plotted, and set down.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruminated</ent><br/
<ent>Ruminate</ent><br/
<mhw>{ <hw>Ru"mi*nate</hw> <pr>(?)</pr>, <hw>Ru"mi*na`ted</hw>
<pr>(?)</pr> }</mhw>, <pos>a.</pos> <fld>(Bot.)</fld> <def>Having a hard
albumen penetrated by irregular channels filled with softer matter, as
the nutmeg and the seeds of the North American papaw.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rumination</ent><br/
<hw>Ru`mi*na"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>ruminatio</ets>: cf. F. <ets>rumination</ets>.]</ety> <sn>1.</sn>
<def>The act or process of ruminating, or chewing the cud; the habit of
chewing the cud.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Rumination</qex> is given to animals to enable them at once
to lay up a great store of food, and afterward to chew it.</q>
<rj><qau>Arbuthnot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The state of being disposed to ruminate or ponder;
deliberate meditation or reflection.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Retiring full of <qex>rumination</qex> sad.</q>
<rj><qau>Thomson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Physiol.)</fld> <def>The regurgitation of food from
the stomach after it has been swallowed, -- occasionally observed as a
morbid phenomenon in man.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruminative</ent><br/
<hw>Ru"mi*na*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Inclined to, or
engaged in, rumination or meditation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruminator</ent><br/
<hw>Ru"mi*na`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.]</ety>
<def>One who ruminates or muses; a meditator.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rumkin</ent><br/
<hw>Rum"kin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. <er>Rummer</er>,
and see <er>-kin</er>.]</ety> <def>A popular or jocular name for a
drinking vessel.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rummage</ent><br/
<hw>Rum"mage</hw> <pr>(?; 48)</pr>, <pos>n.</pos> <ety>[For
<ets>roomage</ets>, fr. <ets>room</ets>; hence originally, a making
room, a packing away closely. See <er>Room</er>.]</ety> <sn>1.</sn>
<fld>(Naut.)</fld> <def>A place or room for the stowage of cargo in a
ship; also, the act of stowing cargo; the pulling and moving about of
packages incident to close stowage; -- formerly written
<xex>romage</xex>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A searching carefully by looking into every corner,
and by turning things over.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He has made such a general <qex>rummage</qex> and reform in the
office of matrimony.</q> <rj><qau>Walpole.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Rummage sale</b></col>, <cd>a clearance sale of unclaimed
goods in a public store, or of odds and ends which have accumulated in a
shop.</cd> <rj><au>Simmonds.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rummage</ent><br/
<hw>Rum"mage</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Rummaged</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Rummaging</conjf> <pr>(?)</pr>.]</vmorph> <sn>1.</sn>
<fld>(Naut.)</fld> <def>To make room in, as a ship, for the cargo; to
move about, as packages, ballast, so as to permit close stowage; to stow
closely; to pack; -- formerly written <altname>roomage</altname>, and
<altname>romage</altname>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>They might bring away a great deal more than they do, if they
would take pain in the <qex>romaging</qex>.</q>
<rj><qau>Hakluyt.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To search or examine thoroughly by looking into
every corner, and turning over or removing goods or other things; to
examine, as a book, carefully, turning over leaf after leaf.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He . . . searcheth his pockets, and taketh his keys, and so
<qex>rummageth</qex> all his closets and trunks.</q>
<rj><qau>Howell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>What schoolboy of us has not <qex>rummaged</qex> his Greek
dictionary in vain for a satisfactory account!</q> <rj><qau>M.
Arnold.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rummage</ent><br/
<hw>Rum"mage</hw>, <pos>v. i.</pos> <def>To search a place
narrowly.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I have often <qex>rummaged</qex> for old books in Little Britain
and Duck Lane.</q> <rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>[His house] was haunted with a jolly ghost, that . . .<br/
. . . <qex>rummaged</qex> like a rat.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rummager</ent><br/
<hw>Rum"ma*ger</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who
rummages.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Naut.)</fld> <def>A person on shipboard whose
business was to take charge of stowing the cargo; -- formerly written
<altname>roomager</altname>, and <altname>romager</altname>.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The master must provide a perfect mariner, called a
<qex>romager</qex>, to range and bestow all merchandise.</q>
<rj><qau>Hakluyt.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rummer</ent><br/
<hw>Rum"mer</hw> <pr>(<?/)</pr>, <pos>n.</pos> <ety>[D.
<ets>roemer</ets>, <ets>romer</ets>, akin to G. <ets>r<oum/mer</ets>,
Sw. <ets>remmare</ets>; perhaps properly, Roman.]</ety> <def>A large and
tall glass, or drinking cup.</def> <mark>[Obs.]</mark> <rj><au>J.
Philips.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rummy</ent><br/
<hw>Rum"my</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining to
rum; characteristic of rum; as a <xex>rummy</xex> flavor.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rummy</ent><br/
<hw>Rum"my</hw>, <pos>n.</pos>; <plu><it>pl.</it> <plw>Rummies</plw>
<pr>(<?/)</pr>.</plu> <def>One who drinks rum; an habitually intemperate
person.</def> <mark>[Low]</mark><br/
[<source>1913 Webster</source>]</p>

<p><-- Rummy, a game of cards. Gin rummy, a type of rummy. --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rummy</ent><br/
<hw>Rum"my</hw>, <pos>a.</pos> <ety>[See <er>Rum</er>,
<pos>a.</pos>]</ety> <def>Strange; odd.</def> <mark>[Slang]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rumney</ent><br/
<hw>Rum"ney</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A sort of Spanish
wine.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rumor</ent><br/
<hw>Ru"mor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>rumeur</ets>,
L. <ets>rumor</ets>; cf. <ets>rumificare</ets>, <ets>rumitare</ets> to
rumor, Skr. <ets>ru</ets> to cry.]</ety> <altsp>[Written also
<asp>rumour</asp>.]</altsp> <sn>1.</sn> <def>A flying or popular report;
the common talk; hence, public fame; notoriety.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This <qex>rumor</qex> of him went forth throughout all Judea, and
throughout all the region round about.</q> <rj><qau>Luke vii.
17.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Great is the <qex>rumor</qex> of this dreadful knight.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A current story passing from one person to another,
without any known authority for its truth; -- in this sense often
personified.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Rumor</qex> next, and Chance,<br/
And Tumult, and Confusion, all embroiled.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A prolonged, indistinct noise.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rumor</ent><br/
<hw>Ru"mor</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Rumored</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Rumoring</conjf>.]</vmorph> <def>To report by rumor; to
tell.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>'T was <qex>rumored</qex><br/
My father 'scaped from out the citadel.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rumorer</ent><br/
<hw>Ru"mor*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A teller of news;
especially, one who spreads false reports.</def> <-- = rumor-monger -->
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rumorous</ent><br/
<hw>Ru"mor*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. OF.
<ets>rumoreux</ets>, It. <ets>rumoroso</ets>,
<ets>romoroso</ets>.]</ety> <sn>1.</sn> <def>Of or pertaining to a
rumor; of the nature of rumors.</def> <mark>[Obs.]</mark> <rj><au>Sir H.
Wotton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Famous; notorious.</def> <mark>[Obs.]</mark>
<rj><au>Bale.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Murmuring.</def> <mark>[Obs. or Poetic]</mark>
<rj><au>Drayton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rump</ent><br/
<hw>Rump</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>rumpe</ets>;
akin to D. <ets>romp</ets> trunk, body, LG. <ets>rump</ets>, G.
<ets>rumpf</ets>, Dan. <ets>rumpe</ets> rump, Icel. <ets>rumpr</ets>,
Sw. <ets>rumpa</ets> rump, tail.]</ety> <sn>1.</sn> <def>The end of the
backbone of an animal, with the parts adjacent; the buttock or
buttocks.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Among butchers, the piece of beef between the
sirloin and the aitchbone piece. See <xex>Illust.</xex> of
<er>Beef</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <mark>Fig.:</mark> <def>The hind or tail end; a fag-end;
a remnant.</def><br/
[<source>1913 Webster</source>]</p>

<cs><p><mcol><col><b>Rump Parliament</b></col>, <it>or</it> <col><b>The
Rump</b></col></mcol> <fld>(Eng. Hist.)</fld>, <cd>the remnant of the
Long Parliament after the expulsion by <persfn>Cromwell</persfn> in 1648
of those who opposed his purposes. It was dissolved by
<persfn>Cromwell</persfn> in 1653, but twice revived for brief sessions,
ending finally in 1659.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>Rump</qex> abolished the <org>House of Lords</org>, the
army abolished the <qex>Rump</qex>, and by this army of saints
<persfn>Cromwell</persfn> governed.</q> <rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <col><b>Rump steak</b></col>, <cd>a beefsteak from the rump.</cd>
<au>Goldsmith.</au><br/
[<source>1913 Webster</source>]</p></cs>

<p><ent>Rumper</ent><br/
<hw>Rump"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A member or a
supporter of the Rump Parliament.</def> <rj><au>I.
Disraeli.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rump-fed</ent><br/
<hw>Rump"-fed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>A Shakespearean word
of uncertain meaning. Perhaps <ldquo/fattened in the rump,
pampered.<rdquo/</def> <ldquo/The <xex>rump-fed</xex> ronyon.<rdquo/<br/
[<source>1913 Webster</source>]</p>

<p><ent>Rumple</ent><br/
<hw>Rum"ple</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Rumpled</conjf> <pos>p. pr. & vb. n.</pos>
<conjf>Rumpling</conjf> <pr>(<?/)</pr>.]</vmorph> <ety>[Cf.
<ets>rimple</ets>, and D. <ets>rimpelen</ets> to wrinkle,
<ets>rompelig</ets> rough, uneven, G. <ets>r<uum/mpfen</ets> to wrinkle,
MHG. <ets>r<uum/mphen</ets>, OHG. <ets>rimpfan</ets>, Gr.
<grk>"ra`mfos</grk> the crooked beak of birds of prey, <?/ to
roam.]</ety> <def>To make uneven; to form into irregular inequalities;
to wrinkle; to crumple; <as>as, to <ex>rumple</ex> an apron or a
cravat</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They would not give a dog's ear of their most <qex>rumpled</qex>
and ragged Scotch paper for twenty of your fairest assignats.</q>
<rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rumple</ent><br/
<hw>Rum"ple</hw>, <pos>n.</pos> <def>A fold or plait; a wrinkle.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rumpled</ent><br/
<hw>Rum"pled</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Wrinkled;
crumpled.</def> <rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rumpless</ent><br/
<hw>Rump"less</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Destitute of a
rump.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rumply</ent><br/
<hw>Rum"ply</hw> <pr>(r<ucr/m"pl<ycr/)</pr>, <pos>a.</pos>
<def>Rumpled.</def> <rj><au>Carlyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rumpus</ent><br/
<hw>Rum"pus</hw> <pr>(r<ucr/m"p<ucr/s)</pr>, <pos>n.</pos> <def>A
disturbance; noise and confusion; a quarrel.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rumseller</ent><br/
<hw>Rum"sell`er</hw> <pr>(r<ucr/m"s<ecr/l`<etil/r)</pr>, <pos>n.</pos>
<def>One who sells rum; one who deals in intoxicating liquors;
especially, one who sells spirituous beverages at retail.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Run</ent><br/
<hw>Run</hw> <pr>(r<ucr/n)</pr>, <pos>v. i.</pos>
<vmorph>[<pos>imp.</pos> <conjf>Ran</conjf> <pr>(r<acr/n)</pr> or
<conjf>Run</conjf>; <pos>p. p.</pos> <conjf>Run</conjf>; <pos>p. pr. &
vb. n.</pos> <conjf>Running</conjf>.]</vmorph> <ety>[OE.
<ets>rinnen</ets>, <ets>rennen</ets> (imp. <ets>ran</ets>, p. p.
<ets>runnen</ets>, <ets>ronnen</ets>). AS. <ets>rinnan</ets> to flow
(imp. <ets>ran</ets>, p. p. <ets>gerunnen</ets>), and <ets>iernan</ets>,
<ets>irnan</ets>, to run (imp. <ets>orn</ets>, <ets>arn</ets>,
<ets>earn</ets>, p. p. <ets>urnen</ets>); akin to D. <ets>runnen</ets>,
<ets>rennen</ets>, OS. & OHG. <ets>rinnan</ets>, G. <ets>rinnen</ets>,
<ets>rennen</ets>, Icel. <ets>renna</ets>, <ets>rinna</ets>, Sw.
<ets>rinna</ets>, <ets>r<aum/nna</ets>, Dan. <ets>rinde</ets>,
<ets>rende</ets>, Goth. <ets>rinnan</ets>, and perh. to L.
<ets>oriri</ets> to rise, Gr. <grk>'orny`nai</grk> to stir up, rouse,
Skr. <ets><rsdot/</ets> (cf. <er>Origin</er>), or perh. to L.
<ets>rivus</ets> brook (cf. <er>Rival</er>). <root/11. Cf.
<er>Ember</er>, <pos>a.</pos>, <er>Rennet</er>.]</ety> <sn>1.</sn>
<def>To move, proceed, advance, pass, go, come, etc., swiftly, smoothly,
or with quick action; -- said of things animate or inanimate. Hence, to
flow, glide, or roll onward, as a stream, a snake, a wagon, etc.; to
move by quicker action than in walking, as a person, a horse, a
dog.</def> Specifically: --<br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> Of voluntary or personal action: <sd>(a)</sd> <def>To go
swiftly; to pass at a swift pace; to hasten.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><ldquo/Ha, ha, the fox!<rdquo/ and after him they
<qex>ran</qex>.</q> <rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(b)</sd> <def>To flee, as from fear or danger.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>As from a bear a man would <qex>run</qex> for life.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(c)</sd> <def>To steal off; to depart secretly.</def><br/
[<source>1913 Webster</source>]</p>

<p><sd>(d)</sd> <def>To contend in a race; hence, to enter into a
contest; to become a candidate; as, to <xex>run</xex> for
Congress.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Know ye not that they which <qex>run</qex> in a race
<qex>run</qex> all, but one receiveth the prize? So <qex>run</qex>, that
ye may obtain.</q> <rj><qau>1 Cor. ix. 24.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(e)</sd> <def>To pass from one state or condition to another; to
come into a certain condition; -- often with <xex>in</xex> or
<xex>into</xex>; as, to <xex>run</xex> into evil practices; to
<xex>run</xex> in debt.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Have I not cause to rave and beat my breast, to rend my heart with
grief and <qex>run</qex> distracted?</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(f)</sd> <def>To exert continuous activity; to proceed; <as>as,
to <ex>run</ex> through life; to <ex>run</ex> in a circle</as>.</def>
<sd>(g)</sd> <def>To pass or go quickly in thought or conversation; as,
to <xex>run</xex> from one subject to another.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Virgil, in his first Georgic, has <qex>run</qex> into a set of
precepts foreign to his subject.</q> <rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(h)</sd> <def>To discuss; to continue to think or speak about
something; -- with <xex>on</xex>.</def> <sd>(i)</sd> <def>To make
numerous drafts or demands for payment, as upon a bank; -- with
<xex>on</xex>.</def> <sd>(j)</sd> <def>To creep, as serpents.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> Of involuntary motion: <sd>(a)</sd> <def>To flow, as a
liquid; to ascend or descend; to course; <as>as, rivers <ex>run</ex> to
the sea; sap <ex>runs</ex> up in the spring; her blood <ex>ran</ex>
cold</as>.</def> <sd>(b)</sd> <def>To proceed along a surface; to
extend; to spread.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The fire <qex>ran</qex> along upon the ground.</q> <rj><qau>Ex.
ix. 23.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(c)</sd> <def>To become fluid; to melt; to fuse.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>As wax dissolves, as ice begins to <qex>run</qex>.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Sussex iron ores <qex>run</qex> freely in the fire.</q>
<rj><qau>Woodward.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(d)</sd> <def>To turn, as a wheel; to revolve on an axis or
pivot; as, a wheel <xex>runs</xex> swiftly round.</def> <sd>(e)</sd>
<def>To travel; to make progress; to be moved by mechanical means; to
go; <as>as, the steamboat <ex>runs</ex> regularly to Albany; the train
<ex>runs</ex> to Chicago</as>.</def> <sd>(f)</sd> <def>To extend; to
reach; <as>as, the road <ex>runs</ex> from Philadelphia to New York; the
memory of man <ex>runneth</ex> not to the contrary</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>She saw with joy the line immortal <qex>run</qex>,<br/
Each sire impressed, and glaring in his son.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(g)</sd> <def>To go back and forth from place to place; to ply;
as, the stage <xex>runs</xex> between the hotel and the
station.</def><-- same as (e)? --> <sd>(h)</sd> <def>To make progress;
to proceed; to pass.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>As fast as our time <qex>runs</qex>, we should be very glad in
most part of our lives that it <qex>ran</qex> much faster.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(i)</sd> <def>To continue in operation; to be kept in action or
motion; <as>as, this engine <ex>runs</ex> night and day; the mill
<ex>runs</ex> six days in the week</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>When we desire anything, our minds <qex>run</qex> wholly on the
good circumstances of it; when it is obtained, our minds run wholly on
the bad ones.</q> <rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(j)</sd> <def>To have a course or direction; as, a line
<xex>runs</xex> east and west.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Where the generally allowed practice <qex>runs</qex> counter to
it.</q> <rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Little is the wisdom, where the flight<br/
So <qex>runs</qex> against all reason.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(k)</sd> <def>To be in form thus, as a combination of
words.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The king's ordinary style <qex>runneth</qex>, <ldquo/Our sovereign
lord the king.<rdquo/</q> <rj><qau>Bp. Sanderson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(l)</sd> <def>To be popularly known; to be generally
received.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Men gave them their own names, by which they <qex>run</qex> a
great while in Rome.</q> <rj><qau>Sir W. Temple.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Neither was he ignorant what report <qex>ran</qex> of himself.</q>
<rj><qau>Knolles.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1261 --></p>

<p><sd>(m)</sd> <def>To have growth or development; <as>as, boys and
girls <ex>run</ex> up rapidly</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If the richness of the ground cause turnips to <qex>run</qex> to
leaves.</q> <rj><qau>Mortimer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(n)</sd> <def>To tend, as to an effect or consequence; to
incline.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A man's nature <qex>runs</qex> either to herbs or weeds.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Temperate climates <qex>run</qex> into moderate governments.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(o)</sd> <def>To spread and blend together; to unite; <as>as,
colors <ex>run</ex> in washing</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In the middle of a rainbow the colors are . . . distinguished, but
near the borders they <qex>run</qex> into one another.</q> <rj><qau>I.
Watts.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(p)</sd> <def>To have a legal course; to be attached; to continue
in force, effect, or operation; to follow; to go in company; <as>as,
certain covenants <ex>run</ex> with the land</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Customs <qex>run</qex> only upon our goods imported or exported,
and that but once for all; whereas interest <qex>runs</qex> as well upon
our ships as goods, and must be yearly paid.</q> <rj><qau>Sir J.
Child.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sd>(q)</sd> <def>To continue without falling due; to hold good;
<as>as, a note has thirty days to <ex>run</ex></as>.</def> <sd>(r)</sd>
<def>To discharge pus or other matter; <as>as, an ulcer
<ex>runs</ex></as>.</def> <sd>(s)</sd> <def>To be played on the stage a
number of successive days or nights; <as>as, the piece <ex>ran</ex> for
six months</as>.</def> <sd>(t)</sd> <fld>(Naut.)</fld> <def>To sail
before the wind, in distinction from reaching or sailing closehauled; --
said of vessels.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Specifically, of a horse: To move rapidly in a gait
in which each leg acts in turn as a propeller and a supporter, and in
which for an instant all the limbs are gathered in the air under the
body.</def> <rj><au>Stillman (The Horse in Motion).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Athletics)</fld> <def>To move rapidly by springing
steps so that there is an instant in each step when neither foot touches
the ground; -- so distinguished from <xex>walking</xex> in athletic
competition.</def><br/
[<source>1913 Webster</source>]</p>

<cs><p><col><b>As things run</b></col>, <cd>according to the usual
order, conditions, quality, etc.; on the average; without selection or
specification.</cd> -- <col><b>To let run</b></col> <fld>(Naut.)</fld>,
<cd>to allow to pass or move freely; to slacken or loosen.</cd> --
<col><b>To run after</b></col>, <cd>to pursue or follow; to search for;
to endeavor to find or obtain; <as>as, <ex>to run after</ex>
similes</as>.</cd> <au>Locke.</au> -- <col><b>To run away</b></col>,
<cd>to flee; to escape; to elope; to run without control or
guidance.</cd> -- <col><b>To run away with</b></col>. <sd>(a)</sd>
<cd>To convey away hurriedly; to accompany in escape or elopement.</cd>
<sd>(b)</sd> <cd>To drag rapidly and with violence; <as>as, a horse
<ex>runs away with</ex> a carriage</as>.</cd> -- <col><b>To run
down</b></col>. <sd>(a)</sd> <cd>To cease to work or operate on account
of the exhaustion of the motive power; -- said of clocks, watches,
etc.</cd><-- batteries --> <sd>(b)</sd> <cd>To decline in condition;
<as>as, <ex>to run down</ex> in health</as>.</cd> -- <col><b>To run down
a coast</b></col>, <cd>to sail along it.</cd> -- <col><b>To run for an
office</b></col>, <cd>to stand as a candidate for an office.</cd> --
<mcol><col><b>To run in</b></col> <it>or</it> <col><b>To run
into</b></col></mcol>. <sd>(a)</sd> <cd>To enter; to step in</cd>.
<sd>(b)</sd> <cd>To come in collision with.</cd> -- <col><b>To run
into</b></col> <cd>To meet, by chance; <as>as, I <ex>ran into</ex> my
brother at the grocery store</as>.</cd> -- <col><b>To run in
trust</b></col>, <cd>to run in debt; to get credit.</cd>
<mark>[Obs.]</mark> -- <col><b>To run in with</b></col>. <sd>(a)</sd>
<cd>To close; to comply; to agree with.</cd> <mark>[R.]</mark> <au>T.
Baker.</au> <sd>(b)</sd> <fld>(Naut.)</fld> <cd>To make toward; to near;
to sail close to; as, <xex>to run in with</xex> the land.</cd> --
<mcol><col><b>To run mad</b></col>, <col><b>To run mad after</b></col>
<it>or</it> <col><b>To run mad on</b></col></mcol>. <cd>See under
<er>Mad</er>.</cd> -- <col><b>To run on</b></col>. <sd>(a)</sd> <cd>To
be continued; as, their accounts had <xex>run on</xex> for a year or two
without a settlement.</cd> <sd>(b)</sd> <cd>To talk incessantly</cd>.
<sd>(c)</sd> <cd>To continue a course</cd>. <sd>(d)</sd> <cd>To press
with jokes or ridicule; to abuse with sarcasm; to bear hard on</cd>.
<sd>(e)</sd> <fld>(Print.)</fld> <cd>To be continued in the same lines,
without making a break or beginning a new paragraph</cd>. -- <col><b>To
run out</b></col>. <sd>(a)</sd> <cd>To come to an end; to expire;
<as>as, the lease <ex>runs out</ex> at Michaelmas</as>.</cd>
<sd>(b)</sd> <cd>To extend; to spread</cd>. <ldquo/Insectile animals . .
. <xex>run</xex> all <xex>out</xex> into legs.<rdquo/ <au>Hammond.</au>
<sd>(c)</sd> <cd>To expatiate; as, <xex>to run out</xex> into beautiful
digressions.</cd> <sd>(d)</sd> <cd>To be wasted or exhausted; to become
poor; to become extinct; as, an estate managed without economy will soon
<xex>run out</xex>.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>And had her stock been less, no doubt<br/
She must have long ago <qex>run out</qex>.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <col><b>To run over</b></col>. <sd>(a)</sd> <cd>To overflow;
<as>as, a cup <ex>runs over</ex>, or the liquor <ex>runs
over</ex></as>.</cd> <sd>(b)</sd> <cd>To go over, examine, or rehearse
cursorily</cd>. <sd>(c)</sd> <cd>To ride or drive over; <as>as, <ex>to
run over</ex> a child</as>.</cd> -- <col><b>To run riot</b></col>,
<cd>to go to excess.</cd> -- <col><b>To run through</b></col>.
<sd>(a)</sd> <cd>To go through hastily; <as>as <ex>to run through</ex> a
book</as>.</cd> <sd>(b)</sd> <cd>To spend wastefully; as, to run through
an estate.</cd> -- <col><b>To run to seed</b></col>, <cd>to expend or
exhaust vitality in producing seed, as a plant; figuratively and
colloquially, to cease growing; to lose vital force, as the body or
mind.</cd> -- <col><b>To run up</b></col>, <cd>to rise; to swell; to
grow; to increase; as, accounts of goods credited <xex>run up</xex> very
fast.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>But these, having been untrimmed for many years, had <qex>run
up</qex> into great bushes, or rather dwarf trees.</q> <rj><qau>Sir W.
Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <col><b>To run with</b></col>. <sd>(a)</sd> <cd>To be drenched
with, so that streams flow; <as>as, the streets <ex>ran with</ex>
blood</as>.</cd> <sd>(b)</sd> <cd>To flow while charged with some
foreign substance</cd>. <ldquo/Its rivers <xex>ran with</xex>
gold.<rdquo/ <au>J. H. Newman.</au><br/
[<source>1913 Webster</source>]</p></cs>

<p><ent>Run</ent><br/
<hw>Run</hw> <pr>(<?/)</pr>, <pos>v. t.</pos> <sn>1.</sn> <def>To cause
to run (in the various senses of <er>Run</er>, <pos>v. i.</pos>);
<as>as, to <ex>run</ex> a horse; to <ex>run</ex> a stage; to
<ex>run</ex> a machine; to <ex>run</ex> a rope through a
block</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To pursue in thought; to carry in
contemplation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>run</qex> the world back to its first original.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I would gladly understand the formation of a soul, and
<qex>run</qex> it up to its <ldquo/punctum saliens.<rdquo/</q>
<rj><qau>Collier.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To cause to enter; to thrust; <as>as, to
<ex>run</ex> a sword into or through the body; to <ex>run</ex> a nail
into the foot</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>You <qex>run</qex> your head into the lion's mouth.</q>
<rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Having <qex>run</qex> his fingers through his hair.</q>
<rj><qau>Dickens.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To drive or force; to cause, or permit, to be
driven.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They <qex>ran</qex> the ship aground.</q> <rj><qau>Acts xxvii.
41.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A talkative person <qex>runs</qex> himself upon great
inconveniences by blabbing out his own or other's secrets.</q>
<rj><qau>Ray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Others, accustomed to retired speculations, <qex>run</qex> natural
philosophy into metaphysical notions.</q> <rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To fuse; to shape; to mold; to cast; <as>as, to
<ex>run</ex> bullets, and the like</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The purest gold must be <qex>run</qex> and washed.</q>
<rj><qau>Felton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To cause to be drawn; to mark out; to indicate; to
determine; <as>as, to <ex>run</ex> a line</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>To cause to pass, or evade, official restrictions;
to smuggle; -- said of contraband or dutiable goods.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Heavy impositions . . . are a strong temptation of
<qex>running</qex> goods.</q> <rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>To go through or accomplish by running; <as>as, to
<ex>run</ex> a race; to <ex>run</ex> a certain career</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>To cause to stand as a candidate for office; to
support for office; <as>as, to <ex>run</ex> some one for
Congress</as>.</def> <mark>[Colloq. U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <def>To encounter or incur, as a danger or risk; <as>as,
to <ex>run</ex> the risk of losing one's life. See <ex>To run the
chances</ex>, below</as>.</def> <ldquo/He <xex>runneth</xex> two
dangers.<rdquo/ <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>If we don't succeed, we <ex>run the risk</ex> of failure.</q>
<qau>Dan Quail</qau>.<br/
[<source>PJC</source>]</p>

<p><sn>11.</sn> <def>To put at hazard; to venture; to risk.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He would himself be in the Highlands to receive them, and
<qex>run</qex> his fortune with them.</q>
<rj><qau>Clarendon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>12.</sn> <def>To discharge; to emit; to give forth copiously; to
be bathed with; <as>as, the pipe or faucet <ex>runs</ex> hot
water</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>At the base of Pompey's statua,<br/
Which all the while <qex>ran</qex> blood, great Caesar fell.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>13.</sn> <def>To be charged with, or to contain much of, while
flowing; <as>as, the rivers <ex>ran</ex> blood</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>14.</sn> <def>To conduct; to manage; to carry on; <as>as, to
<ex>run</ex> a factory or a hotel</as>.</def> <mark>[Colloq.
U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>15.</sn> <def>To tease with sarcasms and ridicule.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>16.</sn> <def>To sew, as a seam, by passing the needle through
material in a continuous line, generally taking a series of stitches on
the needle at the same time.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>17.</sn> <def>To migrate or move in schools; -- said of fish;
esp., to ascend a river in order to spawn.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>18.</sn> <fld>(Golf)</fld> <def>To strike (the ball) in such a
way as to cause it to run along the ground, as when approaching a
hole.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><cs><col><b>To run a blockade</b></col>, <cd>to get to, or away from,
a blockaded port in safety.</cd> -- <col><b>To run down</b></col>.
<sd>(a)</sd> <fld>(Hunting)</fld> <cd>To chase till the object pursued
is captured or exhausted; <as>as, <ex>to run down</ex> a stag</as></cd>.
<sd>(b)</sd> <fld>(Naut.)</fld> <cd>To run against and sink, as a
vessel</cd>. <sd>(c)</sd> <cd>To crush; to overthrow; to overbear</cd>.
<ldquo/Religion is <xex>run down</xex> by the license of these
times.<rdquo/ <au>Berkeley.</au> <sd>(d)</sd> <cd>To disparage; to
traduce.</cd> <au>F. W. Newman.</au> -- <col><b>To run hard</b></col>.
<sd>(a)</sd> <cd>To press in competition; <as>as, <ex>to run</ex> one
<ex>hard</ex> in a race</as>.</cd> <sd>(b)</sd> <cd>To urge or press
importunately</cd>. <sd>(c)</sd> <cd>To banter severely.</cd> --
<col><b>To run into the ground</b></col>, <cd>to carry to an absurd
extreme; to overdo.</cd> <mark>[Slang, U.S.]</mark><-- also, to operate
a machine (as a car) without maintenance, until it malfunctions or
becomes useless --> -- <col><b>To run off</b></col>, <cd>to cause to
flow away, as a charge of molten metal from a furnace.</cd> --
<col><b>To run on</b></col> <fld>(Print.)</fld>, <cd>to carry on or
continue, as the type for a new sentence, without making a break or
commencing a new paragraph.</cd> -- <col><b>To run out</b></col>.
<sd>(a)</sd> <cd>To thrust or push out; to extend.</cd> <sd>(b)</sd>
<cd>To waste; to exhaust; <as>as, <ex>to run out</ex> an
estate</as>.</cd> <sd>(c)</sd> <fld>(Baseball)</fld> <cd>To put out
while running between two bases. Also called <col><b>to run
out</b></col>.</cd> -- <mcol><col><b>To run the chances</b></col>
<it>or</it> <col><b>To run one's chances</b></col></mcol>, <cd>to
encounter all the risks of a certain course.</cd> -- <col><b>To run
through</b></col>, <cd>to transfix; to pierce, as with a sword.</cd>
<ldquo/[He] was <xex>run through</xex> the body by the man who had asked
his advice.<rdquo/ <au>Addison.</au> -- <col><b>To run up</b></col>.
<sd>(a)</sd> <cd>To thrust up, as anything long and slender.</cd>
<sd>(b)</sd> <cd>To increase; to enlarge by additions, as an
account</cd>.<-- e.g. to incur a debt, as to <ex>run up</ex> a bill -->
<sd>(c)</sd> <cd>To erect hastily, as a building</cd>.</cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Run</ent><br/
<hw>Run</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The act of
running; <as>as, a long <ex>run</ex>; a good <ex>run</ex>; a quick
<ex>run</ex>; to go on the <ex>run</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A small stream; a brook; a creek.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which runs or flows in the course of a certain
operation, or during a certain time; <as>as, a <ex>run</ex> of must in
wine making; the first <ex>run</ex> of sap in a maple
orchard</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A course; a series; that which continues in a
certain course or series; <as>as, a <ex>run</ex> of good or bad
luck</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They who made their arrangements in the first <qex>run</qex> of
misadventure . . . put a seal on their calamities.</q>
<rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>State of being current; currency;
popularity.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It is impossible for detached papers to have a general
<qex>run</qex>, or long continuance, if not diversified with humor.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Continued repetition on the stage; -- said of a
play; <as>as, to have a <ex>run</ex> of a hundred successive
nights</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A canting, mawkish play . . . had an immense <qex>run</qex>.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>A continuing urgent demand; especially, a pressure
on a bank or treasury for payment of its notes.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>A range or extent of ground for feeding stock;
<as>as, a sheep <ex>run</ex></as>.</def> <rj><au>Howitt.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <fld>(Naut.)</fld> <sd>(a)</sd> <def>The aftermost part
of a vessel's hull where it narrows toward the stern, under the
quarter.</def> <sd>(b)</sd> <def>The distance sailed by a ship; <as>as,
a good <ex>run</ex>; a <ex>run</ex> of fifty miles</as>.</def>
<sd>(c)</sd> <def>A voyage; <as>as, a <ex>run</ex> to
China</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <def>A pleasure excursion; a trip.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I think of giving her a <qex>run</qex> in London.</q>
<rj><qau>Dickens.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>11.</sn> <fld>(Mining)</fld> <def>The horizontal distance to
which a drift may be carried, either by license of the proprietor of a
mine or by the nature of the formation; also, the direction which a vein
of ore or other substance takes.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>12.</sn> <fld>(Mus.)</fld> <def>A roulade, or series of running
tones.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>13.</sn> <fld>(Mil.)</fld> <def>The greatest degree of swiftness
in marching. It is executed upon the same principles as the
double-quick, but with greater speed.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>14.</sn> <def>The act of migrating, or ascending a river to
spawn; -- said of fish; also, an assemblage or school of fishes which
migrate, or ascend a river for the purpose of spawning.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>15.</sn> <fld>(Sport)</fld> <def>In baseball, a complete circuit
of the bases made by a player, which enables him to score one point;
also, the point thus scored; in cricket, a passing from one wicket to
the other, by which one point is scored; <as>as, a player made three
<ex>runs</ex>; the side went out with two hundred <ex>runs</ex>; the
Yankees scored three <ex>runs</ex> in the seventh inning</as>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><q>The <ldquo/<qex>runs</qex><rdquo/ are made from wicket to wicket,
the batsmen interchanging ends at each <qex>run</qex>.</q> <rj><qau>R.
A. Proctor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>16.</sn> <def>A pair or set of millstones.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>17.</sn> <fld>(Piquet, Cribbage, etc.)</fld> <def>A number of
cards of the same suit in sequence; <as>as, a <ex>run</ex> of four in
hearts</as>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>18.</sn> <fld>(Golf)</fld> <sd>(a)</sd> <def>The movement
communicated to a golf ball by running.</def> <sd>(b)</sd> <def>The
distance a ball travels after touching the ground from a
stroke.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<cs><p><mcol><col><b>At the long run</b></col>, <it>now, commonly</it>,
<col><b>In the long run</b></col></mcol>, <cd>in or during the whole
process or course of things taken together; in the final result; in the
end; finally.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>[Man] starts the inferior of the brute animals, but he surpasses
them <qex>in the long run</qex>.</q> <rj><qau>J. H.
Newman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <col><b>Home run</b></col>. <sd>(a)</sd> <cd>A running or
returning toward home, or to the point from which the start was
made.</cd> Cf. <cref>Home stretch</cref>. <sd>(b)</sd>
<fld>(Baseball)</fld> <cd>See under <er>Home</er>.</cd> --
<mcol><col><b>The run</b></col>, <it>or</it> <col><b>The common
run</b></col>, <it>or</it> <col><b>The run of the mill</b></col>
etc.</mcol>, <cd>ordinary persons; the generality or average of people
or things; also, that which ordinarily occurs; ordinary current, course,
or kind.</cd><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><q>I saw nothing else that is superior to <qex>the common run</qex>
of parks.</q> <rj><qau>Walpole.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Burns never dreamed of looking down on others as beneath him,
merely because he was conscious of his own vast superiority to <qex>the
common run</qex> of men.</q> <rj><qau>Prof. Wilson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>His whole appearance was something out of <qex>the common
run</qex>.</q> <rj><qau>W. Irving.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <col><b>To let go by the run</b></col> <fld>(Naut.)</fld>, <cd>to
loosen and let run freely, as lines; to let fall without restraint, as a
sail.</cd><br/
[<source>1913 Webster</source>]</p></cs>

<p><ent>Run</ent><br/
<hw>Run</hw>, <pos>a.</pos> <sn>1.</sn> <def>Melted, or made from molten
material; cast in a mold; <as>as, <ex>run</ex> butter; <ex>run</ex> iron
or lead</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Smuggled; <as>as, <ex>run</ex> goods</as>.</def>
<mark>[Colloq.]</mark> <rj><au>Miss Edgeworth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Run steel</b></col>, <cd>malleable iron castings. See
under <er>Malleable</er>.</cd> <rj><au>Raymond.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Runagate</ent><br/
<hw>Run"a*gate</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>ren<eacute/gat</ets>, Prov. <ets>renegat</ets>. LL.
<ets>renegatus</ets>; confused with E. <ets>run</ets> and
<ets>gate</ets> a way. See <er>Renegade</er>.]</ety> <def>A fugitive; a
vagabond; an apostate; a renegade. See <er>Renegade</er>.</def>
<rj><au>Bunyan.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Wretched <qex>runagates</qex> from the jail.</q> <rj><qau>De
Quincey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Who has not been a <qex>runagate</qex> from duty?</q>
<rj><qau>Hare.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Run-around</ent><br/
<hw>Run"-a*round`</hw>, <pos>n.</pos> <fld>(Med.)</fld> <def>A whitlow
running around the finger nail, but not affecting the bone.</def>
<mark>[Colloq.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Runaround</ent><br/
<hw>Run"a*round`</hw>, <pos>n.</pos> <def>a delaying or evasive, and
sometimes deceptive, answer to an inquiry or request.</def><br/
[<source>PJC</source>]</p>

<p><ent>Runaway</ent><br/
<hw>Run"a*way`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One
who, or that which, flees from danger, duty, restraint, etc.; a
fugitive.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou <qex>runaway</qex>, thou coward, art thou fled?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The act of running away, esp. of a horse or teams;
<as>as, there was a <ex>runaway</ex> yesterday</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Runaway</ent><br/
<hw>Run"a*way`</hw>, <pos>a.</pos> <sn>1.</sn> <def>Running away;
fleeing from danger, duty, restraint, etc.; <as>as, <ex>runaway</ex>
soldiers; a <ex>runaway</ex> horse</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Accomplished by running away or elopement, or during
flight; <as>as, a <ex>runaway</ex> marriage</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- <sn>3.</sn> <sd>(a)</sd> <def>Won by a long lead; <as>as, a
<ex>runaway</ex> victory</as>.</def> <sd>(b)</sd> <def>Very successful;
accomplishing success quickly; <as>as, a <ex>runaway</ex>
bestseller</as>.</def> --> <br/
[<source>1913 Webster</source>]</p>

<p><ent>Runcation</ent><br/
<hw>Run*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>runcatio</ets>, fr. <ets>runcare</ets> to weed out.]</ety> <def>A
weeding.</def> <mark>[Obs.]</mark> <rj><au>Evelyn.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Runch</ent><br/
<hw>Runch</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>The
wild radish.</def> <rj><au>Dr. Prior.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Runcinate</ent><br/
<hw>Run"ci*nate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>runcinatus</ets>, p. p. of <ets>runcinare</ets> to plane off, fr.
<ets>runcina</ets> a plane.]</ety> <fld>(Bot.)</fld> <def>Pinnately cut
with the lobes pointing downwards, as the leaf of the
dandelion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rundel</ent><br/
<hw>Run"del</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf.
<er>Rindle</er>.]</ety> <def>A moat with water in it; also, a small
stream; a runlet.</def> <mark>[Prov. Eng.]</mark>
<rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rundel</ent><br/
<hw>Run"del</hw>, <pos>n.</pos> <ety>[Cf. <er>Rundle</er>.]</ety> <def>A
circle.</def> <mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rundle</ent><br/
<hw>Run"dle</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[E. <ets>round</ets>.
Cf. <er>Rondle</er>.]</ety> <sn>1.</sn> <def>A round; a step of a
ladder; a rung.</def> <rj><au>Duppa.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A ball.</def> <mark>[Obs.]</mark>
<rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Something which rotates about an axis, as a wheel,
or the drum of a capstan.</def> <ldquo/An axis or cylinder having a
<xex>rundle</xex> about it.<rdquo/ <rj><au>Bp. Wilkins.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Mach.)</fld> <def>One of the pins or trundles of a
lantern wheel.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rundlet</ent><br/
<hw>Rund"let</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Dim. of OF.
<ets>rondele</ets> a little tun, fr. <ets>rond</ets> round. See
<er>Round</er>, and cf. <er>Roundlet</er>, <er>Runlet</er>.]</ety>
<def>A small barrel of no certain dimensions. It may contain from 3 to
20 gallons, but it usually holds about 14<frac12/ gallons.</def>
<altsp>[Written also <asp>runlet</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rune</ent><br/
<hw>Rune</hw> <pr>(r<udd/n)</pr>, <pos>n.</pos> <ety>[AS.
<ets>r<umac/n</ets> a rune, a secret, a mystery; akin to Icel.
<ets>r<umac/n</ets>, OHG. & Goth. <ets>r<umac/na</ets> a secret, secret
colloquy, G. & Dan. <ets>rune</ets> rune, and probably to Gr.
<grk>'ereyna^n</grk> to search for. Cf. <er>Roun</er> to whisper.]</ety>
<sn>1.</sn> <def>A letter, or character, belonging to the written
language of the ancient Norsemen, or Scandinavians; in a wider sense,
applied to the letters of the ancient nations of Northern Europe in
general.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The Norsemen had a peculiar alphabet, consisting of
sixteen letters, or characters, called <xex>runes</xex>, the origin of
which is lost in the remotest antiquity. The signification of the word
<xex>rune</xex> (mystery) seems to allude to the fact that originally
only a few were acquainted with the use of these marks, and that they
were mostly applied to secret tricks, witchcrafts and enchantments. But
the runes were also used in communication by writing.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <pluf>pl.</pluf> <def>Old Norse poetry expressed in
runes.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Runes</qex> were upon his tongue,<br/
As on the warrior's sword.</q> <rj><qau>Longfellow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Rune stone</b></col>, <cd>a stone bearing a runic
inscription.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Runer</ent><br/
<hw>Ru"ner</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A bard, or learned man,
among the ancient Goths.</def> <rj><au>Sir W. Temple.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rung</ent><br/
<hw>Rung</hw> <pr>(?)</pr>, <def><pos>imp. & p. p.</pos> of
<er>Ring</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rung</ent><br/
<hw>Rung</hw>, <pos>n.</pos> <ety>[OE. <ets>ronge</ets>, AS.
<ets>hrung</ets>, a staff, rod, pole; akin to G. <ets>runge</ets> a
short, thick piece of iron or wood, OD. <ets>ronghe</ets> a prop,
support, Icel. <ets>r<oum/ng</ets> a rib in a ship, Goth.
<ets>Hrugga</ets> a staff.]</ety> <sn>1.</sn> <fld>(Shipbuilding)</fld>
<def>A floor timber in a ship.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One of the rounds of a ladder.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>One of the stakes of a cart; a spar; a heavy
staff.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Mach.)</fld> <def>One of the radial handles
projecting from the rim of a steering wheel; also, one of the pins or
trundles of a lantern wheel.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Runghead</ent><br/
<hw>Rung"head`</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Shipbuilding)</fld> <def>The upper end of a floor timber in a
ship.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Runic</ent><br/
<hw>Ru"nic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining to a
rune, to runes, or to the Norsemen; <as>as, <ex>runic</ex> verses;
<ex>runic</ex> letters; <ex>runic</ex> names; <ex>runic</ex>
rhyme</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Runic staff</b></col>. <cd>See <cref>Clog almanac</cref>,
under <er>Clog</er>.</cd> -- <col><b>Runic wand</b></col>, <cd>a willow
wand bearing runes, formerly thought to have been used by the heathen
tribes of Northern Europe in magical ceremonies.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Run-in</ent><br/
<hw>Run"-in</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An argument or
quarrel.</def><br/
[<source>PJC</source>]</p>

<p><ent>Runlet</ent><br/
<hw>Run"let</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Run</ets> +
<ets>-let</ets>.]</ety> <def>A little run or stream; a streamlet; a
brook.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To trace out to its marshy source every <qex>runlet</qex> that has
cast in its tiny pitcherful with the rest.</q>
<rj><qau>Lowell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Runlet</ent><br/
<hw>Run"let</hw>, <pos>n.</pos> <def>Same as <er>Rundlet</er>.</def>
<ldquo/A stoup of sack, or a <xex>runlet</xex> of canary.<rdquo/
<rj><au>Sir W. Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Runnel</ent><br/
<hw>Run"nel</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From <er>Run</er>.
Cf. <er>Rindle</er>.]</ety> <def>A rivulet or small brook.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Bubbling <qex>runnels</qex> joined the sound.</q>
<rj><qau>Collins.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>By the very sides of the way . . . there are slow
<qex>runnels</qex>, in which one can see the minnows swimming.</q>
<rj><qau>Masson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Runner</ent><br/
<hw>Run"ner</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<er>Run</er>.]</ety> <sn>1.</sn> <def>One who, or that which, runs; a
racer.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A detective.</def> <mark>[Slang, Eng.]</mark>
<rj><au>Dickens.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A messenger.</def> <rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A smuggler.</def> <mark>[Colloq.]</mark> <rj><au>R.
North.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>One employed to solicit patronage, as for a
steamboat, hotel, shop, etc.</def> <mark>[Cant, U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Bot.)</fld> <def>A slender trailing branch which
takes root at the joints or end and there forms new plants, as in the
strawberry and the common cinquefoil.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>The rotating stone of a set of millstones.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <fld>(Naut.)</fld> <def>A rope rove through a block and
used to increase the mechanical power of a tackle.</def>
<rj><au>Totten.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1262 --></p>

<p><sn>9.</sn> <def>One of the pieces on which a sled or sleigh slides;
also the part or blade of a skate which slides on the ice.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <fld>(Founding)</fld> <sd>(a)</sd> <def>A horizontal
channel in a mold, through which the metal flows to the cavity formed by
the pattern; also, the waste metal left in such a channel.</def>
<sd>(b)</sd> <def>A trough or channel for leading molten metal from a
furnace to a ladle, mold, or pig bed.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>11.</sn> <def>The movable piece to which the ribs of an umbrella
are attached.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>12.</sn> <fld>(Zool.)</fld> <def>A food fish (<spn>Elagatis
pinnulatus</spn>) of Florida and the West Indies; -- called also
<altname>skipjack</altname>, <altname>shoemaker</altname>, and
<altname>yellowtail</altname>. The name alludes to its rapid successive
leaps from the water.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>13.</sn> <fld>(Zool.)</fld> <def>Any cursorial bird.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>14.</sn> <fld>(Mech.)</fld> <sd>(a)</sd> <def>A movable slab or
rubber used in grinding or polishing a surface of stone.</def>
<sd>(b)</sd> <def>A tool on which lenses are fastened in a group, for
polishing or grinding.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Runnet</ent><br/
<hw>Run"net</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Rennet</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Running</ent><br/
<hw>Run"ning</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Moving or
advancing by running.</def> <specif>Specifically, of a horse:</specif>
<sd>(a)</sd> <def>Having a running gait; not a trotter or pacer.</def>
<sd>(b)</sd> <def>trained and kept for running races; <as>as, a
<ex>running</ex> horse</as>.</def> <rj><au>Law.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Successive; one following the other without break or
intervention; -- said of periods of time; <as>as, to be away two days
<ex>running</ex>; to sow land two years <ex>running</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Flowing; easy; cursive; <as>as, a <ex>running</ex>
hand</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Continuous; keeping along step by step; <as>as, he
stated the facts with a <ex>running</ex> explanation</as>.</def>
<ldquo/A <xex>running</xex> conquest.<rdquo/
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>What are art and science if not a <qex>running</qex> commentary on
Nature?</q> <rj><qau>Hare.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Bot.)</fld> <def>Extending by a slender climbing or
trailing stem; <as>as, a <ex>running</ex> vine</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Med.)</fld> <def>Discharging pus; <as>as, a
<ex>running</ex> sore</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Running block</b></col> <fld>(Mech.)</fld>, <cd>a block
in an arrangement of pulleys which rises or sinks with the weight which
is raised or lowered.</cd> -- <col><b>Running board</b></col>, <cd>a
narrow platform extending along the side of a locomotive.</cd><-- or
automobile(pre-1960) --> -- <col><b>Running bowsprit</b></col>
<fld>(Naut.)</fld> <cd>Same as <cref>Reefing bowsprit</cref>.</cd> --
<col><b>Running days</b></col> <fld>(Com.)</fld>, <cd>the consecutive
days occupied on a voyage under a charter party, including Sundays and
not limited to the working days.</cd> <au>Simmonds.</au> --
<col><b>Running fire</b></col>, <cd>a constant fire of musketry or
cannon.</cd> -- <col><b>Running gear</b></col>, <cd>the wheels and axles
of a vehicle, and their attachments, in distinction from the body; all
the working parts of a locomotive or other machine, in distinction from
the framework.</cd> -- <col><b>Running hand</b></col>, <cd>a style of
rapid writing in which the letters are usually slanted and the words
formed without lifting the pen; -- distinguished from <cref>round
hand</cref>.</cd> -- <col><b>Running part</b></col> <fld>(Naut.)</fld>,
<cd>that part of a rope that is hauled upon, -- in distinction from the
<contr>standing part</contr>.</cd> -- <col><b>Running rigging</b></col>
<fld>(Naut.)</fld>, <cd>that part of a ship's rigging or ropes which
passes through blocks, etc.; -- in distinction from <contr>standing
rigging</contr>. </cd> -- <col><b>Running title</b></col>
<fld>(Print.)</fld>, <cd>the title of a book or chapter continued from
page to page on the upper margin.</cd><-- it may be different, for
conciseness, from the full title on the title page. --></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Running</ent><br/
<hw>Run"ning</hw>, <pos>n.</pos> <def>The act of one who, or of that
which runs; <as>as, the <ex>running</ex> was slow</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which runs or flows; the quantity of a liquid
which flows in a certain time or during a certain operation; <as>as, the
first <ex>running</ex> of a still</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The discharge from an ulcer or other sore.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>At long running</b></col>, <cd>in the long run.</cd>
<mark>[Obs.]</mark> <au>Jer. Taylor.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Running load</ent><br/
<hw>Run"ning load</hw>. <fld>(Aeronautics)</fld> <sd>(a)</sd> <def>The
air pressure supported by each longitudinal foot segment of a
wing.</def> <sd>(b)</sd> <def>Commonly, the whole weight of aeroplane
and load divided by the span, or length from tip to tip.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Runningly</ent><br/
<hw>Run"ning*ly</hw>, <pos>adv.</pos> <def>In a running
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Runnion</ent><br/
<hw>Run"nion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Ronion.</er></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>run-of-the-mill</ent><br/
<hw>run-of-the-mill</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Ordinary;
common; unexceptional.</def><br/
[<source>PJC</source>]</p>

<p><ent>Runology</ent><br/
<hw>Ru*nol"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Rune</ets> +
<ets>-logy</ets>.]</ety> <def>The science of runes.</def> --
<wordforms><wf>Ru*nol"o*gist</wf> <pr>(#)</pr>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Runround</ent><br/
<hw>Run"round`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A felon or
whitlow.</def> <mark>[Colloq. U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Runt</ent><br/
<hw>Runt</hw> <pr>(?)</pr>, <pos>n.</pos> <altsp>[Written also
<asp>rant</asp>.]</altsp> <ety>[Scot. <ets>runt</ets> an old cow, an
old, withered woman, a hardened stem or stalk, the trunk of a tree; cf.
D. <ets>rund</ets> a bullock, an ox or cow, G. <ets>rind</ets>. Cf.
<er>Rother</er>, <pos>a.</pos>]</ety> <sn>1.</sn> <fld>(Zool.)</fld>
<def>Any animal which is unusually small, as compared with others of its
kind; -- applied particularly to domestic animals.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>A variety of domestic pigeon,
related to the barb and carrier.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A dwarf; also, a mean, despicable, boorish person;
-- used opprobriously.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Before I buy a bargain of such <qex>runts</qex>,<br/
I'll buy a college for bears, and live among 'em.</q> <rj><qau>Beau. &
Fl.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The dead stump of a tree; also, the stem of a
plant.</def> <mark>[Obs. or Prov. Eng.]</mark>
<rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Neither young poles nor old <qex>runts</qex> are durable.</q>
<rj><qau>Holland.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Runty</ent><br/
<hw>Runt"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Like a runt;
diminutive; mean.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Runway</ent><br/
<hw>Run"way`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
channel of a stream.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The beaten path made by deer or other animals in
passing to and from their feeding grounds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rupee</ent><br/
<hw>Ru*pee"</hw> <pr>(r<usdot/*p<emac/")</pr>, <pos>n.</pos> <ety>[Hind.
<ets>r<umac/piyah</ets>, fr. Skr. <ets>r<umac/pya</ets> silver, coined
silver or gold, handsome.]</ety> <def>A silver coin, and money of
account, in the East Indies.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The valuation of the rupee of sixteen annas, the
standard coin of India, by the United States Treasury department, varies
from time to time with the price of silver. In 1889 it was rated at
about thirty-two cents.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rupellary</ent><br/
<hw>Ru"pel*la*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From L.
<ets>rupes</ets> a rock.]</ety> <def>Rocky.</def> <mark>[Obs.]</mark>
<ldquo/This <xex>rupellary</xex> nidary.<rdquo/
<rj><au>Evelyn.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rupert's drop</ent><br/
<-- no "<pos>n.</pos>" in original?  PCP -->
<hw>Ru"pert's drop`</hw> <pr>(?)</pr>. <def>A kind of glass drop with a long tail, made by dropping melted glass into water. It is remarkable for bursting into fragments when the surface is scratched or the tail broken; -- so called from Prince <etsep>Rupert</etsep>, nephew of Charles I., by whom they were first brought to England. Called also <altname>Rupert's ball</altname>, and <altname>glass tear</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rupia</ent><br/
\'d8<hw>Ru"pi*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. G. <?/ filth, dirt.]</ety> <fld>(Med.)</fld> <def>An eruption upon the skin, consisting of vesicles with inflamed base and filled with serous, purulent, or bloody fluid, which dries up, forming a blackish crust.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rupial</ent><br/
<hw>Ru"pi*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining to rupia.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rupicola</ent><br/
\'d8<hw>Ru*pic"o*la</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. L. <ets>rupes</ets>, gen. <ets>rupis</ets>, a rock + <ets>colere</ets> to inhabit.]</ety> <fld>(Zool.)</fld> <def>A genus of beautiful South American passerine birds, including the cock of the rock.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The species are remarkable for having an elevated fan-shaped crest of feathers on the head, and for the beautiful color of their plumage, which is mostly some delicate shade of yellow or orange.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rupicoline</ent><br/
<hw>Ru*pic"o*line</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld> <def>Rock-inhabiting.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruption</ent><br/
<hw>Rup"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>ruptio</ets>, fr. <ets>rumpere</ets>, <ets>ruptum</ets>, to break.]</ety> <def>A breaking or bursting open; breach; rupture.</def> <ldquo/By <xex>ruption</xex> or apertion.<rdquo/ <rj><au>Wiseman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruptuary</ent><br/
<hw>Rup"tu*a*ry</hw> <pr>(?; 135)</pr>, <pos>n.</pos> <ety>[Cf. <ets>Roturier</ets>.]</ety> <def>One not of noble blood; a plebeian; a roturier.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The exclusion of the French <qex>ruptuaries</qex> (<ldquo/roturiers,<rdquo/ for history must find a word for this class when it speaks of other nations) from the order of nobility.</q> <rj><qau>Chenevix.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rupture</ent><br/
<hw>Rup"ture</hw> <pr>(?; 135)</pr>, <pos>n.</pos> <ety>[L. <ets>ruptura</ets>, fr. <ets>rumpere</ets>, <ets>ruptum</ets> to break: cf. F. <ets>rupture</ets>. See <er>Reave</er>, and cf. <er>Rout</er> a defeat.]</ety> <sn>1.</sn> <def>The act of breaking apart, or separating; the state of being broken asunder; <as>as, the <ex>rupture</ex> of the skin; the <ex>rupture</ex> of a vessel or fiber; the <ex>rupture</ex> of a lutestring</as>.</def>  <rj><au>Arbuthnot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Hatch from the egg, that soon,<br/
Bursting with kindly <qex>rupture</qex>, forth disclosed<br/
Their callow young.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Breach of peace or concord between individuals; open hostility or war between nations; interruption of friendly relations; <as>as, the parties came to a <ex>rupture</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He knew that policy would disincline Napoleon from a <qex>rupture</qex> with his family.</q> <rj><qau>E. Everett.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Med.)</fld> <def>Hernia. See <er>Hernia</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A bursting open, as of a steam boiler, in a less sudden manner than by explosion. See <er>Explosion</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Modulus of rupture</b></col>. <cd>(Engin.) See under <er>Modulus</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Fracture; breach; break; burst; disruption; dissolution. See <er>Fracture</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rupture</ent><br/
<hw>Rup"ture</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos> <conjf>Ruptured</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos> <conjf>Rupturing</conjf>.]</vmorph> <sn>1.</sn> <def>To part by violence; to break; to burst; <as>as, to <ex>rupture</ex> a blood vessel</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To produce a hernia in.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rupture</ent><br/
<hw>Rup"ture</hw>, <pos>v. i.</pos> <def>To suffer a breach or disruption.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruptured</ent><br/
<hw>Rup"tured</hw> <pr>(?; 135)</pr>, <pos>a.</pos> <fld>(Med.)</fld> <def>Having a rupture, or hernia.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rupturewort</ent><br/
<hw>Rup"ture*wort"</hw> <pr>(?; 135)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <sd>(a)</sd> <def>Same as <er>Burstwort</er>.</def> <sd>(b)</sd> <def>A West Indian plant (<spn>Alternanthera polygonoides</spn>) somewhat resembling burstwort.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rural</ent><br/
<hw>Ru"ral</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F., fr. L. <ets>ruralis</ets>, fr. <ets>rus</ets>, <ets>ruris</ets>, the country.  Cf. <er>Room</er> space, <er>Rustic</er>.]</ety> <sn>1.</sn> <def>Of or pertaining to the country, as distinguished from a city or town; living in the country; suitable for, or resembling, the country; rustic; <as>as, <ex>rural</ex> scenes; a <ex>rural</ex> prospect</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Here is a <qex>rural</qex> fellow; . . . <br/
He brings you figs.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of or pertaining to agriculture; <as>as, <ex>rural</ex> economy</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Rural dean</b></col>. <fld>(Eccl.)</fld> <cd>See under <er>Dean</er>.</cd> -- <col><b>Rural deanery</b></col> <fld>(Eccl.)</fld>, <cd>the state, office, or residence, of a rural dean.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<usage>
<p><syn><b>Syn.</b> -- Rustic.</syn>  -- <er>Rural</er>, <er>Rustic</er>. <xex>Rural</xex> refers to the country itself; as, <xex>rural</xex> scenes, prospects, delights, etc. <xex>Rustic</xex> refers to the character, condition, taste, etc., of the original inhabitants of the country, who were generally uncultivated and rude; as, <xex>rustic</xex> manners; a <xex>rustic</xex> dress; a <xex>rustic</xex> bridge; rustic architecture, etc.<br/
[<source>1913 Webster</source>]</p>

<p><q>We turn<br/
To where the silver Thames first <qex>rural</qex> grows.</q> <rj><qau>Thomson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Lay bashfulness, that <qex>rustic</qex> virtue, by;<br/
To manly confidence thy throughts apply.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p></usage>

<p><ent>Rurales</ent><br/
\'d8<hw>Ru*ra"les</hw> <pr>(r<usdot/*r<amac/"l<emac/z)</pr>, <pos>n. pl.</pos> <ety>[NL.]</ety> <fld>(Zool.)</fld> <def>The gossamer-winged butterflies; a family of small butterflies, including the hairstreaks, violets, and theclas.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruralism</ent><br/
<hw>Ru"ral*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The quality or state of being rural; ruralness.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A rural idiom or expression.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruralist</ent><br/
<hw>Ru"ral*ist</hw>, <pos>n.</pos> <def>One who leads a rural life.</def> <rj><au>Coventry.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rurality</ent><br/
<hw>Ru*ral"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it> -<plw>ties</plw> <pr>(#)</pr>.</plu> <ety>[Cf. LL. <ets>ruralitas</ets>.]</ety> <sn>1.</sn> <def>The quality or state of being rural.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A rural place.</def> <ldquo/Leafy <xex>ruralities</xex>.<rdquo/ <rj><au>Carlyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruralize</ent><br/
<hw>Ru"ral*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos> <conjf>Ruralized</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos> <conjf>Ruralizing</conjf> <pr>(?)</pr>.]</vmorph> <def>To render rural; to give a rural appearance to.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruralize</ent><br/
<hw>Ru"ral*ize</hw>, <pos>v. i.</pos> <def>To become rural; to go into the country; to rusticate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rurally</ent><br/
<hw>Ru"ral*ly</hw>, <pos>adv.</pos> <def>In a rural manner; as in the country.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruralness</ent><br/
<hw>Ru"ral*ness</hw>, <pos>n.</pos> <def>The quality or state of being rural.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruricolist</ent><br/
<hw>Ru*ric"o*list</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>ruricola</ets>; <ets>rus</ets>, <ets>ruris</ets>, the country + <ets>colere</ets> to inhabit.]</ety> <def>An inhabitant of the country.</def> <mark>[R.]</mark>  <rj><au>Bailey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruridecanal</ent><br/
<hw>Ru`ri*dec"a*nal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>rus</ets>, <ets>ruris</ets> the country + <ets>decanus</ets> the chief of ten. See <er>Dean</er>.]</ety> <def>Of or pertaining to a rural dean; <as>as, a <ex>ruridecanal</ex> district; the <ex>ruridecanal</ex> intellect</as>.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rurigenous</ent><br/
<hw>Ru*rig"e*nous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>rurigena</ets>; <ets>rus</ets>, <ets>ruris</ets>, the country + <ets>genere</ets>, <ets>gignere</ets>, to bring forth, pass., to be born.]</ety> <def>Born in the country.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruse</ent><br/
<hw>Ruse</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr. OF. <ets>re<uum/ser</ets>, <ets>rehuser</ets>, to turn aside, to shuffle, retreat, fr. L. <ets>recusare</ets> to refuse; pref. <ets>re-</ets> again + <ets>causa</ets> cause. See <er>Cause</er>, and cf. <er>Recusant</er>.]</ety> <def>An artifice; trick; stratagem; wile; fraud; deceit.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs>\'d8<col><b>Ruse de guerre</b></col> <pr>(<?/)</pr> <ety>[F.]</ety>, <cd>a stratagem of war.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rush</ent><br/
<hw>Rush</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>rusche</ets>, <ets>rische</ets>, <ets>resche</ets>, AS. <ets>risce</ets>, akin to LG. <ets>rusk</ets>, <ets>risch</ets>, D. & G. <ets>rusch</ets>; all probably fr. L. <ets>ruscum</ets> butcher's broom; akin to Goth. <ets>raus</ets> reed, G. <ets>rohr</ets>.]</ety> <sn>1.</sn> <fld>(Bot.)</fld> <def>A name given to many aquatic or marsh-growing endogenous plants with soft, slender stems, as the species of <gen>Juncus</gen> and <gen>Scirpus</gen>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Some species are used in bottoming chairs and plaiting mats, and the pith is used in some places for wicks to lamps and rushlights.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The merest trifle; a straw.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>John Bull's friendship is not worth a <qex>rush</qex>.</q> <rj><qau>Arbuthnot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Bog rush</b></col>. <cd>See under <er>Bog</er>.</cd> -- <col><b>Club rush</b></col>, <cd>any rush of the genus <gen>Scirpus</gen>.</cd> -- <col><b>Flowering rush</b></col>. <cd>See under <er>Flowering</er>.</cd> -- <col><b>Nut rush</b></col> <sd>(a)</sd> <cd>Any plant of the genus <gen>Scleria</gen>, rushlike plants with hard nutlike fruits</cd>. <sd>(b)</sd> <cd>A name for several species of <gen>Cyperus</gen> having tuberous roots.</cd> -- <col><b>Rush broom</b></col>, <cd>an Australian leguminous plant (<spn>Viminaria denudata</spn>), having long, slender branches. Also, the Spanish broom. See under <er>Spanish</er>.</cd> -- <col><b>Rush candle</b></col>, <cd>See under <er>Candle</er>.</cd> -- <col><b>Rush grass</b></col>, <cd>any grass of the genus <gen>Vilfa</gen>, grasses with wiry stems and one-flowered spikelets.</cd> -- <col><b>Rush toad</b></col> <fld>(Zool.)</fld>, <cd>the natterjack.</cd> -- <col><b>Scouring rush</b></col>. <fld>(Bot.)</fld> <cd>Same as <cref>Dutch rush</cref>, under <er>Dutch.</er> -- <col><b>Spike rush</b></col>, any rushlike plant of the genus <gen>Eleocharis</gen>, in which the flowers grow in dense spikes.</cd> -- <col><b>Sweet rush</b></col>, <cd>a sweet-scented grass of Arabia, etc. (<spn>Andropogon schoenanthus</spn>), used in Oriental medical practice.</cd> -- <col><b>Wood rush</b></col>, <cd>any plant of the genus <gen>Luzula</gen>, which differs in some technical characters from <gen>Juncus</gen>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rush</ent><br/
<hw>Rush</hw> <pr>(r<ucr/sh)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos> <conjf>Rushed</conjf> <pr>(r<ucr/sht)</pr>; <pos>p. pr. & vb. n.</pos> <conjf>Rushing</conjf>.]</vmorph> <ety>[OE. <ets>ruschen</ets>; cf. AS. <ets>hryscan</ets> to make a noise, D. <ets>ruischen</ets> to rustle, G. <ets>rauschen</ets>, MHG. <ets>r<umac/schen</ets> to rush, to rustle, LG. <ets>rusken</ets>, OSw. <ets>ruska</ets>, Icel. & Sw. <ets>ruska</ets> to shake, Dan. <ets>ruske</ets> to shake, and E. <ets>rouse</ets>.]</ety> <sn>1.</sn> <def>To move forward with impetuosity, violence, and tumultuous rapidity or haste; <as>as, armies <ex>rush</ex> to battle; waters <ex>rush</ex> down a precipice</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Like to an entered tide, they all <qex>rush</qex> by.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To enter into something with undue haste and eagerness, or without due deliberation and preparation; <as>as, to <ex>rush</ex> business or speculation</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They . . . never think it to be a part of religion to <qex>rush</qex> into the office of princes and ministers.</q> <rj><qau>Sprat.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rush</ent><br/
<hw>Rush</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To push or urge forward with impetuosity or violence; to hurry forward.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To recite (a lesson) or pass (an examination) without an error.</def> <mark>[College Cant, U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rush</ent><br/
<hw>Rush</hw>, <pos>n.</pos> <sn>1.</sn> <def>A moving forward with rapidity and force or eagerness; a violent motion or course; <as>as, a <ex>rush</ex> of troops; a <ex>rush</ex> of winds; a <ex>rush</ex> of water</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A gentleman of his train spurred up his horse, and, with a violent <qex>rush</qex>, severed him from the duke.</q> <rj><qau>Sir H. Wotton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Great activity with pressure; <as>as, a <ex>rush</ex> of business</as>.</def> <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A perfect recitation.</def> <mark>[College Cant, U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Football)</fld> <sd>(a)</sd> <def>A rusher; <as>as, the center <ex>rush</ex>, whose place is in the center of the rush line; the end <ex>rush</ex></as>.</def><-- now, lineman. --> <sd>(b)</sd> <def>The act of running with the ball.</def> <-- rushing. --><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Bunt rush</b></col> <fld>(Football)</fld>, <cd>a combined
rush by main strength.</cd> -- <col><b>Rush line</b></col>
<fld>(Football)</fld>, <cd>the line composed of rushers.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rush-bearing</ent><br/
<hw>Rush"-bear`ing</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A kind of rural
festival at the dedication of a church, when the parishioners brought
rushes to strew the church.</def> <mark>[Eng.]</mark>
<rj><au>Nares.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rushbuckler</ent><br/
<hw>Rush"buc`kler</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A bullying and
violent person; a braggart; a swashbuckler.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>That flock of stout, bragging <qex>rushbucklers</qex>.</q>
<rj><qau>Robynson (More's Utopia).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rushed</ent><br/
<hw>Rushed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Abounding or covered
with rushes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rusher</ent><br/
<hw>Rush"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who rushes.</def>
<rj><au>Whitlock.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rusher</ent><br/
<hw>Rush"er</hw>, <pos>n.</pos> <def>One who strewed rushes on the floor
at dances.</def> <mark>[Obs.]</mark> <rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rushiness</ent><br/
<hw>Rush"i*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<er>Rushy</er>.]</ety> <def>The quality or state of abounding with
rushes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rushingly</ent><br/
<hw>Rush"ing*ly</hw>, <pos>adv.</pos> <def>In a rushing
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rushlight</ent><br/
<hw>Rush"light`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A rush candle, or
its light; hence, a small, feeble light.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rushlike</ent><br/
<hw>Rush"like`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Resembling a rush;
weak.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rushy</ent><br/
<hw>Rush"y</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Abounding
with rushes.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Made of rushes.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>My <qex>rushy</qex> couch and frugal fare.</q>
<rj><qau>Goldsmith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rusine</ent><br/
<hw>Ru"sine</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[NL. <ets>rusa</ets>,
the name of the genus, Malay <ets>r<umac/sa</ets> deer.]</ety>
<fld>(Zool.)</fld> <def>Of, like, or pertaining to, a deer of the genus
<gen>Rusa</gen>, which includes the sambur deer (<spn>Rusa
Aristotelis</spn>) of India.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Rusine antler</b></col> <fld>(Zool.)</fld>, <cd>an antler
with the brow tyne simple, and the beam forked at the tip.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rusk</ent><br/
<hw>Rusk</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sp. <ets>rosca de
mar</ets> sea rusks, a kind of biscuit, <ets>rosca</ets> properly
meaning, a screw, spiral.]</ety> <sn>1.</sn> <def>A kind of light, soft
bread made with yeast and eggs, often toasted or crisped in an oven; or,
a kind of sweetened biscuit.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A kind of light, hard cake or bread, as for
stores.</def> <rj><au>Smart.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Bread or cake which has been made brown and crisp,
and afterwards grated, or pulverized in a mortar.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rusma</ent><br/
<hw>Rus"ma</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Corrupt. from Turk.
<ets>khyryzma</ets> a paste used as a depilatory, fr. Gr. <?/ an
unguent; cf. F. <ets>rusma</ets>.]</ety> <def>A depilatory made of
orpiment and quicklime, and used by the Turks. See
<er>Rhusma</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Russ</ent><br/
<hw>Russ</hw> <pr>(?)</pr>, <pos>n. sing. & pl.</pos> <sn>1.</sn> <def>A
Russian, or the Russians.</def> <mark>[Rare, except in
poetry.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The language of the Russians.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Russ</ent><br/
<hw>Russ</hw>, <pos>a.</pos> <def>Of or pertaining to the
Russians.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Russet</ent><br/
<hw>Rus"set</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F.
<ets>rousset</ets>, dim. of <ets>roux</ets> red, L. <ets>russus</ets>
(for <ets>rudtus</ets>, <ets>rudhtus</ets>), akin to E. <ets>red</ets>.
See <er>Red</er>, and cf. <er>Roussette</er>.]</ety> <sn>1.</sn> <def>Of
a reddish brown color, or (by some called) a red gray; of the color
composed of blue, red, and yellow in equal strength, but unequal
proportions, namely, two parts of red to one each of blue and yellow;
also, of a yellowish brown color.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The morn, in <qex>russet</qex> mantle clad.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Our summer such a <qex>russet</qex> livery wears.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Coarse; homespun; rustic.</def> <mark>[R.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Russet</ent><br/
<hw>Rus"set</hw>, <pos>n.</pos> <sn>1.</sn> <def>A russet color; a
pigment of a russet color.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Cloth or clothing of a russet color.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A country dress; -- so called because often of a
russet color.</def> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>An apple, or a pear, of a russet color; <as>as, the
<stype>English russet</stype>, and the <stype>Roxbury
russet</stype></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Russeting</ent><br/
<hw>Rus"set*ing</hw>, <pos>n.</pos> <def>See <er>Russet</er>,
<pos>n.</pos>, 2 and 4.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Russety</ent><br/
<hw>Rus"set*y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of a russet color;
russet.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Russia</ent><br/
<hw>Rus"sia</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A country of Europe
and Asia.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Russia iron</b></col>, <cd>a kind of sheet iron made in
<country>Russia</country>, having a lustrous blue-black surface.</cd> --
<col><b>Russia leather</b></col>, <cd>a soft kind of leather, made
originally in <country>Russia</country> but now elsewhere, having a
peculiar odor from being impregnated with an oil obtained from birch
bark. It is much used in bookbinding, on account of its not being
subject to mold, and being proof against insects.</cd> -- <col><b>Russia
matting</b></col>, <cd>matting manufactured in <country>Russia</country>
from the inner bark of the linden (<spn>Tilia
Europaea</spn>).</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1263. --></p>

<p><ent>Russian</ent><br/
<hw>Rus"sian</hw> <pr>(r<ucr/sh"<ait/n <it>or</it> r<udd/"sh<ait/n;
277)</pr>, <pos>a.</pos> <def>Of or pertaining to Russia, its
inhabitants, or language.</def> -- <def2><pos>n.</pos> <def>A native or
inhabitant of Russia; the language of Russia.</def></def2></p>

<p><cs><col><b>Russian bath</b></col>. <cd>See under <er>Bath</er>.</cd>
</cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Russian Orthodox Church</ent><br/
<ent>Russian Church</ent><br/
<mhw><hw>Rus"sian Church</hw>, <hw>Rus"sian Or"tho*dox
Church</hw></mhw>. <def>The established church of the Russian empire up
to the revolution of 1917, at which time the ruling Communist party
tried to suppress all religious worship. The czar was the nominal head
of the church, but he never claimed the right of deciding questions of
theology and dogma. It still forms a portion, by far the largest, of the
Orthodox (Eastern) Church and is governed by the Patriarch and the Holy
Synod. In 1988 the church, with official approval, celebrated the 1000
year anniversary of the baptism of Russia. After breakup of the Soviet
Union in 1991 the Russian Church began to regain some its old influence
in Russian life, and the government turned over some of the confiscated
churches back to church control. The Russian Church was recognized anew
as the official church of Russia, with special priveleges, by an act of
the Russian Duma in 1997. The Metropolitan of Moscow, as Patriarch of
the church, is regarded as the first among equals in order of deference
among bishops of the church.</def><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><ent>Russianize</ent><br/
<hw>Rus"sian*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To make
Russian, or more or less like the Russians; <as>as, to
<ex>Russianize</ex> the Poles</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Russian roulette</ent><br/
<hw>Rus"sian roulette</hw> <sd>(a)</sd> <def>An act of bravado played by
loading one bullet into one chamber of a revolver in which the cylinder
has five or six positions, spinning the cylinder (thus moving the bullet
randomly to one of the six positions of the cylinder), pointing the gun
to one's head, and pulling the trigger. If the bullet is in firing
position, the "player" is usually killed. Such a "game" may be played on
a dare, or, in some places, as part of a gamble.</def> <sd>(b)</sd>
<mark>(Fig.)</mark> <def>Any dangerous act resembling Russian roulette
in the acceptance of a high risk of serious negative consequences,
usually unnecessarily.</def> <ldquo/The congress is playing <xex>Russian
roulette</xex> with the economy by enacting such large tax reductions
without spending cuts.<rdquo/<br/
[<source>PJC</source>]</p>

<p><ent>Russification</ent><br/
<hw>Rus"si*fi*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Russia</ets> + L. <ets>-ficare</ets> (in comp.) to make. See
<er>-fy</er>.]</ety> <def>The act or process of Russifying, or the state
of being Russified.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Russify</ent><br/
<hw>Rus"si*fy</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Cf. F.
<ets>russifier.</ets> See <er>-fy</er>.]</ety> <def>To Russianize;
<as>as, to <ex>Russify</ex> conquered tribes</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- Russky Pl. Russkies, a Russian [Colloq.] --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Russophilist</ent><br/
<ent>Russophile</ent><br/
<mhw>{ <hw>Rus"so*phile</hw> <pr>(?)</pr>, <hw>Rus*soph"i*list</hw>
<pr>(?)</pr> }</mhw>, <pos>n.</pos> <ety>[<ets>Russia</ets> + Gr.
<grk>filei^n</grk> to love: cf. F. <ets>russophile</ets>.]</ety>
<def>One who, not being a Russian, favors Russian policy and
aggrandizement.</def> -- <wordforms><wf>Rus*soph"ilism</wf>
<pr>(#)</pr>, <pos>n.</pos></wordforms> <mark>[Chiefly newspaper
words.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Russophobist</ent><br/
<ent>Russophobe</ent><br/
<mhw>{ <hw>Rus"so*phobe</hw> <pr>(?)</pr>, <hw>Rus*soph"o*bist</hw>
<pr>(?)</pr> }</mhw>, <ety>[<ets>Russia</ets> + Gr. <grk>fobei^n</grk>
to fear.]</ety> <def>One who dreads Russia or Russian influence.</def>
<mark>[Words sometimes found in the newspapers.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Russophobia</ent><br/
<hw>Rus`so*pho"bi*a</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Morbid dread
of Russia or of Russian influence.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rust</ent><br/
<hw>Rust</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS. <ets>rust</ets>;
akin to D. <ets>roest</ets>, G. & Sw. <ets>rost</ets>, Icel.
<ets>ry<edh/</ets>; -- named from its color, and akin to E.
<ets>red</ets>. <root/113. See <er>Red</er>.]</ety> <sn>1.</sn>
<fld>(Chem.)</fld> <def>The reddish yellow coating formed on iron when
exposed to moist air, consisting of ferric oxide or hydroxide; hence, by
extension, any metallic film of corrosion.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>A minute mold or fungus forming
reddish or rusty spots on the leaves and stems of cereal and other
grasses (<spn>Trichobasis Rubigo-vera</spn>), now usually believed to be
a form or condition of the corn mildew (<spn>Puccinia graminis</spn>).
As rust, it has solitary reddish spores; as corn mildew, the spores are
double and blackish.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Rust</xex> is also applied to many other minute
fungi which infest vegetation, such as the species of
<gen>Ustilago</gen>, <gen>Uredo</gen>, and
<gen>Lecythea</gen>.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which resembles rust in appearance or
effects.</def> <specif>Specifically:</specif> (a) <def>A composition
used in making a rust joint. See <cref>Rust joint</cref>, below.</def>
<sd>(b)</sd> <def>Foul matter arising from degeneration; <as>as,
<ex>rust</ex> on salted meat</as>.</def> <sd>(c)</sd> <def>Corrosive or
injurious accretion or influence.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Sacred truths cleared from all <qex>rust</qex> and dross of human
mixtures.</q> <rj><qau>Eikon Basilike.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Rust</xex> is used in the formation of compounds of
obvious meaning; as, <xex>rust</xex>-colored, <xex>rust</xex>-consumed,
<xex>rust</xex>-eaten, and the like.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Rust joint</b></col>, <cd>a joint made between surfaces
of iron by filling the space between them with a wet mixture of
cast-iron borings, sal ammoniac, and sulphur, which by oxidation becomes
hard, and impervious to steam, water, etc.</cd> -- <col><b>Rust
mite</b></col> <fld>(Zool.)</fld>, <cd>a minute mite (<spn>Phytopius
oleivorus</spn>) which, by puncturing the rind, causes the rust-colored
patches on oranges.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rust</ent><br/
<hw>Rust</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Rusted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Rusting</conjf>.]</vmorph> <ety>[AS. <ets>rustian</ets>.]</ety>
<sn>1.</sn> <def>To contract rust; to be or become oxidized.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If gold <qex>ruste</qex>, what shall iron do?</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Our armors now may <qex>rust</qex>.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To be affected with the parasitic fungus called
rust; also, to acquire a rusty appearance, as plants.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <mark>Fig.:</mark> <def>To degenerate in idleness; to
become dull or impaired by inaction.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Must I <qex>rust</qex> in Egypt? never more<br/
Appear in arms, and be the chief of Greece?</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rust</ent><br/
<hw>Rust</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To cause to contract
rust; to corrode with rust; to affect with rust of any kind.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Keep up your bright swords, for the dew will <qex>rust</qex>
them.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <mark>Fig.:</mark> <def>To impair by time and
inactivity.</def> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rustful</ent><br/
<hw>Rust"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Full of rust;
resembling rust; causing rust; rusty.</def> <ldquo/<xex>Rustful</xex>
sloth.<rdquo/ <rj><au>Quarles.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rustic</ent><br/
<hw>Rus"tic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>rusticus</ets>, fr. <ets>rus</ets>, <ets>ruris</ets>, the country:
cf. F. <ets>rustique</ets>. See <er>Rural</er>.]</ety> <sn>1.</sn>
<def>Of or pertaining to the country; rural; <as>as, the <ex>rustic</ex>
gods of antiquity</as>.</def> <ldquo/<xex>Rustic</xex> lays.<rdquo/
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And many a holy text around she strews,<br/
That teach the <qex>rustic</qex> moralist to die.</q>
<rj><qau>Gray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>She had a <qex>rustic</qex>, woodland air.</q>
<rj><qau>Wordsworth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Rude; awkward; rough; unpolished; <as>as,
<ex>rustic</ex> manners</as>.</def> <ldquo/A <xex>rustic</xex>
muse.<rdquo/ <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Coarse; plain; simple; <as>as, a <ex>rustic</ex>
entertainment; <ex>rustic</ex> dress</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Simple; artless; unadorned; unaffected.</def>
<rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Rustic moth</b></col> <fld>(Zool.)</fld>, <cd>any moth
belonging to <gen>Agrotis</gen> and allied genera. Their larvae are
called <xex>cutworms</xex>. See <er>Cutworm</er>.</cd> -- <col><b>Rustic
work</b></col>. <sd>(a)</sd> <fld>(Arch.)</fld> <cd>Cut stone facing
which has the joints worked with grooves or channels, the face of each
block projecting beyond the joint, so that the joints are very
conspicuous</cd>. <sd>(b)</sd> <fld>(Arch. & Woodwork)</fld> <cd>Summer
houses, or furniture for summer houses, etc., made of rough limbs of
trees fancifully arranged.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Rural; rude; unpolished; inelegant; untaught;
awkward; rough; coarse; plain; unadorned; simple; artless; honest. See
<er>Rural</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rustic</ent><br/
<hw>Rus"tic</hw>, <pos>n.</pos> <sn>1.</sn> <def>An inhabitant of the
country, especially one who is rude, coarse, or dull; a clown.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Hence to your fields, you <qex>rustics</qex>! hence, away.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A rural person having a natural simplicity of
character or manners; an artless, unaffected person.</def>
<mark>[Poetic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rustical</ent><br/
<hw>Rus`tic*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Rustic.</def>
<ldquo/<xex>Rustical</xex> society.<rdquo/ <rj><au>Thackeray.</au></rj>
-- <wordforms><wf>Rus"tic*al*ly</wf>, <pos>adv.</pos> --
<wf>Rus"tic*al*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rusticate</ent><br/
<hw>Rus"ti*cate</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Rusticated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Rusticating</conjf>.]</vmorph> <ety>[L.
<ets>rusticaticus</ets>, p. p. of <ets>rusticari</ets> to rusticate. See
<er>Rustic</er>.]</ety> <def>To go into or reside in the country; to
ruralize.</def> <rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rusticate</ent><br/
<hw>Rus"ti*cate</hw>, <pos>v. t.</pos> <def>To require or compel to
reside in the country; to banish or send away temporarily; to impose
rustication on.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The town is again beginning to be full, and the
<qex>rusticated</qex> beauty sees an end of her banishment.</q>
<rj><qau>Idler.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rusticated</ent><br/
<hw>Rus"ti*ca`ted</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Arch.)</fld>
<def>Resembling rustic work. See <cref>Rustic work</cref> <sd>(a)</sd>,
under <er>Rustic</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rustication</ent><br/
<hw>Rus`ti*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>rusticatio</ets>.]</ety> <sn>1.</sn> <def>The act of rusticating,
or the state of being rusticated; specifically, the punishment of a
student for some offense, by compelling him to leave the institution for
a time.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Arch.)</fld> <def>Rustic work.</def><br/
[<source>1913 Webster</source>]</p>

<-- headword error in Rusticity.   PCP -->  <-- previous reader's additions at Rustle, Rustler, Rusty, in a Rut, Rutinose, Rytina  need reformatting if used.   I did this for Russian Roulette, but not others.  PCP -->

<p><ent>Rusticity</ent><br/
<hw>Rus*tic"ity</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>rusticitas</ets>: cf. F. <ets>rusticit<eacute/</ets>.]</ety> <def>The quality or state of being rustic; rustic manners; rudeness; simplicity; artlessness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The sweetness and <qex>rusticity</qex> of a pastoral can not be so well expressed in any other tongue as in the Greek, when rightly mixed and qualified with the Doric dialect.</q> <rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The Saxons were refined from their <qex>rusticity</qex>.</q> <rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rusticly</ent><br/
<hw>Rus"tic*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a rustic manner; rustically.</def>  <rj><au>Chapman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rustily</ent><br/
<hw>Rust"i*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a rusty state.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rustiness</ent><br/
<hw>Rust"i*ness</hw>, <pos>n.</pos> <def>The quality or state of being rusty.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rustle</ent><br/
<hw>Rus"tle</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos> <conjf>Rustled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos> <conjf>Rustling</conjf> <pr>(?)</pr>.]</vmorph> <ety>[AS. <ets>hristlan</ets> to rustle; or cf. Sw. <ets>rusta</ets> to stir, make a riot, or E. <ets>rush</ets>, v.]</ety> <sn>1.</sn> <def>To make a quick succession of small sounds, like the rubbing or moving of silk cloth or dry leaves.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He is coming; I hear his straw <qex>rustle</qex>.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Prouder than <qex>rustling</qex> in unpaid-for silk.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To stir about energetically; to strive to succeed; to bustle about.</def> <mark>[Slang, Western U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To steal; -- used of livestock and esp. of cattle.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>To rustle up</b></col> <cd>To gather or find by searching; <as>as, to <ex>rustle up</ex> some food for supper</as>.</cd></cs><br/
[<source>PJC</source>]</p>

<p><ent>Rustle</ent><br/
<hw>Rus"tle</hw>, <pos>v. t.</pos> <def>To cause to rustle; <as>as, the wind <ex>rustles</ex> the leaves</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rustle</ent><br/
<hw>Rus"tle</hw>, <pos>n.</pos> <def>A quick succession or confusion of small sounds, like those made by shaking leaves or straw, by rubbing silk, or the like; a rustling.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>When the noise of a torrent, the <qex>rustle</qex> of a wood, the song of birds, or the play of lambs, had power to fill the attention, and suspend all perception of the course of time.</q> <rj><qau>Idler.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rustler</ent><br/
<hw>Rus"tler</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who, or that which, rustles.</def> <-- esp. cattle rustler --><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A bovine animal that can care for itself in any
circumstances; also, an alert, energetic, driving person.</def>
<mark>[Slang, Western U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rustless</ent><br/
<hw>Rust"less</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Free from
rust.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rusty</ent><br/
<hw>Rust"y</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[AS.
<ets>rustig</ets>.]</ety> <amorph>[<pos>Compar.</pos>
<adjf>Rustier</adjf> <pr>(<?/)</pr>; <pos>superl.</pos>
<adjf>Rustiest.</adjf>]</amorph> <sn>1.</sn> <def>Covered or affected
with rust; <as>as, a <ex>rusty</ex> knife or sword; <ex>rusty</ex>
wheat</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Impaired by inaction, disuse, or neglect.</def> <--
less skillful than when in continued practise --><br/
[<source>1913 Webster</source>]</p>

<p><q>[Hector,] in this dull and long-continued truce,<br/
Is <qex>rusty</qex> grown.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Discolored and rancid; reasty; <as>as,
<ex>rusty</ex> bacon</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Surly; morose; crusty; sullen.</def> <mark>[Obs. or
Prov. Eng.]</mark> <ldquo/<xex>Rusty</xex> words.<rdquo/ <rj><au>Piers
Plowman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Rust-colored; dark.</def> <ldquo/<xex>Rusty</xex>
blood.<rdquo/ <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Discolored; stained; not cleanly kept;
filthy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>rusty</qex> little schooners that bring firewood from the
British provinces.</q> <rj><qau>Hawthorne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Bot.)</fld> <def>Resembling, or covered with a
substance resembling, rust; affected with rust; rubiginous.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rut</ent><br/
<hw>Rut</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>rut</ets>, OF.
<ets>ruit</ets>, L. <ets>rugitus</ets> a roaring, fr. <ets>rugire</ets>
to roar; -- so called from the noise made by deer in rutting
time.]</ety> <sn>1.</sn> <fld>(Physiol.)</fld> <def>Sexual desire or
oestrus of deer, cattle, and various other mammals; heat; also, the
period during which the oestrus exists.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Roaring, as of waves breaking upon the shore; rote.
See <er>Rote</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rut</ent><br/
<hw>Rut</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Rutted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Rutting</conjf>.]</vmorph> <def>To have a strong sexual impulse
at the reproductive period; -- said of deer, cattle, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rut</ent><br/
<hw>Rut</hw>, <pos>v. t.</pos> <def>To cover in copulation.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rut</ent><br/
<hw>Rut</hw>, <pos>n.</pos> <ety>[variant of <ets>route</ets>.]</ety>
<def>A track worn by a wheel or by habitual passage of anything; a
groove in which anything runs. Also used figuratively.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- (Fig.) Habitual, unvarying activity -- usually used in the phrase
<it>in a rut</it>. --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rut</ent><br/
<hw>Rut</hw>, <pos>v. t.</pos> <def>To make a rut or ruts in; -- chiefly
used as a past participle or a participial adj.; <as>as, a
<ex>rutted</ex> road</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruta-baga</ent><br/
<hw>Ru`ta-ba"ga</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>A kind of turnip commonly with a large and long or ovoid yellowish
root; a Swedish turnip. See <er>Turnip</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rutaceous</ent><br/
<hw>Ru*ta"ceous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>rutaceous</ets>, from <ets>ruta</ets> rue. See <er>Rue</er> the
plant.]</ety> <fld>(Bot.)</fld> <def>Of or pertaining to plants of a
natural order (<ord>Rutaceae</ord>) of which the rue is the type, and
which includes also the orange, lemon, dittany, and buchu.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rutate</ent><br/
<hw>Ru"tate</hw> <pr>(r<udd/"t<asl/t)</pr>, <pos>n.</pos>
<fld>(Chem.)</fld> <def>A salt of rutic acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruth</ent><br/
<hw>Ruth</hw> <pr>(r<udd/th)</pr>, <pos>n.</pos> <ety>[From
<er>Rue</er>, <pos>v.</pos>: cf. Icel. <ets>hrygg<edh/</ets>,
<ets>hryg<edh/</ets>.]</ety> <sn>1.</sn> <def>Sorrow for the misery of
another; pity; tenderness.</def> <mark>[Poetic]</mark> <ldquo/They weep
for <xex>ruth</xex>.<rdquo/ <au>Chaucer.</au> <ldquo/Have
<xex>ruth</xex> of the poor.<rdquo/ <au>Piers Plowman.</au><br/
[<source>1913 Webster</source>]</p>

<p><q>To stir up gentle <qex>ruth</qex>,<br/
Both for her noble blood, and for her tender youth.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which causes pity or compassion; misery;
distress; a pitiful sight.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>It had been hard this <qex>ruth</qex> for to see.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>With wretched miseries and woeful <qex>ruth</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruthenic</ent><br/
<hw>Ru*then"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Chem.)</fld>
<def>Pertaining to, or containing, ruthenium; specifically, designating
those compounds in which it has a higher valence as contrasted with
<contr>ruthenious</contr> compounds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruthenious</ent><br/
<hw>Ru*the"ni*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Chem.)</fld>
<def>Pertaining to, or containing, ruthenium; specifically, designating
those compounds in which it has a lower valence as contrasted with
<contr>ruthenic</contr> compounds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruthenium</ent><br/
<hw>Ru*the"ni*um</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. So named
from the <etsep>Ruthenians</etsep>, a Little Russian people, as coming
from Russia, the metal having been found in the Ural mountains.]</ety>
<fld>(Chem.)</fld> <def>A rare element of the light platinum group,
found associated with platinum ores, and isolated as a hard, brittle
steel-gray metal which is very infusible. Symbol Ru. Atomic weight
103.5. Specific gravity 12.26. See <cref>Platinum metals</cref>, under
<er>Platinum</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruthful</ent><br/
<hw>Ruth"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Full of ruth</def>;
as: <sd>(a)</sd> <def>Pitiful; tender.</def> <sd>(b)</sd> <def>Full of
sorrow; woeful.</def> <sd>(c)</sd> <def>Causing sorrow.</def>
<rj><au>Shak.</au></rj> -- <wordforms> <wf>Ruth"ful*ly</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruthless</ent><br/
<hw>Ruth"less</hw>, <pos>a.</pos> <def>Having no ruth; cruel;
pitiless.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Their rage the hostile bands restrain,<br/
All but the <qex>ruthless</qex> monarch of the main.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Ruth"less*ly</wf>, <pos>adv.</pos> --
<wf>Ruth"less*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rutic</ent><br/
<hw>Ru"tic</hw> <pr>(r<udd/"t<icr/k)</pr>, <pos>a.</pos> <ety>[Cf.
<er>Rutaceous</er>.]</ety> <fld>(Chem.)</fld> <def>Pertaining to, or
obtained from, rue (<gen>Ruta</gen>); <as>as, <ex>rutic</ex> acid, now
commonly called <altname>capric acid</altname></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rutilant</ent><br/
<hw>Ru"ti*lant</hw> <pr>(<?/)</pr>, <pos>a.</pos> <ety>[L.
<ets>rutilans</ets>, p. pr. of <ets>rutilare</ets> to have a reddish
glow, fr. <ets>rutilus</ets> red: cf. F. <ets>rutilant</ets>.]</ety>
<def>Having a reddish glow; shining.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Parchments . . . colored with this <qex>rutilant</qex>
mixture.</q> <rj><qau>Evelyn.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rutilate</ent><br/
<hw>Ru"ti*late</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[L.
<ets>rutilare</ets>, <ets>rutilatum</ets>.]</ety> <def>To shine; to emit
rays of light.</def> <mark>[Obs.]</mark> <rj><au>Ure.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rutile</ent><br/
<hw>Ru"tile</hw> <pr>(r<udd/"t<icr/l)</pr>, <pos>n.</pos> <ety>[L.
<ets>rutilus</ets> red, inclining to golden yellow.]</ety>
<fld>(Min.)</fld> <def>A mineral usually of a reddish brown color, and
brilliant metallic adamantine luster, occurring in tetragonal crystals.
In composition it is titanium dioxide, like octahedrite and
brookite.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rutilian</ent><br/
<hw>Ru*til"i*an</hw> <pr>(r<usdot/*t<icr/l"<icr/*<ait/n)</pr>,
<pos>n.</pos> <fld>(Zool.)</fld> <def>Any species of lamellicorn beetles
belonging to <gen>Rutila</gen> and allied genera, as the spotted
grapevine beetle (<spn>Pelidnota punctata</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rutin</ent><br/
<hw>Ru"tin</hw> <pr>(r<udd/"t<icr/n)</pr>, <pos>n.</pos>
<fld>(Chem.)</fld> <def>A glucoside resembling, but distinct from,
quercitrin. Rutin is found in the leaves of the rue (<spn>Ruta
graveolens</spn>) and other plants, and obtained as a bitter yellow
crystalline substance which yields quercitin on decomposition.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rutinose.</ent><br/
<hw>Rutinose.</hw> <def>A disaccharide present in glycosides.</def>
<note>It is prepared from rutin by hydrolysis with rhamnodiastase.
<altname>6-O-<alpha/-L-rhamnosyl-D-glucose</altname>;
<chform>C12H22O10</chform>.</note><br/
[<source>PJC</source>]</p>

<p><ent>Rutter</ent><br/
<hw>Rut"ter</hw> <pr>(r<ucr/t"t<etil/r)</pr>, <pos>n.</pos> <ety>[D.
<ets>ruiter</ets> a rider. Cf. <er>Ruttier</er>.]</ety> <def>A horseman
or trooper.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Such a regiment of <qex>rutters</qex><br/
Never defied men braver.</q> <rj><qau>Beau. & Fl.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rutter</ent><br/
<hw>Rut"ter</hw>, <pos>n.</pos> <ety>[From <er>Rut</er>.]</ety>
<def>That which ruts.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rutterkin</ent><br/
<hw>Rut"ter*kin</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An old crafty fox
or beguiler -- a word of contempt.</def> <mark>[Obs.]</mark>
<rj><au>Cotgrave.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruttier</ent><br/
<hw>Rut"ti*er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>routier</ets>, fr. <ets>route</ets> a road. See
<er>Route</er>.]</ety> <def>A chart of a course, esp. at sea.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruttish</ent><br/
<hw>Rut"tish</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Inclined to rut;
lustful; libidinous; salacious.</def> <rj><au>Shak.</au></rj> --
<wordforms><wf>Rut"tish*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ruttle</ent><br/
<hw>Rut"tle</hw>, <pos>n.</pos> <def>A rattling sound in the throat
arising from difficulty of breathing; a rattle.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rutty</ent><br/
<hw>Rut"ty</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Ruttish; rutting;
lustful.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rutty</ent><br/
<hw>Rut"ty</hw>, <pos>a.</pos> <def>Full of ruts; rutted; <as>as, a
<ex>rutty</ex> road</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rutty</ent><br/
<hw>Rut"ty</hw>, <pos>a.</pos> <ety>[See <er>Root</er>.]</ety>
<def>Rooty.</def> <mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rutylene</ent><br/
<hw>Ru"ty*lene</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>A liquid hydrocarbon, <chform>C10H18</chform>, of the acetylene
series. It is produced artificially.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ryal</ent><br/
<hw>Ry"al</hw> <pr>(? <or/ ?)</pr>, <pos>a.</pos> <def>Royal.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ryal</ent><br/
<hw>Ry"al</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See <er>Rial</er>, an
old English coin.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ryder</ent><br/
<hw>Ry"der</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A clause
added to a document; a rider. See <er>Rider</er>.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <ety>[D. <ets>rijder</ets>, properly, a rider.]</ety>
<def>A gold coin of Zealand [Netherlands] equal to 14 florins, about
$5.60 (ca. 1910).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rye</ent><br/
<hw>Rye</hw> <pr>(r<imac/)</pr>, <pos>n.</pos> <ety>[OE. <ets>rie</ets>,
<ets>reie</ets>, AS. <ets>ryge</ets>; akin to Icel. <ets>rugr</ets>, Sw.
<ets>r<aring/g</ets>, Dan. <ets>rug</ets>, D. <ets>rogge</ets>, OHG.
<ets>rocco</ets>, <ets>roggo</ets>, G. <ets>rocken</ets>,
<ets>roggen</ets>, Lith. <ets>rugei</ets>, Russ. <ets>roje</ets>, and
perh. to Gr. <grk>'o`ryza</grk> rice. Cf. <er>Rice</er>.]</ety>
<sn>1.</sn> <fld>(Bot.)</fld> <def>A grain yielded by a hardy cereal
grass (<spn>Secale cereale</spn>), closely allied to wheat; also, the
plant itself. Rye constitutes a large portion of the breadstuff used by
man.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A disease in a hawk.</def>
<rj><au>Ainsworth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Rye grass</b></col>, <col><b>Italian rye
grass</b></col></mcol>, <fld>(Bot.)</fld> <cd>See under <er>Grass</er>.
See also <er>Ray grass</er>, and <er>Darnel</er>.</cd> -- <col><b>Wild
rye</b></col> <fld>(Bot.)</fld>, <cd>any plant of the genus
<gen>Elymus</gen>, tall grasses with much the appearance of
rye.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rynd</ent><br/
<hw>Rynd</hw> <pr>(? <or/ ?)</pr>, <pos>n.</pos> <ety>[Etymol.
uncertain.]</ety> <def>A piece of iron crossing the hole in the upper
millstone by which the stone is supported on the spindle.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ryot</ent><br/
<hw>Ry"ot</hw> <pr>(r<imac/"<ocr/t)</pr>, <pos>n.</pos> <ety>[Ar. &
Hind. <ets>ra'iyat</ets>, the same word as <ets>ra'iyah</ets>, a
subject, tenant, peasant. See <er>Rayah</er>.]</ety> <def>A peasant or
cultivator of the soil.</def> <mark>[India]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The Indian <qex>ryot</qex> and the Egyptian fellah work for less
pay than any other laborers in the world.</q> <rj><qau>The
Nation.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rypophagous</ent><br/
<hw>Ry*poph"a*gous</hw> <pr>(r<isl/*p<ocr/f"<adot/*g<ucr/s)</pr>,
<pos>a.</pos> <ety>[Gr. <grk>"ry`pos</grk> filth + <grk>fagei^n</grk> to
eat.]</ety> <fld>(Zool.)</fld> <def>Eating, or subsisting on,
filth.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rys</ent><br/
<hw>Rys</hw> <pr>(r<imac/s <it>or</it> r<icr/s)</pr>, <pos>n.</pos>
<def>A branch.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rysh</ent><br/
<hw>Rysh</hw> <pr>(r<icr/sh)</pr>, <pos>n.</pos> <def>Rush, a
plant.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rysimeter</ent><br/
<hw>Ry*sim"e*ter</hw> <pr>(r<isl/*s<icr/m"<esl/*t<etil/r)</pr>,
<pos>n.</pos> <def>See <er>Rhysimeter</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ryth</ent><br/
<hw>Ryth</hw> <pr>(r<icr/th)</pr>, <pos>n.</pos> <ety>[Cf. AS.
<ets>ri<edh/</ets> brook.]</ety> <def>A ford.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Rytina</ent><br/
\'d8<hw>Ryt"i*na</hw> <pr>(r<icr/t"<icr/*n<adot/)</pr>, <pos>n.</pos>
<ety>[NL., fr. Gr. <grk>"ryti`s</grk> a wrinkle.]</ety>
<fld>(Zool.)</fld> <def>A genus of large edentulous sirenians, allied to
the dugong and manatee, including but one species (<spn>Rytina
Stelleri</spn>); -- called also <altname>Steller's sea cow</altname>,
<altname>stellerine</altname> and <altname>steller</altname>.</def>
<altsp>[Written also <asp>Rhytina</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ It is now extinct, but was formerly abundant at Bering's
Island, near Bering's Straits. It was twenty-five feet or more in
length, with a thick, blackish, naked skin. The last were killed in 1768
for their oil and flesh.</note><-- another man-made extinction --><br/
[<source>1913 Webster</source>]</p>

<p><-- Bottom of page 1263. "S" begins at the top of page 1264 --><br/
[<source>1913 Webster</source>]</p>


<-- Local variables: -->
<-- mode: sgml -->
<-- fill-column: 72 -->
<-- End: -->
