<-- This file is part 6 of the GNU version of
    The Collaborative International Dictionary of English (GCIDE)

    Copyright (C) 1992-2012 Patrick J. Cassidy
    Copyright (C) 2012-2024 Sergey Poznyakoff

    GCIDE is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 3, or (at your option)
    any later version.

    GCIDE is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this copy of GCIDE.  If not, see <http://www.gnu.org/licenses/>.
-->

<p><q>A dictionary containing a natural history requires too many
<qex>hands</qex>, as well as too much time, ever to be hoped for.</q>
<rj><qau>Locke.</qau></rj></p>

<p><-- p. 535 --></p>

<p><centered><point26>F.</point26></centered></p>

<p><ent>F</ent><br/
<hw>F</hw> <pr>(<ecr/f)</pr>. <sn>1.</sn> <def>F is the sixth letter of
the English alphabet, and a nonvocal consonant. Its form and sound are
from the Latin. The Latin borrowed the form from the Greek digamma <?/,
which probably had the value of English <it>w</it> consonant. The form
and value of Greek letter came from the Ph<oe/nician, the ultimate
source being probably Egyptian. Etymologically <it>f</it> is most
closely related to <it>p</it>, <it>k</it>, <it>v</it>, and <it>b</it>;
as in E. <it>f</it>ive, Gr. <grk>pe`nte</grk>; E. wol<it>f</it>, L.
lu<it>p</it>us, Gr. <grk>ly`kos</grk>; E. <it>f</it>ox, <it>v</it>ixen ;
<it>f</it>ragile, <it>b</it>reak; <it>f</it>ruit, <it>b</it>rook,
<pos>v. t.</pos>; E. <it>b</it>ear, L. <it>f</it>erre. See <xex>Guide to
Pronunciation</xex>, <sect/<sect/ 178, 179, 188, 198, 230.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mus.)</fld> <def>The name of the fourth tone of the
model scale, or scale of C. F sharp (F <sharp/) is a tone intermediate
between F and G.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>F clef</b></col>, <cd>the bass clef. See under
<er>Clef</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fa</ent><br/
<hw>Fa</hw> <pr>(f<aum/)</pr>, <pos>n.</pos> <ety>[It.]</ety>
<fld>(Mus.)</fld> <sd>(a)</sd> <def>A syllable applied to the fourth
tone of the diatonic scale in solmization.</def> <sd>(b)</sd> <def>The
tone F.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>fab</ent><br/
<hw>fab</hw> <pos>adj.</pos> <ety>[shortened form of
<er>fabulous</er>.]</ety> <def>extremely pleasing.</def>
<mark>[Colloq.]</mark> <br/
<syn><b>Syn. --</b> fabulous.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fabaceae</ent><br/
<hw>Fabaceae</hw> <pos>prop. n.</pos> <def>A large natural family of
trees, shrubs, vines, and herbs bearing bean pods; divided for
convenience into the subfamilies <fam>Caesalpiniacea</fam>;
<fam>Mimosaceae</fam>; <fam>Papilionaceae</fam>.</def><br/
<syn><b>Syn. --</b> Leguminosae, family <fam>Leguminosae</fam>, family
<fam>Fabaceae</fam>, legume family, pea family.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fabaceous</ent><br/
<hw>Fa*ba"ceous</hw> <pr>(f<adot/*b<amac/"sh<ucr/s)</pr>, <pos>a.</pos>
<ety>[L. <ets>fabaceus</ets>, fr. <ets>faba</ets> bean.]</ety>
<def>Having the nature of a bean; like a bean.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fabella</ent><br/
\'d8<hw>Fa*bel"la</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Fabellae</plw> <pr>(-l<emac/)</pr>.</plu> <ety>[NL., dim. of L.
<ets>faba</ets> a bean.]</ety> <fld>(Anat.)</fld> <def>One of the small
sesamoid bones situated behind the condyles of the femur, in some
mammals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fabian</ent><br/
<hw>Fa"bi*an</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>Fabianus</ets>, <ets>Fabius</ets>, belonging to Fabius.]</ety>
<def>Of, pertaining to, or in the manner of, the Roman general,
<person>Quintus Fabius Maximus Verrucosus</person>; cautious; dilatory;
avoiding a decisive contest.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fabian policy</b></col>, <cd>a policy like that of
<person>Fabius Maximus</person>, who, by carefully avoiding decisive
contests, foiled <persfn>Hannibal</persfn>, harassing his army by
marches, countermarches, and ambuscades; a policy of delays and
cautions.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fabian</ent><br/
<hw>Fa"bi*an</hw>, <pos>a.</pos> <sn>1.</sn> <def>Of or pertaining to
the Roman gens Fabia.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>Designating, or pertaining to, a society of
socialists, organized in England in 1884 to spread socialistic
principles gradually without violent agitation.</def></p>

<p><q>The <qex>Fabian</qex> Society proposes then to conquer by delay;
to carry its programme, not by a hasty rush, but through the slower,
but, as it thinks, surer methods of patient discussion, exposition, and
political action.</q> <rj><qau>William Clarke.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Fabian</ent><br/
<hw>Fa"bi*an</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A member of, or
sympathizer with, the Fabian Society.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Fabiana</ent><br/
<hw>Fabiana</hw> <pos>n.</pos> <def>a genus of South and Central
American heathlike evergreen shrubs.</def><br/
<syn><b>Syn. --</b> genus <gen>Fabiana</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fabianism</ent><br/
<hw>Fabianism</hw> <pos>n.</pos> <def>the principles and beliefs of or
similar to those of the Fabian Society, advocating socialism to be
established by gradual reforms within the law.</def>
<mark>[British]</mark><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fable</ent><br/
<hw>Fa"ble</hw> <pr>(f<amac/"b'l)</pr>, <pos>n.</pos> <ety>[F., fr. L.
<ets>fabula</ets>, fr. <ets>fari</ets> to speak, say. See <er>Ban</er>,
and cf. <er>Fabulous</er>, <er>Fame</er>.]</ety> <sn>1.</sn> <def>A
Feigned story or tale, intended to instruct or amuse; a fictitious
narration intended to enforce some useful truth or precept; an apologue.
See the Note under <er>Apologue</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Jotham's <qex>fable</qex> of the trees is the oldest extant.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note> A <ex>fable</ex> may have talking animals anthropomorphically
cast as humans representing different character types, sometimes
illustrating some moral principle; <as>as, Aesop's
<ex>Fables</ex></as>.</note><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>The plot, story, or connected series of events,
forming the subject of an epic or dramatic poem.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The moral is the first business of the poet; this being formed, he
contrives such a design or <qex>fable</qex> as may be most suitable to
the moral.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Any story told to excite wonder; common talk; the
theme of talk.</def> <ldquo/Old wives' <xex>fables</xex>. <rdquo/
<rj><au>1 Tim. iv. 7.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>We grew<br/
The <qex>fable</qex> of the city where we dwelt.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Fiction; untruth; falsehood.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It would look like a <qex>fable</qex> to report that this
gentleman gives away a great fortune by secret methods.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fable</ent><br/
<hw>Fa"ble</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Fabled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Fabling</conjf> <pr>(?)</pr>.]</vmorph> <def>To compose fables;
hence, to write or speak fiction ; to write or utter what is not
true.</def> <ldquo/He <xex>Fables</xex> not.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Vain now the tales which <qex>fabling</qex> poets tell.</q>
<rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He <qex>fables</qex>, yet speaks truth.</q> <rj><qau>M.
Arnold.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fable</ent><br/
<hw>Fa"ble</hw>, <pos>v. t.</pos> <def>To feign; to invent; to devise,
and speak of, as true or real; to tell of falsely.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The hell thou <qex>fablest</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fabler</ent><br/
<hw>Fa"bler</hw> <pr>(f<amac/"bl<etil/r)</pr>, <pos>n.</pos> <def>A
writer of fables; a fabulist; a dealer in untruths or falsehoods.</def>
<rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fabliau</ent><br/
\'d8<hw>Fa`bli`au"</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Fabliaux</plw> <pr>(-<osl/")</pr>.</plu> <ety>[F., fr.
OF.<ets>fablel</ets>, dim. of <ets>fable</ets> a fable.]</ety> <fld>(Fr.
Lit.)</fld> <def>One of the metrical tales of the Trouv<egrave/res, or
early poets of the north of France.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fabric</ent><br/
<hw>Fab"ric</hw> <pr>(f<acr/b"r<icr/k)</pr>, <pos>n.</pos> <ety>[L.
<ets>fabrica</ets> fabric, workshop: cf. F. <ets>fabrique</ets> fabric.
See <er>Forge</er>.]</ety> <sn>1.</sn> <def>The structure of anything;
the manner in which the parts of a thing are united; workmanship;
texture; make; <as>as cloth of a beautiful
<ex>fabric</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is fabricated</def>; <specif>as:</specif>
<sd>(a)</sd> <def>Framework; structure; edifice; building.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Anon out of the earth a <qex>fabric</qex> huge<br/
Rose like an exhalation.</q> <rj><qau>Milton.</qau></rj></p>

<p><sd>(b)</sd> <def>Cloth of any kind that is woven or knit from
fibers, whether vegetable, animal, or synthetic; manufactured cloth;
<as>as, silks or other <ex>fabrics</ex>; made of a <ex>fabric</ex> that
is 50% cotton and 50% polyester</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The act of constructing; construction.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Tithe was received by the bishop, . . . for the <qex>fabric</qex>
of the churches for the poor.</q> <rj><qau>Milman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Any system or structure consisting of connected
parts; <as>as, the <ex>fabric</ex> of the universe</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The whole vast <qex>fabric</qex> of society.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fabric</ent><br/
<hw>Fab"ric</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Fabricked</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Fabricking</conjf>.]</vmorph> <def>To frame; to build; to
construct.</def> <mark>[Obs.]</mark> <ldquo/<xex>Fabric</xex> their
mansions.<rdquo/ <rj><au>J. Philips.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fabricant</ent><br/
<hw>Fab"ri*cant</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<def>One who fabricates; a manufacturer.</def>
<rj><au>Simmonds.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fabricate</ent><br/
<hw>Fab"ri*cate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Fabricated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Fabricating</conjf> <pr>(?)</pr>.]</vmorph> <ety>[L.
<ets>fabricatus</ets>, p. p. of <ets>fabricari</ets>,
<ets>fabricare</ets>, to frame, build, forge, fr. <ets>fabrica</ets>.
See <er>Fabric</er>, <er>Farge</er>.]</ety> <sn>1.</sn> <def>To form
into a whole by uniting its parts; to frame; to construct; to build;
<as>as, to <ex>fabricate</ex> a bridge or ship</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To form by art and labor; to manufacture; to
produce; <as>as, to <ex>fabricate</ex> woolens</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To invent and form; to forge; to devise falsely;
<as>as, to <ex>fabricate</ex> a lie or story</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Our books were not <qex>fabricated</qex> with an accomodation to
prevailing usages.</q> <rj><qau>Paley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>fabricated</ent><br/
<hw>fabricated</hw> <pos>adj.</pos> <def>formed or conceived by the
fancy or imagination; <as>as, a <ex>fabricated</ex> excuse for his
absence</as>.</def><br/
<syn><b>Syn. --</b> fancied, fictional, fictitious, fictive, invented,
made-up.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fabrication</ent><br/
<hw>Fab`ri*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>fabricatio</ets>; cf. F. <ets>fabrication</ets>.]</ety> <sn>1.</sn>
<def>The act of fabricating, framing, or constructing; construction;
manufacture; <as>as, the <ex>fabrication</ex> of a bridge, a church, or
a government</as>.</def> <rj><au>Burke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is fabricated; a falsehood; <as>as, the
story is doubtless a <ex>fabrication</ex></as>.</def></p>

<p><syn><b>Syn.</b> -- See <er>Fiction</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fabricator</ent><br/
<hw>Fab"ri*ca`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.]</ety>
<def>One who fabricates; one who constructs or makes.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>fabricator</qex> of the works of Ossian.</q>
<rj><qau>Mason.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fabricatress</ent><br/
<hw>Fab"ri*ca`tress</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A woman who
fabricates.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fabrile</ent><br/
<hw>Fab"rile</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>fabrilis</ets>, fr. <ets>faber</ets> workman. See
<er>Forge</er>.]</ety> <def>Pertaining to a workman, or to work in
stone, metal, wood etc.; <as>as, <ex>fabrile</ex> skill</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fabulist</ent><br/
<hw>Fab"u*list</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>fabuliste</ets>, fr. L. <ets>fabula</ets>. See
<er>Fable</er>.]</ety> <def>One who invents or writes fables.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fabulize</ent><br/
<hw>Fab"u*lize</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Fabulized</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Fabulizing</conjf> <pr>(?)</pr>.]</vmorph> <ety>[Cf. F.
<ets>fabuliser</ets>. See <er>Fable</er>.]</ety> <def>To invent,
compose, or relate fables or fictions.</def> <rj><au>G. S.
Faber.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fabulosity</ent><br/
<hw>Fab`u*los"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>fabulositas</ets>: cf. F. <ets>fabulosit<eacute/</ets>.]</ety>
<sn>1.</sn> <def>Fabulousness.</def> <mark>[R.]</mark> <rj><au>Abp.
Abbot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A fabulous or fictitious story.</def>
<mark>[R.]</mark> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fabulous</ent><br/
<hw>Fab"u*lous</hw> <pr>(f<acr/b"<usl/*l<ucr/s)</pr>, <pos>a.</pos>
<ety>[L. <ets>fabulosus</ets>; cf. F. <ets>fabuleux</ets>. See
<er>Fable</er>.]</ety> <sn>1.</sn> <def>Feigned, as a story or fable;
related in fable; devised; invented; not real; fictitious; <as>as, a
<ex>fabulous</ex> description; a <ex>fabulous</ex> hero.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>fabulous</qex> birth of Minerva.</q>
<rj><qau>Chesterfield.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Beyond belief; exceedingly great; <as>as, a
<ex>fabulous</ex> price</as>.</def> <rj><au>Macaulay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Exceptionally good; extremely pleasing.</def>
<mark>[informal]</mark> <br/
[<source>PJC</source>]</p>

<p><cs><col><b>Fabulous age</b></col>, <cd>that period in the history of
a nation of which the only accounts are myths and unverified legends;
<as>as, the <ex>fabulous</ex> age of Greece and Rome</as>.</cd></cs></p>

<p>-- <wordforms><wf>Fab"u*lous*ly</wf> <pr>(#)</pr>, <pos>adv.</pos> --
<wf>Fab"u*lous*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Faburden</ent><br/
<hw>Fab"ur*den</hw> <pr>(f<acr/b"<ucr/r*d<eit/n)</pr>, <pos>n.</pos>
<ety>[F. <ets>faux bourdon</ets>. See <er>False</er>, and
<er>Burden</er> a verse.]</ety> <sn>1.</sn> <fld>(Mus.)</fld>
<sd>(a)</sd> <def>A species of counterpoint with a drone bass.</def>
<sd>(b)</sd> <def>A succession of chords of the sixth.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A monotonous refrain.</def> <mark>[Obs.]</mark>
<rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fac</ent><br/
<hw>Fac</hw> <pr>(f<acr/k)</pr>, <pos>n.</pos> <ety>[Abbrev. of
<ets>facsimile</ets>.]</ety> <def>A large ornamental letter used, esp.
by the early printers, at the commencement of the chapters and other
divisions of a book.</def> <rj><au>Brande & C.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Facade</ent><br/
\'d8<hw>Fa`<cced/ade"</hw> <pr>(f<adot/`s<adot/d" <it>or</it>
f<adot/`s<amac/d")</pr>, <pos>n.</pos> <ety>[F., fr. It.
<ets>facciata</ets>, fr. <ets>faccia</ets> face, L. <ets>facies</ets>.
See <er>Face</er>.]</ety> <fld>(Arch.)</fld> <def>The front of a
building; esp., the principal front, having some architectural
pretensions. <as>Thus a church is said to have its <ex>fa<cced/ade</ex>
unfinished, though the interior may be in use.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Face</ent><br/
<hw>Face</hw> <pr>(f<amac/s)</pr>, <pos>n.</pos> <ety>[F., from L.
<ets>facies</ets> form, shape, face, perh. from <ets>facere</ets> to
make (see <er>Fact</er>); or perh. orig. meaning <ets>appearance</ets>,
and from a root meaning <ets>to shine</ets>, and akin to E.
<ets>fancy</ets>. Cf. <er>Facetious</er>.]</ety> <sn>1.</sn> <def>The
exterior form or appearance of anything; that part which presents itself
to the view; especially, the front or upper part or surface; that which
particularly offers itself to the view of a spectator.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A mist . . . watered the whole <qex>face</qex> of the ground.</q>
<rj><qau>Gen. ii. 6.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Lake Leman wooes me with its crystal <qex>face</qex>.</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That part of a body, having several sides, which may
be seen from one point, or which is presented toward a certain
direction; one of the bounding planes of a solid; <as>as, a cube has six
<ex>faces</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Mach.)</fld> <sd>(a)</sd> <def>The principal
dressed surface of a plate, disk, or pulley; the principal flat surface
of a part or object.</def> <sd>(b)</sd> <def>That part of the acting
surface of a cog in a cog wheel, which projects beyond the pitch
line.</def> <sd>(c)</sd> <def>The width of a pulley, or the length of a
cog from end to end; <as>as, a pulley or cog wheel of ten inches
<ex>face</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Print.)</fld> <sd>(a)</sd> <def>The upper surface,
or the character upon the surface, of a type, plate, etc.</def>
<sd>(b)</sd> <def>The style or cut of a type or font of type.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Outside appearance; surface show; look; external
aspect, whether natural, assumed, or acquired.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To set a <qex>face</qex> upon their own malignant design.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>This would produce a new <qex>face</qex> of things in Europe.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>We wear a <qex>face</qex> of joy, because<br/
We have been glad of yore.</q> <rj><qau>Wordsworth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>That part of the head, esp. of man, in which the
eyes, cheeks, nose, and mouth are situated; visage;
countenance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In the sweat of thy <qex>face</qex> shalt thou eat bread.</q>
<rj><qau>Gen. iii. 19.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>Cast of features; expression of countenance; look;
air; appearance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We set the best <qex>face</qex>on it we could.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <fld>(Astrol.)</fld> <def>Ten degrees in extent of a sign
of the zodiac.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>Maintenance of the countenance free from abashment
or confusion; confidence; boldness; shamelessness; effrontery.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This is the man that has the <qex>face</qex> to charge others with
false citations.</q> <rj><qau>Tillotson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <def>Presence; sight; front; as in the phrases,
<xex>before the face of</xex>, in the immediate presence of; <xex>in the
face of</xex>, before, in, or against the front of; <as>as, to fly
<ex>in the face of</ex> danger</as>; <xex>to the face of</xex>, directly
to; <xex>from the face of</xex>, from the presence of.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>11.</sn> <def>Mode of regard, whether favorable or unfavorable;
favor or anger; mostly in Scriptural phrases.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The Lord make his <qex>face</qex> to shine upon thee.</q>
<rj><qau>Num. vi. 25.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>My <qex>face</qex> [favor] will I turn also from them.</q>
<rj><qau>Ezek. vii. 22.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>12.</sn> <fld>(Mining)</fld> <def>The end or wall of the tunnel,
drift, or excavation, at which work is progressing or was last
done.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>13.</sn> <fld>(Com.)</fld> <def>The exact amount expressed on a
bill, note, bond, or other mercantile paper, without any addition for
interest or reduction for discount; most commonly called <altname>face
value</altname>.</def> <rj><au>McElrath.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Face</xex> is used either adjectively or as part of
a compound; as, <xex>face</xex> guard or <xex>face</xex>-guard;
<xex>face</xex> cloth; <xex>face</xex> plan or <xex>face</xex>-plan;
<xex>face</xex> hammer.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Face ague</b></col> <fld>(Med.)</fld>, <cd>a form of
neuralgia, characterized by acute lancinating pains returning at
intervals, and by twinges in certain parts of the face, producing
convulsive twitches in the corresponding muscles; -- called also
<altname>tic douloureux</altname>.</cd> -- <col><b>Face card</b></col>,
<cd>one of a pack of playing cards on which a human face is represented;
the king, queen, or jack.</cd> -- <col><b>Face cloth</b></col>, <cd>a
cloth laid over the face of a corpse.</cd> -- <col><b>Face
guard</b></col>, <cd>a mask with windows for the eyes, worn by workman
exposed to great heat, or to flying particles of metal, stone, etc., as
in glass works, foundries, etc.</cd> -- <col><b>Face hammer</b></col>,
<cd>a hammer having a flat face.</cd> -- <col><b>Face joint</b></col>
<fld>(Arch.)</fld>, <cd>a joint in the face of a wall or other
structure.</cd> -- <col><b>Face mite</b></col> <fld>(Zool.)</fld>, <cd>a
small, elongated mite (<spn>Demdex folliculorum</spn>), parasitic in the
hair follicles of the face.</cd> -- <col><b>Face mold</b></col>, <cd>the
templet or pattern by which carpenters, etc., outline the forms which
are to be cut out from boards, sheet metal, etc.</cd> -- <col><b>Face
plate</b></col>. <sd>(a)</sd> <fld>(Turning)</fld> <cd>A plate attached
to the spindle of a lathe, to which the work to be turned may be
attached.</cd> <sd>(b)</sd> <cd>A covering plate for an object, to
receive wear or shock.</cd> <sd>(c)</sd> <cd>A true plane for testing a
dressed surface.</cd> <au>Knight.</au> -- <col><b>Face wheel</b></col>.
<fld>(Mach.)</fld> <sd>(a)</sd> <cd>A crown wheel.</cd> <sd>(b)</sd>
<cd>A wheel whose disk face is adapted for grinding and polishing; a
lap.</cd> -- <col><b>face value</b></col> <cd>the value written on a
financial instrument; same as <er>face{13}</er>. Also used
metaphorically, to mean <sig>apparent value</sig>; <as>as, to take his
statemnet at its <ex>face value</ex></as>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><cs> <col><b>Cylinder face</b></col> <fld>(Steam Engine)</fld>,
<cd>the flat part of a steam cylinder on which a slide valve moves.</cd>
-- <col><b>Face of an anvil</b></col>, <cd>its flat upper surface.</cd>
-- <col><b>Face of a bastion</b></col> <fld>(Fort.)</fld>, <cd>the part
between the salient and the shoulder angle.</cd> -- <col><b>Face of
coal</b></col> <fld>(Mining)</fld>, <cd>the principal cleavage plane, at
right angles to the stratification.</cd> -- <col><b>Face of a
gun</b></col>, <cd>the surface of metal at the muzzle.</cd> --
<col><b>Face of a place</b></col> <fld>(Fort.)</fld>, <cd>the front
comprehended between the flanked angles of two neighboring
bastions.</cd> <au>Wilhelm.</au> -- <col><b>Face of a square</b></col>
<fld>(Mil.)</fld>, <cd>one of the sides of a battalion when formed in a
square.</cd> -- <mcol><col><b>Face of a</b></col> <col><b>watch, clock,
compass, card etc.</b></col></mcol>, <cd>the dial or graduated surface
on which a pointer indicates the time of day, point of the compass,
etc.</cd> -- <col><b>Face to face</b></col>. <sd>(a)</sd> <cd>In the
presence of each other; <as>as, to bring the accuser and the accused
<ex>face to face</ex></as>.</cd> <sd>(b)</sd> <cd>Without the
interposition of any body or substance.</cd> <ldquo/Now we see through a
glass darkly; but then <xex>face to face</xex>.<rdquo/ 1 <au>Cor. xiii.
12.</au> <sd>(c)</sd> <cd>With the faces or finished surfaces turned
inward or toward one another; <xex>vis <agrave/ vis</xex>; -- opposed to
<contr>back to back</contr>.</cd> -- <col><b>To fly in the face
of</b></col>, <cd>to defy; to brave; to withstand.</cd> -- <col><b>To
make a face</b></col>, <cd>to distort the countenance; to make a
grimace; -- often expressing dislike, annoyance, or disagreement.</cd>
<au>Shak.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Face</ent><br/
<hw>Face</hw> <pr>(f<amac/s)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Faced</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Facing</conjf> <pr>(?)</pr>.]</vmorph> <sn>1.</sn>
<def>To meet in front; to oppose with firmness; to resist, or to meet
for the purpose of stopping or opposing; to confront; to encounter;
<as>as, to <ex>face</ex> an enemy in the field of battle</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I'll <qex>face</qex><br/
This tempest, and deserve the name of king.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To Confront impudently; to bully.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I will neither be <qex>faced</qex>nor braved.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To stand opposite to; to stand with the face or
front toward; to front upon; <as>as, the apartments of the general
<ex>faced</ex> the park; some of the seats on the train <ex>faced</ex>
backward</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He gained also with his forces that part of Britain which
<qex>faces</qex> Ireland.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To cover in front, for ornament, protection, etc.;
to put a facing upon; <as>as, a building <ex>faced</ex> with
marble</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To line near the edge, esp. with a different
material; <as>as, to <ex>face</ex> the front of a coat, or the bottom of
a dress</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To cover with better, or better appearing, material
than the mass consists of, for purpose of deception, as the surface of a
box of tea, a barrel of sugar, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Mach.)</fld> <def>To make the surface of (anything)
flat or smooth; to dress the face of (a stone, a casting, etc.); esp.,
in turning, to shape or smooth the flat surface of, as distinguished
from the cylindrical surface.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>To cause to turn or present a face or front, as in a
particular direction.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To face down</b></col>, <cd>to put down by bold or
impudent opposition.</cd> <ldquo/He <xex>faced</xex> men
<xex>down</xex>.<rdquo/ <au>Prior.</au> -- <col><b>To face (a thing)
out</b></col>, <cd>to persist boldly or impudently in an assertion or in
a line of conduct.</cd> <ldquo/That thinks with oaths <xex>to face</xex>
the matter <xex>out</xex>.<rdquo/ <au>Shak.</au> -- <col><b>to face the
music</b></col> <cd>to admit error and accept reprimand or punishment as
a consequence for having failed or having done something wrong; to
willingly experience an unpleasant situation out of a sense of duty or
obligation; <as>as, as soon as he broke the window with the football,
Billy knew he would have to <ex>face the music</ex></as>.</cd></cs><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Face</ent><br/
<hw>Face</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To carry a false
appearance; to play the hypocrite.</def> <ldquo/To lie, to
<xex>face</xex>, to forge.<rdquo/ <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To turn the face; <as>as, to <ex>face</ex> to the
right or left</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Face</qex> about, man; a soldier, and afraid!</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To present a face or front.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Faced</ent><br/
<hw>Faced</hw> <pr>(f<amac/st)</pr>, <pos>a.</pos> <def>Having (such) a
face, or (so many) faces; <as>as, smooth-<ex>faced</ex>,
two-<ex>faced</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>face-harden</ent><br/
<hw>face-harden</hw> <pos>v. t.</pos> <def>to harden (steel) by adding
carbon.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>face lift</ent><br/
<hw>face lift</hw> <pos>n.</pos> <sn>1.</sn> <def>an operation to remove
wrinkles and other signs of aging from a person's face.</def><br/
<syn><b>Syn. --</b> face lifting, rhytidectomy, rhytidoplasty.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>a renovation that improves the outward appearance,
as of a building.</def><br/
<syn><b>Syn. --</b> face lifting.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>face-lift</ent><br/
<hw>face-lift</hw> <pos>v. t.</pos> <def>to perform cosmetic surgery on
someone's face.</def><br/
<syn><b>Syn. --</b> lift.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Facer</ent><br/
<hw>Fa"cer</hw> <pr>(f<amac/"s<etil/r)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>One who faces; one who puts on a false show; a bold-faced
person.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>There be no greater talkers, nor boasters, nor
<qex>fasers</qex>.</q> <rj><qau>Latimer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A blow in the face, as in boxing; hence, any severe
or stunning check or defeat, as in controversy.</def>
<mark>[Collog.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I should have been a stercoraceous mendicant if I had hollowed
when I got a <qex>facer</qex>.</q> <rj><qau>C. Kingsley.</qau></rj></p>

<p><sn>3.</sn> <def>a serious difficulty with which one is suddenly
faced.</def> <wns>[wns=1]</wns> <mark>[obsolescent Briticism]</mark><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>face-saving</ent><br/
<hw>face-saving</hw> <pos>adj.</pos> <sn>1.</sn> <def>allowing one to
maintain one's dignity or prestige; designed to avoid admitting
something embarrassing; <as>as, a <ex>face-saving</ex> compromise</as>;
-- of actions.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><-- p. 536 --></p>

<p><ent>Facet</ent><br/
<hw>Fac"et</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>facette</ets>,
dim. of <ets>face</ets> face. See <er>Face</er>.]</ety> <sn>1.</sn>
<def>A little face; a small, plane surface; <as>as, the <ex>facets</ex>
of a diamond</as>.</def> <altsp>[Written also
<asp>facette</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Anat.)</fld> <def>A smooth circumscribed surface;
<as>as, the articular <ex>facet</ex> of a bone</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Arch.)</fld> <def>The narrow plane surface between
flutings of a column.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Zool.)</fld> <def>One of the numerous small eyes
which make up the compound eyes of insects and crustaceans.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Facet</ent><br/
<hw>Fac"et</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Faceted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Faceting</conjf>.]</vmorph> <def>To cut facets or small faces
upon; <as>as, to <ex>facet</ex> a diamond</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Facete</ent><br/
<hw>Fa*cete"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>facetus</ets> elegant, fine, facetious; akin to <ets>facies</ets>.
See <er>Face</er>, and cf. <er>Facetious</er>.]</ety> <def>Facetious;
witty; humorous.</def> <mark>[Archaic]</mark> <ldquo/A <xex>facete</xex>
discourse.<rdquo/ <rj><au>Jer. Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><ldquo/How to interpose<rdquo/ with a small, smart remark,
sentiment <qex>facete</qex>, or unctuous anecdote.</q> <rj><qau>Prof.
Wilson.</qau></rj></p>

<p>-- <wordforms><wf>Fa*cete"ly</wf>, <pos>adv.</pos> --
<wf>Fa*cete"ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Faceted</ent><br/
<hw>Fac"et*ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having
facets.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Facetiae</ent><br/
\'d8<hw>Fa*ce"ti*<ae/</hw> <pr>(<?/)</pr>, <pos>n. pl.</pos> <ety>[L.,
fr. <ets>facetus</ets>. See <er>Facete</er>.]</ety> <def>Witty or
humorous writings or saying; witticisms; merry conceits.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>face time</ent><br/
<hw>face" time`</hw> <pr>(f<amac/s" t<imac/m`)</pr>, <pos>n.</pos>
<def>Time spent speaking with a person face-to-face; -- contrasted with
time spent communicating by electronic media, such as telephone or
e-mail, or via written communications; <as>as, the chief of staff has
the most <ex>face time</ex> with the president</as>.</def>
<mark>[Recent]</mark><br/
[<source>PJC</source>]</p>

<p><ent>Facetious</ent><br/
<hw>Fa*ce"tious</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>fac<eacute/tieux</ets>. See <er>Faceti<ae/</er>.]</ety> <sn>1.</sn>
<def>Given to wit and good humor; merry; sportive; jocular; <as>as, a
<ex>facetious</ex> companion</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Characterized by wit and pleasantry; exciting
laughter; <as>as, a <ex>facetious</ex> story or reply</as>.</def></p>

<p>-- <wordforms><wf>Fa*ce"tious*ly</wf>, <pos>adv.</pos> --
<wf>Fa*ce"tious*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>face-to-face</ent><br/
<hw>face-to-face</hw> <pos>adj.</pos> <sn>1.</sn> <def>without
intervening persons; involving direct communication between persons in
each other's presence; -- of conversation or confrontation; <as>as,
<ex>face-to-face</ex> negotiations</as>.</def><br/
<syn><b>Syn. --</b> person-to-person.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>having the front parts facing each other.</def><br/
[<source>PJC</source>]</p>

<p><ent>Facette</ent><br/
<hw>Fa*cette"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety> <def>See
<er>Facet</er>, <pos>n.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Facework</ent><br/
<hw>Face"work`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The material of the
outside or front side, as of a wall or building; facing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Facia</ent><br/
<hw>Fa"ci*a</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Arch.)</fld> <def>See
<er>Fascia</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Facial</ent><br/
<hw>Fa"cial</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[LL.
<ets>facialis</ets>, fr. L. <ets>facies</ets> face : cf. F.
<ets>facial</ets>.]</ety> <def>Of or pertaining to the face; <as>as, the
<ex>facial</ex> artery, vein, or nerve</as>.</def> --
<wordforms><wf>Fa"cial*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Facial angle</b></col> <fld>(Anat.)</fld>, <cd>the angle,
in a skull, included between a straight line (<it>ab</it>, in the
illustrations), from the most prominent part of the forehead to the
front efge of the upper jaw bone, and another (<it>cd</it>) from this
point to the center of the external auditory opening. See <cref>Gnathic
index</cref>, under <er>Gnathic</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Faciend</ent><br/
<hw>Fa"ci*end</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From neut. of L.
<ets>faciendus</ets>, gerundive of <ets>facere</ets> to do.]</ety>
<fld>(Mach.)</fld> <def>The multiplicand. See <er>Facient</er>,
2.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Facient</ent><br/
<hw>Fa"cient</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>faciens</ets>, -- <ets>entis</ets>, p. pr. of <ets>facere</ets> to
make, do. See <er>Fact</er>.]</ety> <sn>1.</sn> <def>One who does
anything, good or bad; a doer; an agent.</def> <mark>[Obs.]</mark>
<rj><au>Bp. Hacket.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mach.)</fld> <sd>(a)</sd> <def>One of the variables
of a quantic as distinguished from a coefficient.</def> <sd>(b)</sd>
<def>The multiplier.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The terms <xex>facient</xex>, <xex>faciend</xex>, and
<xex>factum</xex>, may imply that the multiplication involved is not
ordinary multiplication, but is either some specified operation, or, in
general, any mathematical operation. See
<er>Multiplication</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Facies</ent><br/
\'d8<hw>Fa"ci*es</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., from, face.
See <er>Face</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>The anterior part of the head; the face.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Biol.)</fld> <def>The general aspect or habit of a
species, or group of species, esp. with reference to its adaptation to
its environment.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <def>The face of a bird, or the front
of the head, excluding the bill.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Facies Hippocratica</b></col>. <fld>(Med.)</fld> <cd>See
<er>Hippocratic</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Facile</ent><br/
<hw>Fac"ile</hw> <pr>(?)</pr> <pos>a.</pos> <ety>[L. <ets>facilis</ets>,
prop., capable of being done or made, hence, facile, easy, fr.
<ets>facere</ets> to make, do: cf. F. <ets>facile</ets>. Srr
<er>Fact</er>, and cf. <er>Faculty</er>.]</ety> <sn>1.</sn> <def>Easy to
be done or performed: not difficult; performable or attainable with
little labor.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Order . . . will render the work <qex>facile</qex> and
delightful.</q> <rj><qau>Evelyn.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Easy to be surmounted or removed; easily
conquerable; readily mastered.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>facile</qex> gates of hell too slightly barred.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Easy of access or converse; mild; courteous; not
haughty, austere, or distant; affable; complaisant.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I meant she should be courteous, <qex>facile</qex>, sweet.</q>
<rj><qau>B. Jonson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Easily persuaded to good or bad; yielding; ductile
to a fault; pliant; flexible.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Since Adam, and his <qex>facile</qex> consort Eve,<br/
Lost Paradise, deceived by me.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>This is treating Burns like a child, a person of so
<qex>facile</qex> a disposition as not to be trusted without a keeper on
the king's highway.</q> <rj><qau>Prof. Wilson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Ready; quick; expert; <as>as, he is <ex>facile</ex>
in expedients; he wields a <ex>facile</ex> pen.</as></def></p>

<p>-- <wordforms><wf>Fac"ile*ly</wf>, <pos>adv.</pos> --
<wf>Fac"ile*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Facilitate</ent><br/
<hw>Fa*cil"i*tate</hw> <pr>(f<adot/*s<icr/l"<icr/*t<amac/t)</pr>,
<pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Facilitated</conjf>
<pr>(f<adot/*s<icr/l"<icr/*t<amac/`t<ecr/d)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Facilitating</conjf>
<pr>(f<adot/*s<icr/l"<icr/*t<amac/`t<icr/ng)</pr>.]</vmorph> <ety>[Cf.
F. <ets>faciliter</ets>. See <er>Facility</er>.]</ety> <def>To make easy
or less difficult; to free from difficulty or impediment; to lessen the
labor of; <as>as, to <ex>facilitate</ex> the execution of a
task</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To invite and <qex>facilitate</qex> that line of proceeding which
the times call for.</q> <rj><qau>I. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>facilitated</ent><br/
<hw>facilitated</hw> <pos>adj.</pos> <def>freed from difficulty or
impediment. Contrasted with <ant>delayed</ant>.</def><br/
<syn><b>Syn. --</b> expedited.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Facilitation</ent><br/
<hw>Fa*cil`i*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
facilitating or making easy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>facilitative</ent><br/
<hw>facilitative</hw> <pos>adj.</pos> <def>freeing from difficulty or
impediment; <as>as, <ex>facilitative</ex> changes in the economic
structure</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>facilitator</ent><br/
<hw>facilitator</hw> <pos>n.</pos> <def>someone who makes progress
easier.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>facilitatory</ent><br/
<hw>facilitatory</hw> <pos>adj.</pos> <fld>(Med.)</fld> <def>inducing or
aiding in facilitating neural activity.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Facility</ent><br/
<hw>Fa*cil"i*ty</hw> <pr>(f<adot/*s<icr/l"<icr/*t<ycr/)</pr>,
<pos>n.</pos>; <plu><it>pl.</it> <plw>Facilities</plw>
<pr>(f<adot/*s<icr/l"<icr/*t<icr/z)</pr>.</plu> <ety>[L.
<ets>facilitas</ets>, fr. <ets>facilis</ets> easy: cf. F.
<ets>facilit<eacute/</ets>. See <er>Facile</er>.]</ety> <sn>1.</sn>
<def>The quality of being easily performed; freedom from difficulty;
ease; <as>as, the <ex>facility</ex> of an operation</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>facility</qex> with which government has been overturned
in France.</q> <rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Ease in performance; readiness proceeding from skill
or use; dexterity; <as>as, practice gives a wonderful <ex>facility</ex>
in executing works of art</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Easiness to be persuaded; readiness or compliance;
-- usually in a bad sense; pliancy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It is a great error to take <qex>facility</qex> for good
nature.</q> <rj><qau>L'Estrange.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Easiness of access; complaisance;
affability.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Offers himself to the visits of a friend with
<qex>facility</qex>.</q> <rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>That which promotes the ease of any action or course
of conduct; advantage; aid; assistance; -- usually in the plural;
<as>as, special <ex>facilities</ex> for study</as>.</def></p>

<p><syn><b>Syn.</b> -- Ease; expertness; readiness; dexterity;
complaisance; condescension; affability.</syn> <usage> --
<er>Facility</er>, <er>Expertness</er>, <er>Readiness</er>. These words
have in common the idea of performing any act with ease and promptitude.
<xex>Facility</xex> supposes a natural or acquired power of dispatching
a task with lightness and ease. <xex>Expertness</xex> is the kind of
facility acquired by long practice. <xex>Readiness</xex> marks the
promptitude with which anything is done. A merchant needs great
<xex>facility</xex> in dispatching business; a banker, great
<xex>expertness</xex> in casting accounts; both need great
<xex>readiness</xex> in passing from one employment to another.
<ldquo/The <xex>facility</xex> which we get of doing things by a custom
of doing, makes them often pass in us without our notice.<rdquo/
<au>Locke.</au> <ldquo/The army was celebrated for the
<xex>expertness</xex> and valor of the soldiers.<rdquo/ <ldquo/A
<xex>readiness</xex> to obey the known will of God is the surest means
to enlighten the mind in respect to duty.<rdquo/</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Facing</ent><br/
<hw>Fa"cing</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A covering
in front, for ornament or other purpose; an exterior covering or
sheathing; <as>as, the <ex>facing</ex> of an earthen slope, sea wall,
etc.</as> , to strengthen it or to protect or adorn the exposed
surface.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A lining placed near the edge of a garment for
ornament or protection.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Arch.)</fld> <def>The finishing of any face of a
wall with material different from that of which it is chiefly composed,
or the coating or material so used.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Founding)</fld> <def>A powdered substance, as
charcoal, bituminous coal, etc., applied to the face of a mold, or mixed
with the sand that forms it, to give a fine smooth surface to the
casting.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Mil.)</fld> <sd>(a)</sd> <pluf>pl.</pluf> <def>The
collar and cuffs of a military coat; -- commonly of a color different
from that of the coat.</def> <sd>(b)</sd> <def>The movement of soldiers
by turning on their heels to the right, left, or about; -- chiefly in
the <pluf>pl.</pluf></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Facing brick</b></col>, <cd>front or pressed
brick.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Facingly</ent><br/
<hw>Fa"cing*ly</hw>, <pos>adv.</pos> <def>In a facing manner or
position.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Facinorous</ent><br/
<hw>Fa*cin"o*rous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>facinorous</ets>, from <ets>facinus</ets> deed, bad deed, from
<ets>facere</ets> to make, do.]</ety> <def>Atrociously wicked.</def>
<mark>[Obs.]</mark> <rj><au>Jer. Taylor.</au></rj></p>

<p>-- <wordforms><wf>Fa*cin"o*rous*ness</wf>, <pos>n.</pos>
<mark>[Obs.]</mark></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Facound</ent><br/
<hw>Fac"ound</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>faconde</ets>, L. <ets>facundia</ets>. See <er>Facund</er>.]</ety>
<def>Speech; eloquence.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Her <qex>facound</qex> eke full womanly and plain.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Facsimile</ent><br/
<hw>Fac*sim"i*le</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Facsimiles</plw> <pr>(-l<emac/z)</pr>.</plu> <ety>[L. <ets>fac
simile</ets> make like; or an abbreviation of <ets>factum simile</ets>
made like; <ets>facere</ets> to make + <ets>similes</ets> like. See
<er>Fact</er>, and <er>Simile</er>.]</ety> <sn>1.</sn> <def>A copy of
anything made, either so as to be deceptive or so as to give every part
and detail of the original; an exact copy or likeness.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Telecommunications)</fld> <def>A method for
reproducing documents, drawing, or other planar image at a remote
location by converting the document into coded electronic signals at one
point, transmitting data via telephone line or radio signals to the
remote point, and converting the signals back into a likeness of the
original image. The device used at each end to convert the image to and
from electronic signals was originally called <uses>Facsimile
telegraph</uses>, then <uses>telefax machine</uses>, and now more
commonly <uses>fax machine</uses>. The same process, using the same data
transmission protocols, is now performed not only by devices dedicated
exclusively to the telefax process, but also by computers and combined
copying/scanning/telefax machines. Also called
<altname>telefax</altname> or <altname>fax</altname>.</def><br/
[<source>PJC</source>]</p>
s <p><cs><col><b>Facsimile telegraph</b></col>, <cd>a telegraphic
apparatus reproducing messages in autograph; a fax
machine.</cd></cs><br/
[<source>1913 Webster</source>+ <source>PJC</source>]</p>

<p><ent>Facsimile</ent><br/
<hw>Fac*sim"i*le</hw>, <pr>(<?/)</pr>, <pos>v. t.</pos> <def>To make a
facsimile of.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fact</ent><br/
<hw>Fact</hw> <pr>(f<acr/kt)</pr>, <pos>n.</pos> <ety>[L.
<ets>factum</ets>, fr. <ets>facere</ets> to make or do. Cf.
<er>Feat</er>, <er>Affair</er>, <er>Benefit</er>, <er>Defect</er>,
<er>Fashion</er>, and <er>-fy</er>.]</ety> <sn>1.</sn> <def>A doing,
making, or preparing.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>A project for the <qex>fact</qex> and vending<br/
Of a new kind of fucus, paint for ladies.</q> <rj><qau>B.
Jonson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An effect produced or achieved; anything done or
that comes to pass; an act; an event; a circumstance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>What might instigate him to this devilish <qex>fact</qex>, I am
not able to conjecture.</q> <rj><qau>Evelyn.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He who most excels in <qex>fact</qex> of arms.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Reality; actuality; truth; <as>as, he, in
<ex>fact</ex>, excelled all the rest; the <ex>fact</ex> is, he was
beaten.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The assertion or statement of a thing done or
existing; sometimes, even when false, improperly put, by a transfer of
meaning, for the thing done, or supposed to be done; a thing supposed or
asserted to be done; <as>as, history abounds with false
<ex>facts</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I do not grant the <qex>fact</qex>.</q> <rj><qau>De
Foe.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>This reasoning is founded upon a <qex>fact</qex> which is not
true.</q> <rj><qau>Roger Long.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The term <xex>fact</xex> has in jurisprudence peculiar
uses in contrast with <xex>law</xex>; as, attorney at <xex>law</xex>,
and attorney in <xex>fact</xex>; issue in <xex>law</xex>, and issue in
<xex>fact</xex>. There is also a grand distinction between
<xex>law</xex> and <xex>fact</xex> with reference to the province of the
judge and that of the jury, the latter generally determining the
<xex>fact</xex>, the former the <xex>law</xex>.</note>
<rj><au>Burrill</au> <au>Bouvier.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Accessary before the fact</b></col>, <it>or</it>
<col><b>Accessary after the fact</b></col></mcol>. <cd>See under
<er>Accessary</er>.</cd> -- <col><b>Matter of fact</b></col>, <cd>an
actual occurrence; a verity; used adjectively: of or pertaining to
facts; prosaic; unimaginative; <as>as, a <ex>matter-of-fact</ex>
narration</as>.</cd></cs></p>

<p><syn><b>Syn.</b> -- Act; deed; performance; event; incident;
occurrence; circumstance.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>fact-finding</ent><br/
<hw>fact-finding</hw> <pos>adj.</pos> <def>designed to find information
or ascertain facts; <as>as, a <ex>fact-finding</ex>
committee</as>.</def><br/
<syn><b>Syn. --</b> investigative, investigatory.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Faction</ent><br/
<hw>Fac"tion</hw> <pr>(f<acr/k"sh<ucr/n)</pr>, <pos>n.</pos> <ety>[L.
<ets>factio</ets> a doing, a company of persons acting together, a
faction: cf. F. <ets>faction</ets> See <er>Fashion</er>.]</ety>
<sn>1.</sn> <fld>(Anc. Hist.)</fld> <def>One of the divisions or parties
of charioteers (distinguished by their colors) in the games of the
circus.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A party, in political society, combined or acting in
union, in opposition to the government, or state; -- usually applied to
a minority, but it may be applied to a majority; a combination or clique
of partisans of any kind, acting for their own interests, especially if
greedy, clamorous, and reckless of the common good.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Tumult; discord; dissension.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They remained at Newbury in great <qex>faction</qex> among
themselves.</q> <rj><qau>Clarendon.</qau></rj></p>

<p><syn><b>Syn.</b> -- Combination; clique; junto. See
<er>Cabal</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Factionary</ent><br/
<hw>Fac"tion*a*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>factionnaire</ets>, L. <ets>factionarius</ets> the head of a
company of charioteers.]</ety> <def>Belonging to a faction; being a
partisan; taking sides.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Always <qex>factionary</qex> on the party of your general.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Factioner</ent><br/
<hw>Fac"tion*er</hw> <pr>(-?r)</pr>, <pos>n.</pos> <def>One of a
faction.</def> <rj><au>Abp. Bancroft.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Factionist</ent><br/
<hw>Fac"tion*ist</hw>, <pos>n.</pos> <def>One who promotes
faction.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Factious</ent><br/
<hw>Fac"tious</hw> <pr>(?)</pr>. <pos>a.</pos> <ety>[L.
<ets>factiosus</ets>: cf. F. <ets>factieux</ets>.]</ety> <sn>1.</sn>
<def>Given to faction; addicted to form parties and raise dissensions,
in opposition to government or the common good; turbulent; seditious;
prone to clamor against public measures or men; -- said of
persons.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Factious</qex> for the house of Lancaster.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Pertaining to faction; proceeding from faction;
indicating, or characterized by, faction; -- said of acts or
expressions; <as>as, <ex>factious</ex> quarrels</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Headlong zeal or <qex>factious</qex> fury.</q>
<rj><qau>Burke.</qau></rj></p>

<p>-- <wordforms><wf>Fac"tious*ly</wf>, <pos>adv.</pos> --
<wf>Fac"tious*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Factitious</ent><br/
<hw>Fac*ti"tious</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>factitius</ets>, fr. <ets>facere</ets> to make. See <er>Fact</er>,
and cf. <er>Fetich</er>.]</ety> <def>Made by art, in distinction from
what is produced by nature; artificial; sham; contrived; formed by, or
adapted to, an artificial or conventional, in distinction from a
natural, standard or rule; not natural; <as>as, <ex>factitious</ex>
cinnabar or jewels; a <ex>factitious</ex> taste.</as></def> --
<wordforms><wf>Fac-ti"tious*ly</wf>, <pos>adv.</pos> --
<wf>Fac*ti"tious*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><q>He acquires a <qex>factitious</qex> propensity, he forms an
incorrigible habit, of desultory reading.</q> <rj><qau>De
Quincey.</qau></rj></p>

<p><syn><b>Syn.</b> -- Unnatural.</syn> <usage> -- <er>Factitious</er>,
<er>Unnatural</er>. Anything is <xex>unnatural</xex> when it departs in
any way from its simple or normal state; it is <xex>factitious</xex>
when it is wrought out or wrought up by labor and effort, as, a
<xex>factitious</xex> excitement. An <xex>unnatural</xex> demand for any
article of merchandise is one which exceeds the ordinary rate of
consumption; a factitious demand is one created by active exertions for
the purpose. An <xex>unnatural</xex> alarm is one greater than the
occasion requires; a <xex>factitious</xex> alarm is one wrought up with
care and effort.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Factitive</ent><br/
<hw>Fac"ti*tive</hw> <pr>(?)</pr>. <pos>a.</pos> <ety>[See
<er>Fact</er>.]</ety> <sn>1.</sn> <def>Causing; causative.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Gram.)</fld> <def>Pertaining to that relation which
is proper when the act, as of a transitive verb, is not merely received
by an object, but produces some change in the object, as when we say, He
made the water wine.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Sometimes the idea of activity in a verb or adjective involves in
it a reference to an effect, in the way of causality, in the active
voice on the immediate objects, and in the passive voice on the subject
of such activity. This second object is called the <qex>factitive</qex>
object.</q> <rj><qau>J. W. Gibbs.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Factive</ent><br/
<hw>Fac"tive</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Making; having power
to make.</def> <mark>[Obs.]</mark> <ldquo/You are . . .
<xex>factive</xex>, not destructive.<rdquo/ <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Facto</ent><br/
\'d8<hw>Fac"to</hw> <pr>(?)</pr>, <pos>adv.</pos> <ety>[L., ablative of
<ets>factum</ets> deed, fact.]</ety> <fld>(Law)</fld> <def>In fact; by
the act or fact.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>De facto</b></col>. <fld>(Law)</fld> <cd>See <er>De
facto</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Factor</ent><br/
<hw>Fac"tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>factor</ets>
a doer: cf. F. <ets>facteur</ets> a factor. See <er>Fact</er>.]</ety>
<sn>1.</sn> <fld>(Law)</fld> <def>One who transacts business for
another; an agent; a substitute; especially, a mercantile agent who buys
and sells goods and transacts business for others in commission; a
commission merchant or consignee. He may be a home factor or a foreign
factor. He may buy and sell in his own name, and he is intrusted with
the possession and control of the goods; and in these respects he
differs from a broker.</def> <rj><au>Story.</au>
<au>Wharton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>My <qex>factor</qex> sends me word, a merchant's fled<br/
That owes me for a hundred tun of wine.</q>
<rj><qau>Marlowe.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A steward or bailiff of an estate.</def>
<mark>[Scot.]</mark> <rj><au>Sir W. Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Math.)</fld> <def>One of the elements or quantities
which, when multiplied together, form a product.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>One of the elements, circumstances, or influences
which contribute to produce a result; a constituent; a contributory
cause.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><q>The materal and dynamical <qex>factors</qex> of nutrition.</q>
<rj><qau>H. Spencer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Factor</ent><br/
<hw>Fac"tor</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Factored</conjf> <pr>(-t<ecr/rd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Factoring</conjf>.]</vmorph> <fld>(Mach.)</fld> <def>To resolve
(a quantity) into its factors.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Factorage</ent><br/
<hw>Fac"tor*age</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>factorage</ets>.]</ety> <def>The allowance given to a factor, as a
compensation for his services; -- called also a
<altname>commission</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Factoress</ent><br/
<hw>Fac"tor*ess</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A factor who is a
woman.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Factorial</ent><br/
<hw>Fac*to"ri*al</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Of or
pertaining to a factory.</def> <rj><au>Buchanan.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Math.)</fld> <def>Related to factorials.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Factorial</ent><br/
<hw>Fac*to"ri*al</hw>, <pos>n.</pos> <fld>(Math.)</fld> <sd>(a)</sd>
<pluf>pl.</pluf> <def>A name given to the factors of a continued product
when the former are derivable from one and the same function F(x) by
successively imparting a constant increment or decrement <xex>h</xex> to
the independent variable. Thus the product <mathex>F(x).F(x + h).F(x +
2h) . . . F[x + (n-1)h]</mathex> is called a <xex>factorial term</xex>,
and its several factors take the name of <xex>factorials</xex>.</def>
<rj><au>Brande & C.</au></rj></p>

<p><sd>(b)</sd> <def>The product of the consecutive whole numbers from
unity up to any given number; <as>thus, 5 <ex>factorial</ex> is the
product of 5 times four times three times two times one, or
120</as>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Factoring</ent><br/
<hw>Fac"tor*ing</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Math.)</fld>
<def>The act of resolving into factors.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>factorise</ent><br/
<hw>factorise</hw> <pos>v. t.</pos> <sn>1.</sn> <def>to resolve into
factors, as of a polynomial; same as <er>factorize</er>.</def>
<mark>[mostly Brit.]</mark> <br/
<syn><b>Syn. --</b> factorize.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>factorize</ent><br/
<hw>fac"tor*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Factorized</conjf> <pr>(-?zd)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Factorizing</conjf> <pr>(-?"z?ng)</pr>.]</vmorph>
<sn>1.</sn> <fld>(Law)</fld> <sd>(a)</sd> <def>To give warning to; --
said of a person in whose hands the effects of another are attached, the
warning being to the effect that he shall not pay the money or deliver
the property of the defendant in his hands to him, but appear and answer
the suit of the plaintiff.</def> <sd>(b)</sd> <def>To attach (the
effects of a debtor) in the hands of a third person; to garnish. See
<er>Garnish</er>.</def> <mark>[Vt. & Conn.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Math.)</fld> <def>to resolve (a complex expression,
such as a polynomial) into factors.</def><br/
<syn><b>Syn. --</b> factorise.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Factorship</ent><br/
<hw>Fac"tor*ship</hw>, <pos>n.</pos> <def>The business of a
factor.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Factory</ent><br/
<hw>Fac"to*ry</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Factories</plw> <pr>(-r<icr/z)</pr>.</plu> <ety>[Cf. F.
<ets>factorerie</ets>.]</ety> <sn>1.</sn> <def>A house or place where
factors, or commercial agents, reside, to transact business for their
employers.</def> <ldquo/The Company's <xex>factory</xex> at
Madras.<rdquo/ <rj><au>Burke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The body of factors in any place; <as>as, a chaplain
to a British <ex>factory</ex></as>.</def> <rj><au>W.
Guthrie.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A building, or collection of buildings, appropriated
to the manufacture of goods; the place where workmen are employed in
fabricating goods, wares, or utensils; a manufactory; <as>as, a cotton
<ex>factory</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Factory leg</b></col> <fld>(Med.)</fld>, <cd>a variety of
bandy leg, associated with partial dislocation of the tibia, produced in
young children by working in factories.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>factory-made</ent><br/
<hw>factory-made</hw> <pos>adj.</pos> <def>made in a factory. Contrasted
with <ant>homemade</ant>.</def> [Narrower terms: <stype>boughten,
store-bought </stype>; <stype>mass-produced </stype>]<br/
[<source>WordNet 1.5</source>]</p>

<p><ent>factotum</ent><br/
<hw>fac*to"tum</hw> <pr>(f<acr/k*t<omac/"t<ucr/m)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>factotums</plw> <pr>(-t<ucr/mz)</pr>.</plu>
<ety>[L., do everything; <ets>facere</ets> to do + <ets>totus</ets> all
: cf. F. <ets>factotum</ets>. See <er>Fact</er>, and
<er>Total</er>.]</ety> <def>A person employed to do all kinds of work or
business; a person with many different responsibilities.</def>
<rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>factual</ent><br/
<hw>fac"tu*al</hw> <pr>(f<acr/k*t<usl/"<ait/l)</pr>, <pos>a.</pos>
<sn>1.</sn> <def>of or pertaining to facts; <as>as, <ex>factual</ex>
inaccuracies</as>.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>containing only facts (as contrasted with opinions
or speculations); <as>as, a <ex>factual</ex> report</as>.</def><br/
[<source>PJC</source>]</p>

<p><-- p. 537 --></p>

<p><ent>Factum</ent><br/
\'d8<hw>Fac"tum</hw> <pr>(f<acr/k"t<ucr/m)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Facta</plw> <pr>(#)</pr>.</plu> <ety>[L. See
<er>Fact</er>.]</ety> <sn>1.</sn> <fld>(Law)</fld> <def>A man's own act
and deed</def>; particularly: <sd>(a)</sd> <fld>(Civil Law)</fld>
<def>Anything stated and made certain.</def> <sd>(b)</sd>
<fld>(Testamentary Law)</fld> <def>The due execution of a will,
including everything necessary to its validity.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mach.)</fld> <def>The product. See
<er>Facient</er>, 2.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Facture</ent><br/
<hw>Fac"ture</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>facture</ets> a making, invoice, L. <ets>factura</ets> a making.
See <er>Fact</er>.]</ety> <sn>1.</sn> <def>The act or manner of making
or doing anything; -- now used of a literary, musical, or pictorial
production.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Com.)</fld> <def>An invoice or bill of
parcels.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>faculae</ent><br/
\'d8<hw>fac"u*l<ae/</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[L., pl.
<ets>of facula</ets> a little torch.]</ety> <fld>(Astron.)</fld>
<def>Groups of small shining spots on the surface of the sun which are
brighter than the other parts of the <partof>photosphere</partof>. They
are generally seen in the neighborhood of the dark spots, and are
supposed to be elevated portions of the photosphere.</def>
<rj><au>Newcomb.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Facular</ent><br/
<hw>Fac"u*lar</hw> <pr>(?)</pr> <pos>a.</pos> <fld>(Astron.)</fld>
<def>Of or pertaining to the facul<ae/.</def> <rj><au>R. A.
Proctor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Facultative</ent><br/
<hw>Fac"ul*ta*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>facultas</ets>, <ets>-atis</ets>, faculty: cf. F.
<ets>facultatif</ets>, G. <ets>fakultativ</ets>.]</ety> <sn>1.</sn>
<def>Having relation to the grant or exercise faculty, or authority,
privilege, license, or the like hence, optional; <as>as,
<ex>facultative</ex> enactments, or those which convey a faculty, or
permission; the <ex>facultative</ex> referendum of Switzerland is one
that is optional with the people and is necessary only when demanded by
petition; <ex>facultative</ex> studies;</as> -- opposed to
<contr>obligatory</contr> and <contr>compulsory</contr>, and sometimes
used with <xex>to</xex>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>Of such a character as to admit of existing under
various forms or conditions, or of happening or not happening, or the
like;</def> <specif>specif.</specif>: <fld>(Biol.)</fld> <def>Having the
power to live under different conditions; <as>as, a <ex>facultative</ex>
parasite, a plant which is normally saprophytic, but which may exist
wholly or in part as a parasite</as>; -- opposed to
<contr>obligate</contr>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>3.</sn> <fld>(Physiol.)</fld> <def>Pertaining to a faculty or
faculties.</def></p>

<p><q>In short, there is no <qex>facultative</qex> plurality in the
mind; it is a single organ of true judgment for all purposes, cognitive
or practical.</q> <rj><qau>J. Martineau.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Faculty</ent><br/
<hw>Fac"ul*ty</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Faculties</plw> <pr>(#)</pr>.</plu> <ety>[F. <ets>facult<?/</ets>,
L. <ets>facultas</ets>, fr. <ets>facilis</ets> easy (cf.
<ets>facul</ets> easily), fr. <ets>fecere</ets> to make. See
<er>Fact</er>, and cf. <er>Facility</er>.]</ety> <sn>1.</sn>
<def>Ability to act or perform, whether inborn or cultivated; capacity
for any natural function; especially, an original mental power or
capacity for any of the well-known classes of mental activity; psychical
or soul capacity; capacity for any of the leading kinds of soul
activity, as knowledge, feeling, volition; intellectual endowment or
gift; power; <as>as, <ex>faculties</ex> of the mind or the
soul</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>But know that in the soul<br/
Are many lesser <qex>faculties</qex> that serve<br/
Reason as chief.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>What a piece of work is a man ! how noble in reason ! how infinite
in <qex>faculty</qex> !</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Special mental endowment; characteristic
knack.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He had a ready <qex>faculty</qex>, indeed, of escaping from any
topic that agitated his too sensitive and nervous temperament.</q>
<rj><qau>Hawthorne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Power; prerogative or attribute of office.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>This Duncan<br/
Hath borne his <qex>faculties</qex> so meek.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Privilege or permission, granted by favor or
indulgence, to do a particular thing; authority; license;
dispensation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The pope . . . granted him a <qex>faculty</qex> to set him free
from his promise.</q> <rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>It had not only <qex>faculty</qex> to inspect all bishops'
dioceses, but to change what laws and statutes they should think fit to
alter among the colleges.</q> <rj><qau>Evelyn.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A body of a men to whom any specific right or
privilege is granted; formerly, the graduates in any of the four
departments of a university or college (Philosophy, Law, Medicine, or
Theology), to whom was granted the right of teaching
(<xex>profitendi</xex> or <xex>docendi</xex>) in the department in which
they had studied; at present, the members of a profession itself;
<as>as, the medical <ex>faculty</ex>; the legal <ex>faculty</ex>,
etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Amer. Colleges)</fld> <def>The body of person to
whom are intrusted the government and instruction of a college or
university, or of one of its departments; the president, professors, and
tutors in a college.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dean of faculty</b></col>. <cd>See under
<er>Dean</er>.</cd> -- <col><b>Faculty of advocates</b></col>.
<fld>(Scot.)</fld> <cd>See under <er>Advocate</er>.</cd></cs></p>

<p><syn><b>Syn.</b> -- Talent; gift; endowment; dexterity; expertness;
cleverness; readiness; ability; knack.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Facund</ent><br/
<hw>Fac"und</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>facundus</ets>, fr. <ets>fari</ets> to speak.]</ety>
<def>Eloquent.</def> <mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Facundious</ent><br/
<hw>Fa*cun"di*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>facundiosus</ets>.]</ety> <def>Eloquement; full of words.</def>
<mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Facundity</ent><br/
<hw>Fa*cun"di*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>facunditas</ets>.]</ety> <def>Eloquence; readiness of speech.</def>
<mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fad</ent><br/
<hw>Fad</hw> <pr>(f<acr/d)</pr>, <pos>n.</pos> <ety>[Cf.
<er>Faddle</er>.]</ety> <sn>1.</sn> <def>A hobby ; freak;
whim.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It is your favorite <qex>fad</qex> to draw plans.</q> <rj><qau>G.
Eliot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>a practise followed enthusiastically by a number of
people for a limited period of time; <as>as, the latest <ex>fad</ex> in
fashion</as>.</def><br/
<syn><b>Syn. --</b> craze; mania.</syn><br/
[<source>PJC</source>]</p>

<p> -- <wordforms><wf>Fad"dist</wf>, <pos>n.</pos></wordforms><br/
-- <wordforms><wf>Fad"dish</wf>, <pos>a.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fadaise</ent><br/
\'d8<hw>Fa`daise"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<def>A vapid or meaningless remark; a commonplace; nonsense.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>faddy</ent><br/
<ent>faddish</ent><br/
<mhw><hw>faddish</hw> <hw>faddy</hw></mhw> <pos>adj.</pos> <sn>1.</sn>
<def>intensely fashionable for a short time.</def>
<wns>[wns=1]</wns><br/
<syn><b>Syn. --</b> trendy.</syn>
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>prone to follow fads; <as>as, a <ex>faddish</ex>
clique of teenagers</as>; -- of people.</def><br/
<syn><b>Syn. --</b> trendy.</syn>
[<source>PJC</source>]</p>

<p><ent>faddist</ent><br/
<hw>faddist</hw> <pos>n.</pos> <def>a person who subscribes to a variety
of fads.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Faddle</ent><br/
<hw>Fad"dle</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[Cf.
<er>Fiddle</er>, <er>Fiddle-faddle</er>.]</ety> <def>To trifle; to
toy.</def> -- <def2><pos>v. t.</pos> <def>To fondle; to dandle.</def>
<mark>[Prov. Eng.]</mark></def2> <rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fade</ent><br/
<hw>Fade</hw> <pr>(?)</pr> <pos>a.</pos> <ety>[F., prob. fr. L.
<ets>vapidus</ets> vapid, or possibly fr,<ets>fatuus</ets> foolish,
insipid.]</ety> <def>Weak; insipid; tasteless; commonplace.</def>
<mark>[R.]</mark> <ldquo/Passages that are somewhat
<xex>fade</xex>.<rdquo/ <rj><au>Jeffrey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>His masculine taste gave him a sense of something <qex>fade</qex>
and ludicrous.</q> <rj><qau>De Quincey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fade</ent><br/
<hw>Fade</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Faded</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Fading</conjf>.]</vmorph> <ety>[OE. <ets>faden</ets>,
<ets>vaden</ets>, prob. fr. <ets>fade</ets>, <pos>a.</pos>; cf. Prov. D.
<ets>vadden</ets> to fade, wither, <ets>vaddigh languid</ets>,
<ets>torpid</ets>. Cf. <er>Fade</er>, <pos>a.</pos>,
<er>Vade</er>.]</ety> <sn>1.</sn> <def>To become fade; to grow weak; to
lose strength; to decay; to perish gradually; to wither, as a
plant.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The earth mourneth and <qex>fadeth</qex> away.</q> <rj><qau>Is.
xxiv. 4.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To lose freshness, color, or brightness; to become
faint in hue or tint; hence, to be wanting in color.</def>
<ldquo/Flowers that never <xex>fade</xex>.<rdquo/
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To sink away; to disappear gradually; to grow dim;
to vanish.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The stars shall <qex>fade</qex> away.</q>
<rj><qau>Addison</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He makes a swanlike end,<br/
<qex>Fading</qex> in music.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fade</ent><br/
<hw>Fade</hw>, <pos>v. t.</pos> <def>To cause to wither; to deprive of
freshness or vigor; to wear away.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>No winter could his laurels <qex>fade</qex>.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Faded</ent><br/
<hw>Fad"ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>That has lost
freshness, color, or brightness; grown dim.</def> <ldquo/His
<xex>faded</xex> cheek.<rdquo/ <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Where the <qex>faded</qex> moon<br/
Made a dim silver twilight.</q> <rj><qau>Keats.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fadedly</ent><br/
<hw>Fad"ed*ly</hw>, <pos>adv.</pos> <def>In a faded manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A dull room <qex>fadedly</qex> furnished.</q>
<rj><qau>Dickens.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fadeless</ent><br/
<hw>Fade"less</hw>, <pos>a.</pos> <def>Not liable to fade;
unfading.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fader</ent><br/
<hw>Fa"der</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Father.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fadge</ent><br/
<hw>Fadge</hw> <pr>(f<acr/j)</pr>, <pos>v. i.</pos> <ety>[Cf. OE.
<ets>faden</ets> to flatter, and AS. <ets>f<emac/gan</ets> to join,
unite, G. <ets>f<uum/gen</ets>, or AS. <ets><amac/f<ae/gian</ets> to
depict; all perh. form the same root as E. <ets>fair</ets>. Cf.
<er>Fair</er>, <pos>a.</pos>, <er>Fay</er> to fit.]</ety> <def>To fit;
to suit; to agree.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They shall be made, spite of antipathy, to <qex>fadge</qex>
together.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Well, Sir, how <qex>fadges</qex> the new design ?</q>
<rj><qau>Wycherley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fadge</ent><br/
<hw>Fadge</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Etymol.
uncertain.]</ety> <def>A small flat loaf or thick cake; also, a
fagot.</def> <mark>[Prov. Eng.]</mark> <rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fading</ent><br/
<hw>Fad"ing</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Losing freshness,
color, brightness, or vigor.</def> -- <def2><pos>n.</pos> <def>Loss of
color, freshness, or vigor.</def></def2> --
<wordforms><wf>Fad"ing*ly</wf>, <pos>adv.</pos> --
<wf>Fad"ing*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fading</ent><br/
<hw>Fad"ing</hw>, <pos>n.</pos> <def>An Irish dance; also, the burden of
a song.</def> <ldquo/<xex>Fading</xex> is a fine jig.<rdquo/
<mark>[Obs.]</mark> <rj><au>Beau. & Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fadme</ent><br/
<hw>Fad"me</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A fathom.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fady</ent><br/
<hw>Fad"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Faded.</def>
<mark>[R.]</mark> <rj><au>Shenstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>faecal</ent><br/
<hw>F<ae/"cal</hw> <pr>(?)</pr>, <pos>a.</pos> <def>See
<er>Fecal</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>faeces</ent><br/
\'d8<hw>F<ae/"ces</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[L.
<ets>faex</ets>, pl. <ets>faeces</ets>, dregs.]</ety> <def>Excrement;
ordure; also, settlings; sediment after infusion or distillation.</def>
<altsp>[Written also <asp>feces</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Faecula</ent><br/
\'d8<hw>F<ae/c"u*la</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.]</ety>
<def>See <er>Fecula</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Faerie</ent><br/
<hw>Fa"<eum/r*ie</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A
fairy.</def> <mark>[Archaic]</mark><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>The land of the fairies, in fables;
fairyland.</def><br/
[<source>PJC</source>]</p>

<p><ent>Faery</ent><br/
<hw>Fa"<eum/r*y</hw> <pr>(?)</pr>, <pos>n. & a.</pos> <def>Fairy.</def>
<mark>[Archaic]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Faffle</ent><br/
<hw>Faf"fle</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[Cf.
<er>Famble</er>, <er>Maffle</er>.]</ety> <def>To stammer.</def>
<mark>[Prov. Eng.]</mark> <rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fag</ent><br/
<hw>Fag</hw> <pr>(f<acr/g)</pr> <pos>n.</pos> <sn>1.</sn> <def>A knot or
coarse part in cloth; a flaw.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A cigarette.</def> <mark>[slang]</mark><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>A fag end in a cloth.</def><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <def>A drudge.</def><br/
[<source>PJC</source>]</p>

<p><ent>fag</ent><br/
<hw>fag</hw> <pr>(f<acr/g)</pr>, <pos>n.</pos> <def>A male homosexual;
-- always used disparagingly and considered offensive. Shortened form of
<er>faggot</er>.</def> <mark>[Slang, disparaging.]</mark> <br/
<syn><b>Syn. --</b> faggot.</syn><br/
[<source>PJC</source>]</p>

<p><ent>Fag</ent><br/
<hw>Fag</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Fagged</conjf> <pr>(f<acr/gd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Fagging</conjf> <pr>(f<acr/g"g<icr/ng)</pr>.]</vmorph> <ety>[Cf.
LG. <ets>fakk</ets> wearied, weary, <ets>vaak</ets> slumber, drowsiness,
OFries. <ets>fai</ets>, equiv. to <ets>f<amac/ch</ets> devoted to death,
OS. <ets>f<emac/gi</ets>, OHG. <ets>feigi</ets>, G. <ets>feig</ets>,
<ets>feige</ets>, cowardly, Icel. <ets>feigr</ets> fated to die, AS.
<ets>f<aemac/ge</ets>, Scot. <ets>faik</ets>, to fail, stop, lower the
price; or perh. the same word as E. <ets>flag</ets> to droop.]</ety>
<sn>1.</sn> <def>To become weary; to tire.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Creighton withheld his force till the Italian began to
<qex>fag</qex>.</q> <rj><qau>G. Mackenzie.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To labor to wearness; to work hard; to
drudge.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Read, <qex>fag</qex>, and subdue this chapter.</q>
<rj><qau>Coleridge.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To act as a fag, or perform menial services or
drudgery, for another, as in some English schools.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To fag out</b></col>, <cd>to become untwisted or frayed,
as the end of a rope, or the edge of canvas.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fag</ent><br/
<hw>Fag</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To tire by labor; to
exhaust; <as>as, he was almost <ex>fagged</ex> out</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Anything that fatigues.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>It is such a <qex>fag</qex>, I came back tired to death.</q>
<rj><qau>Miss Austen.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Brain fag</b></col>. <fld>(Med.)</fld> <cd>See
<er>Cerebropathy</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fagaceae</ent><br/
<hw>Fagaceae</hw> <pos>prop. n.</pos> <def>a natural family of chiefly
monoecious trees and shrubs, including beeches, chestnuts, and oaks; it
includes the genera <gen>Castanea</gen>; <gen>Castanopsis</gen>;
<gen>Chrysolepis</gen>; <gen>Fagus</gen>; <gen>Lithocarpus</gen>;
<gen>Nothofagus</gen>; and <gen>Quercus</gen>.</def><br/
<syn><b>Syn. --</b> family <fam>Fagaceae</fam>, beech family.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fag-end</ent><br/
<hw>Fag"-end"</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>An end
of poorer quality, or in a spoiled condition, as the coarser end of a
web of cloth, the untwisted end of a rope, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The refuse or meaner part of anything.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>fag-end</qex> of business.</q>
<rj><qau>Collier.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>fagged</ent><br/
<hw>fagged</hw> <pos>adj.</pos> <sn>1.</sn> <def>same as
<er>burned-out</er>, 1.</def><br/
<syn><b>Syn. --</b> burned-out(prenominal), burnt-out(prenominal),
burned out(predicate), burnt out(predicate), exhausted, fatigued,
played-out(prenominal), played out(predicate), spent,
washed-out(prenominal), washed out(predicate), worn-out(prenominal),
worn out(predicate).</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>fagging</ent><br/
<hw>fag"ging</hw> <pr>(f<acr/g"g<icr/ng)</pr>, <pos>n.</pos>
<def>Laborious drudgery; esp., the acting as a drudge for another at an
English school.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>faggot</ent><br/
<hw>fag"got</hw> <pr>(f<acr/g"<ucr/t)</pr>, <pos>n.</pos> <ety>[perh.
from <ets>fagot{5}</ets>, a shriveled old woman.]</ety> <def>a male
homosexual; -- always used disparagingly and considered offensive.</def>
<mark>[Slang, disparaging]</mark> <br/
<syn><b>Syn. --</b> fagot, fag, fairy, pansy, queer, poof, poove,
pouf.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>a bundle of sticks and branches bound together; --
same as <er>fagot{1}</er>.</def><br/
<syn><b>Syn. --</b> fagot.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fagopyrum</ent><br/
<hw>Fagopyrum</hw> <pos>prop. n.</pos> <def>a genus of plants of the
buckwheat family, including the buckwheat <spn>Fagopyrum
esculentum</spn>; in some classifications included in the genus
<gen>Polygonum</gen>.</def><br/
<syn><b>Syn. --</b> genus <gen>Fagopyrum</gen>.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>fagot</ent><br/
<hw>fag"ot</hw> <pr>(f<acr/g"<ucr/t)</pr> <pos>n.</pos> <ety>[F., prob.
aug. of L. <ets>fax</ets>, <ets>facis</ets>, torch, perh. orig., a
bundle of sticks; cf. Gr. <grk>fa`kelos</grk> bundle, fagot. Cf.
<er>Fagotto</er>.]</ety> <sn>1.</sn> <def>A bundle of sticks, twigs, or
small branches of trees, used for fuel, for raising batteries, filling
ditches, or other purposes in fortification; a fascine.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A bundle of pieces of wrought iron to be worked over
into bars or other shapes by rolling or hammering at a welding heat; a
pile.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Mus.)</fld> <def>A bassoon. See
<er>Fagotto</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A person hired to take the place of another at the
muster of a company.</def> <mark>[Eng.]</mark>
<rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>An old shriveled woman.</def> <mark>[Slang,
Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fagot iron</b></col>, <cd>iron, in bars or masses,
manufactured from fagots.</cd> -- <col><b>Fagot vote</b></col>, <cd>the
vote of a person who has been constituted a voter by being made a
landholder, for party purposes.</cd> <mark>[Political cant,
Eng.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fagot</ent><br/
<hw>Fag"ot</hw> <pr>(?)</pr> <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Fagoted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Fagoting</conjf>.]</vmorph> <def>To make a fagot of; to bind
together in a fagot or bundle; also, to collect promiscuously.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fagotto</ent><br/
\'d8<hw>Fa*got"to</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[It. See
<er>Fagot</er>.]</ety> <fld>(Mus.)</fld> <def>The bassoon; -- so called
from being divided into parts for ease of carriage, making, as it were,
a small fagot.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Faham</ent><br/
\'d8<hw>Fa"ham</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The leaves of an
orchid (<spn>Angraecum fragrans</spn>), of the islands of Bourbon and
Mauritius, used (in France) as a substitute for Chinese tea.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fahlband</ent><br/
\'d8<hw>Fahl"band`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[G., fr.
<ets>fahl</ets> dun-colored + <ets>band</ets> a band.]</ety>
<fld>(Mining)</fld> <def>A stratum in crystalline rock, containing
metallic sulphides.</def> <rj><au>Raymond.</au></rj></p>

<p><ent>Fahlband</ent><br/
<ent>Fahlerz</ent><br/
<mhw>{ <hw>Fahl"erz</hw> <pr>(?)</pr>, <hw>Fahl"band</hw> <pr>(?)</pr>,
}</mhw> <pos>n.</pos> <ety>[G. <ets>fahlerz</ets>; <ets>fahl</ets>
dun-colored, fallow + <ets>erz</ets> ore.]</ety> <fld>(Min.)</fld>
<def>Same as <er>Tetrahedrite</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fahlunite</ent><br/
<hw>Fah"lun*ite</hw> <pr>(f<aum/"l<ucr/n*<imac/t)</pr>, <pos>n.</pos>
<ety>[From <etsep>Fahlun</etsep>, a place in Sweden.]</ety>
<fld>(Min.)</fld> <def>A hydrated silica of alumina, resulting from the
alteration of iolite.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fahr.</ent><br/
<hw>Fahr.</hw> <pos>adj.</pos> <mark>[abbrev.]</mark> <def>an
abbreviation of <er>Fahrenheit</er>; -- used in designating
temperatures; <as>as, 72<deg/ Fahr.</as> Used as an alternative to
<ant>celsius</ant>.</def><br/
<syn><b>Syn. --</b> fahrenheit, f., F.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fahrenheit</ent><br/
<hw>Fah"ren*heit</hw> <pr>(?)</pr> <pos>prop. a.</pos> <ety>[G.]</ety>
<def>Conforming to the scale used by <person>Gabriel Daniel
<etsep>Fahrenheit</etsep></person> in the graduation of his thermometer;
of or relating to Fahrenheit's thermometric scale. Used as an
alternative to <contr>celsius</contr>.</def> -- <def2><pos>n.</pos>
<def>The Fahrenheit thermometer or scale.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The <col><b>Fahrenheit thermometer</b></col> is so
graduated that the freezing point of water is at 32 degrees above the
zero of its scale, and the boiling point at one atmosphere of pressure
is 212 degrees. It is commonly used in the United States and in
England.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Faience</ent><br/
<ent>faience</ent><br/
<mhw><hw>faience</hw>, \'d8<hw>Fa`<ium/*ence"</hw></mhw> <pr>(?)</pr>,
<pos>n.</pos> <ety>[F., fr. <etsep>Faenza</etsep>, a town in Italy, the
original place of manufacture.]</ety> <def>Glazed earthenware; esp., a
fine variety that which is decorated with colorful designs in an opaque
glaze.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Fail</ent><br/
<hw>Fail</hw> <pr>(f<amac/l)</pr> <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Failed</conjf> <pr>(f<amac/ld)</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>Failing</conjf>.]</vmorph> <ety>[F.
<ets>failir</ets>, fr. L. <ets>fallere</ets>, <ets>falsum</ets>, to
deceive, akin to E. <ets>fall</ets>. See <er>Fail</er>, and cf.
<er>Fallacy</er>, <er>False</er>, <er>Fault</er>.]</ety> <sn>1.</sn>
<def>To be wanting; to fall short; to be or become deficient in any
measure or degree up to total absence; to cease to be furnished in the
usual or expected manner, or to be altogether cut off from supply; to be
lacking; <as>as, streams <ex>fail</ex>; crops
<ex>fail</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>As the waters <qex>fail</qex> from the sea.</q> <rj><qau>Job xiv.
11.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Till Lionel's issue <qex>fails</qex>, his should not reign.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To be affected with want; to come short; to lack; to
be deficient or unprovided; -- used with <xex>of</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If ever they <qex>fail</qex> of beauty, this failure is not be
attributed to their size.</q> <rj><qau>Berke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To fall away; to become diminished; to decline; to
decay; to sink.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>When earnestly they seek<br/
Such proof, conclude they then begin to <qex>fail</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To deteriorate in respect to vigor, activity,
resources, etc.; to become weaker; <as>as, a sick man
<ex>fails</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To perish; to die; -- used of a person.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Had the king in his last sickness <qex>failed</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To be found wanting with respect to an action or a
duty to be performed, a result to be secured, etc.; to miss; not to
fulfill expectation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Take heed now that ye <qex>fail</qex> not to do this.</q>
<rj><qau>Ezra iv. 22.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Either my eyesight <qex>fails</qex>, or thou look'st pale.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>To come short of a result or object aimed at or
desired ; to be baffled or frusrated.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Our envious foe hath <qex>failed</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>To err in judgment; to be mistaken.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Which ofttimes may succeed, so as perhaps<br/
Shall grieve him, if I <qex>fail</qex> not.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>To become unable to meet one's engagements;
especially, to be unable to pay one's debts or discharge one's business
obligation; to become bankrupt or insolvent; <as>as, many credit unions
<ex>failed</ex> in the late 1980's</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fail</ent><br/
<hw>Fail</hw> <pr>(?)</pr>, <pos>v. t.</pos> <sn>1.</sn> <def>To be
wanting to ; to be insufficient for; to disappoint; to desert.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There shall not <qex>fail</qex> thee a man on the throne.</q>
<rj><qau>1 Kings ii. 4.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To miss of attaining; to lose.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Though that seat of earthly bliss be <qex>failed</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fail</ent><br/
<hw>Fail</hw>, <pos>n.</pos> <ety>[OF. <ets>faille</ets>, from
<ets>failir</ets>. See <er>Fail</er>, <pos>v. i.</pos>]</ety>
<sn>1.</sn> <def>Miscarriage; failure; deficiency; fault; -- mostly
superseded by <altname>failure</altname> or <altname>failing</altname>,
except in the phrase <ecol><b>without fail</b></ecol>.</def> <ldquo/His
highness' <xex>fail</xex> of issue.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Death; decease.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Failance</ent><br/
<hw>Fail"ance</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Of.
<ets>faillance</ets>, fr. <ets>faillir</ets>.]</ety> <def>Fault;
failure; omission.</def> <mark>[Obs.]</mark> <rj><au>Bp.
Fell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>failed</ent><br/
<hw>failed</hw> <pos>adj.</pos> <def>unsuccessful. Opposite of
<ant>successful</ant>.</def><br/
<syn><b>Syn. --</b> failing.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Failing</ent><br/
<hw>Fail"ing</hw>, <pos>n.</pos> <sn>1.</sn> <def>A failing short; a
becoming deficient; failure; deficiency; imperfection; weakness; lapse;
fault; infirmity; <as>as, a mental <ex>failing</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And ever in her mind she cast about<br/
For that unnoticed <qex>failing</qex> in herself.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The act of becoming insolvent of bankrupt.</def></p>

<p><syn><b>Syn.</b> -- See <er>Fault</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Faille</ent><br/
\'d8<hw>Faille</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety> <def>A
soft silk, heavier than a foulard and not glossy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Failure</ent><br/
<hw>Fail"ure</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<er>Fail</er>.]</ety> <sn>1.</sn> <def>Cessation of supply, or total
defect; a failing; deficiency; <as>as, <ex>failure</ex> of rain;
<ex>failure</ex> of crops.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Omission; nonperformance; <as>as, the
<ex>failure</ex> to keep a promise</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Want of success; the state of having
failed.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Decay, or defect from decay; deterioration; <as>as,
the <ex>failure</ex> of memory or of sight</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A becoming insolvent; bankruptcy; suspension of
payment; <as>as, <ex>failure</ex> in business</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>A failing; a slight fault.</def> <mark>[Obs.]</mark>
<rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fain</ent><br/
<hw>Fain</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OE. <ets>fain</ets>,
<ets>fagen</ets>, AS. <ets>f<ae/gen</ets>; akin to OS. <ets>fagan</ets>,
Icel. <ets>faginn</ets> glad; AS. <ets>f<ae/gnian</ets> to rejoice, OS.
<ets>fagan<omac/n</ets>, Icel. <ets>fagna</ets>, Goth.
<ets>fagin<omac/n</ets>, cf. Goth. <ets>fah<emac/ds</ets> joy; and fr.
the same root as E. <ets>fair</ets>. Srr <er>Fair</er>, <pos>a.</pos>,
and cf. <er>Fawn</er> to court favor.]</ety> <sn>1.</sn>
<def>Well-pleased; glad; apt; wont; fond; inclined.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Men and birds are <qex>fain</qex> of climbing high.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To a busy man, temptation is <qex>fain</qex>to climb up together
with his business.</q> <rj><qau>Jer. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Satisfied; contented; also, constrained.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The learned Castalio was <qex>fain</qex> to make trechers at Basle
to keep himself from starving.</q> <rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fain</ent><br/
<hw>Fain</hw>, <pos>adv.</pos> <def>With joy; gladly; -- with
<xex>wold</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He would <qex>fain</qex> have filled his belly with the husks that
the swine did eat.</q> <rj><qau>Luke xv. 16.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Fain</qex> Would I woo her, yet I dare not.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fain</ent><br/
<hw>Fain</hw>, <pos>v. t. & i.</pos> <def>To be glad ; to wish or
desire.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Whoso fair thing does <qex>fain</qex> to see.</q>
<rj><qau>Spencer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Faineancy</ent><br/
<ent>Faineance</ent><br/
<mhw>{ <hw>Fai"ne*ance</hw> <pr>(?)</pr>, <hw>Fai"ne*an*cy</hw>
<pr>(?)</pr> }</mhw>, <pos>n.</pos> <ety>[Cf. OF. <ets>faineance</ets>.
See <er>Fain<eacute/ant</er>.]</ety> <def>Do-nothingness; inactivity;
indolence.</def></p>

<p><q>The mask of sneering <qex>faineance</qex> was gone.</q>
<rj><qau>C. Kingsley.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>faineant</ent><br/
<mhw><hw>fai`ne`ant"</hw>, \'d8<hw>fai`n<eacute/`ant"</hw></mhw>
<pr>(f<asl/`n<asl/`<aum/N")</pr>, <pos>a.</pos> <ety>[F.;
<ets>fait</ets> he does + <ets>n<eacute/ant</ets> nothing.]</ety>
<def>Doing nothing; shiftless; disinclined to work or
exertion.</def><br/
<syn><b>Syn. --</b> bone-idle, bone-lazy, do-nothing(prenominal),
indolent, lazy, otiose, shiftless, slothful, workshy,
work-shy.</syn><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><ent>faineant</ent><br/
<ent>faineant</ent><br/
<mhw><hw>fai`ne`ant"</hw>, \'d8<hw>fai`n<eacute/`ant"</hw></mhw>
<pr>(f<asl/`n<asl/`<aum/N")</pr>, <pos>n.</pos> <def>A do-nothing; an
idle fellow; a sluggard.</def> <rj><au>Sir W. Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>faineant deity</ent><br/
<hw>Fain<eacute/ant deity</hw>. <def>A deity believed to be real but
conceived as not acting in human affairs, hence not worshiped.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Faint</ent><br/
<hw>Faint</hw> <pr>(f<amac/nt)</pr>, <pos>a.</pos>
<amorph>[<pos>Compar.</pos> <adjf>Fainter</adjf> <pr>(-<etil/r)</pr>;
<pos>superl.</pos> <adjf>Faintest</adjf>.]</amorph> <ety>[OE.
<ets>feint</ets>, <ets>faint</ets>, false, faint, F. <ets>feint</ets>,
p. p. of <ets>feindre</ets> to feign, suppose, hesitate. See
<er>Feign</er>, and cf. <er>Feint</er>.]</ety> <sn>1.</sn> <def>Lacking
strength; weak; languid; inclined to swoon; <as>as, <ex>faint</ex> with
fatigue, hunger, or thirst</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Wanting in courage, spirit, or energy; timorous;
cowardly; dejected; depressed; <as>as, <ldquo/<ex>Faint</ex> heart ne'er
won fair lady</as>.<rdquo/</def> <rj><au>Old Proverb.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Lacking distinctness; hardly perceptible; striking
the senses feebly; not bright, or loud, or sharp, or forcible; weak;
<as>as, a <ex>faint</ex> color, or sound</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Performed, done, or acted, in a weak or feeble
manner; not exhibiting vigor, strength, or energy; slight; <as>as,
<ex>faint</ex> efforts; <ex>faint</ex> resistance.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>faint</qex> prosecution of the war.</q> <rj><qau>Sir J.
Davies.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Faint</ent><br/
<hw>Faint</hw>, <pos>n.</pos> <def>The act of fainting, or the state of
one who has fainted; a swoon. <mark>[R.]</mark> See <er>Fainting</er>,
<pos>n.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><q>The saint,<br/
Who propped the Virgin in her <qex>faint</qex>.</q> <rj><qau>Sir W.
Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Faint</ent><br/
<hw>Faint</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Fainted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Fainting</conjf>.]</vmorph> <sn>1.</sn> <def>To become weak or
wanting in vigor; to grow feeble; to lose strength and color, and the
control of the bodily or mental functions; to swoon; -- sometimes with
<xex>away</xex>. See <er>Fainting</er>, <pos>n.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Hearing the honor intended her, she <qex>fainted</qex> away.</q>
<rj><qau>Guardian.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>If I send them away fasting . . . they will <qex>faint</qex> by
the way.</q> <rj><qau>Mark viii. 8.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 538 --></p>

<p><sn>2.</sn> <def>To sink into dejection; to lose courage or spirit;
to become depressed or despondent.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If thou <qex>faint</qex> in the day of adversity, thy strength is
small.</q> <rj><qau>Prov. xxiv. 10.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To decay; to disappear; to vanish.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Gilded clouds, while we gaze upon them, <qex>faint</qex> before
the eye.</q> <rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Faint</ent><br/
<hw>Faint</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To cause to faint or
become dispirited; to depress; to weaken.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>It <qex>faints</qex> me to think what follows.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Faint-hearted</ent><br/
<hw>Faint"-heart`ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Wanting in
courage; depressed by fear; easily discouraged or frightened; cowardly;
timorous; dejected.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Fear not, neither be <qex>faint-hearted</qex>.</q> <rj><qau>Is.
vii. 4.</qau></rj></p>

<p>-- <wordforms><wf>Faint"-heart`ed*ly</wf>, <pos>adv.</pos> --
<wf>Faint"-heart`ed*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fainting</ent><br/
<hw>Faint"ing</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Syncope, or loss of
consciousness owing to a sudden arrest of the blood supply to the brain,
the face becoming pallid, the respiration feeble, and the heat's beat
weak.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fainting fit</b></col>, <cd>a fainting or swoon;
syncope.</cd> <mark>[Colloq.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Faintish</ent><br/
<hw>Faint"ish</hw>, <pos>a.</pos> <def>Slightly faint; somewhat
faint.</def> -- <wordforms><wf>Faint"ish*ness</wf>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Faintling</ent><br/
<hw>Faint"ling</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Timorous;
feeble-minded.</def> <mark>[Obs.]</mark> <ldquo/A <xex>fainting</xex>,
silly creature.<rdquo/ <rj><au>Arbuthnot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Faintly</ent><br/
<hw>Faint"ly</hw>, <pos>adv.</pos> <def>In a faint, weak, or
timidmanner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Faintness</ent><br/
<hw>Faint"ness</hw>, <pos>n.</pos> <sn>1.</sn> <def>The state of being
faint; loss of strength, or of consciousness, and
self-control.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Want of vigor or energy.</def>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Feebleness, as of color or light; lack of
distinctness; <as>as, <ex>faintness</ex> of description</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Faint-heartedness; timorousness;
dejection.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I will send a <qex>faintness</qex> into their hearts.</q>
<rj><qau>Lev. xxvi. 36.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Faints</ent><br/
<hw>Faints</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <def>The impure spirit
which comes over first and last in the distillation of whisky; -- the
former being called the <xex>strong faints</xex>, and the latter, which
is much more abundant, the <xex>weak faints</xex>. This crude spirit is
much impregnated with fusel oil.</def> <rj><au>Ure.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fainty</ent><br/
<hw>Faint"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Feeble; languid.</def>
<mark>[R.]</mark> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fair</ent><br/
<hw>Fair</hw> <pr>(f<acir/r)</pr>, <pos>a.</pos>
<amorph>[<pos>Compar.</pos> <adjf>Fairer</adjf> <pr>(?)</pr>;
<pos>superl.</pos> <adjf>Fairest</adjf>.]</amorph> <ety>[OE.
<ets>fair</ets>, <ets>fayer</ets>, <ets>fager</ets>, AS.
<ets>f<ae/ger</ets>; akin to OS. & OHG. <ets>fagar</ets>, Icel.
<ets>fagr</ets>, Sw. <ets>fager</ets>, Dan. <ets>faver</ets>, Goth.
<ets>fagrs</ets> fit, also to E. <ets>fay</ets>, G.
<ets>f<uum/gen</ets>, to fit. <ets>fegen</ets> to sweep, cleanse, and
prob. also to E. <ets>fang</ets>, <ets>peace</ets>, <ets>pact</ets>, Cf.
<er>Fang</er>, <er>Fain</er>, <er>Fay</er> to fit.]</ety> <sn>1.</sn>
<def>Free from spots, specks, dirt, or imperfection; unblemished; clean;
pure.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>fair</qex> white linen cloth.</q> <rj><qau>Book of Common
Prayer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Pleasing to the eye; handsome; beautiful.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Who can not see many a <qex>fair</qex> French city, for one
<qex>fair</qex> French made.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Without a dark hue; light; clear; <as>as, a
<ex>fair</ex> skin</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The northern people large and <qex>fair</qex>-complexioned.</q>
<rj><qau>Sir M. Hale.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Not overcast; cloudless; clear; pleasant;
propitious; favorable; -- said of the sky, weather, or wind, etc.;
<as>as, a <ex>fair</ex> sky; a <ex>fair</ex> day.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>You wish <qex>fair</qex> winds may waft him over.</q>
<rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Free from obstacles or hindrances; unobstructed;
unincumbered; open; direct; -- said of a road, passage, etc.; <as>as, a
<ex>fair</ex> mark; in <ex>fair</ex> sight; a <ex>fair</ex>
view.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>The caliphs obtained a mighty empire, which was in a
<xex>fair</xex> way to have enlarged.</q> <rj><qau>Sir W.
Raleigh.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Shipbuilding)</fld> <def>Without sudden change of
direction or curvature; smooth; flowing; -- said of the figure of a
vessel, and of surfaces, water lines, and other lines.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>Characterized by frankness, honesty, impartiality,
or candor; open; upright; free from suspicion or bias; equitable; just;
-- said of persons, character, or conduct; <as>as, a <ex>fair</ex> man;
<ex>fair</ex> dealing; a <ex>fair</ex> statement.</as></def> <ldquo/I
would call it <xex>fair</xex> play.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>Pleasing; favorable; inspiring hope and confidence;
-- said of words, promises, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>When <qex>fair</qex> words and good counsel will not prevail on
us, we must be frighted into our duty.</q> <rj><qau>L'
Estrange.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>Distinct; legible; <as>as, <ex>fair</ex>
handwriting</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <def>Free from any marked characteristic; average;
middling; <as>as, a <ex>fair</ex> specimen</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The news is very <qex>fair</qex> and good, my lord.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fair ball</b></col>. <fld>(Baseball)</fld> <sd>(a)</sd>
<cd>A ball passing over the home base at the height called for by the
batsman, and delivered by the pitcher while wholly within the lines of
his position and facing the batsman.</cd> <sd>(b)</sd> <cd>A batted ball
that falls inside the foul lines; -- called also a <altname>fair
hit</altname>.</cd> -- <col><b>Fair maid</b></col>. <fld>(Zool.)</fld>
<sd>(a)</sd> <cd>The European pilchard (<spn>Clupea pilchardus</spn>)
when dried.</cd> <sd>(b)</sd> <cd>The southern scup (<spn>Stenotomus
Gardeni</spn>).</cd> <mark>[Virginia]</mark> -- <col><b>Fair
one</b></col>, <cd>a handsome woman; a beauty,</cd> -- <col><b>Fair
play</b></col>, <cd>equitable or impartial treatment; a fair or equal
chance; justice.</cd> -- <col><b>From fair to middling</b></col>,
<cd>passable; tolerable.</cd> <mark>[Colloq.]</mark> -- <col><b>The fair
sex</b></col>, <cd>the female sex.</cd></cs></p>

<p><syn><b>Syn.</b> -- Candid; open; frank; ingenuous; clear; honest;
equitable; impartial; reasonable. See <er>Candid</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fair</ent><br/
<hw>Fair</hw>, <pos>adv.</pos> <def>Clearly; openly; frankly; civilly;
honestly; favorably; auspiciously; agreeably.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fair and square</b></col>, <cd>justly; honestly;
equitably; impartially.</cd> <mark>[Colloq.]</mark> -- <col><b>To bid
fair</b></col>. <cd>See under <er>Bid</er>.</cd> -- <col><b>To speak
fair</b></col>, <cd>to address with courtesy and frankness.</cd>
<mark>[Archaic]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fair</ent><br/
<hw>Fair</hw>, <pos>n.</pos> <sn>1.</sn> <def>Fairness, beauty.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A fair woman; a sweetheart.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I have found out a gift for my <qex>fair</qex>.</q>
<rj><qau>Shenstone.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Good fortune; good luck.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Now <qex>fair</qex> befall thee !</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>The fair</b></col>, <cd>anything beautiful; women,
collectively.</cd> <ldquo/For slander's mark was ever yet <xex>the
fair</xex>.<rdquo/ <rj><au>Shak.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fair</ent><br/
<hw>Fair</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To make fair or
beautiful.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Fairing</qex> the foul.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Shipbuilding)</fld> <def>To make smooth and
flowing, as a vessel's lines.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fair</ent><br/
<hw>Fair</hw>, <pos>n.</pos> <ety>[OE. <ets>feire</ets>, OF.
<ets>feire</ets>, F. <ets>foire</ets>, fr. L. <ets>fariae</ets>, pl.,
days of rest, holidays, festivals, akin to <ets>festus</ets> festal. See
<er>Feast</er>.]</ety> <sn>1.</sn> <def>A gathering of buyers and
sellers, assembled at a particular place with their merchandise at a
stated or regular season, or by special appointment, for
trade.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A festival, and sale of fancy articles. erc.,
usually for some charitable object; <as>as, a Grand Army <ex>fair</ex>;
a church <ex>fair</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A competitive exhibition of wares, farm products,
etc., not primarily for purposes of sale; <as>as, the Mechanics'
<ex>fair</ex>; an agricultural <ex>fair</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>an exhibition by a number of organizations,
including governmental organizations, for the purpose of acquainting
people with such organizations or their members, not primarily for
commercial purposes; <as>as, the 1939 World's
<ex>Fair</ex>.</as></def><br/
[<source>PJC</source>]</p>

<p><q>Meet me in St. Louis, Louis<br/
Meet me at the <qex>fair</qex><br/
Don't tell me the lights are shining<br/
Anyplace but there.</q> <rj><qau>Song (1904: words by Andrew B.
Sterling, music by Kerry Mills, popularized by Billy Murray. Prominent
in the movie "Meet Me In St. Louis", 1944)</qau></rj><br/
[<source>PJC</source>]</p>

<p><cs><col><b>After the fair</b></col>, <cd>Too late.</cd>
<mark>[Colloq.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>fair and square</ent><br/
<hw>fair and square</hw> <pos>adv.</pos> <def>justly; honestly;
equitably; impartially. Opposite of <ant>unfairly</ant>.</def>
<mark>[Colloq.]</mark><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>fair-and-square</ent><br/
<hw>fair-and-square</hw> <pos>adj.</pos> <def>fair and honest; just.
Opposite of <ant>unfair</ant>.</def> <mark>[Colloq.]</mark><br/
<syn><b>Syn. --</b> honest.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Fair catch</ent><br/
<hw>Fair catch</hw>. <fld>(Football)</fld> <def>A catch made by a player
on side who makes a prescribed signal that he will not attempt to
advance the ball when caught. He must not then be interfered
with.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>fairground</ent><br/
<hw>fairground</hw>, <pos>n.</pos> <def>an open area for holding fairs
or exhibitions or circuses. Often used in plural.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>fairgrounds</ent><br/
<hw>fairgrounds</hw>, <pos>n. pl.</pos> <def>same as
<er>fairground</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Fair-haired</ent><br/
<hw>Fair"-haired`</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Having fair or light-colored hair.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>favorite; considered especially talented or
promising; <as>as, the <ex>fair-haired</ex> boy of the literary
set</as>.</def> <mark>[prenominal]</mark> <mark>[informal]</mark><br/
<syn><b>Syn. --</b> blue-eyed(prenominal), white-haired(prenominal),
white-headed.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Fairhood</ent><br/
<hw>Fair"hood</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Fairness;
beauty.</def> <mark>[Obs.]</mark> <rj><au>Foxe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fairily</ent><br/
<hw>Fair"i*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In the manner of a
fairy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Numerous as shadows haunting <qex>fairily</qex><br/
<qex>The brain</qex>.</q> <rj><qau>Keats.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fairing</ent><br/
<hw>Fair"ing</hw>, <pos>n.</pos> <def>A present; originally, one given
or purchased at a fair.</def> <rj><au>Gay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fairing box</b></col>, <cd>a box receiving savings or
small sums of money.</cd> <rj><au>Hannah More.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fairish</ent><br/
<hw>Fair"ish</hw>, <pos>a.</pos> <def>Tolerably fair.</def>
<mark>[Colloq.]</mark> <rj><au>W. D. Howells.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fair-leader</ent><br/
<hw>Fair"-lead`er</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Naut.)</fld>
<def>A block, or ring, serving as a guide for the running rigging or for
any rope.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fairly</ent><br/
<hw>Fair"ly</hw>, <pos>adv.</pos> <sn>1.</sn> <def>In a fair manner;
clearly; openly; plainly; fully; distinctly; frankly.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Even the nature of Mr. Dimmesdale's disease had never
<qex>fairly</qex> been revealed to him.</q>
<rj><qau>Hawthorne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Favorably; auspiciously; commodiously; <as>as, a
town <ex>fairly</ex> situated for foreign trade</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Honestly; properly.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Such means of comfort or even luxury, as lay <qex>fairly</qex>
within their grasp.</q> <rj><qau>Hawthorne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Softly; quietly; gently.</def> <mark>[Obs.]</mark>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fair-minded</ent><br/
<hw>Fair"-mind`ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Unprejudiced;
just; judicial; honest.</def> -- <wordforms><wf>Fair"-mind`ed*ness</wf>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fair-natured</ent><br/
<hw>Fair"-na`tured</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Well-disposed.</def> <ldquo/A <xex>fair-natured</xex>
prince.<rdquo/ <rj><au>Ford.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fairness</ent><br/
<hw>Fair"ness</hw>, <pos>n.</pos> <def>The state of being fair, or free
form spots or stains, as of the skin; honesty, as of dealing; candor, as
of an argument, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fair-spoken</ent><br/
<hw>Fair"-spo`ken</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Using fair
speech, or uttered with fairness; bland; civil; courteous;
plausible.</def> <ldquo/A marvelous <xex>fair-spoken</xex> man.<rdquo/
<rj><au>Hooker.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fairway</ent><br/
<hw>Fair"way`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
navigable part of a river, bay, etc., through which vessels enter or
depart; the part of a harbor or channel ehich is kept open and
unobstructed for the passage of vessels.</def>
<rj><au>Totten.</au></rj></p>

<p><sn>2.</sn> <fld>(golf)</fld> <def>That part of a golf course between
the tee and the green which is of closely mowed grass, as contrasted to
the <contr>rough</contr>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Fair-weather</ent><br/
<hw>Fair"-weath`er</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Made or done in pleasant weather, or in circumstances involving but
little exposure or sacrifice; <as>as, a <ex>fair-weather</ex>
voyage</as>.</def> <rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Appearing only when times or circumstances are
prosperous; <as>as, a <ex>fair-weather</ex> friend</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fair-weather sailor</b></col>, <cd>a make-believe or
inexperienced sailor; -- the nautical equivalent of <cref>carpet
knight</cref>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fair-world</ent><br/
<hw>Fair"-world`</hw> <pr>(?)</pr> <pos>n.</pos> <def>State of
prosperity.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>They think it was never <qex>fair-world</qex> with them since.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fairy</ent><br/
<hw>Fair"y</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Fairies</plw> <pr>(#)</pr>.</plu> <ety>[OE. <ets>fairie</ets>,
<ets>faierie</ets>, enchantment, fairy folk, fairy, OF.
<ets>faerie</ets> enchantment, F. <ets>f<eacute/er</ets>, fr. LL.
<ets>Fata</ets> one of the goddesses of fate. See <er>Fate</er>, and cf.
<er>Fay</er> a fairy.]</ety> <altsp>[Written also
<asp>fa<eum/ry</asp>.]</altsp> <sn>1.</sn> <def>Enchantment;
illusion.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The God of her has made an end,<br/
And fro this worlde's <qex>fairy</qex><br/
Hath taken her into company.</q> <rj><qau>Gower.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The country of the fays; land of illusions.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He [Arthur] is a king y-crowned in <qex>Fairy</qex>.</q>
<rj><qau>Lydgate.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>An imaginary supernatural being or spirit, supposed
to assume a human form (usually diminutive), either male or female, and
to meddle for good or evil in the affairs of mankind; a fay. See
<er>Elf</er>, and <er>Demon</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The fourth kind of spirit [is] called the <qex>Fairy</qex>.</q>
<rj><qau>K. James.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And now about the caldron sing,<br/
Like elves and <qex>fairies</qex> in a ring.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>An enchantress.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fairy of the mine</b></col>, <cd>an imaginary being
supposed to inhabit mines, etc. German folklore tells of two species;
one fierce and malevolent, the other gentle, See
<er>Kobold</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><q>No goblin or swart <qex>fairy of the mine</qex><br/
Hath hurtful power over true virginity.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fairy</ent><br/
<hw>Fair"y</hw>, <pos>a.</pos> <sn>1.</sn> <def>Of or pertaining to
fairies.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Given by fairies; <as>as, <ex>fairy</ex>
money</as>.</def> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fairy bird</b></col> <fld>(Zool.)</fld>, <cd>the
Euoropean little tern (<spn>Sterna minuta</spn>); -- called also
<altname>sea swallow</altname>, and <altname>hooded tern</altname>.</cd>
-- <col><b>Fairy bluebird</b></col>. <fld>(Zool.)</fld> <cd>See under
<er>Bluebird</er>.</cd> -- <col><b>Fairy martin</b></col>
<fld>(Zool.)</fld>, <cd>a European swallow (<spn>Hirrundo ariel</spn>)
that builds flask-shaped nests of mud on overhanging cliffs.</cd> --
<mcol><col><b>Fairy rings</b></col> <it>or</it> <col><b>Fairy
circles</b></col></mcol>, <cd>the circles formed in grassy lawns by
certain fungi (as <spn>Marasmius Oreades</spn>), formerly supposed to be
caused by fairies in their midnight dances; also, the mushrooms
themselves. Such circles may have diameters larger than three
meters.</cd> -- <col><b>Fairy shrimp</b></col> <fld>(Zool.)</fld>, <cd>a
European fresh-water phyllopod crustacean (<spn>Chirocephalus
diaphanus</spn>); -- so called from its delicate colors, transparency,
and graceful motions. The name is sometimes applied to similar American
species.</cd> -- <col><b>Fairy stone</b></col> <fld>(Paleon.)</fld>,
<cd>an echinite.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fairyland</ent><br/
<hw>Fair"y*land`</hw> <pr>(?)</pr> <pos>n.</pos> <def>The imaginary land
or abode of fairies.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fairylike</ent><br/
<hw>Fair"y*like`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Resembling a
fairy, or what is made or done be fairies; <as>as, <ex>fairylike</ex>
music</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>fairy-slipper</ent><br/
<hw>fairy-slipper</hw> <pos>n.</pos> <def>a rare north temperate bog
orchid (<spn>Calypso bulbosa</spn>) bearing a solitary white to pink
flower marked with purple at the tip of an erect reddish stalk above one
basal leaf.</def><br/
<syn><b>Syn. --</b> calypso, <spn>Calypso bulbosa</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>fairy tale</ent><br/
<hw>fairy tale</hw> <pos>n.</pos> <sn>1.</sn> <def>a story about magical
or mythological creatures, such as fairies, elves, goblins, trolls,
orcs, unicorns, wizards, dragons, etc., usually composed for the
amusement of children; called also a <altname>fairy
story</altname>.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>a false story intended to deceive or mislead,
especially one involving unlikely events or situations; called also a
<altname>fairy story</altname>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Faith</ent><br/
<hw>Faith</hw> <pr>(f<amac/th)</pr>, <pos>n.</pos> <ety>[OE.
<ets>feith</ets>, <ets>fayth</ets>, <ets>fay</ets>, OF. <ets>feid</ets>,
<ets>feit</ets>, <ets>fei</ets>, F. <ets>foi</ets>, fr. L.
<ets>fides</ets>; akin to <ets>fidere</ets> to trust, Gr.
<grk>pei`qein</grk> to persuade. The ending <ets>th</ets> is perhaps due
to the influence of such words as <ets>truth</ets>, <ets>health</ets>,
<ets>wealth</ets>. See <er>Bid</er>, <er>Bide</er>, and cf.
<er>Confide</er>, <er>Defy</er>, <er>Fealty</er>.]</ety> <sn>1.</sn>
<def>Belief; the assent of the mind to the truth of what is declared by
another, resting solely and implicitly on his authority and veracity;
reliance on testimony.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The assent of the mind to the statement or
proposition of another, on the ground of the manifest truth of what he
utters; firm and earnest belief, on probable evidence of any kind,
especially in regard to important moral truth.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Faith</qex>, that is, fidelity, -- the fealty of the finite
will and understanding to the reason.</q>
<rj><qau>Coleridge.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Judeo-Christian Theol.)</fld> <sd>(a)</sd> <def>The
belief in the historic truthfulness of the Scripture narrative, and the
supernatural origin of its teachings, sometimes called
<xex>historical</xex> and <xex>speculative</xex> faith.</def>
<sd>(b)</sd> <fld>(Christian Theol.)</fld> <def>The belief in the facts
and truth of the Scriptures, with a practical love of them; especially,
that confiding and affectionate belief in the person and work of Christ,
which affects the character and life, and makes a man a true Christian,
-- called a <xex>practical</xex>, <xex>evangelical</xex>, or
<xex>saving</xex> faith.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Without <qex>faith</qex> it is impossible to please him [God].</q>
<rj><qau>Heb. xi. 6.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>faith</qex> of the gospel is that emotion of the mind
which is called <ldquo/trust<rdquo/ or <ldquo/confidence<rdquo/
exercised toward the moral character of God, and particularly of the
Savior.</q> <rj><qau>Dr. T. Dwight.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Faith</qex> is an affectionate, practical confidence in the
testimony of God.</q> <rj><qau>J. Hawes.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>That which is believed on any subject, whether in
science, politics, or religion; especially <fld>(Theol.)</fld>, a system
of religious belief of any kind; <as>as, the Jewish or Muslim
<ex>faith</ex>; the Christian <ex>faith</ex></as>; also, the creed or
belief of a Christian society or church.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><q>Which to believe of her,<br/
Must be a <qex>faith</qex> that reason without miracle<br/
Could never plant in me.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Now preacheth the <qex>faith</qex> which once he destroyed.</q>
<rj><qau>Gal. i. 23.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Fidelity to one's promises, or allegiance to duty,
or to a person honored and beloved; loyalty.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Children in whom is no <qex>faith</qex>.</q> <rj><qau>Deut. xxvii.
20.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Whose failing, while her <qex>faith</qex> to me remains,<br/
I should conceal.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Word or honor pledged; promise given; fidelity;
<as>as, he violated his <ex>faith</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>For you alone<br/
I broke me <qex>faith</qex> with injured Palamon.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>Credibility or truth.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>faith</qex> of the foregoing narrative.</q>
<rj><qau>Mitford.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Act of faith</b></col>. <cd>See
<er>Auto-da-f<eacute/</er>.</cd> -- <mcol><col><b>Breach of
faith</b></col>, <col><b>Confession of faith</b></col></mcol>, <cd>etc.
See under <er>Breach</er>, <er>Confession</er>, etc.</cd> --
<col><b>Faith cure</b></col>, <cd>a method or practice of treating
diseases by prayer and the exercise of faith in God.</cd> -- <col><b>In
good faith</b></col>, <cd>with perfect sincerity.</cd></cs> <-- faith
healing, faith healer = faith cure. --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Faith</ent><br/
<hw>Faith</hw> <pr>(?)</pr>, <pos>interj.</pos> <def>By my faith; in
truth; verily.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Faithed</ent><br/
<hw>Faithed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having faith or a
faith; honest; sincere.</def> <mark>[Obs.]</mark> <ldquo/Make thy words
<xex>faithed</xex>.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Faithful</ent><br/
<hw>Faith"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Full of
faith, or having faith; disposed to believe, especially in the
declarations and promises of God.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>You are not <qex>faithful</qex>, sir.</q> <rj><qau>B.
Jonson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Firm in adherence to promises, oaths, contracts,
treaties, or other engagements.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>faithful</qex> God, which keepeth covenant and mercy with
them that love him.</q> <rj><qau>Deut. vii. 9.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>True and constant in affection or allegiance to a
person to whom one is bound by a vow, by ties of love, gratitude, or
honor, as to a husband, a prince, a friend; firm in the observance of
duty; loyal; of true fidelity; <as>as, a <ex>faithful</ex> husband or
servant</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>So spake the seraph Abdiel, <qex>faithful</qex> found,<br/
Among the faithless, <qex>faithful</qex> only he.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Worthy of confidence and belief; conformable to
truth ot fact; exact; accurate; <as>as, a <ex>faithful</ex> narrative or
representation</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It is a <qex>faithful</qex> saying.</q> <rj><qau>2 Tim. ii.
11.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>The Faithful</b></col>, <cd>the adherents of any system
of religious belief; esp. used as an epithet of the followers of
Mohammed.</cd></cs></p>

<p><syn><b>Syn.</b> -- Trusty; honest; upright; sincere; veracious;
trustworthy.</syn></p>

<p>-- <wordforms><wf>Faith"ful*ly</wf>, <pos>adv.</pos>
-<wf>Faith"ful*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>faithfulness</ent><br/
<hw>faithfulness</hw> <pos>n.</pos> <def>the trait of being
faithful.</def><br/
<syn><b>Syn. --</b> fidelity.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Faithless</ent><br/
<hw>Faith"less</hw>, <pos>a.</pos> <sn>1.</sn> <def>Not believing; not
giving credit.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Be not <qex>faithless</qex>, but believing.</q> <rj><qau>John xx.
27.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Not believing on God or religion; specifically, not
believing in the Christian religion.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Not observant of promises or covenants.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Not true to allegiance, duty, or vows; perfidious;
trecherous; disloyal; not of true fidelity; inconstant, as a husband or
a wife.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A most unnatural and <qex>faithless</qex> service.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Serving to disappoint or deceive; delusive;
unsatisfying.</def> <ldquo/Yonder <xex>faithless</xex> phantom.<rdquo/
<rj><au>Goldsmith.</au></rj></p>

<p>-- <wordforms><wf>Faith"less*ly</wf>,
<pos>adv.</pos><wf>Faith"less*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Faitour</ent><br/
<hw>Fai"tour</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>faitor</ets> a doer, L. <ets>factor</ets>. See
<er>Factor</er>.]</ety> <def>A doer or actor; particularly, an evil
doer; a scoundrel.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Lo! <qex>faitour</qex>, there thy meed unto thee take.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fake</ent><br/
<hw>Fake</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. Scot.
<ets>faik</ets> fold, stratum of stone, AS. <ets>f<ae/c</ets> space,
interval, G. <ets>fach</ets> compartment, partition, row, and E.
<ets>fay</ets> to fit.]</ety> <fld>(Naut.)</fld> <def>One of the circles
or windings of a cable or hawser, as it lies in a coil; a single turn or
coil.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fake</ent><br/
<hw>Fake</hw>, <pos>v. t.</pos> <fld>(Naut.)</fld> <def>To coil (a rope,
line, or hawser), by winding alternately in opposite directions, in
layers usually of zigzag or figure of eight form,, to prevent twisting
when running out.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Faking box</b></col>, <cd>a box in which a long rope is
faked; used in the life-saving service for a line attached to a
shot.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fake</ent><br/
<hw>Fake</hw>, <pos>v. t.</pos> <ety>[Cf. Gael. <ets>faigh</ets> to get,
acquire, reach, or OD. <ets>facken</ets> to catch or gripe.]</ety>
<mark>[<it>Slang in all its senses.</it>]</mark> <sn>1.</sn> <def>To
cheat; to swindle; to steal; to rob.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To make; to construct; to do.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To manipulate fraudulently, so as to make an object
appear better or other than it really is; <as>as, to <ex>fake</ex> a
bulldog, by burning his upper lip and thus artificially shortening
it</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fake</ent><br/
<hw>Fake</hw>, <pos>n.</pos> <def>A trick; a swindle.</def>
<mark>[Slang]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>fakeer</ent><br/
<hw>fakeer</hw> <pos>n.</pos> <def>same as <er>fakir</er>.</def><br/
<syn><b>Syn. --</b> fakir.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>faker</ent><br/
<hw>fak"er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sometimes erroneously
written <ets>fakir</ets>.]</ety> <sn>1.</sn> <def>One who fakes
something;</def> <specif>as</specif> <sd>(a)</sd> <def>a thief.</def>
<sd>(b)</sd>, <def>a peddler of petty things.</def> <sd>(c)</sd> <def>a
workman who dresses things up.</def> <mark>[Slang]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>a person who makes deceitful pretenses.</def><br/
<syn><b>Syn. --</b> imposter, impostor, pretender, fake, fraud, sham,
pseudo, pseud, role player.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fakir</ent><br/
<hw>Fa"kir</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Ar.
<ets>faq<imac/r</ets> poor.]</ety> <def>an Oriental Muslim or Hindu
religious ascetic or begging monk who is regarded as a holy man or a
wonder worker.</def> <altsp>[Written also <asp>faquir</asp> anf
<asp>fakeer</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fakir</ent><br/
<hw>Fa"kir</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Prob. confused with
<er>Fakir</er> an oriental ascetic.]</ety> <def>See
<er>Faker</er>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Falanaka</ent><br/
\'d8<hw>Fa"la*na"ka</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Native
name.]</ety> <fld>(Zool.)</fld> <def>A viverrine mammal of Madagascar
(<spn>Eupleres Goudotii</spn>), allied to the civet; -- called also
<altname>Falanouc</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Falcade</ent><br/
<hw>Fal*cade"</hw> <pr>(f<acr/l*k<amac/d")</pr>, <pos>n.</pos> <ety>[F.,
ultimately fr. L. <ets>falx</ets>, <ets>falcis</ets>, a sickle or
scythe.]</ety> <fld>(Man.)</fld> <def>The action of a horse, when he
throws himself on his haunches two or three times, bending himself, as
it were, in very quick curvets.</def> <rj><au>Harris.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 539 --></p>

<p><ent>Falcated</ent><br/
<ent>Falcate</ent><br/
<mhw>{ <hw>Fal"cate</hw> <pr>(?)</pr>, <hw>Fal"ca*ted</hw> <pr>(?)</pr>,
}</mhw> <pos>a.</pos> <ety>[L. <ets>falcatus</ets>, fr. <ets>falx</ets>,
<ets>falcis</ets>, a sickle or scythe.]</ety> <def>Hooked or bent like a
sickle; <as>as, a <ex>falcate</ex> leaf; a <ex>falcate</ex> claw</as>;
-- said also of the moon, or a planet, when horned or
crescent-formed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Falcation</ent><br/
<hw>Fal*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state of being
falcate; a bend in the form of a sickle.</def> <rj><au>Sir T.
Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Falcer</ent><br/
<hw>Fal"cer</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From L.
<ets>falx</ets>, <ets>falcis</ets>, a sickle.]</ety> <fld>(Zool.)</fld>
<def>One of the mandibles of a spider.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Falchion</ent><br/
<hw>Fal"chion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>fauchon</ets>, OF. <ets>fauchon</ets>, LL. <ets>f<aum/lcio</ets>,
fr. L. <ets>falx</ets>, <ets>falcis</ets>, a sickle, cf. Gr.
<?/<?/<?/<?/<?/<?/ a ship's rib, <?/<?/<?/<?/<?/<?/ bandy-legged; perh,
akin to E. <ets>falcon</ets>; cf. It. <ets>falcione</ets>. Cf.
<er>Defalcation</er>.]</ety> <sn>1.</sn> <def>A broad-bladed sword,
slightly curved, shorter and lighter than the ordinary sword; -- used in
the Middle Ages.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A name given generally and poetically to a sword,
especially to the swords of Oriental and fabled warriors.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Falcidian</ent><br/
<hw>Fal*cid"i*an</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>Falcidius</ets>.]</ety> <def>Of or pertaining to Publius Falcidius,
a Roman tribune.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Falcidian law</b></col> <fld>(Civil Law)</fld>, <cd>a law
by which a testator was obliged to leave at least a fourth of his estate
to the heir.</cd> <rj><au>Burrill.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Falciform</ent><br/
<hw>Fal"ci*form</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>falx</ets>, <ets>falcis</ets>, a sickle + <ets>-form</ets>: cf. F.
<ets>falciforme</ets>.]</ety> <def>Having the shape of a scithe or
sickle; resembling a reaping hook; <as>as, the <ex>falciform</ex>
ligatment of the liver</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Falcon</ent><br/
<hw>Fal"con</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>faucon</ets>, <ets>faucoun</ets>, OF. <ets>faucon</ets>,
<ets>falcon</ets>, <?/. <ets>faucon</ets>, fr. LL. <ets>falco</ets>,
perh. from L. <ets>falx, falcis</ets>, a sickle or scythe, and named
from its curving talons. Cf. <er>Falchion</er>.]</ety> <sn>1.</sn>
<fld>(Zool.)</fld> <sd>(a)</sd> <def>One of a family
(<fam>Falconid<ae/</fam>) of raptorial birds, characterized by a short,
hooked beak, strong claws, and powerful flight.</def> <sd>(b)</sd>
<def>Any species of the genus <gen>Falco</gen>, distinguished by having
a toothlike lobe on the upper mandible; especially, one of this genus
trained to the pursuit of other birds, or game.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In the language of falconry, the female peregrine (<spn>Falco
peregrinus</spn>) is exclusively called the <qex>falcon</qex>.</q>
<rj><qau>Yarrell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Gun.)</fld> <def>An ancient form of
cannon.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Chanting falcon</b></col>. <fld>(Zool.)</fld> <cd>See
under <er>Chanting</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Falconer</ent><br/
<hw>Fal"con*er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>fauconer</ets>, OF. <ets>falconier</ets>, <ets>fauconier</ets>, F.
<ets>fauconnier</ets>. See <er>Falcon</er>.]</ety> <def>A person who
breeds or trains hawks for taking birds or game; one who follows the
sport of fowling with hawks.</def> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Falconet</ent><br/
<hw>Fal"co*net</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Dim. of
<ets>falcon</ets>: cf. F. <ets>fauconneau</ets>, LL.
<ets>falconeta</ets>, properly, a young falcon.]</ety> <sn>1.</sn>
<def>One of the smaller cannon used in the 15th century and
later.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <sd>(a)</sd> <def>One of several very
small Asiatic falcons of the genus <gen>Microhierax</gen>.</def>
<sd>(b)</sd> <def>One of a group of Australian birds of the genus
<gen>Falcunculus</gen>, resembling shrikes and titmice.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>falcon-gentle</ent><br/
<ent>falcon-gentil</ent><br/
<mhw><hw>fal"con-gen`til</hw>, <hw>falcon-gentle</hw></mhw>
<pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>faucon-gentil</ets>. See
<er>Falcon</er>, and <er>Genteel</er>.]</ety> <sn>1.</sn>
<fld>(Zool.)</fld> <def>any female falcon;</def> <specif>especially
--</specif><br/
[<source>PJC</source>]</p>


<p><sn>2.</sn> <fld>(Zool.)</fld> <def>a female peregrine falcon
(<spn>Falco peregrinus</spn>).</def><br/
<syn><b>Syn. --</b> falcon-gentil.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <def>The female or young of the
goshawk (<spn>Accipiter gentilis</spn>, formerly <spn>Astur
palumbarius</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Falconine</ent><br/
<hw>Fal"co*nine</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Like a falcon or hawk; belonging to the
<fam>Falconid<ae/</fam></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Falconry</ent><br/
<hw>Fal"con*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>fauconnerie</ets>. See <er>Falcon</er>.]</ety> <sn>1.</sn> <def>The
art of training falcons or hawks to pursue and attack wild fowl or
game.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The sport of taking wild fowl or game by means of
falcons or hawks.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Falcula</ent><br/
\'d8<hw>Fal"cu*la</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., a small
sickle, a billhook.]</ety> <fld>(Zool.)</fld> <def>A curved and
sharp-pointed claw.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Falculate</ent><br/
<hw>Fal"cu*late</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Curved and sharppointed, like a falcula, or claw of a
falcon.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Faldage</ent><br/
<hw>Fald"age</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL.
<ets>faldagium</ets>, fr. AS. <ets>fald</ets>, E. <ets>fold</ets>. Cf.
<er>Foldage</er>.]</ety> <fld>(O. Eng. Law)</fld> <def>A privilege of
setting up, and moving about, folds for sheep, in any fields within
manors, in order to manure them; -- often reserved to himself by the
lord of the manor.</def> <rj><au>Spelman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Falderal</ent><br/
<hw>Fal"de*ral`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>Nonsense; foolish talk.</def> <altsp>[Also spelled
<asp>folderol</asp> and <asp>falderol</asp>.]</altsp>
<mark>[Colloq.]</mark><br/
<syn><b>Syn. --</b> humbug; balderdash; poppycock.</syn><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>a knickknack; a gew-gaw.</def><br/
[<source>PJC</source>]</p>

<p><ent>Faldfee</ent><br/
<hw>Fald"fee`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS. <ets>fald</ets>
(E.<ets>fold</ets>) + E. <ets>fee</ets>. See <er>Faldage</er>.]</ety>
<fld>(O. Eng. Law)</fld> <def>A fee or rent paid by a tenant for the
privilege of faldage on his own ground.</def>
<rj><au>Blount.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Falding</ent><br/
<hw>Fald"ing</hw>, <pos>n.</pos> <def>A frieze or rough-napped
cloth.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Faldistory</ent><br/
<hw>Fal"dis*to*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL.
<ets>faldistorium</ets>, <ets>faldestorium</ets>, from OHG.
<ets>faldstuol</ets>; <ets>faldan</ets>, <ets>faltan</ets>, to fold (G.
<ets>falten</ets>) + <ets>stuol</ets> stool. So called because it could
be folded or laid together. See <er>Fold</er>, and <er>Stool</er>, and
cf. <er>Faldstool</er>, <er>Fauteuil</er>.]</ety> <def>The throne or
seat of a bishop within the chancel.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Faldstool</ent><br/
<hw>Fald"stool`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Faldistory</er>.]</ety> <def>A folding stool, or portable seat, made
to fold up in the manner of a camo stool. It was formerly placed in the
choir for a bishop, when he offciated in any but his own cathedral
church.</def> <rj><au>Fairholt.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In the modern practice of the Church of England, the
term <xex>faldstool</xex> is given to the reading desk from which the
litany is read. This esage is a relic of the ancient use of a lectern
folding like a camp stool.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Falernian</ent><br/
<hw>Fa*ler"ni*an</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining
to Mount <etsep>Falernus</etsep>, in Italy; <as>as,
<ex>Falernian</ex>wine</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Falk</ent><br/
<hw>Falk</hw> <pr>(f<add/k)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>The razorbill.</def> <altsp>[Written also <asp>falc</asp>, and
<asp>faik</asp>.]</altsp> <mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fall</ent><br/
<hw>Fall</hw> <pr>(f<add/l)</pr>, <pos>v. i.</pos>
<vmorph>[<pos>imp.</pos> <conjf>Fell</conjf> <pr>(f<ecr/l)</pr>; <pos>p.
p.</pos> <conjf>Fallen</conjf> <pr>(f<add/l"'n)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Falling</conjf>.]</vmorph> <ety>[AS. <ets>feallan</ets>;
akin to D. <ets>vallen</ets>, OS. & OHG. <ets>fallan</ets>, G.
<ets>fallen</ets>, Icel. <ets>Falla</ets>, Sw. <ets>falla</ets>, Dan.
<ets>falde</ets>, Lith. <ets>pulti</ets>, L. <ets>fallere</ets> to
deceive, Gr. <grk>sfa`llein</grk> to cause to fall, Skr.
<ets>sphal</ets>, <ets>sphul</ets>, to tremble. Cf. <er>Fail</er>,
<er>Fell</er>, <pos>v. t.</pos>, to cause to fall.]</ety> <sn>1.</sn>
<def>To Descend, either suddenly or gradually; particularly, to descend
by the force of gravity; to drop; to sink; <as>as, the apple
<ex>falls</ex>; the tide <ex>falls</ex>; the mercury <ex>falls</ex> in
the barometer.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>I beheld Satan as lightning <qex>fall</qex> from heaven.</q>
<rj><qau>Luke x. 18.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To cease to be erect; to take suddenly a recumbent
posture; to become prostrate; to drop; <as>as, a child totters and
<ex>falls</ex>; a tree <ex>falls</ex>; a worshiper <ex>falls</ex> on his
knees.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>I <qex>fell</qex> at his feet to worship him.</q> <rj><qau>Rev.
xix. 10.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To find a final outlet; to discharge its waters; to
empty; -- with <xex>into</xex>; <as>as, the river Rhone <ex>falls</ex>
into the Mediterranean</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To become prostrate and dead; to die; especially, to
die by violence, as in battle.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A thousand shall <qex>fall</qex> at thy side.</q> <rj><qau>Ps.
xci. 7.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He rushed into the field, and, foremost fighting,
<qex>fell</qex>.</q> <rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To cease to be active or strong; to die away; to
lose strength; to subside; to become less intense; <as>as, the wind
<ex>falls</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To issue forth into life; to be brought forth; --
said of the young of certain animals.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>To decline in power, glory, wealth, or importance;
to become insignificant; to lose rank or position; to decline in weight,
value, price etc.; to become less; <as>as, the price <ex>falls</ex>;
stocks <ex>fell</ex> two points.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>I am a poor <qex>fallen</qex> man, unworthy now<br/
To be thy lord and master.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The greatness of these Irish lords suddenly <qex>fell</qex> and
vanished.</q> <rj><qau>Sir J. Davies.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>To be overthrown or captured; to be
destroyed.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Heaven and earth will witness,<br/
If Rome must <qex>fall</qex>, that we are innocent.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>To descend in character or reputation; to become
degraded; to sink into vice, error, or sin; to depart from the faith; to
apostatize; to sin.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Let us labor therefore to enter into that rest, lest any man
<qex>fall</qex> after the same example of unbelief.</q> <rj><qau>Heb.
iv. 11.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <def>To become insnared or embarrassed; to be entrapped;
to be worse off than before; <as>as, to <ex>fall</ex> into error; to
<ex>fall</ex> into difficulties</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>11.</sn> <def>To assume a look of shame or disappointment; to
become or appear dejected; -- said of the countenance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Cain was very wroth, and his countenance <qex>fell</qex>.</q>
<rj><qau>Gen. iv. 5.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I have observed of late thy looks are <qex>fallen</qex>.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>12.</sn> <def>To sink; to languish; to become feeble or faint;
<as>as, our spirits rise and <ex>fall</ex> with our
fortunes</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>13.</sn> <def>To pass somewhat suddenly, and passively, into a
new state of body or mind; to become; <as>as, to <ex>fall</ex> asleep;
to <ex>fall</ex> into a passion; to <ex>fall</ex> in love; to
<ex>fall</ex> into temptation.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>14.</sn> <def>To happen; to to come to pass; to light; to befall;
to issue; to terminate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The Romans <qex>fell</qex> on this model by chance.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Sit still, my daughter, until thou know how the matter will
<qex>fall</qex>.</q> <rj><qau>Ruth. iii. 18.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>They do not make laws, they <qex>fall</qex> into customs.</q>
<rj><qau>H. Spencer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>15.</sn> <def>To come; to occur; to arrive.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The vernal equinox, which at the Nicene Council <qex>fell</qex> on
the 21st of March, <qex>falls</qex> now [1694] about ten days
sooner.</q> <rj><qau>Holder.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>16.</sn> <def>To begin with haste, ardor, or vehemence; to rush
or hurry; <as>as, they <ex>fell</ex> to blows</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They now no longer doubted, but <qex>fell</qex> to work heart and
soul.</q> <rj><qau>Jowett (Thucyd. ).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>17.</sn> <def>To pass or be transferred by chance, lot,
distribution, inheritance, or otherwise; <as>as, the estate
<ex>fell</ex> to his brother; the kingdom <ex>fell</ex> into the hands
of his rivals.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>18.</sn> <def>To belong or appertain.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If to her share some female errors <qex>fall</qex>,<br/
Look on her face, and you'll forget them all.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>19.</sn> <def>To be dropped or uttered carelessly; <as>as, an
unguarded expression <ex>fell</ex> from his lips; not a murmur
<ex>fell</ex> from him.</as></def><br/
[<source>1913 Webster</source>]</p>

<cs><p><col><b>To fall abroad of</b></col> <fld>(Naut.)</fld>, <cd>to
strike against; -- applied to one vessel coming into collision with
another.</cd> -- <col><b>To fall among</b></col>, <cd>to come among
accidentally or unexpectedly.</cd> -- <col><b>To fall astern</b></col>
<fld>(Naut.)</fld>, <cd>to move or be driven backward; to be left
behind; as, a ship <xex>falls astern</xex> by the force of a current, or
when outsailed by another.</cd> -- <col><b>To fall away</b></col>.
<sd>(a)</sd> <cd>To lose flesh; to become lean or emaciated; to
pine.</cd> <sd>(b)</sd> <cd>To renounce or desert allegiance; to revolt
or rebel.</cd> <sd>(c)</sd> <cd>To renounce or desert the faith; to
apostatize.</cd> <ldquo/These . . . for a while believe, and in time of
temptation <xex>fall away</xex>.<rdquo/ <au>Luke viii. 13.</au>
<sd>(d)</sd> <cd>To perish; to vanish; to be lost.</cd> <ldquo/How . . .
can the soul . . . <xex>fall away</xex> into nothing?<rdquo/
<au>Addison.</au> <sd>(e)</sd> <cd>To decline gradually; to fade; to
languish, or become faint.</cd> <ldquo/One color <xex>falls away</xex>
by just degrees, and another rises insensibly.<rdquo/ <au>Addison.</au>
-- <col><b>To fall back</b></col>. <sd>(a)</sd> <cd>To recede or
retreat; to give way.</cd> <sd>(b)</sd> <cd>To fail of performing a
promise or purpose; not to fulfill.</cd> -- <mcol><col><b>To fall back
upon</b></col> <it>or</it> <col><b>To fall back on</b></col></mcol>.
<sd>(a)</sd> <fld>(Mil.)</fld> <cd>To retreat for safety to (a stronger
position in the rear, as to a fort or a supporting body of troops).</cd>
<sd>(b)</sd> <cd>To have recourse to (a reserved fund, a more reliable
alternative, or some other available expedient or support).</cd> --
<col><b>To fall calm</b></col>, <cd>to cease to blow; to become
calm.</cd> -- <col><b>To fall down</b></col>. <sd>(a)</sd> <cd>To
prostrate one's self in worship.</cd> <ldquo/All kings shall <xex>fall
down</xex> before him.<rdquo/ <au>Ps. lxxii. 11.</au> <sd>(b)</sd>
<cd>To sink; to come to the ground.</cd> <ldquo/<xex>Down fell</xex> the
beauteous youth.<rdquo/ <au>Dryden.</au> <sd>(c)</sd> <cd>To bend or
bow, as a suppliant.</cd> <sd>(d)</sd> <fld>(Naut.)</fld> <cd>To sail or
drift toward the mouth of a river or other outlet.</cd> -- <col><b>To
fall flat</b></col>, <cd>to produce no response or result; to fail of
the intended effect; as, his speech <xex>fell flat</xex>.</cd> --
<col><b>To fall foul of</b></col>. <sd>(a)</sd> <fld>(Naut.)</fld>
<cd>To have a collision with; to become entangled with</cd> <sd>(b)</sd>
<cd>To attack; to make an assault upon.</cd> -- <col><b>To fall
from</b></col>, <cd>to recede or depart from; not to adhere to; as,
<xex>to fall from</xex> an agreement or engagement; <xex>to fall
from</xex> allegiance or duty.</cd> -- <col><b>To fall from
grace</b></col> <fld>(M. E. Ch.)</fld>, <cd>to sin; to withdraw from the
faith.</cd> -- <col><b>To fall home</b></col> <fld>(Ship Carp.)</fld>,
<cd>to curve inward; -- said of the timbers or upper parts of a ship's
side which are much within a perpendicular.</cd> -- <col><b>To fall
in</b></col>. <sd>(a)</sd> <cd>To sink inwards; as, the roof <xex>fell
in</xex>.</cd> <sd>(b)</sd> <fld>(Mil.)</fld> <cd>To take one's proper
or assigned place in line; as, <xex>to fall in</xex> on the right.</cd>
<sd>(c)</sd> <cd>To come to an end; to terminate; to lapse; <as>as, on
the death of Mr. B., the annuuity, which he had so long received,
<ex>fell in</ex></as>.</cd> <sd>(d)</sd> <cd>To become operative.</cd>
<ldquo/The reversion, to which he had been nominated twenty years
before, <xex>fell in</xex>.<rdquo/ <au>Macaulay.</au> -- <col><b>To fall
into one's hands</b></col>, <cd>to pass, often suddenly or unexpectedly,
into one's ownership or control; as, to spike cannon when they are
likely <xex>to fall into the hands</xex> of the enemy.</cd> --
<col><b>To fall in with</b></col>. <sd>(a)</sd> <cd>To meet with
accidentally; as, <xex>to fall in with</xex> a friend.</cd> <sd>(b)</sd>
<fld>(Naut.)</fld> <cd>To meet, as a ship; also, to discover or come
near, as land.</cd> <sd>(c)</sd> <cd>To concur with; to agree with; as,
the measure <xex>falls in with</xex> popular opinion.</cd> <sd>(d)</sd>
<cd>To comply; to yield to.</cd> <ldquo/You will find it difficult to
persuade learned men <xex>to fall in with</xex> your projects.<rdquo/
<au>Addison.</au> -- <col><b>To fall off</b></col>. <sd>(a)</sd> <cd>To
drop; as, fruits <xex>fall off</xex> when ripe.</cd> <sd>(b)</sd> <cd>To
withdraw; to separate; to become detached; as, friends <xex>fall
off</xex> in adversity.</cd> <ldquo/Love cools, friendship <xex>falls
off</xex>, brothers divide.<rdquo/ <au>Shak.</au> <sd>(c)</sd> <cd>To
perish; to die away; as, words <xex>fall off</xex> by disuse.</cd>
<sd>(d)</sd> <cd>To apostatize; to forsake; to withdraw from the faith,
or from allegiance or duty.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>Those captive tribes . . . <qex>fell off</qex><br/
From God to worship calves.</q> <rj><qau>Milton.</qau></rj></p>

<p><sd>(e)</sd> <cd>To forsake; to abandon; as, his customers <xex>fell
off</xex>.</cd> <sd>(f)</sd> <cd>To depreciate; to change for the worse;
to deteriorate; to become less valuable, abundant, or interesting;
<as>as, a <xex>falling off</xex> in the wheat crop; the magazine or the
review <xex>falls off</xex></as>.</cd> <ldquo/O Hamlet, what a
<xex>falling off</xex> was there!<rdquo/ <au>Shak.</au> <sd>(g)</sd>
<fld>(Naut.)</fld> <cd>To deviate or trend to the leeward of the point
to which the head of the ship was before directed; to fall to
leeward.</cd> -- <col><b>To fall on</b></col>. <sd>(a)</sd> <cd>To meet
with; to light upon; as, we have <xex>fallen on</xex> evil days.</cd>
<sd>(b)</sd> <cd>To begin suddenly and eagerly.</cd> <ldquo/<xex>Fall
on</xex>, and try the appetite to eat.<rdquo/ <au>Dryden.</au>
<sd>(c)</sd> <cd>To begin an attack; to assault; to assail.</cd>
<ldquo/<xex>Fall on</xex>, <xex>fall on</xex>, and hear him not.<rdquo/
<au>Dryden.</au> <sd>(d)</sd> <cd>To drop on; to descend on.</cd> --
<col><b>To fall out</b></col>. <sd>(a)</sd> <cd>To quarrel; to begin to
contend.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>A soul exasperated in ills <qex>falls out</qex><br/
With everything, its friend, itself.</q>
<rj><qau>Addison.</qau></rj></p>

<p><sd>(b)</sd> <cd>To happen; to befall; to chance.</cd> <ldquo/There
<xex>fell out</xex> a bloody quarrel betwixt the frogs and the
mice.<rdquo/ <au>L'Estrange.</au> <sd>(c)</sd> <fld>(Mil.)</fld> <cd>To
leave the ranks, as a soldier.</cd> -- <col><b>To fall over</b></col>.
<sd>(a)</sd> <cd>To revolt; to desert from one side to another.</cd>
<sd>(b)</sd> <cd>To fall beyond.</cd> <au>Shak.</au> -- <col><b>To fall
short</b></col>, <cd>to be deficient; as, the corn <xex>falls
short</xex>; they all <xex>fall short</xex> in duty.</cd> -- <col><b>To
fall through</b></col>, <cd>to come to nothing; to fail; as, the
engageent <xex>has fallen through</xex>.</cd> -- <col><b>To fall
to</b></col>, <cd>to begin.</cd> <ldquo/<xex>Fall to</xex>, with eager
joy, on homely food.<rdquo/ <au>Dryden.</au> -- <col><b>To fall
under</b></col>. <sd>(a)</sd> <cd>To come under, or within the limits
of; to be subjected to; as, they <xex>fell under</xex> the jurisdiction
of the emperor.</cd> <sd>(b)</sd> <cd>To come under; to become the
subject of; <as>as, this point did not <ex>fall under</ex> the
cognizance or deliberations of the court; these things do not <ex>fall
under</ex> human sight or observation.</as></cd> <sd>(c)</sd> <cd>To
come within; to be ranged or reckoned with; to be subordinate to in the
way of classification; <as>as, these substances <ex>fall under</ex> a
different class or order.</as></cd> -- <col><b>To fall upon</b></col>.
<sd>(a)</sd> <cd>To attack.</cd> [See <cref>To fall on</cref>.]
<sd>(b)</sd> <cd>To attempt; to have recourse to.</cd> <ldquo/I do not
intend <xex>to fall upon</xex> nice disquisitions.<rdquo/
<au>Holder.</au> <sd>(c)</sd> <cd>To rush against.</cd><br/
[<source>1913 Webster</source>]</p></cs>

<p><note><hand/ <xex>Fall</xex> primarily denotes descending motion,
either in a perpendicular or inclined direction, and, in most of its
applications, implies, <xex>literally</xex> or <xex>figuratively</xex>,
velocity, haste, suddenness, or violence. Its use is so various, and so
mush diversified by modifying words, that it is not easy to enumerate
its senses in all its applications.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fall</ent><br/
<hw>Fall</hw> <pr>(?)</pr>, <pos>v. t.</pos> <sn>1.</sn> <def>To let
fall; to drop.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>For every tear he <qex>falls</qex>, a Trojan bleeds.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To sink; to depress; <as>as, to <ex>fall</ex> the
voice</as>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To diminish; to lessen or lower.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Upon lessening interest to four per cent, you <qex>fall</qex> the
price of your native commodities.</q> <rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To bring forth; <as>as, to <ex>fall</ex>
lambs</as>.</def> <mark>[R.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To fell; to cut down; <as>as, to <ex>fall</ex> a
tree</as>.</def> <mark>[Prov. Eng. & Local, U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fall</ent><br/
<hw>Fall</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act of falling; a
dropping or descending be the force of gravity; descent; <as>as, a
<ex>fall</ex> from a horse, or from the yard of ship</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The act of dropping or tumbling from an erect
posture; <as>as, he was walking on ice, and had a
<ex>fall</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Death; destruction; overthrow; ruin.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They thy <qex>fall</qex> conspire.</q>
<rj><qau>Denham.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Pride goeth before destruction, and a haughty spirit before a
<qex>fall</qex>.</q> <rj><qau>Prov. xvi. 18.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Downfall; degradation; loss of greatness or office;
termination of greatness, power, or dominion; ruin; overthrow; <as>as,
the <ex>fall</ex> of the Roman empire</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Beholds thee glorious only in thy <qex>fall</qex>.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>The surrender of a besieged fortress or town ;
<as>as, the <ex>fall</ex> of Sebastopol</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Diminution or decrease in price or value;
depreciation; <as>as, the <ex>fall</ex> of prices; the <ex>fall</ex> of
rents.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>A sinking of tone; cadence; <as>as, the
<ex>fall</ex> of the voice at the close of a sentence</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>Declivity; the descent of land or a hill; a
slope.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>Descent of water; a cascade; a cataract; a rush of
water down a precipice or steep; -- usually in the plural, sometimes in
the singular; <as>as, the <ex>falls</ex> of Niagara</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <def>The discharge of a river or current of water into
the ocean, or into a lake or pond; <as>as, the <ex>fall</ex> of the Po
into the Gulf of Venice</as>.</def> <rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>11.</sn> <def>Extent of descent; the distance which anything
falls; <as>as, the water of a stream has a <ex>fall</ex> of five
feet</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>12.</sn> <def>The season when leaves fall from trees;
autumn.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>What crowds of patients the town doctor kills,<br/
Or how, last <qex>fall</qex>, he raised the weekly bills.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>13.</sn> <def>That which falls; a falling; <as>as, a
<ex>fall</ex> of rain; a heavy <ex>fall</ex> of snow.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>14.</sn> <def>The act of felling or cutting down.</def>
<ldquo/The <xex>fall</xex> of timber.<rdquo/
<rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>15.</sn> <def>Lapse or declension from innocence or goodness.
Specifically: The first apostasy; the act of our first parents in eating
the forbidden fruit; also, the apostasy of the rebellious
angels.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>16.</sn> <def>Formerly, a kind of ruff or band for the neck; a
falling band; a faule.</def> <rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>17.</sn> <def>That part (as one of the ropes) of a tackle to
which the power is applied in hoisting.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fall herring</b></col> <fld>(Zool.)</fld>, <cd>a herring
of the Atlantic (<spn>Clupea mediocris</spn>); -- also called
<altname>tailor herring</altname>, and <altname>hickory
shad</altname>.</cd> -- <col><b>To try a fall</b></col>, <cd>to try a
bout at wrestling.</cd> <au>Shak.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fallacious</ent><br/
<hw>Fal*la"cious</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>fallaciosus</ets>, fr. <ets>fallacia</ets>: cf. F.
<ets>fallacieux</ets>. See <er>Fallacy</er>.]</ety> <def>Embodying or
pertaining to a fallacy; illogical; fitted to deceive; misleading;
delusive; <as>as, <ex>fallacious</ex> arguments or reasoning</as>.</def>
-- <wordforms><wf>Fal*la"cious*ly</wf>, <pos>adv.</pos>
-<wf>Fal*la"cious*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 540 --></p>

<p><ent>fallaciousness</ent><br/
<hw>fallaciousness</hw> <pos>n.</pos> <sn>1.</sn> <def>result of a
fallacy or error in reasoning.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fallacy</ent><br/
<hw>Fal"la*cy</hw> <pr>(f<acr/l"l<adot/*s<ycr/)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Fallacies</plw>
<pr>(f<acr/l"l<adot/*s<icr/z)</pr>.</plu> <ety>[OE. <ets>fallace</ets>,
<ets>fallas</ets>, deception, F. <ets>fallace</ets>, fr. L.
<ets>fallacia</ets>, fr. <ets>fallax</ets> deceitful, deceptive, fr.
<ets>fallere</ets> to deceive. See <er>Fail</er>.]</ety> <sn>1.</sn>
<def>Deceptive or false appearance; deceitfulness; that which misleads
the eye or the mind; deception.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Winning by conquest what the first man lost,<br/
By <qex>fallacy</qex> surprised.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Logic)</fld> <def>An argument, or apparent
argument, which professes to be decisive of the matter at issue, while
in reality it is not; a sophism.</def></p>

<p><syn><b>Syn.</b> -- Deception; deceit; mistake.</syn> <usage> --
<er>Fallacy</er>, <er>Sophistry</er>. A <xex>fallacy</xex> is an
argument which professes to be decisive, but in reality is not;
<xex>sophistry</xex> is also false reasoning, but of so specious and
subtle a kind as to render it difficult to expose its
<xex>fallacy</xex>. Many <xex>fallacies</xex> are obvious, but the evil
of <xex>sophistry</xex> lies in its consummate art. <ldquo/Men are apt
to suffer their minds to be misled by <xex>fallacies</xex> which gratify
their passions. Many persons have obscured and confounded the nature of
things by their wretched <xex>sophistry</xex>; though an act be never so
sinful, they will strip it of its guilt.<rdquo/
<au>South.</au></usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fal-lals</ent><br/
<hw>Fal"-lals`</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <def>Gay ornaments;
frippery; gewgaws.</def> <mark>[Colloq.]</mark>
<rj><au>Thackeray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fallax</ent><br/
<hw>Fal"lax</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>fallax</ets>
deceptive. See <er>Fallacy</er>.]</ety> <def>Cavillation; a
caviling.</def> <mark>[Obs.]</mark> <rj><au>Cranmer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>fallback</ent><br/
<hw>fall"back</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The act
or process of falling back.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>Something or someone to which one resorts as an
alternative to a failed resource or method.</def><br/
[<source>PJC</source>]</p>

<p><ent>Fallen</ent><br/
<hw>Fall"en</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Dropped; prostrate;
degraded; ruined; decreased; dead.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Some ruined temple or <qex>fallen</qex> monument.</q>
<rj><qau>Rogers.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fallency</ent><br/
<hw>Fal"len*cy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL.
<ets>fallentia</ets>, L. <ets>fallens</ets> p. pr of
<ets>fallere</ets>.]</ety> <def>An exception.</def> <mark>[Obs.]</mark>
<rj><au>Jer. Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Faller</ent><br/
<hw>Fall"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who,
or that which, falls.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mach.)</fld> <def>A part which acts by falling, as
a stamp in a fulling mill, or the device in a spinning machine to arrest
motion when a thread breaks.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fallfish</ent><br/
<hw>Fall"fish`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>A fresh-water fish of the United States (<spn>Semotilus
bullaris</spn>); -- called also <altname>silver chub</altname>, and
<altname>Shiner</altname>. The name is also applied to other allied
species.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fallibility</ent><br/
<hw>Fal`li*bil"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state of
being fallible; liability to deceive or to be deceived; <as>as, the
<ex>fallibity</ex> of an argument or of an adviser</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fallible</ent><br/
<hw>Fal"li*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[LL.
<ets>fallibilis</ets>, fr. L. <ets>fallere</ets> to deceive: cf. F.
<ets>faillible</ets>. See <er>Fail</er>.]</ety> <def>Liable to fail,
mistake, or err; liable to deceive or to be deceived; <as>as, all men
are <ex>fallible</ex>; our opinions and hopes are
<ex>fallible</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fallibly</ent><br/
<hw>Fal"li*bly</hw>, <pos>adv.</pos> <def>In a fallible
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Falling</ent><br/
<hw>Fall"ing</hw> <pr>(?)</pr>, <pos>a. & n.</pos> <def>from
<er>Fall</er>, <pos>v. i.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Falling away</b></col>, <col><b>Falling
off</b></col></mcol>, etc. <cd>See <cref>To fall away</cref>, <cref>To
fall off</cref>, etc., under <er>Fall</er>, <pos>v. i.</pos></cd> --
<col><b>Falling band</b></col>, <cd>the plain, broad, linen collar
turning down over the doublet, worn in the early part of the 17th
century.</cd> -- <col><b>Falling sickness</b></col> <fld>(Med.)</fld>,
<cd>epilepsy.</cd> <au>Shak.</au> -- <col><b>Falling star</b></col>.
<fld>(Astron.)</fld> <cd>See <er>Shooting star</er>.</cd> --
<col><b>Falling stone</b></col>, <cd>a stone falling through the
atmosphere; a meteorite; an a<eum/rolite.</cd> -- <col><b>Falling
tide</b></col>, <cd>the ebb tide.</cd> -- <col><b>Falling
weather</b></col>, <cd>a rainy season.</cd> <mark>[Colloq.]</mark>
<au>Bartlett.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>falloff</ent><br/
<hw>falloff</hw> <pos>n.</pos> <def>a noticeable decline in performance;
<as>as, a <ex>falloff</ex> in automobile sales</as>.</def><br/
<syn><b>Syn. --</b> slump, drop-off, falling off.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fallopian</ent><br/
<hw>Fal*lo"pi*an</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From
<ets>Fallopius</ets>, or <ets>Fallopio</ets>, a physician of Modena, who
died in 1562.]</ety> <fld>(Anat.)</fld> <def>Pertaining to, or
discovered by, Fallopius; <as>as, the <ex>Fallopian</ex> tubes or
oviducts, the ducts or canals which conduct the ova from the ovaries to
the uterus</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>fallout</ent><br/
<hw>fallout</hw> <pos>n.</pos> <sn>1.</sn> <def>the radioactive
particles that settle to the ground after a nuclear explosion.</def><br/
<syn><b>Syn. --</b> radioactive dust, radioactive fallout.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>the falling to the ground of radioactive particles
lifted into the atmosphere by a nuclear explosion.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>an incidental or unexpected effect, especially one
which is undesirable, consequent to an event or process; ; -- usually
used only in the singular; <as>as, the <ex>fallout</ex> from the
disclosure of the Lewinsky tapes made trouble for the President for
months after the event; <ex>fallout</ex> from the stock market crash
caused property prices to decline in the New York area</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <fld>(Med.)</fld> <def>one selected from a group by some
criterion.</def> <mark>[cant]</mark> <br/
[<source>PJC</source>]</p>

<p><q>Corrective action was taken in 97 of the 418 <qau>fallouts</qau>
from 3,787 patients at risk.</q> <rj><qau>H. Gill Cryer et al. (Journal
of Trauma, Injury, Infection, and Critical Care. Vol 41, no. 3,
1996).</qau></rj><br/
[<source>PJC</source>]</p>

<p><sn>5.</sn> <def>one who fails to maintain the same pace as and lags
behind a group of which s/he is a member.</def> <mark>[cant]</mark> <br/
[<source>PJC</source>]</p>

<p><q>The executive officer's group noted all <qau>fallouts</qau> by
name and policed them into a group to complete the run at a slower
pace.</q> <rj><qau>Lt. Col. William C. David (Preparing a Battalion for
Combat: Physical Fitness and Mental Toughness. Army University After
Next - Virtual Research Library).</qau></rj><br/
[<source>PJC</source>]</p>

<p><ent>Fallow</ent><br/
<hw>Fal"low</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[AS. <ets>fealu</ets>,
<ets>fealo</ets>, pale yellow or red; akin to D. <ets>vaal</ets> fallow,
faded, OHG. <ets>falo</ets>, G. <ets>falb</ets>, <ets>fahl</ets>, Icel.
<ets>f<oum/lr</ets>, and prob. to Lith. <ets>palvas</ets>, OSlav.
<ets>plav<ucr/</ets> white, L. <ets>pallidus</ets> pale,
<ets>pallere</ets> to be pale, Gr. <grk>polio`s</grk> gray, Skr.
<ets>palita</ets>. Cf. <er>Pale</er>, <er>Favel</er>, <pos>a.</pos>,
<er>Favor</er>.]</ety> <sn>1.</sn> <def>Pale red or pale yellow; <as>as,
a <ex>fallow</ex> deer or greyhound</as>.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <ety>[Cf. <er>Fallow</er>, <pos>n.</pos>]</ety> <def>Left
untilled or unsowed after plowing; uncultivated; <as>as, <ex>fallow</ex>
ground</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Fallow chat</b></col>, <col><b>Fallow
finch</b></col></mcol> <fld>(Zool.)</fld>, <cd>a small European bird,
the wheatear (<spn>Saxicola <oe/nanthe</spn>). See
<er>Wheatear</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fallow</ent><br/
<hw>Fal"low</hw>, <pos>n.</pos> <ety>[So called from the
<ets>fallow</ets>, or somewhat yellow, color of naked ground; or perh.
akin to E. <ets>felly</ets>, <pos>n.</pos>, cf. MHG. <ets>valgen</ets>
to plow up, OHG. <ets>felga</ets> felly, harrow.]</ety> <sn>1.</sn>
<def>Plowed land.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Who . . . pricketh his blind horse over the
<qex>fallows</qex>.</q> <rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Land that has lain a year or more untilled or
unseeded; land plowed without being sowed for the season.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The plowing of <qex>fallows</qex> is a benefit to land.</q>
<rj><qau>Mortimer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The plowing or tilling of land, without sowing it
for a season; <as>as, summer <ex>fallow</ex>, properly conducted, has
ever been found a sure method of destroying weeds</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Be a complete summer <qex>fallow</qex>, land is rendered tender
and mellow. The <qex>fallow</qex> gives it a better tilth than can be
given by a fallow crop.</q> <rj><qau>Sinclair.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fallow crop</b></col>, <cd>the crop taken from a green
fallow.</cd> <mark>[Eng.]</mark> -- <col><b>Green fallow</b></col>,
<cd>fallow whereby land is rendered mellow and clean from weeds, by
cultivating some green crop, as turnips, potatoes, etc.</cd>
<mark>[Eng.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fallow</ent><br/
<hw>Fal"low</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Fallowed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Fallowing</conjf>.]</vmorph> <ety>[From <er>Fallow</er>,
<pos>n.</pos>]</ety> <def>To plow, harrow, and break up, as land,
without seeding, for the purpose of destroying weeds and insects, and
rendering it mellow; <as>as, it is profitable to <ex>fallow</ex> cold,
strong, clayey land</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fallow deer</ent><br/
<hw>Fal"low deer`</hw> <pr>(?)</pr>. <ety>[So called from its
<ets>fallow</ets> or pale yellow color.]</ety> <fld>(Zool.)</fld> <def>A
European species of deer (<spn>Cervus dama</spn>), much smaller than the
red deer. In summer both sexes are spotted with white. It is common in
England, where it is often domesticated in the parks.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fallowist</ent><br/
<hw>Fal"low*ist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who favors the
practice of fallowing land.</def> <mark>[R.]</mark>
<rj><au>Sinclair.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fallowness</ent><br/
<hw>Fal"low*ness</hw>, <pos>n.</pos> <def>A well or opening, through the
successive floors of a warehouse or manufactory, through which goods are
raised or lowered.</def> <mark>[U.S.]</mark>
<rj><au>Bartlett.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>fall webworm</ent><br/
<hw>fall webworm</hw>, <pos>n.</pos> <fld>(Zool.)</fld> <def>The larva
of any moth of the genus <gen>Hyphantria</gen>, which spins a web around
the foliage on which it feeds.</def><br/
[<source>PJC</source>]</p>

<p><ent>Falsary</ent><br/
<hw>Fal"sa*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>falsarius</ets>, fr. <ets>falsus</ets>. See <er>False</er>,
<pos>a.</pos>]</ety> <def>A falsifier of evidence.</def>
<mark>[Obs.]</mark> <rj><au>Sheldon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>False</ent><br/
<hw>False</hw> <pr>(?)</pr>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Falser</adjf> <pr>(?)</pr>; <pos>superl.</pos>
<adjf>Falsest</adjf>.]</amorph> <ety>[L. <ets>falsus</ets>, p. p. of
<ets>fallere</ets> to deceive; cf. OF. <ets>faus</ets>, <ets>fals</ets>,
F. <ets>faux</ets>, and AS. <ets>fals</ets> fraud. See <er>Fail</er>,
<er>Fall</er>.]</ety> <sn>1.</sn> <def>Uttering falsehood; unveracious;
given to deceit; dishnest; <as>as, a <ex>false</ex>
witness</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Not faithful or loyal, as to obligations,
allegiance, vows, etc.; untrue; treacherous; perfidious; <as>as, a
<ex>false</ex> friend, lover, or subject; <ex>false</ex> to
promises.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>I to myself was <qex>false</qex>, ere thou to me.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Not according with truth or reality; not true;
fitted or likely to deceive or disappoint; <as>as, a <ex>false</ex>
statement</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Not genuine or real; assumed or designed to deceive;
counterfeit; hypocritical; <as>as, <ex>false</ex> tears; <ex>false</ex>
modesty; <ex>false</ex> colors; <ex>false</ex> jewelry.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>False</qex> face must hide what the false heart doth
know.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Not well founded; not firm or trustworthy;
erroneous; <as>as, a <ex>false</ex> claim; a <ex>false</ex> conclusion;
a <ex>false</ex> construction in grammar.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Whose <qex>false</qex> foundation waves have swept away.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Not essential or permanent, as parts of a structure
which are temporary or supplemental.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Mus.)</fld> <def>Not in tune.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>False arch</b></col> <fld>(Arch.)</fld>, <cd>a member
having the appearance of an arch, though not of arch construction.</cd>
-- <col><b>False attic</b></col>, <cd>an architectural erection above
the main cornice, concealing a roof, but not having windows or inclosing
rooms.</cd> -- <col><b>False bearing</b></col>, <cd>any bearing which is
not directly upon a vertical support; thus, the weight carried by a
corbel has a <xex>false bearing</xex>.</cd> -- <col><b>False
cadence</b></col>, <cd>an imperfect or interrupted cadence.</cd> --
<col><b>False conception</b></col> <fld>(Med.)</fld>, <cd>an abnormal
conception in which a mole, or misshapen fleshy mass, is produced
instead of a properly organized fetus.</cd> -- <col><b>False
croup</b></col> <fld>(Med.)</fld>, <cd>a spasmodic affection of the
larynx attended with the symptoms of membranous croup, but unassociated
with the deposit of a fibrinous membrane.</cd> -- <mcol><col><b>False
door</b></col> <it>or</it> <col><b>False window</b></col></mcol>
<fld>(Arch.)</fld>, <cd>the representation of a door or window, inserted
to complete a series of doors or windows or to give symmetry.</cd> --
<col><b>False fire</b></col>, <cd>a combustible carried by vessels of
war, chiefly for signaling, but sometimes burned for the purpose of
deceiving an enemy; also, a light on shore for decoying a vessel to
destruction.</cd> -- <col><b>False galena</b></col>. <cd>See
<er>Blende</er>.</cd> -- <col><b>False imprisonment</b></col>
<fld>(Law)</fld>, <cd>the arrest and imprisonment of a person without
warrant or cause, or contrary to law; or the unlawful detaining of a
person in custody.</cd> -- <col><b>False keel</b></col>
<fld>(Naut.)</fld>, <cd>the timber below the main keel, used to serve
both as a protection and to increase the shio's lateral resistance.</cd>
-- <col><b>False key</b></col>, <cd>a picklock.</cd> -- <col><b>False
leg</b></col>. <fld>(Zool.)</fld> <cd>See <er>Proleg</er>.</cd> --
<col><b>False membrane</b></col> <fld>(Med.)</fld>, <cd>the fibrinous
deposit formed in croup and diphtheria, and resembling in appearance an
animal membrane.</cd> -- <col><b>False papers</b></col>
<fld>(Naut.)</fld>, <cd>documents carried by a ship giving false
representations respecting her cargo, destination, etc., for the purpose
of deceiving.</cd> -- <col><b>False passage</b></col>
<fld>(Surg.)</fld>, <cd>an unnatural passage leading off from a natural
canal, such as the urethra, and produced usually by the unskillful
introduction of instruments.</cd> -- <col><b>False personation</b></col>
<fld>(Law)</fld>, <cd>the intentional false assumption of the name and
personality of another.</cd> -- <col><b>False pretenses</b></col>
<fld>(Law)</fld>, <cd>false representations concerning past or present
facts and events, for the purpose of defrauding another.</cd> --
<col><b>False rail</b></col> <fld>(Naut.)</fld>, <cd>a thin piece of
timber placed on top of the head rail to strengthen it.</cd> --
<col><b>False relation</b></col> <fld>(Mus.)</fld>, <cd>a progression in
harmony, in which a certain note in a chord appears in the next chord
prefixed by a flat or sharp.</cd> -- <col><b>False return</b></col>
<fld>(Law)</fld>, <cd>an untrue return made to a process by the officer
to whom it was delivered for execution.</cd> -- <col><b>False
ribs</b></col> <fld>(Anat.)</fld>, <cd>the asternal rebs, of which there
are five pairs in man.</cd> -- <col><b>False roof</b></col>
<fld>(Arch.)</fld>, <cd>the space between the upper ceiling and the
roof.</cd> <au>Oxford Gloss.</au> -- <col><b>False token</b></col>,
<cd>a false mark or other symbol, used for fraudulent purposes.</cd> --
<col><b>False scorpion</b></col> <fld>(Zool.)</fld>, <cd>any arachnid of
the genus <gen>Chelifer</gen>. See <er>Book scorpion</er>.</cd> --
<col><b>False tack</b></col> <fld>(Naut.)</fld>, <cd>a coming up into
the wind and filling away again on the same tack.</cd> -- <col><b>False
vampire</b></col> <fld>(Zool.)</fld>, <cd>the <spn>Vampyrus
spectrum</spn> of South America, formerly erroneously supposed to have
blood-sucking habits; -- called also <altname>vampire</altname>, and
<altname>ghost vampire</altname>. The genuine blood-sucking bats belong
to the genera <gen>Desmodus</gen> and <gen>Diphylla</gen>. See
<er>Vampire</er>.</cd> -- <col><b>False window</b></col>.
<fld>(Arch.)</fld> <cd>See <cref>False door</cref>, above.</cd> --
<col><b>False wing</b></col>. <fld>(Zool.)</fld> <cd>See <er>Alula</er>,
and <cref>Bastard wing</cref>, under <er>Bastard</er>.</cd> --
<col><b>False works</b></col> <fld>(Civil Engin.)</fld>,
<cd>construction works to facilitate the erection of the main work, as
scaffolding, bridge centering, etc.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>False</ent><br/
<hw>False</hw>, <pos>adv.</pos> <def>Not truly; not honestly;
falsely.</def> <ldquo/You play me <xex>false</xex>.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>False</ent><br/
<hw>False</hw>, <pos>v. t.</pos> <ety>[L. <ets>falsare</ets> to falsify,
fr. <ets>falsus</ets>: cf. F. <ets>fausser</ets>. See <er>False</er>,
<pos>a.</pos>]</ety> <sn>1.</sn> <def>To report falsely; to
falsify.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To betray; to falsify.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>[He] hath his truthe <qex>falsed</qex> in this wise.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To mislead by want of truth; to deceive.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>In his <qex>falsed</qex> fancy.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To feign; to pretend to make.</def>
<mark>[Obs.]</mark> <ldquo/And <xex>falsed</xex> oft his blows.<rdquo/
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>False-faced</ent><br/
<hw>False"-faced`</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Hypocritical.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>False-heart</ent><br/
<hw>False"-heart`</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>False-hearted.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>False-hearted</ent><br/
<hw>False"-heart`ed</hw>, <pos>a.</pos> <def>Hollow or unsound at the
core; treacherous; deceitful; perfidious.</def> <au>Bacon.</au> --
<wordforms><wf>False"-heart`ed*ness</wf>, <pos>n.</pos> <au>Bp.
Stillingfleet.</au></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Falsehood</ent><br/
<hw>False"hood</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>False</ets> +
<ets>-hood</ets>]</ety> <sn>1.</sn> <def>Want of truth or accuracy; an
untrue assertion or representation; error; misrepresentation;
falsity.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Though it be a lie in the clock, it is but a <qex>falsehood</qex>
in the hand of the dial when pointing at a wrong hour, if rightly
following the direction of the wheel which moveth it.</q>
<rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A deliberate intentional assertion of what is known
to be untrue; a departure from moral integrity; a lie.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Treachery; deceit; perfidy;
unfaithfulness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Betrayed by <qex>falsehood</qex> of his guard.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A counterfeit; a false appearance; an
imposture.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>For his molten image is <qex>falsehood</qex>.</q> <rj><qau>Jer. x.
14.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>No <qex>falsehood</qex> can endure<br/
Touch of celestial temper.</q> <rj><qau>Milton.</qau></rj></p>

<p><syn><b>Syn.</b> -- Falsity; lie; untruth; fiction; fabrication. See
<er>Falsity</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Falsely</ent><br/
<hw>False"ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a false manner;
erroneously; not truly; perfidiously or treacherously.</def> <ldquo/O
<xex>falsely</xex>, <xex>falsely</xex> murdered.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Oppositions of science, <qex>falsely</qex> so called.</q>
<rj><qau>1 Tim. vi. 20.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Will ye steal, murder . . . and swear <qex>falsely</qex> ?</q>
<rj><qau>Jer. vii. 9.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Falseness</ent><br/
<hw>False"ness</hw>, <pos>n.</pos> <def>The state of being false;
contrariety to the fact; inaccuracy; want of integrity or uprightness;
double dealing; unfaithfulness; treachery; perfidy; <as>as, the
<ex>falseness</ex> of a report, a drawing, or a singer's notes; the
<ex>falseness</ex> of a man, or of his word.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Falser</ent><br/
<hw>Fals"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A deceiver.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Falsetto</ent><br/
<hw>Fal*set"to</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Falsettos</plw> <pr>(#)</pr>.</plu> <ety>[It. <ets>falsetto</ets>,
dim. fr. L. <ets>falsus</ets>. See <er>False</er>.]</ety> <def>A false
or artificial voice; that voice in a man which lies above his natural
voice; the male counter tenor or alto voice. See <cref>Head
voice</cref>, under <er>Voice</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Falsicrimen</ent><br/
\'d8<hw>Fal"si*cri"men</hw> <pr>(?)</pr>. <ety>[L.]</ety> <fld>(Civ.
Law)</fld> <def>The crime of falsifying.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ This term in the Roman law included not only forgery,
but every species of fraud and deceit. It never has been used in so
extensive a sense in modern common law, in which its predominant
significance is forgery, though it also includes perjury and offenses of
a like character.</note> <rj><au>Burrill. Greenleaf.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Falsifiable</ent><br/
<hw>Fal"si*fi`a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. OF.
<ets>falsifiable</ets>.]</ety> <sn>1.</sn> <def>Capable of being
falsified, counterfeited, or corrupted.</def>
<rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>able to be proven false, and therefore testable;
<as>as, most religious beliefs are not <ex>falsifiable,</ex> and are
therefor outside the scope of experimental science</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Falsification</ent><br/
<hw>Fal`si*fi*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>falsification</ets>.]</ety> <sn>1.</sn> <def>The act of falsifying,
or making false; a counterfeiting; the giving to a thing an appearance
of something which it is not.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To counterfeit the living image of king in his person exceedeth
all <qex>falsifications</qex>.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Willful misstatement or misrepresentation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Extreme necessity . . . forced him upon this bold and violent
<qex>falsification</qex> of the doctrine of the alliance.</q>
<rj><qau>Bp. Warburton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Equity)</fld> <def>The showing an item of charge in
an account to be wrong.</def> <rj><au>Story.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Falsificator</ent><br/
<hw>Fal"si*fi*ca`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>falsificateur</ets>.]</ety> <def>A falsifier.</def> <rj><au>Bp.
Morton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Falsifier</ent><br/
<hw>Fal"si*fi`er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
falsifies, or gives to a thing a deceptive appearance; a liar.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Falsify</ent><br/
<hw>Fal"si*fy</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Falsified</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Falsifying</conjf>.]</vmorph> <ety>[L. <ets>falsus</ets>
false + <ets>-ly</ets>: cf. F. <ets>falsifier</ets>. See <er>False</er>,
<pos>a.</pos>]</ety> <sn>1.</sn> <def>To make false; to represent
falsely.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The Irish bards use to forge and <qex>falsify</qex> everything as
they list, to please or displease any man.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To counterfeit; to forge; <as>as, to
<ex>falsify</ex> coin</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To prove to be false, or untrustworthy; to confute;
to disprove; to nullify; to make to appear false.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>By how much better than my word I am,<br/
By so much shall I <qex>falsify</qex> men's hope.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Jews and Pagans united all their endeavors, under Julian the
apostate, to baffle and <qex>falsify</qex> the prediction.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To violate; to break by falsehood; <as>as, to
<ex>falsify</ex> one's faith or word</as>.</def> <rj><au>Sir P.
Sidney.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To baffle or escape; <as>as, to <ex>falsify</ex> a
blow</as>.</def> <rj><au>Butler.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Law)</fld> <def>To avoid or defeat; to prove false,
as a judgment.</def> <rj><au>Blackstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Equity)</fld> <def>To show, in accounting, (an inem
of charge inserted in an account) to be wrong.</def> <rj><au>Story.
Daniell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>To make false by multilation or addition; to tamper
with; <as>as, to <ex>falsify</ex> a record or document</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Falsify</ent><br/
<hw>Fal"si*fy</hw>, <pos>v. i.</pos> <def>To tell lies; to violate the
truth.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It is absolutely and universally unlawful to lie and
<qex>falsify</qex>.</q><br/
[<source>1913 Webster</source>]</p>

<p><q>South.</q><br/
[<source>1913 Webster</source>]</p>

<p><ent>Falsism</ent><br/
<hw>Fals"ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>That which is
evidently false; an assertion or statement the falsity of which is
plainly apparent; -- opposed to <xex>truism</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Falsity</ent><br/
<hw>Fal"si*ty</hw> <pr>(?)</pr>, <pos>n.</pos>;<plu><it>pl.</it>
<plw>Falsities</plw> <pr>(#)</pr>.</plu> <ety>[L. <ets>falsitas</ets>:
cf. F. <ets>fausset<eacute/</ets>, OF. also, <ets>falsit<eacute/</ets>.
See <er>False</er>, <pos>a.</pos>]</ety> <sn>1.</sn> <def>The quality of
being false; coutrariety or want of conformity to truth.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Probability does not make any alteration, either in the truth or
<qex>falsity</qex> of things.</q> <rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is false; falsehood; a lie; a false
assertion.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Men often swallow <qex>falsities</qex> for truths.</q>
<rj><qau>Sir T. Brown.</qau></rj></p>

<p><syn><b>Syn.</b> -- Falsehood; lie; deceit.</syn> <usage> --
<er>Falsity</er>, <er>Falsehood</er>, <er>Lie</er>. <xex>Falsity</xex>
denotes the state or quality of being false. A <xex>falsehood</xex> is a
false declaration designedly made. A <xex>lie</xex> is a gross,
unblushing falsehood. The <xex>falsity</xex> of a person's assertion may
be proved by the evidence of others and thus the charge of
<xex>falsehood</xex> be fastened upon him.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Falstaff</ent><br/
<hw>Falstaff</hw> <pos>prop. n.</pos> <def><person>Sir John
Falstaff</person>, a celebrated character in Shakespeare's historical
play " Henry IV." (1st and 2d parts), and also in " The Merry Wives of
Windsor." He is a very fat, sensual, and witty old knight; a swindler,
drunkard, and good-tempered liar; and something of a coward. Falstaff
was originally called <altname>Sir John Oldcastle</altname>. The first
actor of the part was <person>John Heminge</person>.</def><br/
[<source>Century Dict. 1906</source>]</p>

<p><note><hand/ <persfn>Shakespeare</persfn> found the name of
<person>John Oldcastle</person> in the ... older play of "Henry V."; in
the Chronicle he found a <person>John Oldcastle</person>, who was page
to the <person>Duke of Norfolk</person> who plays a part in "Richard
II."; and this, according to Shakespeare, his <persfn>Falstaff</persfn>
(Oldcastle) had been in his youth. When the poet wrote his "Henry IV."
he knew not who this <persfn>Oldcastle</persfn> was, whom he had
rendered so distinct with the designation as Norfolk's page; he was a
Lord Cobham [Sir John Oldcastle, known as the good lord Cobham], who had
perished as a Lollard and Wickliffite in the persecution of the church
under Henry V. The Protestants regarded him as a holy martyr, the
Catholics as a heretic; the latter seized with eagerness this
description of the fat poltroon, and gave it out as a portrait of
<person>Lord Cobham</person>, who was indeed physically and mentally his
contrast. The family complained of this misuse of a name dear to them,
and Shakespeare declared in the epilogue to "Henry IV." that Cobham was
in his sight also a martyr, and that "this was not the man." At the same
time, he changed the name to Falstaff, but this was of little use; in
spite of the express retraction, subsequent Catholic writers on church
history still declared Falstaff to be a portrait of the heretic Cobham.
But it is a strange circumstance that even now under the name of
Falstaff another historical character is again sought for, just as if it
were impossible for such a vigorous form not to be a being of reality.
It was referred to John Fastolfe, whose cowardice is more stigmatised in
"Henry VI." than history justifies; and this too met with public blame,
although Shakespeare could have again asserted that he intended Fastolfe
as little as Cobham. <au>Gervinus, Shakespeare Commentaries (tr. by K.
E. Bunnett, [ed. 1880), p. 800.</au></note><br/
[<source>Century Dict. 1906</source>]</p>

<p><ent>Falstaffian</ent><br/
<hw>Falstaffian</hw> <pos>adj.</pos> <def>Of or pertaining to
<er><person>Falstaff</person></er>, a character in
<person>Shakespeare's</person> plays.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Falter</ent><br/
<hw>Fal"ter</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To thrash in the
chaff; also, to cleanse or sift, as barley.</def> <mark>[Prov.
Eng.]</mark> <rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Falter</ent><br/
<hw>Fal"ter</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Faltered</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Faltering</conjf>.]</vmorph> <ety>[OE. <ets>falteren</ets>,
<ets>faltren</ets>, prob. from <ets>fault</ets>. See <er>Fault</er>,
<pos>v. & n.</pos>]</ety> <sn>1.</sn> <def>To hesitate; to speak
brokenly or weakly; to stammer; <as>as, his tongue
<ex>falters</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With <qex>faltering</qex> speech and visage incomposed.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To tremble; to totter; to be unsteady.</def>
<ldquo/He found his legs <xex>falter</xex>.<rdquo/
<rj><au>Wiseman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To hesitate in purpose or action.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Ere her native king<br/
Shall <qex>falter</qex> under foul rebellion's arms.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To fail in distinctness or regularity of exercise;
-- said of the mind or of thought.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Here indeed the power of disinct conception of space and distance
<qex>falters</qex>.</q> <rj><qau>I. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Falter</ent><br/
<hw>Fal"ter</hw>, <pos>v. t.</pos> <def>To utter with hesitation, or in
a broken, trembling, or weak manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And here he <qex>faltered</qex> forth his last farewell.</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Mde me most happy, <qex>faltering</qex> <ldquo/I am
thine.<rdquo/</q> <rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 541 --></p>

<p><ent>Falter</ent><br/
<hw>Fal"ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See <er>Falter</er>,
<pos>v. i.</pos>]</ety> <def>Hesitation; trembling; feebleness; an
uncertain or broken sound; <as>as, a slight <ex>falter</ex> in her
voice</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>falter</qex> of an idle shepherd's pipe.</q>
<rj><qau>Lowell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Faltering</ent><br/
<hw>Fal"ter*ing</hw>, <pos>a.</pos> <def>Hesitating; trembling.</def>
<ldquo/With <xex>faltering</xex> speech.<rdquo/ <au>Milton.</au> --
<def2><pos>n.</pos> <def>Falter; halting; hesitation.</def></def2> --
<wordforms><wf>Fal"ter*ing*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Faluns</ent><br/
\'d8<hw>Fa`luns"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<fld>(Geol.)</fld> <def>A series of strata, of the Middle Tertiary
period, of France, abounding in shells, and used by Lyell as the type of
his Miocene subdivision.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Falwe</ent><br/
<hw>Fal"we</hw> <pr>(?)</pr>, <pos>a. & n.</pos> <def>Fallow.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Falx</ent><br/
\'d8<hw>Falx</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., a sickle.]</ety>
<fld>(Anat.)</fld> <def>A curved fold or process of the <partof>dura
mater</partof> or the peritoneum; esp., one of the partitionlike folds
of the dura mater which extend into the great fissures of the
brain.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Famble</ent><br/
<hw>Fam"ble</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[OE.
<ets>falmelen</ets>; cf. SW. <ets>famla</ets> to grope, Dan.
<ets>famle</ets> to grope, falter, hesitate, Icel. <ets>f<amac/lma</ets>
to grope. Cf. <er>Famble</er>.]</ety> <def>To stammer.</def>
<mark>[Obs.]</mark> <rj><au>Nares.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Famble</ent><br/
<hw>Fam"ble</hw>, <pos>n.</pos> <ety>[Cf. <er>Famble</er>,
<pos>v.</pos>]</ety> <def>A hand.</def> <mark>[Slang & Obs.]</mark>
<ldquo/We clap our <xex>fambles</xex>.<rdquo/ <rj><au>Beau. &
Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fame</ent><br/
<hw>Fame</hw> <pr>(f<amac/m)</pr>, <pos>n.</pos> <ety>[OF.
<ets>fame</ets>, L. <ets>fama</ets>, fr. <ets>fari</ets> to speak, akin
to Gr. <?/<?/<?/<?/ a saying, report, <grk>fa`nai</grk> to speak. See
<er>Ban</er>, and cf. <er>Fable</er>, <er>Fate</er>, <er>Euphony</er>,
<er>Blame</er>.]</ety> <sn>1.</sn> <def>Public report or
rumor.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>fame</qex> thereof was heard in Pharaoh's house.</q>
<rj><qau>Gen. xlv. 16.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Report or opinion generally diffused; renown; public
estimation; celebrity, either favorable or unfavorable; <as>as, the
<ex>fame</ex> of <persfn>Washington</persfn></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I find thou art no less than <qex>fame</qex> hath bruited.</q>
<rj><qau>Shak.</qau></rj></p>

<p><syn><b>Syn.</b> -- Notoriety; celebrity; renown;
reputation.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fame</ent><br/
<hw>Fame</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Famed</conjf> <pr>(?)</pr>,; <pos>p. pr. & vb. n.</pos>
<conjf>Faming</conjf>.]</vmorph> <sn>1.</sn> <def>To report widely or
honorably.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The field where thou art <qex>famed</qex><br/
To have wrought such wonders.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To make famous or renowned.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Those Hesperian gardens <qex>famed</qex> of old.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fameless</ent><br/
<hw>Fame"less</hw>, <pos>a.</pos> <def>Without fame or renown.</def> --
<wordforms><wf>Fame"less*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>familial</ent><br/
<hw>familial</hw> <pos>adj.</pos> <sn>1.</sn> <def>relating to or having
the characteristics of a family; <as>as, children of the same
<ex>familial</ex> background; <ex>familial</ex>
aggregation</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>tending to occur among members of a family, usually
by hereditary transmission; <as><ex>familial</ex> traits</as>.</def><br/
<syn><b>Syn. --</b> genetic, hereditary, inherited, transmitted,
transmissible.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Familiar</ent><br/
<hw>Fa*mil`iar</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OE.
<ets>familer</ets>, <ets>familier</ets>, F. <ets>familier</ets>, fr. L.
<ets>familiaris</ets>, fr. <ets>familia</ets> family. See
<er>Family</er>.]</ety> <sn>1.</sn> <def>Of or pertaining to a family;
domestic.</def> <ldquo/<xex>Familiar</xex> feuds.<rdquo/
<rj><au>Byron.</au></rj><br/
<syn><b>Syn. --</b> familial.</syn><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Closely acquainted or intimate, as a friend or
companion; well versed in, as any subject of study; <as>as,
<ex>familiar</ex> with the Scriptures</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Characterized by, or exhibiting, the manner of an
intimate friend; not formal; unconstrained; easy; accessible.</def>
<ldquo/In loose, <xex>familiar</xex> strains.<rdquo/
<rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Be thou <qex>familiar</qex>, but by no means vulgar.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Well known; well understood; common; frequent;
<as>as, a <ex>familiar</ex> illustration</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That war, or peace, or both at once, may be<br/
As things acquainted and <qex>familiar</qex> to us.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>There is nothing more <qex>familiar</qex> than this.</q>
<rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Improperly acquainted; wrongly intimate.</def>
<rj><au>Camden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Familiar spirit</b></col>, <cd>a demon or evil spirit
supposed to attend at call.</cd> <rj><au>1 Sam. xxviii. 3,
7-9.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Familiar</ent><br/
<hw>Fa*mil"iar</hw>, <pos>n.</pos> <sn>1.</sn> <def>An intimate; a
companion.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>All my <qex>familiars</qex> watched for my halting.</q>
<rj><qau>Jer. xx. 10.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An attendant demon or evil spirit.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Court of Inquisition)</fld> <def>A confidential
officer employed in the service of the tribunal, especially in
apprehending and imprisoning the accused.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>familiarise</ent><br/
<hw>familiarise</hw> <pos>v. t.</pos> <def>to make familiar or
acquainted; same as <er>familiarize</er>.</def> <mark>[chiefly
Brit.]</mark><br/
<syn><b>Syn. --</b> familiarize, acquaint.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Familiarity</ent><br/
<hw>Fa*mil`iar"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Familiarities</plw> <pr>(#)</pr>.</plu> <ety>[OE.
<ets>familarite</ets>, F. <ets>familiarit<eacute/</ets>fr. L.
<ets>faniliaritas</ets>. See <er>Familiar</er>.]</ety> <sn>1.</sn>
<def>The state of being familiar; intimate and frequent converse, or
association; unconstrained intercourse; freedom from ceremony and
constraint; intimacy; <as>as, to live in remarkable
<ex>familiarity</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Anything said or done by one person to another
unceremoniously and without constraint; esp., in the <pluf>pl.</pluf>,
such actions and words as propriety and courtesy do not warrant;
liberties.</def></p>

<p><syn><b>Syn.</b> -- Acquaintance; fellowship; affability; intimacy.
See <er>Acquaintance</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Familiarization</ent><br/
<hw>Fa*mil`iar*i*za"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act
or process of making familiar; the result of becoming familiar; <as>as,
<ex>familiarization</ex> with scenes of blood</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Familiarize</ent><br/
<hw>Fa*mil"iar*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Familiarized</conjf>
<pr>(?)</pr>; <pos>p. pr. & vb. n.</pos> <conjf>Familiarizing</conjf>
<pr>(?)</pr>.]</vmorph> <ety>[Cf. F. <ets>familiariser</ets>.]</ety>
<sn>1.</sn> <def>To make familiar or intimate; to habituate; to
accustom; to make well known by practice or converse; <as>as, to
<ex>familiarize</ex> one's self with scenes of distress; we
<ex>familiarized</ex> ourselves with the new
surroundings</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To make acquainted, or skilled, by practice or
study; <as>as, to <ex>familiarize</ex> one's self with a business, a
book, or a science</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>familiarized</ent><br/
<hw>familiarized</hw> <pos>adj.</pos> <def>having become
familiar.</def><br/
<syn><b>Syn. --</b> adjusted, acquainted.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>familiarizing</ent><br/
<hw>familiarizing</hw> <pos>adj.</pos> <def>serving to
familiarize.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Familiarly</ent><br/
<hw>Fa"mil"iar*ly</hw>, <pos>adv.</pos> <def>In a familiar
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Familiarness</ent><br/
<hw>Fa*mil"iar*ness</hw>, <pos>n.</pos> <def>Familiarity.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Familiary</ent><br/
<hw>Fa*mil"ia*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>familiaris</ets>. See <er>Familiar</er>.]</ety> <def>Of or
pertaining to a family or household; domestic.</def> <mark>[Obs.]</mark>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Familism</ent><br/
<hw>Fam"i*lism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The tenets of the
Familists.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Familist</ent><br/
<hw>Fam"i*list</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<er>Family</er>.]</ety> <fld>(Eccl. Hist.)</fld> <def>One of a fanatical
Antinomian sect originating in Holland, and existing in England about
1580, called the <membof>Family of Love</membof>, who held that religion
consists wholly in love.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Familistery</ent><br/
<hw>Fam"i*lis*ter*y</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Familisteries</plw> <pr>(<?/)</pr>.</plu> <ety>[F.
<ets>familist<egrave/re</ets>.]</ety> <def>A community in which many
persons unite as in one family, and are regulated by certain communistic
laws and customs.</def></p>

<p><ent>Familistical</ent><br/
<ent>Familistic</ent><br/
<mhw>{ <hw>Fam`i*listic</hw> <pr>(?)</pr>, <hw>Fam`i*lis"tic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <def>Pertaining to Familists.</def>
<rj><au>Baxter.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Family</ent><br/
<hw>Fam"i*ly</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Families</plw> <pr>(#)</pr>.</plu> <ety>[L. <ets>familia</ets>, fr.
<ets>famulus</ets> servant; akin to Oscan <ets>famel</ets> servant, cf.
<ets>faamat</ets> he dwells, Skr. <ets>dh<amac/man</ets> house, fr.
<ets>dh<amac/</ets>to set, make, do: cf. F. <ets>famille</ets>. Cf.
<er>Do</er>, <pos>v. t.</pos>, <er>Doom</er>, <er>Fact</er>,
<er>Feat</er>.]</ety> <sn>1.</sn> <def>The collective body of persons
who live in one house, and under one head or manager; a household,
including parents, children, and servants, and, as the case may be,
lodgers or boarders.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The group comprising a husband and wife and their
dependent children, constituting a fundamental unit in the organization
of society.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The welfare of the <qex>family</qex> underlies the welfare of
society.</q> <rj><qau>H. Spencer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Those who descend from one common progenitor; a
tribe, clan, or race; kindred; house; <as>as, the human <ex>family</ex>;
the <ex>family</ex> of Abraham; the father of a
<ex>family</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Go ! and pretend your <qex>family</qex> is young.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Course of descent; genealogy; line of ancestors;
lineage.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Honorable descent; noble or respectable stock;
<as>as, a man of <ex>family</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>A group of kindred or closely related individuals;
<as>as, a <ex>family</ex> of languages; a <ex>family</ex> of States; the
chlorine <ex>family</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Biol.)</fld> <def>A group of organisms, either
animal or vegetable, related by certain points of resemblance in
structure or development, more comprehensive than a genus, because it is
usually based on fewer or less pronounced points of likeness. In Zoology
a family is less comprehesive than an order; in botany it is often
considered the same thing as an order.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Family circle</b></col>. <cd>See under
<er>Circle</er>.</cd> -- <col><b>Family man</b></col>. <sd>(a)</sd>
<cd>A man who has a family; esp., one who has a wife and children living
with him and dependent upon him.</cd> <sd>(b)</sd> <cd>A man of domestic
habits.</cd> <ldquo/The Jews are generally, when married, most exemplary
<xex>family men</xex>.<rdquo/ <au>Mayhew.</au> -- <mcol><col><b>Family
of curves</b></col> <it>or</it> <col><b>Family of
surfaces</b></col></mcol> <fld>(Geom.)</fld>, <cd>a group of curves or
surfaces derived from a single equation.</cd> -- <col><b>In a family
way</b></col>, <cd>like one belonging to the family.</cd> <ldquo/Why
don't we ask him and his ladies to come over <xex>in a family way</xex>,
and dine with some other plain country gentlefolks?<rdquo/
<au>Thackeray.</au> -- <col><b>In the family way</b></col>,
<cd>pregnant.</cd> <mark>[Colloq. euphemism]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Famine</ent><br/
<hw>Fam"ine</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>famine</ets>,
fr. L. <ets>fames</ets> hunger; cf. Gr. <?/<?/<?/<?/<?/ want, need, Skr.
<ets>h<amac/ni</ets> loss, lack, <ets>h<amac/</ets> to leave.]</ety>
<def>General scarcity of food; dearth; a want of provisions;
destitution.</def> <ldquo/Worn with <xex>famine</xex>.<rdquo/
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>There was a <qex>famine</qex> in the land.</q> <rj><qau>Gen. xxvi.
1.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Famine fever</b></col> <fld>(Med.)</fld>, <cd>typhus
fever.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Famish</ent><br/
<hw>Fam"ish</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Famished</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Famishing</conjf>.]</vmorph> <ety>[OE. <ets>famen</ets>;
cf. OF. <ets>afamer</ets>, L. <ets>fames</ets>. See <er>Famine</er>, and
cf. <er>Affamish</er>.]</ety> <sn>1.</sn> <def>To starve, kill, or
destroy with hunger.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To exhaust the strength or endurance of, by hunger;
to distress with hanger.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And when all the land of Egypt was <qex>famished</qex>, the people
cried to Pharaoh for bread.</q> <rj><qau>Cen. xli. 55.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The pains of <qex>famished</qex> Tantalus he'll feel.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To kill, or to cause to suffer extremity, by
deprivation or denial of anything necessary.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And <qex>famish</qex> him of breath, if not of bread.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To force or constrain by famine.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He had <qex>famished</qex> Paris into a surrender.</q>
<rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Famish</ent><br/
<hw>Fam"ish</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To die of hunger; to
starve.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To suffer extreme hunger or thirst, so as to be
exhausted in strength, or to come near to perish.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>You are all resolved rather to die than to <qex>famish</qex>?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To suffer extremity from deprivation of anything
essential or necessary.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The Lord will not suffer the soul of the righteous to
<qex>famish</qex>.</q> <rj><qau>Prov. x. 3.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Famishment</ent><br/
<hw>Fam"ish*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>State of being
famished.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Famosity</ent><br/
<hw>Fa*mos"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>famositas</ets> infamy: cf. F. <ets>famosit<eacute/</ets>. See
<er>Famous</er>.]</ety> <def>The state or quality of being famous.</def>
<mark>[Obs.]</mark> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Famous</ent><br/
<hw>Fa"mous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>famosus</ets>, fr. <ets>fama</ets> fame: cf. F. <ets>fameux</ets>.
See <er>Fame</er>.]</ety> <def>Celebrated in fame or public report;
renowned; mach talked of; distinguished in story; -- used in either a
good or a bad sense, chiefly the former; often followed by
<xex>for</xex>; <as>as, <ex>famous</ex> for erudition, for eloquence,
for military skill; a <ex>famous</ex> pirate.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Famous</qex> for a scolding tongue.</q>
<rj><qau>Shak.</qau></rj></p>

<p><syn><b>Syn.</b> -- Noted; remarkable; signal; conspicuous;
celebrated; renowned; illustrious; eminent; transcendent;
excellent.</syn> <usage> -- <er>Famous</er>, <er>Renowned</er>,
<er>Illustrious</er>. <xex>Famous</xex> is applied to a person or thing
widely spoken of as extraordinary; <xex>renowned</xex> is applied to
those who are named again and again with honor; <xex>illustrious</xex>,
to those who have dazzled the world by the splendor of their deeds or
their virtues. See <er>Distinguished</er>.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Famoused</ent><br/
<hw>Fa"moused</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Renowned.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Famously</ent><br/
<hw>Fa"mous*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a famous
manner; in a distinguished degree; greatly; splendidly.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Then this land was <qex>famously</qex> enriched<br/
With politic grave counsel.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Famousness</ent><br/
<hw>Fa"mous*ness</hw>, <pos>n.</pos> <def>The state of being
famous.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Famular</ent><br/
<hw>Fam"u*lar</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. L.
<ets>famularis</ets> of servants.]</ety> <def>Domestic; familiar.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Famulate</ent><br/
<hw>Fam"u*late</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[L.
<ets>famulatus</ets>, p. p. of <ets>famulari</ets> to serve, fr.
<ets>famulus</ets> servant.]</ety> <def>To serve.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Famulist</ent><br/
<hw>Fam"u*list</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>famulus</ets> servant.]</ety> <def>A collegian of inferior rank or
position, corresponding to the <altname>sizar</altname> at
Cambridge.</def> <mark>[Oxford Univ., Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fan</ent><br/
<hw>Fan</hw> <pr>(f<acr/n)</pr>, <pos>n.</pos> <ety>[AS.
<ets>fann</ets>, fr. L. <ets>vannus</ets> fan, van for winnowing grain;
cf. F. <ets>van</ets>. Cf. <er>Van</er> a winnowing machine,
<er>Winnow</er>.]</ety> <sn>1.</sn> <def>An instrument used for
producing artificial currents of air, by the wafting or revolving motion
of a broad surface</def>; as: <sd>(a)</sd> <def>An instrument for
cooling the person, made of feathers, paper, silk, etc., and often
mounted on sticks all turning about the same pivot, so as when opened to
radiate from the center and assume the figure of a section of a
circle.</def> <sd>(b)</sd> <fld>(Mach.)</fld> <def>Any revolving vane or
vanes used for producing currents of air, in winnowing grain, blowing a
fire, ventilation, etc., or for checking rapid motion by the resistance
of the air; a fan blower; a fan wheel.</def> <sd>(c)</sd> <def>An
instrument for winnowing grain, by moving which the grain is tossed and
agitated, and the chaff is separated and blown away.</def> <sd>(d)</sd>
<def>Something in the form of a fan when spread, as a peacock's tail, a
window, etc.</def> <sd>(e)</sd> <def>A small vane or sail, used to keep
the large sails of a smock windmill always in the direction of the
wind.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Clean provender, which hath been winnowed with the shovel and with
the <qex>fan</qex>.</q> <rj><qau>Is. xxx. 24.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which produces effects analogous to those of a
fan, as in exciting a flame, etc.; that which inflames, heightens, or
strengthens; <as>as, it served as a <ex>fan</ex> to the flame of his
passion</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A quintain; -- from its form.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fan blower</b></col>, <cd>a wheel with vanes fixed on a
rotating shaft inclosed in a case or chamber, to create a blast of air
(<xex>fan blast</xex>) for forge purposes, or a current for draft and
ventilation; a fanner.</cd> -- <col><b>Fan cricket</b></col>
<fld>(Zool.)</fld>, <cd>a mole cricket.</cd> -- <col><b>Fan
light</b></col> <fld>(Arch.)</fld>, <cd>a window over a door; -- so
called from the semicircular form and radiating sash bars of those
windows which are set in the circular heads of arched doorways.</cd> --
<col><b>Fan shell</b></col> <fld>(Zool.)</fld>, <cd>any shell of the
family <fam>Pectinid<ae/</fam>. See <er>Scallop</er>, <pos>n.</pos>,
1.</cd> -- <col><b>Fan tracery</b></col> <fld>(Arch.)</fld>, <cd>the
decorative tracery on the surface of fan vaulting.</cd> -- <col><b>Fan
vaulting</b></col> <fld>(Arch.)</fld>, <cd>an elaborate system of
vaulting, in which the ribs diverge somewhat like the rays of a fan, as
in Henry VII.'s chapel in Westminster Abbey. It is peculiar to English
Gothic.</cd> -- <col><b>Fan wheel</b></col>, <cd>the wheel of a fan
blower.</cd> -- <col><b>Fan window</b></col>. <cd>Same as <cref>Fan
light</cref> (above).</cd> -- <col><b>electric fan</b></col>. <cd>a fan
having revolving blades for propelling air, powered by an electric
motor.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fan</ent><br/
<hw>Fan</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Fanned</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Fanning</conjf> <pr>(?)</pr>.]</vmorph> <ety>[Cf. OF.
<ets>vanner</ets>, L. <ets>vannere</ets>. See <er>Fan</er>,
<pos>n.</pos>, <er>Van</er> a winnowing machine.]</ety> <sn>1.</sn>
<def>To move as with a fan.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The air . . . <qex>fanned</qex> with unnumbered plumes.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To cool and refresh, by moving the air with a fan;
to blow the air on the face of with a fan.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To ventilate; to blow on; to affect by air put in
motion.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Calm as the breath which <qex>fans</qex> our eastern groves.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To winnow; to separate chaff from, and drive it away
by a current of air; <as>as, to <ex>fan</ex> wheat</as>.</def>
<rj><au>Jer. li. 2.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To excite or stir up to activity, as a fan excites a
flame; to stimulate; <as>as, this conduct <ex>fanned</ex> the excitement
of the populace</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Fanning machine</b></col>, <it>or</it>
<col><b>Fanning mill</b></col></mcol>, <cd>a machine for separating seed
from chaff, etc., by a blast of air; a fanner.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fanal</ent><br/
\'d8<hw>Fa`nal"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety> <def>A
lighthouse, or the apparatus placed in it for giving light.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fanatic</ent><br/
<hw>Fa*nat"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>fanaticus</ets> inspired by divinity, enthusiastic, frantic, fr.
<ets>fanum</ets> fane: cf. F. <ets>fanatique</ets>. See
<er>Fane</er>.]</ety> <def>Pertaining to, or indicating, fanaticism;
extravagant in opinions; ultra; unreasonable; excessively enthusiastic,
especially on religious subjects; <as>as, <ex>fanatic</ex> zeal;
<ex>fanatic</ex> notions.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>But Faith, <qex>fanatic</qex> Faith, once wedded fast<br/
To some dear falsehood, hugs it to the last.</q> <rj><qau>T.
Moore.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fanatic</ent><br/
<hw>Fa*nat"ic</hw>, <pos>n.</pos> <def>A person affected by excessive
enthusiasm, particularly on religious subjects; one who indulges wild
and extravagant notions of religion.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There is a new word, coined within few months, called
<qex>fanatics</qex>, which, by the close stickling thereof, seemeth well
cut out and proportioned to signify what is meant thereby, even the
sectaries of our age.</q> <rj><qau>Fuller (1660).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Fanatics</qex> are governed rather by imagination than by
judgment.</q> <rj><qau>Stowe.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fanatical</ent><br/
<hw>Fa*nat"ic*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Characteristic
of, or relating to, fanaticism; fanatic.</def>
-<wordforms><wf>Fa*nat"ic*al*ly</wf>, <pos>adv.</pos> --
<wf>Fa*nat"ic*al*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fanaticism</ent><br/
<hw>Fa*nat"i*cism</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf.
<er>Fanatism</er>.]</ety> <def>Excessive enthusiasm, unreasoning zeal,
or wild and extravagant notions, on any subject, especially religion,
politics or ideology; religious frenzy.</def></p>

<p><syn><b>Syn.</b> -- See <er>Superstition</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fanaticize</ent><br/
<hw>Fa*nat"i*cize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Fanaticized</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Fanaticizing</conjf> <pr>(?)</pr>.]</vmorph> <def>To
cause to become a fanatic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fanatism</ent><br/
<hw>Fan"a*tism</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>fanatisme</ets>. Cf. <er>Fanaticism</er>.]</ety>
<def>Fanaticism.</def> <mark>[R.]</mark> <rj><au>Gibbon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fancied</ent><br/
<hw>Fan"cied</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From <er>Fancy</er>,
<pos>v. t.</pos>]</ety> <def>Formed or conceived by the fancy; unreal;
<as>as, a <ex>fancied</ex> wrong</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fancier</ent><br/
<hw>Fan"ci*er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who
is governed by fancy.</def> <ldquo/Not reasoners, but
<xex>fanciers</xex>.<rdquo/ <rj><au>Macaulay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who fancies or has a special liking for, or
interest in, a particular object or class or objects; hence, one who
breeds and keeps for sale birds and animals; <as>as, bird
<ex>fancier</ex>, dog <ex>fancier</ex>, etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fanciful</ent><br/
<hw>Fan"ci*ful</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Full of
fancy; guided by fancy, rather than by reason and experience; whimsical;
<as>as, a <ex>fanciful</ex> man forms visionary projects</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Conceived in the fancy; not consistent with facts or
reason; abounding in ideal qualities or figures; <as>as, a
<ex>fanciful</ex> scheme; a <ex>fanciful</ex> theory.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Curiously shaped or constructed; <as>as, she wore a
<ex>fanciful</ex> headdress</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Gather up all <qex>fancifullest</qex> shells.</q>
<rj><qau>Keats.</qau></rj></p>

<p><syn><b>Syn.</b> -- Imaginative; ideal; visionary; capricious;
chimerical; whimsical; fantastical; wild.</syn> <usage> --
<er>Fanciful</er>, <er>Fantastical</er>, <er>Visionary</er>. We speak of
that as <xex>fanciful</xex> which is irregular in taste and judgment; we
speak of it as <xex>fantastical</xex> when it becomes grotesque and
extravagant as well as irregular; we speak of it as <xex>visionary</xex>
when it is wholly unfounded in the nature of things. <xex>Fanciful</xex>
notions are the product of a heated fancy, without any tems are made up
of oddly assorted fancies, aften of the most whimsical kind;
<xex>visionary</xex> expectations are those which can never be realized
in fact.</usage></p>

<p>-- <wordforms><wf>Fan"ci*ful*ly</wf>, <pos>adv.</pos>
-<wf>Fan"ci*ful*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 542 --></p>

<p><ent>Fanciless</ent><br/
<hw>Fan"ci*less</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having no fancy;
without ideas or imagination.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>A pert or bluff important wight,<br/
Whose brain is <qex>fanciless</qex>, whose blood is white.</q>
<rj><qau>Armstrong.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fancy</ent><br/
<hw>Fan"cy</hw> <pr>(f<acr/n"s<ycr/)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Fancies</plw> <pr>(#)</pr>.</plu> <ety>[Contr.
fr. <ets>fantasy</ets>, OF. <ets>fantasie</ets>, <ets>fantaisie</ets>,
F. <ets>fantaisie</ets>, L. <ets>phantasia</ets>, fr. Gr.
<?/<?/<?/<?/<?/<?/<?/<?/ appearance, imagination, the power of
perception and presentation in the mind, fr. <?/<?/<?/<?/<?/<?/<?/<?/ to
make visible, to place before one's mind, fr. <?/<?/<?/<?/<?/<?/<?/ to
show; akin to <?/<?/<?/<?/, <?/<?/<?/, light, Skr. <ets>bh<amac/</ets>to
shine. Cf. <er>Fantasy</er>, <er>Fantasia</er>, <er>Epiphany</er>,
<er>Phantom</er>.]</ety> <sn>1.</sn> <def>The faculty by which the mind
forms an image or a representation of anything perceived before; the
power of combining and modifying such objects into new pictures or
images; the power of readily and happily creating and recalling such
objects for the purpose of amusement, wit, or embellishment;
imagination.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In the soul<br/
Are many lesser faculties, that serve<br/
Reason as chief. Among these <qex>fancy</qex> next<br/
Her office holds.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An image or representation of anything formed in the
mind; conception; thought; idea; conceit.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>How now, my lord ! why do you keep alone,<br/
Of sorriest <qex>fancies</qex> your companoins making ?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>An opinion or notion formed without much reflection;
caprice; whim; impression.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I have always had a <qex>fancy</qex> that learning might be made a
play and recreation to children.</q> <rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Inclination; liking, formed by caprice rather than
reason; <as>as, to strike one's <ex>fancy</ex></as>; hence, the object
of inclination or liking.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To fit your fancies to your father's will.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>That which pleases or entertains the taste or
caprice without much use or value.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>London pride is a pretty <qex>fancy</qex> for borders.</q>
<rj><qau>Mortimer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>A sort of love song or light impromptu ballad.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>The fancy</b></col>, <cd>all of a class who exhibit and
cultivate any peculiar taste or fancy; hence, especially, sporting
characters taken collectively, or any specific class of them, as
jockeys, gamblers, prize fighters, etc.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><q>At a great book sale in London, which had congregated all <qex>the
fancy</qex>.</q> <rj><qau>De Quincey.</qau></rj></p>

<p><syn><b>Syn.</b> -- Imagination; conceit; taste; humor; inclination;
whim; liking. See <er>Imagination</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fancy</ent><br/
<hw>Fan"cy</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Fancied</conjf> <pr>(?)</pr>, <pos>p. pr. & vb. n.</pos>
<conjf>Fancying</conjf> <pr>(<?/)</pr>.]</vmorph> <sn>1.</sn> <def>To
figure to one's self; to believe or imagine something without
proof.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If our search has reached no farther than simile and metaphor, we
rather <qex>fancy</qex> than know.</q> <rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To love.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fancy</ent><br/
<hw>Fan"cy</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To form a conception
of; to portray in the mind; to imagine.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He whom I <qex>fancy</qex>, but can ne'er express.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To have a fancy for; to like; to be pleased with,
particularly on account of external appearance or manners.</def>
<ldquo/We <xex>fancy</xex> not the cardinal.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To believe without sufficient evidence; to imagine
(something which is unreal).</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He <qex>fancied</qex> he was welcome, because those arounde him
were his kinsmen.</q> <rj><qau>Thackeray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fancy</ent><br/
<hw>Fan"cy</hw>, <pos>a.</pos> <sn>1.</sn> <def>Adapted to please the
fancy or taste, especially when of high quality or unusually appealing;
ornamental; <as>as, <ex>fancy</ex> goods; <ex>fancy</ex>
clothes</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Extravagant; above real value.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This anxiety never degenerated into a monomania, like that which
led his [Frederick the Great's] father to pay <qex>fancy</qex> prices
for giants.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fancy ball</b></col>, <cd>a ball in which porsons appear
in fanciful dresses in imitation of the costumes of different persons
and nations.</cd> -- <col><b>Fancy fair</b></col>, <cd>a fair at which
articles of fancy and ornament are sold, generally for some charitable
purpose.</cd> -- <col><b>Fancy goods</b></col>, <cd>fabrics of various
colors, patterns, etc., as ribbons, silks, laces, etc., in distinction
from those of a simple or plain color or make.</cd> -- <col><b>Fancy
line</b></col> <fld>(Naut.)</fld>, <cd>a line rove through a block at
the jaws of a gaff; -- used to haul it down.</cd> -- <col><b>Fancy
roller</b></col> <fld>(Carding Machine)</fld>, <cd>a clothed cylinder
(usually having straight teeth) in front of the doffer.</cd> --
<col><b>Fancy stocks</b></col>, <cd>a species of stocks which afford
great opportunity for stock gambling, since they have no intrinsic
value, and the fluctuations in their prices are artificial.</cd> --
<col><b>Fancy store</b></col>, <cd>one where articles of fancy and
ornament are sold.</cd> -- <col><b>Fancy woods</b></col>, <cd>the more
rare and expensive furniture woods, as mahogany, satinwood, rosewood,
etc.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fancy-free</ent><br/
<hw>Fan"cy-free`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Free from the
power of love.</def> <ldquo/In maiden meditation,
<xex>fancy-free</xex>.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fancymonger</ent><br/
<hw>Fan"cy*mon`ger</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A lovemonger; a
whimsical lover.</def> <mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fancy-sick</ent><br/
<hw>Fan"cy-sick`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Love-sick.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fancywork</ent><br/
<hw>Fan"cy*work`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Ornamental work
with a needle or hook, as embroidery, crocheting, netting,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fand</ent><br/
<hw>Fand</hw> <pr>(?)</pr>, <mark>obs.</mark> <def><pos>imp.</pos> of
<er>Find</er>.</def> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fandango</ent><br/
<hw>Fan*dan"go</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Fandangoes</plw> <pr>(#)</pr>.</plu> <ety>[Sp. A name brought,
together with the dance, from the West Indies to Spain.]</ety>
<sn>1.</sn> <def>A lively dance, in 3-8 or 6-8 time, much practiced in
Spain and Spanish America. Also, the tune to which it is
danced.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A ball or general dance, as in Mexico.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fane</ent><br/
<hw>Fane</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>fanum</ets> a
place dedicated to some deity, a sanctuary, fr. <ets>fari</ets> to
speak. See <er>Fame</er>.]</ety> <def>A temple; a place consecrated to
religion; a church.</def> <mark>[Poet.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Such to this British Isle, her Christian <qex>fanes</qex>.</q>
<rj><qau>Wordsworth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fane</ent><br/
<hw>Fane</hw>, <pos>n.</pos> <ety>[See <er>Vane</er>.]</ety> <def>A
weathercock.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fanega</ent><br/
\'d8<hw>Fa*ne"ga</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sp.]</ety>
<def>A dry measure in Spain and Spanish America, varying from 1<?/ to
2<?/ bushels; also, a measure of land.</def> <rj><au>De
Colange.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fanfare</ent><br/
<hw>Fan"fare`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. Cf.
<er>Fanfaron</er>.]</ety> <def>A flourish of trumpets, as in coming into
the lists, etc.; also, a short and lively air performed on hunting horns
during the chase.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>fanfare</qex> announcing the arrival of the various
Christian princes.</q> <rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fanfaron</ent><br/
\'d8<hw>Fan"fa*ron</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr. Sp.
<ets>fanfarron</ets>; cf. It. <ets>fanfano</ets>, and OSp.
<ets>fanfa</ets> swaggering, boasting, also Ar. <ets>farf<amac/r</ets>
talkative.]</ety> <def>A bully; a hector; a swaggerer; an empty
boaster.</def> <mark>[R.]</mark> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fanfaronade</ent><br/
<hw>Fan*far`on*ade"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>fanfaronnade</ets>, fr. Sp. <ets>fanfarronada</ets>. See
<er>Fanfaron</er>.]</ety> <def>A swaggering; vain boasting; ostentation;
a bluster.</def> <rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fanfoot</ent><br/
<hw>Fan"foot`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<sd>(a)</sd> <def>A species of gecko having the toes expanded into large
lobes for adhesion. The Egyptian fanfoot (<spn>Phyodactylus gecko</spn>)
is believed, by the natives, to have venomous toes.</def> <sd>(b)</sd>
<def>Any moth of the genus <gen>Polypogon</gen>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fang</ent><br/
<hw>Fang</hw> <pr>(f<acr/ng)</pr>, <pos>v. t.</pos> <ety>[OE.
<ets>fangen</ets>, <ets>fongen</ets>, <ets>fon</ets> (<it>g</it> orig.
only in p. p. and imp. tense), AS. <ets>f<omac/n</ets>; akin to D.
<ets>vangen</ets>, OHG. <ets>f<amac/han</ets>, G. <ets>fahen</ets>,
<ets>fangen</ets>, Icel. <ets>f<amac/</ets>, Sw. <ets>f<aring/</ets>,
<ets>f<aring/nga</ets>, Dan. <ets>fange</ets>, <ets>faae</ets>, Goth.
<ets>fahan</ets>, and prob. to E. <ets>fair</ets>, <ets>peace</ets>,
<ets>pact</ets>. Cf. <er>Fair</er>, <pos>a.</pos>]</ety> <sn>1.</sn>
<def>To catch; to seize, as with the teeth; to lay hold of; to gripe; to
clutch.</def> <mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He's in the law's clutches; you see he's <qex>fanged</qex>.</q>
<rj><qau>J. Webster.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To enable to catch or tear; to furnish with
fangs.</def> <ldquo/Chariots <xex>fanged</xex> with scythes.<rdquo/
<rj><au>Philips.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fang</ent><br/
<hw>Fang</hw>, <pos>n.</pos> <ety>[From <er>Fang</er>, <pos>v. t.</pos>;
cf. AS. <ets>fang</ets> a taking, booty, G. <ets>fang</ets>.]</ety>
<sn>1.</sn> <fld>(Zool.)</fld> <def>The tusk of an animal, by which the
prey is seized and held or torn; a long pointed tooth; esp., one of the
usually erectile, venomous teeth of serpents. Also, one of the falcers
of a spider.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Since I am a dog, beware my <qex>fangs</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Any shoot or other thing by which hold is
taken.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The protuberant <qex>fangs</qex> of the yucca.</q>
<rj><qau>Evelyn.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Anat.)</fld> <def>The root, or one of the branches
of the root, of a tooth. See <er>Tooth</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Mining)</fld> <def>A niche in the side of an adit
or shaft, for an air course.</def> <rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Mech.)</fld> <def>A projecting tooth or prong, as
in a part of a lock, or the plate of a belt clamp, or the end of a tool,
as a chisel, where it enters the handle.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Naut.)</fld> <sd>(a)</sd> <def>The valve of a pump
box.</def> <sd>(b)</sd> <def>A bend or loop of a rope.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>In a fang</b></col>, <cd>fast entangled.</cd> --
<col><b>To lose the fang</b></col>, <cd>said of a pump when the water
has gone out</cd>; hence: <col><b>To fang a pump</b></col>, <cd>to
supply it with the water necessary to make it operate.</cd>
<mark>[Scot.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fanged</ent><br/
<hw>Fanged</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having fangs or tusks;
<as>as, a <ex>fanged</ex> adder</as>. Also used figuratively.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fangle</ent><br/
<hw>Fan"gle</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From <er>Fang</er>,
<pos>v. t.</pos>; hence, prop., a taking up a new thing.]</ety>
<def>Something new-fashioned; a foolish innovation; a gewgaw; a trifling
ornament.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fangle</ent><br/
<hw>Fan"gle</hw>, <pos>v. t.</pos> <def>To fashion.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>To control and new <qex>fangle</qex> the Scripture.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fangled</ent><br/
<hw>Fan"gled</hw> <pr>(?)</pr>, <pos>a.</pos> <def>New made; hence,
gaudy; showy; vainly decorated. <mark>[Obs., except with the prefix
<it>new</it>.]</mark> See <er>Newfangled</er>.</def> <ldquo/Our
<xex>fangled</xex> world.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fangleness</ent><br/
<hw>Fan"gle*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Quality of being
fangled.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He them in new <qex>fangleness</qex> did pass.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fangless</ent><br/
<hw>Fang"less</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Destitute of fangs
or tusks.</def> <ldquo/A <xex>fangless</xex> lion.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fangot</ent><br/
<hw>Fan"got</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. It.
<ets>fagotto</ets>, <ets>fangotto</ets>, a bundle. Cf.
<er>Fagot</er>.]</ety> <def>A quantity of wares, as raw silk, etc., from
one hundred weight.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fanion</ent><br/
<hw>Fan"ion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Fanon</er>.]</ety> <sn>1.</sn> <fld>(Mil.)</fld> <def>A small flag
sometimes carried at the head of the baggage of a brigade.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A small flag for marking the stations in
surveying.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fanlike</ent><br/
<hw>Fan"like`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Resembling a
fan;</def> -- <specif>specifically</specif> <fld>(Bot.)</fld>,
<def>folded up like a fan, as certain leaves; plicate.</def></p>

<p><ent>Fannel</ent><br/
<hw>Fan"nel</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Dim., from same
source as <ets>fanon</ets>.]</ety> <def>Same as
<er>Fanon</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fanner</ent><br/
<hw>Fan"ner</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who
fans.</def> <rj><au>Jer. li. 2.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A fan wheel; a fan blower. See under
<er>Fan</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fan-nerved</ent><br/
<hw>Fan"-nerved`</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Bot. &
Zool.)</fld> <def>Having the nerves or veins arranged in a radiating
manner; -- said of certain leaves, and of the wings of some
insects.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fanon</ent><br/
<hw>Fan"on</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>fanon</ets>,
LL. <ets>fano</ets>, fr. OHG. <ets>fano</ets> banner cloth, G.
<ets>fahne</ets> banner. See <er>Vane</er>, and cf. <er>Fanion</er>,
<er>Gonfalon</er>.]</ety> <fld>(Eccl.)</fld> <def>A term applied to
various articles,</def> <specif>as:</specif> <sd>(a)</sd> <def>A
peculiar striped scarf worn by the pope at mass, and by eastern
bishops.</def> <sd>(b)</sd> <def>A maniple.</def> <altsp>[Written also
<asp>fannel</asp>, <asp>phanon</asp>, etc.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fan palm</ent><br/
<hw>Fan" palm`</hw> <pr>(?)</pr>. <fld>(Bot.)</fld> <def>Any palm tree
having fan-shaped or radiate leaves; as the <spn>Cham<ae/rops
humilis</spn> of Southern Europe; the species of <gen>Sabal</gen> and
<gen>Thrinax</gen> in the West Indies, Florida, etc.; and especially the
great talipot tree (<spn>Corypha umbraculifera</spn>) of Ceylon and
Malaya. The leaves of the latter are often eighteen feet long and
fourteen wide, and are used for umbrellas, tents, and roofs. When cut
up, they are used for books and manuscripts.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fantad</ent><br/
<hw>Fan"tad</hw> <pr>(f<acr/n"t<acr/d)</pr>, <pos>n.</pos> <def>see
<er>fantod</er>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Fantail</ent><br/
<hw>Fan"tail`</hw> <pr>(f<acr/n"t<amac/l`)</pr>, <pos>n.</pos>
<fld>(Zool.)</fld> <sd>(a)</sd> <def>A variety of the domestic pigeon,
so called from the shape of the tail.</def> <sd>(b)</sd> <def>Any bird
of the Australian genus <gen>Rhipidura</gen>, in which the tail is
spread in the form of a fan during flight. They belong to the family of
flycatchers.</def> <sd>(c)</sd> <def>the <er>fantail
goldfish</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fan-tailed</ent><br/
<hw>Fan"-tailed`</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Having an expanded, or fan-shaped, tail; <as>as, the
<ex>fan-tailed</ex> pigeon</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>fantail goldfish</ent><br/
<hw>fan"tail` gold"fish</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Zool.)</fld> <def>a type of goldfish bred artificially, having a
realtively short oval body and a tail with four lobes arrayed somewhat
like a folding fan, as though forming a part of the surface of a cone.
Called also <altname>fantail</altname>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Fan-tan</ent><br/
<hw>Fan"-tan`</hw> <pr>(f<acr/n"t<acr/n`)</pr>, <pos>n.</pos>
<ety>[Chinese (of Canton) in <ets>an-tan-kun</ets> gambling
house.]</ety> <sn>1.</sn> <def>A Chinese gambling game in which coins or
other small objects are placed upon a table, usually under a cup, and
the players bet as to what remainder will be left when the sum of the
counters is divided by four.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>A game with playing cards in which the cards are
played in sequences upon the table, the one who first gets rid of his
cards being the winner.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Fantasia</ent><br/
<hw>Fan*ta"si*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[It. See
<er>Fancy</er>.]</ety> <fld>(Mus.)</fld> <def>A continuous composition,
not divided into what are called movements, or governed by the ordinary
rules of musical design, but in which the author's fancy roves
unrestricted by set form.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fantasied</ent><br/
<hw>Fan"ta*sied</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From
<er>Fantasy</er>.]</ety> <def>Filled with fancies or imaginations.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fantasm</ent><br/
<hw>Fan"tasm</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Phantasm</er>, <er>Fancy</er>.]</ety> <def>Same as
<er>Phantasm</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fantast</ent><br/
<hw>Fan"tast</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One whose manners or
ideas are fantastic.</def> <mark>[R.]</mark>
<rj><au>Coleridge.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fantastic</ent><br/
<hw>Fan*tas"tic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F.
<ets>fantastique</ets>, fr. Gr. <?/<?/<?/<?/<?/<?/<?/<?/<?/<?/<?/ able
to represent, fr. <?/<?/<?/<?/<?/<?/<?/<?/<?/ to make visible. See
<er>Fancy</er>.]</ety> <sn>1.</sn> <def>Existing only in imagination;
fanciful; imaginary; not real; chimerical.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Having the nature of a phantom; unreal.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Indulging the vagaries of imagination; whimsical;
full of absurd fancies; capricious; <as>as, <ex>fantastic</ex> minds; a
<ex>fantastic</ex> mistress.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Resembling fantasies in irregularity, caprice, or
eccentricity; irregular; oddly shaped; grotesque.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There at the foot of yonder nodding beech,<br/
That wreathes its old <qex>fantastic</qex> roots so high.</q>
<rj><qau>T. Gray.</qau></rj></p>

<p><syn><b>Syn.</b> -- Fanciful; imaginative; ideal; visionary;
capricious; chimerical; whimsical; queer. See
<er>Fanciful</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fantastic</ent><br/
<hw>Fan*tas"tic</hw>, <pos>n.</pos> <def>A person given to fantastic
dress, manners, etc.; an eccentric person; a fop.</def>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Our <qex>fantastics</qex>, who, having a fine watch, take all
ocasions to draw it out to be seen.</q> <rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fantastical</ent><br/
<hw>Fan*tas"tic*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Fanciful;
unreal; whimsical; capricious; fantastic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fantasticality</ent><br/
<hw>Fan*tas`ti*cal"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Fantastically.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fantastically</ent><br/
<hw>Fan*tas"tic*al*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a
fantastic manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>the letter A, in scarlet, <qex>fantastically</qex> embroidered
with gold thread, upon her bosom.</q> <rj><qau>Hawthorne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fantastic-alness</ent><br/
<hw>Fan*tas"tic-al*ness</hw>, <pos>n.</pos> <def>The quality of being
fantastic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fantasticism</ent><br/
<hw>Fan*tas"ti*cism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The quality of
being fantastical; fancifulness; whimsicality.</def>
<rj><au>Ruskin.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fantasticly</ent><br/
<hw>Fan*tas"tic*ly</hw> <pr>(?)</pr>, <pos>adv.</pos>
<def>Fantastically.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fantasticness</ent><br/
<hw>Fan*tas"tic*ness</hw>, <pos>n.</pos> <def>Fantasticalness.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fantastico</ent><br/
\'d8<hw>Fan*tas"ti*co</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[It.]</ety>
<def>A fantastic.</def> <mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fantasy</ent><br/
<hw>Fan"ta*sy</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Fantasies</plw> <pr>(#)</pr>.</plu> <ety>[See
<er>Fancy</er>.]</ety> <sn>1.</sn> <def>Fancy; imagination; especially,
a whimsical or fanciful conception; a vagary of the imagination; whim;
caprice; humor.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Is not this something more than <qex>fantasy</qex> ?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A thousand <qex>fantasies</qex><br/
Begin to throng into my memory.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Fantastic designs.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Embroidered with <qex>fantasies</qex> and flourishes of gold
thread.</q> <rj><qau>Hawthorne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fantasy</ent><br/
<hw>Fan"ta*sy</hw>, <pos>v. t.</pos> <def>To have a fancy for; to be
pleased with; to like; to fancy.</def> <mark>[Obs.]</mark>
<rj><au>Cavendish.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Which he doth most <qex>fantasy</qex>.</q> <rj><qau>Robynson
(More's Utopia).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fantique</ent><br/
<ent>Fantigue</ent><br/
<mhw>{ <hw>Fan*tigue"</hw> <pr>(?)</pr>, <hw>Fan*tique"</hw>
<pr>(?)</pr> }</mhw>, <pos>n.</pos> <altsp>[Written also
<asp>fanteague</asp>, <asp>fanteeg</asp>, etc.]</altsp> <ety>[Cf.
<er>Fantod</er>.]</ety> <def>State of worry or excitment; fidget; ill
humor.</def> <mark>[Prov. Eng.]</mark> <rj><au>Dickens.</au></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Fantoccini</ent><br/
\'d8<hw>Fan`toc*ci"ni</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[It.,
dim. fr. <ets>fante</ets> child.]</ety> <def>Puppets caused to perform
evolutions or dramatic scenes by means of machinery; also, the
representations in which they are used.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fantad</ent><br/
<ent>Fantod</ent><br/
<mhw>{ <hw>Fan"tod</hw> <pr>(?)</pr>, <hw>Fan"tad</hw> <pr>(?)</pr>,
}</mhw> <pos>n.</pos> <ety>[Cf. <er>Fantigue</er>.]</ety> <def>State of
worry or excitement; fidget; fuss; also, indisposition; pet;
sulks.</def> <mark>[Slang]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Fantom</ent><br/
<hw>Fan"tom</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Phantom</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fantom corn</b></col>, <cd>phantom corn.</cd>
<rj><au>Grose.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>fanwort</ent><br/
<hw>fanwort</hw> <pos>n.</pos> <def>a common aquatic plant (<spn>Cabomba
caroliniana</spn>) of eastern North America having floating and
submerged leaves and white yellow-spotted flowers.</def><br/
<syn><b>Syn. --</b> water-shield, <spn>Cabomba
caroliniana</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fap</ent><br/
<hw>Fap</hw> <pr>(f<acr/p)</pr>, <pos>a.</pos> <def>Fuddled.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>FAQ</ent><br/
<ent>FAQ list</ent><br/
<ent>FAQlist</ent><br/
<mhw><hw>FAQ</hw> <pr>(f<acr/k)</pr>, <hw>FAQ" list`</hw>
<pr>(f<acr/k"l<icr/st`)</pr>, <hw>FAQ"list</hw>
<pr>(f<acr/k"l<icr/st`)</pr></mhw>, <pos>pr. n.</pos> <ety>[acronym from
<ets>F</ets>requently <ets>A</ets>sked <ets>Q</ets>uestions.]</ety>
<def>A list of questions and answers concerning a specific topic, such
as how to use a particular computer program. Many such lists contain
answers to the most commonly asked questions about that topic, however
the questions need not derive from actual queries. Such lists are often
maintained in electronic form and made available on the World Wide
Web.</def> <mark>[acronym]</mark><br/
[<source>PJC</source>]</p>

<p><ent>Faquir</ent><br/
<hw>Fa*quir"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Fakir</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Far</ent><br/
<hw>Far</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Farrow</er>.]</ety> <fld>(Zool.)</fld> <def>A young pig, or a litter
of pigs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Far</ent><br/
<hw>Far</hw>, <pos>a.</pos> <amorph>[<adjf>Farther</adjf> <pr>(#)</pr>
and <adjf>Farthest</adjf> <pr>(#)</pr> are used as the
<pos>compar.</pos> and <pos>superl.</pos> of <ex>far</ex>, although they
are corruptions arising from confusion with <xex>further</xex> and
<xex>furthest</xex>. See <er>Further</er>.]</amorph> <ety>[OE.
<ets>fer</ets>, <ets>feor</ets>, AS. <ets>feor</ets>; akin to OS.
<ets>fer</ets>, D. <ets>ver</ets>, OHG. <ets>ferro</ets>, adv., G.
<ets>fern</ets>, <pos>a.</pos>, Icel. <ets>fjarri</ets>, Dan.
<ets>fjirn</ets>, Sw. <ets>fjerran</ets>, adv., Goth.
<ets>fa<imac/rra</ets>, adv., Gr. <?/<?/<?/<?/<?/ beyond, Skr.
<ets>paras</ets>, adv., far, and prob. to L. <ets>per</ets> through, and
E. prefix <ets>for-</ets>, as in <ets>for</ets>give, and also to
<ets>fare</ets>. Cf. <er>Farther</er>, <er>Farthest</er>.]</ety>
<sn>1.</sn> <def>Distant in any direction; not near; remote; mutually
separated by a wide space or extent.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They said, . . . We be come from a <qex>far</qex> country.</q>
<rj><qau>Josh. ix. 6.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The nations <qex>far</qex> and near contend in choice.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Remote from purpose; contrary to design or wishes;
<as>as, <ex>far</ex> be it from me to justify cruelty</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Remote in affection or obedience; at a distance,
morally or spiritually; t enmity with; alienated.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They that are <qex>far</qex> from thee ahsll perish.</q>
<rj><qau>Ps. lxxiii. 27.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Widely different in nature or quality; opposite in
character.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He was <qex>far</qex> from ill looking, though he thought himself
still farther.</q> <rj><qau>F. Anstey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>The more distant of two; <as>as, the <ex>far</ex>
side (called also <ex>off side</ex>) of a horse, that is, the right
side, or the one opposite to the rider when he mounts</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The distinction between the adjectival and adverbial use
of <xex>far</xex> is sometimes not easily discriminated.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>By far</b></col>, <cd>by much; by a great
difference.</cd> -- <col><b>Far between</b></col>, <cd>with a long
distance (of space or time) between; at long intervals.</cd> <ldquo/The
examinations are few and <xex>far between</xex>.<rdquo/
<au>Farrar.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Far</ent><br/
<hw>Far</hw>, <pos>adv.</pos> <sn>1.</sn> <def>To a great extent or
distance of space; widely; <as>as, we are separated <ex>far</ex> from
each other</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To a great distance in time from any point;
remotely; <as>as, he pushed his researches <ex>far</ex> into
antiquity</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>In great part; <as>as, the day is <ex>far</ex>
spent</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>In a great proportion; by many degrees; very much;
deeply; greatly.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Who can find a virtuous woman ? for her price is <qex>far</qex>
above rubies.</q> <rj><qau>Prov. xxxi. 10.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>As far as</b></col>, <cd>to the extent, or degree, that.
See <cref>As far as</cref>, under <er>As</er>.</cd> -- <col><b>Far
off</b></col>. <sd>(a)</sd> <cd>At a great distance, absolutely or
relatively.</cd> <sd>(b)</sd> <cd>Distant in sympathy or affection;
alienated.</cd> <ldquo/But now, in Christ Jesus, ye who some time were
<xex>far off</xex> are made nigh by the blood of Christ.<rdquo/ <au>Eph.
ii. 13.</au> -- <col><b>Far other</b></col>, <cd>different by a great
degree; not the same; quite unlike.</cd> <au>Pope.</au> -- <col><b>Far
and near</b></col>, <cd>at a distance and close by; throughout a whole
region.</cd> -- <col><b>Far and wide</b></col>, <cd>distantly and
broadly; comprehensively.</cd> <ldquo/<xex>Far and wide</xex> his eye
commands.<rdquo/ <au>Milton.</au> -- <col><b>From far</b></col>,
<cd>from a great distance; from a remote place.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Far</xex> often occurs in self-explaining
compounds, such as <xex>far</xex>-extended, <xex>far</xex>-reaching,
<xex>far</xex>-spread.</note><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 543 --></p>

<p><ent>Far-about</ent><br/
<hw>Far"-a*bout`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A going out of
the way; a digression.</def> <mark>[Obs.]</mark>
<rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Farad</ent><br/
<hw>Far"ad</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From Michael
<etsep>Faraday</etsep>, the English electrician.]</ety>
<fld>(Elec.)</fld> <def>The standard unit of electrical capacity; the
capacity of a condenser whose charge, having an electro-motive force of
one volt, is equal to the amount of electricity which, with the same
electromotive force, passes through one ohm in one second; the capacity,
which, charged with one coulomb, gives an electro-motive force of one
volt.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>faraday</ent><br/
<hw>far"a*day</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From Michael
<etsep>Faraday</etsep>, the English electrician.]</ety>
<fld>(Elec.)</fld> <def>the quantity of electric charge that, passed
though an ionic solution, will cause electrolysis of one equivalent of
ions; it is equal to about 96,490 coulombs. The number of univalent
metal ions (such as silver in a silver nitrate solution) which would be
deposited as free metal by such a current is Avogadro's number,
<mathex>6.023 x 10<exp>23</exp></mathex>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Faradic</ent><br/
<hw>Far*ad"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining to
Michael <etsep>Faraday</etsep>, the distinguished electrician; --
applied especially to induced currents of electricity, as produced by
certain forms of inductive apparatus, on account of Faraday's
investigations of their laws.</def></p>

<p><ent>Faradization</ent><br/
<ent>Faradism</ent><br/
<mhw>{ <hw>Far"a*dism</hw> <pr>(?)</pr>, <hw>Far`a*di*za"tion</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <fld>(Med.)</fld> <def>The treatment
with faradic or induced currents of electricity for remedial
purposes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Faradize</ent><br/
<hw>Far"a*dize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Faradized</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Faradizing</conjf> <pr>(?)</pr>.]</vmorph>
<fld>(Med.)</fld> <def>To stimulate with, or subject to, faradic, or
inducted, electric currents.</def> -- <wordforms><wf>Far"a*diz`er</wf>
<pr>(#)</pr>, <pos>n.</pos></wordforms><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Farand</ent><br/
<hw>Far"and</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See <er>Farrand</er>,
<pos>n.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Farandams</ent><br/
<hw>Far"an*dams</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A fabrik made of
silk and wool or hair.</def> <rj><au>Simmonds.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Farandole</ent><br/
\'d8<hw>Fa`ran`dole"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>farandole</ets>, Pr. <ets>farandoulo</ets>.]</ety> <def>A rapid
dance in six-eight time in which a large number join hands and dance in
various figures, sometimes moving from room to room. It originated in
Provence.</def></p>

<p><q>I have pictured them dancing a sort of <qex>farandole</qex>.</q>
<rj><qau>W. D. Howells.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Farantly</ent><br/
<hw>Far"ant*ly</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Farrand</er>.]</ety> <def>Orderly; comely; respectable.</def>
<mark>[Obs.]</mark> <rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Farce</ent><br/
<hw>Farce</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Farced</conjf> <pr>(?)</pr>, <pos>p. pr. & vb. n.</pos>
<conjf>Farcing</conjf> <pr>(<?/)</pr>.]</vmorph> <ety>[F.
<ets>Farcir</ets>, L. <ets>farcire</ets>; akin to Gr.
<?/<?/<?/<?/<?/<?/<?/<?/ to fence in, stop up. Cf. <er>Force</er> to
stuff, <er>Diaphragm</er>, <er>Frequent</er>, <er>Farcy</er>,
<er>Farse</er>.]</ety> <sn>1.</sn> <def>To stuff with forcemeat; hence,
to fill with mingled ingredients; to fill full; to stuff.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The first principles of religion should not be <qex>farced</qex>
with school points and private tenets.</q> <rj><qau>Bp.
Sanderson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>His tippet was aye <qex>farsed</qex> full of knives.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To render fat.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>If thou wouldst <qex>farce</qex> thy lean ribs.</q> <rj><qau>B.
Jonson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To swell out; to render pompous.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Farcing</qex> his letter with fustian.</q>
<rj><qau>Sandys.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Farce</ent><br/
<hw>Farce</hw>, <pos>n.</pos> <ety>[F. <ets>farce</ets>, from L.
<ets>farsus</ets> (also sometimes <ets>farctus</ets>), p. p. pf
<ets>farcire</ets>. See <er>Farce</er>, <pos>v. t.</pos>]</ety>
<sn>1.</sn> <fld>(Cookery)</fld> <def>Stuffing, or mixture of viands,
like that used on dressing a fowl; forcemeat.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A low style of comedy; a dramatic composition marked
by low humor, generally written with little regard to regularity or
method, and abounding with ludicrous incidents and
expressions.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Farce</qex> is that in poetry which <ldquo/grotesque<rdquo/
is in a picture: the persons and action of a <qex>farce</qex> are all
unnatural, and the manners false.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Ridiculous or empty show; <as>as, a mere
<ex>farce</ex></as>.</def> <ldquo/The <xex>farce</xex> of state.<rdquo/
<rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Farcement</ent><br/
<hw>Farce"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Stuffing;
forcemeat.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>They spoil a good dish with . . . unsavory
<qex>farcements</qex>.</q> <rj><qau>Feltham.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Farcical</ent><br/
<hw>Far"ci*cal</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to
farce; appropriated to farce; ludicrous; unnatural; unreal.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They deny the characters to be <qex>farcical</qex>, because they
are actually in nature.</q> <rj><qau>Gay.</qau></rj></p>

<p>-- <wordforms><wf>Far"ci*cal*ly</wf>, <pos>adv.</pos>
-<wf>Far"ci*cal*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Farcical</ent><br/
<hw>Far"ci*cal</hw>, <pos>a.</pos> <def>Of or pertaining to the disease
called farcy. See <er>Farcy</er>, <pos>n.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Farcilite</ent><br/
<hw>Far"ci*lite</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Farce</ets>+-<ets>lite</ets>.]</ety> <fld>(Min.)</fld>
<def>Pudding stone.</def> <mark>[Obs.]</mark>
<rj><au>Kirwan.</au></rj></p>

<p><ent>Farcin</ent><br/
<ent>Farcimen</ent><br/
<mhw>{ <hw>Far"ci*men</hw> <pr>(?)</pr>, <hw>Far"cin</hw> <pr>(?)</pr>,
}</mhw> <pos>n.</pos> <fld>(Far.)</fld> <def>Same as
<er>Farcy</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Farcing</ent><br/
<hw>Far"cing</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Cookery)</fld>
<def>Stuffing; forcemeat.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Farctate</ent><br/
<hw>Farc"tate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>farctus</ets>, p. p. of <ets>farcire</ets>. See <er>Farce</er>,
<pos>v. t.</pos>]</ety> <fld>(Bot.)</fld> <def>Stuffed; filled solid;
<as>as, a <ex>farctate</ex> leaf, stem, or pericarp</as>; -- opposed to
<xex>tubular</xex> or <xex>hollow</xex>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Farcy</ent><br/
<hw>Far"cy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>farcin</ets>;
cf. L. <ets>farciminum</ets> a disease of horses, fr.
<ets>farcire</ets>. See <er>Farce</er>.]</ety> <fld>(Far.)</fld> <def>A
contagious disease of horses, associated with painful ulcerating
enlargements, esp. upon the head and limbs. It is of the same nature as
glanders, and is often fatal. Called also <altname>farcin</altname>, and
<altname>farcimen</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Farcy</xex>, although more common in horses, is
communicable to other animals and to human beings.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Farcy bud</b></col>, <cd>a hard, prominent swelling
occurring upon the cutaneous surface in farcy, due to the obstruction
and inflammation of the lymphatic vessels, and followed by
ulceration.</cd> <rj><au>Youatt.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fard</ent><br/
<hw>Fard</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., prob. fr. OHG.
gi<ets>farit</ets>, gi<ets>farwit</ets> p. p. of <ets>farwjan</ets> to
color, tinge, fr. <ets>farawa</ets> color, G. <ets>farbe</ets>.]</ety>
<def>Paint used on the face.</def> <mark>[Obs.]</mark> <ldquo/Painted
with French <xex>fard</xex>.<rdquo/ <rj><au>J. Whitaker.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fard</ent><br/
<hw>Fard</hw>, <pos>v. t.</pos> <ety>[F. <ets>farder</ets> to paint
one's face.]</ety> <def>To paint; -- said esp. of one's face.</def>
<mark>[Obs.]</mark> <rj><au>Shenstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fardage</ent><br/
\'d8<hw>Far`dage"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. See
<er>Fardel</er>.]</ety> <fld>(Naut.)</fld> <def>See
<er>Dunnage</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fardel</ent><br/
<hw>Far"del</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>fardel</ets>, F. <ets>fardeau</ets>; cf. Sp. <ets>fardel</ets>,
<ets>fardillo</ets>, <ets>fardo</ets>, LL. <ets>fardellus</ets>; prob.
fr. Ar. <ets>fard</ets> one of the two parts of an object divisible into
two, hence, one of the two parts of a camel's load. Cf.
<er>Furl</er>.]</ety> <def>A bundle or little pack; hence, a
burden.</def> <mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>fardel</qex> of never-ending misery and suspense.</q>
<rj><qau>Marryat.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fardel</ent><br/
<hw>Far"del</hw>, <pos>v. t.</pos> <def>To make up in fardels.</def>
<mark>[Obs.]</mark> <rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Farding-bag</ent><br/
<hw>Far"ding-bag`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Of uncertain
origin; cf. <er>Fardel</er>.]</ety> <def>The upper stomach of a cow, or
other ruminant animal; the rumen.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fardingdale</ent><br/
<hw>Far"ding*dale</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A
farthingale.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fardingdeal</ent><br/
<hw>Far"ding*deal</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Farthing</er>, and <er>Deal</er> a part.]</ety> <def>The fourth part
of an acre of land.</def> <mark>[Obs.]</mark> <altsp>[Written also
<asp>farding dale</asp>, <asp>fardingale</asp>, etc.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fare</ent><br/
<hw>Fare</hw> <pr>(f<acir/r)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Fared</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Faring</conjf>.]</vmorph> <ety>[AS. <ets>faran</ets> to
travel, fare; akin to OS., Goth., & OHG. <ets>faran</ets> to travel, go,
D. <ets>varen</ets>, G. <ets>fahren</ets>, OFries., Icel., & Sw.
<ets>fara</ets>, Dan. <ets>fare</ets>, Gr. <?/<?/<?/<?/<?/ a way
through, <?/<?/<?/<?/<?/<?/<?/ a ferry, strait, <?/<?/<?/<?/<?/<?/<?/<?/
to convey, <?/<?/<?/<?/<?/<?/<?/<?/<?/<?/ to go, march, <?/<?/<?/<?/<?/
beyond, on the other side, <?/<?/<?/<?/<?/ to pass through, L.
<ets>peritus</ets> experienced, <ets>portus</ets> port, Skr.
<ets>par</ets> to bring over. <root/78. Cf. <er>Chaffer</er>,
<er>Emporium</er>, <er>Far</er>, <er>Ferry</er>, <er>Ford</er>,
<er>Peril</er>, <er>Port</er> a harbor, <er>Pore</er>,
<pos>n.</pos>]</ety> <sn>1.</sn> <def>To go; to pass; to journey; to
travel.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>So on he <qex>fares</qex>, and to the border comes<br/
Of Eden.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To be in any state, or pass through any experience,
good or bad; to be attended with any circummstances or train of events,
fortunate or unfortunate; <as>as, he <ex>fared</ex> well, or
ill</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>So <qex>fares</qex> the stag among the enraged hounds.</q>
<rj><qau>Denham.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I bid you most heartily well to <qex>fare</qex>.</q>
<rj><qau>Robynson (More's Utopia).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>So <qex>fared</qex> the knight between two foes.</q>
<rj><qau>Hudibras.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To be treated or entertained at table, or with
bodily or social comforts; to live.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There was a certain rich man which . . . <qex>fared</qex>
sumptuously every day.</q> <rj><qau>Luke xvi. 19.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To happen well, or ill; -- used impersonally;
<as>as, we shall see how it will <ex>fare</ex> with him</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>So <qex>fares</qex> it when with truth falsehood contends.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To behave; to conduct one's self.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>She <qex>ferde</qex> [fared] as she would die.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fare</ent><br/
<hw>Fare</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS. <ets>faru</ets>
journey, fr. <ets>faran</ets>. See <er>Fare</er>, <pos>v.</pos>]</ety>
<sn>1.</sn> <def>A journey; a passage.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>That nought might stay his <qex>fare</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The price of passage or going; the sum paid or due
for conveying a person by land or water; <as>as, the <ex>fare</ex> for
crossing a river; the <ex>fare</ex> in a coach or by
railway.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Ado; bustle; business.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The warder chid and made <qex>fare</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Condition or state of things; fortune; hap;
cheer.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>What <qex>fare</qex>? what news abroad ?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Food; provisions for the table; entertainment;
<as>as, coarse <ex>fare</ex>; delicious <ex>fare</ex>.</as></def>
<ldquo/Philosophic <xex>fare</xex>.<rdquo/ <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>The person or persons conveyed in a vehicle; <as>as,
a full <ex>fare</ex> of passengers</as>.</def> <rj><au>A.
Drummond.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>The catch of fish on a fishing vessel.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Bill of fare</b></col>. <cd>See under <er>Bill</er>.</cd>
-- <mcol><col><b>Fare indicator</b></col> <it>or</it> <col><b> Fare
register</b></col></mcol>, <cd>a device for recording the number of
passengers on a street car, etc.</cd> -- <col><b>Fare wicket</b></col>.
<sd>(a)</sd> <cd>A gate or turnstile at the entrance of toll bridges,
exhibition grounds, etc., for registering the number of persons passing
it.</cd> <sd>(b)</sd> <cd>An opening in the door of a street car for
purchasing tickets of the driver or passing fares to the conductor.</cd>
<rj><au>Knight.</au></rj> </cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Faren</ent><br/
<hw>Far"en</hw> <pr>(?)</pr>, <mark>obs.</mark> <def><pos>p. p.</pos> of
<er>Fare</er>, <pos>v. i.</pos></def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>fare-thee-well</ent><br/
<hw>fare-thee-well</hw> <pos>n.</pos> <def>state of perfection; the
utmost degree; <as>as, they polished the furniture to a
<ex>fare-thee-well</ex></as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Farewell</ent><br/
<hw>Fare`well"</hw> <pr>(?)</pr>, <pos>interj.</pos>
<ety>[<ets>Fare</ets> (thou, you) + <ets>well</ets>.]</ety> <def>Go
well; good-by; adieu; -- originally applied to a person departing, but
by custom now applied both to those who depart and those who remain. It
is often separated by the pronoun; <as>as, <ex>fare</ex> you
<ex>well</ex></as>; and is sometimes used as an expression of separation
only; <as>as, <ex>farewell</ex> the year; <ex>farewell</ex>, ye sweet
groves; that is, I bid you <ex>farewell</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>So <qex>farewell</qex> hope, and with hope, <qex>farewell</qex>
fear.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Fare</qex> thee <qex>well</qex>! and if forever,<br/
Still forever <qex>fare</qex> thee <qex>well</qex>.</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The primary accent is sometimes placed on the first
syllable, especially in poetry.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Farewell</ent><br/
<hw>Fare`well"</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A wish
of happiness or welfare at parting; the parting compliment; a good-by;
adieu.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Act of departure; leave-taking; a last look at, or
reference to something.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And takes her <qex>farewell</qex> of the glorious sun.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Before I take my <qex>farewell</qex> of the subject.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Farewell</ent><br/
<hw>Fare"well`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Parting;
valedictory; final; <as>as, a <ex>farewell</ex> discourse; his
<ex>farewell</ex> bow.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Leans in his spear to take his <qex>farewell</qex> view.</q>
<rj><qau>Tickell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Farewell rock</b></col> <fld>(Mining)</fld>, <cd>the
Millstone grit; -- so called because no coal is found worth working
below this stratum. It is used for hearths of furnaces, having power to
resist intense heat.</cd> <rj><au>Ure.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Farfet</ent><br/
<hw>Far"fet`</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Far</ets> +
<ets>fet</ets>, <pos>p. p.</pos> of <er>Fette</er>.]</ety>
<def>Farfetched.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>York with his <qex>farfet</qex> policy.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Farfetch</ent><br/
<hw>Far"fetch`</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[<ets>Far</ets>
+ <ets>fetch</ets>.]</ety> <def>To bring from far; to seek out
studiously.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>farfetch</qex> the name of Tartar from a Hebrew word.</q>
<rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Farfetch</ent><br/
<hw>Far"fetch`</hw>, <pos>n.</pos> <def>Anything brought from far, or
brought about with studious care; a deep strategem.</def>
<mark>[Obs.]</mark> <ldquo/Politic <xex>farfetches</xex>.<rdquo/
<rj><au>Hudibras.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Farfetched</ent><br/
<hw>Far"fetched`</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Brought from far, or from a remote place.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Every remedy contained a multitude of <qex>farfetched</qex> and
heterogeneous ingredients.</q> <rj><qau>Hawthorne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Studiously sought; not easily or naturally deduced
or introduced; forced; strained; hence, implausible or
improbable.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>far-flung</ent><br/
<hw>far-flung</hw> <pos>adj.</pos> <def>widely spread or distributed;
<as>as, the <ex>far-flung</ex> corners of the Empire</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Farina</ent><br/
<hw>Fa*ri"na</hw> <pr>(f<adot/*r<imac/"n<adot/ <it>or</it>
f<adot/*r<emac/"n<adot/)</pr>, <pos>n.</pos> <ety>[L., meal, flour, fr.
<ets>far</ets> a sort of grain, spelt; akin to E.
<ets>barley</ets>.]</ety> <sn>1.</sn> <def>A fine flour or meal made
from cereal grains or from the starch or fecula of vegetables, extracted
by various processes, and used in cookery.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>Pollen.</def> <mark>[R.]</mark>
<rj><au>Craig.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Farinaceous</ent><br/
<hw>Far`i*na"ceous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>farinaceus</ets>.]</ety> <sn>1.</sn> <def>Consisting or made of
meal or flour; <as>as, a <ex>farinaceous</ex> diet</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Yielding farina or flour; <as>as,
<ex>ffarinaceous</ex> seeds</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Like meal; mealy; pertaining to meal; <as>as, a
<ex>farinaceous</ex> taste, smell, or appearance</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Farinose</ent><br/
<hw>Far`i*nose"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>farinosus</ets>: cf. F. <ets>farineux</ets>.]</ety> <sn>1.</sn>
<def>Yielding farina; <as>as, <ex>farinose</ex>
substances</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot. & Zool.)</fld> <def>Covered with a sort of
white, mealy powder, as the leaves of some poplars, and the body of
certain insects; mealy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Farl</ent><br/
<hw>Farl</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>Same as
<er>Furl</er>.</def> <mark>[Obs.]</mark> <rj><au>Beau. &
Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Farlie</ent><br/
<hw>Far"lie</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>ferlish</ets> wonder, as adj., strange, sudden, fearful, AS.
<ets>f<aemac/rl<imac/c</ets> sudden. See <er>Fear</er>.]</ety> <def>An
unusual or unexpected thing; a wonder. See <er>Fearly</er>.</def>
<mark>[Obs. or Prov. Eng.]</mark> <rj><au>Drayton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Farm</ent><br/
<hw>Farm</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>ferme</ets>
rent, lease, F. <ets>ferme</ets>, LL. <ets>firma</ets>, fr. L.
<ets>firmus</ets> firm, fast, <ets>firmare</ets> to make firm or fast.
See <er>Firm</er>, <pos>a. & n.</pos>]</ety> <sn>1.</sn> <def>The rent
of land, -- originally paid by reservation of part of its
products.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The term or tenure of a lease of land for
cultivation; a leasehold.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>It is great willfulness in landlords to make any longer
<qex>farms</qex> to their tenants.</q> <rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The land held under lease and by payment of rent for
the purpose of cultivation.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Any tract of land devoted to agricultural purposes,
under the management of a tenant or the owner.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In English the ideas of a lease, a term, and a rent,
continue to be in a great degree inseparable, even from the popular
meaning of a <xex>farm</xex>, as they are entirely so from the legal
sense.</note> <rj><au>Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A district of country leased (or farmed) out for the
collection of the revenues of government.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The province was devided into twelve <qex>farms</qex>.</q>
<rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(O. Eng. Law)</fld> <def>A lease of the imposts on
particular goods; <as>as, the sugar <ex>farm</ex>, the silk
<ex>farm</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Whereas G. H. held the <qex>farm</qex> of sugars upon a rent of
10,000 marks per annum.</q> <rj><qau>State Trials (1196).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Farm</ent><br/
<hw>Farm</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Farmed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Farming</conjf>.]</vmorph> <sn>1.</sn> <def>To lease or let for
an equivalent, as land for a rent; to yield the use of to
proceeds.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We are enforced to <qex>farm</qex> our royal realm.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To give up to another, as an estate, a business, the
revenue, etc., on condition of receiving in return a percentage of what
it yields; <as>as, to <ex>farm</ex> the taxes</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>farm</qex> their subjects and their duties toward
these.</q> <rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To take at a certain rent or rate.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To devote (land) to agriculture; to cultivate, as
land; to till, as a farm.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>To farm let</b></col>, <col><b>To let to
farm</b></col></mcol>, <cd>to lease on rent.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Farm</ent><br/
<hw>Farm</hw>, <pos>v. i.</pos> <def>To engage in the business of
tilling the soil; to labor as a farmer.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Farmable</ent><br/
<hw>Farm"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of being
farmed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Farmer</ent><br/
<hw>Farm"er</hw> <pr>(f<aum/rm"<etil/r)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>fermier</ets>.]</ety> <def>One who farms</def>; as: <sd>(a)</sd>
<def>One who hires and cultivates a farm; a cultivator of leased ground;
a tenant.</def> <au>Smart.</au> <sd>(b)</sd> <def>One who is devoted to
the tillage of the soil; one who cultivates a farm; an agriculturist; a
husbandman.</def> <sd>(c)</sd> <def>One who takes taxes, customs,
excise, or other duties, to collect, either paying a fixed annuual rent
for the privilege; <as>as, a <ex>farmer</ex> of the revenues</as>.</def>
<sd>(d)</sd> <fld>(Mining)</fld> <def>The lord of the field, or one who
farms the lot and cope of the crown.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Farmer-general</b></col> <ety>[F.
<ets>fermier-general</ets>]</ety>, <cd>one to whom the right of levying
certain taxes, in a particular district, was <xex>farmed out</xex>,
under the former French monarchy, for a given sum paid down.</cd> --
<col><b>Farmers' satin</b></col>, <cd>a light material of cotton and
worsted, used for coat linings.</cd> <au>McElrath.</au> -- <col><b>The
king's farmer</b></col> <fld>(O. Eng. Law)</fld>, <cd>one to whom the
collection of a royal revenue was farmed out.</cd>
<rj><au>Burrill.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Farmeress</ent><br/
<hw>Farm"er*ess</hw>, <pos>n.</pos> <def>A woman who farms.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>farmerette</ent><br/
<hw>farmerette</hw> <pos>n.</pos> <def>a woman working on a farm; a
farmeress.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Farmership</ent><br/
<hw>Farm"er*ship</hw>, <pos>n.</pos> <def>Skill in farming.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Farmery</ent><br/
<hw>Farm"er*y</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The buildings and
yards necessary for the business of a farm; a homestead.</def>
<mark>[Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Farmhouse</ent><br/
<hw>Farm"house`</hw>, <pos>n.</pos> <def>A dwelling house on a farm; a
farmer's residence.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Farming</ent><br/
<hw>Farm"ing</hw>, <pos>a.</pos> <def>Pertaining to agriculture; devoted
to, adapted to, or engaged in, farming; <as>as, <ex>farming</ex> tools;
<ex>farming</ex> land; a <ex>farming</ex> community.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Farming</ent><br/
<hw>Farm"ing</hw>, <pos>n.</pos> <def>The business of cultivating
land.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>farmland</ent><br/
<hw>farmland</hw> <pos>n.</pos> <def>a rural area where farming is
practiced; land actually under cultivation or capable of supporting
crops.</def><br/
<syn><b>Syn. --</b> farming area.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Farmost</ent><br/
<hw>Far"most`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Most distant;
farthest.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A spacious cave within its <qex>farmost</qex> part.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>farmplace</ent><br/
<hw>farmplace</hw> <pos>n.</pos> <def>a farm together with its
buildings.</def><br/
<syn><b>Syn. --</b> farmstead.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Farmstead</ent><br/
<hw>Farm"stead</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A farm with the
building upon it; a homestead on a farm.</def>
<rj><au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>With its pleasant groves and <qex>farmsteads</qex>.</q>
<rj><qau>Carlyle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Farmsteading</ent><br/
<hw>Farm"stead*ing</hw>, <pos>n.</pos> <def>A farmstead.</def>
<mark>[Scot.]</mark> <rj><au>Black.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Farmyard</ent><br/
<hw>Farm"yard`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The yard or
inclosure attached to a barn, or the space inclosed by the farm
buildings.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Farness</ent><br/
<hw>Far"ness</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From <er>Far</er>,
<pos>a.</pos>]</ety> <def>The state of being far off; distance;
remoteness.</def> <mark>[R.]</mark> <rj><au>Grew.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Faro</ent><br/
<hw>Far"o</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Said to be so called
because the Egyptian king <ets>Pharaoh</ets> was formerly represented
upon one of the cards.]</ety> <def>A gambling game at cards, in which
all the other players play against the dealer or banker, staking their
money upon the order in which the cards will lie and be dealt from the
pack.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Faro bank</b></col>, <cd>the capital which the proprietor
of a faro table ventures in the game; also, the place where a game of
faro is played.</cd> <rj><au>Hoyle.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Faroese</ent><br/
<hw>Fa`ro*ese`</hw> <pr>(?)</pr>, <pos>n. sing. & pl.</pos> <def>An
inhabitant, or, collectively, inhabitants, of the Faroe
islands.</def><br/
[<source>1913 Webster</source>]</p>


<p><ent>Far-off</ent><br/
<hw>Far"-off`</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Remote;
<as>as, the <ex>far-off</ex> distance; troops landing on
<ex>far-off</ex> shores</as>. Cf. <cref>Far-off</cref>, under
<er>Far</er>, adv.</def><br/
<syn><b>Syn. --</b> faraway.</syn><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>remote in time; <as>as, <ex>far-off</ex> happier
times</as>.</def><br/
<syn><b>Syn. --</b> remote, removed.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>far-out</ent><br/
<hw>far-out</hw> <pos>adj.</pos> <def>strikingly unconventional.</def>
<mark>[informal]</mark><br/
<syn><b>Syn. --</b> kinky, offbeat, quirky, way-out.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Farraginous</ent><br/
<hw>Far*rag*i*nous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Farrago</er>.]</ety> <def>Formed of various materials; mixed;
<as>as, a <ex>farraginous</ex> mountain</as>.</def> <mark>[R.]</mark>
<rj><au>Kirwan.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>farraginous</qex> concurrence of all conditions, tempers,
sexes, and ages.</q> <rj><qau>Sir T. Browne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Farrago</ent><br/
\'d8<hw>Far*ra"go</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>farrago</ets>, <ets>-aginis</ets>, mixed fodder for cattle, mash,
medley, fr. <ets>far</ets> a sort of grain. See <er>Farina</er>.]</ety>
<def>A mass composed of various materials confusedly mixed; a medley; a
mixture.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A confounded <qex>farrago</qex> of doubts, fears, hopes, wishes,
and all the flimsy furniture of a country miss's brain.</q>
<rj><qau>Sheridan.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Farrand</ent><br/
<hw>Far"rand</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>farand</ets> beautiful; cf. Gael. <ets>farranta</ets> neat, stout,
stately; or perh. akin to E. <ets>fare</ets>.]</ety> <def>Manner;
custom; fashion; humor.</def> <mark>[Prov. Eng.]</mark> <altsp>[Written
also <asp>farand</asp>.]</altsp> <rj><au>Grose.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>far-reaching</ent><br/
<hw>far-reaching</hw> <pos>adj.</pos> <def>having a wide range or
effect; <as>as, <ex>far-reaching</ex> (or extensive) forests; a
<ex>far-reaching</ex> reform</as>.</def><br/
<syn><b>Syn. --</b> extensive.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Farreation</ent><br/
<hw>Far`re*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>farreatio</ets>.]</ety> <def>Same as
<er>Confarreation</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Farrier</ent><br/
<hw>Far"ri*er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>farrour</ets>, <ets>ferrer</ets>, OF. <ets>ferreor</ets>,
<ets>ferrier</ets>, LL. <ets>Ferrator</ets>, <ets>ferrarius
equorum</ets>, from <ets>ferrare</ets> to shoe a horse,
<ets>ferrum</ets> a horseshoe, fr. L. <ets>ferrum</ets> iron. Cf.
<er>Ferreous</er>.]</ety> <sn>1.</sn> <def>A shoer of horses; a
veterinary surgeon.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Farrier</ent><br/
<hw>Far"ri*er</hw>, <pos>v. i.</pos> <def>To practice as a farrier; to
carry on the trade of a farrier.</def> <mark>[Obs.]</mark>
<rj><au>Mortimer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Farriery</ent><br/
<hw>Far"ri*er*y</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
art of shoeing horses.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The art of preventing, curing, or mitigating
diseases of horses and cattle; the veterinary art.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The place where a smith shoes horses.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>far-right</ent><br/
<hw>far-right</hw> <pos>adj.</pos> <fld>(Politics)</fld> <def>extremely
conservative politically.</def><br/
<syn><b>Syn. --</b> reactionary, reactionist,
ultraconservative.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><-- p. 544 --></p>

<p><ent>Farrow</ent><br/
<hw>Far"row</hw> <pr>(f<acr/r"r<osl/)</pr>, <pos>n.</pos> <ety>[AS.
<ets>fearh</ets> a little pig; a akin to OHG. <ets>farh</ets>,
<ets>farah</ets>, pig, dim. <ets>farheli</ets> little pig, G.
<ets>fercel</ets>, D. <ets>varken</ets> pig, Lith. <ets>parszas</ets>
OIr. <ets>orc</ets>, L. <ets>porcus</ets>, Gr. <grk>po`rkos</grk>. Cf.
<er>Pork</er>.]</ety> <def>A litter of pigs.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Farrow</ent><br/
<hw>Far"row</hw>, <pos>v. t. & i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Farrowed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Farrowing</conjf>.]</vmorph> <def>To bring forth (young); -- said
only of swine.</def> <rj><au>Tusser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Farrow</ent><br/
<hw>Far"row</hw>, <pos>a.</pos> <ety>[Cf. Scot. <ets>ferry cow</ets> a
cow that is not with calf, D. <ets>vaarkoe</ets>, <ets>vaars</ets>,
heifer, G. <ets>f<aum/rse</ets>, AS. <ets>fearr</ets> bull, G.
<ets>farre</ets>. Cf. <er>Heifer</er>.]</ety> <def>Not producing young
in a given season or year; -- said only of cows.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ If a cow has had a calf, but fails in a subsequent year,
she is said to be <xex>farrow</xex>, or to go
<xex>farrow</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Farry</ent><br/
<hw>Far"ry</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A farrow.</def>
<mark>[Obs.]</mark> <rj><au>Perry.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Farse</ent><br/
<hw>Farse</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See <er>Farce</er>,
<pos>n.</pos>]</ety> <fld>(Eccl.)</fld> <def>An addition to, or a
paraphrase of, some part of the Latin service in the vernacular; --
common in English before the Reformation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Farseeing</ent><br/
<hw>Far"see`ing</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Able
to see to a great distance; farsighted.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Having foresight as regards the future.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Farsi</ent><br/
<hw>Far"si</hw> <pr>(f<aum/r"s<esl/)</pr>, <pos>prop. n.</pos> <def>The
language spoken in modern Iran; modern Persian. It is written in the
Arabic alphabet.</def><br/
[<source>PJC</source>]</p>

<p><ent>Farsighted</ent><br/
<hw>Far"sight`ed</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Seeing to great distance; hence, of good judgment regarding the
remote effects of actions; sagacious.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Med.)</fld> <def>Hypermetropic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Farsightedness</ent><br/
<hw>Far"sight`ed*ness</hw>, <pos>n.</pos> <sn>1.</sn> <def>Quality of
bbeing farsighted.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Med.)</fld> <def>Hypermetropia.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Far-stretched</ent><br/
<hw>Far"-stretched`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Stretched
beyond ordinary limits.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Farther</ent><br/
<hw>Far"ther</hw> <pr>(f<aum/r"<th/<etil/r)</pr>, <pos>a.</pos>,
<mord><pos>compar.</pos> of <er>Far</er>.</mord>
<amorph>[<pos>superl.</pos> <adjf>Farthest</adjf>
<pr>(-<th/<ecr/st)</pr>. See <er>Further</er>.]</amorph> <ety>[For
<ets>farrer</ets>, OE. <ets>ferrer</ets>, compar. of <ets>far</ets>;
confused with <ets>further</ets>. Cf. <er>Farthest</er>.]</ety>
<sn>1.</sn> <def>More remote; more distant than something
else.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Tending to a greater distance; beyond a certain
point; additional; further.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Before our <qex>farther</qex> way the fates allow.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Let me add a <qex>farther</qex> Truth.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Some <qex>farther</qex> change awaits us.</q>
<rj><qau>MIlton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Farther</ent><br/
<hw>Far"ther</hw>, <pos>adv.</pos> <sn>1.</sn> <def>At or to a greater
distance; more remotely; beyond; <as>as, let us rest with what we have,
without looking <ex>farther</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Moreover; by way of progress in treating a subject;
<as>as, <ex>farther</ex>, let us consider the probable
event</as>.</def><br/
[<source>1913 Webster</source>]</p>

<cs><p><col><b>No farther</b></col>, <cd>(used elliptically for) go no
farther; say no more, etc.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>It will be dangerous to go on. <qex>No farther</qex> !</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p></cs>

<p><ent>Farther</ent><br/
<hw>Far"ther</hw>, <pos>v. t.</pos> <def>To help onward.
<mark>[R.]</mark> See <er>Further</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fartherance</ent><br/
<hw>Far"ther*ance</hw> <pr>(?)</pr>, <pos>n.</pos> <mark>[Obs.]</mark>
<def>See <er>Furtherance</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Farthermore</ent><br/
<hw>Far"ther*more`</hw> <pr>(?)</pr>, <pos>adv.</pos>
<mark>[Obs.]</mark> <def>See <er>Furthermore</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Farthermost</ent><br/
<hw>Far"ther*most`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Most remote;
farthest.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Farthest</ent><br/
<hw>Far"thest</hw> <pr>(f<aum/r"<th/<ecr/st)</pr>, <pos>a.</pos>
<mord><pos>Superl.</pos> of <er>far</er>.</mord> <ety>[See
<er>Farther</er> and cf. <er>Furthest</er>]</ety> <def>Most distant or
remote; <as>as, the <ex>farthest</ex> degree</as>. See
<er>Furthest</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Farthest</ent><br/
<hw>Far"thest</hw> <pos>adv.</pos> <def>At or to the greatest distance.
See <er>Furthest</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>farthing</ent><br/
<hw>Far"thing</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>furthing</ets>, AS. <ets>fe<oacute/r<edh/ung</ets>, fr.
<ets>fe<oacute/r<edh/a</ets> fourth, <ets>fe<oacute/r</ets>,
<ets>fe<oacute/wer</ets>, four. See <er>Four</er>.]</ety> <sn>1.</sn>
<def>The fourth of a penny; a small copper coin of Great Britain, being
a cent in United States currency.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A very small quantity or value.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>In her cup was no <qex>farthing</qex> seen of grease.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A division of land.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Thirty acres make a <qex>farthing</qex> land; nine
<qex>farthings</qex> a Cornish acre; and four Cornish acres a knight's
fee.</q> <rj><qau>R. Carew.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Farthingale</ent><br/
<hw>Far"thin*gale</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>vardingale</ets>, <ets>fardingale</ets>, fr. OF.
<ets>vertugale</ets>, <ets>verdugade</ets>, F. <ets>vertugade</ets>,
<ets>vertugadin</ets>, from Sp. <ets>verdugado</ets>, being named from
its hoops, fr. <ets>verdugo</ets> a young shoot of tree, fr.
<ets>verde</ets> green, fr. L. <ets>viridis</ets>. See
<er>Verdant</er>.]</ety> <def>A hoop skirt or hoop petticoat, or other
light, elastic material, used to extend the petticoat.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We'll revel it as bravely as the best, . . . <br/
With ruffs and cuffs, and <qex>farthingales</qex> and things.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fasces</ent><br/
\'d8<hw>Fas"ces</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[L.,
<pos>pl.</pos> of <ets>fascis</ets> bundle; cf. <ets>fascia</ets> a
band, and Gr. <grk>fa`kelos</grk> a bundle.]</ety>, <fld>(Rom.
Antiq.)</fld> <def>A bundle of rods, having among them an ax with the
blade projecting, borne before the Roman magistrates as a badge of their
authority.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fascet</ent><br/
<hw>Fas"cet</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Glass Making)</fld>
<def>A wire basket on the end of a rod to carry glass bottles, etc., to
the annealing furnace; also, an iron rod to be thrust into the mouths of
bottles, and used for the same purpose; -- called also
<altname>pontee</altname> and <altname>punty</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fascia</ent><br/
\'d8<hw>Fas"ci*a</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Fasci<ae/</plw> <pr>(#)</pr>.</plu> <ety>[L., a band: cf. It.
<ets>fascia</ets>. See <er>Fasces</er>, and cf. <er>Fess</er>.]</ety>
<sn>1.</sn> <def>A band, sash, or fillet; especially, in surgery, a
bandage or roller.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Arch.)</fld> <def>A flat member of an order or
building, like a flat band or broad fillet; especially, one of the three
bands which make up the architrave, in the Ionic order. See
<xex>Illust.</xex> of <er>Column</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Anat.)</fld> <def>The layer of loose tissue, often
containing fat, immediately beneath the skin; the stronger layer of
connective tissue covering and investing all muscles; an
aponeurosis.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Zool.)</fld> <def>A broad well-defined band of
color.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fascial</ent><br/
<hw>Fas"ci*al</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Pertaining to the fasces.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Anat.)</fld> <def>Relating to a fascia.</def></p>

<p><ent>Fasciated</ent><br/
<ent>Fasciate</ent><br/
<mhw>{ <hw>Fas"ci*ate</hw> <pr>(?)</pr>, <hw>Fas"ci*a`ted</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[L. <ets>fasciatus</ets>, p. p.
of <ets>fasciare</ets> to envelop with bands, fr. <ets>fascia</ets>
band. See <er>Fasces</er>.]</ety> <sn>1.</sn> <def>Bound with a fillet,
sash, or bandage.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <sd>(a)</sd> <def>Banded or compacted
together.</def> <sd>(b)</sd> <def>Flattened and laterally widened, as
are often the stems of the garden cockscomb.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <def>Broadly banded with
color.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fasciation</ent><br/
<hw>Fas`ci*a"tion</hw>, <pos>n.</pos> <def>The act or manner of binding
up; bandage; also, the condition of being fasciated.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fascicle</ent><br/
<hw>Fas"ci*cle</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>fasciculus</ets>, dim. of <ets>fascis</ets>. See
<er>Fasces</er>.]</ety> <sn>1.</sn> <def>A small bundle or collection; a
compact cluster; <as>as, a <ex>fascicle</ex> of fibers; a
<ex>fascicle</ex> of flowers or roots</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One of the divisions of a book published in parts;
fasciculus.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Fascicled</ent><br/
<hw>Fas"ci*cled</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Growing in a
bundle, tuft, or close cluster; <as>as, the <ex>fascicled</ex> leaves of
the pine or larch; the <ex>fascicled</ex> roots of the dahlia;
<ex>fascicled</ex> muscle fibers; <ex>fascicled</ex> tufts of
hair.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fascicular</ent><br/
<hw>Fas*cic"u*lar</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to a
fascicle; fascicled; <as>as, a <ex>fascicular</ex> root</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fascicularly</ent><br/
<hw>Fas*cic"u*lar*ly</hw>, <pos>adv.</pos> <def>In a fascicled
manner.</def> <rj><au>Kirwan.</au></rj></p>

<p><ent>Fasciculated</ent><br/
<ent>Fasciculate</ent><br/
<mhw>{ <hw>Fas*cic"u*late</hw> <pr>(?)</pr>, <hw>Fas*cic"u*la`ted</hw>
<pr>(?)</pr>,}</mhw> <pos>a.</pos> <def>Grouped in a fascicle;
fascicled.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fascicule</ent><br/
<hw>Fas"ci*cule</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Fascicle</er>.]</ety> <def>A small bunch or bundle; a fascicle;
<as>as, a <ex>fascicule</ex> of fibers, hairs, or spines</as>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Fasciculus</ent><br/
\'d8<hw>Fas*cic"u*lus</hw> <pr>(?)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Fasciculi</plw> <pr>(#)</pr>.</plu> <ety>[L. See
<er>Fascicle</er>.]</ety> <sn>1.</sn> <def>A little bundle; a
fascicle.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A division of a book.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fascinate</ent><br/
<hw>Fas"ci*nate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Fascinated</conjf> <pr>(?)</pr>, <pos>p. pr. & vb.
n.</pos>. <conjf>Fascinating</conjf> <pr>(<?/)</pr>.]</vmorph> <ety>[L.
<ets>fascinare</ets>; cf. Gr. <?/<?/<?/<?/<?/<?/<?/<?/<?/<?/ to slander,
bewitch.]</ety> <sn>1.</sn> <def>To influence in an uncontrollable
manner; to operate on by some powerful or irresistible charm; to
bewitch; to enchant.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It has been almost universally believed that . . . serpents can
stupefy and <qex>fascinate</qex> the prey which they are desirous to
obtain.</q> <rj><qau>Griffith (Cuvier).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To excite and allure irresistibly or powerfully; to
charm; to captivate, as by physical or mental charms.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There be none of the passions that have been noted to
<qex>fascinate</qex> or bewitch but love and envy.</q>
<rj><qau>Bacon.</qau></rj></p>

<p><syn><b>Syn.</b> -- To charm; enrapture; captivate; enchant; bewitch;
attract.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>fascinated</ent><br/
<hw>fascinated</hw> <pos>adj.</pos> <sn>1.</sn> <def>having the
attention fixed by a sense of wonder.</def><br/
<syn><b>Syn. --</b> hypnotized, hypnotised, mesmerized, mesmerised,
spellbound, transfixed.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>intensely interested in or attracted by; <as>as, I'm
very interested in birds; in fact I'm <ex>fascinated</ex> by
them</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>fascinating</ent><br/
<hw>fascinating</hw> <pos>adj.</pos> <sn>1.</sn> <def>capable of holding
the attention; <as>as, a <ex>fascinating</ex> story</as>.</def><br/
<syn><b>Syn. --</b> absorbing, engrossing, gripping, riveting,
spellbinding.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>capturing interest as if by a spell; <as>as, a
<ex>fascinating</ex> woman</as>.</def><br/
<syn><b>Syn. --</b> bewitching, captivating, enchanting, enthralling,
entrancing.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fascination</ent><br/
<hw>Fas`ci*na"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>fascinatio</ets>; cf. F. <ets>fascination</ets>.]</ety> <sn>1.</sn>
<def>The act of fascinating, bewitching, or enchanting; enchantment;
witchcraft; the exercise of a powerful or irresistible influence on the
affections or passions; unseen, inexplicable influence.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The Turks hang old rags . . . upon their fairest horses, and other
goodly creatures, to secure them against <qex>fascination</qex>.</q>
<rj><qau>Waller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The state or condition of being
fascinated.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which fascinates; a charm; a spell.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There is a certain bewitchery or <qex>fascination</qex> in
words.</q> <rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fascine</ent><br/
<hw>Fas*cine"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr. L.
<ets>fascina</ets> a bundle of sticks, fr. <ets>fascis</ets>. See
<er>Fasces</er>.]</ety> <fld>(Fort. & Engin.)</fld> <def>A cylindrical
bundle of small sticks of wood, bound together, used in raising
batteries, filling ditches, strengthening ramparts, and making parapets;
also in revetments for river banks, and in mats for dams, jetties,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fascinous</ent><br/
<hw>Fas"ci*nous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>fascinum</ets> witchcraft, akin to <ets>fascinare</ets>. See
<er>Fascinate</er>.]</ety> <def>Caused or acting by witchcraft.</def>
<mark>[Obs.]</mark> <ldquo/<xex>Fascinous</xex> diseases.<rdquo/
<rj><au>Harvey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fasciola</ent><br/
\'d8<hw>Fas*ci"o*la</hw> <pr>(?)</pr>, <pos>n.</pos>;<plu><it>pl.</it>
<plw>Fasciol<ae/</plw> <pr>(#)</pr>.</plu> <ety>[See
<er>Fasciole</er>.]</ety> <fld>(Anat.)</fld> <def>A band of gray matter
bordering the fimbria in the brain; the dentate convolution.</def>
<rj><au>Wilder.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fasciole</ent><br/
<hw>Fas"ci*ole</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>fasciola</ets> a little bandage. See <er>Fascia</er>.]</ety>
<fld>(Zool.)</fld> <def>A band of minute tubercles, bearing modified
spines, on the shells of spatangoid sea urchins. See
<er>Spatangoidea</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>fascism</ent><br/
<hw>fasc"ism</hw> <pr>(f<acr/sh"<icr/z'm)</pr> <pos>n.</pos> <sn>1.</sn>
<def>a political theory advocating an authoritarian hierarchical
government; -- opposed to <contr>democracy</contr> and
<contr>liberalism</contr>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>an authoritarian system of government under absolute
control of a single dictator, allowing no political opposition, forcibly
suppressing dissent, and rigidly controlling most industrial and
economic activities. Such regimes usually try to achieve popularity by a
strongly nationalistic appeal, often mixed with racism.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>Specifically, the Fascist movement led by
<person>Benito Mussolini</person> in Italy from 1922 to 1943.</def><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <def>broadly, a tendency toward or support of a strongly
authoritarian or dictatorial control of government or other
organizations; -- often used pejoratively in this sense.</def><br/
[<source>PJC</source>]</p>

<p><ent>fascist</ent><br/
<hw>fascist</hw> <pos>n.</pos> <def>an adherent of fascism or similar
right-wing authoritarian views.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>fascistic</ent><br/
<ent>fascist</ent><br/
<mhw><hw>fascist</hw> <hw>fascistic</hw></mhw> <pos>adj.</pos>
<sn>1.</sn> <def>of or pertaining to fascism; resembling fascism;
<as>as, <ex>fascist</ex> propaganda</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fash</ent><br/
<hw>Fash</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Fashed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Fashing</conjf>.]</vmorph> <ety>[OF. <ets>faschier</ets>, F.
<ets>f<?/cher</ets>, to anger, vex; cf. Pr. <ets>fasticar</ets>,
<ets>fastigar</ets>, fr. L. <ets>fastidium</ets> dilike. See
<er>Fastidious</er>.]</ety> <def>To vex; to tease; to trouble.</def>
<mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fash</ent><br/
<hw>Fash</hw>, <pos>n.</pos> <def>Vexation; anxiety; care.</def>
<mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Without further <qex>fash</qex> on my part.</q> <rj><qau>De
Quincey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fashion</ent><br/
<hw>Fash"ion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>fasoun</ets>, <ets>facioun</ets>, shape, manner, F.
<ets>facon</ets>, orig., a making, fr. L. <ets>factio</ets> a making,
fr. <ets>facere</ets> to make. See <er>Fact</er>, <er>Feat</er>, and cf.
<er>Faction</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>The make or form of anything; the style, shape,
appearance, or mode of structure; pattern, model; <as>as, the
<ex>fashion</ex> of the ark, of a coat, of a house, of an altar,
etc.</as>; workmanship; execution.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>fashion</qex> of his countenance was altered.</q>
<rj><qau>Luke ix. 29.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I do not like the <qex>fashion</qex> of your garments.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The prevailing mode or style, especially of dress;
custom or conventional usage in respect of dress, behavior, etiquette,
etc.; particularly, the mode or style usual among persons of good
breeding; <as>as, to dress, dance, sing, ride, etc., in the
<ex>fashion</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The innocent diversions in <qex>fashion</qex>.</q>
<rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>As now existing, <qex>fashion</qex> is a form of social regulation
analogous to constitutional government as a form of political
regulation.</q> <rj><qau>H. Spencer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Polite, fashionable, or genteel life; social
position; good breeding; <as>as, men of <ex>fashion</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Mode of action; method of conduct; manner; custom;
sort; way.</def> <ldquo/After his sour <xex>fashion</xex>.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>After a fashion</b></col>, <cd>to a certain extent; of a
sort; sort of.</cd> -- <col><b>Fashion piece</b></col>
<fld>(Naut.)</fld>, <cd>one of the timbers which terminate the transom,
and define the shape of the stern.</cd> -- <col><b>Fashion
plate</b></col>, <cd>a pictorial design showing the prevailing style or
a new style of dress.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fashion</ent><br/
<hw>Fash"ion</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Fashioned</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Fashioning</conjf>.]</vmorph> <ety>[Cf. F.
<ets>faconner</ets>.]</ety> <sn>1.</sn> <def>To form; to give shape or
figure to; to mold.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Here the loud hammer <qex>fashions</qex> female toys.</q>
<rj><qau>Gay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Ingenious art . . . <br/
Steps forth to <qex>fashion</qex> and refine the age.</q>
<rj><qau>Cowper.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To fit; to adapt; to accommodate; -- with
<xex>to</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Laws ought to be <qex>fashioned</qex> to the manners and
conditions of the people.</q> <rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To make according to the rule prescribed by
custom.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Fashioned</qex> plate sells for more than its weight.</q>
<rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To forge or counterfeit.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fashioning needle</b></col> <fld>(Knitting
Machine)</fld>, <cd>a needle used for widening or narrowing the work and
thus shaping it.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fashionable</ent><br/
<hw>Fash"ion*a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Conforming to the fashion or established mode; according with the
prevailing form or style; <as>as, a <ex>fashionable</ex>
dress</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Established or favored by custom or use; current;
prevailing at a particular time; <as>as, the <ex>fashionable</ex>
philosophy; <ex>fashionable</ex> opinions</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Observant of the fashion or customary mode; dressing
or behaving according to the prevailing fashion; <as>as, a
<ex>fashionable</ex> man</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Genteel; well-bred; <as>as, <ex>fashionable</ex>
society</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Time is like a <qex>fashionable</qex> host<br/
That slightly shakes his parting guest by the hand.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fashionable</ent><br/
<hw>Fash"ion*a*ble</hw>, <pos>n.</pos> <def>A person who conforms to the
fashions; -- used chiefly in the plural.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fashionableness</ent><br/
<hw>Fash"ion*a*ble*ness</hw>, <pos>n.</pos> <def>State of being
fashionable.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fashionably</ent><br/
<hw>Fash"ion*a*bly</hw>, <pos>adv.</pos> <def>In a fashionable
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fashioned</ent><br/
<hw>Fash"ioned</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having a certain
style or fashion; <as>as, old-<ex>fashioned</ex>;
new-<ex>fashioned</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fashioner</ent><br/
<hw>Fash"ion*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who fashions,
forms, ar gives shape to anything.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>fashioner</qex> had accomplished his task, and the
dresses were brought home.</q> <rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fashionist</ent><br/
<hw>Fash"ion*ist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An obsequious
follower of the modes and fashions.</def> <mark>[R.]</mark>
<rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fashionless</ent><br/
<hw>Fash"ion*less</hw>, <pos>a.</pos> <def>Having no fashion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fashion-monger</ent><br/
<hw>Fash"ion-mon`ger</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
studies the fashions; a fop; a dandy.</def>
<rj><au>Marston.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fashion-mongering</ent><br/
<hw>Fash"ion-mon`ger*ing</hw>, <pos>a.</pos> <def>Behaving like a
fashion-monger.</def> <mark>[R.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fassaite</ent><br/
<hw>Fas"sa*ite</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Min.)</fld> <def>A
variety of pyroxene, from the valley of <xex>Fassa</xex>, in the
Tyrol.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fast</ent><br/
<hw>Fast</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Fasted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Fasting</conjf>.]</vmorph> <ety>[AS. <ets>f<ae/stan</ets>;
<ets>akin to D</ets>. <ets>vasten</ets>, OHG. <ets>fast<emac/n</ets>, G.
<ets>fasten</ets>, Icel. & Sw. <ets>fasta</ets>, Dan. <ets>faste</ets>,
Goth. <ets>fastan</ets> to keep, observe, fast, and prob. to E.
<ets>fast</ets> firm.]</ety> <sn>1.</sn> <def>To abstain from food; to
omit to take nourishment in whole or in part; to go hungry.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Fasting</qex> he went to sleep, and <qex>fasting</qex>
waked.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To practice abstinence as a religious exercise or
duty; to abstain from food voluntarily for a time, for the mortification
of the body or appetites, or as a token of grief, or humiliation and
penitence.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou didst <qex>fast</qex> and weep for the child.</q> <rj><qau>2
Sam. xii. 21.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fasting day</b></col>, <cd>a fast day; a day of
fasting.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fast</ent><br/
<hw>Fast</hw>, <pos>n.</pos> <ety>[OE. <ets>faste</ets>,
<ets>fast</ets>; cf. AS. <ets>f<ae/sten</ets>, OHG. <ets>fasta</ets>, G.
<ets>faste</ets>. See <er>Fast</er>, <pos>v. i.</pos>]</ety> <sn>1.</sn>
<def>Abstinence from food; omission to take nourishment.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Surfeit is the father of much <qex>fast</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Voluntary abstinence from food, for a space of time,
as a spiritual discipline, or as a token of religious
humiliation.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A time of fasting, whether a day, week, or longer
time; a period of abstinence from food or certain kinds of food; <as>as,
an annual <ex>fast</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fast day</b></col>, <cd>a day appointed for fasting,
humiliation, and religious offices as a means of invoking the favor of
God.</cd> -- <col><b>To break one's fast</b></col>, <cd>to put an end to
a period of abstinence by taking food; especially, to take one's morning
meal; to breakfast.</cd> <rj><au>Shak.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fast</ent><br/
<hw>Fast</hw>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Faster</adjf> <pr>(?)</pr>; <pos>superl.</pos>
<adjf>Fastest</adjf> <pr>(?)</pr>.]</amorph> <ety>[OE., firm, strong,
not loose, AS. <ets>f<ae/st</ets>; akin to OS. <ets>fast</ets>, D.
<ets>vast</ets>, OHG. <ets>fasti</ets>, <ets>festi</ets>, G.
<ets>fest</ets>, Icel. <ets>fastr</ets>, Sw. & Dan. <ets>fast</ets>, and
perh. to E. <ets>fetter</ets>. The sense <ets>swift</ets> comes from the
idea of keeping close to what is pursued; a Scandinavian use. Cf.
<er>Fast</er>, <pos>adv.</pos>, <er>Fast</er>, <pos>v.</pos>,
<er>Avast</er>.]</ety> <sn>1.</sn> <def>Firmly fixed; closely adhering;
made firm; not loose, unstable, or easily moved; immovable; <as>as, to
make <ex>fast</ex> the door</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There is an order that keeps things <qex>fast</qex>.</q>
<rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Firm against attack; fortified by nature or art;
impregnable; strong.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Outlaws . . . lurking in woods and <qex>fast</qex> places.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Firm in adherence; steadfast; not easily separated
or alienated; faithful; <as>as, a <ex>fast</ex> friend</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Permanent; not liable to fade by exposure to air or
by washing; durable; lasting; <as>as, <ex>fast</ex>
colors</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Tenacious; retentive.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Roses, damask and red, are <qex>fast</qex> flowers of their
smells.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Not easily disturbed or broken; deep;
sound.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>All this while in a most <qex>fast</qex> sleep.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>Moving rapidly; quick in mition; rapid; swift;
<as>as, a <ex>fast</ex> horse</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>Given to pleasure seeking; disregardful of
restraint; reckless; wild; dissipated; dissolute; <as>as, a
<ex>fast</ex> man; a <ex>fast</ex> liver.</as></def>
<rj><au>Thackeray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>In such a condition, as to resilience, etc., as to
make possible unusual rapidity of play or action; <as>as, a
<ex>fast</ex> racket, or tennis court; a <ex>fast</ex> track; a
<ex>fast</ex> billiard table, etc.</as></def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><cs><col><b>Fast and loose</b></col>, <cd>now cohering, now
disjoined; inconstant, esp. in the phrases <xex>to play at fast and
loose</xex>, <xex>to play fast and loose</xex>, to act with giddy or
reckless inconstancy or in a tricky manner; to say one thing and do
another.</cd> <ldquo/<xex>Play fast and loose</xex> with faith.<rdquo/
<au>Shak.</au> -- <col><b>Fast and loose pulleys</b></col>
<fld>(Mach.)</fld>, <cd>two pulleys placed side by side on a revolving
shaft, which is driven from another shaft by a band, and arranged to
disengage and re<eum/ngage the machinery driven thereby. When the
machinery is to be stopped, the band is transferred from the pulley
fixed to the shaft to the pulley which revolves freely upon it, and
<xex>vice versa</xex>.</cd> -- <col><b>Hard and fast</b></col>
<fld>(Naut.)</fld>, <cd>so completely aground as to be immovable.</cd>
-- <col><b>To make fast</b></col> <fld>(Naut.)</fld>, <cd>to make
secure; to fasten firmly, as a vessel, a rope, or a door.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 545 --></p>

<p><ent>Fast</ent><br/
<hw>Fast</hw> <pr>(?)</pr>, <pos>adv.</pos> <ety>[OE. <ets>faste</ets>
firmly, strongly, quickly, AS. <ets>f<ae/ste</ets>. See <er>Fast</er>,
<pos>a.</pos>]</ety> <sn>1.</sn> <def>In a fast, fixed, or firmly
established manner; fixedly; firmly; immovably.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We will bind thee <qex>fast</qex>.</q> <rj><qau>Judg. xv.
13.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>In a fast or rapid manner; quickly; swiftly;
extravagantly; wildly; <as>as, to run <ex>fast</ex>; to live
<ex>fast</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Fast by</b></col>, <it>or</it> <col><b>Fast
beside</b></col></mcol>, <cd>close or near to; near at
hand.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><q>He, after Eve seduced, unminded slunk<br/
Into the wood <qex>fast by</qex>.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Fast by</qex> the throne obsequious Fame resides.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fast</ent><br/
<hw>Fast</hw>, <pos>n.</pos> <def>That which fastens or holds;
especially, <fld>(Naut.)</fld> a mooring rope, hawser, or chain; --
called, according to its position, a <xex>bow</xex>, <xex>head</xex>,
<xex>quarter</xex>, <xex>breast</xex>, or <xex>stern fast</xex>; also, a
post on a pier around which hawsers are passed in mooring.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>fastball</ent><br/
<hw>fast"ball`</hw> <pos>n.</pos> <fld>(Baseball)</fld> <def>a baseball
thrown with maximum velocity.</def><br/
<syn><b>Syn. --</b> heater, smoke, hummer, bullet.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>fastbreak</ent><br/
<hw>fast"break`</hw> <pos>n.</pos> <fld>(basketball)</fld> <def>a rapid
dash to get a shot at one's own basket as soon as possible after taking
possession of the ball; -- often occurring after the opposing team has
shot at their basket.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Fasten</ent><br/
<hw>Fas"ten</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Fastened</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Fastening</conjf> <pr>(?)</pr>.]</vmorph> <ety>[AS.
<ets>f<ae/stnian</ets>; akin to OHG. <ets>festin<omac/n</ets>. See
<er>Fast</er>, <pos>a.</pos>]</ety> <sn>1.</sn> <def>To fix firmly; to
make fast; to secure, as by a knot, lock, bolt, etc.; <as>as, to
<ex>fasten</ex> a chain to the feet; to <ex>fasten</ex> a door or
window.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To cause to hold together or to something else; to
attach or unite firmly; to cause to cleave to something , or to cleave
together, by any means; <as>as, to <ex>fasten</ex> boards together with
nails or cords; to <ex>fasten</ex> anything in our
thoughts.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>The words Whig and Tory have been pressed to the service of many
successions of parties, with very different ideas <qex>fastened</qex> to
them.</q> <rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To cause to take close effect; to make to tell; to
lay on; <as>as, to <ex>fasten</ex> a blow</as>.</def>
<mark>[Obs.]</mark> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>If I can <qex>fasten</qex> but one cup upon him.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>To fasten a charge upon</b></col> <it>or</it>
<col><b>To fasten a crime upon</b></col></mcol>, <cd>to make his guilt
certain, or so probable as to be generally believed.</cd> -- <col><b>To
fasten one's eyes upon</b></col>, <cd>to look upon steadily without
cessation.</cd> <au>Acts iii. 4.</au></cs></p>

<p><syn><b>Syn.</b> -- To fix; cement; stick; link; affix;
annex.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fasten</ent><br/
<hw>Fas"ten</hw>, <pos>v. i.</pos> <def>To fix one's self; to take firm
hold; to clinch; to cling.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A horse leech will hardly <qex>fasten</qex> on a fish.</q>
<rj><qau>Sir T. Browne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>fastened</ent><br/
<hw>fastened</hw> <pos>adj.</pos> <sn>1.</sn> <def>affixed. Opposite of
<ant>unaffixed</ant>.</def><br/
<syn><b>Syn. --</b> secured.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>secured against opening; -- of doors, hatches,
etc.</def><br/
<syn><b>Syn. --</b> latched.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fastener</ent><br/
<hw>Fas"ten*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, makes fast or firm.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fastening</ent><br/
<hw>Fas"ten*ing</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Anything that
binds and makes fast, as a lock, catch, bolt, bar, buckle,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Faster</ent><br/
<hw>Fast"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who abstains from
food.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>fast-flying</ent><br/
<hw>fast-flying</hw> <pos>adj.</pos> <def>moving or functioning quickly
and energetically; <as>as, a <ex>fast-flying</ex>
messenger</as>.</def><br/
<syn><b>Syn. --</b> fast flying, hurrying, speedy.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>fast-growing</ent><br/
<hw>fast-growing</hw> <pos>adj.</pos> <def>tending to spread quickly; --
used mostly of plants.</def> <mark>[prenominal]</mark> [Narrower terms:
<stype>invasive (vs. noninvasive) </stype>]<br/
<syn><b>Syn. --</b> aggressive.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fast-handed</ent><br/
<hw>Fast"-hand`ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Close-handed;
close-fisted; covetous; avaricious.</def> <mark>[Obs.]</mark>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fasti</ent><br/
\'d8<hw>Fas"ti</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[L.]</ety>
<sn>1.</sn> <def>The Roman calendar, which gave the days for festivals,
courts, etc., corresponding to a modern almanac.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Records or registers of important events.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fastidiosity</ent><br/
<hw>Fas*tid`i*os"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Fastidiousness; squeamishness.</def> <mark>[Obs.]</mark>
<rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fastidious</ent><br/
<hw>Fas*tid"i*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>fastidiosus</ets> disdainful, fr. <ets>fastidium</ets> loathing,
aversion, perh. fr. <ets>fastus</ets> arrogance (of uncertain origin) +
<ets>taedium</ets> loathing. Cf. <er>Tedious</er>, <er>Fash</er>.]</ety>
<def>Difficult to please; delicate to a fault; suited with difficulty;
squeamish; <as>as, a <ex>fastidious</ex> mind or ear; a
<ex>fastidious</ex> appetite.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Proud youth ! <qex>fastidious</qex> of the lower world.</q>
<rj><qau>Young.</qau></rj></p>

<p><syn><b>Syn.</b> -- Squeamish; critical; overnice; difficult;
punctilious.</syn> -- <usage><er>Fastidious</er>, <er>Squeamish</er>. We
call a person <xex>fastidious</xex> when his taste or feelings are
offended by trifling defects or errors; we call him <xex>squeamish</xex>
when he is excessively nice or critical on minor points, and also when
he is overscrupulous as to questions of duty. <ldquo/Whoever examines
his own imperfections will cease to be <xex>fastidious</xex>; whoever
restrains his caprice and scrupulosity will cease to be
<xex>squeamish</xex>.<rdquo/ <au>Crabb.</au></usage></p>

<p>-- <wordforms><wf>Fas*tid"i*ous*ly</wf>, <pos>adv.</pos> --
<wf>Fas*tid"i*ous*ness</wf>, <pos>n.</pos></wordforms></p>

<p><ent>Fastigiated</ent><br/
<ent>Fastigiate</ent><br/
<mhw>{ <hw>Fas*tig"i*ate</hw> <pr>(?)</pr>, <hw>Fas*tig"i*a`ted</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[L. <ets>fastigium</ets> gable
end, top, height, summit.]</ety> <sn>1.</sn> <def>Narrowing towards the
top.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>Clustered, parallel, and upright,
as the branches of the Lombardy poplar; pointed.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <def>United into a conical bundle, or
into a bundle with an enlarged head, like a sheaf of wheat.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fastish</ent><br/
<hw>Fast"ish</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Rather fast; also,
somewhat dissipated.</def> <mark>[Colloq.]</mark>
<rj><au>Thackeray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fastly</ent><br/
<hw>Fast"ly</hw>, <pos>adv.</pos> <def>Firmly; surely.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fastness</ent><br/
<hw>Fast"ness</hw>, <pos>n.</pos> <ety>[AS. <ets>f<ae/stnes</ets>, fr.
<ets>f<ae/st</ets> fast. See <er>Fast</er>, <pos>a.</pos>]</ety>
<sn>1.</sn> <def>The state of being fast and firm; firmness; fixedness;
security; faithfulness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>All . . . places of <qex>fastness</qex> [are] laid open.</q>
<rj><qau>Sir J. Davies.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A fast place; a stronghold; a fortress or fort; a
secure retreat; a castle; <as>as, the enemy retired to their
<ex>fastnesses</ex> in the mountains</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Conciseness of style.</def> <mark>[Obs.]</mark>
<rj><au>Ascham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The state of being fast or swift.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fastuous</ent><br/
<hw>Fas"tu*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>fastuosus</ets>, from <ets>fastus</ets> haughtiness, pride: cf. F.
<ets>fastueux</ets>.]</ety> <def>Proud; haughty; disdainful.</def>
<mark>[Obs.]</mark> <au>Barrow.</au> --
<wordforms><wf>Fas"tu*ous*ness</wf>, <pos>n.</pos>
<mark>[Obs.]</mark></wordforms> <rj><au>Jer. Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fat</ent><br/
<hw>Fat</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See <er>Vat</er>,
<pos>n.</pos>]</ety> <sn>1.</sn> <def>A large tub, cistern, or vessel; a
vat.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>fats</qex> shall overflow with wine and oil.</q>
<rj><qau>Joel ii. 24.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A measure of quantity, differing for different
commodities.</def> <mark>[Obs.]</mark> <rj><au>Hebert.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fat</ent><br/
<hw>Fat</hw>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Fatter</adjf> <pr>(?)</pr>; <pos>superl.</pos>
<adjf>Fattest</adjf> <pr>(?)</pr>.]</amorph> <ety>[AS.
<ets>f<aemac/tt</ets>; akin to D. <ets>vet</ets>, G. <ets>fett</ets>,
<ets>feist</ets>, Icel. <ets>feitr</ets>, Sw. <ets>fet</ets>, Dan.
<ets>fed</ets>, and perh. to Gr. <grk>pi^dax</grk> spring, fountain,
<grk>pidy`ein</grk> to gush forth, <grk>pi`wn</grk> fat, Skr.
<ets>pi</ets> to swell.]</ety> <sn>1.</sn> <def>Abounding with
fat</def>; as: <sd>(a)</sd> <def>Fleshy; characterized by fatness;
plump; corpulent; not lean; <as>as, a <ex>fat</ex> man; a <ex>fat</ex>
ox</as>.</def> <sd>(b)</sd> <def>Oily; greasy; unctuous; rich; -- said
of food.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Exhibiting the qualities of a fat animal; coarse;
heavy; gross; dull; stupid.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Making our western wits <qex>fat</qex> and mean.</q>
<rj><qau>Emerson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Make the heart of this people <qex>fat</qex>.</q> <rj><qau>Is. vi.
10.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Fertile; productive; <as>as, a <ex>fat</ex> soil; a
<ex>fat</ex> pasture.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Rich; producing a large income; desirable; <as>as, a
<ex>fat</ex> benefice; a <ex>fat</ex> office; a <ex>fat</ex>
job.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Now parson of Troston, a <qex>fat</qex> living in Suffolk.</q>
<rj><qau>Carlyle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Abounding in riches; affluent; fortunate.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Persons grown <qex>fat</qex> and wealthy by long impostures.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Typog.)</fld> <def>Of a character which enables the
compositor to make large wages; -- said of matter containing blank,
cuts, or many leads, etc.; <as>as, a <ex>fat</ex> take; a <ex>fat</ex>
page.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fat lute</b></col>, <cd>a mixture of pipe clay and oil
for filling joints.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fat</ent><br/
<hw>Fat</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <fld>(Physiol.
Chem.)</fld> <def>An oily liquid or greasy substance making up the main
bulk of the adipose tissue of animals, and widely distributed in the
seeds of plants. See <cref>Adipose tissue</cref>, under
<er>Adipose</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Animal fats</xex> are composed mainly of three
distinct fats, <xex>tristearin</xex>, <xex>tripalmitin</xex>, and
<xex>triolein</xex>, mixed in varying proportions. As olein is liquid at
ordinary temperatures, while the other two fats are solid, it follows
that the consistency or hardness of fats depends upon the relative
proportion of the three individual fats. During the life of an animal,
the fat is mainly in a liquid state in the fat cells, owing to the
solubility of the two solid fats in the more liquid olein at the body
temperature. Chemically, fats are composed of fatty acid, as stearic,
palmitic, oleic, etc., united with glyceryl. In butter fat, olein and
palmitin predominate, mixed with another fat characteristic of butter,
butyrin. In the vegetable kingdom many other fats or glycerides are to
be found, as myristin from nutmegs, a glyceride of lauric acid in the
fat of the bay tree, etc.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The best or richest productions; the best part;
<as>as, to live on the <ex>fat</ex> of the land</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Typog.)</fld> <def>Work. containing much blank, or
its equivalent, and, therefore, profitable to the compositor.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fat acid</b></col>. <fld>(Chem.)</fld> <cd>See
<cref>Sebacic acid</cref>, under <er>Sebacic</er>.</cd> --
<mcol><col><b>Fat series</b></col>, <col><b>Fatty
series</b></col></mcol> <fld>(Chem.)</fld>, <cd>the series of the
paraffine hydrocarbons and their derivatives; the marsh gas or methane
series.</cd> -- <col><b>Natural fats</b></col> <fld>(Chem.)</fld>,
<cd>the group of oily substances of natural occurrence, as butter, lard,
tallow, etc., as distinguished from certain fatlike substance of
artificial production, as paraffin. Most natural fats are essentially
mixtures of triglycerides of fatty acids.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fat</ent><br/
<hw>Fat</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Fatted</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>atting</conjf> <pr>(?)</pr>.]</vmorph> <ety>[OE.
<ets>fatten</ets>, AS. <ets>f<aemac/ttian</ets>. See <er>Fat</er>,
<pos>a.</pos>, and cf. <er>Fatten</er>.]</ety> <def>To make fat; to
fatten; to make plump and fleshy with abundant food; <as>as, to
<ex>fat</ex> fowls or sheep</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We <qex>fat</qex> all creatures else to <qex>fat</qex> us.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fat</ent><br/
<hw>Fat</hw>, <pos>v. i.</pos> <def>To grow fat, plump, and
fleshy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>An old ox <qex>fats</qex> as well, and is as good, as a young
one.</q> <rj><qau>Mortimer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fatal</ent><br/
<hw>Fa"tal</hw>, <pos>a.</pos> <ety>[L. <ets>fatalis</ets>, fr.
<ets>fatum</ets>: cf. F. <ets>fatal</ets>. See <er>Fate</er>.]</ety>
<sn>1.</sn> <def>Proceeding from, or appointed by, fate or destiny;
necessary; inevitable.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>These thing are <qex>fatal</qex> and necessary.</q>
<rj><qau>Tillotson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>It was <qex>fatal</qex> to the king to fight for his money.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Foreboding death or great disaster.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>That <qex>fatal</qex> screech owl to our house<br/
That nothing sung but death to us and ours.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Causing death or destruction; deadly; mortal;
destructive; calamitous; <as>as, a <ex>fatal</ex> wound; a
<ex>fatal</ex> disease; a <ex>fatal</ex> day; a <ex>fatal</ex>
error.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fatalism</ent><br/
<hw>Fa"tal*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>fatalisme</ets>.]</ety> <def>The doctrine that all things are
subject to fate, or that they take place by inevitable
necessity.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fatalist</ent><br/
<hw>Fa"tal*ist</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>fataliste</ets>.]</ety> <def>One who maintains that all things
happen by inevitable necessity.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fatalistic</ent><br/
<hw>Fa`tal*is"tic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Implying, or
partaking of the nature of, fatalism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fatality</ent><br/
<hw>Fa*tal"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos>;<plu><it>pl.</it>
<plw>Fatalities</plw> <pr>(#)</pr>.</plu> <ety>[L. <ets>fatalitas</ets>:
cf. F. <ets>fatalit<eacute/</ets>]</ety> <sn>1.</sn> <def>The state of
being fatal, or proceeding from destiny; invincible necessity, superior
to, and independent of, free and rational control.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The Stoics held a <qex>fatality</qex>, and a fixed, unalterable
course of events.</q> <rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The state of being fatal; tendency to destruction or
danger, as if by decree of fate; mortaility.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The year sixty-three is conceived to carry with it the most
considerable <qex>fatality</qex>.</q> <rj><qau>Ser T.
Browne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>By a strange <qex>fatality</qex> men suffer their dissenting.</q>
<rj><qau>Eikon Basilike.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which is decreed by fate or which is fatal; a
fatal event.</def> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fatally</ent><br/
<hw>Fa"tal*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <sn>1.</sn> <def>In a
manner proceeding from, or determined by, fate.</def>
<rj><au>Bentley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>In a manner resulting in death or ruin; mortally;
destructively; <as>as, <ex>fatally</ex> deceived or
wounded</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fatalness</ent><br/
<hw>Fa"tal*ness</hw>, <pos>n.</pos> <def>Quality of being fatal.</def>
<rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fata Morgana</ent><br/
\'d8<hw>Fa"ta Mor*ga"na</hw> <pr>(?)</pr>. <ety>[It.; -- so called
because this phenomenon was looked upon as the work of a fairy (It.
<ets>fata</ets>) of the name of <ets>Morg<aacute/na</ets>. See
<er>Fairy</er>.]</ety> <def>A kind of mirage by which distant objects
appear inverted, distorted, displaced, or multiplied. It is noticed
particularly at the Straits of Messina, between Calabria and
Sicily.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fatback</ent><br/
<hw>Fat"back`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>The menhaden.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fat-brained</ent><br/
<hw>Fat"-brained`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Dull of
apprehension.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fate</ent><br/
<hw>Fate</hw> <pr>(f<amac/t)</pr>, <pos>n.</pos> <ety>[L.
<ets>fatum</ets> a prophetic declaration, oracle, what is ordained by
the gods, destiny, fate, fr. <ets>fari</ets> to speak: cf. OF.
<ets>fat</ets>. See <er>Fame</er>, <er>Fable</er>, <er>Ban</er>, and cf.
1st <er>Fay</er>, <er>Fairy</er>.]</ety> <sn>1.</sn> <def>A fixed decree
by which the order of things is prescribed; the immutable law of the
universe; inevitable necessity; the force by which all existence is
determined and conditioned.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Necessity and chance<br/
Approach not me; and what I will is <qex>fate</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Beyond and above the Olympian gods lay the silent, brooding,
everlasting <qex>fate</qex> of which victim and tyrant were alike the
instruments.</q> <rj><qau>Froude.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Appointed lot; allotted life; arranged or
predetermined event; destiny; especially, the final lot; doom; ruin;
death.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The great, th'important day, big with the <qex>fate</qex><br/
Of Cato and of Rome.</q> <rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Our wills and <qex>fates</qex> do so contrary run<br/
That our devices still are overthrown.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The whizzing arrow sings,<br/
<qex>And bears thy fate</qex>, Antinous, on its wings.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The element of chance in the affairs of life; the
unforeseen and unestimated conitions considered as a force shaping
events; fortune; esp., opposing circumstances against which it is
useless to struggle; <as>as, <ex>fate</ex> was, or the <ex>fates</ex>
were, against him</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A brave man struggling in the storms of <qex>fate</qex>.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Sometimes an hour of <qex>Fate's</qex> serenest weather strikes
through our changeful sky its coming beams.</q> <rj><qau>B.
Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <pluf>pl.</pluf> <ety>[L. <ets>Fata</ets>, pl. of
<ets>fatum</ets>.]</ety> <fld>(Myth.)</fld> <def>The three goddesses,
Clotho, Lachesis, and Atropos, sometimes called the
<altname>Destinies</altname>, or <altname>Parc<ae/</altname>who were
supposed to determine the course of human life. They are represented,
one as holding the distaff, a second as spinning, and the third as
cutting off the thread.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Among all nations it has been common to speak of
<xex>fate</xex> or destiny as a power superior to gods and men --
swaying all things irresistibly. This may be called the <xex>fate</xex>
of poets and mythologists. Philosophical <xex>fate</xex> is the sum of
the laws of the universe, the product of eternal intelligence and the
blind properties of matter. Theological <xex>fate</xex> represents Deity
as above the laws of nature, and ordaining all things according to his
will -- the expression of that will being the law.</note>
<rj><au>Krauth-Fleming.</au></rj></p>

<p><syn><b>Syn.</b> -- Destiny; lot; doom; fortune; chance.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fated</ent><br/
<hw>Fat"ed</hw> <pr>(?)</pr>, <pos>p. p. & a.</pos> <sn>1.</sn>
<def>Decreed by fate; destined; doomed; <as>as, he was <ex>fated</ex> to
rule a factious people</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>One midnight<br/
<qex>Fated</qex> to the purpose.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Invested with the power of determining
destiny.</def> <mark>[Obs.]</mark> <ldquo/The <xex>fated</xex>
sky.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Exempted by fate.</def> <mark>[Obs. or R.]</mark>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fateful</ent><br/
<hw>Fate"ful</hw> <pr>(?)</pr>, <pos>a. .</pos> <def>Having the power of
serving or accomplishing fate.</def> <ldquo/The <xex>fateful</xex>
steel.<rdquo/ <rj><au>J. Barlow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Significant of fate; ominous.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>fateful</qex> cawings of the crow.</q>
<rj><qau>Longfellow.</qau></rj></p>

<p>-- <wordforms><wf>Fate"ful*ly</wf>, <pos>adv.</pos>-
<wf>Fate"ful*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>fat-free</ent><br/
<hw>fat-free</hw> <pos>adj.</pos> <def>containing no fat; -- of foods.
Opposite of <ant>fat-containing</ant>.</def><br/
<syn><b>Syn. --</b> fatless, nonfat.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Fathead</ent><br/
<hw>Fat"head`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<sd>(a)</sd> <def>A cyprinoid fish of the Mississippi valley
(<spn>Pimephales promelas</spn>); -- called also <altname>black-headed
minnow</altname>.</def> <sd>(b)</sd> <def>A labroid food fish of
California; the redfish.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>fatheaded</ent><br/
<hw>fat"head`ed</hw> <pos>adj.</pos> <def>same as <er>stupid</er>.
Opposite of <ant>smart</ant>.</def> <mark>[informal]</mark><br/
<syn><b>Syn. --</b> blockheaded, boneheaded, loggerheaded, thick,
thickheaded, thick-skulled, wooden-headed.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Father</ent><br/
<hw>Fa"ther</hw> <pr>(f<aum/"<th/<etil/r)</pr>, <pos>n.</pos> <ety>[OE.
<ets>fader</ets>, AS. <ets>f<ae/der</ets>; akin to OS. <ets>fadar</ets>,
D. <ets>vader</ets>, OHG. <ets>fatar</ets>, G. <ets>vater</ets>, Icel.
<ets>fa<edh/ir</ets> Sw. & Dan. <ets>fader</ets>, OIr. <ets>athir</ets>,
L. <ets>pater</ets>, Gr. <grk>path`r</grk>, Skr. <ets>pitr</ets>, perh.
fr. Skr. <ets>p<amac/</ets> protect. <root/75, 247. Cf. <er>Papa</er>,
<er>Paternal</er>, <er>Patriot</er>, <er>Potential</er>,
<er>Pablum</er>.]</ety> <sn>1.</sn> <def>One who has begotten a child,
whether son or daughter; a generator; a male parent.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A wise son maketh a glad <qex>father</qex>.</q> <rj><qau>Prov. x.
1.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A male ancestor more remote than a parent; a
progenitor; especially, a first ancestor; a founder of a race or family;
-- in the plural, <xex>fathers</xex>, ancestors.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>David slept with his <qex>fathers</qex>.</q> <rj><qau>1 Kings ii.
10.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Abraham, who is the <qex>father</qex> of us all.</q> <rj><qau>Rom.
iv. 16.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>One who performs the offices of a parent by
maintenance, affetionate care, counsel, or protection.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I was a <qex>father</qex> to the poor.</q> <rj><qau>Job xxix.
16.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He hath made me a <qex>father</qex> to Pharaoh, and lord of all
his house.</q> <rj><qau>Gen. xiv. 8.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A respectful mode of address to an old
man.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And Joash the king of Israel came down unto him [Elisha], . . .
and said, O my <qex>father</qex>, my <qex>father</qex>!</q> <rj><qau>2
Kings xiii. 14.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A senator of ancient Rome.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>A dignitary of the church, a superior of a convent,
a confessor (called also <altname>father confessor</altname>), or a
priest; also, the eldest member of a profession, or of a legislative
assembly, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Bless you, good <qex>father</qex> friar !</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>One of the chief ecclesiastical authorities of the
first centuries after Christ; -- often spoken of collectively as
<xex>the Fathers</xex>; <as>as, the Latin, Greek, or apostolic
<ex>Fathers</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>One who, or that which, gives origin; an originator;
a producer, author, or contriver; the first to practice any art,
profession, or occupation; a distinguished example or teacher.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>father</qex> of all such as handle the harp and
organ.</q> <rj><qau>Gen. iv. 21.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Might be the <qex>father</qex>, Harry, to that thought.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>father</qex> of good news.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>The Supreme Being and Creator; God; in theology, the
first person in the Trinity.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Our <qex>Father</qex>, which art in heaven.</q> <rj><qau>Matt. vi.
9.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Now had the almighty <qex>Father</qex> from above . . . <br/
Bent down his eye.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Adoptive father</b></col>, <cd>one who adopts the child
of another, treating it as his own.</cd> -- <mcol><col><b>Apostolic
father</b></col>, <col><b>Conscript fathers, etc.</b></col></mcol>
<cd>See under <er>Apostolic</er>, <er>Conscript</er>, etc.</cd> --
<col><b>Father in God</b></col>, <cd>a title given to bishops.</cd> --
<col><b>Father of lies</b></col>, <cd>the Devil.</cd> -- <col><b>Father
of the bar</b></col>, <cd>the oldest practitioner at the bar.</cd> --
<col><b>Fathers of the city</b></col>, <cd>the aldermen.</cd> --
<col><b>Father of the Faithful</b></col>. <sd>(a)</sd> <cd>Abraham.</cd>
<au>Rom. iv.</au> <au>Gal. iii. 6-9.</au> <sd>(b)</sd> <cd>Mohammed, or
one of the sultans, his successors.</cd> -- <col><b>Father of the
house</b></col>, <cd>the member of a legislative body who has had the
longest continuous service.</cd> -- <col><b>Most Reverend Father in
God</b></col>, <cd>a title given to archbishops and metropolitans, as to
the archbishops of Canterbury and York.</cd> -- <col><b>Natural
father</b></col>, <cd>the father of an illegitimate child.</cd> --
<col><b>Putative father</b></col>, <cd>one who is presumed to be the
father of an illegitimate child; the supposed father.</cd> --
<col><b>Spiritual father</b></col>. <sd>(a)</sd> <cd>A religious teacher
or guide, esp. one instrumental in leading a soul to God.</cd>
<sd>(b)</sd> <fld>(R. C. Ch.)</fld> <cd>A priest who hears confession in
the sacrament of penance.</cd> -- <col><b>The Holy Father</b></col>
<fld>(R. C. Ch.)</fld>, <cd>the pope.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Father</ent><br/
<hw>Fa"ther</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Fathered</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Fathering</conjf>.]</vmorph> <sn>1.</sn> <def>To make
one's self the father of; to beget.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Cowards <qex>father</qex> cowards, and base things sire base.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To take as one's own child; to adopt; hence, to
assume as one's own work; to acknowledge one's self author of or
responsible for (a statement, policy, etc.).</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Men of wit<br/
Often <qex>fathered</qex> what he writ.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To provide with a father.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Think you I am no stronger than my sex,<br/
Being so <qex>fathered</qex> and so husbanded ?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>To father on</b></col> <it>or</it> <col><b>To
father upon</b></col></mcol>, <cd>to ascribe to, or charge upon, as
one's offspring or work; to put or lay upon as being responsible.</cd>
<ldquo/Nothing can be so uncouth or extravagant, which may not be
<xex>fathered on</xex> some fetch of wit, or some caprice of
humor.<rdquo/ <au>Barrow.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Father-God</ent><br/
<hw>Father-God</hw> <pos>n.</pos> <def>God, when considered as the first
person in the Trinity.</def><br/
<syn><b>Syn. --</b> Father.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><-- p. 546 --></p>

<p><ent>Fatherhood</ent><br/
<hw>Fa"ther*hood</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state of
being a father; the character or authority of a father;
paternity.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Father-in-law</ent><br/
<hw>Fa"ther-in-law`</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Fathers-in-law</plw> <pr>(<?/)</pr>.</plu> <def>The father of one's
husband or wife; -- correlative to <xex>son-in-law</xex> and
<xex>daughter-in-law</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ A man who marries a woman having children already, is
sometimes, though erroneously, called their
<xex>father-in-law</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fatherland</ent><br/
<hw>Fa"ther*land"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Imitated fr. D.
<ets>vaderland</ets>. See <er>Father</er>, and <er>Land</er>.]</ety>
<def>One's native land; the native land of one's fathers or
ancestors.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Father-lasher</ent><br/
<hw>Fa"ther-lash`er</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>A European marine fish (<spn>Cottus bubalis</spn>), allied to the
sculpin; -- called also <altname>lucky proach</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fatherless</ent><br/
<hw>Fa"ther*less</hw>, <pos>a.</pos> <sn>1.</sn> <def>Destitute of a
living father; <as>as, a <ex>fatherless</ex> child</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Without a known author.</def> <rj><au>Beau. &
Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fatherlessness</ent><br/
<hw>Fa"ther*less*ness</hw>, <pos>n.</pos> <def>The state of being
without a father.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fatherliness</ent><br/
<hw>Fa"ther*li*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<er>Fatherly</er>.]</ety> <def>The qualities of a father; parantal
kindness, care, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Father longlegs</ent><br/
<hw>Fa"ther long"legs`</hw> <pr>(?)</pr>. <fld>(Zool.)</fld> <def>See
<er>Daddy longlegs</er>, 2.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fatherly</ent><br/
<hw>Fa"ther*ly</hw>, <pos>a.</pos> <sn>1.</sn> <def>Like a father in
affection and care; paternal; tender; protecting; careful.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>You have showed a tender, <qex>fatherly</qex> regard.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of or pertaining to a father.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fathership</ent><br/
<hw>Fa"ther*ship</hw>, <pos>n.</pos> <def>The state of being a father;
fatherhood; paternity.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fathom</ent><br/
<hw>Fath"om</hw> <pr>(f<acr/<th/"<ucr/m)</pr>, <pos>n.</pos> <ety>[OE.
<ets>fadme</ets>, <ets>fa<edh/me</ets>, AS. <ets>f<ae/<edh/m</ets>
fathom, the embracing arms; akin to OS. <ets>fa<edh/mos</ets> the
outstretched arms, D. <ets>vadem</ets>, <ets>vaam</ets>, fathom, OHG.
<ets>fadom</ets>, <ets>fadum</ets>, G. <ets>faden</ets> fathom, thread,
Icel. <ets>fa<edh/mr</ets> fathom, Sw. <ets>famn</ets>, Dan.
<ets>favn</ets>; cf. Gr. <?/<?/<?/<?/<?/<?/<?/<?/<?/<?/ to spread out,
<?/<?/<?/<?/<?/<?/<?/ outspread, flat, L. <ets>patere</ets> to lie open,
extend. Cf. <er>Patent</er>, <er>Petal</er>.]</ety> <sn>1.</sn> <def>A
measure of length, containing six feet; the space to which a man can
extend his arms; -- used chiefly in measuring cables, cordage, and the
depth of navigable water by soundings.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The measure or extant of one's capacity; depth, as
of intellect; profundity; reach; penetration.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Another of his <qex>fathom</qex> they have none<br/
To lead their business.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fathom</ent><br/
<hw>Fath"om</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Fathomed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Fathoming</conjf>.]</vmorph> <sn>1.</sn> <def>To encompass with
the arms extended or encircling; to measure by throwing the arms about;
to span.</def> <mark>[Obs.]</mark> <rj><au>Purchas.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To measure by a sounding line; especially, to sound
the depth of; to penetrate, measure, and comprehend; to get to the
bottom of.</def> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The page of life that was spread out before me seemed dull and
commonplace, only because I had not <qex>fathomed</qex> its deeper
import.</q> <rj><qau>Hawthotne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fathomable</ent><br/
<hw>Fath"om*a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of being
fathomed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fathomer</ent><br/
<hw>Fath"om*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
fathoms.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fathomless</ent><br/
<hw>Fath"om*less</hw>, <pos>a.</pos> <sn>1.</sn> <def>Incapable of being
fathomed; immeasurable; that can not be sounded.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And buckle in a waist most <qex>fathomless</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Incomprehensible.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>fathomless</qex> absurdity.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fatidical</ent><br/
<hw>Fa*tid"i*cal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>fatidicus</ets>; <ets>fatum</ets> fate + <ets>dicere</ets> to say,
tell.]</ety> <def>Having power to foretell future events; prophetic;
fatiloquent; <as>as, the <ex>fatidical</ex> oak</as>.</def>
<mark>[R.]</mark> <au>Howell.</au> --
<wordforms><wf>Fa*tid"i*cal*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fatiferous</ent><br/
<hw>Fa*tif"er*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>fatifer</ets>; <ets>fatum</ets> fate + <ets>ferre</ets> to bear,
bring.]</ety> <def>Fate-bringing; deadly; mortal; destructive.</def>
<mark>[R.]</mark> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fatigable</ent><br/
<hw>Fat"i*ga*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>fatigabilis</ets>: cf. F. <ets>fatigable</ets>. See
<er>Fatigue</er>.]</ety> <def>Easily tired.</def> <mark>[Obs.]</mark>
<rj><au>Bailey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fatigate</ent><br/
<hw>Fat"i*gate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>fatigatus</ets>, p. p. of <ets>fatigare</ets>. See
<ets>Fatigue</ets>.]</ety> <def>Wearied; tired; fatigued.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Requickened what in flesh was <qex>fatigate</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fatigate</ent><br/
<hw>Fat"i*gate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To weary; to
tire; to fatigue.</def> <mark>[Obs.]</mark> <rj><au>Sir T.
Elyot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fatigation</ent><br/
<hw>Fat`i*ga"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>fatigatio</ets>: cf. OF. <ets>fatigation</ets>.]</ety>
<def>Weariness.</def> <mark>[Obs.]</mark> <rj><au>W.
Montaqu.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fatigue</ent><br/
<hw>Fa*tigue"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr.
<ets>fatiguer</ets> to fatigue, L. <ets>fatigare</ets>; cf. L.
<ets>affatim</ets> sufficiently.]</ety> <sn>1.</sn> <def>Weariness from
bodily labor or mental exertion; lassitude or exhaustion of
strength.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The cause of weariness; labor; toil; <as>as, the
<ex>fatigues</ex> of war</as>.</def> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The weakening of a metal when subjected to repeated
vibrations or strains.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fatigue call</b></col> <fld>(Mil.)</fld>, <cd>a summons,
by bugle or drum, to perform fatigue duties.</cd> -- <col><b>Fatigue
dress</b></col>, <cd>the working dress of soldiers.</cd> --
<col><b>Fatigue duty</b></col> <fld>(Mil.)</fld>, <cd>labor exacted from
soldiers aside from the use of arms.</cd> <au>Farrow.</au> --
<col><b>Fatigue party</b></col>, <cd>a party of soldiers on fatigue
duty.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fatigue</ent><br/
<hw>Fa*tigue"</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Fatigued</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Fatiguing</conjf>, <pos>n.</pos>]</vmorph> <ety>[Cf. F.
<ets>fatiguer</ets>. See <er>Fatigue</er>, <pos>n.</pos>]</ety> <def>To
weary with labor or any bodily or mental exertion; to harass with toil;
to exhaust the strength or endurance of; to tire.</def></p>

<p><syn><b>Syn.</b> -- To jade; tire; weary; bore. See
<er>Jade</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fatiloquent</ent><br/
<hw>Fa*til"o*quent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Fatiloquist</er>.]</ety> <def>Prophetic; fatidical.</def>
<mark>[Obs.]</mark> <rj><au>Blount.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fatiloquist</ent><br/
<hw>Fa*til"o*quist</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>fatiloquus</ets> declaring fate; <ets>fatum</ets> fate+
<ets>Loqui</ets> to speak.]</ety> <def>A fortune teller.</def></p>

<p><ent>Fatimide</ent><br/
<ent>Fatimite</ent><br/
<mhw>{ <hw>Fat"i*mite</hw> <pr>(?)</pr>, <hw>Fat"i*mide</hw>
<pr>(?)</pr> }</mhw>, <pos>a.</pos> <fld>(Hist.)</fld> <def>Descended
from Fatima, the daughter and only child of Mohammed.</def> --
<def2><pos>n.</pos> <def>A descendant of Fatima.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fatiscence</ent><br/
<hw>Fa*tis"cence</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>fatiscense</ets>, p. pr. of <ets>fatiscere</ets> to gape or crack
open.]</ety> <def>A gaping or opening; state of being chinky, or having
apertures.</def> <rj><au>Kirwan.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fat-kidneyed</ent><br/
<hw>Fat"-kid`neyed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Gross;
lubberly.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Peace, ye <qex>fat-kidneyed</qex> rascal !</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fatling</ent><br/
<hw>Fat"ling</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Fat</ets> +
<ets>-ling</ets>.]</ety> <def>A calf, lamb, kid, or other young animal
fattened for slaughter; a fat animal; -- said of such animals as are
used for food.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He sacrificed oxen and <qex>fatlings</qex>.</q> <rj><qau>2 Sam.
vi. 13.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fatly</ent><br/
<hw>Fat"ly</hw>, <pos>adv.</pos> <def>Grossly; greasily.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fatner</ent><br/
<hw>Fat"ner</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who fattens.
<mark>[R.]</mark> See <er>Fattener</er>.</def>
<rj><au>Arbuthnit.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fatness</ent><br/
<hw>Fat"ness</hw>, <pos>n.</pos> <sn>1.</sn> <def>The quality or state
of being fat, plump, or full-fed; corpulency; fullness of
flesh.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Their eyes stand out with <qex>fatness</qex>.</q> <rj><qau>Ps.
lxxiii. 7.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence; Richness; fertility; fruitfulness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Rich in the <qex>fatness</qex> of her plenteous soil.</q>
<rj><qau>Rowe.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which makes fat or fertile.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The clouds drop <qex>fatness</qex>.</q>
<rj><qau>Philips.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>fatso</ent><br/
<hw>fatso</hw> <pos>n.</pos> <def>a rotund, obese individual.</def><br/
<syn><b>Syn. --</b> fatty, fat person, roly-poly.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fatten</ent><br/
<hw>Fat"ten</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Fattened</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Fattening</conjf> <pr>(?)</pr>.]</vmorph> <ety>[See
<er>Fat</er>, <pos>v. t.</pos>]</ety> <sn>1.</sn> <def>To make fat; to
feed for slaughter; to make fleshy or plump with fat; to fill full; to
fat.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To make fertile and fruitful; to enrich; <as>as, to
<ex>fatten</ex> land; to <ex>fatten</ex> fields with blood.</as></def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fatten</ent><br/
<hw>Fat"ten</hw>, <pos>v. i.</pos> <def>To grow fat or corpulent; to
grow plump, thick, or fleshy; to be pampered.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And villains <qex>fatten</qex> with the brave man's labor.</q>
<rj><qau>Otway.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>fattened</ent><br/
<hw>fattened</hw> <pos>adj.</pos> <def>fed until grown and ready for
slaughter or for sale in the market; -- of market animals.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Fattener</ent><br/
<hw>Fat"ten*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, fattens; that which gives fatness or fertility.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fattiness</ent><br/
<hw>Fat"ti*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>State or quality
of being fatty.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fattish</ent><br/
<hw>Fat"tish</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Somewhat fat;
inclined to fatness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Coleridge, a puffy, anxious, obstructed-looking,
<qex>fattish</qex> old man.</q> <rj><qau>Carlyle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>fattism</ent><br/
<hw>fattism</hw> <pos>n.</pos> <def>discrimination against people who
are overweight.</def><br/
<syn><b>Syn. --</b> fatism.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fatty</ent><br/
<hw>Fat"ty</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Containing fat, or
having the qualities of fat; greasy; gross; <as>as, a <ex>fatty</ex>
substance</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fatty acid</b></col> <fld>(Chem.)</fld>, <cd>any one of
the paraffin series of monocarbonic acids, as formic acid, acetic, etc.;
-- so called because the higher members, as stearic and palmitic acids,
occur in the natural fats, and are themselves fatlike substances.</cd>
-- <col><b>Fatty clays</b></col>. <cd>See under <er>Clay</er>.</cd> --
<col><b>Fatty degeneration</b></col> <fld>(Med.)</fld>, <cd>a diseased
condition, in which the oil globules, naturally present in certain
organs, are so multiplied as gradually to destroy and replace the
efficient parts of these organs.</cd> -- <mcol><col><b>Fatty
heart</b></col>, <col><b>Fatty liver</b></col></mcol>, <cd>etc.
<fld>(Med.)</fld>, a heart, liver, etc., which have been the subjects of
fatty degeneration or infiltration.</cd> -- <col><b>Fatty
infiltration</b></col> <fld>(Med.)</fld>, <cd>a condition in which there
is an excessive accumulation of fat in an organ, without destruction of
any essential parts of the latter.</cd> -- <col><b>Fatty tumor</b></col>
<fld>(Med.)</fld>, <cd>a tumor consisting of fatty or adipose tissue;
lipoma.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fatuitous</ent><br/
<hw>Fa*tu"i*tous</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Stupid;
fatuous.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fatuity</ent><br/
<hw>Fa*tu"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>fatuitas</ets>, fr. <ets>fatuus</ets> foolish: cf. F.
<ets>fatuit<eacute/</ets> Cf. <er>Fatuous</er>.]</ety> <def>Weakness or
imbecility of mind; stupidity.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Those many forms of popular <qex>fatuity</qex>.</q> <rj><qau>I
Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fatuous</ent><br/
<hw>Fat"u*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>fatuus</ets>.]</ety> <sn>1.</sn> <def>Feeble in mind; weak; silly;
stupid; foolish; fatuitous.</def> <rj><au>Glanvill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Without reality; illusory, like the <xex>ignis
fatuus</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thence <qex>fatuous</qex> fires and meteors take their birth.</q>
<rj><qau>Danham.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>fatuousness</ent><br/
<hw>fatuousness</hw> <pos>n.</pos> <def>a ludicrous folly.</def><br/
<syn><b>Syn. --</b> absurdity, fatuity, silliness.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>fatwah</ent><br/
<ent>fatwa</ent><br/
<mhw><hw>fat"wa</hw>, <hw>fat"wah</hw></mhw> <pr>(?)</pr>, <pos>n.</pos>
<def>Same as <er>fetwah</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Fat-witted</ent><br/
<hw>Fat"-wit`ted</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Dull;
stupid.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Faubourg</ent><br/
\'d8<hw>Fau`bourg"</hw> <pr>(f<omac/`b<oomac/r"; E.
f<omac/"b<oomac/rg)</pr>, <pos>n.</pos> <ety>[F.]</ety> <def>A suburb of
a French city; also, a district now within a city, but formerly without
its walls.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Faucal</ent><br/
<hw>Fau"cal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>fauces</ets>
throat.]</ety> <def>Pertaining to the fauces, or opening of the throat;
faucial;</def> <specif>esp.,</specif> <fld>(Phon.)</fld> <def>produced
in the fauces, as certain deep guttural sounds found in the Semitic and
some other languages.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Ayin is the most difficult of the <qex>faucals</qex>.</q>
<rj><qau>I. Taylor (The Alphabet).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fauces</ent><br/
\'d8<hw>Fau"ces</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[L.]</ety>
<sn>1.</sn> <fld>(Anat.)</fld> <def>The narrow passage from the mouth to
the pharynx, situated between the soft palate and the base of the
tongue; -- called also the <altname>isthmus of the fauces</altname>. On
either side of the passage two membranous folds, called the <xex>pillars
of the fauces</xex>, inclose the tonsils.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>The throat of a calyx, corolla,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <def>That portion of the interior of a
spiral shell which can be seen by looking into the aperture.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Faucet</ent><br/
<hw>Fau"cet</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>fausset</ets>, perh. fr. L. <ets>fauces</ets> throat.]</ety>
<sn>1.</sn> <def>A fixture for drawing a liquid, as water, molasses,
oil, etc., from a pipe, cask, or other vessel, in such quantities as may
be desired; -- called also <altname>tap</altname>, and
<altname>cock</altname>. It consists of a tubular spout, stopped with a
movable plug, spigot, valve, or slide.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The enlarged end of a section of pipe which receives
the spigot end of the next section.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fauchion</ent><br/
<hw>Fau"chion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Falchion</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Faucial</ent><br/
<hw>Fau"cial</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Anat.)</fld>
<def>Pertaining to the fauces; pharyngeal.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Faugh</ent><br/
<hw>Faugh</hw> <pr>(?)</pr>, <pos>interj.</pos> <ety>[Cf.
<er>Foh</er>.]</ety> <def>An exclamation of contempt, disgust, or
abhorrence.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Faulchion</ent><br/
<hw>Faul"chion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Falchion</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Faulcon</ent><br/
<hw>Faul"con</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>See <er>Falcon</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fauld</ent><br/
<hw>Fauld</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The arch over the dam of
a blast furnace; the tymp arch.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Faule</ent><br/
<hw>Faule</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A fall or falling
band.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>These laces, ribbons, and these <qex>faules</qex>.</q>
<rj><qau>Herrick.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fault</ent><br/
<hw>Fault</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>faut</ets>,
<ets>faute</ets>, F. <ets>faute</ets> (cf. It., Sp., & Pg.
<ets>falta</ets>), fr. a verb meaning <ets>to want</ets>,
<ets>fail</ets>, freq., fr. L. <ets>fallere</ets> to deceive. See
<er>Fail</er>, and cf. <er>Default</er>.]</ety> <sn>1.</sn> <def>Defect;
want; lack; default.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>One, it pleases me, for <qex>fault</qex> of a better, to call my
friend.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Anything that fails, that is wanting, or that
impairs excellence; a failing; a defect; a blemish.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>As patches set upon a little breach<br/
Discredit more in hiding of the <qex>fault</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A moral failing; a defect or dereliction from duty;
a deviation from propriety; an offense less serious than a
crime.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Geol. & Mining)</fld> <sd>(a)</sd> <def>A
dislocation of the strata of the vein.</def> <sd>(b)</sd> <def>In coal
seams, coal rendered worthless by impurities in the seam; <as>as, slate
<ex>fault</ex>, dirt <ex>fault</ex>, etc.</as></def>
<rj><au>Raymond.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Hunting)</fld> <def>A lost scent; act of losing the
scent.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Ceasing their clamorous cry till they have singled,<br/
With much ado, the cold <qex>fault</qex> cleary out.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Tennis)</fld> <def>Failure to serve the ball into
the proper court.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Elec.)</fld> <def>A defective point in an electric
circuit due to a crossing of the parts of the conductor, or to contact
with another conductor or the earth, or to a break in the
circuit.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>8.</sn> <fld>(Geol. & Mining)</fld> <def>A dislocation caused by
a slipping of rock masses along a plane of facture; also, the dislocated
structure resulting from such slipping.</def></p>

<p><note>The surface along which the dislocated masses have moved is
called the <col><b>fault plane</b></col>. When this plane is vertical,
the fault is a <col><b>vertical fault</b></col>; when its inclination is
such that the present relative position of the two masses could have
been produced by the sliding down, along the fault plane, of the mass on
its upper side, the fault is a <mcol><col><b>normal fault</b></col>,
<it>or</it> <col><b>gravity fault</b></col></mcol>. When the fault plane
is so inclined that the mass on its upper side has moved up relatively,
the fault is then called a <mcol><col><b>reverse fault</b></col> (or
<col><b>reversed fault</b></col>), <col><b>thrust fault</b></col>, or
<col><b>overthrust fault</b></col></mcol>. If no vertical displacement
has resulted, the fault is then called a <col><b>horizontal
fault</b></col>. The linear extent of the dislocation measured on the
fault plane and in the direction of movement is the
<col><b>displacement</b></col>; the vertical displacement is the
<col><b>throw</b></col>; the horizontal displacement is the
<col><b>heave</b></col>. The direction of the line of intersection of
the fault plane with a horizontal plane is the <col><b>trend</b></col>
of the fault. A fault is a <col><b>strike fault</b></col> when its trend
coincides approximately with the strike of associated strata (i.e., the
line of intersection of the plane of the strata with a horizontal
plane); it is a <col><b>dip fault</b></col> when its trend is at right
angles to the strike; an <col><b>oblique fault</b></col> when its trend
is oblique to the strike. Oblique faults and dip faults are sometimes
called <col><b>cross faults</b></col>. A series of closely associated
parallel faults are sometimes called <col><b>step faults</b></col> and
sometimes <col><b>distributive faults</b></col>.</note><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><cs><col><b>At fault</b></col>, <cd>unable to find the scent and
continue chase; hence, in trouble or embarrassment, and unable to
proceed; puzzled; thrown off the track.</cd> -- <col><b>To find
fault</b></col>, <cd>to find reason for blaming or complaining; to
express dissatisfaction; to complain; -- followed by <xex>with</xex>
before the thing complained of; but formerly by <xex>at</xex>.</cd>
<ldquo/Matter <xex>to find fault at</xex>.<rdquo/ <rj><au>Robynson
(More's Utopia).</au></rj></cs></p>

<p><syn><b>Syn.</b> -- -- Error; blemish; defect; imperfection;
weakness; blunder; failing; vice.</syn> <usage> -- <er>Fault</er>,
<er>Failing</er>, <er>Defect</er>, <er>Foible</er>. A <xex>fault</xex>
is positive, something morally wrong; a <xex>failing</xex> is negative,
some weakness or falling short in a man's character, disposition, or
habits; a <xex>defect</xex> is also negative, and as applied to
character is the absence of anything which is necessary to its
completeness or perfection; a <xex>foible</xex> is a less important
weakness, which we overlook or smile at. A man may have many
<xex>failings</xex>, and yet commit but few <xex>faults</xex>; or his
<xex>faults</xex> and <xex>failings</xex> may be few, while his
<xex>foibles</xex> are obvious to all. The <xex>faults</xex> of a friend
are often palliated or explained away into mere <xex>defects</xex>, and
the <xex>defects</xex> or <xex>foibles</xex> of an enemy exaggerated
into <xex>faults</xex>. <ldquo/I have <xex>failings</xex> in common with
every human being, besides my own peculiar <xex>faults</xex>; but of
avarice I have generally held myself guiltless.<rdquo/ <au>Fox.</au>
<ldquo/Presumption and self-applause are the <xex>foibles</xex> of
mankind.<rdquo/ <au>Waterland.</au></usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fault</ent><br/
<hw>Fault</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Faulted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Faulting</conjf>.]</vmorph> <sn>1.</sn> <def>To charge with a
fault; to accuse; to find fault with; to blame.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>For that I will not <qex>fault</qex> thee.</q> <rj><qau>Old
Song.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Geol.)</fld> <def>To interrupt the continuity of
(rock strata) by displacement along a plane of fracture; -- chiefly used
in the p. p.; <as>as, the coal beds are badly
<ex>faulted</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fault</ent><br/
<hw>Fault</hw>, <pos>v. i.</pos> <def>To err; to blunder, to commit a
fault; to do wrong.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>If after Samuel's death the people had asked of God a king, they
had not <qex>faulted</qex>.</q> <rj><qau>Latimer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Faulter</ent><br/
<hw>Fault"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who commits a
fault.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Behold the <qex>faulter</qex> here in sight.</q>
<rj><qau>Fairfax.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fault-finder</ent><br/
<hw>Fault"-find`er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who makes a
practice of discovering others' faults and censuring them; a
scold.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fault-finding</ent><br/
<hw>Fault"-find`ing</hw>, <pos>n.</pos> <def>The act of finding fault or
blaming; -- used derogatively. Also <pos>Adj.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Faultful</ent><br/
<hw>Fault"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Full of faults or
sins.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Faultily</ent><br/
<hw>Fault"i*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a faulty
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Faultiness</ent><br/
<hw>Fault"i*ness</hw>, <pos>n.</pos> <def>Quality or state of being
faulty.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Round, even to <qex>faultiness</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Faulting</ent><br/
<hw>Fault"ing</hw>, <pos>n.</pos> <fld>(Geol.)</fld> <def>The state or
condition of being faulted; the process by which a fault is
produced.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Faultless</ent><br/
<hw>Fault"less</hw>, <pos>a.</pos> <def>Without fault; not defective or
imperfect; free from blemish; free from incorrectness, vice, or offense;
perfect; <as>as, a <ex>faultless</ex> poem</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Whoever thinks a <xex>faultless</xex> piece to see,<br/
Thinks what ne'er was, nor is, nor e'er shall be.</q>
<rj><qau>Pope.</qau></rj></p>

<p><syn><b>Syn.</b> -- Blameless; spotless; perfect. See
<er>Blameless</er>.</syn></p>

<p>-- <wordforms><wf>Fault"less*ly</wf>,
<pos>adv.</pos>-<wf>Fault"less*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Faulty</ent><br/
<hw>Fault"y</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Containing
faults, blemishes, or defects; imperfect; not fit for the use
intended.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Created once<br/
So goodly and erect, though <qex>faulty</qex> since.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Guilty of a fault, or of faults; hence, blamable;
worthy of censure.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The king doth speak . . . as one which is <qex>faulty</qex>.</q>
<rj><qau>2 Sam. xiv. 13.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Faun</ent><br/
<hw>Faun</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>Faunus</ets>,
fr. <ets>favere</ets> to be favorable. See <er>Favor</er>.]</ety>
<fld>(Rom. Myth.)</fld> <def>A god of fields and shepherds, differing
little from the satyr. The fauns are usually represented as half goat
and half man.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Satyr or <qex>Faun</qex>, or Sylvan.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fauna</ent><br/
<hw>Fau"na</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL.: cf. F.
<ets>faune</ets>. See <er>Faun</er>.]</ety> <fld>(Zool.)</fld> <def>The
animals of any given area or epoch; <as>as, the <ex>fauna</ex> of
America; fossil <ex>fauna</ex>; recent <ex>fauna</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Faunal</ent><br/
<hw>Fau"nal</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Relating to
fauna.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Faunist</ent><br/
<hw>Fau"nist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who describes the
fauna of country; a naturalist.</def> <rj><au>Gilbert
White.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Faunus</ent><br/
\'d8<hw>Fau"nus</hw> <pr>(?)</pr>, <pos>n.</pos>;<plu><it>pl.</it>
<plw>Fauni</plw> <pr>(#)</pr>.</plu> <ety>[L.]</ety> <fld>(Myth.)</fld>
<def>See <er>Faun</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fausen</ent><br/
<hw>Fau"sen</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. W.
<ets>llysowen</ets> eel, <ets>ll</ets> sounding in Welsh almost like
<ets>fl</ets>.]</ety> <fld>(Zool.)</fld> <def>A young eel.</def>
<mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fausse-braye</ent><br/
\'d8<hw>Fausse`-braye"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>fausse-braie</ets>.]</ety> <fld>(Mil.)</fld> <def>A second rampart,
exterior to, and parallel to, the main rampart, and considerably below
its level.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Faust</ent><br/
<hw>Faust</hw> <pr>(foust)</pr>. <sn>1.</sn> <def>A tragedy by Goethe,
commenced in 1772, and published as <ldquo/Faust, ein Fragment<rdquo/ in
1790. Part 1, complete, was published as "Faust, eine Trag<oum/die" in
1808; part 2, finished in 1831, was published in 1833. It has been
translated into English by Bayard Taylor, Blackie, Anster, Hayward,
Martin, and others (nearly 40 in all). Goethe accomplished the
transformation of Faust from a common necromancer and conjurer into a
personification of humanity, tempted and disquieted, but at length
groping its way to the light. See <er>Goethe</er>.</def><br/
[<source>Century Dict. 1906</source>]</p>

<p><sn>2.</sn> <def>An opera by Gounod (words, after Goethe, by
Carr<eacute/ and Barbier) represented at the Th<eacute/<acir/tre
Lyrique, Paris, March 19, 1859.</def><br/
[<source>Century Dict. 1906</source>]</p>

<p><sn>3.</sn> <def>An opera by Spohr, first produced at Frankfurt in
1818. The words, which do not follow Goethe's play, are by
Bernhard.</def><br/
[<source>Century Dict. 1906</source>]</p>

<p><ent>Faust</ent><br/
<ent>Faustus</ent><br/
<mhw><hw>Faust</hw>, or <hw>Faust"us</hw>
<pr>(f<acir/s"tus)</pr>.</mhw>, <pos>prop. n.</pos> <def><person>Doctor
Johann Faust</person>, a person born at <city>Kundling</city>
(Knittlingen), W<uum/rtemberg, or at <country>Roda</country>, near
<city>Weimar</city>, and said to have died in 1538. He was a man of
licentious character, a magician, astrologer, alchemist, and soothsayer,
who boasted of performing the miracles of <persfn>Christ</persfn>.
German legend has it that he sold his soul to the devil in exchange for
knowledge. It was believed that he was carried off at last by the devil,
who had lived with him in the form of a black dog.</def><br/
[<source>Century Dict. 1906</source>]</p>

<p><note><hand/ The legends of <persfn>Faust</persfn> were gathered from
the then recent traditions concerning him in a book which appeared at
the book-fair at <city>Frankfurt-on-the-Main</city> in 1587. It was
called "The History of Dr. Faustus, the Notorious Magician and Master of
the Black Art, etc." Soon after its appearance it became known in
England.<br/
<br/
<q>A metrical version of it into English was licensed by <person>Aylmer,
Bishop of London</person>, before the end of the year. In 1588 there was
a rimed version of it into German, also a translation into low German,
and a new edition of the original with some slight changes. In 1689
there appeared a version of the first German Faust book into, French, by
<person>Victor Palma Cayet</person>. The English prose version was made
from the second edition of the original, that of 1588, and is undated,
but probably was made at once. There was a revised edition of it in
1592. In 1592 there was a Dutch translation from the second German
edition. This gives the time of the carrying off of Faustus by the devil
as the night between the twenty-third and twenty-fourth of October,
1538. The English version also gives 1538 as the year, and it is a date,
as we have seen, consistent with trustworthy references to his actual
life. <persfn>Marlowe's</persfn> play ('The Tragical History of Doctor
Faustus') was probably written in 1588, soon after the original story
had found its way to England. He treated the legend as a poet, bringing
out with all his power its central thought -- man in the pride of
knowledge turning from his God.</q> <qau>(Morley, Eng. Writers, IX.
254.)</qau><br/
<br/
This play was brought to <country>Germany</country> about the beginning
of the 17th century, and, after passing through various developments on
the stage, finally became a puppet-play, which is still in existence.
<persfn>Lessing</persfn> wrote parts of two versions of the story.
<persfn>M<uum/ller</persfn>, the painter, published two fragments of his
dramatized life of Faust in 1778. <persfn>Goethe's</persfn> tragedy
(which see) was not published till 1808. <persfn>Klinger</persfn>
published a romance "Faust's Leben, Thaten und H<oum/llenfahrt" (1791:
Borrow translated it in 1826). <persfn>Klingemann</persfn> published a
tragedy on the subject (1815), <persfn>Heine</persfn> a ballet "Der
Doctor Faust, ein Tanzpoem" (1851), and Lenau an epic "Faust" (1836).
<person>W. G. Wills</person> adapted a play from
<persfn>Goethe's</persfn> "Faust," which <person>Henry Irving</person>
produced in 1885. <persfn>Calderon's</persfn> play "El Magico
Prodigioso" strongly resembles Goethe's and Marlowe's plays, though
founded on the legend of <person>St. Cyprian</person>.</note><br/
[<source>Century Dict. 1906</source>]</p>

<p><ent>Faustian</ent><br/
<hw>Fau"sti*an</hw> <pr>(fou"st<emac/*<ait/n)</pr>. <pos>prop.
adj.</pos> <def>Pertainnig to or resembling or befitting
<persfn>Faust</persfn> especially in insatiable striving for worldly
knowledge and power even at the price of spiritual values; <as>as, a
<ex>Faustian</ex> pact with the devil.</as>.</def><br/
[<source>WordNet 1.6</source>]</p>

<p><ent>Fauteuil</ent><br/
\'d8<hw>Fau`teuil"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. See
<er>Faldistory</er>.]</ety> <sn>1.</sn> <def>An armchair; hence (because
the members sit in fauteuils or armchairs), membership in the French
Academy.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Chair of a presiding officer.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fautor</ent><br/
<hw>Fau"tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., contr. fr.
<ets>favitor</ets>, fr. <ets>favere</ets> to be favorable: cf. F.
<ets>fauteur</ets>. See <er>Favor</er>.]</ety> <def>A favorer; a patron;
one who gives countenance or support; an abettor.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The king and the <qex>fautors</qex> of his proceedings.</q>
<rj><qau>Latimer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fautress</ent><br/
<hw>Fau"tress</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>fauutrix</ets>: cf. F. <ets>fautrice</ets>.]</ety> <def>A
patroness.</def> <mark>[Obs.]</mark> <rj><au>Chapman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fauvette</ent><br/
\'d8<hw>Fau`vette"</hw> <pr>(f<omac/`v<ecr/t")</pr>, <pos>n.</pos>
<ety>[F., dim. fr. <ets>fauve</ets> fawn-colored.]</ety>
<fld>(Zool.)</fld> <def>A small singing bird, as the nightingale and
warblers.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 547 --></p>

<p><ent>faux</ent><br/
\'d8<hw>faux</hw> <pr>(f<add/ks)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>fauces</plw> <pr>(f<add/"s<emac/z)</pr>.</plu> <ety>[L.]</ety>
<def>See <er>Fauces</er>.</def></p>

<p><ent>faux pas</ent><br/
\'d8<hw>faux` pas"</hw> <pr>(f<omac/` p<adot/")</pr>. <ety>[F. See
<er>False</er>, and <er>Pas</er>.]</ety> <def>A false step; a mistake or
wrong measure;</def> <specif>especially,</specif> <def>a slip or misstep
in social etiquette; a blunder in conduct or manners that causes
embarassment; <as>as, he committed the <ex>faux pas</ex> of mentioning
John's former wife</as>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Favaginous</ent><br/
<hw>Fa*vag"i*nous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>favus</ets> a honeycomb.]</ety> <def>Formed like, or resembling, a
honeycomb.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Favas</ent><br/
<hw>Fa"vas</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See <er>Favus</er>,
<pos>n.</pos>, 2.</def> <rj><au>Fairholt.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>favel</ent><br/
<hw>fa"vel</hw> <pr>(f<amac/"v<ecr/l)</pr>, <pos>a.</pos> <ety>[OF.
<ets>fauvel</ets>, <ets>favel</ets>, dim. of F. <ets>fauve</ets>; of
German oigin. See <er>Fallow</er>, <pos>a.</pos>]</ety> <def>Yellow;
fallow; dun.</def> <mark>[Obs.]</mark> <rj><au>Wright.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>favel</ent><br/
<hw>fa"vel</hw>, <pos>n.</pos> <def>A horse of a favel or dun
color.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To curry favel</b></col>. <cd>See <cref>To curry
favor</cref>, under <er>Favor</er>, <pos>n.</pos></cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>favel</ent><br/
<hw>fa"vel</hw>, <pos>n.</pos> <ety>[OF. <ets>favele</ets>, fr. L.
<ets>fabella</ets> short fable, dim. of <ets>fabula</ets>. See
<er>Fable</er>.]</ety> <def>Flattery; cajolery; deceit.</def>
<mark>[Obs.]</mark> <rj><au>Skeat.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>favella</ent><br/
\'d8<hw>fa*vel"la</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., prob. from
L. <ets>favus</ets> a honeycomb.]</ety> <fld>(Bot.)</fld> <def>A group
of spores arranged without order and covered with a thin gelatinous
envelope, as in certain delicate red alg<ae/.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>faveolate</ent><br/
<hw>fa*ve"o*late</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>favus</ets> honeycomb.]</ety> <def>Honeycomb; having cavities or
cells, somewhat resembling those of a honeycomb; alveolate;
favose.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Favier explosive</ent><br/
<hw>Fa`vier" ex*plo"sive</hw> <pr>(?)</pr> <pos>prop. n.</pos>.
<ety>[After the inventor, <person>P. A. <etsep>Favier</etsep></person>,
a Frenchman.]</ety> <def>Any of several explosive mixtures, chiefly of
ammonium nitrate and a nitrate derivative of naphthalene. They are
stable, but require protection from moisture. As prepared it is a
compressed cylinder of the explosive, filled with loose powder of the
same composition, all inclosed in waterproof wrappers. It is used for
mining.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>favillous</ent><br/
<hw>fa*vil"lous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>favilla</ets> sparkling or glowing ashes.]</ety> <def>Of or
pertaining to ashes.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Light and <qex>favillous</qex> particles.</q> <rj><qau>Sir T.
Browne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>favonian</ent><br/
<hw>fa*vo"ni*an</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>Favonius</ets> the west wind.]</ety> <def>Pertaining to the west
wind; soft; mild; gentle.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>favor</ent><br/
<hw>fa"vor</hw> <pr>(f<amac/"v<etil/r)</pr>, <pos>n.</pos> <ety>[Written
also <ets>favour</ets>.]</ety> <ety>[OF. <ets>favor</ets>, F.
<ets>faveur</ets>, L. <ets>favor</ets>, fr. <ets>favere</ets> to be
favorable, cf. Skr. <ets>bh<amac/vaya</ets> to further, foster,
causative of <ets>bh<umac/</ets> to become, be. Cf. <er>Be</er>. In the
phrase <ets>to curry favor</ets>, <ets>favor</ets> is prob. for
<ets>favel</ets> a horse. See 2d <er>Favel</er>.]</ety> <sn>1.</sn>
<def>Kind regard; propitious aspect; countenance; friendly disposition;
kindness; good will.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Hath crawled into the <qex>favor</qex> of the king.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The act of countenancing, or the condition of being
countenanced, or regarded propitiously; support; promotion;
befriending.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>But found no <qex>favor</qex> in his lady's eyes.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And Jesus increased in wisdom and stature, and in <qex>favor</qex>
with God and man.</q> <rj><qau>Luke ii. 52.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A kind act or office; kindness done or granted;
benevolence shown by word or deed; an act of grace or good will, as
distinct from justice or remuneration.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Beg one <qex>favor</qex> at thy gracious hand.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Mildness or mitigation of punishment;
lenity.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I could not discover the lenity and <qex>favor</qex> of this
sentence.</q> <rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>The object of regard; person or thing
favored.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>All these his wondrous works, but chiefly man,<br/
His chief delight and <qex>favor</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>A gift or present; something bestowed as an evidence
of good will; a token of love; a knot of ribbons; something worn as a
token of affection; <as>as, a marriage <ex>favor</ex> is a bunch or knot
of white ribbons or white flowers worn at a wedding</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Wear thou this <qex>favor</qex> for me, and stick it in thy
cap.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>Appearance; look; countenance; face.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>This boy is fair, of female <qex>favor</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <fld>(Law)</fld> <def>Partiality; bias.</def>
<rj><au>Bouvier.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>A letter or epistle; -- so called in civility or
compliment; <as>as, your <ex>favor</ex> of yesterday is
received</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <pluf>pl.</pluf> <def>Love locks.</def>
<mark>[Obs.]</mark> <rj><au>Wright.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Challenge to the favor</b></col> <it>or</it>
<col><b>Challenge for favor</b></col></mcol> <fld>(Law)</fld>, <cd>the
challenge of a juror on grounds not sufficient to constitute a principal
challenge, but sufficient to give rise to a probable suspicion of favor
or bias, such as acquaintance, business relation, etc. See
<cref>Principal challenge</cref>, under <er>Challenge</er>.</cd> --
<col><b>In favor of</b></col>, <cd>upon the side of; favorable to; for
the advantage of.</cd> -- <col><b>In favor with</b></col>, <cd>favored,
countenanced, or encouraged by.</cd> -- <col><b>To curry favor</b></col>
<ety>[see the etymology of <er>Favor</er>, above]</ety>, <cd>to seek to
gain favor by flattery, caresses, kindness, or officious
civilities.</cd> -- <mcol><col><b>With one's favor</b></col>,
<it>or</it> <col><b>By one's favor</b></col></mcol>, <cd>with leave; by
kind permission.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><q>But, <qex>with your favor</qex>, I will treat it here.</q>
<rj><qau>Dryden.</qau></rj></p>

<p><syn><b>Syn.</b> -- Kindness; countenance; patronage; support;
lenity; grace; gift; present; benefit.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Favor</ent><br/
<hw>Fa"vor</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Favored</conjf> <pr>(f<amac/"v<etil/rd)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Favoring</conjf>.]</vmorph> <ety>[Written also
<ets>favour</ets>.]</ety> <ety>[Cf. OF. <ets>favorer</ets>,
<ets>favorir</ets>. See <er>Favor</er>, <pos>n.</pos>]</ety> <sn>1.</sn>
<def>To regard with kindness; to support; to aid, or to have the
disposition to aid, or to wish success to; to be propitious to; to treat
with consideration or tenderness; to show partiality or unfair bias
towards.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>O happy youth! and <qex>favored</qex> of the skies.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He that <qex>favoreth</qex> Joab, . . . let him go after Joab.</q>
<rj><qau>2 Sam. xx. 11.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>[The painter] has <qex>favored</qex> her squint admirably.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To afford advantages for success to; to facilitate;
<as>as, a weak place <ex>favored</ex> the entrance of the
enemy</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To resemble in features; to have the aspect or looks
of; <as>as, the child <ex>favors</ex> his father</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The porter owned that the gentleman <qex>favored</qex> his
master.</q> <rj><qau>Spectator.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Favorable</ent><br/
<hw>Fa"vor*a*ble</hw> <pr>(f<amac/"v<etil/r*<adot/*b'l)</pr>,
<pos>a.</pos> <altsp>[Written also <asp>favourable</asp>.]</altsp>
<ety>[F. <ets>favorable</ets>, L. <ets>favorabilis</ets> favored,
popular, pleasing, fr. <ets>favor</ets>. See <er>Favor</er>,
<pos>n.</pos>]</ety> <sn>1.</sn> <def>Full of favor; favoring;
manifesting partiality; kind; propitious; friendly.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Lend <qex>favorable</qex> ears to our request.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Lord, thou hast been <qex>favorable</qex> unto thy land.</q>
<rj><qau>Ps. lxxxv. 1.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Conducive; contributing; tending to promote or
facilitate; advantageous; convenient.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A place very <qex>favorable</qex> for the making levies of
men.</q> <rj><qau>Clarendon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The temper of the climate, <qex>favorable</qex> to generation,
health, and long life.</q> <rj><qau>Sir W. Temple.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Beautiful; well-favored.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj></p>

<p>-- <wordforms><wf>Fa"vora*ble*ness</wf>, <pos>n.</pos> --
<wf>Fa"vor*a*bly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>favorableness</qex> of the present times to all exertions
in the cause of liberty.</q> <rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Favored</ent><br/
<hw>Fa"vored</hw> <pr>(f<amac/"v<etil/rd)</pr>, <pos>a.</pos>
<sn>1.</sn> <def>Countenanced; aided; regarded with kindness; <as>as, a
<ex>favored</ex> friend</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Having a certain favor or appearance; featured;
<as>as, well-<ex>favored</ex>; hard-<ex>favored</ex>,
etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Favoredly</ent><br/
<hw>Fa"vored*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a favored or
a favorable manner; favorably.</def> <mark>[Obs.]</mark> <rj><au>Deut.
xvii. 1.</au> <au>Arscham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Favoredness</ent><br/
<hw>Fa"vored*ness</hw>, <pos>n.</pos> <def>Appearance.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Favorer</ent><br/
<hw>Fa"vor*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who favors; one
who regards with kindness or friendship; a well-wisher; one who assists
or promotes success or prosperity.</def> <altsp>[Written also
<asp>favourer</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><q>And come to us as <qex>favorers</qex>, not as foes.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Favoress</ent><br/
<hw>Fa"vor*ess</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A woman who favors
or gives countenance.</def> <altsp>[Written also
<asp>fovouress</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Favoring</ent><br/
<hw>Fa"vor*ing</hw>, <pos>a.</pos> <def>That favors.</def> --
<wordforms><wf>Fa"vor*ing*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Favorite</ent><br/
<hw>Fa"vor*ite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>favorit</ets> favored, F. <ets>favori</ets>, fem.
<ets>favorite</ets>, p. p. of OF. <ets>favorir</ets>, cf. It.
<ets>favorito</ets>, frm. <ets>favorita</ets>, fr. <ets>favorire</ets>
to favor. See <er>Favor</er>.]</ety> <sn>1.</sn> <def>A person or thing
regarded with peculiar favor; one treated with partiality; one preferred
above others; especially, one unduly loved, trusted, and enriched with
favors by a person of high rank or authority.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Committing to a wicked <qex>favorite</qex><br/
All public cares.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <pluf>pl.</pluf> <def>Short curls dangling over the
temples; -- fashionable in the reign of Charles II.</def>
<mark>[Obs.]</mark> <rj><au>Farquhar.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Sporting)</fld> <def>The competitor (as a horse in
a race) that is judged most likely to win; the competitor standing
highest in the betting.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Favorite</ent><br/
<hw>Fa"vor*ite</hw>, <pos>a.</pos> <def>Regarded with particular
affection, esteem, or preference; <as>as, a <ex>favorite</ex> walk; a
<ex>favorite</ex> child.</as></def> <ldquo/His <xex>favorite</xex>
argument.<rdquo/ <rj><au>Macaulay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Favoritism</ent><br/
<hw>Fa"vor*it*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>favoritisme</ets>.]</ety> <def>The disposition to favor and promote
the interest of one person or family, or of one class of men, to the
neglect of others having equal claims; partiality.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A spirit of <qex>favoritism</qex> to the Bank of the United
States.</q> <rj><qau>A. Hamilton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Favorless</ent><br/
<hw>Fa"vor*less</hw>, <pos>a.</pos> <sn>1.</sn> <def>Unfavored; not
regarded with favor; having no countenance or support.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Unpropitious; unfavorable.</def> <mark>[Obs.]</mark>
<ldquo/Fortune <xex>favorless</xex>.<rdquo/
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Favose</ent><br/
<hw>Fa*vose"</hw> <pr>(f<adot/*v<omac/s")</pr>, <pos>a.</pos> <ety>[L.
<ets>favus</ets> honeycomb.]</ety> <sn>1.</sn> <fld>(Bot.)</fld>
<def>Honeycombed. See <er>Faveolate</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Med.)</fld> <def>Of or pertaining to the disease
called favus.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Favosite</ent><br/
<hw>Fav"o*site</hw> <pr>(f<acr/v"<osl/*s<imac/t)</pr>, <pos>a.</pos>
<fld>(Zool.)</fld> <def>Like or pertaining to the genus
<gen>Favosites</gen>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Favosites</ent><br/
\'d8<hw>Fav`o*si"tes</hw> <pr>(f<acr/v`<osl/*s<imac/"t<emac/z)</pr>,
<pos>n.</pos> <ety>[NL. See <er>Favose</er>.]</ety> <fld>(Paleon.)</fld>
<def>A genus of fossil corals abundant in the Silurian and Devonian
rocks, having polygonal cells with perforated walls.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Favus</ent><br/
\'d8<hw>Fa"vus</hw> <pr>(f<amac/"v<ucr/s)</pr>, <pos>n.</pos> <ety>[L.,
honeycomb.]</ety> <sn>1.</sn> <fld>(Med.)</fld> <def>A disease of the
scalp, produced by a vegetable parasite.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A tile or flagstone cut into an hexagonal shape to
produce a honeycomb pattern, as in a pavement; -- called also
<altname>favas</altname> and <altname>sectila</altname>.</def>
<rj><au>Mollett.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fawe</ent><br/
<hw>Fawe</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Fain</er>.]</ety> <def>Fain; glad; delighted.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fawkner</ent><br/
<hw>Fawk"ner</hw> <pr>(f<add/k"n<etil/r)</pr>, <pos>n.</pos> <ety>[See
<er>Falconer</er>.]</ety> <def>A falconer.</def> <mark>[Obs.]</mark>
<rj><au>Donne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fawn</ent><br/
<hw>Fawn</hw> <pr>(f<add/n)</pr>, <pos>n.</pos> <ety>[OF.
<ets>faon</ets> the young one of any beast, a fawn, F. <ets>faon</ets> a
fawn, for <ets>fedon</ets>, fr. L. <ets>fetus</ets>. See
<er>Fetus</er>.]</ety> <sn>1.</sn> <fld>(Zool.)</fld> <def>A young deer;
a buck or doe of the first year. See <er>Buck</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The young of an animal; a whelp.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>[The tigress] . . . followeth . . . after her
<qex>fawns</qex>.</q> <rj><qau>Holland.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A fawn color.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fawn</ent><br/
<hw>Fawn</hw>, <pos>a.</pos> <def>Of the color of a fawn;
fawn-colored.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fawn</ent><br/
<hw>Fawn</hw>, <pos>v. i.</pos> <ety>[Cf. F. <ets>faonner</ets>.]</ety>
<def>To bring forth a fawn.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fawn</ent><br/
<hw>Fawn</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Fawned</conjf> <pr>(f<add/nd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Fawning</conjf>.]</vmorph> <ety>[OE. <ets>fawnen</ets>,
<ets>fainen</ets>, <ets>fagnien</ets>, to rejoice, welcome, flatter, AS.
<ets>f<ae/gnian</ets> to rejoice; akin to Icel. <ets>fagna</ets> to
rejoice, welcome. See <er>Fain</er>.]</ety> <def>To court favor by low
cringing, frisking, etc., as a dog; to flatter meanly; -- often followed
by <ptcl>on</ptcl> or <ptcl>upon</ptcl>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>You showed your teeth like apes, and <qex>fawned</qex> like
hounds.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou with trembling fear,<br/
Or like a <qex>fawning</qex> parasite, obeyest.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Courtiers who <qex>fawn</qex> on a master while they betray
him.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fawn</ent><br/
<hw>Fawn</hw>, <pos>n.</pos> <def>A servile cringe or bow; mean
flattery; sycophancy.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fawn-colored</ent><br/
<hw>Fawn"-col`ored</hw> <pr>(f<add/n"k<ucr/l`<etil/rd)</pr>,
<pos>a.</pos> <def>Of the color of a fawn; light yellowish
brown.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fawner</ent><br/
<hw>Fawn"er</hw> <pr>(f<add/n"<etil/r)</pr>, <pos>n.</pos> <def>One who
fawns; a sycophant.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fawningly</ent><br/
<hw>Fawn"ing*ly</hw>, <pos>adv.</pos> <def>In a fawning
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>fax</ent><br/
<hw>fax</hw> <pr>(f<acr/ks)</pr>, <pos>n.</pos> <ety>[Shortened form of
<ets>telefax</ets>, from <ets>tele-</ets> and
<ets>facs</ets>imile.]</ety> <def>A document which is a facsimile of
another document, converted into electrical symbols by a facsimile
machine at one telephone terminal, transmitted via telephone and printed
on some form of paper at a facsimile machine at a second telephone
terminal. A document transmitted using a computer at one or both ends
may also be called a <ex>fax</ex> if the transmission protocol is
similar to that used by telefax devices, i.e. if the originating or
receiving device could be a telefax device.</def><br/
[<source>PJC</source>]</p>

<p><ent>fax</ent><br/
<hw>fax</hw> <pr>(f<acr/ks)</pr>, <pos>v. t.</pos> <ety>[Shortened form
of <ets>telefax</ets>, from <ets>tele-</ets> and
<ets>facs</ets>imile.]</ety> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>faxed</conjf> <pr>(f<acr/kst)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>faxing</conjf> <pr>(f<acr/ks"<icr/ng)</pr>.]</vmorph> <def>To
transmit a copy of a document (a <ex>fax</ex>) over a telephone line
using facsimile devices or the telefax protocol at both ends. See
<er>fax</er>, n., and <er>facsimile</er>{2}, n.</def><br/
[<source>PJC</source>]</p>

<p><ent>faxed</ent><br/
<hw>faxed</hw> <pr>(f<acr/kst)</pr>, <pos>a.</pos> <ety>[AS.
<ets>feaxede</ets> haired, fr. <ets>feax</ets> hair. Cf.
<er>Paxwax</er>.]</ety> <def>Hairy.</def> <mark>[Obs.]</mark>
<rj><au>amden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>fax machine</ent><br/
<hw>fax" ma*chine`</hw> <pr>(f<acr/ks'm<adot/*sh<emac/n`)</pr>,
<pos>n.</pos> <ety>[Shortened form of <ets>telefax</ets>, from
<ets>tele-</ets> and <ets>facs</ets>imile.]</ety> <def>A device which is
designed to transmit and receive images by the facsimile{2} process.
Such a device may also be able to perform other functions, such as
scanning an image or copying an image; a telefax device.</def><br/
[<source>PJC</source>]</p>

<p><ent>Fay</ent><br/
<hw>Fay</hw> <pr>(f<amac/)</pr>, <pos>n.</pos> <ety>[F.
<ets>f<eacute/e</ets>. See <er>Fate</er>, and cf. <er>Fairy</er>.]</ety>
<def>A fairy; an elf.</def> <ldquo/Yellow-skirted
<xex>fays</xex>.<rdquo/ <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fay</ent><br/
<hw>Fay</hw>, <pos>n.</pos> <ety>[OF. <ets>fei</ets>, F. <ets>foi</ets>.
See <er>Faith</er>.]</ety> <def>Faith; <as>as, by my
<ex>fay</ex></as>.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fay</ent><br/
<hw>Fay</hw> <pr>(f<amac/)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>fayed</conjf> <pr>(f<amac/d)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Faying</conjf>.]</vmorph> <ety>[OE. <ets>feien</ets>,
v.t. & i., AS. <ets>f<emac/gan</ets> to join, unite; akin to OS.
<ets>f<omac/gian</ets>, D. <ets>voegen</ets>, OHG. <ets>fuogen</ets>, G.
<ets>f<uum/gen</ets>, Sw. <ets>foga</ets>. See <er>Fair</er>, and cf.
<er>Fadge</er>.]</ety> <fld>(Shipbuilding)</fld> <def>To fit; to join;
to unite closely, as two pieces of wood, so as to make the surface fit
together.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fay</ent><br/
<hw>Fay</hw>, <pos>v. i.</pos> <fld>(Shipbuilding)</fld> <def>To lie
close together; to fit; to fadge; -- often with <xex>in</xex>,
<xex>into</xex>, <xex>with</xex>, or <xex>together</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Faying surface</b></col>, <cd>that surface of an object
which comes with another object to which it is fastened; -- said of
plates, angle irons, etc., that are riveted together in
shipwork.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fayalite</ent><br/
<hw>Fay"al*ite</hw> <pr>(f<amac/"<ait/l*<imac/t)</pr>, <pos>n.</pos>
<ety>[So called from the island <etsep>Fayal</etsep>.]</ety>
<fld>(Min.)</fld> <def>A black, greenish, or brownish mineral of the
chrysolite group. It is a silicate of iron.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fayence</ent><br/
\'d8<hw>Fa`y*ence"</hw> <pr>(f<aum/`<esl/*y<aum/Ns")</pr>, <pos>n.</pos>
<def>See <er>Fa<ium/ence</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Faytour</ent><br/
<hw>Fay"tour</hw> <pr>(f<amac/"t<oomac/r)</pr>, <pos>n.</pos> <def>See
<er>Faitour</er>.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>faze</ent><br/
<hw>faze</hw> <pr>(f<amac/z)</pr>, <pos>v. t.</pos> <def>To cause to
become disconcerted or disturbed. A variant form of
<er>Feeze</er>.</def> <ldquo/The perpetual need to learn new software
doesn't <ex>faze</ex> him.<rdquo/<br/
[<source>1913 Webster</source> <source>+PJC</source> ]</p>

<p><ent>fazzolet</ent><br/
<hw>faz"zo*let`</hw> <pr>(f<acr/z"z<osl/*l<ecr/t`)</pr>, <pos>n.</pos>
<ety>[It. <ets>fazzoletto</ets>.]</ety> <def>A handkerchief.</def>
<mark>[R.]</mark> <rj><au>Percival.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>feaberry</ent><br/
<hw>fea"ber*ry</hw> <pr>(<emac/"b<etil/r*r<ycr/)</pr>, <pos>n.</pos>
<ety>[Cf. Prov. E. <ets>feabe</ets>, <ets>theabe</ets>,
<ets>thape</ets>.]</ety> <fld>(Bot.)</fld> <def>A gooseberry.</def>
<mark>[Prov. Eng.]</mark> <rj><au>Prior.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>feague</ent><br/
<hw>feague</hw> <pr>(f<emac/g)</pr>, <pos>v. t.</pos> <ety>[Cf. G.
<ets>fegen</ets> to sweep, Icel. <ets>f<ae/gja</ets> to cleanse, polish,
E. <ets>fair</ets>, <ets>fay</ets>, to fit, <ets>fey</ets> to
cleanse.]</ety> <def>To beat or whip; to drive.</def>
<mark>[Obs.]</mark> <rj><au>Otway.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>feal</ent><br/
<hw>fe"al</hw> <pr>(f<emac/"<ait/l)</pr>, <pos>a.</pos> <ety>[OF.
<ets>feal</ets>, <ets>feel</ets>, <ets>feeil</ets>, <ets>fedeil</ets>,
F. <ets>fid<egrave/le</ets>, L. <ets>fidelis</ets> faithful, fr.
<ets>fides</ets> faith. See <er>Faith</er>.]</ety> <def>Faithful;
loyal.</def> <mark>[Obs.]</mark> <rj><au>Wright.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>fealty</ent><br/
<hw>fe"al*ty</hw> <pr>(f<emac/"<ait/l*t<ycr/)</pr>, <pos>n.</pos>
<ety>[OE. <ets>feaute</ets>, OF. <ets>feaut<eacute/</ets>,
<ets>fealt<eacute/</ets>, <ets>feelt<eacute/</ets>, <ets>feelteit</ets>,
fr. L. <ets>fidelitas</ets>, fr. <ets>fidelis</ets> faithful. See
<er>Feal</er>, and cf. <ets>Fidelity</ets>.]</ety> <sn>1.</sn>
<def>Fidelity to one's lord; the feudal obligation by which the tenant
or vassal was bound to be faithful to his lord; the special oath by
which this obligation was assumed; fidelity to a superior power, or to a
government; loyalty. It is no longer the practice to exact the
performance of fealty, as a feudal obligation.</def> <rj><au>Wharton
(Law Dict.).</au> <au>Tomlins.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Fidelity; constancy; faithfulness, as of a friend to
a friend, or of a wife to her husband.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He should maintain <qex>fealty</qex> to God.</q> <rj><qau>I.
Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Makes wicked lightnings of her eyes, and saps<br/
The <qex>fealty</qex> of our friends.</q>
<rj><qau>tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Swore <qex>fealty</qex> to the new government.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <ex>Fealty</ex> is distinguished from
<contr>homage</contr>, which is an acknowledgment of tenure, while
<ex>fealty</ex> implies an oath. See <er>Homage</er>.</note>
<rj><au>Wharton.</au></rj></p>

<p><syn><b>Syn.</b> -- Homage; loyality; fidelity; constancy.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fear</ent><br/
<hw>Fear</hw> <pr>(f<emac/r)</pr>, <pos>n.</pos> <def>A variant of
<er>Fere</er>, a mate, a companion.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fear</ent><br/
<hw>Fear</hw>, <pos>n.</pos> <ety>[OE. <ets>fer</ets>, <ets>feer</ets>,
<ets>fere</ets>, AS. <ets>f<aemac/r</ets> a coming suddenly upon, fear,
danger; akin to D. <ets>vaar</ets>, OHG. <ets>f<amac/ra</ets> danger, G.
<ets>gefahr</ets>, Icel. <ets>f<amac/r</ets> harm, mischief, plague, and
to E. <ets>fare</ets>, <ets>peril</ets>. See <er>Fare</er>.]</ety>
<sn>1.</sn> <def>A painful emotion or passion excited by the expectation
of evil, or the apprehension of impending danger; apprehension; anxiety;
solicitude; alarm; dread.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The degrees of this passion, beginning with the most
moderate, may be thus expressed, -- <contr>apprehension</contr>,
<ex>fear</ex>, <contr>dread</contr>, <contr>fright</contr>,
<contr>terror</contr>.</note><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Fear</qex> is an uneasiness of the mind, upon the thought of
future evil likely to befall us.</q> <rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Where no hope is left, is left no <qex>fear</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Script.)</fld> <sd>(a)</sd> <def>Apprehension of
incurring, or solicitude to avoid, God's wrath; the trembling and awful
reverence felt toward the Supreme Being.</def> <sd>(b)</sd>
<def>Respectful reverence for men of authority or worth.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I will put my <qex>fear</qex> in their hearts.</q> <rj><qau>Jer.
xxxii. 40.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I will teach you the <qex>fear</qex> of the Lord.</q> <rj><qau>Ps.
xxxiv. 11.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Render therefore to all their dues; tribute to whom tribute is due
. . . <qex>fear</qex> to whom <qex>fear</qex>.</q> <rj><qau>Rom. xiii.
7.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which causes, or which is the object of,
apprehension or alarm; source or occasion of terror; danger;
dreadfulness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There were they in great fear, where no <qex>fear</qex> was.</q>
<rj><qau>Ps. liii. 5.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>fear</qex> of your adventure would counsel you to a more
equal enterprise.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>For fear</b></col>, <cd>in apprehension lest.</cd>
<ldquo/<xex>For fear</xex> you ne'er see chain nor money more.<rdquo/
<rj><au>Shak.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fear</ent><br/
<hw>Fear</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Feared</conjf> <pr>(f<emac/rd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Fearing</conjf>.]</vmorph> <ety>[OE. <ets>feren</ets>,
<ets>faeren</ets>, to frighten, to be afraid, AS. <ets>f<aemac/ran</ets>
to terrify. See <er>Fear</er>, <pos>n.</pos>]</ety> <sn>1.</sn> <def>To
feel a painful apprehension of; to be afraid of; to consider or expect
with emotion of alarm or solicitude.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I will <qex>fear</qex> no evil, for thou art with me.</q>
<rj><qau>Ps. xxiii. 4.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note>With subordinate clause.<br/
<q>I greatly <qex>fear</qex> my money is not safe.</q>
<rj><qau>Shak.</qau></rj><br/
<br/
<q>I almost <qex>fear</qex> to quit your hand.</q> <rj><qau>D.
Jerrold.</qau></rj></note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To have a reverential awe of; to be solicitous to
avoid the displeasure of.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Leave them to God above; him serve and <qex>fear</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To be anxious or solicitous for; now replaced by
<altname>fear for</altname>.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The sins of the father are to be laid upon the children, therefore
. . . I <qex>fear</qex> you.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To suspect; to doubt.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Ay what else, <qex>fear</qex> you not her courage?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To affright; to terrify; to drive away or prevent
approach of by fear.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Fear</qex> their people from doing evil.</q>
<rj><qau>Robynson (More's Utopia).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Tush, tush! <qex>fear</qex> boys with bugs.</q>
<rj><qau>Shak.</qau></rj></p>

<p><syn><b>Syn.</b> -- To apprehend; dread; reverence;
venerate.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fear</ent><br/
<hw>Fear</hw>, <pos>v. i.</pos> <def>To be in apprehension of evil; to
be afraid; to feel anxiety on account of some expected evil.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I exceedingly <qex>fear</qex> and quake.</q> <rj><qau>Heb. xii.
21.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fearer</ent><br/
<hw>Fear"er</hw> <pr>(f<emac/r"<etil/r)</pr>, <pos>n.</pos> <def>One who
fears.</def> <rj><au>Sir P. Sidney.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fearful</ent><br/
<hw>Fear"ful</hw> <pr>(f<emac/r"f<usdot/l)</pr>, <pos>a.</pos>
<sn>1.</sn> <def>Full of fear, apprehension, or alarm; afraid;
frightened.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Anxious amidst all their success, and <qex>fearful</qex> amidst
all their power.</q> <rj><qau>Bp. Warburton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Inclined to fear; easily frightened; without
courage; timid.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>What man is there that is <qex>fearful</qex> and
faint-hearted?</q> <rj><qau>Deut. xx. 8.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Indicating, or caused by, fear.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Cold <qex>fearful</qex> drops stand on my trembling flesh.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Inspiring fear or awe; exciting apprehension or
terror; terrible; frightful; dreadful.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This glorious and <qex>fearful</qex> name, <sc>The Lord thy
God</sc>.</q> <rj><qau>Deut. xxviii. 58.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Death is a <qex>fearful</qex> thing.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>In dreams they <qex>fearful</qex> precipices tread.</q>
<rj><qau>Dryden.</qau></rj></p>

<p><syn><b>Syn.</b> -- Apprehensive; afraid; timid; timorous; horrible;
distressing; shocking; frightful; dreadful; awful.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fearfully</ent><br/
<hw>Fear"ful*ly</hw>, <pos>adv.</pos> <def>In a fearful
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fearfulness</ent><br/
<hw>Fear"ful*ness</hw>, <pos>n.</pos> <def>The state of being
fearful.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fearless</ent><br/
<hw>Fear"less</hw>, <pos>a.</pos> <def>Free from fear.</def></p>

<p><syn><b>Syn.</b> -- Bold; daring; courageous; intrepid; valorous;
valiant; brave; undaunted; dauntless; heroic.</syn></p>

<p>-- <wordforms><wf>Fear"less*ly</wf>, <pos>adv.</pos> --
<wf>Fear"less*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fearnaught</ent><br/
<hw>Fear"naught`</hw> <pr>(f<emac/r"n<add/t`)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>A fearless person.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A stout woolen cloth of great thickness;
dreadnaught; also, a warm garment.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fearsome</ent><br/
<hw>Fear"some</hw> <pr>(f<emac/r"s<ucr/m)</pr> <pos>a.</pos> <sn>1.</sn>
<def>Frightful; causing fear.</def> <mark>[Scotch]</mark> <ldquo/This
<xex>fearsome</xex> wind.<rdquo/ <rj><au>Sir W. Scott</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Easily frightened; timid; timorous.</def> <ldquo/A
silly <xex>fearsome</xex> thing.<rdquo/ <rj><au>B. Taylor</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 548 --></p>

<p><ent>Feasibility</ent><br/
<hw>Fea"si*bil*ity</hw> <pr>(f<emac/`z<icr/*b<icr/l"<icr/*t<ycr/)</pr>
<pos>n.</pos>; <plu><it>pl.</it> <plw>Feasibilities</plw>
<pr>(f<emac/`z<icr/*b<icr/l"<icr/*tiz)</pr>.</plu> <ety>[from
<er>Feasible</er>]</ety> <def>The quality of being feasible;
practicability; also, that which is feasible; <as>as, before we adopt a
plan, let us consider its <ex>feasibility</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Men often swallow falsities for truths, dubiosities for
certainties, possibilities for <qex>feasibilities</qex>.</q>
<rj><qau>Sir T. Browne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feasible</ent><br/
<hw>Fea"si*ble</hw> <pr>(f<emac/"z<icr/*b'l)</pr> <pos>a.</pos> <ety>[F.
<ets>faisable</ets>, fr. <ets>faire</ets> to make or do, fr. L.
<ets>facere</ets>. See <er>Fact</er>, <er>Feat</er>.]</ety> <sn>1.</sn>
<def>Capable of being done, executed, or effected;
practicable.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Always existing before their eyes as a thing <qex>feasible</qex>
in practice.</q> <rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>It was not <qex>feasible</qex> to gratify so many ambitions.</q>
<rj><qau>Beaconsfield.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Fit to be used or tilled, as land.</def>
<mark>[R.]</mark> <rj><au>R. Trumbull.</au></rj></p>

<p><wordforms><wf>Fea"si*ble*ness</wf>, <pos>n.</pos>
--<wf>Fea"si*bly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feast</ent><br/
<hw>Feast</hw> <pr>(f<emac/st)</pr>, <pos>n.</pos> <ety>[OE.
<ets>feste</ets> festival, holiday, feast, OF. <ets>feste</ets>
festival, F. <ets>f<ecir/te</ets>, fr. L. <ets>festum</ets>, pl.
<ets>festa</ets>, fr. <ets>festus</ets> joyful, festal; of uncertain
origin. Cf. <er>Fair</er>, <pos>n.</pos>, <er>Festal</er>,
<er>F<ecir/te</er>.]</ety> <sn>1.</sn> <def>A festival; a holiday; a
solemn, or more commonly, a joyous, anniversary.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The seventh day shall be a <qex>feast</qex> to the Lord.</q>
<rj><qau>Ex. xiii. 6.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Now his parents went to Jerusalem every year at the
<qex>feast</qex> of the passover.</q> <rj><qau>Luke ii.
41.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ An Ecclesiastical <ex>feast</ex> is called a
<stype>immovable feast</stype> when it always occurs on the same day of
the year; otherwise it is called a <stype>movable feast</stype>. Easter
is a notable <ex>movable feast</ex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A festive or joyous meal; a grand, ceremonious, or
sumptuous entertainment, of which many guests partake; a banquet
characterized by tempting variety and abundance of food.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Enough is as good as a <qex>feast</qex>.</q> <rj><qau>Old
Proverb.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Belshazzar the King made a great <qex>feast</qex> to a thousand of
his lords.</q> <rj><qau>Dan. v. 1.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which is partaken of, or shared in, with
delight; something highly agreeable; entertainment.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>feast</qex> of reason, and the flow of soul.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Feast day</b></col>, <cd>a holiday; a day set as a solemn
commemorative festival.</cd></cs></p>

<p><syn><b>Syn.</b> -- Entertainment; regale; banquet; treat; carousal;
festivity; festival.</syn> <usage> -- <er>Feast</er>, <er>Banquet</er>,
<er>Festival</er>, <er>Carousal</er>. A <xex>feast</xex> sets before us
viands superior in quantity, variety, and abundance; a
<xex>banquet</xex> is a luxurious feast; a <xex>festival</xex> is the
joyful celebration by good cheer of some agreeable event.
<xex>Carousal</xex> is unrestrained indulgence in frolic and
drink.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feast</ent><br/
<hw>Feast</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Feasted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Feasting</conjf>.]</vmorph> <ety>[OE. <ets>festen</ets>, cf. OF.
<ets>fester</ets> to rest from work, F. <ets>f<ecir/ter</ets> to
celebrate a holiday. See <er>Feast</er>, <pos>n.</pos>]</ety>
<sn>1.</sn> <def>To eat sumptuously; to dine or sup on rich provisions,
particularly in large companies, and on public festivals.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And his sons went and <qex>feasted</qex> in their houses.</q>
<rj><qau>Job. i. 4.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To be highly gratified or delighted.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With my love's picture then my eye doth <qex>feast</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feast</ent><br/
<hw>Feast</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To entertain with
sumptuous provisions; to treat at the table bountifully; <as>as, he was
<ex>feasted</ex> by the king</as>.</def> <rj><au>Hayward.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To delight; to gratify; <as>as, to <ex>feast</ex>
the soul</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Feast</qex> your ears with the music a while.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feaster</ent><br/
<hw>Feast"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who
fares deliciously.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who entertains magnificently.</def>
<rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feastful</ent><br/
<hw>Feast"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Festive; festal;
joyful; sumptuous; luxurious.</def> <ldquo/<xex>Feastful</xex>
days.<rdquo/ <rj><au>Milton.</au></rj></p>

<p>-- <wordforms><wf>Feast"ful*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feat</ent><br/
<hw>Feat</hw> <pr>(f<emac/t)</pr>, <pos>n.</pos> <ety>[OE.
<ets>fet</ets>, OF. <ets>fet</ets>, <ets>fait</ets>, F. <ets>fait</ets>,
<ets>factum</ets>, fr. L. <ets>facere</ets>, <ets>factum</ets>, to make
or do. Cf. <er>Fact</er>, <er>Feasible</er>, <er>Do</er>.]</ety>
<sn>1.</sn> <def>An act; a deed; an exploit.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The warlike <qex>feats</qex> I have done.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A striking act of strength, skill, or cunning; a
trick; <as>as, <ex>feats</ex> of horsemanship, or of
dexterity</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feat</ent><br/
<hw>Feat</hw>, <pos>v. t.</pos> <def>To form; to fashion.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>To the more mature,<br/
A glass that <qex>feated</qex> them.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feat</ent><br/
<hw>Feat</hw>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Feater</adjf> <pr>(?)</pr>; <pos>superl.</pos>
<adjf>Featest</adjf>.]</amorph> <ety>[F. <ets>fait</ets> made, shaped,
fit, p. p. of <ets>faire</ets> to make or do. See <er>Feat</er>,
<pos>n.</pos>]</ety> <def>Dexterous in movements or service; skillful;
neat; nice; pretty.</def> <mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Never master had a page . . . so <qex>feat</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And look how well my garments sit upon me --<br/
Much <qex>feater</qex> than before.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feat-bodied</ent><br/
<hw>Feat"-bod`ied</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having a feat or
trim body.</def> <mark>[Obs.]</mark> <rj><au>Beau. & Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feateous</ent><br/
<hw>Feat"e*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. OF.
<ets>faitis</ets>, <ets>faitice</ets>, <ets>fetis</ets>, well made,
fine, L. <ets>facticius</ets> made by art.]</ety> <def>Dexterous;
neat.</def> <mark>[Obs.]</mark> <rj><au>Johnson.</au></rj></p>

<p>-- <wordforms><wf>Feat"e*ous*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feather</ent><br/
<hw>Feath"er</hw> <pr>(f<ecr/<th/"<etil/r)</pr>, <pos>n.</pos> <ety>[OE.
<ets>fether</ets>, AS. <ets>fe<edh/er</ets>; akin to D.
<ets>veder</ets>, OHG. <ets>fedara</ets>, G. <ets>feder</ets>, Icel.
<ets>fj<oum/<edh/r</ets>, Sw. <ets>fj<aum/der</ets>, Dan.
<ets>fj<ae/der</ets>, Gr. <grk>ptero`n</grk> wing, feather,
<grk>pe`tesqai</grk> to fly, Skr. <ets>pattra</ets> wing, feather,
<ets>pat</ets> to fly, and prob. to L. <ets>penna</ets> feather, wing.
<root/76, 248. Cf. <er>Pen</er> a feather.]</ety> <sn>1.</sn> <def>One
of the peculiar dermal appendages, of several kinds, belonging to birds,
as contour feathers, quills, and down.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ An ordinary feather consists of the quill or hollow
basal part of the stem; the shaft or rachis, forming the upper, solid
part of the stem; the vanes or webs, implanted on the rachis and
consisting of a series of slender lamin<ae/ or barbs, which usually bear
barbules, which in turn usually bear barbicels and interlocking hooks by
which they are fastened together. See <er>Down</er>, <er>Quill</er>,
<er>Plumage</er>.</note></p>

<p><sn>2.</sn> <def>Kind; nature; species; -- from the proverbial
phrase, <ldquo/Birds of a feather,<rdquo/ that is, of the same
species.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I am not of that <qex>feather</qex> to shake off<br/
My friend when he must need me.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The fringe of long hair on the legs of the setter
and some other dogs.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A tuft of peculiar, long, frizzly hair on a
horse.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>One of the fins or wings on the shaft of an
arrow.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Mach. & Carp.)</fld> <def>A longitudinal strip
projecting as a fin from an object, to strengthen it, or to enter a
channel in another object and thereby prevent displacement sidwise but
permit motion lengthwise; a spline.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>A thin wedge driven between the two semicylindrical
parts of a divided plug in a hole bored in a stone, to rend the
stone.</def> <rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>The angular adjustment of an oar or paddle-wheel
float, with reference to a horizontal axis, as it leaves or enters the
water.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Feather</xex> is used adjectively or in
combination, meaning <xex>composed of</xex>, or <xex>resembling</xex>,
<xex>a feather or feathers</xex>; as, <xex>feather</xex> fan,
<xex>feather</xex>-heeled, <xex>feather</xex> duster.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs> <col><b>Feather alum</b></col> <fld>(Min.)</fld>, <cd>a hydrous
sulphate of alumina, resulting from volcanic action, and from the
decomposition of iron pyrites; -- called also
<altname>halotrichite</altname>.</cd> <au>Ure.</au> -- <col><b>Feather
bed</b></col>, <cd>a bed filled with feathers.</cd> -- <col><b>Feather
driver</b></col>, <cd>one who prepares feathers by beating.</cd> --
<col><b>Feather duster</b></col>, <cd>a dusting brush of feathers.</cd>
-- <col><b>Feather flower</b></col>, <cd>an artifical flower made of
feathers, for ladies' headdresses, and other ornamental purposes.</cd>
-- <col><b>Feather grass</b></col> <fld>(Bot.)</fld>, <cd>a kind of
grass (<spn>Stipa pennata</spn>) which has a long feathery awn rising
from one of the chaffy scales which inclose the grain.</cd> --
<col><b>Feather maker</b></col>, <cd>one who makes plumes, etc., of
feathers, real or artificial.</cd> -- <col><b>Feather ore</b></col>
<fld>(Min.)</fld>, <cd>a sulphide of antimony and lead, sometimes found
in capillary forms and like a cobweb, but also massive. It is a variety
of Jamesonite.</cd> -- <mcol><col><b>Feather shot</b></col>, <it>or</it>
<col><b>Feathered shot</b></col></mcol> <fld>(Metal.)</fld>, <cd>copper
granulated by pouring into cold water.</cd> <au>Raymond.</au> --
<col><b>Feather spray</b></col> <fld>(Naut.)</fld>, <cd>the spray thrown
up, like pairs of feathers, by the cutwater of a fast-moving
vessel.</cd> -- <col><b>Feather star</b></col>. <fld>(Zool.)</fld>
<cd>See <er>Comatula</er>.</cd> -- <col><b>Feather weight</b></col>.
<fld>(Racing)</fld> <sd>(a)</sd> <cd>Scrupulously exact weight, so that
a feather would turn the scale, when a jockey is weighed or
weighted.</cd> <sd>(b)</sd> <cd>The lightest weight that can be put on
the back of a horse in racing.</cd> <au>Youatt.</au> <sd>(c)</sd> <cd>In
wrestling, boxing, etc., a term applied to the lightest of the classes
into which contestants are divided; -- in contradistinction to
<contr>light weight</contr>, <contr>middle weight</contr>, and
<contr>heavy weight</contr>.</cd> -- <col><b>A feather in the
cap</b></col> <cd>an honour, trophy, or mark of distinction.</cd>
<mark>[Colloq.]</mark> -- <col><b>To be in full feather</b></col>,
<cd>to be in full dress or in one's best clothes.</cd>
<mark>[Collog.]</mark> -- <col><b>To be in high feather</b></col>,
<cd>to be in high spirits.</cd> <mark>[Collog.]</mark> -- <col><b>To cut
a feather</b></col>. <sd>(a)</sd> <fld>(Naut.)</fld> <cd>To make the
water foam in moving; in allusion to the ripple which a ship throws off
from her bows.</cd> <sd>(b)</sd> <cd>To make one's self
conspicuous.</cd> <mark>[Colloq.]</mark> -- <col><b>To show the white
feather</b></col>, <cd>to betray cowardice, -- a white feather in the
tail of a cock being considered an indication that he is not of the true
game breed.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feather</ent><br/
<hw>Feath"er</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Feathered</conjf> <pr>(#)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Feathering.</conjf>]</vmorph> <sn>1.</sn> <def>To
furnish with a feather or feathers, as an arrow or a cap.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>An eagle had the ill hap to be struck with an arrow
<qex>feathered</qex> from her own wing.</q>
<rj><qau>L'Estrange.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To adorn, as with feathers; to fringe.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A few birches and oaks still <qex>feathered</qex> the narrow
ravines.</q> <rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To render light as a feather; to give wings
to.</def><mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The Polonian story perhaps may <qex>feather</qex> some tedious
hours.</q> <rj><qau>Loveday.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To enrich; to exalt; to benefit.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They stuck not to say that the king cared not to plume his
nobility and people to <qex>feather</qex> himself.</q>
<rj><qau>Bacon.</qau></rj> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To tread, as a cock.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To feather one's nest</b></col>, <cd>to provide for one's
self especially from property belonging to another, confided to one's
care; -- an expression taken from the practice of birds which collect
feathers for the lining of their nests.</cd> -- <col><b>To feather an
oar</b></col> <fld>(Naut)</fld>, <cd>to turn it when it leaves the water
so that the blade will be horizontal and offer the least resistance to
air while reaching for another stroke.</cd> -- <col><b>To tar and
feather a person</b></col>, <cd>to smear him with tar and cover him with
feathers, as a punishment or an indignity.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feather</ent><br/
<hw>Feath"er</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To grow or form
feathers; to become feathered; -- often with <xex>out</xex>; <as>as, the
birds are <ex>feathering</ex> out</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To curdle when poured into another liquid, and float
about in little flakes or <ldquo/feathers;<rdquo/ <as>as, the cream
<ex>feathers</ex></as>.</def> <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To turn to a horizontal plane; -- said of
oars.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>feathering</qex> oar returns the gleam.</q>
<rj><qau>Tickell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Stopping his sculls in the air to <qex>feather</qex>
accurately.</q> <rj><qau>Macmillan's Mag.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To have the appearance of a feather or of feathers;
to be or to appear in feathery form.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A clump of ancient cedars <qex>feathering</qex> in evergreen
beauty down to the ground.</q> <rj><qau>Warren.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The ripple <qex>feathering</qex> from her bows.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>featherbed</ent><br/
<hw>featherbed</hw> <pos>n.</pos> <sn>1.</sn> <def>a mattress stuffed
with feathers.</def><br/
<syn><b>Syn. --</b> feather bed.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Featherbone</ent><br/
<hw>Feath"er*bone`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A substitute
for whalebone, made from the quills of geese and turkeys.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>feather-brained</ent><br/
<ent>featherbrained</ent><br/
<mhw><hw>feath"er*brained</hw>, <hw>feath"er-brained</hw></mhw>
<pr>(?)</pr>, <pos>a.</pos> <def>Giddy; frivolous; lacking seriousness;
given to frivolity; feather-headed.</def> <mark>[Colloq.]</mark><br/
<syn><b>Syn. --</b> airheaded, dizzy, empty-headed, giddy, lightheaded,
light-headed, silly.</syn><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><ent>Feathered</ent><br/
<hw>Feath"ered</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Clothed, covered, or fitted with (or as with) feathers or wings;
<as>as, a <ex>feathered</ex> animal; a <ex>feathered</ex>
arrow.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Rise from the ground like <qex>feathered</qex> Mercury.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Nonsense <qex>feathered</qex> with soft and delicate phrases and
pointed with pathetic accent.</q> <rj><qau>Dr. J. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Furnished with anything featherlike; ornamented;
fringed; <as>as, land <ex>feathered</ex> with trees</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <def>Having a fringe of feathers, as
the legs of certian birds; or of hairs, as the legs of a setter
dog.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Her.)</fld> <def>Having feathers; -- said of an
arrow, when the feathers are of a tincture different from that of the
shaft.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feather-edge</ent><br/
<hw>Feath"er-edge`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<fld>(Zool.)</fld> <def>The thin, new growth around the edge of a shell,
of an oyster.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Any thin, as on a board or a razor.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feather-edged</ent><br/
<hw>Feath"er-edged`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having a
feather-edge; also, having one edge thinner than the other, as a board;
-- in the United States, said only of stuff one edge of which is made as
thin as practicable.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feather-few</ent><br/
<hw>Feath"er-few`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>Feverfew.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feather-foil</ent><br/
<hw>Feath"er-foil`</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Feather</ets> + <ets>foil</ets> a leaf.]</ety>
<fld>(Bot.)</fld> <def>An aquatic plant (<spn>Hottonia palustris</spn>),
having finely divided leaves.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feather-head</ent><br/
<hw>Feath"er-head`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A frivolous or
feather-brained person.</def> <mark>[Colloq.]</mark> <rj><au>H.
James.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feather-headed</ent><br/
<hw>Feath"er-head`ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Giddy;
frivolous; foolish.</def> <mark>[Colloq.]</mark> <rj><au>G.
Eliot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feather-heeled</ent><br/
<hw>Feath"er-heeled`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Light-heeled;
gay; frisky; frolicsome.</def> <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Featheriness</ent><br/
<hw>Feath"er*i*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state or
condition of being feathery.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feathering</ent><br/
<hw>Feath"er*ing</hw>, <pos>n.</pos> <sn>1.</sn> <fld>(Arch.)</fld>
<def>Same as <er>Foliation</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The act of turning the blade of the oar, as it rises
from the water in rowing, from a vertical to a horizontal position. See
<cref>To feather an oar</cref>, under <er>Feather</er>, <pos>v.
t.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A covering of feathers.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Feathering float</b></col> <fld>(Naut.)</fld>, <cd>the
float or paddle of a feathering wheel.</cd> -- <col><b>Feathering
screw</b></col> <fld>(Naut.)</fld>, <cd>a screw propeller, of which the
blades may be turned so as to move edgewise through the water when the
vessel is moving under sail alone.</cd> -- <col><b>Feathering
wheel</b></col> <fld>(Naut.)</fld>, <cd>a paddle wheel whose floats turn
automatically so as to dip about perpendicularly into the water and
leave in it the same way, avoiding beating on the water in the descent
and lifting water in the ascent.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Featherless</ent><br/
<hw>Feath"er*less</hw>, <pos>a.</pos> <def>Destitute of
feathers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Featherly</ent><br/
<hw>Feath"er*ly</hw>, <pos>a.</pos> <def>Like feathers.</def>
<mark>[Obs.]</mark> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feather-pated</ent><br/
<hw>Feath"er-pat"ed</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Feather-headed; frivolous.</def> <mark>[Colloq.]</mark> <rj><au>Sir
W. Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Featherstitch</ent><br/
<hw>Feath"er*stitch`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A kind of
embroidery stitch producing a branching zigzag line.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Feather-veined</ent><br/
<hw>Feath"er-veined`</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Bot.)</fld>
<def>Having the veins (of a leaf) diverging from the two sides of a
midrib.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feathery</ent><br/
<hw>Feath"er*y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to, or
resembling, feathers; covered with, or as with, feathers; <as>as,
<ex>feathery</ex> spray or snow</as>.</def>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Ye <qex>feathery</qex> people of mid air.</q> <rj><qau>Barry
Cornwall.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Featly</ent><br/
<hw>Feat"ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <ety>[From <er>Feat</er>,
<pos>a.</pos>]</ety> <def>Neatly; dexterously; nimbly.</def>
<mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Foot <qex>featly</qex> here and there.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Featness</ent><br/
<hw>Feat"ness</hw>, <pos>n.</pos> <def>Skill; adroitness.</def>
<mark>[Archaic]</mark> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feature</ent><br/
<hw>Fea"ture</hw> <pr>(?; 135)</pr>, <pos>n.</pos> <ety>[OE.
<ets>feture</ets> form, shape, feature, OF. <ets>faiture</ets> fashion,
make, fr. L. <ets>factura</ets> a making, formation, fr.
<ets>facere</ets>, <ets>factum</ets>, to make. See <er>Feat</er>,
<er>Fact</er>, and cf. <er>Facture</er>.]</ety> <sn>1.</sn> <def>The
make, form, or outward appearance of a person; the whole turn or style
of the body; esp., good appearance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>What needeth it his <qex>feature</qex> to descrive?</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Cheated of <qex>feature</qex> by dissembling nature.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The make, cast, or appearance of the human face, and
especially of any single part of the face; a lineament.
(<pluf>pl.</pluf>) The face, the countenance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It is for homely <qex>features</qex> to keep home.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The cast or structure of anything, or of any part of
a thing, as of a landscape, a picture, a treaty, or an essay; any marked
peculiarity or characteristic; <as>as, one of the <ex>features</ex> of
the landscape</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And to her service bind each living creature<br/
Through secret understanding of their <qex>feature</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A form; a shape.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>So scented the grim <qex>feature</qex>, and upturned<br/
His nostril wide into the murky air.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Featured</ent><br/
<hw>Fea"tured</hw> <pr>(?; 135)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Shaped; fashioned.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>How noble, young, how rarely <qex>featured</qex>!</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Having features; formed into features.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The well-stained canvas or the <qex>featured</qex> stone.</q>
<rj><qau>Young.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Featureless</ent><br/
<hw>Fea"ture*less</hw> <pr>(?; 135)</pr>, <pos>a.</pos> <def>Having no
distinct or distinctive features.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Featurely</ent><br/
<hw>Fea"ture*ly</hw>, <pos>a.</pos> <def>Having features; showing marked
peculiarities; handsome.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Featurely</qex> warriors of Christian chivalry.</q>
<rj><qau>Coleridge.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feaze</ent><br/
<hw>Feaze</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Feazed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Feazing</conjf>.]</vmorph> <ety>[Cf. OE. <ets>faseln</ets> to
ravel, fr. AS. <ets>f<ae/s</ets> fringe; akin to G. <ets>fasen</ets> to
separate fibers or threads, <ets>fasen</ets>, <ets>faser</ets>, thread,
filament, OHG. <ets>faso</ets>.]</ety> <def>To untwist; to unravel, as
the end of a rope.</def> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feaze</ent><br/
<hw>Feaze</hw>, <pos>v. t.</pos> <ety>[See <er>Feese</er>.<-- now
<ets>faze</ets>-->]</ety> <def>To beat; to chastise; also, to humble; to
harass; to worry.</def> <mark>[Obs.]</mark>
<rj><au>insworth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feaze</ent><br/
<hw>Feaze</hw>, <pos>n.</pos> <def>A state of anxious or fretful
excitement; worry; vexation.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feazings</ent><br/
<hw>Feaz"ings</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[See
<er>Feaze</er>, <pos>v. t.</pos>]</ety> <fld>(Naut.)</fld> <def>The
unlaid or ragged end of a rope.</def> <rj><au>Ham. Nav.
Encyc.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Febricitate</ent><br/
<hw>Fe*bric"i*tate</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[L.
<ets>febricitare</ets>, fr. <ets>febris</ets>. See
<er>Febrile</er>.]</ety> <def>To have a fever.</def> <mark>[Obs.]</mark>
<rj><au>Bailey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Febriculose</ent><br/
<hw>Fe*bric"u*lose`</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>febriculosus</ets>.]</ety> <def>Somewhat feverish.</def>
<mark>[Obs.]</mark> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Febrifacient</ent><br/
<hw>Feb`ri*fa"cient</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>febris</ets> fever + <ets>faciens</ets>, p. pr. of
<ets>facere</ets> to make.]</ety> <def>Febrific.</def>
<rj><au>Dunglison.</au></rj></p>

<p>-- <def2><pos>n.</pos> <def>That which causes fever.</def>
<au>Beddoes.</au></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Febriferous</ent><br/
<hw>Fe*brif"er*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>febris</ets> fever + <ets>-ferous</ets>.]</ety> <def>Causing fever;
<as>as, a <ex>febriferous</ex> locality</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Febrific</ent><br/
<hw>Fe*brif"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>febris</ets> fever + <ets>ficare</ets> (in comp.) to make. See
<er>fy</er>-.]</ety> <def>Producing fever.</def>
<rj><au>Dunglison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Febrifugal</ent><br/
<hw>Fe*brif"u*gal</hw> <pr>(? <or/ ?)</pr>, <pos>a.</pos> <ety>[See
<er>Febrifuge</er>.]</ety> <def>Having the quality of mitigating or
curing fever.</def> <rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Febrifuge</ent><br/
<hw>Feb"ri*fuge</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>febris</ets> fever + <ets>fugare</ets> to put to flight, from
<ets>fugere</ets> to flee: cf. F. <ets>f<eacute/brifuge</ets>. see
<er>Febrile</er>, <er>Feverfew</er>.]</ety> <fld>(Med.)</fld> <def>A
medicine serving to mitigate or remove fever.</def> --
<def2><pos>a.</pos> <def>Antifebrile.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Febrile</ent><br/
<hw>Fe"brile</hw> <pr>(?; 277)</pr>, <pos>a.</pos> <ety>[F.
<ets>f<eacute/brile</ets>, from L. <ets>febris</ets> fever. See
<er>Fever</er>.]</ety> <def>Pertaining to fever; indicating fever, or
derived from it; <as>as, <ex>febrile</ex> symptoms; <ex>febrile</ex>
action.</as></def> <rj><au>Dunglison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>February</ent><br/
<hw>Feb"ru*a*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>Februarius</ets>, orig., the month of expiation, because on the
fifteenth of this month the great feast of expiation and purification
was held, fr. <ets>februa</ets>, pl., the Roman festival or
purification; akin to <ets>februare</ets> to purify, expiate.]</ety>
<def>The second month in the year, said to have been introduced into the
Roman calendar by Numa. In common years this month contains twenty-eight
days; in the bissextile, or leap year, it has twenty-nine
days.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Februation</ent><br/
<hw>Feb`ru*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>februatio</ets>. See <er>february</er>.]</ety> <def>Purification; a
sacrifice.</def> <mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fecal</ent><br/
<hw>Fe"cal</hw> <pr>(f<emac/"k<ait/l)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>f<eacute/cal</ets>. See <er>Feces</er>.]</ety> <def>Relating to, or
containing, dregs, feces, or ordure; f<ae/cal.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fecche</ent><br/
<hw>Fec"che</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To fetch.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feces</ent><br/
<hw>Fe"ces</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <def>Dregs; sediment;
excrement. See <er>faeces</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 549 --></p>

<p><ent>Fecial</ent><br/
<hw>Fe"cial</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>fetialis</ets> belonging to the <ets>fetiales</ets>, the Roman
priests who sanctioned treaties and demanded satisfaction from the enemy
before a formal declaration of war.]</ety> <def>Pertaining to heralds,
declarations of war, and treaties of peace; <as>as, <ex>fecial</ex>
law</as>.</def> <rj><au>Kent.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fecifork</ent><br/
<hw>Fe"ci*fork`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Feces</ets>
+ <ets>fork</ets>.]</ety> <fld>(Zool.)</fld> <def>The anal fork on which
the larv<ae/ of certain insects carry their f<ae/ces.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feckless</ent><br/
<hw>Feck"less</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Perh. a corruption
of <ets>effectless</ets>.]</ety> <def>Spiritless; weak; worthless.</def>
<mark>[Scot]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feck</ent><br/
<hw>Feck</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Abbrev. fr.
<ets>effect</ets>.]</ety> <sn>1.</sn> <def>Effect.</def>
<mark>[Obs.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>Efficacy; force; value.</def> <mark>[Scot. & Prov.
Eng.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>3.</sn> <def>Amount; quantity.</def> <mark>[Scot. & Prov.
Eng.]</mark></p>

<p><q>He had a <qex>feck</qex> o' books wi' him.</q> <rj><qau>R. L.
Stevenson.</qau></rj></p>

<p><cs><mcol><col><b>The most feck</b></col>, <it>or</it> <col><b>The
feck</b></col></mcol>, <cd>the greater or larger part.</cd> <ldquo/The
<xex>feck</xex> o' my life.<rdquo/ <au>Burns.</au></cs><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Fecks</ent><br/
<hw>Fecks</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A corruption of the word
<altname>faith</altname>.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>fecula</ent><br/
<ent>feculae</ent><br/
<hw>fec"u*la</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>fecul<ae/</plw></plu> <ety>[L.<ets>faecula</ets> burnt tartar or
salt of tartar, dim. of <ets>faex</ets>, <ets>faecis</ets>, sediment,
dregs: cf. F. <ets>f<eacute/cule</ets>.]</ety> <def>Any pulverulent
matter obtained from plants by simply breaking down the texture, washing
with water, and subsidence.</def> <specif>Especially:</specif>
<sd>(a)</sd> <def>The nutritious part of wheat; starch or farina; --
called also <altname>amylaceous fecula</altname>.</def> <sd>(b)</sd>
<def>The green matter of plants; chlorophyll.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feculence</ent><br/
<hw>Fec"u*lence</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>faeculentia</ets> dregs, filth: cf. F.
<ets>f<eacute/culence</ets>.]</ety> <sn>1.</sn> <def>The state or
quality of being feculent; muddiness; foulness.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is feculent; sediment; lees;
dregs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feculency</ent><br/
<hw>Fec"u*len*cy</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Feculence.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feculent</ent><br/
<hw>Fec"u*lent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>faeculentus</ets>, fr. <ets>faecula</ets>: cf. F.
<ets>f<eacute/culent</ets>. See <er>Fecula</er>.]</ety> <def>Foul with
extraneous or impure substances; abounding with sediment or
excrementitious matter; muddy; thick; turbid.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Both his hands most filthy <qex>feculent</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fecund</ent><br/
<hw>Fec"und</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>fecundus</ets>, from the root of <ets>fetus</ets>: cf. F.
<ets>f<eacute/cond</ets>. see <er>Fetus</er>.]</ety> <def>Fruitful in
children; prolific.</def> <rj><au>Graunt.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fecundate</ent><br/
<hw>Fec"un*date</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Fecundated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Fecundating</conjf> <pr>(?)</pr>.]</vmorph> <ety>[L.
<ets>fecundare</ets>, fr. <ets>fecundus</ets>. See
<er>Fecund</er>.]</ety> <sn>1.</sn> <def>To make fruitful or
prolific.</def> <rj><au>W. Montagu.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Biol.)</fld> <def>To render fruitful or prolific;
to impregnate; <as>as, in flowers the pollen <ex>fecundates</ex> the
ovum through the stigma</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fecundation</ent><br/
<hw>Fec`un*da"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>f<eacute/condation</ets>.]</ety> <fld>(Biol.)</fld> <def>The act by
which, either in animals or plants, material prepared by the generative
organs the female organism is brought in contact with matter from the
organs of the male, so that a new organism results; impregnation;
fertilization.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fecundify</ent><br/
<hw>Fe*cun"di*fy</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<ety>[<ets>Fecund</ets> + <ets>-fy</ets>.]</ety> <def>To make fruitful;
to fecundate.</def> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fecundity</ent><br/
<hw>Fe*cun"di*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>fecunditas</ets>: cf. F. <ets>f<eacute/condit<eacute/</ets>. See
<er>Fecund</er>.]</ety> <sn>1.</sn> <def>The quality or power of
producing fruit; fruitfulness; especially <fld>(Biol.)</fld>, the
quality in female organisms of reproducing rapidly and in great
numbers.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The power of germinating; as in seeds.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The power of bringing forth in abundance; fertility;
richness of invention; <as>as, the <ex>fecundity</ex> of God's creative
power</as>.</def> <rj><au>Bentley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fed</ent><br/
<hw>Fed</hw> <pr>(f<ecr/d)</pr>, <def><pos>imp. & p. p.</pos> of
<er>Feed</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fedary</ent><br/
<hw>Fed"a*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A feodary.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>fedayee</ent><br/
<hw>fedayee</hw> <pos>n.</pos>; <plu><it>pl.</it>
<plw>fedayeen</plw></plu>. <ety>[(1950-1955). Ar.
<ets>fid<amac/'<imac/</ets>, one who sacrifices himself.]</ety> <def>a
member of an Arab paramilitary organization, predominantly Palestinian,
which performs commando raids, especially against Israel or Israeli
targets. Usually used in the plural.</def><br/
[<source>PJC</source>]</p>

<p><ent>fedelini</ent><br/
<hw>fedelini</hw> <pos>n.</pos> <def>an extremely fine pasta thinner
than vermicelli.</def> <altsp>[Sometimes spelled <asp>fedellini</asp> or
<asp>fedelline</asp>.]</altsp><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Federal</ent><br/
<hw>Fed"er*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>foedus</ets> league, treaty, compact; akin to <ets>fides</ets>
faith: cf. F. <ets>f<eacute/d<eacute/ral</ets>. see
<er>Faith</er>.]</ety> <sn>1.</sn> <def>Pertaining to a league or
treaty; derived from an agreement or covenant between parties,
especially between nations; constituted by a compact between parties,
usually governments or their representatives.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The Romans compelled them, contrary to all <qex>federal</qex>
right, . . . to part with Sardinia.</q> <rj><qau>Grew.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <specif>Specifically:</specif> <sd>(a)</sd> <def>Composed
of states or districts which retain only a subordinate and limited
sovereignty, as the <xex>Union</xex> of the United States, or the
<xex>Sonderbund</xex> of Switzerland.</def> <sd>(b)</sd> <def>Consisting
or pertaining to such a government; <as>as, the <ex>Federal</ex>
Constitution; a <ex>Federal</ex> officer</as>.</def> <sd>(c)</sd>
<def>Friendly or devoted to such a government; <as>as, the
<ex>Federal</ex> party</as>. see <er>Federalist</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Federal Congress</b></col>. <cd>See under
<er>Congress</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Federal</ent><br/
<hw>Fed"er*al</hw>, <pos>n.</pos> <def>See
<er>Federalist</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Federalism</ent><br/
<hw>Fed"er*al*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>f<eacute/d<eacute/ralisme</ets>.]</ety> <def>The principles of
Federalists or of federal union.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Federalist</ent><br/
<hw>Fed"er*al*ist</hw>, <pos>n.</pos> <ety>[Cf. F.
<ets>f<eacute/d<eacute/raliste</ets>.]</ety> <def>An advocate of
confederation; specifically <fld>(Amer. Hist.)</fld>, a friend of the
Constitution of the United States at its formation and adoption; a
member of the political party which favored the administration of
president Washington.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>federalize</ent><br/
<hw>fed"er*al*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Federalized</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Federalizing</conjf> <pr>(?)</pr>.]</vmorph> <ety>[Cf.
F. <ets>f<eacute/d<eacute/raliser</ets>.]</ety> <def>To unite in
compact, as different States; to confederate for political purposes; to
unite by or under the Federal Constitution.</def>
<rj><au>Barlow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Federal National Mortgage Association</ent><br/
<hw>Federal National Mortgage Association</hw> <pos>prop. n.</pos>
<def>A federally chartered corporation that purchases and resells
mortgages.</def> <mark>[acron.]</mark> <br/
<syn><b>Syn. --</b> FNMA, Fannie Mae.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>federary</ent><br/
<hw>fed"er*a*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Federal</er>.]</ety> <def>A partner; a confederate; an
accomplice.</def> <mark>[Obs.]</mark> <rj><au>hak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Federate</ent><br/
<hw>Fed"er*ate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>foederatus</ets>, p. p. of <ets>foederare</ets> to establish by
treaty or league, fr. <ets>foedus</ets>. See <er>Federal</er>.]</ety>
<def>United by compact, as sovereignties, states, or nations; joined in
confederacy; leagued; confederate; <as>as, <ex>federate</ex>
nations</as>.</def><br/
<syn><b>Syn. --</b> federated.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>federated</ent><br/
<hw>fed"er*at*ed</hw> <pr>(?)</pr>, <pos>adj.</pos> <def>United by
compact under a central organization, as governments or commercial
organizations.</def><br/
<syn><b>Syn. --</b> federate.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Federation</ent><br/
<hw>Fed`er*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>f<eacute/d<eacute/ration</ets>.]</ety> <sn>1.</sn> <def>The act of
uniting in a league; confederation.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A league; a confederacy; a federal or confederated
government.</def> <rj><au>Burke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Federative</ent><br/
<hw>Fed"er*a*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>f<eacute/d<eacute/ratif</ets>.]</ety> <def>Uniting in a league;
forming a confederacy; federal.</def> <ldquo/A <xex>federative</xex>
society.<rdquo/ <rj><au>Burke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fedity</ent><br/
<hw>Fed"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>foeditas</ets>, fr. <ets>foedus</ets> foul, filthy.]</ety>
<def>Turpitude; vileness.</def> <mark>[Obs.]</mark> <rj><au>Bp.
Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>fedora</ent><br/
<hw>fe*do"ra</hw> <pr>(f<icr/*d<ocir/r"<adot/)</pr>, <pos>n.</pos>
<def>A soft felt hat with a crown creased lengthwise.</def><br/
<syn><b>Syn. --</b> felt hat, homburg, Stetson, trilby.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fee</ent><br/
<hw>Fee</hw> <pr>(f<emac/)</pr>, <pos>n.</pos> <ety>[OE. <ets>fe</ets>,
<ets>feh</ets>, <ets>feoh</ets>, cattle, property, money, fief, AS.
<ets>feoh</ets> cattle, property, money; the senses of <ldquo/property,
money,<rdquo/ arising from cattle being used in early times as a medium
of exchange or payment, property chiefly consisting of cattle; akin to
OS. <ets>fehu</ets> cattle, property, D. <ets>vee</ets> cattle, OHG.
<ets>fihu</ets>, <ets>fehu</ets>, G. <ets>vieh</ets>, Icel.
<ets>f<emac/</ets> cattle, property, money, Goth.
<ets>fa<iacute/hu</ets>, L. <ets>pecus</ets> cattle, <ets>pecunia</ets>
property, money, Skr. <ets>pa<cced/u</ets> cattle, perh. orig., <ldquo/a
fastened or tethered animal,<rdquo/ from a root signifying <ets>to
bind</ets>, and perh. akin to E. <ets>fang</ets>, <ets>fair</ets>, a.;
cf. OF. <ets>fie</ets>, <ets>flu</ets>, <ets>feu</ets>, <ets>fleu</ets>,
<ets>fief</ets>, F. <ets>fief</ets>, from German, of the same origin.
the sense <ets>fief</ets> is due to the French. <root/249. Cf.
<er>Feud</er>, <er>Fief</er>, <er>Fellow</er>,
<er>Pecuniary</er>.]</ety> <sn>1.</sn> <def>property; possession;
tenure.</def> <ldquo/Laden with rich <xex>fee</xex>.<rdquo/
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Once did she hold the gorgeous East in <qex>fee</qex>.</q>
<rj><qau>Wordsworth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Reward or compensation for services rendered or to
be rendered; especially, payment for professional services, of optional
amount, or fixed by custom or laws; charge; pay; perquisite; <as>as, the
<ex>fees</ex> of lawyers and physicians; the <ex>fees</ex> of office;
clerk's <ex>fees</ex>; sheriff's <ex>fees</ex>; marriage <ex>fees</ex>,
etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>To plead for love deserves more <qex>fee</qex> than hate.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Feud. Law)</fld> <def>A right to the use of a
superior's land, as a stipend for services to be performed; also, the
land so held; a fief.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Eng. Law)</fld> <def>An estate of inheritance
supposed to be held either mediately or immediately from the sovereign,
and absolutely vested in the owner.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ All the land in England, except the crown land, is of
this kind. An <xex>absolute fee</xex>, or <xex>fee simple</xex>, is land
which a man holds to himself and his heirs forever, who are called
<xex>tenants in fee simple</xex>. In modern writers, by <xex>fee</xex>
is usually meant <xex>fee simple</xex>. A <xex>limited fee</xex> may be
a <xex>qualified</xex> or <xex>base fee</xex>, which ceases with the
existence of certain conditions; or a <xex>conditional fee</xex>, or
<xex>fee tail</xex>, which is limited to particular heirs.</note>
<rj><au>Blackstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Amer. Law)</fld> <def>An estate of inheritance
belonging to the owner, and transmissible to his heirs, absolutely and
simply, without condition attached to the tenure.</def><br/
[<source>1913 Webster</source>]</p>

<cs><p><col><b>Fee estate</b></col> <fld>(Eng. Law)</fld>, <cd>land or
tenements held in fee in consideration or some acknowledgment or service
rendered to the lord.</cd> -- <col><b>Fee farm</b></col>
<fld>(Law)</fld>, <cd>land held of another in fee, in consideration of
an annual rent, without homage, fealty, or any other service than that
mentioned in the feoffment; an estate in fee simple, subject to a
perpetual rent.</cd> <au>Blackstone.</au> -- <col><b>Fee farm
rent</b></col> <fld>(Eng. Law)</fld>, <cd>a perpetual rent reserved upon
a conveyance in fee simple.</cd> -- <col><b>Fee fund</b></col>
<fld>(Scot. Law)</fld>, <cd>certain court dues out of which the clerks
and other court officers are paid.</cd> -- <col><b>Fee simple</b></col>
<fld>(Law)</fld>, <cd>an absolute fee; a fee without conditions or
limits.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>Buy the <qex>fee simple</qex> of my life for an hour and a
quarter.</q> <rj><qau>Shak.</qau></rj></p>

<p>-- <col><b>Fee tail</b></col> <fld>(Law)</fld>, <cd>an estate of
inheritance, limited and restrained to some particular heirs.</cd>
<au>Burill.</au><br/
[<source>1913 Webster</source>]</p></cs>

<p><ent>Fee</ent><br/
<hw>Fee</hw> <pr>(f<emac/)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Feed</conjf> <pr>(f<emac/d)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Feeing</conjf>.]</vmorph> <def>To reward for services
performed, or to be performed; to recompense; to hire or keep in hire;
hence, to bribe.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The patient . . . <qex>fees</qex> the doctor.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>There's not a one of them but in his house<br/
I keep a servant <qex>feed</qex>.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feeble</ent><br/
<hw>Fee"ble</hw> <pr>(f<emac/"b'l)</pr>, <pos>a.</pos>
<amorph>[<pos>Compar.</pos> <adjf>Feebler</adjf> <pr>(-bl<etil/r)</pr>;
<pos>superl.</pos> <adjf>Feeblest</adjf>
<pr>(-bl<ecr/st)</pr>.]</amorph> <ety>[OE. <ets>feble</ets>, OF.
<ets>feble</ets>, <ets>flebe</ets>, <ets>floibe</ets>,
<ets>floible</ets>, <ets>foible</ets>, F. <ets>faible</ets>, L.
<ets>flebilis</ets> to be wept over, lamentable, wretched, fr.
<ets>flere</ets> to weep. Cf. <er>Foible</er>.]</ety> <sn>1.</sn>
<def>Deficient in physical strength; weak; infirm;
debilitated.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Carried all the <qex>feeble</qex> of them upon asses.</q>
<rj><qau>2 Chron. xxviii. 15.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Wanting force, vigor, or efficiency in action or
expression; not full, loud, bright, strong, rapid, etc.; faint; <as>as,
a <ex>feeble</ex> color; <ex>feeble</ex> motion.</as></def> <ldquo/A
lady's <xex>feeble</xex> voice.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feeble</ent><br/
<hw>Fee"ble</hw>, <pos>v. t.</pos> <def>To make feble; to
enfeeble.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Shall that victorious hand be <qex>feebled</qex> here?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feeble-minded</ent><br/
<hw>Fee"ble-mind"ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Weak in
intellectual power; wanting firmness or constancy; irresolute;
vacillating; imbecile.</def> <ldquo/comfort the
<xex>feeble-minded</xex>.<rdquo/ <rj><au>1 Thess. v. 14.</au></rj></p>

<p>-- <wordforms><wf>Fee"ble-mind"ed*ness</wf>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>feeble-mindedness</ent><br/
<hw>fee"ble-mind"ed*ness</hw> <pos>n.</pos> <def>severe mental
deficiency.</def><br/
<syn><b>Syn. --</b> amentia.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Feebleness</ent><br/
<hw>Fee"ble*ness</hw>, <pos>n.</pos> <def>The quality or condition of
being feeble; debility; infirmity.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That shakes for age and <qex>feebleness</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feebly</ent><br/
<hw>Fee"bly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a feeble
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The restored church . . . contended <qex>feebly</qex>, and with
half a heart.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feed</ent><br/
<hw>Feed</hw> <pr>(f<emac/d)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Fed</conjf> <pr>(f<ecr/d)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Feeding</conjf>.]</vmorph> <ety>[AS.
<ets>f<emac/dan</ets>, fr. <ets>f<omac/da</ets> food; akin to OS.
<ets>f<omac/dian</ets>, OFries. <ets>f<emac/da</ets>,
<ets>f<omac/da</ets>, D. <ets>voeden</ets>, OHG. <ets>fuottan</ets>,
Icel. <ets>f<ae/<edh/a</ets>, Sw. <ets>f<oum/da</ets>, Dan.
<ets>f<oum/de</ets>. <root/75. See <er>Food</er>.]</ety> <sn>1.</sn>
<def>To give food to; to supply with nourishment; to satisfy the
physical huger of.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If thine enemy hunger, <qex>feed</qex> him.</q> <rj><qau>Rom. xii.
20.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Unreasonable creatures <qex>feed</qex> their young.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To satisfy; gratify or minister to, as any sense,
talent, taste, or desire.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I will <qex>feed</qex> fat the ancient grudge I bear him.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Feeding</qex> him with the hope of liberty.</q>
<rj><qau>Knolles.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To fill the wants of; to supply with that which is
used or wasted; <as>as, springs <ex>feed</ex> ponds; the hopper
<ex>feeds</ex> the mill; to <ex>feed</ex> a furnace with
coal.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To nourish, in a general sense; to foster,
strengthen, develop, and guard.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou shalt <qex>feed</qex> my people Israel.</q> <rj><qau>2 Sam.
v. 2.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Mightiest powers by deepest calms are <qex>fed</qex>.</q>
<rj><qau>B. Cornwall.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To graze; to cause to be cropped by feeding, as
herbage by cattle; <as>as, if grain is too forward in autumn,
<ex>feed</ex> it with sheep</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Once in three years <qex>feed</qex> your mowing lands.</q>
<rj><qau>Mortimer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To give for food, especially to animals; to furnish
for consumption; <as>as, to <ex>feed</ex> out turnips to the cows; to
<ex>feed</ex> water to a steam boiler.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Mach.)</fld> <sd>(a)</sd> <def>To supply (the
material to be operated upon) to a machine; <as>as, to <ex>feed</ex>
paper to a printing press</as>.</def> <sd>(b)</sd> <def>To produce
progressive operation upon or with (as in wood and metal working
machines, so that the work moves to the cutting tool, or the tool to the
work).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feed</ent><br/
<hw>Feed</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To take food; to
eat.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Her kid . . . which I afterwards killed because it would not
<qex>feed</qex>.</q> <rj><qau>De Foe.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To subject by eating; to satisfy the appetite; to
feed one's self (upon something); to prey; -- with <xex>on</xex> or
<xex>upon</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Leaving thy trunk for crows to <qex>feed</qex> upon.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To be nourished, strengthened, or satisfied, as if
by food.</def> <ldquo/He <xex>feeds</xex> upon the cooling shade.<rdquo/
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To place cattle to feed; to pasture; to
graze.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If a man . . . shall put in his beast, and shall <qex>feed</qex>
in another man's field.</q> <rj><qau>Ex. xxii. 5.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feed</ent><br/
<hw>Feed</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>That which is
eaten; esp., food for beasts; fodder; pasture; hay; grain, ground or
whole; <as>as, the best <ex>feed</ex> for sheep</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A grazing or pasture ground.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>An allowance of provender given to a horse, cow,
etc.; a meal; <as>as, a <ex>feed</ex> of corn or oats</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A meal, or the act of eating.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>For such pleasure till that hour<br/
At <qex>feed</qex> or fountain never had I found.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>The water supplied to steam boilers.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Mach.)</fld> <sd>(a)</sd> <def>The motion, or act,
of carrying forward the stuff to be operated upon, as cloth to the
needle in a sewing machine; or of producing progressive operation upon
any material or object in a machine, as, in a turning lathe, by moving
the cutting tool along or in the work.</def> <sd>(b)</sd> <def>The
supply of material to a machine, as water to a steam boiler, coal to a
furnace, or grain to a run of stones.</def> <sd>(c)</sd> <def>The
mechanism by which the action of feeding is produced; a feed
motion.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Feed bag</b></col>, <cd>a nose bag containing feed for a
horse or mule.</cd> -- <col><b>Feed cloth</b></col>, <cd>an apron for
leading cotton, wool, or other fiber, into a machine, as for carding,
etc.</cd> -- <col><b>Feed door</b></col>, <cd>a door to a furnace, by
which to supply coal.</cd> -- <col><b>Feed head</b></col>. <sd>(a)</sd>
<cd>A cistern for feeding water by gravity to a steam boiler.</cd>
<sd>(b)</sd> <fld>(Founding)</fld> <cd>An excess of metal above a mold,
which serves to render the casting more compact by its pressure; -- also
called a <altname>riser</altname>, <altname>deadhead</altname>, or
simply <altname>feed</altname> or <altname>head</altname></cd>
<au>Knight.</au> -- <col><b>Feed heater</b></col>. <sd>(a)</sd>
<fld>(Steam Engine)</fld> <cd>A vessel in which the feed water for the
boiler is heated, usually by exhaust steam.</cd> <sd>(b)</sd> <cd>A
boiler or kettle in which is heated food for stock.</cd> --
<mcol><col><b>Feed motion</b></col>, <it>or</it> <col><b>Feed
gear</b></col></mcol> <fld>(Mach.)</fld>, <cd>the train of mechanism
that gives motion to the part that directly produces the feed in a
machine.</cd> -- <col><b>Feed pipe</b></col>, <cd>a pipe for supplying
the boiler of a steam engine, etc., with water.</cd> -- <col><b>Feed
pump</b></col>, <cd>a force pump for supplying water to a steam boiler,
etc.</cd> -- <col><b>Feed regulator</b></col>, <cd>a device for
graduating the operation of a feeder.</cd> <au>Knight.</au> --
<col><b>Feed screw</b></col>, <cd>in lathes, a long screw employed to
impart a regular motion to a tool rest or tool, or to the work.</cd> --
<col><b>Feed water</b></col>, <cd>water supplied to a steam boiler,
etc.</cd> -- <col><b>Feed wheel</b></col> <fld>(Mach.)</fld>, <cd>a kind
of feeder. See <er>Feeder</er>, <pos>n.</pos>, 8.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>feedback</ent><br/
<hw>feedback</hw> <pos>n.</pos> <sn>1.</sn> <def>the process in which
part of the output of a system is returned to its input.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>response to an inquiry or experiment.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>feed bag</ent><br/
<ent>feedbag</ent><br/
<mhw><hw>feedbag</hw>, <hw>feed bag</hw></mhw> <pos>n.</pos> <def>a
canvas bag that is used to feed an animal (such as a horse or mule);
animal feed such as oats are placed in the bag, and it is fastened at
the top of the head, covering the muzzle. The animal may then eat the
contents while thus wearing the feedbag.</def><br/
<syn><b>Syn. --</b> nosebag.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Feeder</ent><br/
<hw>Feed"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who,
or that which, gives food or supplies nourishment; steward.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A couple of friends, his chaplain and <qex>feeder</qex>.</q>
<rj><qau>Goldsmith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who furnishes incentives; an encourager.</def>
<ldquo/The <xex>feeder</xex> of my riots.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>One who eats or feeds; specifically, an animal to be
fed or fattened.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With eager feeding, food doth choke the <qex>feeder</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>One who fattens cattle for slaughter.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A stream that flows into another body of water; a
tributary; specifically <fld>(Hydraulic Engin.)</fld>, a water course
which supplies a canal or reservoir by gravitation or natural
flow.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>A branch railroad, stage line, air route, or the
like; a side line which increases the business of the main
line.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>7.</sn> <fld>(Mining)</fld> <sd>(a)</sd> <def>A small lateral
lode falling into the main lode or mineral vein.</def> <au>Ure.</au>
<sd>(b)</sd> <def>A strong discharge of gas from a fissure; a
blower.</def> <au>Raymond.</au><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <fld>(Mach.)</fld> <def>An auxiliary part of a machine
which supplies or leads along the material operated upon.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <fld>(Steam Engine)</fld> <def>A device for supplying
steam boilers with water as needed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feeding</ent><br/
<hw>Feed"ing</hw>, <pos>n.</pos> <sn>1.</sn> <def>the act of eating, or
of supplying with food; the process of fattening.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is eaten; food.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which furnishes or affords food, especially for
animals; pasture land.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Feeding bottle</b></col>. <cd>See under
<er>Bottle</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fee-faw-fum</ent><br/
<hw>Fee`-faw`-fum"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A nonsensical
exclamation attributed to giants and ogres; hence, any expression
calculated to impose upon the timid and ignorant.</def> <ldquo/Impudent
<xex>fee-faw-fums</xex>.<rdquo/ <rj><au>J. H. Newman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feejee</ent><br/
<hw>Fee"jee</hw> <pr>(?)</pr>, <pos>a. & n.</pos> <fld>(Ethnol.)</fld>
<def>See <er>Fijian</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feel</ent><br/
<hw>Feel</hw> <pr>(f<emac/l)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Felt</conjf> <pr>(f<ecr/lt)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Feeling</conjf>.]</vmorph> <ety>[AS.
<ets>f<emac/lan</ets>; akin to OS. <ets>gif<omac/lian</ets> to perceive,
D. <ets>voelen</ets> to feel, OHG. <ets>fuolen</ets>, G.
<ets>f<uum/hlen</ets>, Icel. <ets>f<amac/lma</ets> to grope, and prob.
to AS. <ets>folm</ets> palm of the hand, L. <ets>palma</ets>. Cf.
<er>Fumble</er>, <er>Palm</er>.]</ety> <sn>1.</sn> <def>To perceive by
the touch; to take cognizance of by means of the nerves of sensation
distributed all over the body, especially by those of the skin; to have
sensation excited by contact of (a thing) with the body or
limbs.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Who <qex>feel</qex><br/
Those rods of scorpions and those whips of steel.</q>
<rj><qau>Creecn.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To touch; to handle; to examine by touching; <as>as,
<ex>feel</ex> this piece of silk</as>; hence, to make trial of; to test;
often with <ex>out</ex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Come near, . . . that I may <qex>feel</qex> thee, my son.</q>
<rj><qau>Gen. xxvii. 21.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He hath this to <qex>feel</qex> my affection to your honor.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To perceive by the mind; to have a sense of; to
experience; to be affected by; to be sensible of, or sensitive to;
<as>as, to <ex>feel</ex> pleasure; to <ex>feel</ex> pain.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Teach me to <qex>feel</qex> another's woe.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Whoso keepeth the commandment shall <qex>feel</qex> no evil
thing.</q> <rj><qau>Eccl. viii. 5.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He best can paint them who shall <qex>feel</qex> them most.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Mankind have <qex>felt</qex> their strength and made it
<qex>felt</qex>.</q> <rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To take internal cognizance of; to be conscious of;
to have an inward persuasion of.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>For then, and not till then, he <qex>felt</qex> himself.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To perceive; to observe.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To feel the helm</b></col> <fld>(Naut.)</fld>, <cd>to
obey it.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 550 --></p>

<p><ent>Feel</ent><br/
<hw>Feel</hw> <pr>(?)</pr>, <pos>v. i.</pos> <sn>1.</sn> <def>To have
perception by the touch, or by contact of anything with the nerves of
sensation, especially those upon the surface of the body.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To have the sensibilities moved or
affected.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>[She] <qex>feels</qex> with the dignity of a Roman matron</q>.
<rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And mine as man, who <qex>feel</qex> for all mankind.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To be conscious of an inward impression, state of
mind, persuasion, physical condition, etc.; to perceive one's self to
be; -- followed by an adjective describing the state, etc.; <as>as, to
<ex>feel</ex> assured, grieved, persuaded</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I then did <qex>feel</qex> full sick.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To know with feeling; to be conscious; hence, to
know certainly or without misgiving.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Garlands . . . which I <qex>feel</qex><br/
I am not worthy yet to wear.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To appear to the touch; to give a perception; to
produce an impression by the nerves of sensation; -- followed by an
adjective describing the kind of sensation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Blind men say black <qex>feels</qex> rough, and white
<qex>feels</qex> smooth.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<cs><p><col><b>To feel after</b></col>, <cd>to search for; to seek to
find; to seek as a person groping in the dark.</cd> <ldquo/If haply they
might <xex>feel after</xex> him, and find him.<rdquo/ <rj><au>Acts xvii.
27.</au></rj></p>

<p> -- <col><b>To feel of</b></col>, <cd>to examine by
touching.</cd><br/
[<source>1913 Webster</source>]</p></cs>

<p><ent>Feel</ent><br/
<hw>Feel</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>Feeling;
perception.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>To intercept and have a more kindly <qex>feel</qex> of its genial
warmth.</q> <rj><qau>Hazlitt.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A sensation communicated by touching; impression
made upon one who touches or handles; <as>as, this leather has a greasy
<ex>feel</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The difference between these two tumors will be distinguished by
the <qex>feel</qex>.</q> <rj><qau>S. Sharp.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feeler</ent><br/
<hw>Feel"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who,
or that which, feels.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>One of the sense organs or
certain animals (as insects), which are used in testing objects by touch
and in searching for food; an antenna; a palp.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Insects . . . perpetually feeling and searching before them with
their <qex>feelers</qex> or antenn<ae/.</q>
<rj><qau>Derham.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Anything, as a proposal, observation, etc., put
forth or thrown out in order to ascertain the views of others; something
tentative.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feeling</ent><br/
<hw>Feel"ing</hw>, <pos>a.</pos> <sn>1.</sn> <def>Possessing great
sensibility; easily affected or moved; <as>as, a <ex>feeling</ex>
heart</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Expressive of great sensibility; attended by, or
evincing, sensibility; <as>as, he made a <ex>feeling</ex> representation
of his wrongs</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feeling</ent><br/
<hw>Feel"ing</hw>, <pos>n.</pos> <sn>1.</sn> <def>The sense by which the
mind, through certain nerves of the body, perceives external objects, or
certain states of the body itself; that one of the five senses which
resides in the general nerves of sensation distributed over the body,
especially in its surface; the sense of touch; nervous sensibility to
external objects.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Why was the sight<br/
To such a tender ball as the eye confined, . . . <br/
And not, as <qex>feeling</qex>, through all parts diffused?</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An act or state of perception by the sense above
described; an act of apprehending any object whatever; an act or state
of apprehending the state of the soul itself; consciousness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The apprehension of the good<br/
Gives but the greater feeling to the worse.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The capacity of the soul for emotional states; a
high degree of susceptibility to emotions or states of the sensibility
not dependent on the body; <as>as, a man of <ex>feeling</ex>; a man
destitute of <ex>feeling</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Any state or condition of emotion; the exercise of
the capacity for emotion; any mental state whatever; <as>as, a right or
a wrong <ex>feeling</ex> in the heart; our angry or kindly
<ex>feelings</ex>; a <ex>feeling</ex> of pride or of
humility.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>A fellow <qex>feeling</qex> makes one wondrous kind.</q>
<rj><qau>Garrick.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Tenderness for the <qex>feelings</qex> of others.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>That quality of a work of art which embodies the
mental emotion of the artist, and is calculated to affect similarly the
spectator.</def> <rj><au>Fairholt.</au></rj></p>

<p><syn><b>Syn.</b> -- Sensation; emotion; passion; sentiment;
agitation; opinion. See <er>Emotion</er>, <er>Passion</er>,
<er>Sentiment</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feelingly</ent><br/
<hw>Feel"ing*ly</hw>, <pos>adv.</pos> <def>In a feeling manner;
pathetically; sympathetically.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feere</ent><br/
<hw>Feere</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See <er>Fere</er>,
<pos>n.</pos>]</ety> <def>A consort, husband or wife; a companion; a
fere.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feese</ent><br/
<hw>Feese</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. OE.
<ets>fesien</ets> to put to flight, AS. <ets>f<emac/sian</ets>,
<ets>f<ymac/sian</ets>, <ets>f<ymac/san</ets>, fr. <ets>f<umac/s</ets>,
prompt, willing.]</ety> <def>The short run before a leap.</def>
<mark>[Obs.]</mark> <rj><au>Nares.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feet</ent><br/
<hw>Feet</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <def>See
<er>Foot</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feet</ent><br/
<hw>Feet</hw>, <pos>n.</pos> <ety>[See <er>Feat</er>,
<pos>n.</pos>]</ety> <def>Fact; performance.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feetless</ent><br/
<hw>Feet"less</hw>, <pos>a.</pos> <def>Destitute of feet; <as>as,
<ex>feetless</ex> birds</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feeze</ent><br/
<hw>Feeze</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[For sense 1, cf. F.
<ets>visser</ets> to screw, <ets>vis</ets> screw, or 1st E.
<ets>feaze</ets>, v.t.: for sense 2, see <er>Feese</er>.]</ety>
<sn>1.</sn> <def>To turn, as a screw.</def> <mark>[Scot]</mark>
<rj><au>Jamieson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To beat; to chastise; to humble; to worry.</def>
<mark>[Obs.]</mark> <altsp>[Written also <asp>feaze</asp>,
<asp>feize</asp>, <asp>pheese</asp>.]</altsp> <rj><au>Beau. &
Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To feeze up</b></col>, <cd>to work into a passion.</cd>
<mark>[Obs.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feeze</ent><br/
<hw>Feeze</hw>, <pos>n.</pos> <def>Fretful excitement.
<mark>[Obs.]</mark> See <er>Feaze</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fehling</ent><br/
\'d8<hw>Feh"ling</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>See <cref>Fehling's solution</cref>, under
<er>Solution</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fehmgericht</ent><br/
<ent>Fehm</ent><br/
<mhw>\'d8<hw>Fehm</hw> <pr>(?)</pr>, <pos>n.</pos>,
\'d8<hw>Fehm"ge*richt`</hw> <pr>(<?/)</pr></mhw>, <pos>n.</pos>
<def>Same as <er>Vehm</er>, <er>Vehmgericht</er>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Fehmic</ent><br/
<hw>Feh"mic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>See
<er>Vehmic</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feign</ent><br/
<hw>Feign</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Feigned</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Feigning</conjf>.]</vmorph> <ety>[OE. <ets>feinen</ets>, F.
<ets>feindre</ets> (p. pr. <ets>feignant</ets>), fr. L.
<ets>fingere</ets>; akin to L. <ets>figura</ets> figure,and E.
<ets>dough</ets>. See <er>Dough</er>, and cf. <er>Figure</er>,
<er>Faint</er>, <er>Effigy</er>, <er>Fiction</er>.]</ety> <sn>1.</sn>
<def>To give a mental existence to, as to something not real or actual;
to imagine; to invent; hence, to pretend; to form and relate as if
true.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There are no such things done as thou sayest, but thou
<qex>feignest</qex> them out of thine own heart.</q> <rj><qau>Neh. vi.
8.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The poet<br/
Did <qex>feign</qex> that Orpheus drew trees, stones, and floods.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To represent by a false appearance of; to pretend;
to counterfeit; <as>as, to <ex>feign</ex> a sickness</as>.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To dissemble; to conceal.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feigned</ent><br/
<hw>Feigned</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Not real or genuine;
pretended; counterfeit; insincere; false.</def> <ldquo/A
<xex>feigned</xex> friend.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Give ear unto my prayer, that goeth not out of <qex>feigned</qex>
lips.</q> <rj><qau>Ps. xvii. 1.</qau></rj></p>

<p>-- <wordforms><wf>Feign"ed*ly</wf> <pr>(#)</pr>, <pos>adv.</pos> --
<wf>Feign"ed*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><q>Her treacherous sister Judah hath not turned unto me with her
whole heart, but <qex>feignedly</qex>.</q> <rj><qau>Jer. iii.
10.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Feigned issue</b></col> <fld>(Law)</fld>, <cd>an issue
produced in a pretended action between two parties for the purpose of
trying before a jury a question of fact which it becomes necessary to
settle in the progress of a cause.</cd> <au>Burill.</au>
<au>Bouvier.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feigner</ent><br/
<hw>Feign"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who feigns or
pretends.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feigning</ent><br/
<hw>Feign"ing</hw>, <pos>a.</pos> <def>That feigns; insincere; not
genuine; false.</def></p>

<p>-- <wordforms><wf>Feign"ing*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feine</ent><br/
<hw>Feine</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <def>To feign.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feint</ent><br/
<hw>Feint</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F. <ets>feint</ets>, p.
p. of <ets>feindre</ets> to feign. See <er>Feign</er>.]</ety>
<def>Feigned; counterfeit.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Dressed up into any <qex>feint</qex> appearance of it.</q>
<rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feint</ent><br/
<hw>Feint</hw>, <pos>n.</pos> <ety>[F. <ets>feinte</ets>, fr.
<ets>feint</ets>. See <er>Feint</er>, <pos>a.</pos>]</ety> <sn>1.</sn>
<def>That which is feigned; an assumed or false appearance; a pretense;
a stratagem; a fetch.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Courtley's letter is but a <qex>feint</qex> to get off.</q>
<rj><qau>Spectator.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A mock blow or attack on one part when another part
is intended to be struck; -- said of certain movements in fencing,
boxing, war, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feint</ent><br/
<hw>Feint</hw>, <pos>v. i.</pos> <def>To make a feint, or mock
attack.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feitsui</ent><br/
\'d8<hw>Fei`tsui"</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Min.)</fld>
<def>The Chinese name for a highly prized variety of pale green jade.
See <er>Jade</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feize</ent><br/
<hw>Feize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>See <er>Feeze</er>,
<pos>v. t.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Felanders</ent><br/
<hw>Fel"an*ders</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <def>See
<er>Filanders</er>.</def></p>

<p><ent>Feldspath</ent><br/
<ent>Feldspar</ent><br/
<mhw>{ <hw>Feld"spar`</hw> <pr>(?)</pr>, <hw>Feld"spath`</hw>
<pr>(?)</pr> }</mhw>, <pos>n.</pos> <ety>[G. <ets>feldspath</ets>;
<ets>feld</ets> field + <ets>spath</ets> spar.]</ety> <fld>(Min.)</fld>
<def>A name given to a group of minerals, closely related in crystalline
form, and all silicates of alumina with either potash, soda, lime, or,
in one case, baryta. They occur in crystals and crystalline masses,
vitreous in luster, and breaking rather easily in two directions at
right angles to each other, or nearly so. The colors are usually white
or nearly white, flesh-red, bluish, or greenish.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The group includes the monoclinic
(<xex>orthoclastic</xex>) species <xex>orthoclase</xex> or common potash
feldspar, and the rare <xex>hyalophane</xex> or baryta feldspar; also
the triclinic species (called in general <xex>plagioclase</xex>)
<xex>microcline</xex>, like orthoclase a potash feldspar;
<xex>anorthite</xex> or lime feldspar; <xex>albite</xex> or soda
feldspar; also intermediate between the last two species,
<xex>labradorite</xex>, <xex>andesine</xex>, <xex>oligoclase</xex>,
containing both lime and soda in varying amounts. The feldspars are
essential constituents of nearly all crystalline rocks, as granite,
gneiss, mica, slate, most kinds of basalt and trachyte, etc. The
decomposition of feldspar has yielded a large part of the clay of the
soil, also the mineral kaolin, an essential material in the making of
fine pottery. Common feldspar is itself largely used for the same
purpose.</note></p>

<p><ent>Feldspathose</ent><br/
<ent>Feldspathic</ent><br/
<mhw>{ <hw>Feld*spath"ic</hw> <pr>(?)</pr>, <hw>Feld*spath"ose</hw>
<pr>(?)</pr> }</mhw>, <pos>a.</pos> <def>Pertaining to, or consisting
of, feldspar.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fele</ent><br/
<hw>Fele</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[AS. <ets>fela</ets>,
<ets>feola</ets>; akin to G. <ets>viel</ets>, gr. <?/. See
<er>Full</er>, <pos>a.</pos>]</ety> <def>Many.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Felicify</ent><br/
<hw>Fe*lic"ify</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>felix</ets> happy + <ets>-fy</ets>.]</ety> <def>To make happy; to
felicitate.</def> <mark>[Obs.]</mark> <rj><au>Quarles.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Felicitate</ent><br/
<hw>Fe*lic"i*tate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>felicitatus</ets>, p. p. of <ets>felicitare</ets> to felicitate,
fr. <ets>felix</ets>, <ets>-icis</ets>, happy. See
<er>felicity</er>.]</ety> <def>Made very happy.</def>
<mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I am alone <qex>felicitate</qex><br/
In your dear highness' love.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Felicitate</ent><br/
<hw>Fe*lic"i*tate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Felicitated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>felicitating</conjf>.]</vmorph> <ety>[Cf. F.
<ets>f<eacute/liciter</ets>.]</ety> <sn>1.</sn> <def>To make very happy;
to delight.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>What a glorious entertainment and pleasure would fill and
<qex>felicitate</qex> his spirit.</q> <rj><qau>I. Watts.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To express joy or pleasure to; to wish felicity to;
to call or consider (one's self) happy; to congratulate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Every true heart must <qex>felicitate</qex> itself that its lot is
cast in this kingdom.</q> <rj><qau>W. Howitt.</qau></rj></p>

<p><syn><b>Syn.</b> -- See <er>Congratulate</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Felicitation</ent><br/
<hw>Fe*lic`i*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>f<eacute/licitation</ets>.]</ety> <def>The act of felicitating; a
wishing of joy or happiness; congratulation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Felicitous</ent><br/
<hw>Fe*lic"i*tous</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Characterized by
felicity; happy; prosperous; delightful; skillful; successful; happily
applied or expressed; appropriate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Felicitous</qex> words and images.</q> <rj><qau>M.
Arnold.</qau></rj></p>

<p>-- <wordforms><wf>Fe*lic"i*tous*ly</wf>, <pos>adv.</pos> --
<wf>Fe*lic"i*tous*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>felicitousness</ent><br/
<hw>fe*lic"i*tous*ness</hw> <pos>n.</pos> <def>a pleasing and
appropriate manner or style, especially of expression.</def><br/
<syn><b>Syn. --</b> felicity.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Felicity</ent><br/
<hw>Fe*lic"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Felicities</plw> <pr>(#)</pr>.</plu> <ety>[OE. <ets>felicite</ets>,
F. <ets>f<eacute/licit<eacute/</ets>, fr. L. <ets>felicitas</ets>, fr.
<ets>felix</ets>, <ets>-icis</ets>, happy, fruitful; akin to
<ets>fetus</ets>.]</ety> <sn>1.</sn> <def>The state of being happy;
blessedness; blissfulness; enjoyment of good.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Our own <qex>felicity</qex> we make or find.</q>
<rj><qau>Johnson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Finally, after this life, to attain everlasting joy and
<qex>felicity</qex>.</q> <rj><qau>Book of Common Prayer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which promotes happiness; a successful or
gratifying event; prosperity; blessing.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>the <qex>felicities</qex> of her wonderful reign.</q>
<rj><qau>Atterbury.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A pleasing faculty or accomplishment; <as>as,
<ex>felicity</ex> in painting portraits, or in writing or
talking</as>.</def> <ldquo/<xex>Felicity</xex> of expression.<rdquo/
<rj><au>Bp. Warburton.</au></rj></p>

<p><syn><b>Syn.</b> -- Happiness; bliss; beatitude; blessedness;
blissfulness. See <er>Happiness</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>felid</ent><br/
<hw>felid</hw> <pos>n.</pos> <def>any of various lithe-bodied
round-headed fissiped mammals, many with retractile claws; a member of
the <fam>Felidae</fam>.</def><br/
<syn><b>Syn. --</b> feline.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Felidae</ent><br/
<hw>Felidae</hw> <pos>n.</pos> <def>a natural family of lithe-bodied
round-headed fissiped mammals, including the cats; wildcats; lions;
leopards; cheetahs; and saber-toothed tigers.</def><br/
<syn><b>Syn. --</b> family <fam>Felidae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Feline</ent><br/
<hw>Fe"line</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>felinus</ets>, fr. <ets>feles</ets>, <ets>felis</ets>, cat, prob.
orig., the fruitful: cf. F. <ets>f<eacute/lin</ets>. See
<er>Fetus</er>.]</ety> <sn>1.</sn> <fld>(Zool.)</fld> <def>Catlike; of
or pertaining to the genus <gen>Felis</gen>, or family
<fam>Felid<ae/</fam>; <as>as, the <ex>feline</ex> race; <ex>feline</ex>
voracity.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Characteristic of cats; sly; stealthy; treacherous;
<as>as, a <ex>feline</ex> nature; <ex>feline</ex>
manners.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Felis</ent><br/
\'d8<hw>Fe"lis</hw> <pr>(f<emac/"l<icr/s)</pr>, <pos>prop. n.</pos>
<ety>[L., cat.]</ety> <fld>(Zool.)</fld> <def>A genus of mostly small
carnivorous mammals, including the domestic cat, puma, ocelot, and
margay, which share the inability to roar due to bone structure in the
larynx. The lion, tiger, and other large roaring cats were once included
in <gen>Felis</gen> but are now assigned to the genus
<gen>Panthera</gen>. The lynx (<spn>Felis lynx</spn>) is also called
<spn>Lynx lynx</spn>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>fell</ent><br/
<hw>Fell</hw> <pr>(f<ecr/l)</pr>, <def><pos>imp.</pos> of
<er>Fall</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fell</ent><br/
<hw>Fell</hw>, <pos>a.</pos> <ety>[OE. <ets>fel</ets>, OF.
<ets>fel</ets> cruel, fierce, perfidious; cf. AS. <ets>fel</ets> (only
in comp.) OF. <ets>fel</ets>, as a noun also accus. <ets>felon</ets>, is
fr. LL. <ets>felo</ets>, of unknown origin; cf. Arm <ets>fall</ets>
evil, Ir. <ets>feal</ets>, Arm. <ets>falloni</ets> treachery, Ir. &
Gael. <ets>feall</ets> to betray; or cf. OHG. <ets>fillan</ets> to flay,
torment, akin to E. <ets>fell</ets> skin. Cf. <er>Felon</er>.]</ety>
<sn>1.</sn> <def>Cruel; barbarous; inhuman; fierce; savage;
ravenous.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>While we devise <qex>fell</qex> tortures for thy faults.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Eager; earnest; intent.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I am so <qex>fell</qex> to my business.</q>
<rj><qau>Pepys.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fell</ent><br/
<hw>Fell</hw>, <pos>n.</pos> <ety>[Cf. L. <ets>fel</ets> gall, bile, or
E. <ets>fell</ets>, <pos>a.</pos>]</ety> <def>Gall; anger;
melancholy.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Untroubled of vile fear or bitter <qex>fell</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fell</ent><br/
<hw>Fell</hw>, <pos>n.</pos> <ety>[AS. <ets>fell</ets>; akin to D.
<ets>vel</ets>, OHG. <ets>fel</ets>, G. <ets>fell</ets>, Icel.
<ets>fell</ets> (in comp.), Goth <ets>fill</ets> in
<thorn/ruts<ets>fill</ets> leprosy, L. <ets>pellis</ets> skin, Gr.
<grk>pe`lla</grk>. Cf. <er>Film</er>, <er>Peel</er>, <er>Pell</er>,
<pos>n.</pos>]</ety> <def>A skin or hide of a beast with the wool or
hair on; a pelt; -- used chiefly in composition, as
wool<xex>fell</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We are still handling our ewes, and their <qex>fells</qex>, you
know, are greasy.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fell</ent><br/
<hw>Fell</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Icel. <ets>fell</ets>,
<ets>fjally</ets>; akin to Sw. <ets>fj<aum/ll</ets> a ridge or chain of
mountains, Dan. <ets>fjeld</ets> mountain, rock and prob. to G.
<ets>fels</ets> rock, or perh. to <ets>feld</ets> field, E.
<ets>field</ets>.]</ety> <sn>1.</sn> <def>A barren or rocky hill.</def>
<rj><au>T. Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A wild field; a moor.</def>
<rj><au>Dryton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fell</ent><br/
<hw>Fell</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Felled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Felling</conjf>.]</vmorph> <ety>[AS. <ets>fellan</ets>, a
causative verb fr. <ets>feallan</ets> to fall; akin to D.
<ets>vellen</ets>, G. <ets>f<aum/llen</ets>, Icel. <ets>fella</ets>, Sw.
<ets>f<aum/lla</ets>, Dan. <ets>f<ae/lde</ets>. See <er>Fall</er>,
<pos>v. i.</pos>]</ety> <def>To cause to fall; to prostrate; to bring
down or to the ground; to cut down.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Stand, or I'll <qex>fell</qex> thee down.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fell</ent><br/
<hw>Fell</hw>, <pos>n.</pos> <fld>(Mining)</fld> <def>The finer portions
of ore which go through the meshes, when the ore is sorted by
sifting.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fell</ent><br/
<hw>Fell</hw>, <pos>v. t.</pos> <ety>[Cf. Gael. <ets>fill</ets> to fold,
plait, Sw. <ets>f<aring/ll</ets> a hem.]</ety> <def>To sew or hem; --
said of seams.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fell</ent><br/
<hw>Fell</hw>, <pos>n.</pos> <sn>1.</sn> <fld>(Sewing)</fld> <def>A form
of seam joining two pieces of cloth, the edges being folded together and
the stitches taken through both thicknesses.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Weaving)</fld> <def>The end of a web, formed by the
last thread of the weft.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fellable</ent><br/
<hw>Fell"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Fit to be
felled.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fellah</ent><br/
\'d8<hw>Fel"lah</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it> Ar.
<plw>Fellahin</plw> <pr>(#)</pr>, E. <plw>Fellahs</plw>
<pr>(#)</pr>.</plu> <ety>[Ar.]</ety> <def>A peasant or cultivator of the
soil among the Egyptians, Syrians, etc.</def> <rj><au>W. M.
Thomson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>fellatio</ent><br/
<hw>fel*la"ti*o</hw> <pr>(f<ecr/l*l<amac/"sh<emac/*<osl/;
f<ecr/l*l<amac/"t<emac/*<osl/)</pr>, <pos>n.</pos> <def>a form of sexual
activity between two persons in which the penis of one is stimulated by
the other's mouth, especially until orgasm is achieved. It is a form of
<isa>oral sex</isa>. Compare <contr>cunnilingus</contr>. The act is also
called by the slang term <altname>blow job</altname>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Feller</ent><br/
<hw>Fell"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, fells, knocks or cuts down; a machine for felling
trees.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feller</ent><br/
<hw>Fell"er</hw>, <pos>n.</pos> <def>An appliance to a sewing machine
for felling a seam.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fellfare</ent><br/
<hw>Fell"fare`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. AS.
<ets>fealafor</ets>, and E. <ets>fieldfare</ets>.]</ety>
<fld>(Zool.)</fld> <def>The fieldfare.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fellifluous</ent><br/
<hw>Fel*lif"lu*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>fellifuus</ets>; <ets>fel</ets> gall + <ets>fluere</ets> to
flow.]</ety> <def>Flowing with gall.</def> <mark>[R.]</mark>
<rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fellinic</ent><br/
<hw>Fel*lin"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>fel</ets>,
<ets>fellis</ets>, gall.]</ety> <def>Of, relating to, or derived from,
bile or gall; <as>as, <ex>fellinic</ex> acid</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fellmonger</ent><br/
<hw>Fell"mon`ger</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A dealer in fells
or sheepskins, who separates the wool from the pelts.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fellness</ent><br/
<hw>Fell"ness</hw>, <pos>n.</pos> <ety>[See <er>Fell</er> cruel.]</ety>
<def>The quality or state of being fell or cruel; fierce
barbarity.</def> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Felloe</ent><br/
<hw>Fel"loe</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Felly</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fellon</ent><br/
<hw>Fel"lon</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Variant of
<er>Felon</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Those two were foes the <qex>fellonest</qex> on ground.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fellow</ent><br/
<hw>Fel"low</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>felawe</ets>, <ets>felaghe</ets>, Icel. <ets>f<emac/lagi</ets>, fr.
<ets>f<emac/lag</ets> companionship, prop., a laying together of
property; <ets>f<emac/</ets> property + <ets>lag</ets> a laying, pl.
<ets>l<oum/g</ets> law, akin to <ets>liggja</ets> to lie. See
<er>Fee</er>, and <er>Law</er>, <er>Lie</er> to be low.]</ety>
<sn>1.</sn> <def>A companion; a comrade; an associate; a partner; a
sharer.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>fellows</qex> of his crime.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>We are <qex>fellows</qex> still,<br/
Serving alike in sorrow.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>That enormous engine was flanked by two <qex>fellows</qex> almost
of equal magnitude.</q> <rj><qau>Gibbon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Commonly used of men, but sometimes of women.</note>
<rj><au>Judges xi. 37.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A man without good breeding or worth; an ignoble or
mean man.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Worth makes the man, and want of it, the <qex>fellow</qex>.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>An equal in power, rank, character, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It is impossible that ever Rome<br/
Should breed thy <qex>fellow</qex>.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>One of a pair, or of two things used together or
suited to each other; a mate; the male.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>When they be but heifers of one year, . . . they are let go to the
<qex>fellow</qex> and breed.</q> <rj><qau>Holland.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>This was my glove; here is the <qex>fellow</qex> of it.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A person; an individual.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>She seemed to be a good sort of <qex>fellow</qex>.</q>
<rj><qau>Dickens.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>In the English universities, a scholar who is
appointed to a foundation called a <xex>fellowship</xex>, which gives a
title to certain perquisites and privileges.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>In an American college or university, a member of
the corporation which manages its business interests; also, a graduate
appointed to a fellowship, who receives the income of the
foundation.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>A member of a literary or scientific society;
<as>as, a <ex>Fellow</ex> of the Royal Society</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Fellow</xex> is often used in compound words, or
adjectively, signifying <xex>associate</xex>, <xex>companion</xex>, or
sometimes <xex>equal</xex>. Usually, such compounds or phrases are
self-explanatory; as, <xex>fellow</xex>-citizen, or <xex>fellow</xex>
citizen; <xex>fellow</xex>-student, or <xex>fellow</xex> student;
<xex>fellow</xex>-workman, or <xex>fellow</xex> workman;
<xex>fellow</xex>-mortal, or <xex>fellow</xex> mortal;
<xex>fellow</xex>-sufferer; bed<xex>fellow</xex>; play<xex>fellow</xex>;
work<xex>fellow</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><q>Were the great duke himself here, and would lift up<br/
My head to <qex>fellow</qex> pomp amongst his nobles.</q>
<rj><qau>Ford.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fellow</ent><br/
<hw>Fel"low</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To suit with; to
pair with; to match.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fellow-commoner</ent><br/
<hw>Fel"low-com"mon*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A student
at Cambridge University, England, who <xex>commons</xex>, or dines, at
the Fellow's table.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fellow-creature</ent><br/
<hw>Fel"low-crea"ture</hw> <pr>(?; 135)</pr>, <pos>n.</pos> <def>One of
the same race or kind; one made by the same Creator.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Reason, by which we are raised above our
<qex>fellow-creatures</qex>, the brutes.</q> <rj><qau>I.
Watts.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fellowfeel</ent><br/
<hw>Fel"low*feel"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To share
through sympathy; to participate in.</def> <mark>[R.]</mark> <rj><au>D.
Rodgers.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fellow-feeling</ent><br/
<hw>Fel"low-feel"ing</hw>, <pos>n.</pos> <sn>1.</sn> <def>Sympathy; a
like feeling.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Joint interest.</def> <mark>[Obs.]</mark>
<rj><au>Arbuthnot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fellowless</ent><br/
<hw>Fel"low*less</hw>, <pos>a.</pos> <def>Without fellow or equal;
peerless.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Whose well-built walls are rare and <qex>fellowless</qex>.</q>
<rj><qau>Chapman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fellowlike</ent><br/
<hw>Fel"low*like`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Like a
companion; companionable; on equal terms; sympathetic.</def>
<mark>[Obs.]</mark> <rj><au>Udall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fellowly</ent><br/
<hw>Fel"low*ly</hw>, <pos>a.</pos> <def>Fellowlike.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fellowship</ent><br/
<hw>Fel"low*ship</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Fellow +
-ship.]</ety> <sn>1.</sn> <def>The state or relation of being or
associate.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Companionship of persons on equal and friendly
terms; frequent and familiar intercourse.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In a great town, friends are scattered, so that there is not that
<qex>fellowship</qex> which is in less neighborhods.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Men are made for society and mutual <qex>fellowship</qex>.</q>
<rj><qau>Calamy.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A state of being together; companionship;
partnership; association; hence, confederation; joint
interest.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The great contention of the sea and skies<br/
Parted our <qex>fellowship</qex>.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Fellowship</qex> in pain divides not smart</q>.
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Fellowship</qex> in woe doth woe assuage</q>.
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The goodliest <qex>fellowship</qex> of famous knights,<br/
Whereof this world holds record.</q> <rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Those associated with one, as in a family, or a
society; a company.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The sorrow of Noah with his <qex>fellowship</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>With that a joyous <qex>fellowship</qex> issued<br/
Of minstrels.</q> <rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Eng. & Amer. Universities)</fld> <def>A foundation
for the maintenance, on certain conditions, of a scholar called a
fellow, who usually resides at the university.</def> <-- why
"foundation"? stipend is more accurate now. This use is sense 4 of this
dictionary, an "endowment" --><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Arith.)</fld> <def>The rule for dividing profit and
loss among partners; -- called also partnership, company, and
distributive proportion.</def><br/
[<source>1913 Webster</source>]</p>

<cs><p><col><b>Good fellowship</b></col>, <cd>companionableness; the
spirit and disposition befitting comrades.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>There's neither honesty, manhood, nor good <qex>fellowship</qex>
in thee.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p></cs>

<p><-- p. 551 --></p>

<p><ent>Fellowship</ent><br/
<hw>Fel"low*ship</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Fellowshiped</conjf> <pr>(<?/)</pr>; <pos>p. pr. &
vb. n.</pos>. <conjf>Fellowshiping</conjf>.]</vmorph> <fld>(Eccl.)</fld>
<def>To acknowledge as of good standing, or in communion according to
standards of faith and practice; to admit to Christian
fellowship.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Felly</ent><br/
<hw>Fel"ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a fell or cruel
manner; fiercely; barbarously; savagely.</def>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Felly</ent><br/
<hw>Fel"ly</hw>, <pos>n.</pos>; <plu><it>pl.</it> <plw>Fellies</plw>
<pr>(<?/)</pr>.</plu> <ety>[OE. <ets>feli</ets>, <ets>felwe</ets>,
<ets>felow</ets>, AS. <ets>felg</ets>, <ets>felge</ets>; akin to D.
<ets>velg</ets>, G. <ets>felge</ets>, OHG. <ets>felga</ets> felly (also,
a harrow, but prob. a different word), Dan. <ets>felge</ets>.]</ety>
<def>The exterior wooden rim, or a segment of the rim, of a wheel,
supported by the spokes.</def> <altsp>[Written also
<asp>felloe</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><q>Break all the spokes and <qex>fellies</qex> from her wheel.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Felo-de-se</ent><br/
\'d8<hw>Fe"lo-de-se`</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Felos-de-se</plw> <pr>(#)</pr>.</plu> <ety>[LL. <ets>felo</ets>, E.
<ets>felon</ets> + <ets>de</ets> of, concerning + <ets>se</ets>
self.]</ety> <fld>(Law)</fld> <def>One who deliberately puts an end to
his own existence, or loses his life while engaged in the commission of
an unlawful or malicious act; a suicide.</def>
<rj><au>Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Felon</ent><br/
<hw>Fel"on</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE., adj., cruel,
<pos>n.</pos>, villain, ruffian, traitor, whitlow, F.
<ets>f<eacute/lon</ets> traitor, in OF. also, villain, fr. LL.
<ets>felo</ets>. See Fell, <pos>a.</pos>]</ety> <sn>1.</sn>
<fld>(Law)</fld> <def>A person who has committed a felony.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A person guilty or capable of heinous
crime.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Med.)</fld> <def>A kind of whitlow; a painful
imflammation of the periosteum of a finger, usually of the last
joint.</def></p>

<p><syn><b>Syn.</b> -- Criminal; convict; malefactor; culprit.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Felon</ent><br/
<hw>Fel"on</hw>, <pos>a.</pos> <def>Characteristic of a felon;
malignant; fierce; malicious; cruel; traitorous; disloyal.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Vain shows of love to vail his felon hate.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Felonious</ent><br/
<hw>Fe*lo"ni*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having the
quality of felony; malignant; malicious; villainous; traitorous;
perfidious; in a legal sense, done with intent to commit a crime;
<as>as, <ex>felonious</ex> homicide</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>O thievish Night,<br/
Why should'st thou, but for some <qex>felonious</qex> end,<br/
In thy dark lantern thus close up the stars?</q>
<rj><qau>Milton.</qau></rj></p>

<p>-- <wordforms><wf>Fe*lo"ni*ous*ly</wf>, <pos>adv.</pos> --
<wf>Fe*lo"ni*ous*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Felonous</ent><br/
<hw>Fel"o*nous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. OF.
<ets>feloneus</ets>. Cf. <er>Felonious</er>.]</ety> <def>Wicked;
felonious.</def> <mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Felonry</ent><br/
<hw>Fel"on*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A body of felons;
specifically, the convict population of a penal colony.</def>
<rj><au>Howitt.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Felonwort</ent><br/
<hw>Fel"on*wort`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>The bittersweet nightshade (<spn>Solanum Dulcamara</spn>). See
<er>Bittersweet</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Felony</ent><br/
<hw>Fel"o*ny</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Felonies</plw> <pr>(#)</pr>.</plu> <ety>[OE. <ets>felonie</ets>
cruelty, OF. <ets>felonie</ets>, F. <ets>f<eacute/lonie</ets> treachery,
malice. See <er>Felon</er>, <pos>n.</pos>]</ety> <sn>1.</sn>
<fld>(Feudal Law)</fld> <def>An act on the part of the vassal which cost
him his fee by forfeiture.</def> <rj><au>Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(O.Eng.Law)</fld> <def>An offense which occasions a
total forfeiture either lands or goods, or both, at the common law, and
to which capital or other punishment may be added, according to the
degree of guilt.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A heinous crime; especially, a crime punishable by
death or imprisonment.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Forfeiture for crime having been generally abolished in
the United States, the term <xex>felony</xex>, in American law, has lost
this point of distinction; and its meaning, where not fixed by statute,
is somewhat vague and undefined; generally, however, it is used to
denote an offense of a high grade, punishable either capitally or by a
term of imprisonment. In Massachusetts, by statute, any crime punishable
by death or imprisonment in the state prison, and no other, is a
<xex>felony</xex>; so in New York. the tendency now is to obliterate the
distinction between felonies and misdemeanors; and this has been done
partially in England, and completely in some of the States of the Union.
The distinction is purely arbitrary, and its entire abolition is only a
question of time.</note><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ There is no lawyer who would undertake to tell what a
<xex>felony</xex> is, otherwise than by enumerating the various kinds of
offenses which are so called. originally, the word <xex>felony</xex> had
a meaning: it denoted all offenses the penalty of which included
forfeiture of goods; but subsequent acts of Parliament have declared
various offenses to be felonies, without enjoining that penalty, and
have taken away the penalty from others, which continue, nevertheless,
to be called <xex>felonies</xex>, insomuch that the acts so called have
now no property whatever in common, save that of being unlawful and
purnishable.</note> <rj><au>J. S. Mill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col>To compound a felony</col>. <cd>See under <er>Compound</er>,
<pos>v. t.</pos></cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Felsite</ent><br/
<hw>Fel"site</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf.
<er>Feldspar</er>.]</ety> <fld>(Min.)</fld> <def>A finegrained rock,
flintlike in fracture, consisting essentially of orthoclase feldspar
with occasional grains of quartz.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Felsitic</ent><br/
<hw>Fel*sit"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>relating to,
composed of, or containing, felsite.</def></p>

<p><ent>Felspath</ent><br/
<ent>Felspar</ent><br/
<mhw>{ <hw>Fel"spar`</hw> <pr>(?)</pr>, <hw>Fel"spath`</hw> <pr>(?)</pr>
}</mhw>, <pos>n.</pos> <fld>(Min.)</fld> <def>See
<er>Feldspar</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Felspathic</ent><br/
<hw>Fel*spath"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>See
<er>Feldspathic</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Felstone</ent><br/
<hw>Fel"stone`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From G.
<ets>feldstein</ets>, in analogy with E. <ets>fel</ets>spar.]</ety>
<fld>(Min.)</fld> <def>See <er>Felsite</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Felt</ent><br/
<hw>Felt</hw> <pr>(?)</pr>, <def><pos>imp. & p. p. <or/ a.</pos> from
<er>Feel</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Felt</ent><br/
<hw>Felt</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS. <ets>felt</ets>;
akin to D. <ets>vilt</ets>, G. <ets>filz</ets>, and possibly to Gr. <?/
hair or wool wrought into felt, L. <ets>pilus</ets> hair,
<ets>pileus</ets> a felt cap or hat.]</ety> <sn>1.</sn> <def>A cloth or
stuff made of matted fibers of wool, or wool and fur, fulled or wrought
into a compact substance by rolling and pressure, with lees or size,
without spinning or weaving.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It were a delicate stratagem to shoe<br/
A troop of horse with felt.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A hat made of felt.</def>
<rj><au>Thynne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A skin or hide; a fell; a pelt.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>To know whether sheep are sound or not, see that the
<qex>felt</qex> be loose.</q> <rj><qau>Mortimer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col>Felt grain</col>, <cd>the grain of timber which is
transverse to the annular rings or plates; the direction of the
medullary rays in oak and some other timber.</cd>
<rj><au>Knight.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Felt</ent><br/
<hw>Felt</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Felted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Felting</conjf>.]</vmorph> <sn>1.</sn> <def>To make into felt, or
a feltike substance; to cause to adhere and mat together.</def>
<rj><au>Sir M. Hale.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To cover with, or as with, felt; <as>as, to
<ex>felt</ex> the cylinder of a steam engine</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Felter</ent><br/
<hw>Felt"er</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To clot or mat
together like felt.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His <qex>feltered</qex> locks that on his bosom fell.</q>
<rj><qau>Fairfax.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Felting</ent><br/
<hw>Felt"ing</hw>, <pos>n.</pos> <sn>1.</sn> <def>The material of which
felt is made; also, felted cloth; also, the process by which it is
made.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The act of splitting timber by the felt
grain.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feltry</ent><br/
<hw>Fel"try</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>feltre</ets>.]</ety> <def>See <er>Felt</er>, <pos>n.</pos></def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Felucca</ent><br/
<hw>Fe*luc"ca</hw> <pr>(<?/)</pr>, <pos>n.</pos> <ety>[It.
<ets>feluca</ets> (cf. Sp. <ets>faluca</ets>, Pg. <ets>falua</ets>), fr.
Ar. <ets>fulk</ets> ship, or <ets>harr<amac/qah</ets> a sort of
ship.]</ety> <fld>(Naut.)</fld> <def>A small, swift-sailing vessel,
propelled by oars and lateen sails, -- once common in the
Mediterranean.</def> <note>Sometimes it is constructed so that the helm
may be used at either end.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Felwort</ent><br/
<hw>Fel"wort`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Probably a
corruption of <ets>fieldwort</ets>.]</ety> <fld>(Bot.)</fld> <def>A
European herb (<spn>Swertia perennis</spn>) of the Gentian
family.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Female</ent><br/
<hw>Fe"male</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>femel</ets>,
<ets>femal</ets>, F. <ets>femelle</ets>, fr. L. <ets>femella</ets>, dim.
of <ets>femina</ets> woman. See <er>Feminine</er>.]</ety> <sn>1.</sn>
<def>An individual of the sex which conceives and brings forth young, or
(in a wider sense) which has an ovary and produces ova.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The male and <qex>female</qex> of each living thing.</q>
<rj><qau>Drayton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>A plant which produces only that
kind of reproductive organs which are capable of developing into fruit
after impregnation or fertilization; a pistillate plant.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Female</ent><br/
<hw>Fe"male</hw>, <pos>a.</pos> <sn>1.</sn> <def>Belonging to the sex
which conceives and gives birth to young, or (in a wider sense) which
produces ova; not male.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>As patient as the <qex>female</qex> dove<br/
When that her golden couplets are disclosed.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Belonging to an individual of the female sex;
characteristic of woman; feminine; <as>as, <ex>female</ex>
tenderness</as>.</def> <ldquo/<qex>Female</qex> usurpation.<rdquo/
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To the generous decision of a <qex>female</qex> mind, we owe the
discovery of America.</q> <rj><qau>Belknap.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Bot.)</fld> <def>Having pistils and no stamens;
pistillate; or, in cryptogamous plants, capable of receiving
fertilization.</def><br/
[<source>1913 Webster</source>]</p>

<cs><p><col>Female rhymes</col> <fld>(Pros.)</fld>, <cd>double rhymes,
or rhymes (called in French <xex>feminine</xex> rhymes because they end
in <xex>e</xex> weak, or <xex>feminine</xex>) in which two syllables, an
accented and an unaccented one, correspond at the end of each
line.</cd><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ A rhyme, in which the final syllables only agree
(<xex>strain</xex>, <xex>complain</xex>) is called a male rhyme; one in
which the two final syllables of each verse agree, the last being short
(<xex>motion</xex>, <xex>ocean</xex>), is called
<xex>female</xex>.</note> <rj><au>Brande & C.</au></rj></p>

<p>-- <col>Female screw</col>, <cd>the spiral-threaded cavity into which
another, or male, screw turns.</cd> <au>Nicholson.</au> -- <col>Female
fern</col> <fld>(Bot.)</fld>, <cd>a common species of fern with large
decompound fronds (<spn>Asplenium Filixf<ae/mina</spn>), growing in many
countries; lady fern.</cd><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The names <xex>male fern</xex> and <xex>female
fern</xex> were anciently given to two common ferns; but it is now
understood that neither has any sexual character.</note></p></cs>

<p><syn><b>Syn.</b> -- <er>Female</er>, <er>Feminine</er>.</syn>
<usage>We apply <xex>female</xex> to the sex or individual, as opposed
to <xex>male</xex>; also, to the distinctive belongings of women; as,
<xex>female</xex> dress, <xex>female</xex> form, <xex>female</xex>
character, etc.; <xex>feminine</xex>, to things appropriate to, or
affected by, women; as, <xex>feminine</xex> studies, employments,
accomplishments, etc. <ldquo/<xex>Female</xex> applies to sex rather
than gender, and is a physiological rather than a grammatical term.
<xex>Feminine</xex> applies to gender rather than sex, and is
grammatical rather than physiological.<rdquo/</usage>
<rj><au>Latham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Femalist</ent><br/
<hw>Fe"mal*ist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A gallant.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Courting her smoothly like a <qex>femalist</qex>.</q>
<rj><qau>Marston.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Femalize</ent><br/
<hw>Fe"mal*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To make, or to
describe as, female or feminine.</def>
<rj><au>Shaftesbury.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feme</ent><br/
\'d8<hw>Feme</hw> <pr>(f<ecr/m <it>or</it> f<acr/m)</pr>, <pos>n.</pos>
<ety>[OF. <ets>feme</ets>, F. <ets>femme</ets>.]</ety> <fld>(Old
Law)</fld> <def>A woman.</def> <rj><au>Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Feme covert</b></col> <fld>(Law)</fld>, <cd>a married
woman. See <er>Covert</er>, <pos>a.</pos>, 3.</cd> -- <col><b>Feme
sole</b></col> <fld>(Law)</fld>, <cd>a single or unmarried woman; a
woman who has never been married, or who has been divorced, or whose
husband is dead.</cd> -- <mcol><col><b>Feme sole trader</b></col>
<it>or</it> <col><b>Feme sole merchant</b></col></mcol> <fld>(Eng.
Law)</fld>, <cd>a married woman, who, by the custom of London, engages
in business on her own account, inpendently of her
husband.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Femeral</ent><br/
<hw>Fem"er*al</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Arch.)</fld>
<def>See <er>Femerell</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Femerell</ent><br/
<hw>Fem"er*ell</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>fumeraille</ets> part of a chimney. See <er>Fume</er>.]</ety>
<fld>(Arch.)</fld> <def>A lantern, or louver covering, placed on a roof,
for ventilation or escape of smoke.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feminal</ent><br/
<hw>Fem"i*nal</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Feminine.</def>
<mark>[Obs.]</mark> <rj><au>West.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feminality</ent><br/
<hw>Fem`i*nal"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Feminity.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feminate</ent><br/
<hw>Fem"i*nate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>feminatus</ets> effeminate.]</ety> <def>Feminine.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Femineity</ent><br/
<hw>Fem`i*ne"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>femineus</ets> womanly.]</ety> <def>Womanliness; femininity.</def>
<rj><au>C. Reade.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feminine</ent><br/
<hw>Fem"i*nine</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>femininus</ets>, fr. <ets>femina</ets> woman; prob. akin to L.
<ets>fetus</ets>, or to Gr. <grk>qh^sqai</grk> to suck,
<grk>qh^sai</grk> to suckle, Skr. <ets>dh<amac/</ets> to suck; cf. AS.
<ets>f<aemac/mme</ets> woman, maid: cf. F. <ets>f<eacute/minin</ets>.
See <er>Fetus</er>.]</ety> <sn>1.</sn> <def>Of or pertaining to a woman,
or to women; characteristic of a woman; womanish; womanly.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Her letters are remarkably deficient in <qex>feminine</qex> ease
and grace.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Having the qualities of a woman; becoming or
appropriate to the female sex; as, in a good sense, modest, graceful,
affectionate, confiding; or, in a bad sense, weak, nerveless, timid,
pleasure-loving, effeminate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Her heavenly form<br/
Angelic, but more soft and <qex>feminine</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Ninus being esteemed no man of war at all, but altogether
<qex>feminine</qex>, and subject to ease and delicacy.</q> <rj><qau>Sir
W. Raleigh.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col>Feminine rhyme</col>. <fld>(Pros.)</fld> <cd>See
<cref>Female rhyme</cref>, under <er>Female</er>,
<pos>a.</pos></cd></cs></p>

<p><syn><b>Syn.</b> -- See <er>Female</er>, <pos>a.</pos></syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feminine</ent><br/
<hw>Fem"i*nine</hw>, <pos>n.</pos> <sn>1.</sn> <def>A woman.</def>
<mark>[Obs. or Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>They guide the <qex>feminines</qex> toward the palace.</q>
<rj><qau>Hakluyt.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Gram.)</fld> <def>Any one of those words which are
the appellations of females, or which have the terminations usually
found in such words; as, <examp>actress</examp>,
<examp>songstress</examp>, <examp>abbess</examp>,
<examp>executrix</examp>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There are but few true <qex>feminines</qex> in English.</q>
<rj><qau>Latham.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Femininely</ent><br/
<hw>Fem"i*nine*ly</hw>, <pos>adv.</pos> <def>In a feminine manner.</def>
<rj><au>Byron.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feminineness</ent><br/
<hw>Fem"i*nine*ness</hw>, <pos>n.</pos> <def>The quality of being
feminine; womanliness; womanishness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Femininity</ent><br/
<hw>Fem`i*nin"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
quality or nature of the female sex; womanliness.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The female form.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>O serpent under <qex>femininitee</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feminity</ent><br/
<hw>Fe*min"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Womanliness;
femininity.</def> <mark>[Obs.]</mark> <ldquo/Trained up in true
<qex>feminity</qex>.<rdquo/ <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feminization</ent><br/
<hw>Fem`i*ni*za"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
feminizing, or the state of being feminized.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feminize</ent><br/
<hw>Fem"i*nize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Cf. F.
<ets>f<eacute/miniser</ets>.]</ety> <def>To make womanish or
effeminate.</def> <rj><au>Dr. H. More.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feminye</ent><br/
<hw>Fem"i*nye</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>femenie</ets>, <ets>feminie</ets>, the female sex, realm of
women.]</ety> <def>The people called Amazons.</def> <mark>[Obs.]</mark>
<ldquo/[The reign of] <xex>feminye</xex>.<rdquo/ <au>Chaucer.</au><br/
[<source>1913 Webster</source>]</p>

<p><ent>Femme</ent><br/
\'d8<hw>Femme</hw> <pr>(? <or/ ?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<def>A woman. See <er>Feme</er>, <pos>n.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Femme de chambre</b></col> <pr>(?)</pr>. <ety>[F.]</ety>
<cd>A lady's maid; a chambermaid.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Femoral</ent><br/
<hw>Fem"o*ral</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>femur</ets>, <ets>femoris</ets>, thigh: cf. F.
<ets>f<eacute/moral</ets>.]</ety> <def>Pertaining to the femur or thigh;
<as>as, the <ex>femoral</ex> artery</as>.</def>
<ldquo/<xex>Femoral</xex> habiliments.<rdquo/ <au>Sir W. Scott.</au><br/
[<source>1913 Webster</source>]</p>

<p><ent>femoris</ent><br/
<hw>femoris</hw> <pos>n.</pos> <def>The thigh bone; same as
<er>femur</er>.</def><br/
<syn><b>Syn. --</b> femur, thighbone.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Femur</ent><br/
\'d8<hw>Fe"mur</hw> <pr>(f<emac/"m<ucr/r)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Femora</plw>
<pr>(f<ecr/m"<osl/*r<adot/)</pr>.</plu> <ety>[L. thigh.]</ety>
<fld>(Anat.)</fld> <sd>(a)</sd> <def>The thigh bone; -- it is the
longest and thickest bone of the human skeleton, which extends from the
pelvis to the knee.</def> <sd>(b)</sd> <def>The proximal segment of the
hind limb containing the thigh bone; the thigh. See
<er>Coxa</er>.</def><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><ent>Fen</ent><br/
<hw>Fen</hw> <pr>(f<ecr/n)</pr>, <pos>n.</pos> <ety>[AS. <ets>fen</ets>,
<ets>fenn</ets>, marsh, mud, dirt; akin to D. <ets>veen</ets>, OFries.
<ets>fenne</ets>, <ets>fene</ets>, OHG. <ets>fenna</ets>, G.
<ets>fenn</ets>, Icel. <ets>fen</ets>, Goth. <ets>fani</ets> mud.]</ety>
<def>Low land overflowed, or covered wholly or partially with water, but
producing sedge, coarse grasses, or other aquatic plants; boggy land;
moor; marsh.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>'Mid reedy <qex>fens</qex> wide spread.</q>
<rj><qau>Wordsworth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Fen</xex> is used adjectively with the sense of
<xex>belonging to</xex>, or <xex>of the nature of</xex>, <xex>a
fen</xex> or <xex>fens</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fen boat</b></col>, <cd>a boat of light draught used in
marshes.</cd> -- <col><b>Fen duck</b></col> <fld>(Zool.)</fld>, <cd>a
wild duck inhabiting fens; the shoveler.</cd> <mark>[Prov. Eng.]</mark>
-- <col><b>Fen fowl</b></col> <fld>(Zool.)</fld>, <cd>any water fowl
that frequent fens.</cd> -- <col><b>Fen goose</b></col>
<fld>(Zool.)</fld>, <cd>the graylag goose of Europe.</cd> <mark>[Prov.
Eng.]</mark> -- <col><b>Fen land</b></col>, <cd>swamp
land.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fence</ent><br/
<hw>Fence</hw> <pr>(f<ecr/ns)</pr>, <pos>n.</pos> <ety>[Abbrev. from
<ets>defence</ets>.]</ety> <sn>1.</sn> <def>That which fends off attack
or danger; a defense; a protection; a cover; security; shield.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Let us be backed with God and with the seas,<br/
Which he hath given for <qex>fence</qex> impregnable.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>fence</qex> betwixt us and the victor's wrath.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An inclosure about a field or other space, or about
any object; especially, an inclosing structure of wood, iron, or other
material, intended to prevent intrusion from without or straying from
within.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Leaps o'er the <qex>fence</qex> with ease into the fold.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In England a hedge, ditch, or wall, as well as a
structure of boards, palings, or rails, is called a
<xex>fence</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Locks)</fld> <def>A projection on the bolt, which
passes through the tumbler gates in locking and unlocking.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Self-defense by the use of the sword; the art and
practice of fencing and sword play; hence, skill in debate and repartee.
See <er>Fencing</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Enjoy your dear wit, and gay rhetoric,<br/
That hath so well been taught her dazzing <qex>fence</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Of dauntless courage and consummate skill in <qex>fence</qex>.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A receiver of stolen goods, or a place where they
are received.</def> <mark>[Slang]</mark> <rj><au>Mayhew.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fence month</b></col> <fld>(Forest Law)</fld>, <cd>the
month in which female deer are fawning, when hunting is prohibited.</cd>
<au>Bullokar.</au> -- <col><b>Fence roof</b></col>, <cd>a covering for
defense.</cd> <ldquo/They fitted their shields close to one another in
manner of a <xex>fence roof</xex>.<rdquo/ <au>Holland.</au> --
<col><b>Fence time</b></col>, <cd>the breeding time of fish or game,
when they should not be killed.</cd> -- <col><b>Rail fence</b></col>,
<cd>a fence made of rails, sometimes supported by posts.</cd> --
<col><b>Ring fence</b></col>, <cd>a fence which encircles a large area,
or a whole estate, within one inclosure.</cd> -- <col><b>Worm
fence</b></col>, <cd>a zigzag fence composed of rails crossing one
another at their ends; -- called also <altname>snake fence</altname>, or
<altname>Virginia rail fence</altname>.</cd> -- <col><b>To be on the
fence</b></col>, <cd>to be undecided or uncommitted in respect to two
opposing parties or policies.</cd> <mark>[Colloq.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 552 --></p>

<p><ent>Fence</ent><br/
<hw>Fence</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Fenced</conjf> <pr>(f<ecr/nst)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Fencing</conjf> <pr>(f<ecr/n"s<icr/ng)</pr>.]</vmorph>
<sn>1.</sn> <def>To fend off danger from; to give security to; to
protect; to guard.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>fence</qex> my ear against thy sorceries.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To inclose with a fence or other protection; to
secure by an inclosure.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>O thou wall! . . . dive in the earth,<br/
And <qex>fence</qex> not Athens.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A sheepcote <qex>fenced</qex> about with olive trees.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To fence the tables</b></col> <fld>(Scot. Church)</fld>,
<cd>to make a solemn address to those who present themselves to commune
at the Lord's supper, on the feelings appropriate to the service, in
order to hinder, so far as possible, those who are unworthy from
approaching the table.</cd> <au>McCheyne.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fence</ent><br/
<hw>Fence</hw> <pr>(?)</pr>, <pos>v. i.</pos> <sn>1.</sn> <def>To make a
defense; to guard one's self of anything, as against an attack; to give
protection or security, as by a fence.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Vice is the more stubborn as well as the more dangerous evil, and
therefore, in the first place, to be <qex>fenced</qex> against.</q>
<rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To practice the art of attack and defense with the
sword or with the foil, esp. with the smallsword, using the point
only.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He will <qex>fence</qex> with his own shadow.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Hence, to fight or dispute in the manner of fencers,
that is, by thrusting, guarding, parrying, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They <qex>fence</qex> and push, and, pushing, loudly roar;<br/
Their dewlaps and their sides are bathed in gore.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>As when a billow, blown against,<br/
Falls back, the voice with which I <qex>fenced</qex><br/
A little ceased, but recommenced.</q> <rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fenceful</ent><br/
<hw>Fence"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Affording defense;
defensive.</def> <mark>[Obs.]</mark> <rj><au>Congreve.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fenceless</ent><br/
<hw>Fence"less</hw>, <pos>a.</pos> <def>Without a fence; uninclosed;
open; unguarded; defenseless.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fencer</ent><br/
<hw>Fen"cer</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who fences; one
who teaches or practices the art of fencing with sword or
foil.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>As blunt as the <qex>fencer's</qex> foils.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fencible</ent><br/
<hw>Fen"ci*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of being
defended, or of making or affording defense.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>No fort so <qex>fencible</qex>, nor walls so strong.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fencible</ent><br/
<hw>Fen"ci*ble</hw>, <pos>n.</pos> <fld>(Mil.)</fld> <def>A soldier
enlisted for home service only; -- usually in the
<pluf>pl.</pluf></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fencing</ent><br/
<hw>Fen"cing</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The art
or practice of attack and defense with the sword, esp. with the
smallsword. See <er>Fence</er>, <pos>v. i.</pos>, 2.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Disputing or debating in a manner resembling the art
of fencers.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The materials used for building fences.</def>
<mark>[U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The act of building a fence.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>The aggregate of the fences put up for inclosure or
protection; <as>as, the <ex>fencing</ex> of a farm</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fen cricket</ent><br/
<hw>Fen" crick`et</hw> <pr>(?)</pr>. <fld>(Zool.)</fld> <def>The mole
cricket.</def> <mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fend</ent><br/
<hw>Fend</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A fiend.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fend</ent><br/
<hw>Fend</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Fended</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Fending</conjf>.]</vmorph> <ety>[Abbrev. fr.
<ets>defend</ets>.]</ety> <def>To keep off; to prevent from entering or
hitting; to ward off; to shut out; -- often with <xex>off</xex>; <as>as,
to <ex>fend</ex> off blows</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With fern beneath to <qex>fend</qex> the bitter cold.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>To fend off a boat</b></col> <it>or</it> <col><b>To
fend off a vessel</b></col></mcol> <fld>(Naut.)</fld>, <cd>to prevent
its running against anything with too much violence.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fend</ent><br/
<hw>Fend</hw>, <pos>v. i.</pos> <def>To act on the defensive, or in
opposition; to resist; to parry; to shift off.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The dexterous management of terms, and being able to
<qex>fend</qex> . . . with them, passes for a great part of
learning.</q> <rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fender</ent><br/
<hw>Fen"der</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From <er>Fend</er>,
<pos>v. t. & i.</pos>, cf. <er>Defender</er>.]</ety> <def>One who or
that which defends or protects by warding off harm</def>; as:
<sd>(a)</sd> <def>A screen to prevent coals or sparks of an open fire
from escaping to the floor.</def> <sd>(b)</sd> <def>Anything serving as
a cushion to lessen the shock when a vessel comes in contact with
another vessel or a wharf.</def> <sd>(c)</sd> <def>A screen to protect a
carriage from mud thrown off the wheels: also, a splashboard.</def>
<sd>(d)</sd> <def>Anything set up to protect an exposed angle, as of a
house, from damage by carriage wheels.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fendliche</ent><br/
<hw>Fend"liche</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Fiendlike.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fenerate</ent><br/
<hw>Fen"er*ate</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[L.
<ets>faeneratus</ets>, p. p. of <ets>faenerari</ets> lend on interest,
fr. <ets>faenus</ets> interest.]</ety> <def>To put money to usury; to
lend on interest.</def> <mark>[Obs.]</mark>
<rj><au>Cockeram.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feneration</ent><br/
<hw>Fen`er*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>faeneratio</ets>.]</ety> <def>The act of fenerating;
interest.</def> <mark>[Obs.]</mark> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fenes-tella</ent><br/
\'d8<hw>Fen`es-tel"la</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., dim. of
<ets>fenestra</ets> <?/ window.]</ety> <fld>(Arch.)</fld> <def>Any small
windowlike opening or recess, esp. one to show the relics within an
altar, or the like.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fenestra</ent><br/
\'d8<hw>Fe*nes"tra</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Fenestr<ae/</plw> <pr>(#)</pr>.</plu> <ety>[L., a window.]</ety>
<fld>(Anat.)</fld> <def>A small opening; esp., one of the apertures,
closed by membranes, between the tympanum and internal ear.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fenestral</ent><br/
<hw>Fe*nes"tral</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>fenestra</ets> a window.]</ety> <sn>1.</sn> <fld>(Arch.)</fld>
<def>Pertaining to a window or to windows.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Anat.)</fld> <def>Of or pertaining to a
fenestra.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fenestral</ent><br/
<hw>Fe*nes"tral</hw>, <pos>n.</pos> <fld>(Arch.)</fld> <def>A casement
or window sash, closed with cloth or paper instead of glass.</def>
<rj><au>Weale.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fenestrate</ent><br/
<hw>Fe*nes"trate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>fenestratus</ets>, p. p. of <ets>fenestrare</ets> to furnish with
openings and windows.]</ety> <sn>1.</sn> <def>Having numerous openings;
irregularly reticulated; <as>as, <ex>fenestrate</ex> membranes;
<ex>fenestrate</ex> fronds.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>Having transparent spots, as the
wings of certain butterflies.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fenestrated</ent><br/
<hw>Fe*nes"tra*ted</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<fld>(Arch.)</fld> <def>Having windows; characterized by
windows.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Same as <er>Fenestrate</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fenestration</ent><br/
<hw>Fen`es*tra"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<fld>(Arch.)</fld> <def>The arrangement and proportioning of windows; --
used by modern writers for the decorating of an architectural
composition by means of the window (and door) openings, their ornaments,
and proportions.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Anat.)</fld> <def>The state or condition of being
fenestrated.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fenestrule</ent><br/
<hw>Fe*nes"trule</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>fenestrula</ets> a little window, dim. of <ets>fenestra</ets> a
window.]</ety> <fld>(Zool.)</fld> <def>One of the openings in a
fenestrated structure.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feng-hwang</ent><br/
<hw>F<ecir/ng"-hwang`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Chin.
<ets>feng</ets> + <ets><lsquo/huang</ets>.]</ety> <fld>(Chinese
Myth.)</fld> <def>A pheasantlike bird of rich plumage and graceful form
and movement, fabled to appear in the land on the accession of a sage to
the throne, or when right principles are about to prevail. It is often
represented on porcelains and other works of art.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Fengite</ent><br/
<hw>Fen"gite</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Min.)</fld> <def>A
kind of marble or alabaster, sometimes used for windows on account of
its transparency.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feng-shui</ent><br/
<hw>F<ecir/ng"-shu`i</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Chin.
<ets>feng</ets> wind + <ets>shiu</ets> water.]</ety> <def>A system of
spirit influences for good and evil believed by the Chinese to attend
the natural features of landscape; also, a kind of geomancy dealing with
these influences, used in determining sites for graves, houses,
etc.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Fenian</ent><br/
<hw>Fe"ni*an</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From the
<ets>Finians</ets> or <ets>Fenii</ets>, the old militia of Ireland, who
were so called from <ets>Fin</ets> or <ets>Finn</ets>, <ets>Fionn</ets>,
or <ets>Fingal</ets>, a popular hero of Irish traditional
history.]</ety> <def>A member of a secret organization, consisting
mainly of Irishmen, having for its aim the overthrow of English rule in
Ireland.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fenian</ent><br/
<hw>Fe"ni*an</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to Fenians
or to Fenianism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fenianism</ent><br/
<hw>Fe"ni*an*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The principles,
purposes, and methods of the Fenians.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fenks</ent><br/
<hw>Fenks</hw> <pr>(f<ecr/<nsm/ks)</pr>, <pos>n.</pos> <def>The refuse
whale blubber, used as a manure, and in the manufacture of Prussian
blue.</def> <rj><au>Ure.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fennec</ent><br/
<hw>Fen"nec</hw> <pr>(f<ecr/n"n<ecr/k)</pr>, <pos>n.</pos> <ety>[Ar.
<ets>fanek</ets>.]</ety> <fld>(Zool.)</fld> <def>A small, African,
foxlike animal (<spn>Vulpes zerda</spn>) of a pale fawn color,
remarkable for the large size of its ears.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fennel</ent><br/
<hw>Fen"nel</hw> <pr>(f<ecr/n"n<ecr/l)</pr>, <pos>n.</pos> <ety>[AS.
<ets>fenol</ets>, <ets>finol</ets>, from L. <ets>feniculum</ets>,
<ets>faeniculum</ets>, dim. of <ets>fenum</ets>, <ets>faenum</ets>, hay:
cf. F. <ets>fenouil</ets>. Cf. <er>Fenugreek</er>.
<er>Finochio</er>.]</ety> <fld>(Bot.)</fld> <def>A perennial plant of
the genus <gen>F<ae/niculum</gen> (<spn>F<ae/niculum vulgare</spn>),
having very finely divided leaves. It is cultivated in gardens for the
agreeable aromatic flavor of its seeds.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Smell of sweetest <qex>fennel</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A sprig of <qex>fennel</qex> was in fact the theological smelling
bottle of the tender sex.</q> <rj><qau>S. G. Goodrich.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Azorean fennel</b></col>, <it>or</it> <col><b>Sweet
fennel</b></col></mcol>, <cd>(<spn>F<ae/niculum dulce</spn>). It is a
smaller and stouter plant than the common fennel, and is used as a pot
herb.</cd> -- <col><b>Dog's fennel</b></col> <cd>(<spn>Anthemis
Cotula</spn>), a foul-smelling European weed; -- called also
<altname>mayweed</altname>.</cd> -- <col><b>Fennel flower</b></col>
<fld>(Bot.)</fld>, <cd>an herb (<gen>Nigella</gen>) of the Buttercup
family, having leaves finely divided, like those of the fennel.
<spn>Nigella Damascena</spn> is common in gardens. <spn>Nigella
sativa</spn> furnishes the fennel seed, used as a condiment, etc., in
India. These seeds are the <ldquo/fitches<rdquo/ mentioned in Isaiah
(xxviii. 25).</cd> -- <col><b>Fennel water</b></col> <fld>(Med.)</fld>,
<cd>the distilled water of fennel seed. It is stimulant and
carminative.</cd> -- <col><b>Giant fennel</b></col> <cd>(<spn>Ferula
communis</spn>), has stems full of pith, which, it is said, were used to
carry fire, first, by Prometheus.</cd> -- <col><b>Hog's
fennel</b></col>, <cd>a European plant (<spn>Peucedanum
officinale</spn>) looking something like fennel.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fennish</ent><br/
<hw>Fen"nish</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Abounding in fens;
fenny.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fenny</ent><br/
<hw>Fen"ny</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[AS.
<ets>fennig</ets>.]</ety> <def>Pertaining to, or inhabiting, a fen;
abounding in fens; swampy; boggy.</def> <ldquo/<xex>Fenny</xex>
snake.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fenowed</ent><br/
<hw>Fen"owed</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[AS. <ets>fynig</ets>
musty, <ets>fynegean</ets> to become musty or filthy: cf.
<ets>fennig</ets> fenny, muddy, dirty, fr. <ets>fen</ets> fen. Cf.
<er>Finew</er>.]</ety> <def>Corrupted; decayed; moldy. See
<er>Vinnewed</er>.</def> <mark>[Obs.]</mark> <rj><au>Dr.
Favour.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fensi-ble</ent><br/
<hw>Fen"si-ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Fencible.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fen-sucked</ent><br/
<hw>Fen"-sucked`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Sucked out of
marches.</def> <ldquo/<xex>Fen-sucked</xex> fogs.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fenugreek</ent><br/
<hw>Fen"u*greek</hw> <pr>(? <or/ ?)</pr>, <pos>n.</pos> <ety>[L.
<ets>faenum Graecum</ets>, lit., Greek hay: cf. F. <ets>fenugrec</ets>.
Cf. <er>Fennel</er>.]</ety> <fld>(Bot.)</fld> <def>A plant
(<spn>trigonella F<oe/num Gr<ae/cum</spn>) cultivated for its
strong-smelling seeds, which are</def> <ldquo/now only used for giving
false importance to horse medicine and damaged hay.<rdquo/ <rj><au>J.
Smith (Pop. Names of Plants, 1881).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feod</ent><br/
<hw>Feod</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A feud. See 2d
<er>Feud</er>.</def> <rj><au>Blackstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feodal</ent><br/
<hw>Feod"al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Feudal. See
<er>Feudal</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feodality</ent><br/
<hw>Feo*dal"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Feudal tenure;
the feudal system. See <er>Feudality</er>.</def>
<rj><au>Burke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feodary</ent><br/
<hw>Feod"a*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>An
accomplice.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Art thou a <qex>feodary</qex> for this act?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Eng. Law)</fld> <def>An ancient officer of the
court of wards.</def> <rj><au>Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feodatory</ent><br/
<hw>Feod"a*to*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Feudatory</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feoff</ent><br/
<hw>Feoff</hw> <pr>(?; 277)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Feoffed</conjf> <pr>(#)</pr>; <pos>p. pr. & vb.
n.</pos>. <conjf>Feoffing</conjf>.]</vmorph> <ety>[OE.
<ets>feffen</ets>, OF. <ets>feffer</ets>, <ets>fieffer</ets>, F.
<ets>fieffer</ets>, fr. <ets>fief</ets> fief; cf. LL.
<ets>feoffare</ets>, <ets>fefare</ets>. See <er>Fief</er>.]</ety>
<fld>(Law)</fld> <def>To invest with a fee or feud; to give or grant a
corporeal hereditament to; to enfeoff.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feoff</ent><br/
<hw>Feoff</hw>, <pos>n.</pos> <fld>(Law)</fld> <def>A fief. See
<er>Fief</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feoffee</ent><br/
<hw>Feof*fee"</hw> <pr>(?; 277)</pr>, <pos>n.</pos> <ety>[OF.
<ets>feoff<eacute/</ets>.]</ety> <fld>(Law)</fld> <def>The person to
whom a feoffment is made; the person enfeoffed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feoffment</ent><br/
<hw>Feoff"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>feoffement</ets>, <ets>fieffement</ets>; cf. LL.
<ets>feoffamentum</ets>.]</ety> <fld>(Law)</fld> <sd>(a)</sd> <def>The
grant of a feud or fee.</def> <sd>(b)</sd> <fld>(Eng. Law)</fld> <def>A
gift or conveyance in fee of land or other corporeal hereditaments,
accompanied by actual delivery of possession.</def>
<rj><au>Burrill.</au></rj></p>

<p><sd>(c)</sd> <def>The instrument or deed by which corporeal
hereditaments are conveyed.</def> <mark>[Obs. in the U.S., Rare in
Eng.]</mark></p>

<p><ent>Feoffer</ent><br/
<ent>Feofor</ent><br/
<mhw>{ <hw>Feo"for</hw> <pr>(?)</pr>, <hw>Feof"fer</hw> <pr>(?)</pr>
}</mhw>, <pos>n.</pos> <ety>[OF. <ets>feoour</ets>.]</ety>
<fld>(Law)</fld> <def>One who enfeoffs or grants a fee.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fer</ent><br/
<hw>Fer</hw> <pr>(?)</pr>, <pos>a. & adv.</pos> <def>Far.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feracious</ent><br/
<hw>Fe*ra"cious</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>ferax</ets>, <ets>-acis</ets>, fr. <ets>ferre</ets> to bear.]</ety>
<def>Fruitful; producing abundantly.</def> <mark>[R.]</mark>
<rj><au>Thomson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feracity</ent><br/
<hw>Fe*rac"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>feracitas</ets>.]</ety> <def>The state of being feracious or
fruitful.</def> <mark>[Obs.]</mark> <rj><au>Beattie.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferae</ent><br/
\'d8<hw>Fe"r<ae/</hw> <pr>(?)</pr>, <pos>prop. n. pl.</pos> <ety>[L.,
wild animals, fem. pl. of <ets>ferus</ets> wild.]</ety>
<fld>(Zool.)</fld> <def>A group of mammals which formerly included the
Carnivora, Insectivora, Marsupialia, and lemurs, but is now often
restricted to the Carnivora.</def></p>

<p><ent>Fer<ae/ natur<ae/</ent><br/
<-- no pos in original = adj.? -->
\'d8<hw>Fe"r<ae/ na*tu"r<ae/</hw> <pr>(?)</pr>. <ety>[L.]</ety> <def>Of a wild nature; -- applied to animals, as foxes, wild ducks, etc., in which no one can claim property.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>feral</ent><br/
<hw>fe"ral</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>ferus</ets>. See <er>Fierce</er>.]</ety> <fld>(Bot. & Zool.)</fld> <def>Wild; untamed; ferine; not domesticated; -- said of beasts, birds, and plants.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>feral child</ent><br/
<hw>fe"ral child`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A child not raised in the company of humans;  a child raised by wild animals.   Romulus and Remus in Roman mythology were <ex>feral children</ex>.  Authenticated examples of children raised by beasts are rare or nonexistent, though there are stories of children being raised from infancy in isolation from adults, or in the presence of deaf and dumb adults, resulting in an inability to speak human language.</def><br/
[<source>PJC</source>]</p>

<p><ent>Feral</ent><br/
<hw>Fe"ral</hw>, <pos>a.</pos> <ety>[L. <ets>feralis</ets>, belonging to the dead.]</ety> <def>Funereal; deadly; fatal; dangerous.</def> <mark>[R.]</mark> <ldquo/<xex>Feral</xex> accidents.<rdquo/  <rj><au>Burton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferde</ent><br/
<hw>Ferde</hw> <pr>(?)</pr>, <mark>obs.</mark> <def><pos>imp.</pos> of <er>Fare</er>.</def>  <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fer-de-lance</ent><br/
\'d8<hw>Fer`-de-lance"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., the iron of a lance, lance head.]</ety> <fld>(Zool.)</fld> <def>A large, venomous serpent (<spn>Trigonocephalus lanceolatus</spn><-- now Bothrops atrox -->) of Brazil and the West Indies. It is allied to the rattlesnake, but has no rattle.</def>
<-- also in Central America. --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferding</ent><br/
<hw>Fer"ding</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See <er>Farthing</er>.]</ety> <def>A measure of land mentioned in Domesday Book. It is supposed to have consisted of a few acres only.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferdness</ent><br/
<hw>Ferd"ness</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>ferd</ets> fear. See <er>Fear</er>.]</ety> <def>Fearfulness.</def> <mark>[Obs.]</mark>  <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fere</ent><br/
<hw>Fere</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>fere</ets> companion, AS. <ets>gef<emac/ra</ets>, from <ets>f<emac/ran</ets> to go, travel, <ets>faran</ets> to travel. <root/78. See <er>Fare</er>.]</ety> <def>A mate or companion; -- often used of a wife.</def> <mark>[Obs.]</mark> <altsp>[Written also <asp>fear</asp> and <asp>feere</asp>.]</altsp>  <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And Cambel took Cambrina to his <qex>fere</qex>.</q> <rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>In fere</b></col>, <cd>together; in company.</cd> <mark>[Obs.]</mark>  <rj><au>Chaucer.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fere</ent><br/
<hw>Fere</hw>, <pos>a.</pos> <ety>[Cf. L. <ets>ferus</ets> wild.]</ety> <def>Fierce.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fere</ent><br/
<hw>Fere</hw>, <pos>n.</pos> <ety>[See <er>Fire</er>.]</ety> <def>Fire.</def> <mark>[Obs.]</mark>  <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fere</ent><br/
<hw>Fere</hw>, <pos>n.</pos> <ety>[See <er>Fear</er>.]</ety> <def>Fear.</def> <mark>[Obs.]</mark>  <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fere</ent><br/
<hw>Fere</hw>, <pos>v. t. & i.</pos> <def>To fear.</def> <mark>[Obs.]</mark>  <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feretory</ent><br/
<hw>Fer`e*to*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>feretrum</ets> bier, Gr. <?/, fr. <grk>fe`rein</grk> to bear, akin to L. <ets>ferre</ets>, E. <ets>bear</ets> to support.]</ety> <def>A portable bier or shrine, variously adorned, used for containing relics of saints.</def>  <rj><au>Mollett.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferforth</ent><br/
<hw>Fer"forth`</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>Far forth.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>As ferforth as</b></col>, <cd>as far as.</cd> -- <col><b>So ferforth</b></col>, <cd>to such a degree.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferforthly</ent><br/
<hw>Fer"forth`ly</hw>, <pos>adv.</pos> <def>Ferforth.</def> <mark>[Obs.]</mark>  <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fergusonite</ent><br/
<hw>Fer"gu*son*ite</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Min.)</fld> <def>A mineral of a brownish black color, essentially a tantalo-niobate of yttrium, erbium, and cerium; -- so called after Robert <ets>Ferguson</ets>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feria</ent><br/
\'d8<hw>Fe"ri*a</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it> <plw>Feri<ae/</plw> <pr>(<?/)</pr>.</plu> <fld>(Eccl.)</fld> <def>A week day, esp. a day which is neither a festival nor a fast.</def>  <rj><au>Shipley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferial</ent><br/
<hw>Fe"ri*al</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as <er>Feria</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferial</ent><br/
<hw>Fe"ri*al</hw>, <pos>a.</pos> <ety>[LL. <ets>ferialis</ets>, fr. L. <ets>ferie</ets> holidays: cf. F. <ets>f<eacute/rial</ets>. See 5th <er>Fair</er>.]</ety> <sn>1.</sn> <def>Of or pertaining to holidays.</def> <mark>[Obs.]</mark>  <rj><au>J. Gregory.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Belonging to any week day, esp. to a day that is neither a festival nor a fast.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feriation</ent><br/
<hw>Fe`ri*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>feriari</ets> to keep holiday, fr. <ets>ferie</ets> holidays.]</ety> <def>The act of keeping holiday; cessation from work.</def> <mark>[Obs.]</mark>  <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferie</ent><br/
<hw>Fe"rie</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF. <ets>ferie</ets>, fr. L. <ets>ferie</ets> holidays. See 5th <er>Fair</er>.]</ety> <def>A holiday.</def> <mark>[Obs.]</mark>  <rj><au>Bullokar.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferier</ent><br/
<hw>Fe"ri*er</hw> <pr>(?)</pr>, <pos>a.</pos>, <def><pos>compar.</pos> of <er>Fere</er>, fierce.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Rhenus <qex>ferier</qex> than the cataract.</q> <rj><qau>Marston.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferine</ent><br/
<hw>Fe"rine</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>ferinus</ets>, fr. <ets>ferus</ets> wild. See <er>Fierce</er>.]</ety> <def>Wild; untamed; savage; <as>as, lions, tigers, wolves, and bears are <ex>ferine</ex> beasts</as>.</def>  <rj><au>Sir M. Hale.</au></rj> -- <def2><pos>n.</pos> <def>A wild beast; a beast of prey.</def></def2> -- <wordforms><wf>Fe"rine*ly</wf>, <pos>adv.</pos> -- <wf>Fe"rine*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feringee</ent><br/
\'d8<hw>Fer*in"gee</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Per. <ets>Farang<imac/</ets>, or Ar. <ets>Firanj<imac/</ets>, properly, a Frank.]</ety> <def>The name given to Europeans by the Hindus.</def> <altsp>[Written also <asp>Feringhee</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferity</ent><br/
<hw>Fer"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>feritas</ets>, from <ets>ferus</ets> wild.]</ety> <def>Wildness; savageness; fierceness.</def> <mark>[Obs.]</mark>  <rj><au>Woodward.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferly</ent><br/
<hw>Fer"ly</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[AS. <ets>f<?/rlic</ets> sudden, unexpected. See <er>Fear</er>, <pos>n.</pos>]</ety> <def>Singular; wonderful; extraordinary.</def> <mark>[Obs.]</mark> -- <def2><pos>n.</pos> <def>A wonder; a marvel.</def></def2> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Who hearkened ever such a <qex>ferly</qex> thing.</q> <rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferme</ent><br/
<ent>Ferm</ent><br/
<mhw>{ <hw>Ferm</hw>, <hw>Ferme</hw> <pr>(?)</pr>, <pos>n.</pos> }</mhw><ety>[See <er>Farm</er>.]</ety> <def>Rent for a farm; a farm; also, an abode; a place of residence; <as>as, he let his land to <ex>ferm</ex></as>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Out of her fleshy <qex>ferme</qex> fled to the place of pain.</q> <rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fermacy</ent><br/
<hw>Fer"ma*cy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. See <er>Pharmacy</er>.]</ety> <def>Medicine; pharmacy.</def> <mark>[Obs.]</mark>  <rj><au>Chaucer.</au></rj></p>

<p><ent>Ferment</ent><br/
<hw>Fer"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>fermentum</ets> ferment (in senses 1 & 2), perh. for <ets>fervimentum</ets>, fr. <ets>fervere</ets> to be boiling hot, boil, ferment: cf. F. <ets>ferment</ets>.  Cf. 1st <er>Barm</er>, <er>Fervent</er>.]</ety> <sn>1.</sn> <def>That which causes fermentation, as yeast, barm, or fermenting beer.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Ferments are of two kinds: (<stype>a</stype>) Formed or organized ferments. (<stype>b</stype>) Unorganized or structureless ferments. The latter are now called <stype>enzymes</stype> and were formerly called <stype>soluble ferments</stype> or <stype>chemical ferments</stype>. Ferments of the first class are as a rule simple microscopic vegetable organisms, and the fermentations which they engender are due to their growth and development; as, the <stype>acetic ferment</stype>, the <stype>butyric ferment</stype>, etc. See <er>Fermentation</er>. Ferments of the second class, on the other hand, are chemical substances; as a rule they are proteins soluble in glycerin and precipitated by alcohol. In action they are catalytic and, mainly, hydrolytic. Good examples are pepsin of the dastric juice, ptyalin of the salvia, and disease of malt.  Before 1960 the term "ferment" to mean "enzyme" fell out of use.  Enzymes are now known to be <er>globular protein</er>s, capable of catalyzing a wide variety of chemical reactions, not merely hydrolytic.  The full set of enzymes causing production of ethyl alcohol from sugar has been identified and individually purified and studied.  See <er>enzyme</er>.</note><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>Intestine motion; heat; tumult; agitation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Subdue and cool the <qex>ferment</qex> of desire.</q> <rj><qau>Rogers.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>the nation is in a <qex>ferment</qex>.</q> <rj><qau>Walpole.</qau></rj>
<-- <col><b>in a ferment</b></col> <cd>in a state of agitation, applied to human groups.</cd> --><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A gentle internal motion of the constituent parts of
a fluid; fermentation.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Down to the lowest lees the <qex>ferment</qex> ran.</q>
<rj><qau>Thomson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>ferment oils</b></col>, <cd>volatile oils produced by the
fermentation of plants, and not originally contained in them. These were
the <xex>quintessences</xex> of the alchemists.</cd>
<rj><au>Ure.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferment</ent><br/
<hw>Fer*ment"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Fermented</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Fermenting</conjf>.]</vmorph> <ety>[L. <ets>fermentare</ets>,
<ets>fermentatum</ets>: cf. F. <ets>fermenter</ets>. See
<er>Ferment</er>, <pos>n.</pos>]</ety> <def>To cause ferment or
fermentation in; to set in motion; to excite internal emotion in; to
heat.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Ye vigorous swains! while youth <qex>ferments</qex> your
blood.</q> <rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferment</ent><br/
<hw>Fer*ment"</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To undergo
fermentation; to be in motion, or to be excited into sensible internal
motion, as the constituent particles of an animal or vegetable fluid; to
work; to effervesce.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To be agitated or excited by violent
emotions.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>But finding no redress, <qex>ferment</qex> and rage.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The intellect of the age was a <qex>fermenting</qex>
intellect.</q> <rj><qau>De Quincey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fermentability</ent><br/
<hw>Fer*ment`a*bil"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Capability
of fermentation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fermentable</ent><br/
<hw>Fer*ment"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>fermentable</ets>.]</ety> <def>Capable of fermentation; <as>as,
cider and other vegetable liquors are
<ex>fermentable</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fermental</ent><br/
<hw>Fer*ment"al</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Fermentative.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 553 --></p>

<p><ent>Fermentation</ent><br/
<hw>Fer`men*ta"tion</hw> <pr>(f<etil/r`m<ecr/n*t<amac/"sh<ucr/n)</pr>,
<pos>n.</pos> <ety>[Cf. F. <ets>fermentation</ets>.]</ety> <sn>1.</sn>
<def>The process of undergoing an effervescent change, as by the action
of yeast;</def> <specif>in a wider sense</specif> <fld>(Physiol.
Chem.)</fld>, <def>the transformation of an organic substance into new
compounds by the action of a <er>ferment{1}</er>, whether in the form of
living organisms or enzymes. It differs in kind according to the nature
of the ferment which causes it.</def> <note>In industrial microbiology
<ex>fermentation</ex> usually refers to the production of chemical
substances by use of microorganisms.</note><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>A state of agitation or excitement, as of the
intellect or the feelings.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It puts the soul to <qex>fermentation</qex> and activity.</q>
<rj><qau>Jer. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A univesal <qex>fermentation</qex> of human thought and faith.</q>
<rj><qau>C. Kingsley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<cs><p><mcol><col><b>Acetous fermentation</b></col> <it>or</it>
<col><b>Acetic fermentation</b></col></mcol>, <cd>a form of oxidation in
which alcohol is converted into vinegar or acetic acid by the agency of
a specific fungus (<spn>Mycoderma aceti</spn>) or series of enzymes. The
process involves two distinct reactions, in which the oxygen of the air
is essential. An intermediate product, acetaldehyde, is formed in the
first process.</cd></p>

<p><bold>1.</bold> <chreact>C2H6O + O <rarr/ H2O + C2H4O</chreact>
<note> Alcohol. Water. Acetaldehyde.</note></p>

<p><bold>2.</bold> <chreact>C2H4O + O <rarr/ C2H4O2</chreact> <note>
Acetaldehyde. Acetic acid.</note></p>

<p>-- <col><b>Alcoholic fermentation</b></col>, <cd>the fermentation
which saccharine bodies undergo when brought in contact with the yeast
plant or Torula. The sugar is converted, either directly or indirectly,
into alcohol and carbonic acid, the rate of action being dependent on
the rapidity with which the Torul<ae/ develop.</cd> --
<col><b>Ammoniacal fermentation</b></col>, <cd>the conversion of the
urea of the urine into ammonium carbonate, through the growth of the
special urea ferment.</cd></p>

<p><chreact>CON2H4 + 2H2O = (NH4)2CO3</chreact> <note> Urea. Water.
Ammonium carbonate.</note><br/
[<source>1913 Webster</source>]</p>

<p><note>Whenever urine is exposed to the air in open vessels for
several days it undergoes this alkaline fermentation.</note> --
<col><b>Butyric fermentation</b></col>, <cd>the decomposition of various
forms of organic matter, through the agency of a peculiar worm-shaped
vibrio, with formation of more or less butyric acid. It is one of the
many forms of fermentation that collectively constitute putrefaction.
See <cref>Lactic fermentation</cref>.</cd> -- <mcol><col><b>enzymatic
fermentation</b></col> <it>or</it> <col><b>Fermentation by an
unorganized ferment</b></col></mcol>. <cd>Fermentations of this class
are purely chemical reactions, in which the enzyme acts as a simple
catalytic agent. Of this nature are the decomposition or inversion of
cane sugar into levulose and dextrose by boiling with dilute acids, the
conversion of starch into dextrin and sugar by similar treatment, the
conversion of starch into like products by the action of diastase of
malt or ptyalin of saliva, the conversion of albuminous food into
peptones and other like products by the action of pepsin-hydrochloric
acid of the gastric juice or by the ferment of the pancreatic
juice.</cd> -- <col><b>Fermentation theory of disease</b></col>
<fld>(Biol. & Med.)</fld>, <cd>the theory that most if not all,
infectious or zymotic disease are caused by the introduction into the
organism of the living germs of ferments, or ferments already developed
(organized ferments), by which processes of fermentation are set up
injurious to health. See <er>Germ theory</er>.</cd> -- <col><b>Glycerin
fermentation</b></col>, <cd>the fermentation which occurs on mixing a
dilute solution of glycerin with a peculiar species of schizomycetes and
some carbonate of lime, and other matter favorable to the growth of the
plant, the glycerin being changed into butyric acid, caproic acid,
butyl, and ethyl alcohol. With another form of bacterium (<spn>Bacillus
subtilis</spn>) ethyl alcohol and butyric acid are mainly formed.</cd>
-- <col><b>Lactic fermentation</b></col>, <cd>the transformation of milk
sugar or other saccharine body into lactic acid, as in the souring of
milk, through the agency of a special bacterium (<spn>Bacterium
lactis</spn> of Lister). In this change the milk sugar, before assuming
the form of lactic acid, presumably passes through the stage of
glucose.</cd></p>

<p><chreact>C12H22O11.H2O --> 4C3H6O3</chreact> <note> Hydrated milk
sugar. Lactic acid.</note><br/
[<source>1913 Webster</source>]</p>

<p><note>In the lactic fermentation of dextrose or glucose, the lactic
acid which is formed is very prone to undergo butyric fermentation after
the manner indicated in the following equation: <chreact>2C3H6O3 (lactic
acid) --> C4H8O2 (butyric acid) + 2CO2 (carbonic acid) + 2H2 (hydrogen
gas).</chreact></note> -- <col><b>Putrefactive fermentation</b></col>.
<cd>See <er>Putrefaction</er>.</cd><br/
[<source>1913 Webster</source>]</p></cs>

<p><ent>Fermentation tank</ent><br/
<hw>Fer`men*ta"tion tank</hw>. <def>a tank in which fermentations are
carried out.</def><br/
[<source>PJC</source>]</p>

<p><ent>Fermentative</ent><br/
<hw>Fer*ment"a*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>fermentatif</ets>.]</ety> <def>Causing, or having power to cause,
fermentation; produced by fermentation; fermenting; <as>as, a
<ex>fermentative</ex> process</as>.</def></p>

<p>-- <wordforms><wf>Fer*ment"a*tive*ly</wf>, <pos>adv.</pos> --
<wf>Fer*ment"a*tive*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fermenter</ent><br/
<hw>Fer*ment"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>an apparatus for
carrying out <er>fermentation</er> by a liquid suspension of
microorganisms; a fermentation tank; <as>as, an industrial
<ex>fermenter</ex></as>.</def> <note>Laboratiory and industrial
<ex>fermenters</ex> are usually equipped with a means of stirring the
contained liquid so as to avoid settling of the fermenting organisms,
and often have other, sometimes elaborate, mechanisms to control
conditions of the fermentation, such as temperature, degree of aeration,
or pH. The main structures of large industrial fermenters are typically
made of steel.</note><br/
[<source>PJC</source>]</p>

<p><ent>Fermerere</ent><br/
<hw>Fer"mer*ere</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>enfermerier</ets>, fr. <ets>enfermerie</ets> infirmary. See
<er>Infirmary</er>.]</ety> <def>The officer in a religious house who had
the care of the infirmary.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fermeture</ent><br/
<hw>Fer"me*ture</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr.
<ets>fermer</ets> to close.]</ety> <fld>(Mil.)</fld> <def>The mechanism
for closing the breech of a breech-loading firearm, in artillery
consisting principally of the breechblock, obturator, and carrier
ring.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Fermillet</ent><br/
<hw>Fer"mil*let</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF., dim. of
<ets>fermeil</ets>, <ets>fermail</ets>, clasp, prob. fr. OF. & F.
<ets>fermer</ets> to make fast, fr. <ets>ferme</ets> fast. See
<er>Firm</er>.]</ety> <def>A buckle or clasp.</def> <mark>[Obs.]</mark>
<rj><au>Donne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>fermion</ent><br/
<hw>fermion</hw> <pos>n.</pos> <def>any particle that obeys Fermi-Dirac
statistcs and is subject to the Pauli exclusion principle.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>fermium</ent><br/
<hw>fermium</hw> <pos>n.</pos> <def>the transuranic element of atomic
number 100; symbol Fm. The atomic weight of the most stable isotope,
having a half-life of about 80 days, is 257. The first isotope,
Fm<sup>255</sup> was discovered in 1952 in the debris of a thermonuclear
explosion. Other istopes have been produced in nuclear reactors and by
decay of other transuranic elements.</def> <au>Handb. Ch. Phys.
61.</au><br/
<syn><b>Syn. --</b> Fm.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fern</ent><br/
<hw>Fern</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>Long ago.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fern</ent><br/
<hw>Fern</hw>, <pos>a.</pos> <ety>[AS. <ets>fyrn</ets>.]</ety>
<def>Ancient; old. <mark>[Obs.]</mark> <ldquo/Pilgrimages to . . .
<xex>ferne</xex> halwes.<rdquo/ [saints].</def>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fern</ent><br/
<hw>Fern</hw> <pr>(f<etil/rn)</pr>, <pos>n.</pos> <ety>[AS.
<ets>fearn</ets>; akin to D. <ets>varen</ets>, G. <ets>farn</ets>,
<ets>farn</ets>kraut; cf. Skr. <ets>par<nsdot/a</ets> wing, feather,
leaf, sort of plant, or Lith. <ets>papartis</ets> fern.]</ety>
<fld>(Bot.)</fld> <def>An order of cryptogamous plants, the
<ord>Filices</ord>, which have their fructification on the back of the
fronds or leaves. They are usually found in humid soil, sometimes grow
epiphytically on trees, and in tropical climates often attain a gigantic
size.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The plants are asexual, and bear clustered sporangia,
containing minute spores, which germinate and form prothalli, on which
are borne the true organs of reproduction. The brake or bracken, the
maidenhair, and the polypody are all well known ferns.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Christmas fern</b></col>. <cd>See under
<er>Christmas</er>.</cd> -- <col><b>Climbing fern</b></col>
<fld>(Bot.)</fld>, <cd>a delicate North American fern (<spn>Lygodium
palmatum</spn>), which climbs several feet high over bushes, etc., and
is much sought for purposes of decoration.</cd> -- <mcol><col><b>Fern
owl</b></col>. <fld>(Zool.)</fld> <sd>(a)</sd> <cd>The European
goatsucker.</cd> <sd>(b)</sd> <cd>The short-eared owl.</cd> <mark>[Prov.
Eng.]</mark> -- <col><b>Fern shaw</b></col></mcol>, <cd>a fern
thicket.</cd> <mark>[Eng.]</mark> <au>R. Browning.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>ferned</ent><br/
<hw>ferned</hw> <pos>adj.</pos> <def>abounding in or covered with
ferns.</def> [Narrower terms: <stype>braky </stype>]
<ant>fernless</ant><br/
<syn><b>Syn. --</b> ferny.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Fernery</ent><br/
<hw>Fern"er*y</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A place for rearing
ferns.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>fernless</ent><br/
<hw>fernless</hw> <pos>adj.</pos> <def>devoid of ferns. Opposite of
<ant>ferned</ant>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>fernlike</ent><br/
<hw>fernlike</hw> <pos>adj.</pos> <def>resembling ferns especially in
leaf shape; <as>as, the <ex>fernlike</ex> shadows of locust
leaves</as>.</def><br/
<syn><b>Syn. --</b> ferny.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Fernticle</ent><br/
<hw>Fern"ti*cle</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A freckle on the
skin, resembling the seed of fern.</def> <mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferny</ent><br/
<hw>Fern"y</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Abounding
in ferns.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>resembling a fern; fernlike.</def><br/
[<source>PJC</source>]</p>

<p><ent>Ferocactus</ent><br/
<hw>Ferocactus</hw> <pos>n.</pos> <def>a genus of nearly globular cacti
of Mexico and Southwestern U. S., including some of the barrel
cacti.</def><br/
<syn><b>Syn. --</b> genus <gen>Ferocactus</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Ferocious</ent><br/
<hw>Fe*ro"cious</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>ferox</ets>, <ets>-ocis</ets>, fierce: cf. F.
<ets>f<eacute/roce</ets>. See <er>Ferocity</er>.]</ety> <def>Fierce;
savage; wild; indicating cruelty; ravenous; rapacious; <as>as,
<ex>ferocious</ex> look or features; a <ex>ferocious</ex>
lion.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>The humbled power of a <qex>ferocious</qex> enemy.</q>
<rj><qau>Lowth.</qau></rj></p>

<p><syn><b>Syn.</b> -- <er>Ferocious</er>, <er>Fierce</er>,
<er>Savage</er>, <er>Barbarous</er>.</syn> <usage>When these words are
applied to human feelings or conduct, <xex>ferocious</xex> describes the
disposition; <xex>fierce</xex>, the haste and violence of an act;
<xex>barbarous</xex>, the coarseness and brutality by which it was
marked; <xex>savage</xex>, the cruel and unfeeling spirit which it
showed. A man is <xex>ferocious</xex> in his temper, <xex>fierce</xex>
in his actions, <xex>barbarous</xex> in the manner of carrying out his
purposes, <xex>savage</xex> in the spirit and feelings expressed in his
words or deeds.</usage></p>

<p>-- <wordforms><wf>Fe*ro"cious*ly</wf>, <pos>adv.</pos> --
<wf>Fe*ro"cious*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>ferociousness</ent><br/
<hw>ferociousness</hw> <pos>n.</pos> <def>the trait of extreme
cruelty.</def><br/
<syn><b>Syn. --</b> brutality, viciousness, savageness,
savagery.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><q>It [Christianity] has adapted the <qex>ferociousness</qex> of
war.</q> <rj><qau>Blair.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferocity</ent><br/
<hw>Fe*roc"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>ferocitas</ets>, fr. <ets>ferox</ets>, <ets>-ocis</ets>, fierce,
kin to <ets>ferus</ets> wild: cf. F. <ets>ferocit<eacute/</ets>. See
<er>Fierce</er>.]</ety> <def>Savage wildness or fierceness; fury;
cruelty; <as>as, <ex>ferocity</ex> of countenance</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The pride and <qex>ferocity</qex> of a Highland chief.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feroher</ent><br/
\'d8<hw>Fer*o"her</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Arch<ae/ol.)</fld> <def>A symbol of the solar deity, found on
monuments exhumed in Babylon, Nineveh, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferous</ent><br/
<hw>Fe"rous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>ferus</ets>.
See <er>Fierce</er>.]</ety> <def>Wild; savage.</def> <mark>[R.]</mark>
<rj><au>Arthur Wilson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>-ferous</ent><br/
<hw>-fer*ous</hw> <pr>(?)</pr>. <ety>[L. <ets>-fer</ets>. fr. ferre to
bear. See <er>Bear</er> to support.]</ety> <def>A suffix signifying
<sig>bearing</sig>, <sig>producing</sig>, <sig>yielding</sig>; <as>as,
auri<ex>ferous</ex>, yielding gold; chyli<ex>ferous</ex>, producing
chyle.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferrandine</ent><br/
<hw>Fer*ran"dine</hw> <pr>(? <or/ ?)</pr>, <pos>n.</pos> <ety>[F.; cf.
OF. <ets>ferrant</ets> iron-gray, from L. <ets>ferrum</ets> iron.]</ety>
<def>A stuff made of silk and wool.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I did buy a colored silk <qex>ferrandine</qex>.</q>
<rj><qau>Pepys.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferranti mains</ent><br/
<ent>Ferranti cables</ent><br/
<mhw>{ <hw>Fer*ran"ti ca"bles</hw> <pr>(?)</pr>, <hw>Fer*ran"ti
mains"</hw> <pr>(?)</pr> }</mhw>. <fld>(Elec.)</fld> <def>A form of
conductor, designed by <etsep>Ferranti</etsep>, for currents of high
potential, and consisting of concentric tubes of copper separated by an
insulating material composed of paper saturated with black mineral
wax.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Ferranti phenomenon</ent><br/
<hw>Fer*ran"ti phe*nom"e*non</hw>. <fld>(Elec.)</fld> <def>An increase
in the ratio of transformation of an alternating current converter,
accompanied by other changes in electrical conditions, occurring when
the secondary of the converter is connected with a condenser of moderate
capacity; -- so called because first observed in connection with the
Ferranti cables in London.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Ferrara</ent><br/
<hw>Fer*ra"ra</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A sword bearing the
mark of one of the Ferrara family of Italy. These swords were highly
esteemed in England and Scotland in the 16th and 17th
centuries.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferrarese</ent><br/
<hw>Fer`ra*rese"</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to
Ferrara, in Italy.</def> -- <def2><pos>n., sing. & pl.</pos> <def>A
citizen of Ferrara; collectively, the inhabitants of
Ferrara.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferraro</ent><br/
<hw>Fer*ra"ro</hw> <pr>(?)</pr>, <pos>prop. n.</pos>
<def><person>Geraldine Anne Ferraro</person>, a United States
politician. Born in 1935, she was a congresswoman from New York in the
United States Congress from 1978 to 1984, and ran unsuccessfully in 1984
a candidate for Vice President of the United States, with <person>Walter
Mondale</person> as the Presidential candidate. She was the first woman
to be nominated by a major U. S. political party for the office of Vice
President.</def><br/
[<source>PJC</source>]</p>

<p><ent>Ferrary</ent><br/
<hw>Fer"ra*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>ferraria</ets> iron works. See <er>Ferreous</er>.]</ety> <def>The
art of working in iron.</def> <mark>[Obs.]</mark>
<rj><au>Chapman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferrate</ent><br/
<hw>Fer"rate</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>ferrum</ets>
iron.]</ety> <fld>(Chem.)</fld> <def>A salt of ferric acid.</def></p>

<p><ent>Ferrer</ent><br/
<ent>Ferre</ent><br/
<mhw>{ <hw>Fer"re</hw> <pr>(?)</pr>, <hw>Fer"rer</hw> <pr>(?)</pr>,
<pos>a. & adv.</pos> }</mhw> <mark>Obs.</mark> <def><pos>compar.</pos>
of <er>Fer</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferreous</ent><br/
<hw>Fer"re*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>ferreus</ets>, fr. <ets>ferrum</ets> iron. Cf. <er>Farrier</er>,
<er>Ferrous</er>.]</ety> <def>Partaking of, made of, or pertaining to,
iron; like iron.</def> <mark>[Obs.]</mark> <rj><au>Sir T.
Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferrest</ent><br/
<hw>Fer"rest</hw> <pr>(?)</pr>, <pos>a. & adv.</pos> <mark>Obs.</mark>
<def><pos>superl.</pos> of <er>Fer</er>.</def>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferret</ent><br/
<hw>Fer"ret</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>furet</ets>,
cf. LL. <ets>furo</ets>; prob. fr. L. <ets>fur</ets> thief (cf.
<er>Furtive</er>); cf. Arm. <ets>fur</ets> wise, sly.]</ety>
<fld>(Zool.)</fld> <def>An animal of the Weasel family (<spn>Mustela
furo</spn> syn. <spn>Putorius furo</spn>), about fourteen inches in
length, of a pale yellow or white color, with red eyes. It is a native
of Africa, but has been domesticated in Europe. Ferrets are used to
drive rabbits and rats out of their holes. They are sometimes kept as
pets.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Ferret</ent><br/
<hw>Fer"ret</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Ferreted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Ferreting</conjf>.]</vmorph> <ety>[Cf. F. <ets>fureter</ets>. See
<er>Ferret</er>, <pos>n.</pos>]</ety> <def>To drive or hunt out of a
lurking place, as a ferret does the cony; to search out by patient and
sagacious efforts; -- often used with <ptcl>out</ptcl>; <as>as, to
<ex>ferret</ex> out a secret</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Master Fer! I'll fer him, and firk him, and <qex>ferret</qex>
him.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferret</ent><br/
<hw>Fer"ret</hw>, <pos>n.</pos> <ety>[Ital. <ets>foretto</ets>, dim. of
<ets>fiore</ets> flower; or F. <ets>fleuret</ets>. Cf.
<er>Floret</er>.]</ety> <def>A kind of narrow tape, usually made of
woolen; sometimes of cotton or silk; -- called also
<altname>ferreting</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferret</ent><br/
<hw>Fer"ret</hw>, <pos>n.</pos> <ety>[F. <ets>feret</ets>, dim. or
<ets>fer</ets> iron, L. <ets>ferrum</ets>.]</ety> <fld>(Glass
Making)</fld> <def>The iron used for trying the melted glass to see if
is fit to work, and for shaping the rings at the mouths of
bottles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferreter</ent><br/
<hw>Fer"ret*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
ferrets.</def> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferret-eye</ent><br/
<hw>Fer"ret-eye`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>The spur-winged goose; -- so called from the red circle around the
eyes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferretto</ent><br/
<hw>Fer*ret"to</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[It.
<ets>ferretto</ets> di Spagna, dim. of <ets>ferro</ets> iron, fr. L.
<ets>ferrum</ets>.]</ety> <def>Copper sulphide, used to color
glass.</def> <rj><au>Hebert.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferri-</ent><br/
<hw>Fer"ri-</hw> <pr>(<?/)</pr>. <fld>(Chem.)</fld> <def>A combining
form indicating <sig>ferric iron</sig> as an ingredient; <as>as,
<ex>ferri</ex>cyanide</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferriage</ent><br/
<hw>Fer"ri*age</hw> <pr>(?; 48)</pr>, <pos>n.</pos> <ety>[From
<er>Ferry</er>.]</ety> <def>The price or fare to be paid for passage at
a ferry.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferric</ent><br/
<hw>Fer"ric</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>ferrum</ets>
iron: cf. F. <ets>ferrique</ets>. See <er>Ferrous</er>.]</ety>
<def>Pertaining to, derived from, or containing iron. Specifically
<fld>(Chem.)</fld>, denoting those compounds in which iron has a higher
valence than in the <xex>ferrous</xex> compounds; <as>as,
<ex>ferric</ex> oxide; <ex>ferric</ex> acid.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Ferric acid</b></col> <fld>(Chem.)</fld>, <cd>an acid,
<chform>H2FeO4</chform>, which is not known in the free state, but forms
definite salts, analogous to the chromates and sulphates.</cd> --
<col><b>Ferric oxide</b></col> <fld>(Chem.)</fld>, <cd>sesquioxide of
iron, <chform>Fe2O3</chform>; hematite. See
<er>Hematite</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferricyanate</ent><br/
<hw>Fer`ri*cy"a*nate</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Ferri-</ets> + <ets>cyanate</ets>.]</ety> <fld>(Chem.)</fld>
<def>A salt of ferricyanic acid; a ferricyanide.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferricyanic</ent><br/
<hw>Fer`ri*cy*an"ic</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Ferri-</ets> + <ets>cyanic</ets>.]</ety> <fld>(Chem.)</fld>
<def>Pertaining to, or derived from, a ferricyanide.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Ferricyanic acid</b></col> <fld>(Chem.)</fld>, <cd>a
brown crystalline substance, <chform>H6(CN)12Fe2</chform>, obtained from
potassium ferricyanide, and regarded as the type of the ferricyanides;
-- called also <altname>hydro-ferricyanic acid</altname>,
<altname>hydrogen ferricyanide</altname>, etc.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferricyanide</ent><br/
<hw>Fer`ri*cy"a*nide</hw> <pr>(?; 104)</pr>, <pos>n.</pos>
<ety>[<ets>Ferri-</ets> + <ets>cyanide</ets>.]</ety> <fld>(Chem.)</fld>
<def>One of a complex series of double cyanides of ferric iron and some
other base.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Potassium ferricyanide</b></col> <fld>(Chem.)</fld>,
<cd>red prussiate of potash; a dark, red, crystalline salt,
<chform>K6(CN)12Fe2</chform>, consisting of the double cyanide of
potassium and ferric iron. From it is derived the ferrous ferricyanate,
<xex>Turnbull's blue</xex>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferrier</ent><br/
<hw>Fer"ri*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A ferryman.</def>
<rj><au>Calthrop.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferriferous</ent><br/
<hw>Fer*rif"er*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>ferrum</ets> iron + <ets>-ferous</ets>: cf. F.
<ets>ferrif<egrave/re</ets>.]</ety> <def>Producing or yielding
iron.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferriprussiate</ent><br/
<hw>Fer`ri*prus"si*ate</hw> <pr>(? <or/ ?; see <er>Prussiate</er>,
277)</pr>, <pos>n.</pos> <ety>[<ets>Ferri-</ets> +
<ets>prussiate</ets>.]</ety> <fld>(Chem.)</fld> <def>A ferricyanate; a
ferricyanide.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferriprussic</ent><br/
<hw>Fer`ri*prus"sic</hw> <pr>(? <or/ ?; see <er>Prussik</er>, 277)</pr>,
<pos>a.</pos> <ety>[<ets>Ferri-</ets> + <ets>prussic</ets>.]</ety>
<fld>(Chem.)</fld> <def>Ferricyanic.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferris wheel</ent><br/
<hw>Fer"ris wheel</hw> <pr>(?)</pr>. <def>An amusement device consisting
of a giant power-driven vertically oriented steel wheel, revolvable on
its horizontal stationary axle, and carrying a number of balanced
passenger cars or open seats around its rim; the seats are suspended so
as to remain horizontal as the wheel rotates, and, depending on the size
of the wheel, the passengers when they reach the top may have a grand
vista of the surrounding area; -- so called after <person>G. W. G.
Ferris</person>, American engineer, who erected the first of its kind
for the World's Columbian Exposition in Chicago in 1893.</def>
<note>Ferris wheels are often found at traveling fairs and at permanent
amusement parks. The <stype>Reisenrad</stype> in Vienna is one of the
world's largest and most famous Ferris wheels.</note><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><ent>Ferro-</ent><br/
<hw>Fer"ro-</hw> <pr>(<?/)</pr>. <fld>(Chem.)</fld> <def>A prefix, or
combining form, indicating <xex>ferrous iron</xex> as an ingredient;
<as>as, <ex>ferro</ex>cyanide</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferrocalcite</ent><br/
<hw>Fer`ro*cal"cite</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Ferro-</ets> + <ets>calcite</ets>.]</ety> <def>Limestone
containing a large percentage of iron carbonate, and hence turning brown
on exposure.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferro-concrete</ent><br/
<hw>Fer"ro-con"crete</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Arch. &
Engin.)</fld> <def>Concrete strengthened by a core or foundation
skeleton of iron or steel bars, strips, etc. Floors, columns, piles,
water pipes, etc., have been successfully made of it. Called also
<altname>armored concrete steel</altname>, and most commonly
<altname>reenforced concrete</altname>.</def><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><ent>Ferrocyanate</ent><br/
<hw>Fer`ro*cy"a*nate</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Ferro-</ets> + <ets>cyanate</ets>: cf. F.
<ets>ferrocyanate</ets>.]</ety> <fld>(Chem.)</fld> <def>A salt of
ferrocyanic acid; a ferrocyanide.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferrocyanic</ent><br/
<hw>Fer`ro*cy*an"ic</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Ferro-</ets> + <ets>cyanic</ets>: cf. F.
<ets>ferrocyanique</ets>.]</ety> <fld>(Chem.)</fld> <def>Pertaining to,
derived from, or designating, a ferrocyanide.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>ferrocyanic acid</b></col> <fld>(Chem.)</fld>, <cd>a
white crystalline substance, <chform>H4(CN)6Fe</chform>, of strong acid
properties, obtained from potassium ferrocyanide, and regarded as the
type of the ferrocyanides; -- called also <altname>hydro-ferrocyanic
acid</altname>, <altname>hydrogen ferrocyanide</altname>.
etc.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferrocyanide</ent><br/
<hw>Fer`ro*cy"a*nide</hw> <pr>(? <or/ ?; 104)</pr>, <pos>n.</pos>
<ety>[<ets>Ferro-</ets> + <ets>cyanide</ets>.]</ety> <fld>(Chem.)</fld>
<def>One of a series of complex double cyanides of ferrous iron and some
other base.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Potassium ferrocyanide</b></col> <fld>(Chem.)</fld>,
<cd>yellow prussiate of potash; a tough, yellow, crystalline salt,
<chform>K4(CN)6Fe</chform>, the starting point in the manufacture of
almost all cyanogen compounds, and the basis of the ferric ferrocyanate,
<xex>prussian blue</xex>. It is obtained by strongly heating together
potash, scrap iron, and animal matter containing nitrogen, as horn,
leather, blood, etc., in iron pots.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferroprussiate</ent><br/
<hw>Fer`ro*prus"si*ate</hw> <pr>(<?/ <or/ <?/ <or/ <?/; see
<er>Prussiate</er>, 277)</pr>, <pos>n.</pos> <ety>[<ets>Ferro-</ets> +
<ets>prussiate</ets>.]</ety> <fld>(Chem.)</fld> <def>A ferrocyanate; a
ferocyanide.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferroprussic</ent><br/
<hw>Fer`ro*prus"sic</hw> <pr>(? <or/ ?; see <er>Prussic</er>, 277)</pr>,
<pos>a.</pos> <ety>[<ets>Ferro-</ets> + <ets>prussic</ets>.]</ety>
<fld>(Chem.)</fld> <def>Ferrocyanic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferroso-</ent><br/
<hw>Fer*ro"so-</hw> <pr>(<?/)</pr>. <fld>(Chem.)</fld> <def>See
<er>Ferro-</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferrotype</ent><br/
<hw>Fer"ro*type</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>ferrum</ets> iron + <ets>-type</ets>.]</ety> <def>A photographic
picture taken on an iron plate by a collodion process; -- familiarly
called <xex>tintype</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferrous</ent><br/
<hw>Fer"rous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>ferreux</ets>. See <er>Ferreous</er>.]</ety> <fld>(Chem.)</fld>
<def>Pertaining to, or derived from, iron; -- especially used of
compounds of iron in which the iron has its lower valence of two;
<as>as, <ex>ferrous</ex> sulphate</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferruginated</ent><br/
<hw>Fer*ru"gi*na`ted</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Ferrugo</er>.]</ety> <def>Having the color or properties of the rust
of iron.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferrugineous</ent><br/
<hw>Fer`ru*gin"e*ous</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Ferruginous.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferruginous</ent><br/
<hw>Fer*ru"gi*nous</hw> <pr>(f<ecr/r*r<udd/"j<icr/*n<ucr/s)</pr>,
<pos>a.</pos> <ety>[L. <ets>ferruginus</ets>, <ets>ferrugineus</ets>,
fr. <ets>ferrugo</ets>, <ets>-ginis</ets>, iron rust: cf. F.
<ets>ferrugineux</ets>. See <er>Ferrugo</er>.]</ety> <sn>1.</sn>
<def>Partaking of iron; containing particles of iron.</def>
<rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Resembling iron rust in appearance or color;
brownish red, or yellowish red.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferrugo</ent><br/
\'d8<hw>Fer*ru"go</hw> <pr>(f<ecr/r*r<udd/"g<osl/)</pr>, <pos>n.</pos>
<ety>[L., iron rust, fr. <ets>ferrum</ets> iron.]</ety> <def>A disease
of plants caused by fungi, commonly called the <altname>rust</altname>,
from its resemblance to iron rust in color.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferrule</ent><br/
<hw>Fer"rule</hw> <pr>(f<ecr/r"r<icr/l <it>or</it> f<ecr/r"r<usdot/l;
277)</pr>, <pos>n.</pos> <ety>[Formerly <ets>verrel</ets>, F.
<ets>virole</ets>, fr. L. <ets>viriola</ets> little bracelet, dim. of
<ets>viriae</ets>, pl., bracelets; prob. akin to <ets>viere</ets> to
twist, weave, and E. <ets>withe</ets>. The spelling with <it>f</it> is
due to confusion with L. <ets>ferrum</ets> iron.]</ety>
<altsp>[Sometimes spelled <asp>ferule</asp>.]</altsp> <sn>1.</sn> <def>A
ring or cap of metal put round a cane, tool, handle, or other similar
object, to strengthen it, or prevent splitting and wearing.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Machinery)</fld> <def>Any of various circular or
cylindrical metal objects used at joints in a tube, pipe, or rod,
especially to assist making a tight seal at a joint.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <specif>Hence:</specif> <fld>(Steam Boilers)</fld> <def>A
bushing for expanding the end of a flue to fasten it tightly in the tube
plate, or for partly filling up its mouth.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <specif>Hence:</specif> <fld>(Chemistry)</fld> <def>A
bushing used at the joints of metal tubing in HPLC equipment to make a
tight seal.</def><br/
[<source>PJC</source>]</p>

<p><sn>5.</sn> <fld>(Fishing)</fld> <def>One of several small rings at
the top of a casting rod which holds the fishing line.</def>
<au>RHUD</au><br/
[<source>PJC</source>]</p>

<p><ent>Ferruminate</ent><br/
<hw>Fer*ru"mi*nate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>ferruminatus</ets>, p. p. of <ets>ferruminare</ets> to cement,
solder, fr. <ets>ferrumen</ets> cement, fr. <ets>ferrum</ets>
iron.]</ety> <def>To solder or unite, as metals.</def> <mark>[R.]</mark>
<rj><au>Coleridge.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferrumination</ent><br/
<hw>Fer*ru`mi*na"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>ferruminatio</ets>: cf. F. <ets>ferrumination</ets>.]</ety>
<def>The soldering or uniting of metals.</def> <mark>[R.]</mark>
<rj><au>Coleridge.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferry</ent><br/
<hw>Fer"ry</hw> <pr>(f<ecr/r"r<ycr/)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Ferried</conjf>
<pr>(-r<icr/d)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Ferrying</conjf>.]</vmorph> <ety>[OE. <ets>ferien</ets> to
convey, AS. <ets>ferian</ets>, from <ets>faran</ets> to go; akin to
Icel. <ets>ferja</ets> to ferry, Goth. <ets>farjan</ets> to sail. See
<er>Fare</er>.]</ety> <sn>1.</sn> <def>To carry or transport over a
river, strait, or other narrow water, in a boat.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To convey back and forth regularly between two
points in a vehicle; <as>as, part of her day was spent <ex>ferrying</ex>
the kids to and from school</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Ferry</ent><br/
<hw>Fer"ry</hw>, <pos>v. i.</pos> <def>To pass over water in a boat or
by a ferry.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They <qex>ferry</qex> over this Lethean sound<br/
Both to and fro.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferry</ent><br/
<hw>Fer"ry</hw>, <pos>n.</pos>; <plu><it>pl.</it> <plw>Ferries</plw>
<pr>(#)</pr>.</plu> <ety>[OE. <ets>feri</ets>; akin to Icel.
<ets>ferja</ets>, Sw. <ets>f<aum/rja</ets>, Dan. <ets>f<ae/rge</ets>, G.
<ets>f<aum/hre</ets>. See <er>Ferry</er>, <pos>v. t.</pos>]</ety>
<sn>1.</sn> <def>A place where persons or things are carried across a
river, arm of the sea, etc., in a ferryboat.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It can pass the <qex>ferry</qex> backward into light.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To row me o'er the <qex>ferry</qex>.</q>
<rj><qau>Campbell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A vessel in which passengers and goods are conveyed
over narrow waters; a ferryboat; a wherry.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A franchise or right to maintain a vessel for
carrying passengers and freight across a river, bay, etc., charging
tolls.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Ferry bridge</b></col>, <cd>a ferryboat adapted in its
structure for the transfer of railroad trains across a river or
bay.</cd> -- <col><b>Ferry railway</b></col>. <cd>See under
<er>Railway</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferryboat</ent><br/
<hw>Fer"ry*boat`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A vessel for
conveying passengers, merchandise, etc., usually across streams, rivers,
bays, and other narrow waters.</def><br/
<syn><b>Syn. --</b> ferry{2}.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferryman</ent><br/
<hw>Fer"ry*man</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Ferrymen</plw> <pr>(<?/)</pr>.</plu> <def>One who maintains or
attends a ferry.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fers</ent><br/
<hw>Fers</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Fierce.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferthe</ent><br/
<hw>Ferthe</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Fourth.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fertile</ent><br/
<hw>Fer"tile</hw> <pr>(? <or/ ?; 277)</pr>, <pos>a.</pos> <ety>[L.
<ets>fertilis</ets>, fr. <ets>ferre</ets> to bear, produce: cf. F.
<ets>fertile</ets>. <ets>See</ets> <er>Bear</er> to support.]</ety>
<sn>1.</sn> <def>Producing fruit or vegetation in abundance; fruitful;
able to produce abundantly; prolific; fecund; productive; rich;
inventive; <as>as, <ex>fertile</ex> land or fields; a <ex>fertile</ex>
mind or imagination.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Though he in a <qex>fertile</qex> climate dwell.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <sd>(a)</sd> <def>Capable of producing
fruit; fruit-bearing; <as>as, <ex>fertile</ex> flowers</as>.</def>
<sd>(b)</sd> <def>Containing pollen; -- said of anthers.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>produced in abundance; plenteous; ample.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Henceforth, my early care . . . <br/
Shall tend thee, and the <qex>fertile</qex> burden ease<br/
Of thy full branches.</q> <rj><qau>Milton.</qau></rj></p>

<p><syn><b>Syn.</b> -- <er>Fertile</er>, <er>Fruitful</er>.</syn>
<usage> <xex>Fertile</xex> implies the inherent power of production;
<xex>fruitful</xex>, the act. The prairies of the West are
<xex>fertile</xex> by nature, and are turned by cultivation into
<xex>fruitful</xex> fields. The same distinction prevails when these
words are used figuratively. A man of <xex>fertile</xex> genius has by
nature great readiness of invention; one whose mind is
<xex>fruitful</xex> has resources of thought and a readiness of
application which enable him to think and act effectively.</usage><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 554 --></p>

<p><ent>Fertilely</ent><br/
<hw>Fer"tile*ly</hw> <pr>(? <or/ ?; 277)</pr>, <pos>adv.</pos> <def>In a
fertile or fruitful manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>fertileness</ent><br/
<hw>fer"tile*ness</hw>, <pos>n.</pos> <def>Fertility.</def> <rj><au>Sir
P. Sidney.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fertilitate</ent><br/
<hw>Fer*til"i*tate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To
fertilize; to fecundate.</def> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fertility</ent><br/
<hw>Fer*til"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>fertilitas</ets>: cf. F. <ets>fertilit<eacute/</ets>.]</ety>
<def>The state or quality of being fertile or fruitful; fruitfulness;
productiveness; fecundity; richness; abundance of resources; fertile
invention; quickness; readiness; <as>as, the <ex>fertility</ex> of soil,
or of imagination</as>.</def> <ldquo/<xex>fertility</xex> of
resource.<rdquo/ <rj><au>E. Everett.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And all her husbandry doth lie on heaps<br/
Corrupting in its own <qex>fertility</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Thy very weeds are beautiful; thy waste<br/
More rich than other climes' <qex>fertility</qex>.</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fertilization</ent><br/
<hw>Fer`ti*li*za"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>The act or process of rendering fertile.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Biol.)</fld> <def>The act of fecundating or
impregnating animal or vegetable germs; esp., the process by which in
flowers the pollen renders the ovule fertile, or an analogous process in
flowerless plants; fecundation; impregnation.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Close fertilization</b></col> <fld>(Bot.)</fld>, <cd>the
fertilization of pistils by pollen derived from the stamens of the same
blossom.</cd> -- <col><b>Cross fertilization</b></col>,
<cd>fertilization by pollen from some other blossom. See under
<er>Cross</er>, <pos>a.</pos></cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fertilize</ent><br/
<hw>Fer"ti*lize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Fertilized</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Fertilizing</conjf> <pr>(?)</pr>.]</vmorph> <ety>[Cf. F.
<ets>fertiliser</ets>.]</ety> <sn>1.</sn> <def>To make fertile or
enrich; to supply with nourishment for plants; to make fruitful or
productive; <as>as, to <ex>fertilize</ex> land, soil, ground, and
meadows</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And <qex>fertilize</qex> the field that each pretends to gain.</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To fecundate; <as>as, to <ex>fertilize</ex>
flower</as>.</def> <rj><au>A. R. Wallace.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>fertilized</ent><br/
<hw>fertilized</hw> <pos>adj.</pos> <sn>1.</sn> <def>united with a male
gamete to begin the development of an individual embryo; -- of female
gametes.</def><br/
<syn><b>Syn. --</b> impregnated, inseminated.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>made more suitable for growth of crops by addition
of fertilizer{2}; -- of soil.</def><br/
<syn><b>Syn. --</b> enriched.</syn><br/
[<source>PJC</source>]</p>

<p><ent>Fertilizer</ent><br/
<hw>Fer"ti*lizer</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One
who fertilizes; the agent that carries the fertilizing principle, as a
moth to an orchid.</def> <rj><au>A. R. Wallace.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which renders fertile; a general name for
commercial substances which make plants grow better, as manure, guano,
phosphate of lime, ammonium nitrate, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferula</ent><br/
\'d8<hw>Fer"u*la</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>ferula</ets> giant fennel (its stalks were used in punishing
schoolboys), rod, whip, fr. <ets>ferire</ets> to strike; akin to OHG.
<ets>berjan</ets>, Icel. <ets>berja</ets>. Cf. <er>Ferule</er>.]</ety>
<sn>1.</sn> <def>A ferule.</def> <mark>[Obs.]</mark> <rj><au>Beau. &
Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The imperial scepter in the Byzantine or Eastern
Empire.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <mark>[capitalized]</mark> <def>A genus of plants of the
parsley family <fam>Apiaceae</fam> (of the order
<ord>Umbelliferae</ord>), including some yielding
<prod>asafetida</prod>. Members include <spn>Ferula asafoetida</spn>
(<spn>Ferula foetida</spn>), the <member>giant fennel</member>
(<spn>Ferula communis)</spn>, and <spn>Ferula
orientalis</spn>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Ferulaceous</ent><br/
<hw>Fer`u*la"ceous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>ferulaceus</ets>, fr. <ets>ferula</ets> rod: cf. F.
<ets>f<eacute/rulac<eacute/</ets>.]</ety> <def>Pertaining to reeds and
canes; having a stalk like a reed; <as>as, <ex>ferulaceous</ex>
plants</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferular</ent><br/
<hw>Fer"u*lar</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A ferule.</def>
<mark>[Obs.]</mark> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferule</ent><br/
<hw>Fer"ule</hw> <pr>(? <or/ ?; 277)</pr>, <pos>n.</pos> <ety>[L.
<ets>ferula</ets>: cf. F. <ets>f<eacute/rule</ets>. See
<er>Ferula</er>.]</ety> <sn>1.</sn> <def>A flat piece of wood, used for
striking, children, esp. on the hand, in punishment.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A <er>ferrule</er>.</def> <mark>[R.]</mark><br/
[<source>PJC</source>]</p>

<p><ent>Ferule</ent><br/
<hw>Fer"ule</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Feruled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Feruling</conjf>.]</vmorph> <def>To punish with a
ferule.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ferulic</ent><br/
<hw>Fe*ru"lic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Chem.)</fld>
<def>Pertaining to, or derived from, asafetida (<spn>Ferula
asaf<oe/tida</spn>); <as>as, <ex>ferulic</ex> acid</as>.</def>
<altsp>[Written also <asp>ferulaic</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fervence</ent><br/
<hw>Fer"vence</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Heat;
fervency.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fervency</ent><br/
<hw>Fer"ven*cy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. OF.
<ets>fervence</ets>. See <er>Fervent</er>.]</ety> <def>The state of
being fervent or warm; ardor; warmth of feeling or devotion;
eagerness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>When you pray, let it be with attention, with <qex>fervency</qex>,
and with perseverance.</q> <rj><qau>Wake.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fervent</ent><br/
<hw>Fer"vent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F.
<ets>fervent</ets>, L. <ets>fervens</ets>, <ets>-entis</ets>. p. pr. of
<ets>fervere</ets> o the boiling hot, to boil, glow.]</ety> <sn>1.</sn>
<def>Hot; glowing; boiling; burning; <as>as, a <ex>fervent</ex>
summer</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The elements shall melt with <qex>fervent</qex> heat.</q>
<rj><qau>2 Pet. iii. 10.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Warm in feeling; ardent in temperament; earnest;
full of fervor; zealous; glowing.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Not slothful in business; <qex>fervent</qex> in spirit.</q>
<rj><qau>Rom. iii. 11.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>So spake the <qex>fervent</qex> angel.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>fervent</qex> desire to promote the happiness of
mankind.</q> <rj><qau>Macaulay.</qau></rj></p>

<p>-- <wordforms><wf>Fer"vent*ly</wf>, <pos>adv.</pos> --
<wf>Fer"vent*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><q>Laboring <qex>fervently</qex> for you in prayers.</q>
<rj><qau>Col. iv. 12.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fervescent</ent><br/
<hw>Fer*ves"cent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>fervescens</ets>, p. pr. of <ets>fervescere</ets> to become boiling
hot, incho., fr. <ets>fervere</ets>. See <er>Fervent</er>.]</ety>
<def>Growing hot.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fervid</ent><br/
<hw>Fer"vid</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>fervidus</ets>, fr. <ets>fervere</ets>. See
<er>Fervent</er>.]</ety> <sn>1.</sn> <def>Very hot; burning;
boiling.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The mounted sun<br/
Shot down direct his <qex>fervid</qex> rays.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Ardent; vehement; zealous.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>fervid</qex> wishes, holy fires.</q>
<rj><qau>Parnell.</qau></rj></p>

<p>-- <wordforms><wf>Fer"vid*ly</wf>, <pos>adv.</pos> --
<wf>Fer"vid*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fervor</ent><br/
<hw>Fer"vor</hw> <pr>(?)</pr>, <pos>n.</pos> <altsp>[Written also
<asp>fervour</asp>.]</altsp> <ety>[OF. <ets>fervor</ets>,
<ets>fervour</ets>, F. <ets>ferveur</ets>, L. <ets>fervor</ets>, fr.
<ets>fervere</ets>. See <er>Fervent</er>.]</ety> <sn>1.</sn> <def>Heat;
excessive warmth.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>fevor</qex> of ensuing day.</q>
<rj><qau>Waller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Intensity of feeling or expression; glowing ardor;
passion; holy zeal; earnestness.</def> <rj><au>Hooker.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Winged with <qex>fervor</qex> of her love.</q>
<rj><qau>Shak.</qau></rj></p>

<p><syn><b>Syn.</b> -- <er>Fervor</er>, <er>Ardor</er>.</syn> <usage>
<xex>Fervor</xex> is a boiling heat, and <xex>ardor</xex> is a burning
heat. Hence, in metaphor, we commonly use <xex>fervor</xex> and its
derivatives when we conceive of thoughts or emotions under the image of
ebullition, or as pouring themselves forth. Thus we speak of the
<xex>fervor</xex> of passion, <xex>fervid</xex> declamation,
<xex>fervid</xex> importunity, <xex>fervent</xex> supplication,
<xex>fervent</xex> desires, etc. <xex>Ardent</xex> is used when we think
of anything as springing from a deepseated glow of soul; as,
<xex>ardent</xex> friendship, <xex>ardent</xex> zeal, <xex>ardent</xex>
devotedness; burning with <xex>ardor</xex> for the fight.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fescennine</ent><br/
<hw>Fes"cen*nine</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>Fescenninus</ets>, fr. <etsep>Fescennia</etsep>, a city of
Etruria.]</ety> <def>Pertaining to, or resembling, the
Fescennines.</def> -- <def2><pos>n.</pos> <def>A style of low,
scurrilous, obscene poetry originating in fescennia.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fescue</ent><br/
<hw>Fes"cue</hw> <pr>(f<ecr/s"k<usl/)</pr>, <pos>n.</pos> <ety>[OE.
<ets>festu</ets>, OF. <ets>festu</ets>, F. <ets>f<eacute/tu</ets>, fr.
L. <ets>festuca</ets> stalk, straw.]</ety> <sn>1.</sn> <def>A straw,
wire, stick, etc., used chiefly to point out letters to children when
learning to read.</def> <ldquo/Pedantic <xex>fescue</xex>.<rdquo/
<rj><au>Sterne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To come under the <qex>fescue</qex> of an imprimatur.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An instrument for playing on the harp; a
plectrum.</def> <mark>[Obs.]</mark> <rj><au>Chapman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The style of a dial.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Bot.)</fld> <def>A grass of the genus
<gen>Festuca</gen>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fescue grass</b></col> <fld>(Bot.)</fld>, <cd>a genus of
grasses (<gen>Festuca</gen>) containing several species of importance in
agriculture. <spn>Festuca ovina</spn> is <stype>sheep's fescue</stype>;
<spn>F. elatior</spn> is <stype>meadow fescue</stype>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fescue</ent><br/
<hw>Fes"cue</hw> <pr>(f<ecr/s"k<usl/)</pr>, <pos>v. i. & t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Fescued</conjf> <pr>(?)</pr>;
<pos>p. pr. & vb. n.</pos> <conjf>Fescuing</conjf>.]</vmorph> <def>To
use a fescue, or teach with a fescue.</def>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fesels</ent><br/
<hw>Fes"els</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[Written also
<ets>fasels</ets>.]</ety> <def>See <er>Phasel</er>.</def>
<mark>[Obs.]</mark> <rj><au>May (Georgics).</au></rj></p>

<p><ent>Fesse</ent><br/
<ent>Fess</ent><br/
<mhw>{ <hw>Fess</hw>, <hw>Fesse</hw> }</mhw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[OF. <ets>fesse</ets>, <ets>faisse</ets>, F. <ets>fasce</ets>, fr.
L. <ets>fascia</ets> band. See <er>Fascia</er>.]</ety> <fld>(Her.)</fld>
<def>A band drawn horizontally across the center of an escutcheon, and
containing in breadth the third part of it; one of the nine honorable
ordinaries.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fess point</b></col> <fld>(Her.)</fld>, <cd>the exact
center of the escutcheon. See <er>Escutcheon</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fessitude</ent><br/
<hw>Fes"si*tude</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>fessus</ets> wearied, fatigued.]</ety> <def>Weariness.</def>
<mark>[Obs.]</mark> <rj><au>Bailey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fesswise</ent><br/
<hw>Fess"wise</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In the manner of
fess.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fest</ent><br/
<hw>Fest</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Fist</er>.]</ety> <def>The fist.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj></p>

<p><ent>Feste</ent><br/
<ent>Fest</ent><br/
<mhw>{ <hw>Fest</hw>, <hw>Fes"te</hw> <pr>(?)</pr>, <pos>n.</pos>
}</mhw> <def>A feast.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Festal</ent><br/
<hw>Fes"tal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>festum</ets>
holiday, feast. See <er>feast</er>.]</ety> <def>Of or pertaining to a
holiday or a feast; joyous; festive.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>You bless with choicer wine the <qex>festal</qex> day.</q>
<rj><qau>Francis.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Festally</ent><br/
<hw>Fes"tal*ly</hw>, <pos>adv.</pos> <def>Joyously; festively;
mirthfully.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Festennine</ent><br/
<hw>Fes"ten*nine</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A
fescennine.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fester</ent><br/
<hw>Fes"ter</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Festered</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Festering</conjf>.]</vmorph> <ety>[OE.
<ets>festern</ets>, fr. <ets>fester</ets>, <pos>n.</pos>; <ets>or
fr</ets>. <ets>OF</ets>. <ets>festrir</ets>, fr. <ets>festre</ets>,
<pos>n.</pos> See <er>Fester</er>, <pos>n.</pos>]</ety> <sn>1.</sn>
<def>To generate pus; to become imflamed and suppurate; <as>as, a sore
or a wound <ex>festers</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Wounds immedicable<br/
Rankle, and <qex>fester</qex>, and gangrene.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Unkindness may give a wound that shall bleed and smart, but it is
treachery that makes it <qex>fester</qex>.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Hatred . . . <qex>festered</qex> in the hearts of the children of
the soil.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To be inflamed; to grow virulent, or malignant; to
grow in intensity; to rankle.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fester</ent><br/
<hw>Fes`ter</hw>, <pos>v. t.</pos> <def>To cause to fester or
rankle.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>For which I burnt in inward, swelt'ring hate,<br/
And <qex>festered</qex> ranking malice in my breast.</q>
<rj><qau>Marston.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fester</ent><br/
<hw>Fes"ter</hw>, <pos>n.</pos> <ety>[OF. <ets>festre</ets>, L.
<ets>fistula</ets> a sort of ulcer. Cf. <er>Fistula</er>.]</ety>
<sn>1.</sn> <def>A small sore which becomes inflamed and discharges
corrupt matter; a pustule.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A festering or rankling.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>fester</qex> of the chain their necks.</q> <rj><qau>I.
Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Festerment</ent><br/
<hw>Fes"ter*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A
festering.</def> <mark>[R.]</mark> <rj><au>Chalmers.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Festeye</ent><br/
<hw>Fest"eye</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[OF.
<ets>festier</ets>, <ets>festeer</ets>, F. <ets>festoyer</ets>.]</ety>
<def>To feast; to entertain.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Festinate</ent><br/
<hw>Fes"ti*nate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>festinatus</ets>, p. p. of <ets>festinare</ets> to hasten.]</ety>
<def>Hasty; hurried.</def> <mark>[Obs.]</mark> --
<wordforms><wf>Fes"ti*nate*ly</wf>, <pos>adv.</pos>
<mark>[Obs.]</mark></wordforms> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Festination</ent><br/
<hw>Fes`ti*na"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>festinatio</ets>.]</ety> <def>Haste; hurry.</def>
<mark>[Obs.]</mark> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Festival</ent><br/
<hw>Fes"ti*val</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OF.
<ets>festival</ets>, fr. L. <ets>festivum</ets> festive jollity, fr.
<ets>festivus</ets> festive, gay. See <er>Festive</er>.]</ety>
<def>Pertaining to a fest; festive; festal; appropriate to a festival;
joyous; mirthful.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I cannot woo in <qex>festival</qex> terms.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Festi-val</ent><br/
<hw>Fes"ti-val</hw>, <pos>n.</pos> <def>A time of feasting or
celebration; an anniversary day of joy, civil or religious.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The morning trumpets <qex>festival</qex> proclaimed.</q>
<rj><qau>Milton.</qau></rj></p>

<p><syn><b>Syn.</b> -- Feast; banquet; carousal. See
<er>Feast</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Festive</ent><br/
<hw>Fes"tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>festivus</ets>, fr. <ets>festum</ets> holiday, feast. See
<er>feast</er>, and cf. <er>Festivous</er>.]</ety> <def>Pertaining to,
or becoming, a feast; festal; joyous; gay; mirthful; sportive.</def> --
<wordforms><wf>Fes"tive*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><q>The glad circle round them yield their souls<br/
To <qex>festive</qex> mirth and wit that knows no gall.</q>
<rj><qau>Thomson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Festivity</ent><br/
<hw>Fes*tiv"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Festivities</plw> <pr>(#)</pr>.</plu> <ety>[L.
<ets>festivitas</ets>: cf. F. <ets>festivit<eacute/</ets>.]</ety>
<sn>1.</sn> <def>The condition of being festive; social joy or
exhilaration of spirits at an entertaintment; joyfulness;
gayety.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The unrestrained <qex>festivity</qex> of the rustic youth.</q>
<rj><qau>Bp. Hurd.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A festival; a festive celebration.</def> <rj><au>Sir
T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Festivous</ent><br/
<hw>Fes"ti*vous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Festive</er>.]</ety> <def>Pertaining to a feast; festive.</def>
<mark>[R.]</mark> <rj><au>Sir W. Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Festlich</ent><br/
<hw>Fest"lich</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See <er>Feast</er>,
<pos>n.</pos>]</ety> <def>Festive; fond of festive occasions.</def>
<mark>[Obs.]</mark> <ldquo/A <xex>festlich</xex> man.<rdquo/
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Festoon</ent><br/
<hw>Fes*toon"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>feston</ets> (cf. Sp. <ets>feston</ets>, It. <ets>festone</ets>),
prob. fr. L. <ets>festum</ets> festival. See <er>Feast</er>.]</ety>
<sn>1.</sn> <def>A garland or wreath hanging in a depending curve, used
in decoration for festivals, etc.; anything arranged in this
way.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Arch. & Sculp.)</fld> <def>A carved ornament
consisting of flowers, and leaves, intermixed or twisted together, wound
with a ribbon, and hanging or depending in a natural curve. See
<xex>Illust.</xex> of <er>Bucranium</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Festoon</ent><br/
<hw>Fes*toon"</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Festooned</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Festooning</conjf>.]</vmorph> <def>To form in festoons, or to
adorn with festoons.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Festoony</ent><br/
<hw>Fes*toon"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to,
consisting of, or resembling, festoons.</def> <rj><au>Sir J.
Herschel.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Festucine</ent><br/
<hw>Fes*tu*cine</hw> <pr>(? <or/ ?)</pr>, <pos>a.</pos> <ety>[L.
<ets>festula</ets> stalk, straw. Cf. <er>Fescue</er>.]</ety> <def>Of a
straw color; greenish yellow.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>A little insect of a <qex>festucine</qex> or pale green.</q>
<rj><qau>Sir T. Browne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Festucous</ent><br/
<hw>Fes"tu*cous</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Formed or
consisting of straw.</def> <mark>[Obs.]</mark> <rj><au>Sir T.
Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Festue</ent><br/
<hw>Fes"tue</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Fescue</er>.]</ety> <def>A straw; a fescue.</def>
<mark>[Obs.]</mark> <rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fet</ent><br/
<hw>Fet</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. <ets>feat</ets>, F.
<ets>fait</ets>, and It. <ets>fett<?/</ets> slice, G. <ets>fetzen</ets>
rag, Icel. <ets>fat</ets> garment.]</ety> <def>A piece.</def>
<mark>[Obs.]</mark> <rj><au>Dryton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fet</ent><br/
<hw>Fet</hw>, <pos>v. t.</pos> <ety>[OE. <ets>fetten</ets>,
<ets>feten</ets>, AS. <ets>fetian</ets>; akin to AS. <ets>f<ae/t</ets> a
journey, and to E. <ets>foot</ets>; cf. G. <ets>fassen</ets> to seize.
<root/ 77. See <er>Foot</er>, and cf. <er>Fetch</er>.]</ety> <def>To
fetch.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>And from the other fifty soon the prisoner <qex>fet</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fet</ent><br/
<hw>Fet</hw>, <pos>p. p.</pos> <mord>of <er>Fette</er></mord>.
<def>Fetched.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fetal</ent><br/
<hw>Fe"tal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From
<er>Fetus</er>.]</ety> <def>Pertaining to, or connected with, a fetus;
<as>as, <ex>fetal circulation</ex>; <ex>fetal</ex>
membranes.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fetation</ent><br/
<hw>Fe*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The formation of a
fetus in the womb; pregnancy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fetch</ent><br/
<hw>Fetch</hw> <pr>(f<ecr/ch; 224)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Fetched</conjf> 2; <pos>p. pr. &
vb. n.</pos>. <conjf>Fetching</conjf>.]</vmorph> <ety>[OE.
<ets>fecchen</ets>, AS. <ets>feccan</ets>, perh. the same word as
<ets>fetian</ets>; or cf. <ets>facian</ets> to wish to get, OFries.
<ets>faka</ets> to prepare. <root/77. Cf. <er>Fet</er>, <pos>v.
t.</pos>]</ety> <sn>1.</sn> <def>To bear toward the person speaking, or
the person or thing from whose point of view the action is contemplated;
to go and bring; to get.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Time will run back and <qex>fetch</qex> the age of gold.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He called to her, and said, <qex>Fetch</qex> me, I pray thee, a
little water in a vessel, that I may drink. And as she was going to
<qex>fetch</qex> it he called to her, and said, Bring me, I pray thee, a
morsel of bread in thine hand.</q> <rj><qau>1 Kings xvii. 11,
12.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To obtain as price or equivalent; to sell
for.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Our native horses were held in small esteem, and
<qex>fetched</qex> low prices.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To recall from a swoon; to revive; -- sometimes with
<xex>to</xex>; <as>as, to <ex>fetch</ex> a man to</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Fetching</qex> men again when they swoon.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To reduce; to throw.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The sudden trip in wrestling that <qex>fetches</qex> a man to the
ground.</q> <rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To bring to accomplishment; to achieve; to make; to
perform, with certain objects; <as>as, to <ex>fetch</ex> a compass; to
<ex>fetch</ex> a leap; to <ex>fetch</ex> a sigh.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>I'll <qex>fetch</qex> a turn about the garden.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He <qex>fetches</qex> his blow quick and sure.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To bring or get within reach by going; to reach; to
arrive at; to attain; to reach by sailing.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Meantine flew our ships, and straight we <qex>fetched</qex><br/
The siren's isle.</q> <rj><qau>Chapman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>To cause to come; to bring to a particular
state.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They could n't <qex>fetch</qex> the butter in the churn.</q>
<rj><qau>W. Barnes.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To fetch a compass</b></col> <fld>(Naut.)</fld>, <cd>to
make a circuit; to take a circuitous route going to a place.</cd> --
<col><b>To fetch a pump</b></col>, <cd>to make it draw water by pouring
water into the top and working the handle.</cd> -- <mcol><col><b>To
fetch headway</b></col> <it>or</it> <col><b>To fetch
sternway</b></col></mcol> <fld>(Naut.)</fld>, <cd>to move ahead or
astern.</cd> -- <col><b>To fetch out</b></col>, <cd>to develop.</cd>
<ldquo/The skill of the polisher <xex>fetches out</xex> the colors [of
marble]<rdquo/ <au>Addison.</au> -- <col><b>To fetch up</b></col>.
<sd>(a)</sd> <cd>To overtake.</cd> <mark>[Obs.]</mark> <ldquo/Says [the
hare], I can <xex>fetch up</xex> the tortoise when I please.<rdquo/
<au>L'Estrange.</au> <sd>(b)</sd> <cd>To stop suddenly.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>fetch</ent><br/
<hw>fetch</hw>, <pos>v. i.</pos> <def>To bring one's self; to make
headway; to veer; <as>as, to <ex>fetch</ex> about; to <ex>fetch</ex> to
windward.</as></def> <rj><au>Totten.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To fetch away</b></col> <fld>(Naut.)</fld>, <cd>to break
loose; to roll or slide to leeward.</cd> -- <col><b>To fetch and
carry</b></col>, <cd>to serve obsequiously, like a trained
spaniel.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fetch</ent><br/
<hw>Fetch</hw>, <pos>n.</pos> <sn>1.</sn> <def>A stratagem by which a
thing is indirectly brought to pass, or by which one thing seems
intended and another is done; a trick; an artifice.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Every little <qex>fetch</qex> of wit and criticism.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The apparation of a living person; a
wraith.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The very <qex>fetch</qex> and ghost of Mrs. Gamp.</q>
<rj><qau>Dickens.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The unobstructed region of the ocean over which the
wind blows to generate waves.</def><br/
[<source>RH</source>]</p>

<p><sn>4.</sn> <specif>Hence:</specif> <def>The length of such a
region.</def><br/
[<source>RH</source>]</p>

<p><cs><col><b>Fetch candle</b></col>, <cd>a light seen at night,
superstitiously believed to portend a person's death.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fetcher</ent><br/
<hw>Fetch"er</hw> <pr>(f<ecr/ch"<etil/r)</pr>, <pos>n.</pos> <def>One
who fetches or brings.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>fetching</ent><br/
<hw>fetching</hw> <pos>adj.</pos> <def>drawing favorable attention;
<as>as, a <ex>fetching</ex> new hat</as>.</def><br/
<syn><b>Syn. --</b> appealing, taking, winning.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fete</ent><br/
<hw>Fete</hw> <pr>(f<emac/t)</pr>, <pos>n.</pos> <ety>[See
<er>feat</er>.]</ety> <def>A feat.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fete</ent><br/
<hw>Fete</hw>, <pos>n. pl.</pos> <ety>[See <er>Foot</er>.]</ety>
<def>Feet.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>fete</ent><br/
\'d8<hw>f<ecir/te</hw> <pr>(f<asl/t)</pr>, <pos>n.</pos> <ety>[F. See
<er>Feast</er>.]</ety> <def>A festival.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>F<ecir/te champ<ecir/tre</b></col> <pr>(<?/)</pr>
<ety>[F.]</ety>, <cd>a festival or entertainment in the open air; a
rural festival.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>fete</ent><br/
<hw>f<ecir/te</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>F<ecir/ted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>F<ecir/ting</conjf>.]</vmorph> <ety>[Cf. F.
<ets>f<ecir/ter</ets>.]</ety> <def>To feast; to honor with a
festival.</def></p>

<p><ent>Fetish</ent><br/
<ent>Fetich</ent><br/
<mhw>{ <hw>Fe"tich</hw>, <hw>Fe"tish</hw> <pr>(?)</pr>, <pos>n.</pos>
}</mhw><ety>[F. <ets>f<eacute/tiche</ets>, from Pg.
<ets>feiti<?/o</ets>, adj., <pos>n.</pos>, sorcery, charm, fr. L.
<ets>facticius</ets> made by art, artifical, factitious. See
<er>Factitious</er>.]</ety> <sn>1.</sn> <def>A material object supposed
among certain African tribes to represent in such a way, or to be so
connected with, a supernatural being, that the possession of it gives to
the possessor power to control that being.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Any object to which one is excessively
devoted.</def></p>

<p><ent>Fetishism</ent><br/
<ent>fetichism</ent><br/
<mhw>{ <hw>fe"tich*ism</hw>, <hw>Fe"tish*ism</hw> <pr>(? <or/ ?)</pr>;
277), <pos>n.</pos> }</mhw><ety>[Cf. F.
<ets>f<eacute/tichisme</ets>.]</ety> <altsp>[Written also
<asp>feticism</asp>.]</altsp> <sn>1.</sn> <def>The doctrine or practice
of belief in fetiches.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Excessive devotion to one object or one idea; abject
superstition; blind adoration.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The real and absolute worship of fire falls into two great
divisions, the first belonging rather to <qex>fetichism</qex>, the
second to polytheism proper.</q> <rj><qau>Tylor.</qau></rj></p>

<p><ent>Fetishist</ent><br/
<ent>Fetichist</ent><br/
<mhw>{ <hw>Fe"tich*ist</hw>, <hw>Fe"tish*ist</hw>, <pos>n.</pos> }</mhw>
<def>A believer in fetiches.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He was by nature a <qex>fetichist</qex>.</q> <rj><qau>H.
Holbeach.</qau></rj></p>

<p><ent>Fetishistic</ent><br/
<ent>Fetichistic</ent><br/
<mhw>{ <hw>Fe`tich*is"tic</hw> <pr>(?)</pr>, <hw>Fe`tish*is"tic</hw>,
<pos>a.</pos>}</mhw> <def>Pertaining to, or involving,
fetichism.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A man of the fifteenth century, inheriting its strange web of
belief and unbelief, of epicurean levity and <qex>fetichistic</qex>
dread.</q> <rj><qau>G. Eliot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feticide</ent><br/
<hw>Fe"ti*cide</hw> <pr>(? <or/ ?)</pr>, <pos>n.</pos> <altsp>[Written
also <asp>f<oe/ticide</asp>.]</altsp> <ety>[<ets>Fetus</ets> + L.
<ets>caedere</ets> to kill.]</ety> <fld>(Med. & Law)</fld> <def>The act
of killing the fetus in the womb; the offense of procuring an
abortion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feticism</ent><br/
<hw>Fe"ti*cism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Fetichism</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fetid</ent><br/
<hw>Fet"id</hw> <pr>(? <or/ ?; 277)</pr>, <pos>a.</pos> <ety>[L.
<ets>fetidus</ets>, <ets>foetidus</ets>, fr. <ets>fetere</ets>,
<ets>foetere</ets>, to have an ill smell, to stink: cf. F.
<ets>f<eacute/tide</ets>.]</ety> <def>Having an offensive smell;
stinking.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Most putrefactions . . . smell either <qex>fetid</qex> or
moldy.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fetidity</ent><br/
<hw>Fet*id"i*ty</hw> <pr>(? <or/ ?)</pr>, <pos>n.</pos>
<def>Fetidness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fetidness</ent><br/
<hw>Fet"id*ness</hw>, <pos>n.</pos> <def>The quality or state of being
fetid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fetiferous</ent><br/
<hw>Fe*tif"er*ous</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Fetus</ets> + <ets>-ferous</ets>.]</ety> <def>Producing
young, as animals.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 555 --></p>

<p><ent>Fetis</ent><br/
<hw>Fe"tis</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OF. <ets>fetis</ets>,
<ets>faitis</ets>. Cf. <er>Factitious</er>.]</ety> <def>Neat; pretty;
well made; graceful.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Full <qex>fetis</qex> was her cloak, as I was ware.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fetisely</ent><br/
<hw>Fe"tise*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>Neatly;
gracefully; properly.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj></p>

<p><ent>Fetishistic</ent><br/
<ent>Fetishism</ent><br/
<ent>Fetish</ent><br/
<mhw><hw>Fe"tish</hw> <pr>(?)</pr>, <pos>n.</pos>, <hw>Fe"tish*ism</hw>
<pr>(<?/ <or/ <?/; 277)</pr>, <pos>n.</pos>, <hw>Fe`tish*is"tic</hw>
<pr>(<?/)</pr>, <pos>a.</pos></mhw> <def>See <er>Fetich</er>,
<pos>n.</pos>, <er>Fetichism</er>, <pos>n.</pos>, <er>Fetichistic</er>,
<pos>a.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fetlock</ent><br/
<hw>Fet"lock</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>fetlak</ets>, <ets>fitlock</ets>, cf. Icel. <ets>fet</ets> pace,
step, <ets>fit</ets> webbed foot of water birds, akin to E.
<ets>foot</ets>. <root/ 77. See <er>Foot</er>.]</ety> <def>The
cushionlike projection, bearing a tuft of long hair, on the back side of
the leg above the hoof of the horse and similar animals. Also, the joint
of the limb at this point (between the great pastern bone and the
metacarpus), or the tuft of hair.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Their wounded steeds<br/
Fret <qex>fetlock</qex> deep in gore.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fetor</ent><br/
<hw>Fe"tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>fetor</ets>,
<ets>foetor</ets>. See <er>Fetid</er>.]</ety> <def>A strong, offensive
smell; stench; fetidness.</def> <rj><au>Arbuthnot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fette</ent><br/
<hw>Fet"te</hw> <pr>(? <or/ ?)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp.</pos> <conjf>Fette</conjf>, <pos>p. p.</pos>
<conjf>Fet</conjf>.]</vmorph> <ety>[See <er>Fet</er>, <pos>v.
t.</pos>]</ety> <def>To fetch.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fetter</ent><br/
<hw>Fet"ter</hw> <pr>(f<ecr/t"t<etil/r)</pr>, <pos>n.</pos> <ety>[AS.
<ets>fetor</ets>, <ets>feter</ets>; akin to OS. <ets>feter<omac/s</ets>,
pl., OD. <ets>veter</ets>, OHG. <ets>fezzera</ets>, Icel.
<ets>fj<oum/turr</ets>, L. <ets>pedica</ets>, Gr. <grk>pe`dh</grk>, and
to E. <ets>foot</ets>. <root/ 77. See <er>Foot</er>.]</ety>
<mark>[Chiefly used in the plural, <plw>fetters</plw>.]</mark>
<sn>1.</sn> <def>A chain or shackle for the feet; a chain by which an
animal is confined by the foot, either made fast or disabled from free
and rapid motion; a bond; a shackle.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>[They] bound him with <qex>fetters</qex> of brass.</q>
<rj><qau>Judg. xvi. 21.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Anything that confines or restrains; a
restraint.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Passion's too fierce to be in <qex>fetters</qex> bound.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fetter</ent><br/
<hw>Fet"ter</hw>, <pos>v. t.</pos> <ety>[<pos>imp. & p. p.</pos>
<er>Fettered</er> <pr>(<?/)</pr>; <pos>p. pr. & vb. n.</pos>
<er>Fettering</er>.]</ety> <sn>1.</sn> <def>To put fetters upon; to
shackle or confine the feet of with a chain; to bind.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>My heels are <qex>fettered</qex>, but my fist is free.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To restrain from motion; to impose restraints on; to
confine; to enchain; <as>as, <ex>fettered</ex> by
obligations</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>My conscience! thou art <qex>fettered</qex><br/
More than my shanks and wrists.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>fetterbush</ent><br/
<hw>fet"ter*bush`</hw> <pos>n.</pos> <sn>1.</sn> <def>An ornamental
evergreen shrub (<spn>Pieris floribunda</spn>) of the Southeastern U. S.
having small white bell-shaped flowers.</def><br/
<syn><b>Syn. --</b> mountain fetterbush, mountain andromeda, <spn>Pieris
floribunda</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>A showy evergreen shrub (<spn>Lyonia lucida</spn>)
of the Southeastern U. S. with shiny leaves and angled branches and
umbel-like clusters of pink to reddish flowers.</def><br/
<syn><b>Syn. --</b> fetter bush, shiny lyonia, <spn>Lyonia
lucida</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fettered</ent><br/
<hw>Fet"tered</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Seeming as if fettered, as the feet of certain animals which bend
backward, and appear unfit for walking.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fetterer</ent><br/
<hw>Fet"ter*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
fetters.</def> <rj><au>Landor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fetterless</ent><br/
<hw>Fet"ter*less</hw>, <pos>a.</pos> <def>Free from fetters.</def>
<rj><au>Marston.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fettle</ent><br/
<hw>Fet"tle</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[OE. & Prov. E., to
fettle (in sense 1), <ets>fettle</ets>, <pos>n.</pos>, order, repair,
preparation, dress; prob. akin to E. <ets>fit</ets>. See <er>Fit</er>,
<pos>a.</pos>]</ety> <sn>1.</sn> <def>To repair; to prepare; to put in
order.</def> <mark>[Prov. Eng.]</mark> <rj><au>Carlyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Metal.)</fld> <def>To cover or line with a mixture
of ore, cinders, etc., as the hearth of a puddling furnace.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fettle</ent><br/
<hw>Fet"tle</hw>, <pos>v. i.</pos> <def>To make preparations; to put
things in order; to do trifling business.</def> <mark>[Prov.
Eng.]</mark> <rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fettle</ent><br/
<hw>Fet"tle</hw>, <pos>n.</pos> <def>The act of fettling.</def>
<mark>[Prov. Eng.]</mark> <rj><au>Wright.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>In fine fettle</b></col>, <cd>in good
spirits.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fettling</ent><br/
<hw>Fet"tling</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<fld>(Metal.)</fld> <def>A mixture of ore, cinders, etc., used to line
the hearth of a puddling furnace.</def> <mark>[Eng.]</mark> <note>[It is
commonly called <altname>fix</altname> in the United States.]</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Pottery)</fld> <def>The operation of shaving or
smoothing the surface of undried clay ware.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fetuous</ent><br/
<hw>Fet"u*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Neat; feat.</def>
<mark>[Obs.]</mark> <rj><au>Herrick.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fetus</ent><br/
<hw>Fe"tus</hw> <pr>(f<emac/"t<ucr/s)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Fetuses</plw>
<pr>(f<emac/"t<ucr/s*<ecr/z)</pr>.</plu> <ety>[L. <ets>fetus</ets>,
<ets>foetus</ets>, a bringing forth, brood, offspring, young ones, cf.
<ets>fetus</ets> fruitful, fructified, that is or was filled with young;
akin to E. <ets>fawn</ets> a deer, <ets>fecundity</ets>,
<ets>felicity</ets>, <ets>feminine</ets>, <ets>female</ets>, and prob.
to <ets>do</ets>, or according to others, to <ets>be</ets>.]</ety>
<def>The young or embryo of a vertebrate animal in the womb, or in the
egg; often restricted to the later stages in the development of
viviparous and oviparous animals. showing the main recognizable features
of the mature animal, <contr>embryo</contr> being applied to the earlier
stages.</def> <altsp>[Written also <asp>f<oe/tus</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fetwah</ent><br/
\'d8<hw>Fet"wah</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Ar.]</ety> <def>A
written decision of a Turkish mufti some point of law; also applied to
opinions by certain other Islamic religious authorities on points of
Islamic law, such as in Iran.</def> <altsp>[Also spelled
<asp>fatwah</asp> and <asp>fatwa</asp>.]</altsp>
<rj><au>Whitworth.</au></rj><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Feu</ent><br/
<hw>Feu</hw> <pr>(f<umac/)</pr>, <pos>n.</pos> <ety>[See 2d
<er>Feud</er>, and <er>Fee</er>.]</ety> <fld>(Scots Law)</fld> <def>A
free and gratuitous right to lands made to one for service to be
performed by him; a tenure where the vassal, in place of military
services, makes a return in grain or in money.</def>
<rj><au>Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feuar</ent><br/
<hw>Feu"ar</hw> <pr>(f<umac/"<etil/r)</pr>, <pos>n.</pos> <ety>[From
Feu.]</ety> <fld>(Scots Law)</fld> <def>One who holds a feu.</def>
<rj><au>Sir W. Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feud</ent><br/
<hw>Feud</hw> <pr>(f<umac/d)</pr>, <pos>n.</pos> <ety>[OE.
<ets>feide</ets>, AS. <ets>f<aemac/h<edh/</ets>, fr. <ets>f<amac/h</ets>
hostile; akin to OHG. <ets>f<emac/hida</ets>, G. <ets>fehde</ets>, Sw.
<ets>fejd</ets>, D. <ets>feide</ets>; prob. akin to E. <ets>fiend</ets>.
See Foe.]</ety> <sn>1.</sn> <def>A combination of kindred to avenge
injuries or affronts, done or offered to any of their blood, on the
offender and all his race.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A contention or quarrel; especially, an inveterate
strife between families, clans, or parties; deadly hatred; contention
satisfied only by bloodshed.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Mutual <qex>feuds</qex> and battles betwixt their several tribes
and kindreds.</q> <rj><qau>Purchas.</qau></rj></p>

<p><syn><b>Syn.</b> -- Affray; fray; broil; contest; dispute;
strife.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feud</ent><br/
<hw>Feud</hw>, <pos>n.</pos> <ety>[LL. <ets>feudum</ets>,
<ets>feodum</ets> prob. of same origin as E. <ets>fief</ets>. See
<er>Fief</er>, <er>Fee</er>.]</ety> <fld>(Law)</fld> <def>A stipendiary
estate in land, held of a superior, by service; the right which a vassal
or tenant had to the lands or other immovable thing of his lord, to use
the same and take the profits thereof hereditarily, rendering to his
superior such duties and services as belong to military tenure, etc.,
the property of the soil always remaining in the lord or superior; a
fief; a fee.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>feudal</ent><br/
<hw>feu"dal</hw> <pr>(f<umac/"d<ait/l)</pr>, <pos>a.</pos> <ety>[F.
<ets>f<eacute/odal</ets>, or LL. <ets>feudalis</ets>.]</ety> <sn>1.</sn>
<def>Of or pertaining to feuds, fiefs, or fees; <as>as, <ex>feudal</ex>
rights or services; <ex>feudal</ex> tenures.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Consisting of, or founded upon, feuds or fiefs;
embracing tenures by military services; <as>as, the <ex>feudal</ex>
system</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feudalism</ent><br/
<hw>Feu"dal*ism</hw> <pr>(f<umac/"d<ait/l*<icr/z'm)</pr>, <pos>n.</pos>
<ety>[Cf. F. <ets>f<eacute/odalisme</ets>.]</ety> <def>The feudal
system; a system by which the holding of estates in land is made
dependent upon an obligation to render military service to the king or
feudal superior; feudal principles and usages.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>feudalist</ent><br/
<hw>feu"dal*ist</hw>, <pos>n.</pos> <def>An upholder of
feudalism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feudality</ent><br/
<hw>Feu*dal"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>f<eacute/odalit<eacute/</ets>.]</ety> <def>The state or quality of
being feudal; feudal form or constitution.</def>
<rj><au>Burke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feudalization</ent><br/
<hw>Feu`dal*i*za"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
reducing to feudal tenure.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feudalize</ent><br/
<hw>Feu"dal*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Feudalized</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Feudalizing</conjf> <pr>(?)</pr>.]</vmorph> <def>To
reduce to a feudal tenure; to conform to feudalism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feudally</ent><br/
<hw>Feu"dal*ly</hw>, <pos>adv.</pos> <def>In a feudal manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feudary</ent><br/
<hw>Feu"da*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[LL.
<ets>feudarius</ets>, fr. <ets>feudum</ets>. See 2d
<er>Feud</er>.]</ety> <def>Held by, or pertaining to, feudal
tenure.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feudary</ent><br/
<hw>Feu"da*ry</hw>, <pos>n.</pos> <sn>1.</sn> <def>A tenant who holds
his lands by feudal service; a feudatory.</def>
<rj><au>Foxe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A feodary. See <er>Feodary</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feudatary</ent><br/
<hw>Feu"da*ta*ry</hw> <pr>(?)</pr>, <pos>a. & n.</pos> <ety>[LL.
<ets>feudatarius</ets>: cf. F. <ets>feudataire</ets>.]</ety> <def>See
<er>Feudatory</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feudatory</ent><br/
<hw>Feu"da*to*ry</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Feudatories</plw> <pr>(<?/)</pr>.</plu> <def>A tenant or vassal who
held his lands of a superior on condition of feudal service; the tenant
of a feud or fief.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The grantee . . . was styled the <qex>feudatory</qex> or
vassal.</q> <rj><qau>Blackstone.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>[He] had for <qex>feudatories</qex> great princes.</q> <rj><qau>J.
H. Newman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feudatory</ent><br/
<hw>Feu"da*to*ry</hw>, <pos>a.</pos> <def>Held from another on some
conditional tenure; <as>as, a <ex>feudatory</ex> title</as>.</def>
<rj><au>Bacon.</au></rj></p>

<p><ent>Feu de joie</ent><br/
<-- no pos in original = n. -->
\'d8<hw>Feu` de joie"</hw> <pr>(?)</pr>. <ety>[F., lit., fire of joy.]</ety> <def>A fire kindled in a public place in token of joy; a bonfire; a firing of guns in token of joy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feudist</ent><br/
<hw>Feud"ist</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F. <ets>feudiste</ets>.]</ety> <def>A writer on feuds; a person versed in feudal law.</def>  <rj><au>Spelman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feuillants</ent><br/
\'d8<hw>Feu`illants"</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <def>A reformed branch of the Bernardines, founded in 1577 at <xex>Feuillans</xex>, near Toulouse, in France.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feuillemort</ent><br/
<hw>Feuille"mort`</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F. <ets>feuille morte</ets> a dead leaf.]</ety> <def>Having the color of a faded leaf.</def>  <rj><au>Locke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feuilleton</ent><br/
\'d8<hw>Feu`ille*ton"</hw> <pr>(? <or/ ?)</pr>, <pos>n.</pos> <ety>[F., from <ets>feulle</ets> leaf.]</ety> <def>A part of a French newspaper (usually the bottom of the page), devoted to light literature, criticism, etc.; also, the article or tale itself, thus printed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feuilltonist</ent><br/
<hw>Feuill"ton*ist</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>feuilletoniste</ets>.]</ety> <def>A writer of feuilletons.</def>  <rj><au>F. Harrison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>feuter</ent><br/
<hw>feu"ter</hw> <pr>(<?/)</pr>, <pos>v. t.</pos> <ety>[OE. <ets>feutre</ets> rest for a lance, OF. <ets>feutre</ets>, <ets>fautre</ets>, <ets>feltre</ets>, felt, cushion, rest for a lance, fr. LL. <ets>filtrum</ets>, <ets>feltrum</ets>; of German origin, and akin to E. <ets>felt</ets>. See <er>Felt</er>, and cf. <er>Filter</er>.]</ety> <def>To set close; to fix in rest, as a spear.</def>  <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feuterer</ent><br/
<hw>Feu"ter*er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Either fr. G. <ets>f<uum/tterer</ets> feeder, or corrupted fr. OF. <ets>vautrier</ets>, <ets>vaultrier</ets>; fr. vaultre, viautre, a kind of hound, fr. L. <ets>vertragus</ets>, <ets>vertraga</ets>, a greyhound. The last is of Celtic origin.]</ety> <def>A dog keeper.</def> <mark>[Obs.]</mark>  <rj><au>Massinger.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fever</ent><br/
<hw>Fe"ver</hw> <pr>(f<emac/"v<etil/r)</pr>, <pos>n.</pos> <ety>[OE. <ets>fever</ets>, <ets>fefer</ets>, AS. <ets>fefer</ets>, <ets>fefor</ets>, L. <ets>febris</ets>: cf. F. <ets>fi<egrave/vre</ets>.  Cf. <er>Febrile</er>.]</ety> <sn>1.</sn> <fld>(Med.)</fld> <def>A diseased state of the system, marked by increased heat, acceleration of the pulse, and a general derangement of the functions, including usually, thirst and loss of appetite.  Many diseases, of which fever is the most prominent symptom, are denominated <xex>fevers</xex>; <as>as, typhoid <ex>fever</ex>; yellow <ex>fever</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Remitting</xex> fevers subside or abate at intervals; <xex>intermitting</xex> fevers intermit or entirely cease at intervals; <xex>continued</xex> or <xex>continual</xex> fevers neither remit nor intermit.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Excessive excitement of the passions in consequence of strong emotion; a condition of great excitement; <as>as, this quarrel has set my blood in a <ex>fever</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>An envious <qex>fever</qex><br/
Of pale and bloodless emulation.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>After life's fitful <qex>fever</qex> he sleeps well.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Brain fever</b></col>, <col><b>Continued fever</b></col></mcol>, <cd>etc. See under <er>Brain</er>, <er>Continued</er>, etc.</cd> -- <col><b>Fever and ague</b></col>, <cd>a form of fever recurring in paroxysms which are preceded by chills. It is of malarial origin.</cd> -- <col><b>Fever blister</b></col> <fld>(Med.)</fld>, <cd>a blister or vesicle often found about the mouth in febrile states; a variety of herpes.</cd> -- <col><b>Fever bush</b></col> <fld>(Bot.)</fld>, <cd>the wild allspice or spice bush. See <er>Spicewood</er>.</cd> -- <col><b>Fever powder</b></col>. <cd>Same as <er>Jame's powder</er>.</cd> -- <col><b>Fever root</b></col> <fld>(Bot.)</fld>, <cd>an American herb of the genus <gen>Triosteum</gen> (<spn>Triosteum perfoliatum</spn>); -- called also <altname>feverwort</altname> and <altname>horse gentian</altname>.</cd> -- <col><b>Fever sore</b></col>, <cd>a carious ulcer or necrosis.</cd> <au>Miner.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fever</ent><br/
<hw>Fe"ver</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos> <conjf>Fevered</conjf> <pr>(f<emac/"v<etil/rd)</pr>; <pos>p. pr. & vb. n.</pos> <conjf>Fevering</conjf>.]</vmorph> <def>To put into a fever; to affect with fever; <as>as, a <ex>fevered</ex> lip</as>.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The white hand of a lady <qex>fever</qex> thee.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>fevered</ent><br/
<hw>fevered</hw> <pos>adj.</pos> <def>Highly excited; <as>as, a <ex>fevered</ex> imagination</as>.</def><br/
<syn><b>Syn. --</b> feverish.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Feveret</ent><br/
<hw>Fe"ver*et</hw> <pr>(f<emac/"v<etil/r*<ecr/t)</pr>, <pos>n.</pos> <def>A slight fever.</def> <mark>[Obs.]</mark>  <rj><au>Ayliffe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feverfew</ent><br/
<hw>Fe"ver*few</hw> <pr>(f<emac/"v<etil/r*f<umac/)</pr>, <pos>n.</pos> <ety>[AS. <ets>feferfuge</ets>, fr. L. <ets>febrifugia</ets>. See <er>fever</er>, <er>Fugitive</er>, and cf. <er>Febrifuge</er>.]</ety> <fld>(Bot.)</fld> <def>A perennial plant (<spn>Pyrethrum Parthenium</spn>, or <spn>Chrysanthemum Parthenium</spn>) allied to camomile, having finely divided leaves and white blossoms; -- so named from its supposed febrifugal qualities.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feverish</ent><br/
<hw>Fe"ver*ish</hw>, <pos>a.</pos> <sn>1.</sn> <def>Having a fever; suffering from, or affected with, a moderate degree of fever; showing increased heat and thirst; <as>as, the patient is <ex>feverish</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Indicating, or pertaining to, fever; characteristic of a fever; <as>as, <ex>feverish</ex> symptoms</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Hot; sultry.</def> <ldquo/The <xex>feverish</xex> north.<rdquo/  <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Disordered as by fever; excited; restless; <as>as, the <ex>feverish</ex> condition of the commercial world</as>.</def><br/
<syn><b>Syn. --</b> fevered.</syn><br/
[<source>1913 Webster</source>]</p>

<p><q>Strive to keep up a frail and <qex>feverish</qex> being.</q> <rj><qau>Milton.</qau></rj></p>

<p>-- <wordforms><wf>Fe"ver*ish*ly</wf>, <pos>adv.</pos> -- <wf>Fe"ver*ish*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feverous</ent><br/
<hw>Fe"ver*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf.F. <ets>fi<eacute/vreux</ets>.]</ety> <sn>1.</sn> <def>Affected with fever or ague; feverish.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His heart, love's <qex>feverous</qex> citadel.</q> <rj><qau>Keats.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Pertaining to, or having the nature of, fever; <as>as, a <ex>feverous</ex> pulse</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>All maladies . . . all <qex>feverous</qex> kinds.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Having the tendency to produce fever; <as>as, a <ex>feverous</ex> disposition of the year</as>.</def> <mark>[R.]</mark>  <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feverously</ent><br/
<hw>Fe"ver*ous*ly</hw>, <pos>adv.</pos> <def>Feverishly.</def> <mark>[Obs.]</mark>  <rj><au>Donne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feverwort</ent><br/
<hw>Fe"ver*wort`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See <cref>Fever root</cref>, under <er>Fever</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fevery</ent><br/
<hw>Fe"ver*y</hw> <pr>(f<emac/"v<etil/r*<ycr/)</pr>, <pos>a.</pos> <def>Feverish.</def> <mark>[Obs.]</mark>  <rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Few</ent><br/
<hw>Few</hw> <pr>(f<umac/)</pr>, <pos>a.</pos> <amorph>[<pos>Compar.</pos> <adjf>Fewer</adjf> <pr>(f<umac/"<etil/r)</pr>; <pos>superl.</pos> <adjf>Fewest</adjf>.]</amorph> <ety>[OE. <ets>fewe</ets>, <ets>feawe</ets>, AS. <ets>fe<aacute/</ets>, pl. <ets>fe<aacute/we</ets>; akin to OS. <ets>f<amac/h</ets>, OHG. <ets>f<omac/</ets> <ets>fao</ets>, Icel. <ets>f<amac/r</ets>, Sw. <ets>f<aring/</ets>, pl., Dan. <ets>faa</ets>, pl., Goth. <ets>faus</ets>, L. <ets>paucus</ets>, cf. Gr. <grk>pay^ros</grk>.  Cf. <er>Paucity</er>.]</ety> <def>Not many; small, limited, or confined in number; -- indicating a small portion of units or individuals constituting a whole; often, by ellipsis of a noun, a few people.</def> <ldquo/Are not my days <xex>few</xex>?<rdquo/  <rj><au>Job x. 20.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Few</qex> know and <qex>fewer</qex> care.</q> <rj><qau>Proverb.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Few</xex> is often used partitively; as, <xex>few</xex> of them.</note><br/
[<source>1913 Webster</source>]</p>

<cs><p><col><b>A few</b></col>, <cd>a small number.</cd> -- <col><b>In few</b></col>, <cd>in a few words; briefly.</cd>  <rj><au>Shak.</au></rj></p>

<p>-- <col><b>No few</b></col>, <cd>not few; more than a few; many.</cd>  <rj><au>Cowper.</au></rj></p>

<p>-- <col><b>The few</b></col>, <cd>the minority; -- opposed to <xex>the many</xex> or <xex>the majority</xex>.</cd><br/
[<source>1913 Webster</source>]</p></cs>

<p><ent>Fewel</ent><br/
<hw>Fe"wel</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See <er>Fuel</er>.]</ety> <def>Fuel.</def> <mark>[Obs.]</mark>  <rj><au>Hooker.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fewmet</ent><br/
<hw>Few"met</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See <er>Fumet</er>.</def> <mark>[Obs.]</mark>  <rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fewness</ent><br/
<hw>Few"ness</hw>, <pos>n.</pos> <sn>1.</sn> <def>The state of being few; smallness of number; paucity.</def>  <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Brevity; conciseness.</def> <mark>[Obs.]</mark>  <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fey</ent><br/
<hw>Fey</hw> <pr>(f<amac/)</pr>, <pos>a.</pos> <ety>[AS. <ets>f<aemac/ga</ets>, Icel. <ets>feigr</ets>, OHG. <ets>feigi</ets>.]</ety> <def>Fated; doomed.</def> <mark>[Old Eng. & Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fey</ent><br/
<hw>Fey</hw> <pr>(f<amac/)</pr>, <pos>n.</pos> <ety>[See <er>Fay</er> faith.]</ety> <def>Faith.</def> <mark>[Obs.]</mark>  <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fey</ent><br/
<hw>Fey</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Cf. <er>Feague</er>.]</ety> <def>To cleanse; to clean out.</def> <mark>[Obs.]</mark>  <rj><au>Tusser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feyne</ent><br/
<hw>Feyne</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To feign.</def> <mark>[Obs.]</mark>  <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Feyre</ent><br/
<hw>Feyre</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A fair or market.</def> <mark>[Obs.]</mark>  <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fez</ent><br/
<hw>Fez</hw> <pr>(f<ecr/z)</pr>, <pos>n.</pos> <ety>[F., fr. the town of <etsep>Fez</etsep> in Morocco.]</ety> <def>A felt or cloth cap, usually red and having a tassel, -- a variety of the tarboosh. See <er>Tarboosh</er>.</def>  <rj><au>B. Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>FHLMC</ent><br/
<hw>FHLMC</hw> <pos>n.</pos> <ety>[acronym from <ets>F</ets>ederal <ets>H</ets>ome <ets>L</ets>oan <ets>M</ets>ortgage <ets>C</ets>orporation.]</ety> <def>a corporation authorized by Congress to provide a secondary market for residential mortgages.  It is called <altname>Freddie Mac</altname> in the jargon of the finance industry.</def> <mark>[acronym]</mark> <br/
<syn><b>Syn. --</b> Federal Home Loan Mortgage Corporation, Freddie Mac.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fiacre</ent><br/
\'d8<hw>Fia"cre</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety> <def>A kind of French hackney coach.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fiance</ent><br/
<hw>Fi"ance</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[F. <ets>fiancer</ets>. See <er>Affiance</er>.]</ety> <def>To betroth; to affiance.</def> <mark>[Obs.]</mark>  <rj><au>Harmar.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fiance</ent><br/
\'d8<hw>Fi`an`c<eacute/"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety> <def>A betrothed man; the man to whom one is betrothed.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Fiancee</ent><br/
\'d8<hw>Fi`an`c<eacute/e"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety> <def>A betrothed woman; the woman to whom one is betrothed.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Fiants</ent><br/
<hw>Fi"ants</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>fiente</ets> dung.]</ety> <def>The dung of the fox, wolf, boar, or badger.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fiar</ent><br/
<hw>Fi"ar</hw> <pr>(? <or/ ?)</pr>, <pos>n.</pos> <ety>[See <er>Feuar</er>.]</ety> <sn>1.</sn> <fld>(Scots Law)</fld> <def>One in whom the property of an estate is vested, subject to the estate of a life renter.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I am <qex>fiar</qex> of the lands; she a life renter.</q> <rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <pluf>pl.</pluf> <def>The price of grain, as legally fixed, in the counties of Scotland, for the current year.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fiasco</ent><br/
\'d8<hw>Fi*as"co</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it> <plw>Fiascoes</plw> <pr>(#)</pr>.</plu> <ety>[It.]</ety> <def>A complete or ridiculous failure, esp. of a musical performance, or of any pretentious undertaking.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fiat</ent><br/
<hw>Fi"at</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., let it be done, 3d pers. sing., subj. pres., fr. <ets>fieri</ets>, used as pass. of <ets>facere</ets> to make.  Cf. <er>Be</er>.]</ety> <sn>1.</sn> <def>An authoritative command or order to do something; an effectual decree.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His <qex>fiat</qex> laid the corner stone.</q> <rj><qau>Willis.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Eng. Law)</fld> <sd>(a)</sd> <def>A warrant of a judge for certain processes.</def> <sd>(b)</sd> <def>An authority for certain proceedings given by the Lord Chancellor's signature.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fiat money</b></col>, <cd>irredeemable paper currency, not resting on a specie basis, but deriving its purchasing power from the declaratory fiat of the government issuing it.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fiaunt</ent><br/
<hw>Fi*aunt"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Commission; fiat; order; decree.</def> <mark>[Obs.]</mark>  <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fib</ent><br/
<hw>Fib</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Prob. fr. <ets>fable</ets>; cf. Prov. E. <ets>fibble-fabble</ets> nonsense.]</ety> <def>A falsehood; a lie; -- used euphemistically.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They are very serious; they don't tell <qex>fibs</qex>.</q> <rj><qau>H. James.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fib</ent><br/
<hw>Fib</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos> <conjf>Fibbed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos> <conjf>Fibbing</conjf> <pr>(?)</pr>.]</vmorph> <def>To speak falsely.</def> <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fib</ent><br/
<hw>Fib</hw>, <pos>v. t.</pos> <def>To tell a fib to.</def> <mark>[R.]</mark>  <rj><au>De Quincey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fibber</ent><br/
<hw>Fib"ber</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who tells fibs.</def></p>

<p><ent>Fibre</ent><br/
<ent>Fiber</ent><br/
<mhw>{ <hw>Fi"ber</hw>, <hw>Fi"bre</hw>  }</mhw>, <pr>(<?/)</pr>, <pos>n.</pos> <ety>[F. <ets>fibre</ets>, L. <ets>fibra</ets>.]</ety> <sn>1.</sn> <def>One of the delicate, threadlike portions of which the tissues of plants and animals are in part constituted; <as>as, the <ex>fiber</ex> of flax or of muscle</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Any fine, slender thread, or threadlike substance; <as>as, a <ex>fiber</ex> of spun glass</as>; especially, one of the slender rootlets of a plant.</def> <wns>[wns=1]</wns><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>the inherent complex of attributes that determine a person's moral and ethical actions and reactions; sinew; strength; toughness; <as>as, a man of real <ex>fiber</ex></as>.</def> <wns>[wns=2]</wns><br/
<syn><b>Syn. --</b> character, fibre.</syn><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><q>Yet had no <qex>fibers</qex> in him, nor no force.</q> <rj><qau>Chapman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A general name for the raw material, such as cotton, flax, hemp, etc., used in textile manufactures.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Nutrition)</fld> <def>that portion of food composed of carbohydrates which are completely or partly indigestible, such as cellulose or pectin; it may be in an insoluble or a soluble form.  It provides bulk to the solid waste and stimulates peristalsis in the intestine.  It is found especially in grains, fruits, and vegetables.  There is some medical evidence which indicates that diets high in fiber reduce the risk of colon cancer and reduce cholesterol levels in the blood.  It is also called <altname>dietary fiber</altname>, <altname>roughage</altname>, or <altname>bulk</altname>.</def><br/
[<source>PJC</source>]</p>

<p><sn>6.</sn> <def>a leatherlike material made by compressing layers of paper or cloth.</def> <wns>[wns=3]</wns><br/
<syn><b>Syn. --</b> fibre, vulcanized fiber.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><cs><col><b>Fiber gun</b></col>, <cd>a kind of steam gun for converting, wood, straw, etc., into fiber. The material is shut up in the gun with steam, air, or gas at a very high pressure which is afterward relieved suddenly by letting a lid at the muzzle fly open, when the rapid expansion separates the fibers.</cd> -- <col><b>Fiber plants</b></col> <fld>(Bot.)</fld>, <cd>plants capable of yielding fiber useful in the arts, as hemp, flax, ramie, agave, etc.</cd></cs></p>

<p><ent>fiberboard</ent><br/
<hw>fiberboard</hw> <pos>n.</pos> <def>a type of wallboard composed of wood chips or shavings bonded together with resin and compressed into rigid sheets, calle also <altname>particle board</altname>.</def><br/
<syn><b>Syn. --</b> fibreboard, particle board.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fibred</ent><br/
<ent>Fibered</ent><br/
<mhw>{ <hw>Fi"bered</hw>, <hw>Fi"bred</hw>  }</mhw> <pr>(?)</pr>, <pos>a.</pos> <def>Having fibers; made up of fibers.</def></p>

<p><ent>Fibre-faced</ent><br/
<ent>Fiber-faced</ent><br/
<mhw>{ <hw>Fi"ber-faced`</hw>, <hw>Fi"bre-faced`</hw>  }</mhw> <pr>(?)</pr>, <pos>a.</pos> <def>Having a visible fiber embodied in the surface of; -- applied esp. to a kind of paper for checks, drafts, etc.</def></p>

<p><ent>fiberglass</ent><br/
<hw>fiberglass</hw> <pos>n.</pos> <def>a material made of fine glass fibers woven into a fabric-like form, and used in applications requiring heat resistance; it is also embedded in resins to make a pliable but strong composite material used as the main component of fishing rods and boat hulls, and replacing the sheet metal in some automobile bodies.</def> <altsp>[Also spelled <asp>fibreglass</asp>, mostly British in usage.]</altsp><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fibreless</ent><br/
<ent>Fiberless</ent><br/
<mhw>{ <hw>Fi"ber*less</hw>, <hw>Fi"bre*less</hw>  }</mhw>, <pos>a.</pos> <def>Having no fibers; destitute of fibers or fiber.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fiber optics</ent><br/
<hw>Fi"ber op`tics</hw>, <pr>(<?/)</pr>, <pos>n.</pos> <def>that branch of optics which studies the transmission of light through thin transparent fibers.</def> <note>Light transmission through optical fibers has become an important means of data and telephone signal transmission, in some areas superseding the carrying of vioce and data signals through electrical pulses over copper wire.  It is also used for directly carrying images from otherwise inaccessible locations, as from inside the body, for medical procedures.  Light transmission via fiber optics for data transmission uses an <er>optical fiber</er> made of specially purified glass with low light absorption characteristics.</note><br/
[<source>PJC</source>]</p>

<p><ent>fiberscope</ent><br/
<hw>fi"ber*scope</hw> <pos>n.</pos> <fld>(Med.)</fld> <def>an instrument used to examine internal organs.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>fibre</ent><br/
<hw>fibre</hw> <pos>n.</pos> <def>Same as <er>fiber</er>.</def> <mark>[Mostly British usage]</mark> <br/
[<source>WordNet 1.5</source>]</p>

<p><ent>fibreboard</ent><br/
<hw>fibreboard</hw> <pos>n.</pos> <def>Same as <er>fiberboard</er>.</def> <mark>[mostly British usage]</mark> <br/
[<source>WordNet 1.5</source>]</p>

<p><ent>fibreglass</ent><br/
<hw>fibreglass</hw> <pos>n.</pos> <def>Same as <er>fiberglass</er>.</def> <mark>[mostly British usage]</mark> <br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fibriform</ent><br/
<hw>Fi"bri*form</hw> <pr>(? <or/ ?)</pr>, <pos>a.</pos> <ety>[L. <ets>fibra</ets> a fiber + <ets>-form</ets>.]</ety> <fld>(Biol.)</fld> <def>Having the form of a fiber or fibers; resembling a fiber.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fibril</ent><br/
<hw>Fi"bril</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>fibrille</ets>, dim. of <ets>fibre</ets>, L. <ets>fibra</ets>.]</ety> <def>A small fiber; the branch of a fiber; a very slender thread; a fibrilla.</def>  <rj><au>Cheyne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fibrilla</ent><br/
\'d8<hw>fi*bril"la</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it> <plw>fibrill<ae/</plw> <pr>(#)</pr>.</plu> <ety>[NL. See <er>Fibril</er>.]</ety> <def>A minute thread or fiber, as one of the fibrous elements of a muscular fiber; a fibril.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fibrillar</ent><br/
<hw>Fi"bril*lar</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining to fibrils or fibers; <as>as, <ex>fibrillar</ex> twitchings</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fibrillary</ent><br/
<hw>Fi"bril*la*ry</hw> <pr>(? <or/ ?)</pr>, <pos>a.</pos> <def>Of of pertaining to fibrils.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fibrillated</ent><br/
<hw>Fi"bril*la`ted</hw> <pr>(? <or/ ?)</pr>, <pos>a.</pos> <def>Furnished with fibrils; fringed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fibrillation</ent><br/
<hw>Fi`bril*la"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state of being reduced to fibers.</def>  <rj><au>Carpenter.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fibrillose</ent><br/
<hw>Fi*bril"lose</hw> <pr>(? <or/ ?)</pr>, <pos>a.</pos> <def>Covered with hairlike appendages, as the under surface of some lichens; also, composed of little strings or fibers; <as>as, <ex>fibrillose</ex> appendages</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 556 --></p>

<p><ent>Fibrillous</ent><br/
<hw>Fi*bril"lous</hw> <pr>(? <or/ ?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>fibraleux</ets>.]</ety> <def>Pertaining to, or composed of,
fibers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fibrin</ent><br/
<hw>Fi"brin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>fibrine</ets>. See <er>Fiber</er>.]</ety> <fld>(Physiol.
Chem.)</fld> <sn>1.</sn> <def>A white, albuminous, fibrous substance,
formed in the coagulation of the blood either by decomposition of
fibrinogen, or from the union of fibrinogen and paraglobulin which exist
separately in the blood. It is insoluble in water, but is readily
digestible in gastric and pancreatic juice.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The white, albuminous mass remaining after washing
lean beef or other meat with water until all coloring matter is removed;
the fibrous portion of the muscle tissue; flesh fibrin.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>An albuminous body, resembling animal fibrin in
composition, found in cereal grains and similar seeds; vegetable
fibrin.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fibrin factors</b></col> <fld>(Physiol.)</fld>, <cd>the
albuminous bodies, paraglobulin and fibrinigen in the blood, which, by
the action of the fibrin ferment, are changed into fibrin, in
coagulation.</cd> -- <col><b>Fibrin ferment</b></col> <fld>(Physiol.
Chem.)</fld>, <cd>a ferment which makes its appearance in the blood
shortly after it is shed, and is supposed to be the active agent in
causing coagulation of the blood, with formation of
fibrin.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fibrination</ent><br/
<hw>Fi`bri*na"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Med.)</fld>
<def>The state of acquiring or having an excess of fibrin.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fibrine</ent><br/
<hw>Fi"brine</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Belonging to the
fibers of plants.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fibrinogen</ent><br/
<hw>Fi*brin"o*gen</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Fibrin</ets> + <ets>-gen</ets>.]</ety> <fld>(Physiol.
Chem.)</fld> <def>An albuminous substance existing in the blood, and in
other animal fluids, which either alone or with fibrinoplastin or
paraglobulin forms fibrin, and thus causes coagulation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fibrinogenous</ent><br/
<hw>Fi`bri*nog"e*nous</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Physiol.
Chem.)</fld> <def>Possessed of properties similar to fibrinogen; capable
of forming fibrin.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fibrinoplastic</ent><br/
<hw>Fi`bri*no*plas"tic</hw> <pr>(?)</pr>, <pos>a.</pos>
<fld>(Physiol.Chem.)</fld> <def>Like fibrinoplastin; capable of forming
fibrin when brought in contact with fibrinogen.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fibrinoplastin</ent><br/
<hw>Fi`bri*no*plas"tin</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Fibrin</ets> + Gr. <?/ to form, mold.]</ety>
<fld>(Physiol.Chem.)</fld> <def>An albuminous substance, existing in the
blood, which in combination with fibrinogen forms fibrin; -- called also
<altname>paraglobulin</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fibrinous</ent><br/
<hw>Fi"bri*nous</hw> <pr>(? <or/ ?; 277)</pr>, <pos>a.</pos>
<def>Having, or partaking of the properties of, fibrin; <as>as,
<ex>fibrious</ex> exudation</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fibrocartilage</ent><br/
<hw>Fi`bro*car"ti*lage</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>fibra</ets> a fiber + E. <ets>cartilage</ets>.]</ety>
<fld>(Anat.)</fld> <def>A kind of cartilage with a fibrous matrix and
approaching fibrous connective tissue in structure.</def> --
<wordforms><wf>Fi`bro*car`ti*lag"i*nous</wf> <pr>(#)</pr>,
<pos>a.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fibrochondrosteal</ent><br/
<hw>Fi`bro*chon*dros"te*al</hw>
<pr>(f<imac/`br<osl/*k<ocr/n*dr<ocr/s"t<esl/*<ait/l)</pr>, <pos>a.</pos>
<ety>[L. <ets>fibra</ets> a fiber + gr. <grk>cho`ndros</grk> cartilage +
<grk>'oste`on</grk> bone.]</ety> <fld>(Anat.)</fld> <def>Partly fibrous,
partly cartilaginous, and partly osseous.</def> <rj><au>St. George
Mivart.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>fibroid</ent><br/
<hw>fi"broid</hw> <pr>(f<imac/"broid)</pr>, <pos>a.</pos> <ety>[L.
<ets>fibra</ets> a fiber + <ets>-oid</ets>.]</ety> <fld>(Med.)</fld>
<def>Resembling or forming fibrous tissue; made up of fibers; <as>as,
<ex>fibroid</ex> tumors</as>.</def> -- <def2><pos>n.</pos> <def>A
fibroid tumor; a fibroma.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fibroid degeneration</b></col>, <cd>a form of
degeneration in which organs or tissues are converted into fibroid
tissue.</cd> -- <col><b>Fibroid phthists</b></col>, <cd>a form of
pulmonary consumption associated with the formation of fibrous tissue in
the lungs, and the gradual atrophy of the lungs, from the pressure due
to the contraction of this tissue.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>fibroin</ent><br/
<hw>fi"bro*in</hw> <pr>(f<imac/"br<osl/*<icr/n <it>or</it>
f<icr/b"r<osl/*<icr/n)</pr>, <pos>n.</pos> <ety>[L. <ets>fibra</ets> a
fiber.]</ety> <fld>(Chem.)</fld> <def>A variety of gelatin; the chief
ingredient of raw silk, extracted as a white amorphous mass.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fibrolite</ent><br/
<hw>Fi"bro*lite</hw> <pr>(? <or/ ?)</pr>, <pos>n.</pos> <ety>[L.
<ets>fibra</ets> a fiber + <ets>-lite</ets>: cf. F.
<ets>fibrolithe</ets>.]</ety> <fld>(Min.)</fld> <def>A silicate of
alumina, of fibrous or columnar structure. It is like andalusite in
composition; -- called also <altname>sillimanite</altname>, and
<altname>bucholzite</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fibroma</ent><br/
\'d8<hw>Fi*bro"ma</hw> <pr>(f<isl/*br<omac/"m<adot/)</pr>, <pos>n.</pos>
<ety>[NL. See <er>Fiber</er>, and <er>-oma</er>.]</ety>
<fld>(Med.)</fld> <def>A tumor consisting mainly of fibrous tissue, or
of same modification of such tissue.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fibrospongiae</ent><br/
\'d8<hw>Fi`bro*spon"gi*<ae/</hw> <pr>(?)</pr>, <pos>prop. n. pl.</pos>
<ety>[NL., fr. L. <ets>fibra</ets> a fiber + <ets>spongia</ets> a
sponge.]</ety> <fld>(Zool.)</fld> <def>An order of sponges having a
fibrous skeleton, including the commercial sponges.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fibrous</ent><br/
<hw>Fi"brous</hw> <pr>(f<imac/"br<ucr/s)</pr>, <pos>a.</pos> <ety>[Cf.
F. <ets>fibreux</ets>.]</ety> <def>Containing, or consisting of, fibers;
<as>as, the <ex>fibrous</ex> coat of the cocoanut; the <ex>fibrous</ex>
roots of grasses.</as></def> -- <wordforms><wf>Fi"brous*ness</wf>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fibrovascular</ent><br/
<hw>Fi`bro*vas"cu*lar</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>fibra</ets> a fiber + E. <ets>vascular</ets>.]</ety>
<fld>(Bot.)</fld> <def>Containing woody fiber and ducts, as the stems of
all flowering plants and ferns; -- opposed to
<xex>cellular</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fibster</ent><br/
<hw>Fib"ster</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who tells
fibs.</def> <mark>[Jocular]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fibula</ent><br/
\'d8<hw>fib"u*la</hw> <pr>(f<icr/b"<usl/*l<adot/)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>fibul<ae/</plw> <pr>(#)</pr>.</plu> <ety>[L.,
clasp, buckle.]</ety> <sn>1.</sn> <def>A brooch, clasp, or
buckle.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Mere <qex>fibul<ae/</qex>, without a robe to clasp.</q>
<rj><qau>Wordsworth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Anat.)</fld> <def>The outer and usually the smaller
of the two bones of the leg, or hind limb, below the knee.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Surg.)</fld> <def>A needle for sewing up
wounds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fibular</ent><br/
<hw>Fib"u*lar</hw> <pr>(f<icr/b"<usl/*l<etil/r)</pr>, <pos>a.</pos>
<def>Pertaining to the fibula.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fibulare</ent><br/
\'d8<hw>Fib`u*la"re</hw> <pr>(f<icr/b`<usl/*l<amac/"r<esl/)</pr>,
<pos>n.</pos>; <plu><it>pl.</it> <plw>Fibularia</plw>
<pr>(#)</pr>.</plu> <ety>[NL. See <er>Fibula</er>.]</ety>
<fld>(Anat.)</fld> <def>The bone or cartilage of the tarsus, which
articulates with the fibula, and corresponds to the calcaneum in man and
most mammals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fice</ent><br/
<hw>Fice</hw> <pr>(f<imac/s)</pr>, <pos>n.</pos> <def>A small dog; --
written also <asp>fise</asp>, <asp>fyce</asp>, <asp>fiste</asp>,
etc.</def> <mark>[Southern U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fiche</ent><br/
<hw>Fi*ch<eacute/</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Her.)</fld>
<def>See <er>Fitch<eacute/</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fichtelite</ent><br/
<hw>Fich"tel*ite</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Min.)</fld>
<def>A white crystallized mineral resin from the Fichtelgebirge,
Bavaria.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fichu</ent><br/
<hw>Fich"u</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.,
neckerchief.]</ety> <def>A light cape, usually of lace, worn by women,
to cover the neck and throat, and extending to the shoulders.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fickle</ent><br/
<hw>Fic"kle</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OE. <ets>fikel</ets>
untrustworthy, deceitful, AS. <ets>ficol</ets>, fr. <ets>fic</ets>,
<ets>gefic</ets>, fraud, deceit; cf. <ets>f<amac/cen</ets> deceit, OS.
<ets>f<?/kn</ets>, OHG. <ets>feichan</ets>, Icel. <ets>feikn</ets>
portent. Cf. <er>Fidget</er>.]</ety> <def>Not fixed or firm; liable to
change; unstable; of a changeable mind; not firm in opinion or purpose;
inconstant; capricious; <as>as, Fortune's <ex>fickle</ex>
wheel</as>.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>They know how <qex>fickle</qex> common lovers are.</q>
<rj><qau>Dryden.</qau></rj></p>

<p><syn><b>Syn.</b> -- Wavering; irresolute; unsettled; vacillating;
unstable; inconsonant; unsteady; variable; mutable; changeful;
capricious; veering; shifting.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fickleness</ent><br/
<hw>Fic"kle*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The quality of
being fickle; instability; inconsonancy.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fickly</ent><br/
<hw>Fic"kly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a fickle
manner.</def> <mark>[Obs.]</mark> <rj><au>Pepys.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fico</ent><br/
\'d8<hw>Fi"co</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Ficoes</plw> <pr>(#)</pr>.</plu> <ety>[It., a fig, fr.
L.<ets>ficus</ets>. See <er>Fig</er>.]</ety> <def>A fig; an
insignificant trifle, no more than the snap of one's thumb; a sign of
contempt made by the fingers, expressing. <xex>A fig for
you</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Steal! foh, a <qex>fico</qex> for the phrase.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fictile</ent><br/
<hw>Fic"tile</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>fictilis</ets>. See <er>Fiction</er>.]</ety> <def>Molded, or
capable of being molded, into form by art; relating to pottery or to
molding in any soft material.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Fictile</qex> earth is more fragile than crude earth.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The earliest specimens of Italian <qex>fictile</qex> art.</q>
<rj><qau>C. Wordsworth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fictile ware</b></col>, <cd>ware made of any material
which is molded or shaped while soft; hence, pottery of any
sort.</cd></cs></p>

<p>-- <wordforms><wf>Fic"tile*ness</wf>, <pos>n.</pos> --
<wf>Fic*til"i*ty</wf> <pr>(#)</pr>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fiction</ent><br/
<hw>Fic"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>fiction</ets>, L. <ets>fictio</ets>, fr. <ets>fingere</ets>,
<ets>fictum</ets> to form, shape, invent, feign. See
<er>Feign</er>.]</ety> <sn>1.</sn> <def>The act of feigning, inventing,
or imagining; <as>as, by a mere <ex>fiction</ex> of the mind</as>.</def>
<rj><au>Bp. Stillingfleet.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is feigned, invented, or imagined;
especially, a feigned or invented story, whether oral or written. Hence:
A story told in order to deceive; a fabrication; -- opposed to
<xex>fact</xex>, or <xex>reality</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>fiction</qex> of those golden apples kept by a
dragon.</q> <rj><qau>Sir W. Raleigh.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>When it could no longer be denied that her flight had been
voluntary, numerous <qex>fictions</qex> were invented to account for
it.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Fictitious literature; comprehensively, all works of
imagination; specifically, novels and romances.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The office of <qex>fiction</qex> as a vehicle of instruction and
moral elevation has been recognized by most if not all great
educators.</q> <rj><qau>Dict. of Education.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Law)</fld> <def>An assumption of a possible thing
as a fact, irrespective of the question of its truth.</def>
<rj><au>Wharton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Any like assumption made for convenience, as for
passing more rapidly over what is not disputed, and arriving at points
really at issue.</def></p>

<p><syn><b>Syn.</b> -- Fabrication; invention; fable; falsehood.</syn>
<usage> -- <er>Fiction</er>, <er>Fabrication</er>. <xex>Fiction</xex> is
opposed to what is real; <xex>fabrication</xex> to what is true.
<xex>Fiction</xex> is designed commonly to amuse, and sometimes to
instruct; a <xex>fabrication</xex> is always intended to mislead and
deceive. In the novels of Sir Walter Scott we have <xex>fiction</xex> of
the highest order. The poems of Ossian, so called, were chiefly
<xex>fabrications</xex> by Macpherson.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fictional</ent><br/
<hw>Fic"tion*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to, or
characterized by, fiction; fictitious;
romantic.</def><ldquo/<xex>Fictional</xex> rather than
historical.<rdquo/ <rj><au>Latham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fictionist</ent><br/
<hw>Fic"tion*ist</hw>, <pos>n.</pos> <def>A writer of fiction.</def>
<mark>[R.]</mark> <rj><au>Lamb.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fictious</ent><br/
<hw>Fic"tious</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Fictitious.</def>
<mark>[R.]</mark> <rj><au>Prior.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fictitious</ent><br/
<hw>Fic*ti"tious</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>fictitius</ets>. See <er>Fiction</er>.]</ety> <def>Feigned;
imaginary; not real; fabulous; counterfeit; false; not genuine; <as>as,
<ex>fictitious</ex> fame</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The human persons are as <qex>fictitious</qex> as the airy
ones.</q> <rj><qau>Pope.</qau></rj></p>

<p>-- <wordforms><wf>Fic*ti"tious*ly</wf>, <pos>adv.</pos> --
<wf>Fic*ti"tious*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fictive</ent><br/
<hw>Fic"tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>fictif</ets>.]</ety> <def>Feigned; counterfeit.</def> <ldquo/The
fount of <xex>fictive</xex> tears.<rdquo/
<rj><au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fictor</ent><br/
<hw>Fic"tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.]</ety> <def>An
artist who models or forms statues and reliefs in any plastic
material.</def> <mark>[R.]</mark> <rj><au>Elmes.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ficus</ent><br/
\'d8<hw>Fi"cus</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., a fig.]</ety>
<def>A genus of trees or shrubs, one species of which (<spn>F.
Carica</spn>) produces the figs of commerce; the fig tree.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <spn>Ficus Indica</spn> is the banyan tree; <spn>F.
religiosa</spn>, the peepul tree; <spn>F. elastica</spn>, the
India-rubber tree.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fid</ent><br/
<hw>Fid</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Prov. E. <ets>fid</ets> a
small, thick lump.]</ety> <sn>1.</sn> <fld>(Naut.)</fld> <def>A square
bar of wood or iron, used to support the topmast, being passed through a
hole or mortise at its heel, and resting on the trestle trees.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A wooden or metal bar or pin, used to support or
steady anything.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A pin of hard wood, tapering to a point, used to
open the strands of a rope in splicing.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ There are <xex>hand fids</xex> and <xex>standing
fids</xex> (which are larger than the others, and stand upon a flat
base). An iron implement for this purpose is called a <xex>marline
spike</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Mil.)</fld> <def>A block of wood used in mounting
and dismounting heavy guns.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fidalgo</ent><br/
<hw>Fi*dal"go</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pg. See
<er>Hidalgo</er>.]</ety> <def>The lowest title of nobility in Portugal,
corresponding to that of <xex>Hidalgo</xex> in Spain.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fiddle</ent><br/
<hw>Fid"dle</hw> <pr>(f<icr/d"d'l)</pr>, <pos>n.</pos> <ety>[OE.
<ets>fidele</ets>, <ets>fithele</ets>, AS. <ets>fi<edh/ele</ets>; akin
to D. <ets>vedel</ets>, OHG. <ets>fidula</ets>, G. <ets>fiedel</ets>,
Icel. <ets>fi<edh/la</ets>, and perh. to E. <ets>viol</ets>. Cf.
<er>Viol</er>.]</ety> <sn>1.</sn> <fld>(Mus.)</fld> <def>A stringed
instrument of music played with a bow; a violin; a kit.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>A kind of dock (<spn>Rumex
pulcher</spn>) with fiddle-shaped leaves; -- called also <altname>fiddle
dock</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Naut.)</fld> <def>A rack or frame of bars connected
by strings, to keep table furniture in place on the cabin table in bad
weather.</def> <rj><au>Ham. Nav. Encyc.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fiddle beetle</b></col> <fld>(Zool.)</fld>, <cd>a
Japanese carabid beetle (<spn>Damaster blaptoides</spn>); -- so called
from the form of the body.</cd> -- <col><b>Fiddle block</b></col>
<fld>(Naut.)</fld>, <cd>a long tackle block having two sheaves of
different diameters in the same plane, instead of side by side as in a
common double block.</cd> <au>Knight.</au> -- <col><b>Fiddle
bow</b></col>, <cd>fiddlestick.</cd> -- <col><b>Fiddle fish</b></col>
<fld>(Zool.)</fld>, <cd>the angel fish.</cd> -- <col><b>Fiddle
head</b></col>, <cd>See <er>fiddle head</er> in the vocabulary.</cd> --
<col><b>Fiddle pattern</b></col>, <cd>a form of the handles of spoons,
forks, etc., somewhat like a violin.</cd> -- <col><b>Scotch
fiddle</b></col>, the itch. (<mark>Low</mark>) -- <mcol><col><b>To play
first fiddle</b></col>, <it>or</it> <col><b>To play second
fiddle</b></col></mcol>, <cd>to take a leading or a subordinate
part.</cd> <mark>[Colloq.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fiddle</ent><br/
<hw>Fid"dle</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Fiddled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Fiddling</conjf> <pr>(?)</pr>.]</vmorph> <sn>1.</sn> <def>To play
on a fiddle.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Themistocles . . . said he could not <qex>fiddle</qex>, but he
could make a small town a great city.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To keep the hands and fingers actively moving as a
fiddler does; to move the hands and fingers restlessy or in busy
idleness; to trifle.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Talking, and <qex>fiddling</qex> with their hats and feathers.</q>
<rj><qau>Pepys.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fiddle</ent><br/
<hw>Fid"dle</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To play (a tune) on
a fiddle.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>fiddledeedee</ent><br/
<hw>fid"dle*dee*dee`</hw> <pr>(?)</pr>, <pos>interj.</pos> <def>An
exclamatory word or phrase, equivalent to
<altname>nonsense</altname>!</def> <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fm</ent><br/
<hw>Fm</hw> <pos>prop. n.</pos> <def>the symbol for the element
<er>Fermium</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>fiddle-faddle</ent><br/
<hw>fid"dle-fad`dle</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A trifle;
trifling talk; nonsense.</def> <mark>[Colloq.]</mark>
<rj><au>Spectator.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>fiddle-faddle</ent><br/
<hw>fid"dle-fad`dle</hw>, <pos>v. i.</pos> <def>To talk nonsense.</def>
<mark>[Colloq.]</mark> <rj><au>Ford.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>fiddlehead</ent><br/
<hw>fid"dle*head`</hw> <pos>n.</pos> <sn>1.</sn> <def>any of several
tall ferns of northern temperate regions having graceful arched fronds
and sporophylls resembling ostrich plumes.</def><br/
<syn><b>Syn. --</b> ostrich fern, shuttlecock fern, <spn>Matteuccia
struthiopteris</spn>, <spn>Pteretis struthiopteris</spn>, <spn>Onoclea
struthiopteris</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>New World fern (<spn>Osmunda cinnamonea</spn>)
having woolly cinnamon-colored spore-bearing fronds in early spring
later surrounded by green fronds, called also <altname>fiddlehead
fern</altname>; the early uncurling fronds are edible, and sometimes
considered as a vegetable delicacy.</def><br/
<syn><b>Syn. --</b> cinnamon fern, fiddlehead fern, <spn>Osmunda
cinnamonea</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>3.</sn> <fld>(Naut.)</fld> <def>an ornament on a ship's bow,
curved like the volute or scroll at the head of a violin. Sometimes it
serves the function of a <er>billhead</er>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>fiddleneck</ent><br/
<hw>fiddleneck</hw> <pos>n.</pos> <def>hairy annual plant (<spn>Phacelia
tanacetifolia</spn>) of California to Mexico with crowded cymes of small
blue to lilac or mauve flowers.</def><br/
<syn><b>Syn. --</b> <spn>Phacelia tanacetifolia</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>fiddle-shaped</ent><br/
<hw>fiddle-shaped</hw> <pos>adj.</pos> <def>shaped like a fiddle; -- of
a leaf shape.</def><br/
<syn><b>Syn. --</b> pandurate, panduriform.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fiddler</ent><br/
<hw>Fid"dler</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS.
<ets>fi<edh/elere</ets>.]</ety> <sn>1.</sn> <def>One who plays on a
fiddle or violin.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>A burrowing crab of the genus
<gen>Gelasimus</gen>, of many species. The male has one claw very much
enlarged, and often holds it in a position similar to that in which a
musician holds a fiddle, hence the name; -- called also <altname>fiddler
crab</altname>, <altname>calling crab</altname>, <altname>soldier
crab</altname>, and <altname>fighting crab</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <def>The common European sandpiper
(<spn>Tringoides hypoleucus</spn>); -- so called because it continually
oscillates its body.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fiddler crab</b></col>. <fld>(Zool.)</fld> <cd>See
<er>Fiddler</er>, <pos>n.</pos>, 2.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fiddle-shaped</ent><br/
<hw>Fid"dle-shaped`</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Bot.)</fld>
<def>Inversely ovate, with a deep hollow on each side.</def>
<rj><au>Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fiddlestick</ent><br/
<hw>Fid"dle*stick`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The bow, strung
with horsehair, used in playing the fiddle; a fiddle bow.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fiddlestring</ent><br/
<hw>Fid"dle*string`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One of the
catgut strings of a fiddle.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fiddlewood</ent><br/
<hw>Fid"dle*wood`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Corrupted fr.
F. bois-<ets>fid<egrave/le</ets>, lit., faithful wood; -- so called from
its durability.]</ety> <def>The wood of several West Indian trees,
mostly of the genus <gen>Citharexylum</gen>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fidejussion</ent><br/
<hw>Fi`de*jus"sion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>fidejussio</ets>, from <ets>fidejubere</ets> to be surety or bail;
<ets>fides</ets> faith + <ets>jubere</ets> to order: cf. F.
<ets>fid<eacute/jussion</ets>.]</ety> <fld>(Civil Law)</fld> <def>The
act or state of being bound as surety for another; suretyship.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fidejussor</ent><br/
<hw>Fi`de*jus"sor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.: cf. F.
<ets>fid<eacute/jusseur</ets>.]</ety> <fld>(Civil Law)</fld> <def>A
surety; one bound for another, conjointly with him; a guarantor.</def>
<rj><au>Blackstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fidelity</ent><br/
<hw>Fi*del"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>fidelitas</ets>: cf. F. <ets>fid<eacute/lit<eacute/</ets>. See
<er>Fealty</er>.]</ety> <def>Faithfulness; adherence to right; careful
and exact observance of duty, or discharge of obligations.</def>
Especially: <sd>(a)</sd> <def>Adherence to a person or party to which
one is bound; loyalty.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Whose courageous <qex>fidelity</qex> was proof to all danger.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The best security for the <qex>fidelity</qex> of men is to make
interest coincide with duty.</q> <rj><qau>A. Hamilton.</qau></rj></p>

<p><sd>(b)</sd> <def>Adherence to the marriage contract.</def>
<sd>(c)</sd> <def>Adherence to truth; veracity; honesty.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The principal thing required in a witness is
<qex>fidelity</qex>.</q> <rj><qau>Hooker.</qau></rj></p>

<p><syn><b>Syn.</b> -- Faithfulness; honesty; integrity; faith; loyalty;
fealty.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fides</ent><br/
\'d8<hw>Fi"des</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., faith.]</ety>
<fld>(Roman Muth.)</fld> <def>Faith personified as a goddess; the
goddess of faith.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fidge</ent><br/
<hw>Fidge</hw> <pr>(f<icr/j)</pr>, <pos>n. & v. i.</pos> <def>See
<er>Fidget</er>.</def> <mark>[R.]</mark> <rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fidget</ent><br/
<hw>Fidg"et</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Fidgeted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Fodgeting</conjf>.]</vmorph> <ety>[From <er>Fidge</er>; cf. OE.
<ets>fiken</ets> to fidget, to flatter, Icel. <ets>fika</ets> to hasten,
Sw. <ets>fika</ets> to hunt after, AS. <ets>befician</ets> to deceive.
Cf. <er>Fickle</er>.]</ety> <def>To move uneasily one way and the other;
to move irregularly, or by fits and starts.</def>
<rj><au>Moore.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fidget</ent><br/
<hw>Fidg"et</hw>, <pos>n.</pos> <sn>1.</sn> <def>Uneasiness;
restlessness.</def> <rj><au>Cowper.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <pluf>pl.</pluf> <def>A general nervous restlessness,
manifested by incessant changes of position; dysphoria.</def>
<rj><au>Dunglison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fidgetiness</ent><br/
<hw>Fidg"et*i*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Quality of
being fidgety.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fidgety</ent><br/
<hw>Fidg"et*y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Restless;
uneasy.</def> <rj><au>Lowell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fidia</ent><br/
\'d8<hw>Fid"i*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., prob. fr. L.
<ets>fidus</ets> trusty.]</ety> <fld>(Zool.)</fld> <def>A genus of small
beetles, of which one species (the grapevine Fidia, <spn>F.
longipes</spn>) is very injurious to vines in America.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fidicinal</ent><br/
<hw>Fi*dic"i*nal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>fidicinus</ets>, fr. <ets>fidicen</ets>, <ets>-inis</ets>, a lute
player.]</ety> <fld>(Mus.)</fld> <def>Of or pertaining to a stringed
instrument.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fiducial</ent><br/
<hw>Fi*du"cial</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>fiducia</ets> trust, confidence; akin to <ets>fides</ets> faith.
See <er>Faith</er>.]</ety> <sn>1.</sn> <def>Having faith or trust;
confident; undoubting; firm.</def> <ldquo/<xex>Fiducial</xex> reliance
on the promises of God.<rdquo/ <rj><au>Hammond.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Having the nature of a trust; fiduciary; <as>as,
<ex>fiducial</ex> power</as>.</def> <rj><au>Spelman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fiducial edge</b></col> <fld>(Astron. & Surv.)</fld>,
<cd>the straight edge of the alidade or ruler along which a straight
line is to be drawn.</cd> -- <mcol><col><b>Fiducial line</b></col>
<it>or</it> <col><b>Fiducial point</b></col></mcol> <fld>(Math. &
Physics.)</fld>, <cd>a line or point of reference, as for setting a
graduated circle or scale used for measurements.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fiducially</ent><br/
<hw>Fi*du"cial*ly</hw>, <pos>adv.</pos> <def>With confidence.</def>
<rj><au>South.</au></rj></p>

<p><ent>Fiduciary</ent><br/
<hw>Fi*du"ci*a*ry</hw> <pr>(? <or/ ?)</pr>, <pos>a.</pos> <ety>[L.
<ets>fiduciarus</ets>, fr. <ets>fiducia</ets>: cf. F.
<ets>fiduciaire</ets>. See <er>Fiducial</er>.]</ety> <sn>1.</sn>
<def>Involving confidence or trust; confident; undoubting; faithful;
firm; <as>as, in a <ex>fiduciary</ex> capacity</as>.</def>
<ldquo/<xex>Fiduciary</xex> obedience.<rdquo/
<rj><au>Howell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Holding, held, or founded, in trust.</def>
<rj><au>Spelman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fiduciary</ent><br/
<hw>Fi*du"ci*a*ry</hw>, <pos>n.</pos> <sn>1.</sn> <def>One who holds a
thing in trust for another; a trustee.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Instrumental to the conveying God's blessing upon those whose
<qex>fiduciaries</qex> they are.</q> <rj><qau>Jer.
Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Theol.)</fld> <def>One who depends for salvation on
faith, without works; an Antinomian.</def>
<rj><au>Hammond.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fie</ent><br/
<hw>Fie</hw> <pr>(?)</pr>, <pos>interj.</pos> <ety>[OE. <ets>fi</ets>;
cf. D. <ets>fif</ets>. G. <ets>pfui</ets>, Icel. <ets>f<?/</ets>, Sw. &
Dan. <ets>fy</ets>, F. <ets>fi</ets>, L. <ets>fi</ets>,
<ets>phy</ets>.]</ety> <def>An exclamation denoting contempt or dislike.
See <er>Fy</er>.</def> <rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fief</ent><br/
<hw>Fief</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>fief</ets>; of
German origin, and the same word as E. <ets>fee</ets>. See <er>Fee</er>,
and cf. <er>Feud</er>, a tief.]</ety> <fld>(Law)</fld> <def>An estate
held of a superior on condition of military service; a fee; a feud. See
under <er>Benefice</er>, <pos>n.</pos>, 2.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 557 --></p>

<p><ent>field</ent><br/
<hw>field</hw> <pr>(f<emac/ld)</pr>, <pos>n.</pos> <ety>[OE.
<ets>feld</ets>, <ets>fild</ets>, AS. <ets>feld</ets>; akin to D.
<ets>veld</ets>, G. <ets>feld</ets>, Sw. <ets>f<aum/lt</ets>, Dan.
<ets>felt</ets>, Icel. <ets>fold</ets> field of grass, AS.
<ets>folde</ets> earth, land, ground, OS. <ets>folda</ets>.]</ety>
<sn>1.</sn> <def>Cleared land; land suitable for tillage or pasture;
cultivated ground; the open country.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A piece of land of considerable size; esp., a piece
inclosed for tillage or pasture.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Fields</qex> which promise corn and wine.</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A place where a battle is fought; also, the battle
itself.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In this glorious and well-foughten <qex>field</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>What though the <qex>field</qex> be lost?</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>An open space; an extent; an expanse.</def>
<specif>Esp.:</specif> <sd>(a)</sd> <def>Any blank space or ground on
which figures are drawn or projected.</def> <sd>(b)</sd> <def>The space
covered by an optical instrument at one view; <as>as,
wide-<ex>field</ex> binoculars</as>.</def><br/
[<source>1913 Webster</source> + <source>PJC</source>]</p>

<p><q>Without covering, save yon <qex>field</qex> of stars.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Ask of yonder argent <qex>fields</qex> above.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Her.)</fld> <def>The whole surface of an
escutcheon; also, so much of it is shown unconcealed by the different
bearings upon it. See <xex>Illust.</xex> of <er>Fess</er>, where the
<xex>field</xex> is represented as gules (red), while the
<xex>fess</xex> is argent (silver).</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>An unresticted or favorable opportunity for action,
operation, or achievement; province; room.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Afforded a clear <qex>field</qex> for moral experiments.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Sports)</fld> <def>An open, usually flat, piece of
land on which a sports contest is played; a playing field; <as>as, a
football <ex>field</ex>; a baseball <ex>field</ex></as>.</def><br/
<syn><b>Syn. --</b> playing field, athletic field, playing
area.</syn><br/
[<source>PJC</source>]</p>

<p><sn>8.</sn> <specif>Specifically:</specif> <fld>(Baseball)</fld>
<def>That part of the grounds reserved for the players which is outside
of the diamond; -- called also <altname>outfield</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>A geographic region (land or sea) which has some
notable feature, activity or valuable resource; <as>as, the diamond
<ex>fields</ex> of South Africa; an oil <ex>field</ex>; a gold
<ex>field</ex>; an ice <ex>field</ex></as>.</def><br/
[<source>WordNet 1.6</source>]</p>

<p><sn>10.</sn> <def>A facility having an airstrip where airplanes can
take off and land; an airfield.</def><br/
<syn><b>Syn. --</b> airfield, landing field, flying field,
aerodrome.</syn><br/
[<source>WordNet 1.6</source>]</p>

<p><sn>11.</sn> <def>A collective term for all the competitors in any
outdoor contest or trial, or for all except the favorites in the
betting.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>12.</sn> <def>A branch of knowledge or sphere of activity;
especially, a learned or professional discipline; <as>as, she's an
expert in the <ex>field</ex> of geology; in what <ex>field</ex> did she
get her doctorate?; they are the top company in the <ex>field</ex> of
entertainment</as>.</def><br/
<syn><b>Syn. --</b> discipline, subject, subject area, subject field,
field of study, study, branch of knowledge.</syn><br/
[<source>WordNet 1.6</source>]</p>

<p><note> Within the master text files of this electronic dictionary,
where a word is used in a specific sense in some specialized
<ex>field</ex> of knowledge, that field is indicated by the tags:
<fld>()</fld> preceding that sense of the word.</note><br/
[<source>PJC</source>]</p>

<p><sn>13.</sn> <def>A location, usually outdoors, away from a studio or
office or library or laboratory, where practical work is done or data is
collected; <as>as, anthropologists do much of their work in the
<ex>field</ex>; the paleontologist is in the <ex>field</ex> collecting
specimens</as>. Usually used in the phrase <col><b>in the
field</b></col>.</def><br/
[<source>WordNet 1.6</source>]</p>

<p><sn>14.</sn> <fld>(Physics)</fld> <def>The influence of a physical
object, such as an electrically charged body, which is capable of
exerting force on objects at a distance; also, the region of space over
which such an influence is effective; <as>as, the earth's gravitational
<ex>field</ex>; an electrical <ex>field</ex>; a magnetic <ex>field</ex>;
a force <ex>field</ex></as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>15.</sn> <fld>(Math.)</fld> <def>A set of elements within which
operations can be defined analagous to the operations of addition,
subtraction, multiplication, and division on the real numbers; within
such a set of elements addition and multiplication are commutative and
associative and multiplication is distributive over addition and there
are two elements 0 and 1; a commutative division ring; <as>as, the set
of all rational numbers is a <ex>field</ex></as>.</def><br/
[<source>WordNet 1.6</source>]</p>

<p><note><hand/ <xex>Field</xex> is often used adjectively in the sense
of <xex>belonging to</xex>, or <xex>used in</xex>, <xex>the
fields</xex>; especially with reference to the operations and equipments
of an army during a campaign away from permanent camps and
fortifications. In most cases such use of the word is sufficiently
clear; as, <xex>field</xex> battery; <xex>field</xex> fortification;
<xex>field</xex> gun; <xex>field</xex> hospital, etc. A <xex>field</xex>
geologist, naturalist, etc., is one who makes investigations or
collections out of doors. A survey uses a <xex>field</xex> book for
recording <xex>field</xex> notes, <it>i.e.</it>, measurement,
observations, etc., made in <xex>field</xex> work (outdoor operations).
A farmer or planter employs <xex>field</xex> hands, and may use a
<xex>field</xex> roller or a <xex>field</xex> derrick. <xex>Field</xex>
sports are hunting, fishing, athletic games, etc.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Coal field</b></col> <fld>(Geol.)</fld> <cd>See under
<er>Coal</er>.</cd> -- <col><b>Field artillery</b></col>, <cd>light
ordnance mounted on wheels, for the use of a marching army.</cd> --
<col><b>Field basil</b></col> <fld>(Bot.)</fld>, <cd>a plant of the Mint
family (<spn>Calamintha Acinos</spn>); -- called also <altname>basil
thyme</altname>.</cd> -- <col><b>Field colors</b></col>
<fld>(Mil.)</fld>, <cd>small flags for marking out the positions for
squadrons and battalions; camp colors.</cd> -- <col><b>Field
cricket</b></col> <fld>(Zool.)</fld>, <cd>a large European cricket
(<spn>Gryllus campestric</spn>), remarkable for its loud notes.</cd> --
<col><b>Field day</b></col>. <sd>(a)</sd> <cd>A day in the fields.</cd>
<sd>(b)</sd> <fld>(Mil.)</fld> <cd>A day when troops are taken into the
field for instruction in evolutions.</cd> <au>Farrow.</au> <sd>(c)</sd>
<cd>A day of unusual exertion or display; a gala day.</cd> --
<col><b>Field driver</b></col>, <cd>in New England, an officer charged
with the driving of stray cattle to the pound.</cd> -- <col><b>Field
duck</b></col> <fld>(Zool.)</fld>, <cd>the little bustard (<spn>Otis
tetrax</spn>), found in Southern Europe.</cd> -- <col><b>Field
glass</b></col>. <fld>(Optics)</fld> <sd>(a)</sd> <cd>A binocular
telescope of compact form; a lorgnette; a race glass.</cd> <sd>(b)</sd>
<cd>A small achromatic telescope, from 20 to 24 inches long, and having
3 to 6 draws.</cd> <sd>(c)</sd> <cd>See <cref>Field lens</cref>.</cd> --
<col><b>Field lark</b></col>. <fld>(Zool.)</fld> <sd>(a)</sd> <cd>The
skylark.</cd> <sd>(b)</sd> <cd>The tree pipit.</cd> -- <col><b>Field
lens</b></col> <fld>(Optics)</fld>, <cd>that one of the two lenses
forming the eyepiece of an astronomical telescope or compound microscope
which is nearer the object glass; -- called also <altname>field
glass</altname>.</cd> -- <col><b>Field madder</b></col>
<fld>(Bot.)</fld>, <cd>a plant (<spn>Sherardia arvensis</spn>) used in
dyeing.</cd> -- <col><b>Field marshal</b></col> <fld>(Mil.)</fld>,
<cd>the highest military rank conferred in the British and other
European armies.</cd> -- <col><b>Field officer</b></col>
<fld>(Mil.)</fld>, <cd>an officer above the rank of captain and below
that of general.</cd> -- <col><b>Field officer's court</b></col>
<fld>(U.S.Army)</fld>, <cd>a court-martial consisting of one field
officer empowered to try all cases, in time of war, subject to
jurisdiction of garrison and regimental courts.</cd> <au>Farrow.</au> --
<col><b>Field plover</b></col> <fld>(Zool.)</fld>, <cd>the black-bellied
plover (<spn>Charadrius squatarola</spn>); also sometimes applied to the
Bartramian sandpiper (<spn>Bartramia longicauda</spn>).</cd> --
<col><b>Field spaniel</b></col> <fld>(Zool.)</fld>, <cd>a small spaniel
used in hunting small game.</cd> -- <col><b>Field sparrow</b></col>.
<fld>(Zool.)</fld> <sd>(a)</sd> <cd>A small American sparrow
(<spn>Spizella pusilla</spn>).</cd> <sd>(b)</sd> <cd>The hedge
sparrow.</cd> <mark>[Eng.]</mark> -- <col><b>Field staff</b></col>
<fld>(Mil.)</fld>, <cd>a staff formerly used by gunners to hold a
lighted match for discharging a gun.</cd> -- <col><b>Field
vole</b></col> <fld>(Zool.)</fld>, <cd>the European meadow mouse.</cd>
-- <col><b>Field of ice</b></col>, <cd>a large body of floating ice; a
pack.</cd> -- <mcol><col><b>Field</b></col>, <it>or</it> <col><b>Field
of view</b></col></mcol>, <cd>in a telescope or microscope, the entire
space within which objects are seen.</cd> -- <col><b>Field
magnet</b></col>. <cd>see under <er>Magnet</er>.</cd> --
<col><b>Magnetic field</b></col>. <cd>See <er>Magnetic</er>.</cd> --
<mcol><col><b>To back the field</b></col>, <it>or</it> <col><b>To bet on
the field</b></col>. <cd>See under <er>Back</er>, <pos>v. t.</pos></cd>
-- <col><b>To keep the field</b></col></mcol>. <sd>(a)</sd>
<fld>(Mil.)</fld> <cd>To continue a campaign.</cd> <sd>(b)</sd> <cd>To
maintain one's ground against all comers.</cd> -- <mcol><col><b>To lay
against the field</b></col> <it>or</it> <col><b>To back against the
field</b></col></mcol>, <cd>to bet on (a horse, etc.) against all
comers.</cd> -- <col><b>To take the field</b></col> <fld>(Mil.)</fld>,
<cd>to enter upon a campaign.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Field</ent><br/
<hw>Field</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Fielded</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Fielding</conjf>.]</vmorph> <sn>1.</sn> <def>To take the
field.</def> <mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Ball Playing)</fld> <def>To stand out in the field,
ready to catch, stop, or throw the ball.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Field</ent><br/
<hw>Field</hw>, <pos>v. t.</pos> <fld>(Ball Playing)</fld> <def>To
catch, stop, throw, etc. (the ball), as a fielder.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fielded</ent><br/
<hw>Field"ed</hw>, <pos>a.</pos> <def>Engaged in the field;
encamped.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>To help <qex>fielded</qex> friends.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fielden</ent><br/
<hw>Field"en</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Consisting of
fields.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>fielden</qex> country also and plains.</q>
<rj><qau>Holland.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fielder</ent><br/
<hw>Field"er</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Ball Playing)</fld>
<def>A ball payer who stands out in the field to catch or stop
balls.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fieldfare</ent><br/
<hw>Field"fare`</hw> <pr>(?; 277)</pr>, <pos>n.</pos> <ety>[OE.
<ets>feldfare</ets>, AS. <ets>feldfare</ets>; field + <ets>faran</ets>
to travel.]</ety> <fld>(Zool.)</fld> <def>a small thrush (<spn>Turdus
pilaris</spn>) which breeds in northern Europe and winters in Great
Britain. The head, nape, and lower part of the back are ash-colored; the
upper part of the back and wing coverts, chestnut; -- called also
<altname>fellfare</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fielding</ent><br/
<hw>Field"ing</hw>, <pos>n.</pos> <fld>(Ball Playing)</fld> <def>The act
of playing as a fielder.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>field mouse</ent><br/
<ent>fieldmouse</ent><br/
<mhw><hw>fieldmouse</hw>, <hw>field mouse</hw></mhw> <pos>n.</pos>
<sn>1.</sn> <fld>(Zool.)</fld> <def>any nocturnal Old World mouse of the
genus <gen>Apodemus</gen> inhabing woods and fields and
gardens.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>any mouse inhabiting fields, as
the <stype>campagnol</stype> and the <stype>deer mouse</stype>. See
<er>Campagnol</er>, and <er>Deer mouse</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fieldpiece</ent><br/
<hw>Field"piece`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A cannon mounted
on wheels, for the use of a marching army; a piece of field artillery;
-- called also <altname>field gun</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>fieldsman</ent><br/
<hw>fields"man</hw> <pos>n.</pos> <fld>(Cricket)</fld> <def>a member of
the cricket team that is fielding rather than batting.</def><br/
<syn><b>Syn. --</b> fielder.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>field test</ent><br/
<ent>field-test</ent><br/
<mhw><hw>field-test</hw>, <hw>field test</hw></mhw> <pos>v. t.</pos>
<def>to test something in the field, <it>i. e.</it> under the actual
conditions under which it will be used; <as>as, The Army
<ex>field-tested</ex> the new tanks</as>. Used in contrast with testing
in a laboratory or under controlled conditions.</def><br/
<syn><b>Syn. --</b> field test.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Fieldwork</ent><br/
<hw>Field"work`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Mil.)</fld>
<def>Any temporary fortification thrown up by an army in the field; --
commonly in the plural.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>All works which do not come under the head of permanent
fortification are called <qex>fieldworks</qex>.</q>
<rj><qau>Wilhelm.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fieldy</ent><br/
<hw>Field"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Open, like a
field.</def> <mark>[Obs.]</mark> <rj><au>Wyclif.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>fiend</ent><br/
<hw>fiend</hw> <pr>(f<emac/nd)</pr>, <pos>n.</pos> <ety>[OE.
<ets>fend</ets>, <ets>find</ets>, <ets>fiend</ets>, <ets>feond</ets>,
fiend, foe, AS. <ets>fe<oacute/nd</ets>; akin to OS.
<ets>f<imac/ond</ets>, D. <ets>vijand</ets> enemy, OHG.
<ets>f<imac/ant</ets>, G. <ets>feind</ets>, Icel. <ets>fj<amac/nd</ets>,
Sw. & Dan. <ets>fiende</ets>, Goth. <ets>fijands</ets>; orig. p. pr. of
a verb meaning <ets>to hate</ets>, AS. <ets>fe<oacute/n</ets>,
<ets>fe<oacute/gan</ets>, OHG. <ets>f<imac/<?/n</ets>, Goth.
<ets>fijan</ets>, Skr. <ets>p<imac/y</ets> to scorn; prob. akin to E.
<ets>feud</ets> a quarrel. <root/81. Cf. <er>Foe</er>,
<er>Friend</er>.]</ety> <def>An implacable or malicious foe; one who is
diabolically wicked or cruel; an infernal being; -- applied specifically
to the devil or a demon.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Into this wild abyss the wary <qex>fiend</qex><br/
Stood on the brink of Hell and looked a while.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>O woman! woman! when to ill thy mind<br/
Is bent, all hell contains no fouler <qex>fiend</qex>.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fiendful</ent><br/
<hw>Fiend"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Full of fiendish
spirit or arts.</def> <rj><au>Marlowe.</au></rj></p>

<p>-- <wordforms><wf>Fiend"ful*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fiendish</ent><br/
<hw>Fiend"ish</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Like a fiend;
diabolically wicked or cruel; infernal; malignant; devilish;
hellish.</def> -- <wordforms><wf>Fiend"ish*ly</wf>, <pos>adv.</pos> --
<wf>Fiend"ish*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fiendlike</ent><br/
<hw>Fiend"like`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Fiendish;
diabolical.</def> <rj><au>Longfellow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fiendly</ent><br/
<hw>Fiend"ly</hw>, <pos>a.</pos> <ety>[AS.
<ets>fe<oacute/ndlic</ets>.]</ety> <def>Fiendlike; monstrous;
devilish.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fierasfer</ent><br/
\'d8<hw>Fi`e*ras"fer</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL.]</ety>
<fld>(Zool.)</fld> <def>A genus of small, slender fishes, remarkable for
their habit of living as commensals in other animals. One species
inhabits the gill cavity of the pearl oyster near Panama; another lives
within an East Indian holothurian.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fierce</ent><br/
<hw>Fierce</hw> <pr>(?)</pr>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Fiercer</adjf> <pr>(?)</pr>; <pos>superl.</pos>
<adjf>Fiercest</adjf> <pr>(?)</pr>.]</amorph> <ety>[OE. <ets>fers</ets>,
<ets>fiers</ets>, OF. <ets>fier</ets>, nom. <ets>fiers</ets>, fierce,
savage, cruel, F. <ets>fier</ets> proud, from L. <ets>ferus</ets> wild,
savage, cruel; perh. akin to E. <ets>bear</ets> the animal. Cf.
<er>Feral</er>, <er>Ferocity</er>.]</ety> <sn>1.</sn> <def>Furious;
violent; unrestrained; impetuous; <as>as, a <ex>fierce</ex>
wind</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His <qex>fierce</qex> thunder drove us to the deep.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Vehement in anger or cruelty; ready or eager to kill
or injure; of a nature to inspire terror; ferocious.</def> <ldquo/A
<xex>fierce</xex> whisper.<rdquo/ <au>Dickens.</au> <ldquo/A
<xex>fierce</xex> tyrant.<rdquo/ <au>Pope.</au><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>fierce</qex> foe hung upon our broken rear.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou huntest me as a <qex>fierce</qex> lion.</q> <rj><qau>Job. x.
16.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Excessively earnest, eager, or ardent.</def></p>

<p><syn><b>Syn.</b> -- Ferocious; savage; cruel; vehement; impetuous;
barbarous; fell. See <er>Ferocious</er>.</syn></p>

<p>-- <wordforms><wf>Fierce"ly</wf>, <pos>adv.</pos> --
<wf>Fierce"ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>fierceness</ent><br/
<hw>fierceness</hw> <pos>n.</pos> <def>the quality of being fierce;
ferocity; fury; vehemence.</def><br/
<syn><b>Syn. --</b> ferocity, furiousness, fury, vehemence, violence,
wildness, strength.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Fieri facias</ent><br/
\'d8<hw>Fi"e*ri fa"ci*as</hw> <pr>(?)</pr>. <ety>[L., cause it to be
done.]</ety> <fld>(Law)</fld> <def>A judicial writ that lies for one who
has recovered in debt or damages, commanding the sheriff that he cause
to be made of the goods, chattels, or real estate of the defendant, the
sum claimed.</def> <rj><au>Blackstone. Cowell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fieriness</ent><br/
<hw>Fi"er*i*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The quality of
being fiery; heat; acrimony; irritability; <as>as, a <ex>fieriness</ex>
of temper</as>.</def> <rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fiery</ent><br/
<hw>Fi"er*y</hw> <pr>(? <or/ ?)</pr>, <pos>a.</pos> <ety>[Formerly
written <ets>firy</ets>, fr. <ets>fire</ets>.]</ety> <sn>1.</sn>
<def>Consisting of, containing, or resembling, fire; <as>as, the
<ex>fiery</ex> gulf of Etna; a <ex>fiery</ex> appearance.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>And <qex>fiery</qex> billows roll below.</q> <rj><qau>I.
Watts.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Vehement; ardent; very active; impetuous.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Hath thy <qex>fiery</qex> heart so parched thine entrails?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>fiery</qex> spirit of his forefathers.</q> <rj><qau>W.
Irwing.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Passionate; easily provoked; irritable.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>You know the <qex>fiery</qex> quality of the duke.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Unrestrained; fierce; mettlesome;
spirited.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>One curbed the <qex>fiery</qex> steed.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>heated by fire, or as if by fire; burning hot;
parched; feverish.</def> <rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The sword which is made <qex>fiery</qex>.</q>
<rj><qau>Hooker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fiery cross</b></col>, <cd>a cross constructed of two
firebrands, and pitched upon the point of a spear; formerly in Scotland
borne by a runner as a signal for the clan to take up arms.</cd>
<rj><au>Sir W. Scott.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fiesta</ent><br/
\'d8<hw>Fies"ta</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sp. See
<er>Feast</er>, <pos>n.</pos>]</ety> <sn>1.</sn> <def>Among Spanish, a
religious festival; a saint's day or holiday; also, a holiday or
festivity.</def></p>

<p><q>Even . . . a bullfight is a <qex>fiesta</qex>.</q> <rj><qau>Am.
Dialect Notes.</qau></rj></p>

<p><q>Some <qex>fiesta</qex>, when all the surrounding population were
expected to turn out in holiday dress for merriment.</q> <rj><qau>The
Century.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>an organized series of acts and
performances.</def><br/
<syn><b>Syn. --</b> festival, feast, fete.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fife</ent><br/
<hw>Fife</hw> <pr>(f<imac/f)</pr>, <pos>n.</pos> <ety>[F.
<ets>fifre</ets>, OHG. <ets>pf<imac/fa</ets>, LL. <ets>pipa</ets> pipe,
<ets>pipare</ets> to play on the pipe, fr. L. <ets>pipire</ets>,
<ets>pipare</ets>, to peep, pip, chirp, as a chiken. See
<er>Pipe</er>.]</ety> <fld>(Mus.)</fld> <def>A small shrill pipe,
resembling the piccolo flute, used chiefly to accompany the drum in
military music.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fife major</b></col> <fld>(Mil.)</fld>, <cd>a
noncommissioned officer who superintends the fifers of a regiment.</cd>
-- <col><b>Fife rail</b></col>. <fld>(Naut.)</fld> <sd>(a)</sd> <cd>A
rail about the mast, at the deck, to hold belaying pins, etc.</cd>
<sd>(b)</sd> <cd>A railing around the break of a poop
deck.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fife</ent><br/
<hw>Fife</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Fifed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>fifing</conjf>.]</vmorph> <def>To play on a fife.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fifer</ent><br/
<hw>Fif"er</hw> <pr>(f<imac/f"<etil/r)</pr>, <pos>n.</pos> <def>One who
plays on a fife.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>FIFO</ent><br/
<hw>FIFO</hw> <pr>(f<imac/"f<omac/)</pr>, <pos>a.</pos> <ety>[acronym,
<ets>F</ets>irst <ets>I</ets>n <ets>F</ets>irst <ets>O</ets>ut.]</ety>
<sn>1.</sn> <fld>(accounting)</fld> <def>an accounting method in which
goods in inventory are valued at the price of the most recent
acquisition of each type of goods, and those used up from inventory are
valued at the cost of those first acquired.</def><br/
[<source>PJC</source>]</p>

<p><ent>Fifteen</ent><br/
<hw>Fif"teen`</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OE.
<ets>fiftene</ets>, AS. <ets>f<imac/ft<ymac/ne</ets>,
<ets>f<imac/ft<emac/ne</ets>. See <er>Five</er>, and <er>Ten</er>, and
cf. <er>Fifty</er>.]</ety> <def>Five and ten; one more than
fourteen.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fifteen</ent><br/
<hw>Fif"teen`</hw>, <pos>n.</pos> <sn>1.</sn> <def>The sum of five and
ten; fifteen units or objects.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A symbol representing fifteen units, as 15, or
xv.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fifteenth</ent><br/
<hw>Fif"teenth`</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OE.
<ets>fiftenthe</ets>; cf. <ets>fiftethe</ets>, AS.
<ets>f<imac/fte<omac/<edh/a</ets>. See <er>Fifteen</er>.]</ety>
<sn>1.</sn> <def>Next in order after the fourteenth; -- the ordinal of
fifteen.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Consisting of one of fifteen equal parts or
divisions of a thing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fifteenth</ent><br/
<hw>Fif"teenth`</hw>, <pos>n.</pos> <sn>1.</sn> <def>One of fifteen
equal parts or divisions; the quotient of a unit divided by
fifteen.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A species of tax upon personal property formerly
laid on towns, boroughs, etc., in England, being one fifteenth part of
what the personal property in each town, etc., had been valued at.</def>
<rj><au>Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Mus.)</fld> <sd>(a)</sd> <def>A stop in an organ
tuned two octaves above the diaposon.</def> <sd>(b)</sd> <def>An
interval consisting of two octaves.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fifth</ent><br/
<hw>Fifth</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OE. <ets>fifte</ets>,
<ets>fifthe</ets>, AS. <ets>f<imac/fta</ets>. See <er>Five</er>.]</ety>
<sn>1.</sn> <def>Next in order after the fourth; -- the ordinal of
five.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Consisting of one of five equal divisions of a
thing.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fifth monarchy men</b></col> <fld>(Hist.)</fld>, <cd>a
fanatical sect in England, of the time of the commonwealth, who
maintained that there would be a fifth universal monarchy, during which
Christ would reign on earth a thousand years.</cd> -- <col><b>Fifth
wheel</b></col>, <cd>a horizontal wheel or segment above the fore axle
of a carriage and beneath the body, forming an extended support to
prevent careening.</cd></cs><-- something superfluous, as an unwanted
person. --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fifth</ent><br/
<hw>Fifth</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The quotient
of a unit divided by five; one of five equal parts; a fifth
part.</def><-- a fifth of whiskey = a fifth of a gallon --><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mus.)</fld> <def>The interval of three tones and a
semitone, embracing five diatonic degrees of the scale; the dominant of
any key.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>fifth column</ent><br/
<hw>fifth` col"umn</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[from a
statement during the Spanish Civil War (1936) that the Falange had four
columns of soldiers marching on the city, and a fifth column
<ldquo/already there<rdquo/ (i.e. sympathizers inside the Republican
lines).]</ety> <sn>1.</sn> <def>a group of persons inside the battle
lines of a territory engaged in a conflict, who secretly sympathize with
the enemy, and who engage in espionage or sabotage; -- sometimes also
referred to as a <altname>trojan horse</altname>.</def><br/
[<source>RP</source>]</p>

<p><sn>2.</sn> <def>Hence, any faction of persons within a group who
secretly sympathize with an enemy, especially those who engage in
activities harmful to the group; an enemy in one's midst; a group of
traitors.</def><br/
[<source>RP</source>]</p>

<p><ent>Fifthly</ent><br/
<hw>Fifth"ly</hw>, <pos>adv.</pos> <def>In the fifth place; as the fifth
in order.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>fifties</ent><br/
<hw>fifties</hw> <pos>n.</pos> <sn>1.</sn> <def>the decade from 1950 to
1959.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>the time of life between 50 and 60.</def><br/
<syn><b>Syn. --</b> mid-fifties.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fiftieth</ent><br/
<hw>Fif"ti*eth</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[AS.
<ets>f<imac/ftigo<edh/a</ets>. See <er>Fifty</er>.]</ety> <sn>1.</sn>
<def>Next in order after the forty-ninth; -- the ordinal of
fifty.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Consisting of one of fifty equal parts or
divisions.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fiftieth</ent><br/
<hw>Fif"ti*eth</hw>, <pos>n.</pos> <def>One of fifty equal parts; the
quotient of a unit divided by fifty.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fifty</ent><br/
<hw>Fif"ty</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[AS.
<ets>f<imac/ftig</ets>; akin to OHG. <ets>finfzug</ets>,
<ets>fimfzuc</ets>, G. <ets>f<uum/nfzig</ets>, <ets>funfzig</ets>, Goth.
<ets>fimftigjus</ets>. See <er>Five</er>, and <er>Ten</er>, and cf.
<er>Fifteen</er>.]</ety> <def>Five times ten; <as>as, <ex>fifty</ex>
men</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fifty</ent><br/
<hw>Fif"ty</hw>, <pos>n.</pos>; <plu><it>pl.</it> <plw>Fifties</plw>
<pr>(<?/)</pr>.</plu> <sn>1.</sn> <def>The sum of five tens; fifty units
or objects.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A symbol representing fifty units, as 50, or
l.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>fifty-fifty</ent><br/
<hw>fifty-fifty</hw> <pos>adj.</pos> <def>equally large; -- of
probabilities.</def><br/
<syn><b>Syn. --</b> even.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>fifty-fifty</ent><br/
<hw>fifty-fifty</hw> <pos>n.</pos> <def>a lottery in which the
organizers retain fifty percent of the money wagered, and distribute
fifty percent of the wagered money to the winner.</def><br/
[<source>PJC</source>]</p>

<p><ent>Fig</ent><br/
<hw>Fig</hw> <pr>(f<icr/g)</pr>, <pos>n.</pos> <ety>[F. <ets>figue</ets>
the fruit of the tree, Pr. <ets>figa</ets>, fr. L. <ets>ficus</ets> fig
tree, fig. Cf. <er>Fico</er>.]</ety> <sn>1.</sn> <fld>(Bot.)</fld>
<def>A small fruit tree (<spn>Ficus Carica</spn>) with large leaves,
known from the remotest antiquity. It was probably native from Syria
westward to the Canary Islands.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The fruit of a fig tree, which is of round or oblong
shape, and of various colors.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The fruit of a fig tree is really the hollow end of a
stem, and bears numerous achenia inside the cavity. Many species have
little, hard, inedible figs, and in only a few does the fruit become
soft and pulpy. The fruit of the cultivated varieties is much prized in
its fresh state, and also when dried or preserved. See
<er>Caprification</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A small piece of tobacco.</def>
<mark>[U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The value of a fig, practically nothing; a fico; --
used in scorn or contempt.</def> <ldquo/A <xex>fig</xex> for
Peter.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Cochineal fig</b></col>. <cd>See <er>Conchineal
fig</er>.</cd> -- <col><b>Fig dust</b></col>, <cd>a preparation of fine
oatmeal for feeding caged birds.</cd> -- <col><b>Fig faun</b></col>,
<cd>one of a class of rural deities or monsters supposed to live on
figs.</cd> <ldquo/Therefore shall dragons dwell there with the <xex>fig
fauns</xex>.<rdquo/ <au>Jer. i. 39. (Douay version).</au> -- <col><b>Fig
gnat</b></col> <fld>(Zool.)</fld>, <cd>a small fly said to be injurious
to figs.</cd> -- <col><b>Fig leaf</b></col>, <cd>the leaf tree; hence,
in allusion to the first clothing of Adam and Eve (Genesis iii.7), a
covering for a thing that ought to be concealed; esp., an inadequate
covering; a symbol for affected modesty.</cd> -- <col><b>Fig
marigold</b></col> <fld>(Bot.)</fld>, <cd>the name of several plants of
the genus <gen>Mesembryanthemum</gen>, some of which are prized for the
brilliancy and beauty of their flowers.</cd> -- <col><b>Fig
tree</b></col> <fld>(Bot.)</fld>, <cd>any tree of the genus
<gen>Ficus</gen>, but especially <spn>F. Carica</spn> which produces the
fig of commerce.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fig</ent><br/
<hw>Fig</hw>, <pos>v. t.</pos> <ety>[See <er>Fico</er>, <er>Fig</er>,
<pos>n.</pos>]</ety> <sn>1.</sn> <def>To insult with a fico, or
contemptuous motion. See <er>Fico</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>When Pistol lies, do this, and <qex>fig</qex> me like<br/
The bragging Spaniard.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To put into the head of, as something useless o<?/
contemptible.</def> <mark>[Obs.]</mark>
<rj><au>L'Estrange.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fig</ent><br/
<hw>Fig</hw>, <pos>n.</pos> <def>Figure; dress; array.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Were they all in full <qex>fig</qex>, the females with feathers on
their heads, the males with chapeaux bras?</q> <rj><qau>Prof.
Wilson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Figaro</ent><br/
\'d8<hw>Fi`ga`ro"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From the name
of the barber in Beaumarchais' <ldquo/Barber of Seville.<rdquo/]</ety>
<def>An adroit and unscrupulous intriguer.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Figary</ent><br/
<hw>Fig"a*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Corrupted fr.
<ets>vagary</ets>.]</ety> <def>A frolic; a vagary; a whim.</def>
<mark>[Obs.]</mark> <rj><au>Beau. & Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Figeater</ent><br/
<hw>Fig"eat`er</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<sd>(a)</sd> <def>A large beetle (<spn>Allorhina nitida</spn>) which in
the Southern United States destroys figs. The elytra are velvety green
with pale borders.</def> <sd>(b)</sd> <def>A bird. See
<er>Figpecker</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Figent</ent><br/
<hw>Fig"ent</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Fidgety;
restless.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Such a little <qex>figent</qex> thing.</q> <rj><qau>Beau. &
Fl.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>fig leaf</ent><br/
<hw>fig leaf</hw> <sn>1.</sn> <def>The leaf from a fig tree.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>An ornamental design shaped like the leaf of a fig
tree, used in architecture; also, a design shaped like a fig leaf to
cover genitalia in sculpture or paintings -- in reference to the
biblical story in Genesis of Adam and Eve, who covered their privates
with fig leaves.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <specif>Hence:</specif> <mark>[figurative]</mark>
<def>Anything used to conceal what is considered embarrassing or
indecent. See sense 2.</def><br/
[<source>PJC</source>]</p>

<p><ent>Figgum</ent><br/
<hw>Fig"gum</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Etymol.
uncertain.]</ety> <def>A juggler's trick; conjuring.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The devil is the author of wicked <qex>figgum</qex>.</q>
<rj><qau>B. Jonson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fight</ent><br/
<hw>Fight</hw> <pr>(f<imac/t)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Fought</conjf> <pr>(f<add/t)</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>Fighting</conjf>.]</vmorph> <ety>[OE.
<ets>fihten</ets>, <ets>fehten</ets>, AS. <ets>feohtan</ets>; akin to D.
<ets>vechten</ets>, OHG. <ets>fehtan</ets>, G. <ets>fechten</ets>, Sw.
<ets>f<aum/kta</ets>, Dan. <ets>fegte</ets>, and perh. to E.
<ets>fist</ets>; cf. L. <ets>pugnare</ets> to fight, <ets>pugnus</ets>
fist.]</ety> <sn>1.</sn> <def>To strive or contened for victory, with
armies or in single combat; to attempt to defeat, subdue, or destroy an
enemy, either by blows or weapons; to contend in arms; -- followed by
<xex>with</xex> or <xex>against</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>You do <qex>fight</qex> against your country's foes.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>fight</qex> with thee no man of arms will deign.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To act in opposition to anything; to struggle
against; to contend; to strive; to make resistance.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To fight shy</b></col>, <cd>to avoid meeting fairly or at
close quarters; to keep out of reach.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fight</ent><br/
<hw>Fight</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To carry on, or wage,
as a conflict, or battle; to win or gain by struggle, as one's way; to
sustain by fighting, as a cause.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He had to <qex>fight</qex> his way through the world.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I have <qex>fought</qex> a good fight.</q> <rj><qau>2 Tim. iv.
7.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To contend with in battle; to war against; <as>as,
they <ex>fought</ex> the enemy in two pitched battles; the sloop
<ex>fought</ex> the frigate for three hours.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To cause to fight; to manage or maneuver in a fight;
<as>as, to <ex>fight</ex> cocks; to <ex>fight</ex> one's
ship.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To fight it out</b></col>, <cd>to fight until a decisive
and conclusive result is reached.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 558 --></p>

<p><ent>Fight</ent><br/
<hw>Fight</hw>, <pos>n.</pos> <ety>[OE. <ets>fight</ets>,
<ets>feht</ets>, AS. <ets>feoht</ets>. See <er>Fight</er>, <pos>v.
i.</pos>]</ety> <sn>1.</sn> <def>A battle; an engagement; a contest in
arms; a combat; a violent conflict or struggle for victory, between
individuals or between armies, ships, or navies, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Who now defies thee thrice to single <qex>fight</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A struggle or contest of any kind.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Strength or disposition for fighting; pugnacity;
<as>as, he has a great deal of <ex>fight</ex> in him</as>.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A screen for the combatants in ships.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Up with your <qex>fights</qex>, and your nettings prepare.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Running fight</b></col>, <cd>a fight in which the enemy
is continually chased; also, one which continues without definite end or
result.</cd></cs></p>

<p><syn><b>Syn.</b> -- Combat; engagement; contest; struggle; encounter;
fray; affray; action; conflict. See <er>Battle</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fighter</ent><br/
<hw>Fight"er</hw> <pr>(f<imac/t"<etil/r)</pr>, <pos>n.</pos> <ety>[AS.
<ets>feohtere</ets>.]</ety> <sn>1.</sn> <def>One who fights; a
combatant; a warrior.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A boxer; a pugilist.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>A person with the determination and will to persist
through great difficulty to achieve a goal; one with the courage to
fight and resist an opponent, and to struggle with all one's
powers.</def><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <fld>(Mil.)</fld> <def>A military aircraft designed to
seek out and destroy enemy aircraft; it is usually smaller and more
maneuvarable than aircraft designed specifically for bombing. However,
hybrid <contr>fighter-bomber</contr> aircraft that perform both
functions also are used.</def><br/
[<source>PJC</source>]</p>

<p><ent>Fighting</ent><br/
<hw>Fight"ing</hw>, <pos>a.</pos> <sn>1.</sn> <def>Qualified for war;
fit for battle.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>An host of <qex>fighting</qex> men.</q> <rj><qau>2 Chron. xxvi.
11.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Occupied in war; being the scene of a battle;
<as>as, a <ex>fighting</ex> field</as>.</def>
<rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>A fighting chance</b></col>, <cd>one dependent upon the
issue of a struggle.</cd> <mark>[Colloq.]</mark> -- <col><b>Fighting
crab</b></col> <fld>(Zool.)</fld>, <cd>the fiddler crab.</cd> --
<col><b>Fighting fish</b></col> <fld>(Zool.)</fld>, <cd>a remarkably
pugnacious East Indian fish (<spn>Betta pugnax</spn>), reared by the
Siamese for spectacular fish fights.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fightingly</ent><br/
<hw>Fight"ing*ly</hw>, <pos>adv.</pos> <def>Pugnaciously.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fightwite</ent><br/
<hw>Fight"wite`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Fight</ets>
+ <ets>wite</ets>.]</ety> <fld>(O.Eng. Law)</fld> <def>A mulct or fine
imposed on a person for making a fight or quarrel to the disturbance of
the peace.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Figment</ent><br/
<hw>Fig"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>figmentum</ets>, fr. <ets>fingere</ets> to form, shape, invent,
feign. See <er>Feign</er>.]</ety> <def>An invention; a fiction;
something feigned or imagined.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Social <qex>figments</qex>, feints, and formalism.</q>
<rj><qau>Mrs. Browning.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>It carried rather an appearance of <qex>figment</qex> and
invention . . . than of truth and reality.</q>
<rj><qau>Woodward.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Figpecker</ent><br/
<hw>Fig"peck`er</hw> <pr>(f<icr/g"p<ecr/k`<etil/r)</pr>, <pos>n.</pos>
<fld>(Zool.)</fld> <def>The European garden warbler (<spn>Sylvia
hortensis</spn> <it>or</it> <spn>Currica, hortensis</spn>); -- called
also <altname>beccafico</altname> and <altname>greater
pettychaps</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fig-shell</ent><br/
<hw>Fig"-shell`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>A marine univalve shell of the genus <gen>Pyrula</gen>, or
<gen>Ficula</gen>, resembling a fig in form.</def></p>

<p><ent>Figulated</ent><br/
<ent>Figulate</ent><br/
<mhw>{ <hw>Fig"u*late</hw> <pr>(?)</pr>, <hw>Fig"u*la`ted</hw>
<pr>(?)</pr> }</mhw>, <pos>a.</pos> <ety>[L. <ets>figulatus</ets>, p. p.
of <ets>figulare</ets> to shape, fr. <ets>figulus</ets> potter, fr.
<ets>fingere</ets> to shape.]</ety> <def>Made of potter's clay; molded;
shaped.</def> <mark>[R.]</mark> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Figuline</ent><br/
<hw>Fig"u*line</hw> <pr>(? <or/ ?)</pr>, <pos>n.</pos> <ety>[F., fr. L.
<ets>figulina</ets> pottery, fr. <ets>figulus</ets>. See
<er>Figulate</er>.]</ety> <def>A piece of pottery ornamented with
representations of natural objects.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Whose <qex>figulines</qex> and rustic wares<br/
Scarce find him bread from day to day.</q>
<rj><qau>Longfellow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Figuline</ent><br/
<hw>Fig"u*line</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>figulinus</ets>. See <er>Figulate</er>.]</ety> <sn>1.</sn>
<def>Suitable for the making of pottery; fictile; -- said of
clay.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>Made of clay, as by the potter; -- said of vessels,
ornamental figures, or the like; <as>as, <ex>figuline</ex>
ware</as>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Figurability</ent><br/
<hw>Fig`ur*a*bil"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>figurabilit<eacute/</ets>.]</ety> <def>The quality of being
figurable.</def> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Figurable</ent><br/
<hw>Fig`ur*a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>figurare</ets> to form, shape, fr. <ets>figura</ets> figure: cf. F.
<ets>figurable</ets>. See <er>Figure</er>.]</ety> <def>Capable of being
brought to a fixed form or shape.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Lead is <qex>figurable</qex>, but water is not.</q>
<rj><qau>Johnson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Figural</ent><br/
<hw>Fig"ur*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From
<er>Figure</er>.]</ety> <sn>1.</sn> <def>Represented by figure or
delineation; consisting of figures; <as>as, <ex>figural</ex>
ornaments</as>.</def> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mus.)</fld> <def>Figurate. See
<er>Figurate</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Figural numbers</b></col>. <cd>See <cref>Figurate
numbers</cref>, under <er>Figurate</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Figurant</ent><br/
<hw>Fig"u*rant`</hw> <pr>(? <or/ ?)</pr>, <pos>n. masc.</pos> <ety>[F.,
prop. p. pr. of <ets>figurer</ets> figure, represent, make a
figure.]</ety> <def>One who dances at the opera, not singly, but in
groups or figures; an accessory character on the stage, who figures in
its scenes, but has nothing to say; hence, one who figures in any scene,
without taking a prominent part.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Figurante</ent><br/
<hw>Fig"u*rante`</hw> <pr>(? <or/ ?)</pr>, <pos>n. fem.</pos>
<ety>[F.]</ety> <def>A female figurant; esp., a ballet girl.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Figurate</ent><br/
<hw>Fig"ur*ate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>figuratus</ets>, p. p. of <ets>figurare</ets>. See
<er>Figure</er>.]</ety> <sn>1.</sn> <def>Of a definite form or
figure.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Plants are all <qex>figurate</qex> and determinate, which
inanimate bodies are not.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Figurative; metaphorical.</def> <mark>[Obs.]</mark>
<rj><au>Bale.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Mus.)</fld> <def>Florid; figurative; involving
passing discords by the freer melodic movement of one or more parts or
voices in the harmony; <as>as, <ex>figurate</ex> counterpoint or
descant</as>.</def><br/
[<source>1913 Webster</source>]</p>

<cs><p><mcol><col><b>Figurate counterpoint</b></col> <it>or</it>
<col><b>Figurate descant</b></col></mcol> <fld>(Mus.)</fld>, <cd>that
which is not simple, or in which the parts do not move together tone for
tone, but in which freer movement of one or more parts mingles passing
discords with the harmony; -- called also <altname>figural</altname>,
<altname>figurative</altname>, and <altname>figured
counterpoint</altname> or <altname>descant</altname> (although the term
<xex>figured</xex> is more commonly applied to a bass with numerals
written above or below to indicate the other notes of the harmony).</cd>
-- <col><b>Figurate numbers</b></col> <fld>(Math.)</fld>, <cd>numbers,
or series of numbers, formed from any arithmetical progression in which
the first term is a unit, and the difference a whole number, by taking
the first term, and the sums of the first two, first three, first four,
etc., as the successive terms of a new series, from which another may be
formed in the same manner, and so on, the numbers in the resulting
series being such that points representing them are capable of
symmetrical arrangement in different geometrical figures, as triangles,
squares, pentagons, etc.</cd> <note>In the following example, the two
lower lines are composed of <xex>figurate numbers</xex>, those in the
second line being <xex>triangular</xex>, and represented thus: --</note></p>

<p>
<pre><tt>
			.              1, 2,  3,  4, etc.
	      .        . .             1, 3,  6, 10, etc.
      .      . .     . . . .   etc.    1, 4, 10, 20, etc
 .   . .   . . . .  . . . . .
</tt></pre><br/
<br/
[<source>1913 Webster</source>]</p></cs>

<p><ent>Figurated</ent><br/
<hw>Fig"ur*a`ted</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having a
determinate form.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Figurately</ent><br/
<hw>Fig"ur*ate*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a figurate
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Figuration</ent><br/
<hw>Fig`u*ra"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>figuratio</ets>.]</ety> <sn>1.</sn> <def>The act of giving figure
or determinate form; determination to a certain form.</def>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mus.)</fld> <def>Mixture of concords and
discords.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Figurative</ent><br/
<hw>Fig"ur*a*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>figurativus</ets>: cf. F. <ets>figuratif</ets>. See
<er>Figurative</er>.]</ety> <sn>1.</sn> <def>Representing by a figure,
or by resemblance; typical; representative.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This, they will say, was <qex>figurative</qex>, and served, by
God's appointment, but for a time, to shadow out the true glory of a
more divine sanctity.</q> <rj><qau>Hooker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Used in a sense that is tropical, as a metaphor; not
literal; -- applied to words and expressions.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Abounding in figures of speech; flowery; florid;
<as>as, a highly <ex>figurative</ex> description</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Relating to the representation of form or figure by
drawing, carving, etc. See <er>Figure</er>, <pos>n.</pos>, 2.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They belonged to a nation dedicated to the <qex>figurative</qex>
arts, and they wrote for a public familiar with painted form.</q>
<rj><qau>J. A. Symonds.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Figurative counterpoint</b></col> <it>or</it>
<col><b>Figurative descant</b></col></mcol>. <cd>See under
<er>Figurate</er>.</cd></cs></p>

<p>-- <wordforms><wf>Fig"ur*a*tive*ly</wf>, <pos>adv.</pos> --
<wf>Fig"ur*a*tive*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Figure</ent><br/
<hw>Fig"ure</hw> <pr>(f<icr/g"<usl/r; 135)</pr>, <pos>n.</pos> <ety>[F.,
<ets>figure</ets>, L. <ets>figura</ets>; akin to <ets>fingere</ets> to
form, shape, feign. See <er>Feign</er>.]</ety> <sn>1.</sn> <def>The form
of anything; shape; outline; appearance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Flowers have all exquisite <qex>figures</qex>.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The representation of any form, as by drawing,
painting, modeling, carving, embroidering, etc.; especially, a
representation of the human body; <as>as, a <ex>figure</ex> in bronze; a
<ex>figure</ex> cut in marble.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>A coin that bears the <qex>figure</qex> of an angel.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A pattern in cloth, paper, or other manufactured
article; a design wrought out in a fabric; <as>as, the muslin was of a
pretty <ex>figure</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Geom.)</fld> <def>A diagram or drawing, made to
represent a magnitude or the relation of two or more magnitudes; a
surface or space inclosed on all sides; -- called <xex>superficial</xex>
when inclosed by lines, and <xex>solid</xex> when inclosed by surfaces;
any arrangement made up of points, lines, angles, surfaces,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>The appearance or impression made by the conduct or
career of a person; <as>as, a sorry <ex>figure</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I made some <qex>figure</qex> there.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Gentlemen of the best <qex>figure</qex> in the county.</q>
<rj><qau>Blackstone.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Distinguished appearance; magnificence; conspicuous
representation; splendor; show.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That he may live in <qex>figure</qex> and indulgence.</q>
<rj><qau>Law.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>A character or symbol representing a number; a
numeral; a digit; as, 1, 2,3, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>Value, as expressed in numbers; price; <as>as, the
goods are estimated or sold at a low <ex>figure</ex></as>.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>With nineteen thousand a year at the very lowest
<qex>figure</qex>.</q> <rj><qau>Thackeray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>A person, thing, or action, conceived of as
analogous to another person, thing, or action, of which it thus becomes
a type or representative.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Who is the <qex>figure</qex> of Him that was to come.</q>
<rj><qau>Rom. v. 14.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <fld>(Rhet.)</fld> <def>A mode of expressing abstract or
immaterial ideas by words which suggest pictures or images from the
physical world; pictorial language; a trope; hence, any deviation from
the plainest form of statement. Also called a <altname>figure of
speech</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To represent the imagination under the <qex>figure</qex> of a
wing.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>11.</sn> <fld>(Logic)</fld> <def>The form of a syllogism with
respect to the relative position of the middle term.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>12.</sn> <fld>(Dancing)</fld> <def>Any one of the several regular
steps or movements made by a dancer.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>13.</sn> <fld>(Astrol.)</fld> <def>A horoscope; the diagram of
the aspects of the astrological houses.</def>
<rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>14.</sn> <fld>(Music)</fld> <sd>(a)</sd> <def>Any short
succession of notes, either as melody or as a group of chords, which
produce a single complete and distinct impression.</def>
<rj><au>Grove.</au></rj></p>

<p><sd>(b)</sd> <def>A form of melody or accompaniment kept up through a
strain or passage; a musical phrase or motive; a florid
embellishment.</def><br/
[<source>1913 Webster</source>]</p>

<note><p><hand/ Figures are often written upon the staff in music to
denote the kind of measure. They are usually in the form of a fraction,
the upper figure showing how many notes of the kind indicated by the
lower are contained in one measure or bar. Thus, <musfig>2/4</musfig>
signifies that the measure contains two quarter notes. The following are
the principal figures used for this purpose: -- <-- the "figures"
illustrated here have a bar through each number and cannot be
represented as simple fractions, thus the special "musfig" field
notation. The following numbers are contained in a single line of large
(ca. 14 pt.) bold type --></p>

<p><musfig>2/2</musfig><musfig>2/4</musfig><musfig>2/8</musfig>
<musfig>4/2</musfig><musfig>2/4</musfig><musfig>4/8</musfig>
<musfig>3/2</musfig><musfig>3/4</musfig><musfig>3/8</musfig>
<musfig>6/4</musfig><musfig>6/4</musfig><musfig>6/8</musfig><br/
[<source>1913 Webster</source>]</p></note>

<p><cs><mcol><col><b>Academy figure</b></col>, <col><b>Canceled
figures</b></col>, <col><b>Lay figure</b></col>, etc.</mcol> <cd>See
under <er>Academy</er>, <er>Cancel</er>, <er>Lay</er>, etc.</cd> --
<mcol><col><b>Figure caster</b></col>, <it>or</it> <col><b>Figure
flinger</b></col></mcol>, <cd>an astrologer.</cd> <ldquo/This
<xex>figure caster</xex>.<rdquo/ <au>Milton.</au> -- <col><b>Figure
flinging</b></col>, <cd>the practice of astrology.</cd> --
<col><b>Figure-of-eight knot</b></col>, <cd>a knot shaped like the
figure 8. See <xex>Illust.</xex> under <er>Knot</er>.</cd> --
<col><b>Figure painting</b></col>, <cd>a picture of the human figure, or
the act or art of depicting the human figure.</cd> -- <col><b>Figure
stone</b></col> <fld>(Min.)</fld>, <cd>agalmatolite.</cd> --
<col><b>Figure weaving</b></col>, <cd>the art or process of weaving
figured fabrics.</cd> -- <col><b>To cut a figure</b></col>, <cd>to make
a display.</cd> <mark>[Colloq.]</mark> <au>Sir W. Scott.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Figure</ent><br/
<hw>Fig"ure</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Figured</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Figuring</conjf>.]</vmorph> <ety>[F. <ets>figurer</ets>, L.
<ets>figurare</ets>, fr. <ets>figura</ets>. See <er>Figure</er>,
<pos>n.</pos>]</ety> <sn>1.</sn> <def>To represent by a figure, as to
form or mold; to make an image of, either palpable or ideal; also, to
fashion into a determinate form; to shape.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If love, alas! be pain I bear,</q><br/
[<source>1913 Webster</source>]</p>

<p><q>No thought can <qex>figure</qex>, and no tongue
declare.Prior.</q><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To embellish with design; to adorn with
figures.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The vaulty top of heaven<br/
<qex>Figured</qex> quite o'er with burning meteors.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To indicate by numerals; also, to compute.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>As through a crystal glass the <qex>figured</qex> hours are
seen.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To represent by a metaphor; to signify or
symbolize.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Whose white vestments <qex>figure</qex> innocence.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To prefigure; to foreshow.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In this the heaven <qex>figures</qex> some event.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Mus.)</fld> <sd>(a)</sd> <def>To write over or
under the bass, as figures or other characters, in order to indicate the
accompanying chords.</def> <sd>(b)</sd> <def>To embellish.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To figure out</b></col>, <cd>to solve; to compute or find
the result of.</cd> -- <col><b>To figure up</b></col>, <cd>to add; to
reckon; to compute the amount of.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Figure</ent><br/
<hw>Fig"ure</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To make a figure; to
be distinguished or conspicious; <as>as, the envoy <ex>figured</ex> at
court</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Sociable, hospitable, eloquent, admired, <qex>figuring</qex> away
brilliantly.</q> <rj><qau>M. Arnold.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To calculate; to contrive; to scheme; <as>as, he is
<ex>figuring</ex> to secure the nomination</as>.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>go figure</b></col> <cd>a phrase used by itself as an
interjection to mean <ldquo/How can one explain that?<rdquo/, or to
express puzzlement over some seeming contradiction.</cd>
<mark>[Colloq.]</mark></cs><br/
[<source>PJC</source>]</p>

<p><ent>Figured</ent><br/
<hw>Fig"ured</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Adorned
with figures; marked with figures; <as>as, <ex>figured</ex>
muslin</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Not literal; figurative.</def> <mark>[Obs.]</mark>
<rj><au>Locke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Mus.)</fld> <sd>(a)</sd> <def>Free and florid;
<as>as, a <ex>figured</ex> descant</as>. See <er>Figurate</er>, 3.</def>
<sd>(b)</sd> <def>Indicated or noted by figures.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Figured bass</b></col>. <cd>See <cref>Continued
bass</cref>, under <er>Continued</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Figurehead</ent><br/
<hw>Fig"ure*head`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<fld>(Naut.)</fld> <def>The figure, statue, or bust, on the prow of a
ship.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A person who allows his name to be used to give
standing to enterprises in which he has no responsible interest or
duties; a nominal, but not real, head or chief.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Figurial</ent><br/
<hw>Fi*gu"ri*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Represented by
figure or delineation.</def> <mark>[R.]</mark>
<rj><au>Craig.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Figurine</ent><br/
\'d8<hw>Fi`gu`rine"</hw> <pr>(? <or/ ?)</pr>, <pos>n.</pos> <ety>[F.,
<ets>dim</ets>. <ets>of figure</ets>.]</ety> <def>A very small figure,
whether human or of an animal; especially, one in terra cotta or the
like; -- distinguished from <contr>statuette</contr>, which is applied
to small figures in bronze, marble, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Figurist</ent><br/
<hw>Fig"ur*ist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who uses or
interprets figurative expressions.</def>
<rj><au>Waterland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Figwort</ent><br/
<hw>Fig"wort`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>A
genus of herbaceous plants (<gen>Scrophularia</gen>), mostly found in
the north temperate zones. See <er>Brownwort</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fijian</ent><br/
<hw>Fi"ji*an</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining to
the Fiji islands or their inhabitants.</def> -- <def2><pos>n.</pos>
<def>A native of the Fiji islands.</def></def2> <altsp>[Written also
<asp>Feejeean</asp>, <asp>Feejee</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fike</ent><br/
<hw>Fike</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Fyke</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fil</ent><br/
<hw>Fil</hw> <pr>(?)</pr>, <mark>obs.</mark> <def><pos>imp.</pos> of
<er>Fall</er>, <pos>v. i.</pos> Fell.</def>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Filaceous</ent><br/
<hw>Fi*la"ceous</hw> <pr>(? <or/ ?)</pr>, <pos>a.</pos> <ety>[L.
<ets>filum</ets> thread.]</ety> <def>Composed of threads.</def>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Filacer</ent><br/
<hw>Fil"a*cer</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>filace</ets> a file, or thread, on which the records of the courts
of justice were strung, F. <ets>filasse</ets> tow of flax or hemp, fr.
L. <ets>filum</ets> thread.]</ety> <fld>(Eng. Law)</fld> <def>A former
officer in the English Court of Common Pleas; -- so called because he
<xex>filed</xex> the writs on which he made out process.</def>
<mark>[Obs.]</mark> <rj><au>Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Filament</ent><br/
<hw>Fil"a*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>filament</ets>, fr. L. <ets>filum</ets> thread. See <er>File</er> a
row.]</ety> <def>A thread or threadlike object or appendage; a
fiber;</def> <specif>esp.</specif> <fld>(Bot.)</fld>, <def>the
threadlike part of the stamen supporting the anther.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Filamentary</ent><br/
<hw>Fil`a*men"ta*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having the
character of, or formed by, a filament.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Filamentoid</ent><br/
<hw>Fil"a*men*toid`</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Filament</ets> + <ets>-oid</ets>.]</ety> <def>Like a
filament.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Filamentous</ent><br/
<hw>Fil`a*men"tous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>filamenteux</ets>.]</ety> <def>Like a thread; consisting of threads
or filaments.</def> <rj><au>Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Filander</ent><br/
<hw>Fil"an*der</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>A species of kangaroo (<spn>Macropus Brunii</spn>), inhabiting New
Guinea.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Filanders</ent><br/
<hw>Fil"an*ders</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[F.
<ets>filandres</ets>, fr. L. <ets>filum</ets> thread.]</ety>
<fld>(Falconry)</fld> <def>A disease in hawks, characterized by the
presence of small threadlike worms, also of filaments of coagulated
blood, from the rupture of a vein; -- called also
<altname>backworm</altname>.</def> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Filar</ent><br/
<hw>Fi"lar</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>filum</ets> a
thread.]</ety> <def>Of or pertaining to a thread or line; characterized
by threads stretched across the field of view; <as>as, a <ex>filar</ex>
microscope; a <ex>filar</ex> micrometer.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Filaria</ent><br/
<hw>Fi*la"ri*a</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>filariae</plw>.</plu> <ety>[NL., fr. L. <ets>filum</ets> a
thread.]</ety> <fld>(Zool.)</fld> <def>a small, slender nematode worm of
the family <fam>Onchocercidae</fam> (<fam>Filariidae</fam>) of many
species, parasitic when adult in various animals, including man. They
may live within the blood, or in other bodily fluids, or within tissues
or cavities of the body. Infection with such organisms may be
transmitted by blood-sucking arthropods.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Filaria</ent><br/
\'d8<hw>Fi*la"ri*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. L.
<ets>filum</ets> a thread.]</ety> <fld>(Zool.)</fld> <def>a former genus
comprised of certain nematodes, now classed as belonging to several
genera within the family <fam>Onchocercidae</fam>. See
<er>Onchocerca</er> and <er>Guinea worm</er>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Filarial</ent><br/
<hw>Fi*la"ri*al</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <fld>(Zool.
& Med.)</fld> <def>Of, pertaining to, or caused by, filari<ae/ and
allied parasitic worms.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>Straight, as if in a line; <as>as, the
<ex>filarial</ex> flight of birds</as>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Filariasis</ent><br/
<hw>Fil`a*ri"a*sis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL.]</ety>
<sn>1.</sn> <fld>(Zool., Med.)</fld> <def>the presence of filariae
within the body of an organism; infection with filariae. It is mostly
found in tropical and subtropical regions.</def><br/
[<source>Webster 1913 Suppl.</source> <source>PJC</source>]</p>

<p><sn>2.</sn> <fld>(Med.)</fld> <def>a disease caused by nematodes in
the blood or tissues of the body causing blockage of lymphatic vessels.
Death of the adult worms may lead to inflammation and permanent
fibrosis; the condition may lead to serious symptoms, such as
elephantiasis or blindness. See <er>river blindness</er></def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>filariid</ent><br/
<hw>filariid</hw> <pos>adj.</pos> <def>of or pertaining to family
<fam>Filariidae</fam>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Filariidae</ent><br/
<hw>Filariidae</hw> <pos>n.</pos> <def>a natural family consisting of
threadlike roundworms, called <er>filariae</er>.</def><br/
<syn><b>Syn. --</b> family <fam>Filariidae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Filasse</ent><br/
<hw>Fi*lasse"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr.
<ets>fil</ets> thread, L. <ets>filum</ets>.]</ety> <def>Vegetable fiber,
as jute or ramie, prepared for manufacture.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Filatory</ent><br/
<hw>Fil"a*to*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL.
<ets>filatorium</ets> place for spinning, fr. <ets>filare</ets> to spin,
fr. L. <ets>filum</ets> a thread.]</ety> <def>A machine for forming
threads.</def> <mark>[Obs.]</mark> <rj><au>W. Tooke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Filature</ent><br/
<hw>Fil"a*ture</hw> <pr>(?; 135)</pr>, <pos>n.</pos> <ety>[LL.
<ets>filatura</ets>, fr. <ets>filare</ets> to spin: cf. F.
<ets>filature</ets>. See <er>Filatory</er>.]</ety> <sn>1.</sn> <def>A
drawing out into threads; hence, the reeling of silk from cocoons.</def>
<rj><au>Ure.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A reel for drawing off silk from cocoons; also, an
establishment for reeling silk.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>filbert</ent><br/
<hw>fil"bert</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Perh. fr. <ets>fill
+ bread</ets>, as filling the bread or husk; cf. G. <ets>bartnuss</ets>
(lit., bread nut) filbert; or perh. named from a
St.<ets>Philibert</ets>, whose day, Aug. 22, fell in the nutting
season.]</ety> <sn>1.</sn> <fld>(Bot.)</fld> <def>The fruit of the
<spn>Corylus Avellana</spn> or <spn>Corylus maxima</spn>, also called
the hazel; the hazelnut. It is an oval nut, containing a kernel that has
a mild, farinaceous, oily taste, agreeable to the palate.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In England <xex>filberts</xex> are usually large
hazelnuts, especially the nuts from selected and cultivated trees. The
American hazelnuts are of two other species, <spn>Corylus
Americana</spn> and <spn>Corylus cornuta</spn>, and are also sometimes
called <ex>filberts</ex>.</note><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>The tree bearing the filbert; the
hazelnut tree.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Filbert gall</b></col> <fld>(Zool.)</fld>, <cd>a gall
resembling a filbert in form, growing in clusters on grapevines. It is
produced by the larva of a gallfly
(<gen>Cecidomyia</gen>).</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Filch</ent><br/
<hw>Filch</hw> <pr>(f<icr/lch)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Filched</conjf> <pr>(f<icr/lcht)</pr>; <pos>p. pr.
& vb. n.</pos> <conjf>Filching</conjf>.]</vmorph> <ety>[Cf. AS.
<ets>feolan</ets> to stick to, OHG. <ets>felhan</ets>,
<ets>felahan</ets>, to hide, Icel. <ets>fela</ets>, Goth.
<ets>filhan</ets> to hide, bury, Prov. E. <ets>feal</ets> to hide slyly,
OE. <ets>felen</ets>.]</ety> <def>To steal or take privily (commonly,
that which is of little value); to pilfer.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Fain would they <qex>filch</qex> that little food away.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>But he that <qex>filches</qex> from me my good name,<br/
Robs me of that which not enriches him,<br/
And makes me poor indeed.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Filcher</ent><br/
<hw>Filch"er</hw> <pr>(f<icr/lch"<etil/r)</pr>, <pos>n.</pos> <def>One
who filches; a thief.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Filchingly</ent><br/
<hw>Filch"ing*ly</hw>, <pos>adv.</pos> <def>By pilfering or petty
stealing.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 559 --></p>

<p><ent>File</ent><br/
<hw>File</hw> <pr>(f<imac/l)</pr>, <pos>n.</pos> <ety>[F.
<ets>file</ets> row (cf. Pr., Sp., Pg., & It. <ets>fila</ets>), LL.
<ets>fila</ets>, fr. L. <ets>filum</ets> a thread. Cf.
<er>Enfilade</er>, <er>Filament</er>, <er>Fillet</er>.]</ety>
<sn>1.</sn> <def>An orderly succession; a line; a row</def>; as:
<sd>(a)</sd> <sd>(Mil.)</sd> <def>A row of soldiers ranged one behind
another; -- in contradistinction to <contr>rank</contr>, which
designates a row of soldiers standing abreast; a number consisting the
depth of a body of troops, which, in the ordinary modern formation,
consists of two men, the battalion standing two deep, or in two
ranks.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The number of <xex>files</xex> in a company describes
its width, as the number of ranks does its depth; thus, 100 men in
<ldquo/fours deep<rdquo/ would be spoken of as 25 <xex>files</xex> in 4
ranks. <rj><au>Farrow.</au></rj> </note></p>

<p><sd>(b)</sd> <def>An orderly collection of papers, arranged in
sequence or classified for preservation and reference; as,
<xex>files</xex> of letters or of newspapers; this mail brings English
<xex>files</xex> to the 15th instant.</def> <sd>(c)</sd> <def>The line,
wire, or other contrivance, by which papers are put and kept in
order.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It is upon a <qex>file</qex> with the duke's other letters.</q>
<rj><qau>Shak.</qau></rj></p>

<p><sd>(d)</sd> <def>A roll or list.</def> <ldquo/A <xex>file</xex> of
all the gentry.<rdquo/ <rj><au>Shak.</au></rj></p>

<p><sn>2.</sn> <def>Course of thought; thread of narration.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Let me resume the <qex>file</qex> of my narration.</q>
<rj><qau>Sir H. Wotton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(computers)</fld> <def>a collection of data on a
digital recording medium treated as a unit for the purpose of recording,
reading, storage, or indexing; -- such a <ex>file</ex> is typically
accessible by computer programs by the use of a file name. The data may
be of any type codable digitally, such as simple ASCII-coded text,
complex binary-coded data, or an executable program, or may be itself a
collection of other files.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>File firing</b></col>, <cd>the act of firing by file, or
each file independently of others.</cd> -- <col><b>File
leader</b></col>, <cd>the soldier at the front of any file, who covers
and leads those in rear of him.</cd> -- <col><b>File marching</b></col>,
<cd>the marching of a line two deep, when faced to the right or left, so
that the front and rear rank march side by side.</cd> <au>Brande &
C.</au> --<mcol><col><b>Indian file</b></col>, <it>or</it>
<col><b>Single file</b></col></mcol>, <cd>a line of people marching one
behind another; a single row. Also used adverbially; as, to march
<ex>Indian file</ex>.</cd> -- <col><b>On file</b></col>, <cd>preserved
in an orderly collection; recorded in some database.</cd> --
<col><b>Rank and file</b></col>. <sd>(a)</sd> <cd>The body of soldiers
constituting the mass of an army, including corporals and privates.</cd>
<au>Wilhelm.</au> <sd>(b)</sd> <cd>Those who constitute the bulk or
working members of a party, society, etc., in distinction from the
leaders.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>File</ent><br/
<hw>File</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Filed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Filing</conjf>.]</vmorph> <sn>1.</sn> <def>To set in order; to
arrange, or lay away, esp. as papers in a methodical manner for
preservation and reverence; to place on file; to insert in its proper
place in an arranged body of papers.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I would have my several courses and my dishes well
<qex>filed</qex>.</q> <rj><qau>Beau. & Fl.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To bring before a court or legislative body by
presenting proper papers in a regular way; <as>as, to <ex>file</ex> a
petition or bill</as>.</def> <rj><au>Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Law)</fld> <def>To put upon the files or among the
records of a court; to note on (a paper) the fact date of its reception
in court.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>file</qex> a paper, on the part of a party, is to place it
in the official custody of the clerk. To <qex>file</qex>, on the part of
the clerk, is to indorse upon the paper the date of its reception, and
retain it in his office, subject to inspection by whomsoever it may
concern.</q> <rj><qau>Burrill.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>File</ent><br/
<hw>File</hw>, <pos>v. i.</pos> <ety>[Cf. F. <ets>filer</ets>.]</ety>
<fld>(Mil.)</fld> <def>To march in a file or line, as soldiers, not
abreast, but one after another; -- generally with
<xex>off</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To file with</b></col>, <cd>to follow closely, as one
soldier after another in file; to keep pace.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><q>My endeavors<br/
Have ever come too short of my desires,<br/
Yet <qex>filed with</qex> my abilities.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>File</ent><br/
<hw>File</hw> <pr>(f<imac/l)</pr>, <pos>n.</pos> <ety>[AS.
<ets>fe<oacute/l</ets>; akin to D. <ets>viji</ets>, OHG.
<ets>f<imac/la</ets>, <ets>f<imac/hala</ets>, G. <ets>feile</ets>, Sw.
<ets>fil</ets>, Dan. <ets>fiil</ets>, cf. Icel.
<ets><thorn/<emac/l</ets>, Russ. <ets>pila</ets>, and Skr.
<ets>pi<cced/</ets> to cut out, adorn; perh. akin to E.
<ets>paint</ets>.]</ety> <sn>1.</sn> <def>A steel instrument, having
cutting ridges or teeth, made by indentation with a chisel, used for
abrading or smoothing other substances, as metals, wood, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ A <xex>file</xex> differs from a <xex>rasp</xex> in
having the furrows made by straight cuts of a chisel, either single or
crossed, while the rasp has coarse, single teeth, raised by the
pyramidal end of a triangular punch.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Anything employed to smooth, polish, or rasp,
literally or figuratively.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Mock the nice touches of the critic's <qex>file</qex>.</q>
<rj><qau>Akenside.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A shrewd or artful person.</def>
<mark>[Slang]</mark> <rj><au>Fielding.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Will is an old <qex>file</qex> in spite of his smooth face.</q>
<rj><qau>Thackeray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Bastard file</b></col>, <col><b>Cross
file</b></col></mcol>, <cd>etc. See under <er>Bastard</er>,
<er>Cross</er>, etc.</cd> -- <col><b>Cross-cut file</b></col>, <cd>a
file having two sets of teeth crossing obliquely.</cd> -- <col><b>File
blank</b></col>, <cd>a steel blank shaped and ground ready for cutting
to form a file.</cd> -- <col><b>File cutter</b></col>, <cd>a maker of
files.</cd> -- <col><b>Second-cut file</b></col>, <cd>a file having
teeth of a grade next finer than bastard.</cd> -- <col><b>Single-cut
file</b></col>, <cd>a file having only one set of parallel teeth; a
float.</cd> -- <col><b>Smooth file</b></col>, <cd>a file having teeth so
fine as to make an almost smooth surface.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>File</ent><br/
<hw>File</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To rub, smooth, or cut
away, with a file; to sharpen with a file; <as>as, to <ex>file</ex> a
saw or a tooth</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To smooth or polish as with a file.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>File</qex> your tongue to a little more courtesy.</q>
<rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>File</ent><br/
<hw>File</hw>, <pos>v. t.</pos> <ety>[OE. <ets>fulen</ets>,
<ets>filen</ets>, <ets>foulen</ets>, AS. <ets>f<?/lan</ets>, fr. f<?/l
foul. See <er>Foul</er>, and cf. <er>Defile</er>, <pos>v.
t.</pos>]</ety> <def>To make foul; to defile.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>All his hairy breast with blood was <qex>filed</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>For Banquo's issue have I <qex>filed</qex> my mind.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>File closer</ent><br/
<hw>File" clos`er</hw>. <fld>(Mil.)</fld> <def>A commissioned or
noncommissioned officer posted in the rear of a line, or on the flank of
a column, of soldiers, to rectify mistakes and insure steadiness and
promptness in the ranks.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Filefish</ent><br/
<hw>File"fish`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>Any plectognath fish of the genera <gen>Monacanthus</gen>,
<gen>Alutera</gen>, <gen>balistes</gen>, and allied genera; -- so called
on account of the roughly granulated skin, which is sometimes used in
place of sandpaper.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Filemot</ent><br/
<hw>Fil"e*mot</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Feullemort</er>.</def> <rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Filer</ent><br/
<hw>Fil"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who works with a
file.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Filial</ent><br/
<hw>Fil"ial</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>filialis</ets>, fr. <ets>filius</ets> son, <ets>filia</ets>
daughter; akin to e. <ets>female</ets>, <ets>feminine</ets>. Cf.
<er>Fitz</er>.]</ety> <sn>1.</sn> <def>Of or pertaining to a son or
daughter; becoming to a child in relation to his parents; <as>as,
<ex>filial</ex> obedience</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Bearing the relation of a child.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And thus the <qex>filial</qex> Godhead answering spoke.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Filially</ent><br/
<hw>Fil"ial*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a filial
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Filiate</ent><br/
<hw>Fil"i*ate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To adopt as son
or daughter; to establish filiation between.</def> <mark>[R.]</mark>
<rj><au>Southey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Filiation</ent><br/
<hw>Fil`i*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL.
<ets>filiatio</ets>, fr. L. <ets>filius</ets> son: cf. F.
<ets>filiation</ets>. See <er>Filial</er>.]</ety> <sn>1.</sn> <def>The
relationship of a son or child to a parent, esp. to a father.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The relation of paternity and <qex>filiation</qex>.</q>
<rj><qau>Sir M. Hale.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>The assignment of a bastard child
to some one as its father; affiliation.</def>
<rj><au>Smart.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Descent from, or as if from, a parent; relationship
like that of a son; <as>as, to determine the <ex>filiation</ex> of a
language</as>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>4.</sn> <def>One that is derived from a parent or source; an
offshoot; <as>as, the <ex>filiations</ex> are from a common
stock</as>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Filibeg</ent><br/
<hw>Fil"i*beg</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gael.
<ets>feileadhbeag</ets>, <it>i. e.</it>, little kilt;
<ets>feileadh</ets> kilt + <ets>beag</ets> little, small; cf.
<ets>filleadh</ets> a plait, fold.]</ety> <def>Same as
<er>Kilt</er>.</def> <altsp>[Written also
<asp>philibeg</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Filibuster</ent><br/
<hw>Fil"i*bus`ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sp.
<ets>flibuster</ets>, <ets>flibustero</ets>, corrupted fr. E.
<ets>freebooter</ets>. See <er>Freebooter</er>.]</ety> <def>A lawless
military adventurer, especially one in quest of plunder; a freebooter;
-- originally applied to buccaneers infesting the Spanish American
coasts, but introduced into common English to designate the followers of
<persfn>Lopez</persfn> in his expedition to Cuba in 1851, and those of
<persfn>Walker</persfn> in his expedition to Nicaragua, in
1855.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Filibuster</ent><br/
<hw>Fil"i*bus*ter</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Fillibustered</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Filibustering</conjf>.]</vmorph> <sn>1.</sn> <def>To act
as a filibuster, or military freebooter.</def>
<rj><au>Bartlett.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To delay legislation, by dilatory motions or other
artifices.</def> <mark>[political cant or slang, U.S.]</mark>
<rj><au>Bartlett.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Filibusterism</ent><br/
<hw>Fil"i*bus`ter*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The
characteristics or practices of a filibuster.</def>
<rj><au>Bartlett.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Filical</ent><br/
<hw>Fil"i*cal</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Belonging to the
<xex>Filices</xex>, r ferns.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Filicic</ent><br/
<hw>Fi*lic"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>filix</ets>, <ets>-icis</ets>, a fern.]</ety> <fld>(Chem.)</fld>
<def>Pertaining to, or derived from, ferns; <as>as, <ex>filicic</ex>
acid</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Filicide</ent><br/
<hw>Fil"i*cide</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>filius</ets> son, <ets>filia</ets> daughter + <ets>caedere</ets> to
kill.]</ety> <def>The act of murdering a son or a daughter; also, parent
who commits such a murder.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Filiciform</ent><br/
<hw>Fi*lic"i*form</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>filix</ets>, <ets>-icis</ets>, fern + <ets>-form</ets>: cf. F.
<ets>filiciforme</ets>]</ety> <def>Shaped like a fern or like the parts
of a fern leaf.</def> <rj><au>Smart.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Filicoid</ent><br/
<hw>Fil"i*coid</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>filix</ets>, <ets>-icis</ets>, fern + <ets>-oid</ets>: cf. F.
<ets>filicoi<ium/de</ets>.]</ety> <fld>(Bot.)</fld> <def>Fernlike,
either in form or in the nature of the method of reproduction.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Filicoid</ent><br/
<hw>Fil"i*coid</hw>, <pos>n.</pos> <fld>(Bot.)</fld> <def>A fernlike
plant.</def> <rj><au>Lindley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Filiety</ent><br/
<hw>Fi*li"e*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>filietas</ets>.]</ety> <def>The relation of a son to a father;
sonship; -- the correlative of <xex>paternity</xex>.</def> <rj><au>J. S.
Mill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Filiferous</ent><br/
<hw>Fi*lif"er*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>filum</ets> a thread + <ets>-ferous</ets>.]</ety> <def>Producing
threads.</def> <rj><au>Carpenter.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>filiform</ent><br/
<hw>fil"i*form</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>filum</ets> thread + <ets>-form</ets>: cf. F.
<ets>filiforme</ets>.]</ety> <def>Having the shape of a thread or
filament; <as>as, the <ex>filiform</ex> papill<ae/ of the tongue; a
<ex>filiform</ex> style or peduncle.</as> See <ex>Illust</ex>. of
<er>Antenn<ae/</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Filigrane</ent><br/
<ent>Filigrain</ent><br/
<mhw>{ <hw>Fil"i*grain</hw>, <hw>Fil"i*grane</hw> }</mhw> <pr>(?)</pr>,
<pos>n.</pos> <ety>[Sp. <ets>filigrana</ets> (cf. It.
<ets>filigrana</ets>, E. <ets>filigrane</ets>), fr. L. <ets>filum</ets>a
thread + <ets>granum</ets> grain. See <er>File</er> a row, and
<er>Grain</er>, and cf. <er>Filigree</er>.]</ety> <def>Filigree.</def>
<mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>With her head . . . touches the crown of <qex>filigrane</qex>.</q>
<rj><qau>Longfellow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Filigraned</ent><br/
<hw>Fil"i*graned</hw> <pr>(?)</pr>, <pos>a.</pos> <def>See
<er>Filigreed</er>.</def> <mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Filigree</ent><br/
<hw>Fil"i*gree</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Corrupted fr.
<ets>filigrane</ets>.]</ety> <def>Ornamental work, formerly with grains
or breads, but now composed of fine wire and used chiefly in decorating
gold and silver to which the wire is soldered, being arranged in designs
frequently of a delicate and intricate arabesque pattern.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Filigree</ent><br/
<hw>Fil"i*gree</hw>, <pos>a.</pos> <def>Relating to, composed of, or
resembling, work in filigree; <as>as, a <ex>filigree</ex> basket</as>.
Hence: Fanciful; unsubstantial; merely decorative.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>You ask for reality, not fiction and <qex>filigree</qex> work.</q>
<rj><qau>J. C. Shairp.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Filigreed</ent><br/
<hw>Fil"i*greed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Adorned with
filigree.</def> <rj><au>Tatler.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Filing</ent><br/
<hw>Fil"ing</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A fragment or particle
rubbed off by the act of filing; <as>as, iron
<ex>filings</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Filioque</ent><br/
\'d8<hw>Fil`i*o"que</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Eccl.
Hist.)</fld> <def>The Latin for, <ldquo/and from the Son,<rdquo/
equivalent to <xex>et filio</xex>, inserted by the third council of
Toledo (<sc>a. d.</sc> 589) in the clause <xex>qui ex Patre
procedit</xex> (who proceedeth from the Father) of the
Niceno-Constantinopolitan Creed (<sc>a. d.</sc> 381), which makes a
creed state that the Holy Ghost proceeds from the Son as well as from
the Father. Hence, the doctrine itself (not admitted by the Eastern
Church).</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Filipendulous</ent><br/
<hw>Fil`i*pen"du*lous</hw> <pr>(?; 135)</pr>, <pos>a.</pos> <ety>[L.
<ets>filum</ets> a thread + <ets>pendulus</ets> hanging, fr.
<ets>pend<emac/re</ets> to hang.]</ety> <fld>(Bot.)</fld> <def>Suspended
by, or strung upon, a thread; -- said of tuberous swellings in the
middle or at the extremities of slender, threadlike rootlets.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Filipino</ent><br/
<hw>Filipino</hw> <pos>adj.</pos> <sn>1.</sn> <def>of or relating to the
Philippines or its people or customs.</def><br/
<syn><b>Syn. --</b> Philippine.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>of or relating to the language of the
Philippines.</def><br/
<syn><b>Syn. --</b> Tagalog.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Filipino</ent><br/
<hw>Fil`i*pi"no</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu>pl.
<plw>Filipinos</plw> <pr>(#)</pr></plu>. <ety>[Sp.]</ety> <def>A native
or inhabitant of the Philippine Islands, specif. one of Spanish descent
or of mixed blood.</def> <wns>[wns=1]</wns></p>

<p><q>Then there are <qex>Filipinos</qex>, -- <ldquo/children of the
country,<rdquo/ they are called, -- who are supposed to be pure-blooded
descendants of Spanish settlers. But there are few of them without some
touch of Chinese or native blood.</q> <rj><qau>The
Century.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>the official language of the Philippines, based on
Tagalog. It draws its lexicon from other Philippine languages.</def>
<wns>[wns=2]</wns><br/
<syn><b>Syn. --</b> Philippine.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fill</ent><br/
<hw>Fill</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Thill</er>.]</ety> <def>One of the thills or shafts of a
carriage.</def> <rj><au>Mortimer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fill horse</b></col>, <cd>a thill horse.</cd>
<rj><au>Shak.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fill</ent><br/
<hw>Fill</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Filled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Filling</conjf>.]</vmorph> <ety>[OE. <ets>fillen</ets>,
<ets>fullen</ets>, AS. <ets>fyllan</ets>, fr. <ets>full</ets> full; akin
to D. <ets>vullen</ets>, G. <ets>f<uum/llen</ets>, Icel.
<ets>fylla</ets>, Sw. <ets>fylla</ets>, Dan. <ets>fylde</ets>, Goth.
<ets>fulljan</ets>. See <er>Full</er>, <pos>a.</pos>]</ety> <sn>1.</sn>
<def>To make full; to supply with as much as can be held or contained;
to put or pour into, till no more can be received; to occupy the whole
capacity of.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The rain also <qex>filleth</qex> the pools.</q> <rj><qau>Ps.
lxxxiv. 6.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Jesus saith unto them, <qex>Fill</qex> the waterpots with water.
Anf they <qex>filled</qex> them up to the brim.</q> <rj><qau>John ii.
7.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To furnish an abudant supply to; to furnish with as
mush as is desired or desirable; to occupy the whole of; to swarm in or
overrun.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And God blessed them, saying. Be fruitful, and multiply, and
<qex>fill</qex> the waters in the seas.</q> <rj><qau>Gen. i.
22.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The Syrians <qex>filled</qex> the country.</q> <rj><qau>1 Kings
xx. 27.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To fill or supply fully with food; to feed; to
satisfy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Whence should we have so much bread in the wilderness, as to
<qex>fill</qex>so great a multitude?</q> <rj><qau>Matt. xv.
33.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Things that are sweet and fat are more <qex>filling</qex>.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To possess and perform the duties of; to officiate
in, as an incumbent; to occupy; to hold; <as>as, a king <ex>fills</ex> a
throne; the president <ex>fills</ex> the office of chief magistrate; the
speaker of the House <ex>fills</ex> the chair.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To supply with an incumbent; <as>as, to
<ex>fill</ex> an office or a vacancy</as>.</def> <rj><au>A.
Hamilton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Naut.)</fld> <sd>(a)</sd> <def>To press and dilate,
as a sail; <as>as, the wind <ex>filled</ex> the sails</as>.</def>
<sd>(b)</sd> <def>To trim (a yard) so that the wind shall blow on the
after side of the sails.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Civil Engineering)</fld> <def>To make an embankment
in, or raise the level of (a low place), with earth or gravel.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To fill in</b></col>, <cd>to insert; as, he <xex>filled
in</xex> the figures.</cd> -- <col><b>To fill out</b></col>, <cd>to
extend or enlarge to the desired limit; to make complete; as, to
<xex>fill out</xex> a bill.</cd> -- <col><b>To fill up</b></col>, <cd>to
make quite full; to fill to the brim or entirely; to occupy completely;
to complete.</cd> <ldquo/The bliss that <xex>fills up</xex> all the
mind.<rdquo/ <au>Pope.</au> <ldquo/And <xex>fill up</xex> that which is
behind of the afflictions of Christ.<rdquo/ <au>Col. i.
24.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fill</ent><br/
<hw>Fill</hw> <pr>(?)</pr>, <pos>v. i.</pos> <sn>1.</sn> <def>To become
full; to have the whole capacity occupied; to have an abundant supply;
to be satiated; <as>as, corn <ex>fills</ex> well in a warm season; the
sail <ex>fills</ex> with the wind.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To fill a cup or glass for drinking.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Give me some wine; <qex>fill</qex> full.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To back and fill</b></col>. See under <er>Back</er>,
<pos>v. i.</pos> -- <col><b>To fill up</b></col>, <cd>to grow or become
quite full; as, the channel of the river <xex>fills up</xex> with
sand.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fill</ent><br/
<hw>Fill</hw>, <pos>n.</pos> <ety>[AS. <ets>fyllo</ets>. See
<er>Fill</er>, <pos>v. t.</pos>]</ety> <sn>1.</sn> <def>A full supply,
as much as supplies want; as much as gives complete satisfaction.</def>
<ldquo/Ye shall eat your <xex>fill</xex>.<rdquo/ <rj><au>Lev. xxv.
19.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I'll bear thee hence, where I may weep my <qex>fill</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which fills; filling; filler; specif., an
embankment, as in railroad construction, to fill a hollow or ravine;
also, the place which is to be filled.</def><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><ent>Filled cheese</ent><br/
<hw>Filled cheese</hw>. <def>An inferior kind of cheese made from skim
milk with a fatty <ldquo/filling,<rdquo/ such as oleomargarine or lard,
to replace the fat removed in the cream.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>fillagree</ent><br/
<hw>fillagree</hw> <pos>n.</pos> <def>variant spelling of
<er>filigree</er>.</def><br/
<syn><b>Syn. --</b> filigree, filagree.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>fille</ent><br/
<hw>fille</hw> <pos>n.</pos> <def>a young unmarried woman.</def><br/
<syn><b>Syn. --</b> girl, filly, miss, missy, gal, young lady, young
woman.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>filled</ent><br/
<hw>filled</hw> <pos>adj.</pos> <sn>1.</sn> <def>containing as much or
as many as is possible or normal; <as>as, <ex>filled</ex> to
overflowing</as>. Opposite of <ant>empty</ant>.</def> [Narrower terms:
<stype>abounding in(predicate), abounding with(predicate), bristling
with(predicate), full of(predicate), overflowing, overflowing
with(predicate), rich in(predicate), rife with(predicate), thick
with(predicate)</stype>; <stype>brimful, brimful of(predicate),
brimfull, brimfull of(predicate), brimming, brimming
with(predicate)</stype>; <stype>chockablock(predicate),
chock-full(predicate), chockfull(predicate), chockful(predicate),
choke-full(predicate), chuck-full(predicate), cram full</stype>;
<stype>congested, engorged</stype>; <stype>crawling with(predicate),
overrun with, swarming, swarming with(predicate), teeming, teeming
with(predicate)</stype>; <stype>flooded, inundated, swamped </stype>;
<stype>glutted, overfull</stype>; <stype>heavy with(predicate) </stype>;
<stype>laden, loaded </stype>; <stype>overladen, overloaded </stype>;
<stype>stuffed </stype>; <stype>stuffed</stype>; <stype>well-lined
</stype>]<br/
<syn><b>Syn. --</b> full.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>entirely of one substance with no holes inside.
Opposite of <ant>hollow</ant>.</def><br/
<syn><b>Syn. --</b> solid.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>3.</sn> <def>having appointments throughout the course of a
period; -- of an appointment schedule; <as>as, My calendar is
<ex>filled</ex> for the week</as>. Opposite of <ant>unoccupied</ant> and
<ant>free</ant></def><br/
<syn><b>Syn. --</b> occupied.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Filler</ent><br/
<hw>Fill"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who,
or that which, fills; something used for filling.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>'T is mere <qex>filler</qex>, to stop a vacancy in the
hexameter.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>They have six diggers to four <qex>fillers</qex>, so as to keep
the <qex>fillers</qex> always at work.</q>
<rj><qau>Mortimer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Paint.)</fld> <def>A composition, as of powdered
silica and oil, used to fill the pores and grain of wood before applying
paint, varnish, etc.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>3.</sn> <fld>(Forestry)</fld> <def>Any standing tree or standard
higher than the surrounding coppice in the form of forest known as
<membof>coppice under standards</membof>. Chiefly used in the
<pluf>pl.</pluf></def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Filler</ent><br/
<hw>Fill"er</hw>, <pos>n.</pos> <ety>[From 1st <er>Fill</er>.]</ety>
<def>A thill horse.</def> <mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fillet</ent><br/
<hw>Fil"let</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>filet</ets>,
<ets>felet</ets>, fr. OF. <ets>filet</ets> thread, fillet of meat, dim.
of <ets>fil</ets> a thread, fr. L. <ets>filum</ets>. See <er>Fille</er>
a row.]</ety> <sn>1.</sn> <def>A little band, especially one intended to
encircle the hair of the head.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A belt her waist, a <qex>fillet</qex> binds her hair.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Cooking)</fld> <def>A piece of lean meat without
bone; sometimes, a long strip rolled together and tied.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ A <xex>fillet</xex> of beef is the under side of the
sirlom; also called <xex>tenderloin</xex>. A <xex>fillet</xex> of veal
or mutton is the fleshy part of the thigh. A <xex>fillet</xex> of fish
is a slice of flat fish without bone. <ldquo/<xex>Fillet</xex> of a
fenny snake.<rdquo/</note> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A thin strip or ribbon; esp.: <sd>(a)</sd> A strip
of metal from which coins are punched. <sd>(b)</sd> A strip of card
clothing. <sd>(c)</sd> A thin projecting band or strip.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Mach.)</fld> <def>A concave filling in of a
re<eum/ntrant angle where two surfaces meet, forming a rounded
corner.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Arch.)</fld> <def>A narrow flat member; especially,
a flat molding separating other moldings; a reglet; also, the space
between two flutings in a shaft. See <xex>Illust.</xex> of
<er>Base</er>, and <er>Column</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Her.)</fld> <def>An ordinary equaling in breadth
one fourth of the chief, to the lowest portion of which it corresponds
in position.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Mech.)</fld> <def>The thread of a screw.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>A border of broad or narrow lines of color or
gilt.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>The raised molding about the muzzle of a
gun.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <def>Any scantling smaller than a batten.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>11.</sn> <fld>(Anat.)</fld> <def>A fascia; a band of fibers;
applied esp. to certain bands of white matter in the brain.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>12.</sn> <fld>(Man.)</fld> <def>The loins of a horse, beginning
at the place where the hinder part of the saddle rests.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Arris fillet</b></col>. <cd>See under
<er>Arris</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fillet</ent><br/
<hw>Fil"let</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Filleted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Filleting</conjf>.]</vmorph> <def>To bind, furnish, or adorn with
a fillet.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Filleting</ent><br/
<hw>Fil"let*ing</hw>, <pos>n.</pos> <sn>1.</sn> <fld>(Arch.)</fld>
<def>The protecting of a joint, as between roof and parapet wall, with
mortar, or cement, where <xex>flashing</xex> is employed in better
work.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The material of which fillets are made; also,
fillets, collectively.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fillibeg</ent><br/
<hw>Fil"li*beg</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A kilt. See
<er>Filibeg</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fillibuster</ent><br/
<hw>Fil"li*bus`ter</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Filibuster</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Filling</ent><br/
<hw>Fill"ing</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>That
which is used to fill a cavity or any empty space, or to supply a
deficiency; <as>as, <ex>filling</ex> for a cavity in a tooth, a
depression in a roadbed, the space between exterior and interior walls
of masonry, the pores of open-grained wood, the space between the outer
and inner planks of a vessel, etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The woof in woven fabrics.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Brewing)</fld> <def>Prepared wort added to ale to
cleanse it.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Back filling</b></col>. <fld>(Arch.)</fld> <cd>See under
<er>Back</er>, <pos>a.</pos></cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fillip</ent><br/
<hw>Fil"lip</hw> <pr>(f<icr/l"l<icr/p)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Filliped</conjf> <pr>(?)</pr>;
<pos>p. pr. & vb. n.</pos> <conjf>Filliping</conjf>.]</vmorph> <ety>[For
<ets>filp</ets>, <ets>flip</ets>. Cf. <er>Flippant</er>.]</ety>
<sn>1.</sn> <def>To strike with the nail of the finger, first placed
against the ball of the thumb, and forced from that position with a
sudden spring; to snap with the finger.</def> <ldquo/You
<xex>fillip</xex> me o' the head.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To snap; to project quickly.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The use of the elastic switch to <qex>fillip</qex> small missiles
with.</q> <rj><qau>Tylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fillip</ent><br/
<hw>Fil"lip</hw>, <pos>n.</pos> <sn>1.</sn> <def>A jerk of the finger
forced suddenly from the thumb; a smart blow.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Something serving to rouse or excite.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I take a glass of grog for a <qex>filip</qex>.</q>
<rj><qau>Dickens.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fillipeen</ent><br/
<hw>Fil"li*peen`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Philopena</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fillister</ent><br/
<hw>Fil"lis*ter</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
rabbet on the outer edge of a sash bar to hold the glass and the
putty.</def> <rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A plane for making a rabbet.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fillister screw had</b></col>, <cd>a short cylindrical
screw head, having a convex top.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Filly</ent><br/
<hw>Fil"ly</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Fillies</plw> <pr>(#)</pr>.</plu> <ety>[Cf. Icel. <ets>fylia</ets>,
<ets>fr</ets>. <ets>foli</ets> foal. See <er>Foal</er>.]</ety>
<sn>1.</sn> <fld>(Zool.)</fld> <def>A female foal or colt; a young mare.
Cf. <er>Colt</er>, <er>Foal</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Neighing in likeness of a <qex>filly</qex> foal.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A lively, spirited young girl.</def>
<mark>[Colloq.]</mark> <rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Film</ent><br/
<hw>Film</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS. <ets>film</ets>
skin, fr. <ets>fell</ets> skin; akin to <ets>fylmen</ets> membrane,
OFries. <ets>filmene</ets> skin. See <er>Fell</er> skin.]</ety>
<sn>1.</sn> <def>A thin skin; a pellicle; a membranous covering, causing
opacity.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He from thick <qex>films</qex> shall purge the visual ray.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>hence, any thin layer covering a surface.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>3.</sn> <def>A slender thread, as that of a cobweb.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Her whip of cricket's bone, the lash of <qex>film</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Photog.)</fld> <def>The layer, usually of gelatin
or collodion, containing the sensitive salts of photographic
plates.</def><br/
[<source>PJC</source>]</p>

<p><sn>5.</sn> <fld>(Photog.)</fld> <def>a flexible sheet of celluloid
or other plastic material to which a light-sensitive layer has been
applied, used for recording images by the processes of photography. It
is commonly used in rolls mounted within light-proof canisters suitable
for simple insertion into cameras designed for such canisters. On such
rolls, varying numbers of photographs may be taken before the canister
needs to be replaced.</def><br/
[<source>PJC</source>]</p>

<p><sn>6.</sn> <def>a motion picture.</def><br/
[<source>PJC</source>]</p>

<p><sn>7.</sn> <def>the art of making motion pictures; -- used mostly in
the phrase <it>the film</it>.</def><br/
[<source>PJC</source>]</p>

<p><sn>8.</sn> <def>a thin transparent sheet of plastic, used for
wrapping objects; <as>as, polyethylene <ex>film</ex></as>.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Celluloid film</b></col> <fld>(Photog.)</fld>, <cd>a thin
flexible sheet of celluloid, coated with a sensitized emulsion of
gelatin, and used as a substitute for photographic plates.</cd> --
<col><b>Cut film</b></col> <fld>(Photog.)</fld>, <cd>a celluloid film
cut into pieces suitable for use in a camera.</cd></cs><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Film</ent><br/
<hw>Film</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To cover with a thin
skin or pellicle.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It will but skin and <qex>film</qex> the ulcerous place.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>to make a motion picture of (any event or literary
work); to record with a movie camera; <as>as, to <ex>film</ex> the
inauguration ceremony; to <ex>film</ex> Dostoevsky's Crime and
Punishment or Tolstoy's War and Peace</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>filmable</ent><br/
<hw>filmable</hw> <pos>adj.</pos> <def>readily adaptable to motion
picture form; -- of books, plays, and other works of
literature.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>filmed</ent><br/
<hw>filmed</hw> <pos>adj.</pos> <def>recorded on film.</def><br/
<syn><b>Syn. --</b> canned, taped, tape-recorded, transcribed.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Filminess</ent><br/
<hw>Film"i*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>State of being
filmy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>filmmake</ent><br/
<hw>filmmake</hw> <pos>v. i.</pos> <def>to make films; be a film
maker.</def><br/
<syn><b>Syn. --</b> film-make.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Filmy</ent><br/
<hw>Film"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Composed of film or
films.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Whose <qex>filmy</qex> cord should bind the struggling fly.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Filoplumaceous</ent><br/
<hw>Fil`o*plu*ma"ceous</hw> <pr>(?)</pr>, <pos>a.</pos>
<fld>(Zool.)</fld> <def>Having the structure of a filoplume.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Filoplume</ent><br/
<hw>Fil"o*plume</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>filum</ets> a thread <?/ <ets>pluma</ets> a soft feather.]</ety>
<fld>(Zool.)</fld> <def>A hairlike feather; a father with a slender
scape and without a web in most or all of its length.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 560 --></p>

<p><ent>Filose</ent><br/
<hw>Fi"lose`</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>filum</ets>
a thread.]</ety> <def>Terminating in a threadlike process.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Filoselle</ent><br/
<hw>Fil`o*selle"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., floss
silk.]</ety> <def>A kind of silk thread less glossy than floss, and spun
from coarser material. It is much used in embroidery instead of
floss.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Fils</ent><br/
\'d8<hw>Fils</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr. L.
<ets>filius</ets>. See <er>Filial</er>.]</ety> <def>Son; -- sometimes
used after a French proper name to distinguish a son from his father,
<as>as, Alexandre Dumas, <ex>fils</ex></as>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Filter</ent><br/
<hw>Fil"ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>filtre</ets>,
the same word as <ets>feutre</ets> felt, LL. <ets>filtrum</ets>,
<ets>feltrum</ets>, felt, fulled wool, this being used for straining
liquors. See <er>Feuter</er>.]</ety> <def>Any porous substance, as
cloth, paper, sand, or charcoal, through which water or other liquid may
passed to cleanse it from the solid or impure matter held in suspension;
a chamber or device containing such substance; a strainer; also, a
similar device for purifying air.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Filter bed</b></col>, <cd>a pond, the bottom of which is
a filter composed of sand gravel.</cd> -- <col><b>Filter
gallery</b></col>, <cd>an underground gallery or tunnel, alongside of a
stream, to collect the water that filters through the intervening sand
and gravel; -- called also <altname>infiltration
gallery</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Filter</ent><br/
<hw>Fil"ter</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Filtered</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Filtering</conjf>]</vmorph> <ety>[Cf. F. <ets>filter</ets>. See
<er>Filter</er>, <pos>n.</pos>, and cf. <er>Filtrate</er>.]</ety>
<def>To purify or defecate, as water or other liquid, by causing it to
pass through a filter.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Filtering paper</b></col>, <it>or</it>
<col><b>Filter paper</b></col></mcol>, <cd>a porous unsized paper, for
filtering.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Filter</ent><br/
<hw>Fil"ter</hw>, <pos>v. i.</pos> <def>To pass through a filter; to
percolate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Filter</ent><br/
<hw>Fil"ter</hw>, <pos>n.</pos> <def>Same as <er>Philter</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>filter-tipped</ent><br/
<hw>filter-tipped</hw> <pos>adj.</pos> <def>having a tip designed to
filter the smoke; -- of a cigarette or cigar; <as>as,
<ex>filter-tipped</ex> cigarettes</as>.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Filth</ent><br/
<hw>Filth</hw> <pr>(f<icr/lth)</pr>, <pos>n.</pos> <ety>[OE.
<ets>filthe</ets>, <ets>ful<edh/e</ets>, AS. <ets>f<ymac/l<edh/</ets>,
fr. <ets>f<umac/l</ets> foul; akin to OHG. <ets>f<umac/lida</ets>. See
<er>Foul</er>, and cf. <er>File</er>.]</ety> <sn>1.</sn> <def>Foul
matter; anything that soils or defiles; dirt; nastiness.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Anything that sullies or defiles the moral
character; corruption; pollution.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To purify the soul from the dross and <qex>filth</qex> of sensual
delights.</q> <rj><qau>Tillotson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Filth disease</b></col> <fld>(Med.)</fld>, <cd>a disease
supposed to be due to pollution of the soil or water.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Filthily</ent><br/
<hw>Filth"i*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a filthy
manner; foully.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Filthiness</ent><br/
<hw>Filth"i*ness</hw>, <pos>n.</pos> <sn>1.</sn> <def>The state of being
filthy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Let us cleanse ourselves from all <qex>filthiness</qex> of the
flesh and spirit.</q> <rj><qau>2 Cor. vii. 1.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is filthy, or makes filthy; foulness;
nastiness; corruption; pollution; impurity.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Carry forth the <qex>filthiness</qex> out of the holy place.</q>
<rj><qau>2 Chron. xxix. 5.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Filthy</ent><br/
<hw>Filth"y</hw> <pr>(?)</pr>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Filthier</adjf> <pr>(?)</pr>; <pos>superl.</pos>
<adjf>Filthiest</adjf>.]</amorph> <def>Defiled with filth, whether
material or moral; nasty; dirty; polluted; foul; impure; obscene.</def>
<ldquo/In the <xex>filthy</xex>-mantled pool.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He which is <qex>filthy</qex> let him be <qex>filthy</qex>
still.</q> <rj><qau>Rev. xxii. 11.</qau></rj></p>

<p><syn><b>Syn.</b> -- Nasty; foul; dirty; squalid; unclean; sluttish;
gross; vulgar; licentious. See <er>Nasty</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Filtrate</ent><br/
<hw>Fil"trate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Filtrated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Filtrating</conjf>. <pr>(<?/)</pr>]</vmorph> <ety>[Cf.
LL. <ets>filtrare</ets>. See <er>Filter</er>.]</ety> <def>To filter; to
defecate; as liquid, by straining or percolation.</def>
<rj><au>Arbuthnot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Filtrate</ent><br/
<hw>Fil"trate</hw> <pr>(?)</pr>, <pos>n.</pos> <def>That which has been
filtered; the liquid which has passed through the filter in the process
of filtration. Contrasted with <contr>retentate</contr>, the material
remaining on the filter.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Filtration</ent><br/
<hw>Fil*tra"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>filtration</ets>.]</ety> <def>The act or process of filtering; the
mechanical separation of a liquid from the undissolved particles
floating in it.</def></p>

<p><ent>Fimble hemp</ent><br/
<ent>Fimble</ent><br/
<mhw>{ <hw>Fim"ble</hw>, <pos>n.</pos>, <it>or</it> <hw>Fim"ble
hemp`</hw> <pr>(f<icr/m"b'l h<ecr/mp`)</pr>. }</mhw><ety>[Corrupted from
<ets>female hemp</ets>.]</ety> <def>Light summer hemp, that bears no
seed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fimbria</ent><br/
\'d8<hw>Fim"bri*a</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Fimbri<ae/</plw> <pr>(#)</pr>.</plu> <ety>[L., fringe. See
<er>Fringle</er>.]</ety> <fld>(Anat.)</fld> <sd>(a)</sd>
<pluf>pl.</pluf> <def>A fringe, or fringed border.</def> <sd>(b)</sd>
<def>A band of white matter bordering the hippocampus in the
brain.</def> -- <wordforms><wf>Fim"bri*al</wf> <pr>(#)</pr>,
<pos>a.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fimbriate</ent><br/
<hw>Fim*bri*ate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>fimbriatus</ets> fibrous, fringed, fr. <ets>fimbria</ets> fiber,
fringe. See <er>Fringe</er>.]</ety> <def>Having the edge or extremity
bordered by filiform processes thicker than hairs; fringed; <as>as, the
<ex>fimbriate</ex> petals of the pink; the <ex>fimbriate</ex> end of the
Fallopian tube.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fimbriate</ent><br/
<hw>Fim"bri*ate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Fimbriated</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Fimbriating</conjf>.]</vmorph> <def>To hem; to fringe.</def>
<rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fimbriated</ent><br/
<hw>Fim"bri*a`ted</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Having a fringed border; fimbriate.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Her.)</fld> <def>Having a very narrow border of
another tincture; -- said esp. of an ordinary or subordinary.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fimbricate</ent><br/
<hw>Fim"bri*cate</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Fringed; jagged; fimbriate.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>fringed, on one side only, by
long, straight hairs, as the antenn<ae/ of certain insects.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fin</ent><br/
<hw>Fin</hw> <pr>(f<icr/n)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Finned</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Finning</conjf>.]</vmorph> <ety>[Cf. <er>Fin</er> of a
fish.]</ety> <def>To carve or cut up, as a chub.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fin</ent><br/
<hw>Fin</hw>, <pos>n.</pos> <ety>[See <er>Fine</er>,
<pos>n.</pos>]</ety> <def>End; conclusion; object.</def>
<mark>[Obs.]</mark> <ldquo/She knew eke the <xex>fin</xex> of his
intent.<rdquo/ <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fin</ent><br/
<hw>Fin</hw>, <pos>n.</pos><ety>[OE. <ets>finne</ets>, <ets>fin</ets>,
AS. <ets>finn</ets>; akin to D. <ets>vin</ets>, G. & Dan.
<ets>finne</ets>, Sw. <ets>fena</ets>, L. <ets>pinna</ets>,
<ets>penna</ets>, a wing, feather. Cf. <er>pen</er> a feather.]</ety>
<sn>1.</sn> <fld>(Zool.)</fld> <def>An organ of a fish, consisting of a
membrane supported by rays, or little bony or cartilaginous ossicles,
and serving to balance and propel it in the water.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Fishes move through the water chiefly by means of the
caudal fin or tail, the principal office of the other fins being to
balance or direct the body, though they are also, to a certain extent,
employed in producing motion.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>A membranous, finlike, swimming
organ, as in pteropod and heteropod mollusks.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A finlike organ or attachment; a part of an object
or product which protrudes like a fin</def>, as: <sd>(a)</sd> <def>The
hand.</def> <mark>[Slang]</mark> <sd>(b)</sd> <fld>(Com.)</fld> <def>A
blade of whalebone.</def> <mark>[Eng.]</mark>
<rj><au>McElrath.</au></rj> <sd>(c)</sd> <fld>(Mech.)</fld> <def>A mark
or ridge left on a casting at the junction of the parts of a mold.</def>
<sd>(d)</sd> <fld>(Mech.)</fld> <def>The thin sheet of metal squeezed
out between the collars of the rolls in the process of rolling.</def>
<rj><au>Raymond.</au></rj></p>

<p><sd>(e)</sd> <fld>(Mech.)</fld> <def>A feather; a spline.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A finlike appendage, as to submarine
boats.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(A<eum/ronautics)</fld> <def>A fixed stabilizing
surface, usually vertical, similar in purpose to a bilge keel on a
ship.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><cs><col><b>Apidose fin</b></col>. <fld>(Zool.)</fld> <cd>See under
<er>Adipose</er>, <pos>a.</pos></cd> -- <col><b>Fin ray</b></col>
<fld>(Anat.)</fld>, <cd>one of the hornlike, cartilaginous, or bony,
dermal rods which form the skeleton of the fins of fishes.</cd> --
<col><b>Fin whale</b></col> <fld>(Zool.)</fld>, <cd>a finback.</cd> --
<col><b>Paired fins</b></col> <fld>(Zool.)</fld>, <cd>the pectoral and
ventral fins, corresponding to the fore and hind legs of the higher
animals.</cd> -- <mcol><col><b>Unpaired fins</b></col>, <it>or</it>
<col><b>Median fins</b></col></mcol> <fld>(Zool.)</fld>, <cd>the dorsal,
caudal, and anal fins.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Finable</ent><br/
<hw>Fin"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From
<er>Fine</er>.]</ety> <def>Liable or subject to a fine; <as>as, a
<ex>finable</ex> person or offense</as>.</def>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>finagle</ent><br/
<hw>finagle</hw> <pos>v. i. & t.</pos> <def>to achieve something by
means of trickery or devious methods.</def><br/
<syn><b>Syn. --</b> wangle, manage.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Final</ent><br/
<hw>Fi"nal</hw> <pr>(f<imac/"n<ait/l)</pr>, <pos>a.</pos> <ety>[F., fr.
L. <ets>finalis</ets>, fr. finis boundary, limit, end. See
<er>Finish</er>.]</ety> <sn>1.</sn> <def>Pertaining to the end or
conclusion; last; terminating; ultimate; <as>as, the <ex>final</ex> day
of a school term</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Yet despair not of his <qex>final</qex> pardon.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Conclusive; decisive; <as>as, a <ex>final</ex>
judgment; the battle of Waterloo brought the contest to a <ex>final</ex>
issue.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Respecting an end or object to be gained; respecting
the purpose or ultimate end in view.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Final cause</b></col>. <cd>See under
<er>Cause</er>.</cd></cs></p>

<p><syn><b>Syn.</b> -- <er>Final</er>, <er>Conclusive</er>,
<er>Ultimate</er>.</syn> <usage> <xex>Final</xex> is now appropriated to
that which brings with it an end; as, a <xex>final</xex> adjustment; the
<xex>final</xex> judgment, etc. <xex>Conclusive</xex> implies the
closing of all discussion, negotiation, etc.; as, a
<xex>conclusive</xex> argument or fact; a <xex>conclusive</xex>
arrangement. In using <xex>ultimate</xex>, we have always reference to
something earlier or proceeding; as when we say, a temporary reverse may
lead to an <xex>ultimate</xex> triumph. The statements which a man
<xex>finally</xex> makes at the close of a negotiation are usually
<xex>conclusive</xex> as to his <xex>ultimate</xex> intentions and
designs.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Finale</ent><br/
\'d8<hw>Fi*na"le</hw> <pr>(f<esl/*n<aum/"l<asl/)</pr>, <pos>n.</pos>
<ety>[It. See <er>Final</er>.]</ety> <def>Close; termination</def>; as:
<sd>(a)</sd> <fld>(Mus.)</fld> <def>The last movement of a symphony,
sonata, concerto, or any instrumental composition.</def> <sd>(b)</sd>
<def>The last composition performed in any act of an opera.</def>
<sd>(c)</sd> <def>The closing part, piece, or scene in any public
performance or exhibition.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>finalisation</ent><br/
<hw>finalisation</hw> <pos>n.</pos> <def>same as
<er>finalization</er>.</def><br/
<syn><b>Syn. --</b> finalization.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Finalist</ent><br/
<hw>Fi"nal*ist</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Sports)</fld>
<def>Any of the players who meet in the final round of a tournament in
which the losers in any round do not play again.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Finality</ent><br/
<hw>Fi*nal"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Finalities</plw> <pr>(#)</pr>.</plu> <ety>[L. <ets>finalitas</ets>
the being last.]</ety> <sn>1.</sn> <def>The state of being final,
finished, or complete; a final or conclusive arrangement; a
settlement.</def> <rj><au>Baxter.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The relation of end or purpose to its means.</def>
<rj><au>Janet.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>finalization</ent><br/
<hw>finalization</hw> <pos>n.</pos> <def>the act of
finalizing.</def><br/
<syn><b>Syn. --</b> finalisation.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>finalize</ent><br/
<hw>finalize</hw> <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>finalized</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>finalizing</conjf>.]</vmorph> <def>to put the last touches on;
put into final form.</def><br/
<syn><b>Syn. --</b> make final, settle, nail down.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Finally</ent><br/
<hw>Fi"nal*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <sn>1.</sn> <def>At the
end or conclusion; ultimately; lastly; <as>as, the contest was long, but
the Romans <ex>finally</ex> conquered</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Whom patience <qex>finally</qex> must crown.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Completely; beyond recovery.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Not any house of noble English in Ireland was utterly destroyed or
<qex>finally</qex> rooted out.</q> <rj><qau>Sir J.
Davies.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Finance</ent><br/
<hw>Fi*nance"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr. LL.
<ets>financia</ets> payment of money, money, fr. <ets>finare</ets> to
pay a fine or subsidy (cf. OF. <ets>finer</ets> to finish, pay), fr. L.
<ets>finis</ets> end. See <er>Fine</er>, <pos>n.</pos>,
<er>Finish</er>.]</ety> <sn>1.</sn> <def>The income of a ruler or of a
state; revenue; public money; sometimes, the income of an individual;
often used in the plural for funds; available money;
resources.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>All the <qex>finances</qex> or revenues of the imperial crown.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The science of raising and expending the public
revenue.</def> <ldquo/Versed in the details of
<xex>finance</xex>.<rdquo/ <rj><au>Macaulay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Finance</ent><br/
<hw>Fi*nance"</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Financed</conjf> <pr>(?)</pr>;
<pos>p. pr. & vb. n.</pos> <conjf>Financing</conjf>.]</vmorph> <def>To
conduct the finances of; to provide for, and manage, the capital for; to
financier.</def></p>

<p><q>Securing foreign capital to <qex>finance</qex> multitudinous
undertakings.</q> <rj><qau>B. H. Chamberlain.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>finances</ent><br/
<hw>finances</hw> <pos>n.</pos> <def>assets in the form of
money.</def><br/
<syn><b>Syn. --</b> funds, monetary resource, cash in hand, pecuniary
resource.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Financial</ent><br/
<hw>Fi*nan"cial</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to
finance.</def> <ldquo/Our <xex>financial</xex> and commercial
system.<rdquo/ <rj><au>Macaulay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Financialist</ent><br/
<hw>Fi*nan"cial*ist</hw>, <pos>n.</pos> <def>A financier.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Financially</ent><br/
<hw>Fi*nan"cial*ly</hw>, <pos>adv.</pos> <def>In a financial
manner.</def> <rj><au>Burke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Financier</ent><br/
<hw>Fin`an*cier"</hw> <pr>(?; 277)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>financier</ets>.]</ety> <sn>1.</sn> <def>One charged with the
administration of finance; an officer who administers the public
revenue; a treasurer.</def> <rj><au>Burke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One skilled in financial operations; one acquainted
with money matters.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Financier</ent><br/
<hw>Fin`an*cier"</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Financiered</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Financiering</conjf>.]</vmorph> <def>To conduct financial
operations.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Finary</ent><br/
<hw>Fin"a*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Iron Works)</fld>
<def>See <er>Finery</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Finative</ent><br/
<hw>Fi"na*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Conclusive;
decisive; definitive; final.</def> <mark>[Obs.]</mark> <rj><au>Greene
(1593).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Finback</ent><br/
<hw>Fin"back`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>Any whale of the genera <gen>Sibbaldius</gen>,
<gen>Bal<ae/noptera</gen>, and allied genera, of the family
<fam>Bal<ae/nopterid<ae/</fam>, characterized by a prominent fin on the
back. The common finbacks of the New England coast are <spn>Sibbaldius
tectirostris</spn> and <spn>S. tuberosus</spn>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Finbat kite</ent><br/
<hw>Fin"bat kite</hw> <pr>(?)</pr>. <def>same as <er>Eddy
kite</er>.</def> <mark>[Eng.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Finch</ent><br/
<hw>Finch</hw> <pr>(f<icr/nch)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Finches</plw> <pr>(f<icr/nch"<ecr/z)</pr>.</plu> <ety>[AS.
<ets>finc</ets>; akin to D. <ets>vink</ets>, OHG. <ets>fincho</ets>, G.
<ets>fink</ets>; cf. W. <ets>pinc</ets> a finch; also E.
<ets>spink</ets>.]</ety> <fld>(Zool.)</fld> <def>A small singing bird of
many genera and species, belonging to the family
<fam>Fringillid<ae/</fam>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The word is often used in composition, as in
chaf<xex>finch</xex>, gold<xex>finch</xex>, grass<xex>finch</xex>,
pine<xex>finch</xex>, etc.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Bramble finch</b></col>. <cd>See <er>Brambling</er>.</cd>
-- <col><b>Canary finch</b></col>, <cd>the canary bird.</cd> --
<col><b>Copper finch</b></col>. <cd>See <er>Chaffinch</er>.</cd> --
<col><b>Diamond finch</b></col>. <cd>See under <er>Diamond</er>.</cd> --
<col><b>Finch falcon</b></col> <fld>(Zool.)</fld>, <cd>one of several
very small East Indian falcons of the genus <gen>Hierax</gen>.</cd> --
<col><b>To pull a finch</b></col>, <cd>to swindle an ignorant or
unsuspecting person.</cd> <mark>[Obs.]</mark> <ldquo/Privily a
<xex>finch</xex> eke could he <xex>pull</xex>.<rdquo/
<rj><au>Chaucer.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Finchbacked</ent><br/
<hw>Finch"backed`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Streaked or
spotted on the back; -- said of cattle.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Finched</ent><br/
<hw>Finched</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Same as
<er>Finchbacked</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Find</ent><br/
<hw>Find</hw> <pr>(f<imac/nd)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Found</conjf> <pr>(found)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Finding</conjf>.]</vmorph> <ety>[AS. <ets>findan</ets>;
akin to D. <ets>vinden</ets>, OS. & OHG. <ets>findan</ets>, G.
<ets>finden</ets>, Dan. <ets>finde</ets>, icel. & Sw. <ets>finna</ets>,
Goth. <ets>fin<thorn/an</ets>; and perh. to L. <ets>petere</ets> to
seek, Gr. <grk>pi`ptein</grk> to fall, Skr. <ets>pat</ets> to fall, fly,
E. <ets>petition</ets>.]</ety> <sn>1.</sn> <def>To meet with, or light
upon, accidentally; to gain the first sight or knowledge of, as of
something new, or unknown; hence, to fall in with, as a
person.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Searching the window for a flint, I <qex>found</qex><br/
This paper, thus sealed up.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>In woods and forests thou art <qex>found</qex>.</q>
<rj><qau>Cowley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To learn by experience or trial; to perceive; to
experience; to discover by the intellect or the feelings; to detect; to
feel.</def> <ldquo/I <xex>find</xex> you passing gentle.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The torrid zone is now <qex>found</qex> habitable.</q>
<rj><qau>Cowley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To come upon by seeking; <as>as, to <ex>find</ex>
something lost</as>.</def> <sd>(a)</sd> <def>To discover by sounding;
<as>as, to <ex>find</ex> bottom</as>.</def> <sd>(b)</sd> <def>To
discover by study or experiment direct to an object or end; <as>as,
water is <ex>found</ex> to be a compound substance</as>.</def>
<sd>(c)</sd> <def>To gain, as the object of desire or effort; <as>as, to
<ex>find</ex> leisure; to <ex>find</ex> means</as>.</def> <sd>(d)</sd>
<def>To attain to; to arrive at; to acquire.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Seek, and ye shall <qex>find</qex>.</q> <rj><qau>Matt. vii.
7.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Every mountain now hath <qex>found</qex> a tongue.</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To provide for; to supply; to furnish; <as>as, to
<ex>find</ex> food for workemen; he <ex>finds</ex> his nephew in
money.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Wages <pound/14 and all <qex>found</qex>.</q> <rj><qau>London
Times.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Nothing a day and <qex>find</qex> yourself.</q>
<rj><qau>Dickens.</qau></rj> <-- obsolete?? --><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To arrive at, as a conclusion; to determine as true;
to establish; <as>as, to <ex>find</ex> a verdict; to <ex>find</ex> a
true bill (of indictment) against an accused person.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>find</qex> his title with some shows of truth.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To find out</b></col>, <cd>to detect (a thief); to
discover (a secret) -- to solve or unriddle (a parable or enigma); to
understand.</cd> <ldquo/Canst thou by searching <xex>find out</xex>
God?<rdquo/ <au>Job. xi. 7.</au> <ldquo/We do hope <xex>to find
out</xex> all your tricks.<rdquo/ <au>Milton.</au> -- <col><b>To find
fault with</b></col>, <cd>to blame; to censure.</cd> -- <col><b>To find
one's self</b></col>, <cd>to be; to fare; -- often used in speaking of
health; <as>as, how do you <ex>find yourself</ex> this
morning?</as></cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Find</ent><br/
<hw>Find</hw> <pr>(?)</pr>, <pos>v. i.</pos> <fld>(Law)</fld> <def>To
determine an issue of fact, and to declare such a determination to a
court; <as>as, the jury <ex>find</ex> for the plaintiff</as>.</def>
<rj><au>Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Find</ent><br/
<hw>Find</hw>, <pos>n.</pos> <def>Anything found; a discovery of
anything valuable; especially, a deposit, discovered by
arch<ae/ologists, of objects of prehistoric or unknown origin.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Findable</ent><br/
<hw>Find"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of being
found; discoverable.</def> <rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Finder</ent><br/
<hw>Find"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who,
or that which, finds;</def> <specif>specifically</specif>
<fld>(Astron.)</fld>, <def>a small telescope of low power and large
field of view, attached to a larger telescope, for the purpose of
finding an object more readily, called also a <altname>finder
telescope</altname> or <altname>finder scope</altname>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <fld>(Micros.)</fld> <def>A slide ruled in squares, so as
to assist in locating particular points in the field of
vision.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Fin de siecle</ent><br/
\'d8<hw>Fin` de si<egrave/"cle</hw> <pr>(?)</pr>. <ety>[F.]</ety>
<def>Lit., end of the century; -- mostly used adjectively in English to
signify: belonging to, or characteristic of, the close of the 19th
century. At that time the phrase was also intended to imply
<ldquo/modern<rdquo/ or <ldquo/up-to-date;<rdquo/ <as>as,
<ex>fin-de-si<egrave/cle</ex> ideas</as>.</def> <note>As the twentieth
century comes to a close, the meaning may change.</note><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><ent>Findfault</ent><br/
<hw>Find"fault`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A censurer or
caviler.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Findfaulting</ent><br/
<hw>Find"fault`ing</hw>, <pos>a.</pos> <def>Apt to censure or cavil;
faultfinding; captious.</def> <mark>[Obs.]</mark>
<rj><au>Whitlock.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Finding</ent><br/
<hw>Find"ing</hw>, <pos>n.</pos> <sn>1.</sn> <def>That which is found,
come upon, or provided; esp. (<pluf>pl.</pluf>), that which a journeyman
artisan finds or provides for himself; as tools, trimmings,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>When a man hath been laboring . . . in the deep mines of
knowledge, hath furnished out his <qex>findings</qex> in all their
equipage.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Support; maintenance; that which is provided for
one; expence; provision.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Law)</fld> <def>The result of a judicial
examination or inquiry, especially into some matter of fact; a verdict;
<as>as, the <ex>finding</ex> of a jury</as>.</def>
<rj><au>Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>After his friends <qex>finding</qex> and his rent.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>findy</ent><br/
<hw>fin"dy</hw> <pr>(f<icr/n"d<ycr/)</pr>, <pos>a.</pos> <ety>[AS.
<ets>finding</ets> heavy; cf. Dan. <ets>fyndig</ets> strong,
energetical, <ets>fynd</ets> strength, energy, emphasis.]</ety>
<def>Full; heavy; firm; solid; substantial.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>A cold May and a windy<br/
Makes the barn fat and <qex>findy</qex>.</q> <rj><qau>Old
Proverb.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>fine</ent><br/
<hw>fine</hw> <pr>(f<imac/n)</pr>, <pos>a.</pos>
<amorph>[<pos>Compar.</pos> <adjf>finer</adjf>
<pr>(f<imac/n"<etil/r)</pr>; <pos>superl.</pos>
<adjf>finest</adjf>.]</amorph> <ety>[F. <ets>fin</ets>, LL.
<ets>finus</ets> fine, pure, fr. L. <ets>finire</ets> to finish; cf.
<ets>finitus</ets>, p. p., finished, completed (hence the sense
<ets>accomplished</ets>, <ets>perfect</ets>.) See <er>Finish</er>, and
cf. <er>Finite</er>.]</ety> <sn>1.</sn> <def>Finished; brought to
perfection; refined; hence, free from impurity; excellent; superior;
elegant; worthy of admiration; accomplished; beautiful.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The gain thereof [is better] than <qex>fine</qex> gold.</q>
<rj><qau>Prov. iii. 14.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A cup of wine that's brisk and <qex>fine</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Not only the <qex>finest</qex> gentleman of his time, but one of
the <qex>finest</qex> scholars.</q> <rj><qau>Felton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To soothe the sick bed of so <qex>fine</qex> a being [Keats].</q>
<rj><qau>Leigh Hunt.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Aiming at show or effect; loaded with ornament;
overdressed or overdecorated; showy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He gratified them with occasional . . . <qex>fine</qex>
writing.</q> <rj><qau>M. Arnold.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Nice; delicate; subtle; exquisite; artful; skillful;
dexterous.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The spider's touch, how exquisitely <qex>fine</qex>!</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The nicest and most delicate touches of satire consist in
<qex>fine</qex> raillery.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He has as <qex>fine</qex> a hand at picking a pocket as a
woman.</q> <rj><qau>T. Gray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Not coarse, gross, or heavy</def>; as: <sd>(a)</sd>
<def>Not gross; subtile; thin; tenous.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The eye standeth in the <qex>finer</qex> medium and the object in
the grosser.</q> <rj><qau>Bacon.</qau></rj></p>

<p><sd>(b)</sd> <def>Not coarse; comminuted; in small particles; <as>as,
<ex>fine</ex> sand or flour</as>.</def> <sd>(c)</sd> <def>Not thick or
heavy; slender; filmy; <as>as, a <ex>fine</ex> thread</as>.</def>
<sd>(d)</sd> <def>Thin; attenuate; keen; <as>as, a <ex>fine</ex>
edge</as>.</def> <sd>(e)</sd> <def>Made of fine materials; light;
delicate; <as>as, <ex>fine</ex> linen or silk</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Having (such) a proportion of pure metal in its
composition; <as>as, coins nine tenths <ex>fine</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>(Used ironically.)</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Ye have made a <qex>fine</qex> hand, fellows.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <ex>Fine</ex> is often compounded with participles and
adjectives, modifying them adverbially; a, <ex>fine</ex>-drawn,
<ex>fine</ex>-featured, <ex>fine</ex>-grained, <ex>fine</ex>-spoken,
<ex>fine</ex>-spun, etc.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fine arch</b></col> <fld>(Glass Making)</fld>, <cd>the
smaller fritting furnace of a glasshouse.</cd> <au>Knight.</au> --
<col><b>Fine arts</b></col>. <cd>See the Note under <er>Art</er>.</cd>
-- <col><b>Fine cut</b></col>, <cd>fine cut tobacco; a kind of chewing
tobacco cut up into shreds.</cd> -- <col><b>Fine goods</b></col>,
<cd>woven fabrics of fine texture and quality.</cd> <au>McElrath.</au>
-- <col><b>Fine stuff</b></col>, <cd>lime, or a mixture of lime,
plaster, etc., used as material for the finishing coat in
plastering.</cd> -- <col><b>To sail fine</b></col> <fld>(Naut.)</fld>,
<cd>to sail as close to the wind as possible.</cd></cs></p>

<p><syn><b>Syn.</b> -- <er>Fine</er>, <er>Beautiful</er>.</syn> <usage>
When used as a word of praise, <xex>fine</xex> (being opposed to
<xex>coarse</xex>) denotes no <ldquo/ordinary thing of its kind.<rdquo/
It is not as strong as <xex>beautiful</xex>, in reference to the single
attribute implied in the latter term; but when we speak of a
<xex>fine</xex> woman, we include a greater variety of particulars,
viz., all the qualities which become a woman, -- breeding, sentiment,
tact, etc. The term is equally comprehensive when we speak of a
<xex>fine</xex> garden, landscape, horse, poem, etc.; and, though
applied to a great variety of objects, the word has still a very
definite sense, denoting a high degree of characteristic
excellence.</usage><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 561 --></p>

<p><ent>Fine</ent><br/
<hw>Fine</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Fined</conjf> <pr>(f<imac/nd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Fining</conjf>.]</vmorph> <ety>[From <er>Fine</er>,
<pos>a.</pos>]</ety> <sn>1.</sn> <def>To make fine; to refine; to
purify, to clarify; <as>as, to <ex>fine</ex> gold</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It hath been <qex>fined</qex> and refined by . . . learned
men.</q> <rj><qau>Hobbes.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To make finer, or less coarse, as in bulk, texture,
etc.; as. to <xex>fine</xex> the soil.</def> <rj><au>L. H.
Bailey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To change by fine gradations; as <fld>(Naut.)</fld>,
to <xex>fine</xex> down a ship's lines, to diminish her lines
gradually.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I often sate at home<br/
On evenings, watching how they <qex>fined</qex> themselves<br/
With gradual conscience to a perfect night.</q>
<rj><qau>Browning.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fine</ent><br/
<hw>Fine</hw> <pr>(f<imac/n)</pr>, <pos>n.</pos> <ety>[OE.
<ets>fin</ets>, L. <ets>finis</ets> end, also in LL., a <ets>final</ets>
agreement or concord between the lord and his vassal; a sum of money
paid at the <ets>end</ets>, so as to make an <ets>end</ets> of a
transaction, suit, or prosecution; mulct; penalty; cf. OF.
<ets>fin</ets> end, settlement, F. <ets>fin</ets> end. See
<er>Finish</er>, and cf. <er>Finance</er>.]</ety> <sn>1.</sn> <def>End;
conclusion; termination; extinction.</def> <mark>[Obs.]</mark> <ldquo/To
see their fatal <xex>fine</xex>.<rdquo/ <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Is this the <qex>fine</qex> of his fines?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A sum of money paid as the settlement of a claim, or
by way of terminating a matter in dispute; especially, a payment of
money imposed upon a party as a punishment for an offense; a
mulct.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Law)</fld> <sd>(a)</sd> <fld>(Feudal Law)</fld>
<def>A final agreement concerning lands or rents between persons, as the
lord and his vassal.</def> <rj><au>Spelman.</au></rj></p>

<p><sd>(b)</sd> <fld>(Eng. Law)</fld> <def>A sum of money or price paid
for obtaining a benefit, favor, or privilege, as for admission to a
copyhold, or for obtaining or renewing a lease.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fine for alienation</b></col> <fld>(Feudal Law)</fld>,
<cd>a sum of money paid to the lord by a tenant whenever he had occasion
to make over his land to another.</cd> <au>Burrill.</au> -- <col><b>Fine
of lands</b></col>, <cd>a species of conveyance in the form of a
fictitious suit compromised or terminated by the acknowledgment of the
previous owner that such land was the right of the other party.</cd>
<au>Burrill.</au> See <er>Concord</er>, <pos>n.</pos>, 4. -- <col><b>In
fine</b></col>, <cd>in conclusion; by way of termination or summing
up.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fine</ent><br/
<hw>Fine</hw>, <pos>v. t.</pos> <ety>[From <er>Fine</er>,
<pos>n.</pos>]</ety> <def>To impose a pecuniary penalty upon for an
offense or breach of law; to set a fine on by judgment of a court; to
punish by fine; to mulct; <as>as, the trespassers were <ex>fined</ex>
ten dollars</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fine</ent><br/
<hw>Fine</hw>, <pos>v. i.</pos> <def>To pay a fine. See <er>Fine</er>,
<pos>n.</pos>, 3 <sd>(b)</sd>.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Men <qex>fined</qex> for the king's good will; or that he would
remit his anger; women <qex>fined</qex> for leave to marry.</q>
<rj><qau>Hallam.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fine</ent><br/
<hw>Fine</hw>, <pos>v. t. & i.</pos> <ety>[OF. <ets>finer</ets>, F.
<ets>finir</ets>. See <er>Finish</er>, <pos>v. t.</pos>]</ety> <def>To
finish; to cease; or to cause to cease.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fine</ent><br/
<hw>Fine</hw> <pr>(f<imac/n)</pr>, <pos>adv.</pos> <sn>1.</sn>
<def>Finely; well; elegantly; fully; delicately; mincingly.</def>
<mark>[Obs., Dial., or Colloq.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <fld>(Billiards & Pool)</fld> <def>In a manner so that
the driven ball strikes the object ball so far to one side as to be
deflected but little, the object ball being driven to one
side.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Fine</ent><br/
<hw>Fine</hw> <pr>(f<imac/n)</pr>, <pos>v. i.</pos> <def>To become fine
(in any one of various senses); <as>as, the ale will <ex>fine</ex>; the
weather <ex>fined</ex></as>.</def></p>

<cs><p><mcol><col><b>To fine</b></col> <col><b>away, down,
off</b></col></mcol>, <cd>gradually to become fine; to diminish; to
dwindle.</cd></p>

<p><q>I watched her [the ship] . . . gradually <qex>fining</qex> down in
the westward until I lost of her hull.</q> <rj><qau>W. C.
Russel.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p></cs>

<p><ent>fineable</ent><br/
<hw>fineable</hw> <pos>adj.</pos> <def>liable to a fine.</def><br/
<syn><b>Syn. --</b> finable.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>fined</ent><br/
<hw>fined</hw> <pos>adj.</pos> <def>subjected to punishment by a
fine.</def><br/
<syn><b>Syn. --</b> mulcted.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Finedraw</ent><br/
<hw>Fine"draw`</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Finedrawn</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Finedrawing</conjf>.]</vmorph> <def>To sew up, so nicely
that the seam is not perceived; to renter.</def>
<rj><au>Marryat.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Finedrawer</ent><br/
<hw>Fine"draw`er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
finedraws.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Finedrawn</ent><br/
<hw>Fine"drawn`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Drawn out with too
much subtilty; overnice; <as>as, <ex>finedrawn</ex>
speculations</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fineer</ent><br/
<hw>Fi*neer"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To run in debt by
getting goods made up in a way unsuitable for the use of others, and
then threatening not to take them except on credit.</def>
<mark>[R.]</mark> <rj><au>Goldsmith.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fineer</ent><br/
<hw>Fi*neer"</hw>, <pos>v. t.</pos> <def>To veneer.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>fine-grained</ent><br/
<hw>fine-grained</hw> <pos>adj.</pos> <sn>1.</sn> <def>consisting of
fine particles.</def><br/
<syn><b>Syn. --</b> powdered, powdery, pulverized,
small-grained.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>dense or compact in structure or texture, as a wood
composed of small-diameter cells.</def><br/
<syn><b>Syn. --</b> close-grained.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>3.</sn> <def>involving careful consideration of details and fine
distinctions; -- of conceptual schemas; <as>as, <ex>fine-grained</ex>
distinctions</as>.</def><br/
<syn><b>Syn. --</b> detailed.</syn><br/
[<source>PJC</source>]</p>

<p><ent>Fineless</ent><br/
<hw>Fine"less</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Fine</ets> end
+ <ets>-less</ets>.]</ety> <def>Endless; boundless.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>fine-looking</ent><br/
<hw>fine-looking</hw> <pos>adj.</pos> <def>pleasing in appearance
especially by reason of conformity to ideals of form and proportion;
<as>as, a <ex>fine-looking</ex> woman</as>.</def>[Narrower terms:
<stype>beautiful (vs. ugly) </stype>]<br/
<syn><b>Syn. --</b> good-looking, better-looking, handsome,
well-favored, well-favoured.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Finely</ent><br/
<hw>Fine"ly</hw>, <pos>adv.</pos> <def>In a fine or finished
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fineness</ent><br/
<hw>Fine"ness</hw>, <pos>n.</pos> <ety>[From <er>Fine</er>,
<pos>a.</pos>]</ety> <sn>1.</sn> <def>The quality or condition of being
fine.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Freedom from foreign matter or alloy; clearness;
purity; <as>as, the <ex>fineness</ex> of liquor</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>fineness</qex> of the gold, and chargeful fashion.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The proportion of pure silver or gold in jewelry,
bullion, or coins.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The fineness of United States coin is nine tenths, that
of English gold coin is eleven twelfths, and that of English silver coin
is <frac925x1000/.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Keenness or sharpness; <as>as, the <ex>fineness</ex>
of a needle's point, or of the edge of a blade</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Finer</ent><br/
<hw>Fin"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who fines or
purifies.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Finery</ent><br/
<hw>Fin"er*y</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>Fineness;
beauty.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Don't choose your place of study by the <qex>finery</qex> of the
prospects.</q> <rj><qau>I. Watts.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Ornament; decoration; especially, excecially
decoration; showy clothes; jewels.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Her mistress' cast-off <qex>finery</qex>.</q> <rj><qau>F. W.
Robertson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <ety>[Cf. <er>Refinery</er>.]</ety> <fld>(Iron
Works)</fld> <def>A charcoal hearth or furnace for the conversion of
cast iron into wrought iron, or into iron suitable for
puddling.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Finespun</ent><br/
<hw>Fine"spun`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Spun so as to be
fine; drawn to a fine thread; attenuated; hence, unsubstantial;
visionary; <as>as, <ex>finespun</ex> theories</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Finesse</ent><br/
<hw>Fi`nesse"</hw> <pr>(? <or/ ?)</pr>, <pos>n.</pos> <ety>[F., fr.
<ets>fin</ets> fine. See <er>Fine</er>, <pos>a.</pos>]</ety> <sn>1.</sn>
<def>Subtilty of contrivance to gain a point; artifice;
stratagem.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This is the artificialest piece of <qex>finesse</qex> to persuade
men into slavery.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Whist Playing)</fld> <def>The act of finessing. See
<er>Finesse</er>, <pos>v. i.</pos>, 2.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Finesse</ent><br/
<hw>Fi*nesse"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Finessed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Finessing</conjf>.]</vmorph> <sn>1.</sn> <def>To use
artifice or stratagem.</def> <rj><au>Goldsmith.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Whist Playing)</fld> <def>To attempt, when second
or third player, to make a lower card answer the purpose of a higher,
when an intermediate card is out, risking the chance of its being held
by the opponent yet to play.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Finestill</ent><br/
<hw>Fine"still`</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To distill, as
spirit from molasses or some saccharine preparation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Finestiller</ent><br/
<hw>Fine"still`er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
finestills.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>fine-toothed</ent><br/
<ent>fine-tooth</ent><br/
<mhw><hw>fine-tooth</hw> <hw>fine-toothed</hw></mhw> <pos>adj.</pos>
<def>having fine teeth set close together; <as>as, a <ex>fine-tooth</ex>
comb</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>fine-tune</ent><br/
<hw>fine-tune</hw> <pos>v. t.</pos> <def>to adjust carefully and
precisely so as to achieve optimum performance or efficiency; <as>as,
The mechanic <ex>fine-tuned</ex> the engine</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Finew</ent><br/
<hw>Fin"ew</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Fenowed</er>.]</ety> <def>Moldiness.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Finfish</ent><br/
<hw>Fin"fish`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<sd>(a)</sd> <def>A finback whale.</def> <sd>(b)</sd> (<pluf>pl.</pluf>)
<def>True fish, as distinguished from shellfish.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Finfoot</ent><br/
<hw>Fin"foot`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>A
South American bird (<spn>Heliornis fulica</spn>) allied to the grebes.
The name is also applied to several related species of the genus
<gen>Podica</gen>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fin-footed</ent><br/
<hw>Fin"-foot`ed</hw>, <pos>a.</pos> <fld>(Zool.)</fld> <sd>(a)</sd>
<def>Having palmate feet.</def> <sd>(b)</sd> <def>Having lobate toes, as
the coot and grebe.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Finger</ent><br/
<hw>Fin"ger</hw> <pr>(f<icr/<nsm/"g<etil/r)</pr>, <pos>n.</pos>
<ety>[AS. <ets>finger</ets>; akin to D. <ets>vinger</ets>, OS. & OHG.
<ets>fingar</ets>, G. <ets>finger</ets>, Icel. <ets>fingr</ets>, Sw. &
Dan. <ets>finger</ets>, Goth. <ets>figgrs</ets>; of unknown origin;
perh. akin to E. <ets>fang</ets>.]</ety> <sn>1.</sn> <def>One of the
five terminating members of the hand; a digit; esp., one of the four
extremities of the hand, other than the thumb.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Anything that does the work of a finger; as, the
pointer of a clock, watch, or other registering machine;</def>
<specif>especially</specif> <fld>(Mech.)</fld> <def>a small projecting
rod, wire, or piece, which is brought into contact with an object to
effect, direct, or restrain a motion.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The breadth of a finger, or the fourth part of the
hand; a measure of nearly an inch; also, the length of finger, a measure
in domestic use in the United States, of about four and a half inches or
one eighth of a yard.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A piece of steel three <qex>fingers</qex> thick.</q> <rj><qau>Bp.
Wilkins.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Skill in the use of the fingers, as in playing upon
a musical instrument.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>She has a good <qex>finger</qex>.</q>
<rj><qau>Busby.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Ear finger</b></col>, <cd>the little finger.</cd> --
<col><b>Finger alphabet</b></col>. <cd>See <er>Dactylology</er>.</cd> --
<col><b>Finger bar</b></col>, <cd>the horizontal bar, carrying slotted
spikes, or fingers, through which the vibratory knives of mowing and
reaping machines play.</cd> -- <col><b>Finger board</b></col>
<fld>(Mus.)</fld>, <cd>the part of a stringed instrument against which
the fingers press the strings to vary the tone; the keyboard of a piano,
organ, etc.; manual.</cd> -- <mcol><col><b>Finger bowl</b></col>
<col><b>Finger glass</b></col></mcol>, <cd>a bowl or glass to hold water
for rinsing the fingers at table.</cd> -- <col><b>Finger
flower</b></col> <fld>(Bot.)</fld>, <cd>the foxglove.</cd> --
<col><b>Finger grass</b></col> <fld>(Bot.)</fld>, <cd>a kind of grass
(<spn>Panicum sanguinale</spn>) with slender radiating spikes; common
crab grass. See <cref>Crab grass</cref>, under <er>Crab</er>.</cd> --
<col><b>Finger nut</b></col>, <cd>a fly nut or thumb nut.</cd> --
<col><b>Finger plate</b></col>, <cd>a strip of metal, glass, etc., to
protect a painted or polished door from finger marks.</cd> --
<col><b>Finger post</b></col>, <cd>a guide post bearing an index
finger.</cd> -- <col><b>Finger reading</b></col>, <cd>reading printed in
relief so as to be sensible to the touch; -- so made for the blind.</cd>
-- <col><b>Finger shell</b></col> <fld>(Zool.)</fld>, <cd>a marine shell
(<spn>Pholas dactylus</spn>) resembling a finger in form.</cd> --
<col><b>Finger sponge</b></col> <fld>(Zool.)</fld>, <cd>a sponge having
finger-shaped lobes, or branches.</cd> -- <col><b>Finger
stall</b></col>, <cd>a cover or shield for a finger.</cd> --
<col><b>Finger steel</b></col>, <cd>a steel instrument for whetting a
currier's knife.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To burn one's fingers</b></col>. <cd>See under
<er>Burn</er>.</cd> -- <col><b>To have a finger in</b></col>, <cd>to be
concerned in.</cd> <mark>[Colloq.]</mark> -- <col><b>To have at one's
fingers' ends</b></col>, <cd>to be thoroughly familiar with.</cd>
<mark>[Colloq.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Finger</ent><br/
<hw>Fin"ger</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Fingered</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Fingering</conjf>.]</vmorph> <sn>1.</sn> <def>To touch
with the fingers; to handle; to meddle with.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Let the papers lie;<br/
You would be <qex>fingering</qex> them to anger me.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To touch lightly; to toy with.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Mus.)</fld> <sd>(a)</sd> <def>To perform on an
instrument of music.</def> <sd>(b)</sd> <def>To mark the notes of (a
piece of music) so as to guide the fingers in playing.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To take thievishly; to pilfer; to purloin.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To execute, as any delicate work.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Finger</ent><br/
<hw>Fin"ger</hw>, <pos>v. i.</pos> <fld>(Mus.)</fld> <def>To use the
fingers in playing on an instrument.</def> <rj><au>Busby.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>fingerboard</ent><br/
<hw>fingerboard</hw> <pos>n.</pos> <sn>1.</sn> <def>a guidepost
resembling a hand with a pointing index finger.</def><br/
<syn><b>Syn. --</b> fingerpost.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>a bank of keys on a musical instrument.</def><br/
<syn><b>Syn. --</b> piano keyboard, clavier.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>3.</sn> <def>a narrow strip of wood on the neck of some stringed
instruments (violin or cello or guitar etc) where the strings are held
against the wood with the fingers.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>fingerbreadth</ent><br/
<hw>fingerbreadth</hw> <pos>n.</pos> <def>the length or breadth of a
finger used as a linear measure.</def><br/
<syn><b>Syn. --</b> finger, finger's breadth, digit.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>finger cot</ent><br/
<hw>finger cot</hw> <pos>n.</pos> <def>a close-fitting sheath worn at
the end of a finger, for protection of the finger or to avoid soiling
the object touched.</def><br/
<syn><b>Syn. --</b> fingerstall, cot{3}.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Fingered</ent><br/
<hw>Fin"gered</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Having
fingers.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>Having leaflets like fingers;
digitate.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Mus.)</fld> <def>Marked with figures designating
which finger should be used for each note.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fingerer</ent><br/
<hw>Fin"ger*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who fingers; a
pilferer.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fingering</ent><br/
<hw>Fin"ger*ing</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act or process
of handling or touching with the fingers.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The mere sight and <qex>fingering</qex> of money.</q>
<rj><qau>Grew.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The manner of using the fingers in playing or
striking the keys of an instrument of music; movement or management of
the fingers in playing on a musical instrument, in typewriting,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The marking of the notes of a piece of music to
guide or regulate the action or use of the fingers.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Delicate work made with the fingers.</def>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fingerling</ent><br/
<hw>Fin"ger*ling</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Finger</ets> + <ets>-ling</ets>.]</ety> <fld>(Zool.)</fld>
<def>A young salmon. See <er>Parr</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>finger paint</ent><br/
<ent>fingerpaint</ent><br/
<mhw><hw>fingerpaint</hw>, <hw>finger paint</hw></mhw> <pos>n.</pos>
<def>A type of paint having the consistency of a thin paste or jelly,
which is applied to a surface by dipping fingers into the paint and
smearing the paint on the surface, usually in artistic patterns. It is
used primarily by children.</def><br/
[<source>PJC</source>]</p>

<p><ent>fingerpaint</ent><br/
<ent>finger-paint</ent><br/
<mhw><hw>finger-paint</hw>, <hw>fingerpaint</hw></mhw> <pos>v. i. &
t.</pos> <def>To paint{1} with fingerpaint.</def><br/
<syn><b>Syn. --</b> use fingerpaint.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>finger painting</ent><br/
<hw>finger painting</hw> <pos>n.</pos> <def>Creating pictures using
finger paint.</def><br/
[<source>PJC</source>]</p>

<p><ent>fingerpost</ent><br/
<hw>fingerpost</hw> <pos>n.</pos> <def>a guidepost resembling a hand
with a pointing index finger.</def><br/
<syn><b>Syn. --</b> fingerboard.</syn><br/
[<source>WordNet 1.5</source>]</p>

<-- ##?? see list of collocations beginning with "finger" -->
<p><ent>Fingerprint</ent><br/
<hw>Fin"ger*print</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Finger</ets> + <ets>print</ets>.]</ety> <sn>1.</sn> <def>an impression of the pattern of ridges on the skin of the last joint of a person's finger, left on a surface after a person has touched the surface.</def>  <note><ex>Fingerprints</ex> left by persons who have committed crimes are considered as reliable <isa>physical evidence</isa> linking an individual with a crime, because each person's fingerprints are distinctively different from those of others, allowing identification of a person with high confidence.</note> <br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>a fingerprint{1} made intentionally in ink on a paper form for the purpose of identification of the individual.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>any distinctive pattern of characteristics or properties of an object which can serve to identify that object; <as>as, the distinctive <ex>fingerprint</ex> of eugenol in the mass spectrum allowed easy recognition of its presence in the sample</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <def>a smudge made by a (dirty) finger.</def> <wns>[wns=3]</wns><br/
<syn><b>Syn. --</b> fingermark.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>fingerprint</ent><br/
<hw>fin"ger*print</hw> <pos>v. t.</pos> <def>to take an impression of the fingerprints of (a person); <as>as, to <ex>fingerprint</ex> applicants for a gun permit</as>.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>fingerprinting</ent><br/
<hw>fingerprinting</hw> <pos>n.</pos> <def>The procedure of taking inked impressions of a person's fingerprints.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>finger-roll</ent><br/
<hw>finger-roll</hw> <pos>n.</pos> <fld>(Basketball)</fld> <def>A shot that rolls off the tips of the fingers into the basket.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>fingerroot</ent><br/
<hw>fingerroot</hw> <pos>n.</pos> <def>tall leafy European biennial or perennial (<spn>Digitalis purpurea</spn>) having spectacular clusters of large tubular pink-purple flowers; -- its leaves yield the drug digitalis and are poisonous to livestock.</def><br/
<syn><b>Syn. --</b> common foxglove, fairy bell, fingerflower, <spn>Digitalis purpurea</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>fingerstall</ent><br/
<hw>fingerstall</hw> <pos>n.</pos> <def>a sheath worn to protect a finger.</def><br/
<syn><b>Syn. --</b> cot.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>fingertip</ent><br/
<hw>fingertip</hw> <pos>n.</pos> <def>the end (tip) of a finger.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fingle-fangle</ent><br/
<hw>Fin"gle-fan`gle</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From <ets>fangle</ets>.]</ety> <def>A trifle.</def> <mark>[Low]</mark>  <rj><au>Hudibras.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fingrigo</ent><br/
\'d8<hw>Fin"gri*go</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it> <plw>Fingrigos</plw> <pr>(#)</pr>.</plu> <ety>[So called in Jamaica.]</ety> <fld>(Bot.)</fld> <def>A prickly, climbing shrub of the genus <gen>Pisonia</gen>. The fruit is a kind of berry.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Finial</ent><br/
<hw>Fin"i*al</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>finire</ets> to finish, end. See <er>Finish</er>.]</ety> <fld>(Arch.)</fld> <def>The knot or bunch of foliage, or foliated ornament, that forms the upper extremity of a pinnacle in Gothic architecture; sometimes, the pinnacle itself.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Finical</ent><br/
<hw>Fin"i*cal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From <er>Fine</er>, <pos>a.</pos>]</ety> <def>Affectedly fine; overnice; unduly particular; fastidious.</def> <ldquo/<xex>Finical</xex> taste.<rdquo/  <rj><au>Wordsworth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The gross style consists in giving no detail, the <qex>finical</qex> in giving nothing else.</q> <rj><qau>Hazlitt.</qau></rj></p>

<p><syn><b>Syn.</b> -- <er>Finical</er>, <er>Spruce</er>, <er>Foppish</er>.</syn> <usage> These words are applied to persons who are studiously desirous to cultivate finery of appearance. One who is <xex>spruce</xex> is elaborately nice in dress; one who is <xex>finical</xex> shows his affectation in language and manner as well as in dress; one who is <xex>foppish</xex> distinguishes himself by going to the extreme of the fashion in the cut of his clothes, by the tawdriness of his ornaments, and by the ostentation of his manner. <ldquo/A <xex>finical</xex> gentleman clips his words and screws his body into as small a compass as possible, to give himself the air of a delicate person; a <xex>spruce</xex> gentleman strives not to have a fold wrong in his frill or cravat, nor a hair of his head to lie amiss; a <xex>foppish</xex> gentleman seeks . . . to render himself distinguished for finery.<rdquo/</usage>  <rj><au>Crabb.</au></rj></p>

<p>-- <wordforms><wf>Fin"i*cal*ly</wf>, <pos>adv.</pos> -- <wf>Fin"i*cal*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Finicality</ent><br/
<hw>Fin`i*cal"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The quality of being finical; finicalness.</def></p>

<p><ent>Finicky</ent><br/
<ent>Finicking</ent><br/
<mhw>{ <hw>Fin"ick*ing</hw> <pr>(?)</pr>, <hw>Fin"ick*y</hw>, <pos>a.</pos> }</mhw> <def>Finical; unduly particular; excessively demanding over minor details.</def> <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Finific</ent><br/
<hw>Fi*nif"ic</hw> <pr>(? <or/ ?)</pr>, <pos>n.</pos> <ety>[L. <ets>finis</ets> end + <ets>facere</ets> to make.]</ety> <def>A limiting element or quality.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The essential <qex>finific</qex> in the form of the finite.</q> <rj><qau>Coleridge.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Finify</ent><br/
<hw>Fin"i*fy</hw> <pr>(? <or/ ?)</pr>, <pos>v. t.</pos> <ety>[<ets>Fine</ets>, <pos>a.</pos> + <ets>-fy</ets>.]</ety> <def>To make fine; to dress finically.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Hath so pared and <qex>finified</qex> them [his feet.]</q> <rj><qau>B. Jonson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Finikin</ent><br/
<hw>Fin"i*kin</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Fine</ets>, <pos>a.</pos> + <ets>-kin</ets>.]</ety> <def>Precise in trifles; idly busy.</def> <mark>[Colloq.]</mark>  <rj><au>Smart.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fining</ent><br/
<hw>Fin"ing</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The act of imposing a fin<?/.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The process of fining or refining; clarification; also <fld>(Metal.)</fld>, the conversion of cast iron into suitable for puddling, in a hearth or charcoal fire.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which is used to refine; especially, a preparation of isinglass, gelatin, etc., for clarifying beer.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fining pot</b></col>, <cd>a vessel in which metals are refined.</cd> <rj><au>Prov. xvii. 3.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Finis</ent><br/
\'d8<hw>Fi"nis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.]</ety> <def>An end; conclusion. It is often placed at the end of a book.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Finish</ent><br/
<hw>Fin"ish</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos> <conjf>Finished</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos> <conjf>Finishing</conjf>.]</vmorph> <ety>[F. <ets>finir</ets> (with a stem <ets>finiss-</ets> in several forms, whence E. <ets>-ish</ets>: see <ets>-ish</ets>.),fr. L. <ets>finire</ets> to limit, finish, end, fr. <ets>finis</ets> boundary, limit, end; perh. for <ets>fidnis</ets>, and akin <ets>findere</ets> to cleave, E. <ets>fissure</ets>.]</ety> <sn>1.</sn> <def>To arrive at the end of; to bring to an end; to put an end to; to make an end of; to terminate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And heroically hath <qex>finished</qex><br/
A life heroic.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To bestow the last required labor upon; to complete; to bestow the utmost possible labor upon; to perfect; to accomplish; to polish.</def></p>

<p><syn><b>Syn.</b> -- To end; terminate; close; conclude; complete; accomplish; perfect.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Finish</ent><br/
<hw>Fin"ish</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To come to an end; to terminate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His days may <qex>finish</qex> ere that hapless time.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To end; to die.</def> <mark>[R.]</mark>  <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Finish</ent><br/
<hw>Fin"ish</hw>, <pos>n.</pos> <sn>1.</sn> <def>That which finishes, puts an end to<?/ or perfects.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Arch.)</fld> <def>The joiner work and other finer work required for the completion of a building, especially of the interior. See <cref>Inside finish</cref>, and <cref>Outside finish</cref>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Fine Arts)</fld> <sd>(a)</sd> <def>The labor required to give final completion to any work; hence, minute detail, careful elaboration, or the like.</def> <sd>(b)</sd> <def>See <cref>Finishing coat</cref>, under <er>Finishing</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The result of completed labor, as on the surface of an object; manner or style of finishing; <as>as, a rough, dead, or glossy <ex>finish</ex> given to cloth, stone, metal, etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Completion; -- opposed to <ant>start</ant>, or <ant>beginning</ant>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Finished</ent><br/
<hw>Fin"ished</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Polished to the highest degree of excellence; complete; perfect; <as>as, a <ex>finished</ex> poem; a <ex>finished</ex> education.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Finished work</b></col> <fld>(Mach.)</fld>, <cd>work that is made smooth or polished, though not necessarily completed.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Finisher</ent><br/
<hw>Fin"ish*er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who finishes, puts an end to, completes, or perfects; esp. used in the trades, as in hatting, weaving, etc., for the workman who gives a finishing touch to the work, or any part of it, and brings it to perfection.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>O prophet of glad tidings, <qex>finisher</qex><br/
Of utmost hope!</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Something that gives the finishing touch to, or settles, anything.</def> <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Finishing</ent><br/
<hw>Fin"ish*ing</hw>, <pos>n.</pos> <def>The act or process of completing or perfecting; the final work upon or ornamentation of a thing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Finishing</ent><br/
<hw>Fin"ish*ing</hw>, <pos>a.</pos> <def>Tending to complete or to render fit for the market or for use.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Finishing coat</b></col>. <sd>(a)</sd> <fld>(Plastering)</fld> <cd>the final coat of plastering applied to walls and ceilings, usually white and rubbed smooth.</cd> <sd>(b)</sd> <fld>(Painting)</fld> <cd>The final coat of paint, usually differently mixed applied from the others.</cd> -- <col><b>Finishing press</b></col>, <cd>a machine for pressing fabrics.</cd> -- <col><b>Finishing rolls</b></col> <fld>(Iron Working)</fld>, <cd>the rolls of a train which receive the bar from roughing rolls, and reduce it to its finished shape.</cd>  <rj><au>Raymond.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Finite</ent><br/
<hw>Fi"nite</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>finitus</ets>, p. p. of <ets>finire</ets>. See <er>Finish</er>, and cf. <er>Fine</er>, <pos>a.</pos>]</ety> <def>Having a limit; limited in quantity, degree, or capacity; bounded; -- opposed to <xex>infinite</xex>; <as>as, <ex>finite</ex> number; <ex>finite</ex> existence; a <ex>finite</ex> being; a <ex>finite</ex> mind; <ex>finite</ex> duration.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Finiteless</ent><br/
<hw>Fi"nite*less</hw>, <pos>a.</pos> <def>Infinite.</def> <mark>[Obs.]</mark>  <rj><au>Sir T. browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Finitely</ent><br/
<hw>Fi"nite*ly</hw>, <pos>adv.</pos> <def>In a finite manner or degree.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Finiteness</ent><br/
<hw>Fi"nite*ness</hw>, <pos>n.</pos> <def>The state of being finite.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Finitude</ent><br/
<hw>Fin"i*tude</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>finire</ets>. See <er>Finish</er>.]</ety> <def>Limitation.</def>  <rj><au>Cheyne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Finjan</ent><br/
<hw>Fin*jan"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Also <ets>fingan</ets>, <ets>findjan</ets>, <ets>fingian</ets>, etc.]</ety> <ety>[Ar. <ets>finj<amac/n</ets>.]</ety> <def>In the Levant, a small coffee cup without a handle, such as is held in a cup or stand called a <er>zarf</er>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Fin keel</ent><br/
<hw>Fin keel</hw>. <fld>(Naut.)</fld> <def>A projection downward from the keel of a yacht, resembling in shape the fin of a fish, though often with a cigar-shaped bulb of lead at the bottom, and generally made of metal. Its use is to ballast the boat and also to enable her to sail close to the wind and to make the least possible leeway by offering great resistance to lateral motion through the water.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Finlander</ent><br/
<hw>Fin"land*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A native or inhabitant of Finland.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Finless</ent><br/
<hw>Fin"less</hw>, <pos>a.</pos> <fld>(Zool.)</fld> <def>destitute of fins.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Finlet</ent><br/
<hw>Fin"let</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Fin</ets> + <ets>-let</ets>.]</ety> <def>A little fin; one of the parts of a divided fin.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Finlike</ent><br/
<hw>Fin"like`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Resembling a fin.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Finn</ent><br/
<hw>Finn</hw> <pr>(?)</pr>, <pos>a.</pos> <def>A native of Finland; one of the Finn<?/ in the ethnological sense. See <er>Finns</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Finnan haddie</ent><br/
<hw>Fin"nan had"die</hw> <pr>(f<icr/n"n<ait/n h<acr/d"d<icr/)</pr>. <ety>[See <er>Haddock</er>.]</ety> <def>Haddock cured in peat smoke, originally at Findon (pron. f<icr/n"<ait/n), Scotland.  The name is also applied to other kinds of smoked haddock.</def> <altsp>[Written also <asp>finnan haddock</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Finned</ent><br/
<hw>Finned</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having a fin, or fins, or anything resembling a fin.</def>  <rj><au>Mortimer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Finner</ent><br/
<hw>Fin"ner</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>A finback whale.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Finnic</ent><br/
<hw>Finn"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining to the Finns.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Finnikin</ent><br/
<hw>Fin"ni*kin</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>A variety of pigeon, with a crest somewhat resembling the mane of a horse.</def> <altsp>[Written also <asp>finikin</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Finnish</ent><br/
<hw>Finn"ish</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining to Finland, to the Finns, or to their language.</def> -- <def2><pos>n.</pos> <def>A Northern Turanian group of languages; the language of the Finns.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Finns</ent><br/
<hw>Finns</hw> <pr>(?)</pr>, <pos>n. pl.</pos>; <sing>sing. <singw>Finn</singw></sing>. <fld>(Ethnol.)</fld> <sd>(a)</sd> <def>Natives of Finland; Finlanders.</def> <sd>(b)</sd> <def>A branch of the Mongolian race, inhabiting Northern and Eastern Europe, including the Magyars, Bulgarians, Permians, Lapps, and Finlanders.</def> <altsp>[Written also <asp>Fins</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Finny</ent><br/
<hw>Fin"ny</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <fld>(Zool.)</fld> <def>Having, or abounding in, fins, as fishes; pertaining to fishes.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Abounding in fishes.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With patient angle trolls the <qex>finny</qex> deep.</q> <rj><qau>Goldsmoth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Finochio</ent><br/
\'d8<hw>Fi*no"chi*o</hw> <pr>(?; 277)</pr>, <pos>n.</pos> <ety>[It. <ets>finocchio</ets> fennel, LL. <ets>fenuclum</ets>. See <er>Fennel</er>.]</ety> <fld>(Bot.)</fld> <def>An umbelliferous plant (<spn>F<oe/niculum dulce</spn>) having a somewhat tuberous stem; sweet fennel. The blanched stems are used in France and Italy as a culinary vegetable.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 562 --></p>

<p><ent>Finos</ent><br/
\'d8<hw>Fi"nos</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[Sp., pl., fr.
<ets>fino</ets> fine.]</ety> <def>Second best wool from Merino
sheep.</def> <rj><au>Gardner.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Finpike</ent><br/
<hw>Fin"pike`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>The bichir. See <er>Crossopterygii</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Finsen light</ent><br/
<hw>Fin"sen light</hw> <pr>(?)</pr>. <ety>[After Prof. Niels R.
<etsep>Finsen</etsep> (b. 1860), Danish physician.]</ety>
<fld>(Med.)</fld> <def>Highly actinic light, derived from sunlight or
from some form of electric lamp, used in the treatment of lupus and
other cutaneous affections.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Fint</ent><br/
<hw>Fint</hw> <pr>(?)</pr>, <def><pos>3d pers. sing. pr.</pos> of
<er>Find</er>, for <xex>findeth</xex>.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fin-toed</ent><br/
<hw>Fin"-toed`</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Having toes connected by a membrane; palmiped; palmated; also,
lobate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fiord</ent><br/
\'d8<hw>Fiord</hw> <pr>(fy<?/rd; <it>i</it> or <it>y</it> consonant,
<sect/ 272)</pr>, <pos>n.</pos> <ety>[Dan. & Norw. <ets>fiord</ets>. See
<er>Frith</er>.]</ety> <def>A narrow inlet of the sea, penetrating
between high banks or rocks, as on the coasts of Norway and
Alaska.</def> <altsp>[Written also <asp>fjord</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fiorin</ent><br/
<hw>Fi"o*rin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. Ir.
<ets>fiothran</ets> a sort of grass.]</ety> <fld>(Bot.)</fld> <def>A
species of creeping bent grass (<spn>Agrostis alba</spn>); -- called
also <altname>fiorin grass</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fiorite</ent><br/
<hw>Fi"o*rite</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Min.)</fld> <def>A
variety of opal occuring in the cavities of volcanic tufa, in smooth and
shining globular and botryoidal masses, having a pearly luster; -- so
called from <ets>Fiora</ets>, in Ischia.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fioriture</ent><br/
\'d8<hw>Fio`ri*tu"re</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[It., pl.
of <ets>fioritura</ets> a flowering.]</ety> <fld>(Mus.)</fld>
<def>Little flowers of ornament introduced into a melody by a singer or
player.</def> <-- no pos in original. = n. --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fippenny bit</ent><br/
<hw>Fip"pen*ny bit`</hw> <pr>(? <or/ ?)</pr>. <ety>[Corruption of
<ets>five penny bit</ets>.]</ety> <def>The Spanish half real, or one
sixteenth of a dollar, -- so called in Pennsylvania and the adjacent
States.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Before the act of Congress, Feb. 21, 1857, caused the
adoption of decimal coins and the withdrawal of foreign coinage from
circulation, this coin passed currently for 6<frac14/ cents, and was
called in New England a <xex>fourpence ha'penny</xex> or
<xex>fourpence</xex>; in New York a <xex>sixpence</xex>; in
Pennsylvania, Virginia, etc., a <xex>fip</xex>; and in Louisiana, a
<xex>picayune</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fipple</ent><br/
<hw>Fip"ple</hw> <pr>(f<etil/r)</pr>, <pos>n.</pos> <ety>[perh. fr. L.
<ets>fibula</ets> a clasp, a pin; cf. Prov. E. <ets>fible</ets> a stick
used to stir pottage.]</ety> <def>A stopper, as in a wind instrument of
music.</def> <mark>[Obs.]</mark> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fir</ent><br/
<hw>Fir</hw> <pr>(f<etil/r)</pr>, <pos>n.</pos> <ety>[Dan.
<ets>fyr</ets>, <ets>fyrr</ets>; akin to Sw. <ets>furu</ets>, Icel.
<ets>fura</ets>, AS. <ets>furh</ets> in <ets>furh</ets>wudu fir wood, G.
<ets>f<oum/hre</ets>, OHG. <ets>forha</ets> pine, <ets>vereh</ets>eih a
sort of oak, L. <ets>quercus</ets> oak.]</ety> <fld>(Bot.)</fld> <def>A
genus (<gen>Abies</gen>) of coniferous trees, often of large size and
elegant shape, some of them valued for their timber and others for their
resin. The species are distinguished as the <stype>balsam fir</stype>,
the <stype>silver fir</stype>, the <stype>red fir</stype>, etc. The
<xex>Scotch fir</xex> is a <gen>Pinus</gen>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Fir</xex> in the Bible means any one of several
coniferous trees, including, cedar, cypress, and probably three species
of pine.</note> <rj><au>J. D. Hooker.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fire</ent><br/
<hw>Fire</hw> <pr>(f<imac/r)</pr>, <pos>n.</pos> <ety>[OE.
<ets>fir</ets>, <ets>fyr</ets>, <ets>fur</ets> AS. <ets>f<ymac/r</ets>;
akin to D. <ets>vuur</ets>, OS. & OHG. <ets>fiur</ets>, G.
<ets>feuer</ets>, Icel. <ets>f<ymac/ri</ets>, <ets>f<umac/rr</ets>, Gr.
<grk>py^r</grk>, and perh. to L. <ets>purus</ets> pure, E.
<ets>pure</ets> Cf. <er>Empyrean</er>, <er>Pyre</er>.]</ety> <sn>1.</sn>
<def>The evolution of light and heat in the combustion of bodies;
combustion; state of ignition.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The form of <xex>fire</xex> exhibited in the combustion
of gases in an ascending stream or current is called <xex>flame</xex>.
Anciently, <xex>fire</xex>, air, earth, and water were regarded as the
four elements of which all things are composed.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Fuel in a state of combustion, as on a hearth, or in
a stove or a furnace.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The burning of a house or town; a
conflagration.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Anything which destroys or affects like
fire.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Ardor of passion, whether love or hate; excessive
warmth; consuming violence of temper.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>he had <qex>fire</qex> in his temper.</q>
<rj><qau>Atterbury.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Liveliness of imagination or fancy; intellectual and
moral enthusiasm; capacity for ardor and zeal.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And bless their critic with a poet's <qex>fire</qex>.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>Splendor; brilliancy; luster; hence, a
star.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Stars, hide your <qex>fires</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>As in a zodiac<br/
representing the heavenly <qex>fires</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>Torture by burning; severe trial or
affliction.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>The discharge of firearms; firing; <as>as, the
troops were exposed to a heavy <ex>fire</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Blue fire</b></col>, <col><b>Red fire</b></col>,
<col><b>Green fire</b></col></mcol> <fld>(Pyrotech.)</fld>,
<cd>compositions of various combustible substances, as sulphur, niter,
lampblack, etc., the flames of which are colored by various metallic
salts, as those of antimony, strontium, barium, etc.</cd> --
<col><b>Fire alarm</b></col> <sd>(a)</sd> <cd>A signal given on the
breaking out of a fire.</cd> <sd>(b)</sd> <cd>An apparatus for giving
such an alarm.</cd> -- <col><b>Fire annihilator</b></col>, <cd>a
machine, device, or preparation to be kept at hand for extinguishing
fire by smothering it with some incombustible vapor or gas, as carbonic
acid.</cd> -- <col><b>Fire balloon</b></col>. <sd>(a)</sd> <cd>A balloon
raised in the air by the buoyancy of air heated by a fire placed in the
lower part<-- = hot-air balloon --></cd>. <sd>(b)</sd> <cd>A balloon
sent up at night with fireworks which ignite at a regulated height.</cd>
<au>Simmonds.</au> -- <col><b>Fire bar</b></col>, <cd>a grate bar.</cd>
-- <col><b>Fire basket</b></col>, <cd>a portable grate; a cresset.</cd>
<au>Knight.</au> -- <col><b>Fire beetle</b></col>. <fld>(Zool.)</fld>
<cd>See in the Vocabulary.</cd> -- <col><b>Fire blast</b></col>, <cd>a
disease of plants which causes them to appear as if burnt by fire.</cd>
-- <col><b>Fire box</b></col>, <cd>the chamber of a furnace, steam
boiler, etc., for the fire.</cd> -- <col><b>Fire brick</b></col>, <cd>a
refractory brick, capable of sustaining intense heat without fusion,
usually made of fire clay or of siliceous material, with some cementing
substance, and used for lining fire boxes, etc.</cd> -- <col><b>Fire
brigade</b></col>, <cd>an organized body of men for extinguished
fires.</cd> -- <col><b>Fire bucket</b></col>. <cd>See under
<er>Bucket</er>.</cd> -- <col><b>Fire bug</b></col>, <cd>an incendiary;
one who, from malice or through mania, persistently sets fire to
property; a pyromaniac.</cd> <mark>[U.S.]</mark> -- <col><b>Fire
clay</b></col>. <cd>See under <er>Clay</er>.</cd> -- <col><b>Fire
company</b></col>, <cd>a company of men managing an engine in
extinguishing fires.</cd> -- <col><b>Fire cross</b></col>. <cd>See
<er>Fiery cross</er>.</cd> <mark>[Obs.]</mark> <au>Milton.</au> --
<col><b>Fire damp</b></col>. <cd>See under <er>Damp</er>.</cd> --
<col><b>Fire dog</b></col>. <cd>See <er>Firedog</er>, in the
Vocabulary.</cd> -- <col><b>Fire drill</b></col>. <sd>(a)</sd> <cd>A
series of evolutions performed by fireman for practice</cd>.
<sd>(b)</sd> <cd>An apparatus for producing fire by friction, by rapidly
twirling a wooden pin in a wooden socket; -- used by the Hindoos during
all historic time, and by many savage peoples.</cd> -- <col><b>Fire
eater</b></col>. <sd>(a)</sd> <cd>A juggler who pretends to eat
fire.</cd> <sd>(b)</sd> <cd>A quarrelsome person who seeks affrays; a
hotspur.</cd> <mark>[Colloq.]</mark> -- <col><b>Fire engine</b></col>,
<cd>a portable forcing pump, usually on wheels, for throwing water to
extinguish fire.</cd> -- <col><b>Fire escape</b></col>, <cd>a
contrivance for facilitating escape from burning buildings.</cd> --
<col><b>Fire gilding</b></col> <fld>(Fine Arts)</fld>, <cd>a mode of
gilding with an amalgam of gold and quicksilver, the latter metal being
driven off afterward by heat.</cd> -- <col><b>Fire gilt</b></col>
<fld>(Fine Arts)</fld>, <cd>gold laid on by the process of fire
gilding.</cd> -- <col><b>Fire insurance</b></col>, <cd>the act or system
of insuring against fire; also, a contract by which an insurance company
undertakes, in consideration of the payment of a premium or small
percentage -- usually made periodically -- to indemnify an owner of
property from loss by fire during a specified period.</cd> --
<col><b>Fire irons</b></col>, <cd>utensils for a fireplace or grate, as
tongs, poker, and shovel.</cd> -- <col><b>Fire main</b></col>, <cd>a
pipe for water, to be used in putting out fire.</cd> -- <col><b>Fire
master</b></col> <sd>(Mil)</sd>, <cd>an artillery officer who formerly
supervised the composition of fireworks.</cd> -- <col><b>Fire
office</b></col>, <cd>an office at which to effect insurance against
fire.</cd> -- <col><b>Fire opal</b></col>, <cd>a variety of opal giving
firelike reflections.</cd> -- <col><b>Fire ordeal</b></col>, <cd>an
ancient mode of trial, in which the test was the ability of the accused
to handle or tread upon red-hot irons.</cd> <au>Abbot.</au> --
<col><b>Fire pan</b></col>, <cd>a pan for holding or conveying fire,
especially the receptacle for the priming of a gun.</cd> -- <col><b>Fire
plug</b></col>, <cd>a plug or hydrant for drawing water from the main
pipes in a street, building, etc., for extinguishing fires.</cd> --
<col><b>Fire policy</b></col>, <cd>the writing or instrument expressing
the contract of insurance against loss by fire.</cd> -- <col><b>Fire
pot</b></col>. <sd>(a)</sd> <fld>(Mil.)</fld> <cd>A small earthen pot
filled with combustibles, formerly used as a missile in war.</cd>
<sd>(b)</sd> <cd>The cast iron vessel which holds the fuel or fire in a
furnace.</cd> <sd>(c)</sd> <cd>A crucible.</cd> <sd>(d)</sd> <cd>A
solderer's furnace.</cd> -- <col><b>Fire raft</b></col>, <cd>a raft
laden with combustibles, used for setting fire to an enemy's ships.</cd>
-- <col><b>Fire roll</b></col>, <cd>a peculiar beat of the drum to
summon men to their quarters in case of fire.</cd> -- <col><b>Fire
setting</b></col> <fld>(Mining)</fld>, <cd>the process of softening or
cracking the working face of a lode, to facilitate excavation, by
exposing it to the action of fire; -- now generally superseded by the
use of explosives.</cd> <au>Raymond.</au> -- <col><b>Fire
ship</b></col>, <cd>a vessel filled with combustibles, for setting fire
to an enemy's ships.</cd> -- <col><b>Fire shovel</b></col>, <cd>a shovel
for taking up coals of fire.</cd> -- <col><b>Fire stink</b></col>,
<cd>the stench from decomposing iron pyrites, caused by the formation of
hydrogen sulfide.</cd> <au>Raymond.</au> -- <col><b>Fire
surface</b></col>, <cd>the surfaces of a steam boiler which are exposed
to the direct heat of the fuel and the products of combustion; heating
surface.</cd> -- <col><b>Fire swab</b></col>, <cd>a swab saturated with
water, for cooling a gun in action and clearing away particles of
powder, etc.</cd> <au>Farrow.</au> -- <col><b>Fire teaser</b></col>,
<cd>in England, the fireman of a steam emgine.</cd> -- <col><b>Fire
water</b></col>, <cd>a strong alcoholic beverage; -- so called by the
American Indians.</cd> -- <col><b>Fire worship</b></col>, <cd>the
worship of fire, which prevails chiefly in Persia, among the followers
of <persfn>Zoroaster</persfn>, called <xex>Chebers</xex>, or
<xex>Guebers</xex>, and among the Parsees of India.</cd> --
<col><b>Greek fire</b></col>. <cd>See under <er>Greek</er>.</cd> --
<col><b>On fire</b></col>, <cd>burning; hence, ardent; passionate;
eager; zealous.</cd> -- <col><b>Running fire</b></col>, <cd>the rapid
discharge of firearms in succession by a line of troops.</cd> --
<col><b>St. Anthony's fire</b></col>, <cd>erysipelas; -- an eruptive
fever which St. Anthony was supposed to cure miraculously.</cd>
<au>Hoblyn.</au> -- <col><b>St. Elmo's fire</b></col>. <cd>See under
<er>Saint Elmo</er>.</cd> -- <col><b>To set on fire</b></col>, <cd>to
inflame; to kindle.</cd> -- <col><b>To take fire</b></col>, <cd>to begin
to burn; to fly into a passion.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fire</ent><br/
<hw>Fire</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Fired</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Fring</conjf>.]</vmorph> <sn>1.</sn> <def>To set on fire; to
kindle; <as>as, to <ex>fire</ex> a house or chimney; to <ex>fire</ex> a
pile.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To subject to intense heat; to bake; to burn in a
kiln; <as>as, to <ex>fire</ex> pottery</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To inflame; to irritate, as the passions; <as>as, to
<ex>fire</ex> the soul with anger, pride, or revenge</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Love had <qex>fired</qex> my mind.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To animate; to give life or spirit to; <as>as, to
<ex>fire</ex> the genius of a young man</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To feed or serve the fire of; <as>as, to
<ex>fire</ex> a boiler</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To light up as if by fire; to illuminate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>[The sun] <qex>fires</qex> the proud tops of the eastern
pines.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>To cause to explode; <as>as, to <ex>fire</ex> a
torpedo</as>; to discharge; <as>as, to <ex>fire</ex> a rifle, pistol, or
cannon; to <ex>fire</ex> cannon balls, rockets, etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>To drive by fire.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Till my bad angel <qex>fire</qex> my good one out.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <fld>(Far.)</fld> <def>To cauterize.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <def>to dismiss from employment, a post, or other job;
to cause (a person) to cease being an employee; -- of a person. The act
of <ex>firing</ex> is usually performed by that person's supervisor or
employer.</def> <ldquo/You can't <xex>fire</xex> me! I quit!<rdquo/<br/
[<source>PJC</source>]</p>

<p><cs><col><b>To fire up</b></col>, <sn>1.</sn> <cd>to light up the
fires of, as of an engine;</cd> <specif>also,</specif>
<mark>figuratively</mark>, <cd>to start up any machine.</cd> --
<sn>2.</sn> <cd>to render enthusiastic; -- of people.</cd></cs><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Fire</ent><br/
<hw>Fire</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To take fire; to be
kindled; to kindle.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To be irritated or inflamed with passion.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To discharge artillery or firearms; <as>as, they
<ex>fired</ex> on the town</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To fire up</b></col>, <cd>to grow irritated or
angry.</cd> <ldquo/He . . . <xex>fired up</xex>, and stood vigorously on
his defense.<rdquo/ <rj><au>Macaulay.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>fire-on-the-mountain</ent><br/
<hw>fire-on-the-mountain</hw> <pos>n.</pos> <sn>1.</sn> <def>poinsettia
(<spn>Euphoria cyathophora</spn>) of the U. S. and eastern Mexico; often
confused with <spn>Euphoria heterophylla</spn>.</def><br/
<syn><b>Syn. --</b> painted leaf, Mexican fire plant, <spn>Euphoria
cyathophora</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Firearm</ent><br/
<hw>Fire"arm`</hw> <pr>(f<imac/r"<aum/rm`)</pr>, <pos>n.</pos> <def>A
gun, pistol, or any weapon from which a shot is discharged by the force
of an explosive substance, as gunpowder.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fireback</ent><br/
<hw>Fire"back`</hw> <pr>(f<imac/r"b<acr/k`)</pr>, <pos>n.</pos>
<fld>(Zool.)</fld> <def>One of several species of pheasants of the genus
<gen>Euplocamus</gen>, having the lower back a bright, fiery red. They
inhabit Southern Asia and the East Indies.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fireball</ent><br/
<hw>Fire"ball`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<fld>(Mil.)</fld> <def>A ball filled with powder or other combustibles,
intended to be thrown among enemies, and to injure by explosion; also,
to set fire to their works and light them up, so that movements may be
seen.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A rare phenomenon often associated with or caused by
lightning, resembling a luminous ball of fire passing rapidly through
the air or along solid objects, then disappearing, and sometimes
exploding. It seldom lasts more than a few seconds. Also called
<altname>ball lightning</altname>, <altname>globe lightning</altname>,
<altname>globular lightning</altname>, or
<altname>kugelblitz</altname>.</def><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><sn>3.</sn> <def>A large mass of fire caused by a large explosion, as
of inflammable liquids or a nuclear device. The larger
<ex>fireballs</ex>, as of nuclear explosions, rise seemingly intact into
the air and may reach high altitudes while still glowing.</def><br/
[<source>PJC</source>]</p>

<p><ent>Firebare</ent><br/
<hw>Fire"bare`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A beacon.</def>
<mark>[Obs.]</mark> <rj><au>Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fire beetle</ent><br/
<hw>Fire" bee`tle</hw> <pr>(?)</pr>. <fld>(Zool.)</fld> <def>A very
brilliantly luminous beetle (<spn>Pyrophorus noctilucus</spn>), one of
the elaters, found in Central and South America; -- called also
<altname>cucujo</altname>. The name is also applied to other species.
See <er>Firefly</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Firebird</ent><br/
<hw>Fire"bird`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>The Baltimore oriole.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fireboard</ent><br/
<hw>Fire"board`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A chimney board or
screen to close a fireplace when not in use.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Firebote</ent><br/
<hw>Fire"bote`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(O. Eng. Law)</fld>
<def>An allowance of fuel. See <er>Bote</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Firebrand</ent><br/
<hw>Fire"brand`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A
piece of burning wood.</def> <rj><au>L'Estrange.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who inflames factions, or causes contention and
mischief; an incendiary.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>firebrat</ent><br/
<hw>firebrat</hw> <pos>n.</pos> <fld>(Zool.)</fld> <def>an insect
(<spn>Thermobia domestica</spn>) which is a type of bristletail that
lives in warm moist areas e.g. around furnaces.</def><br/
<syn><b>Syn. --</b> <spn>Thermobia domestica</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>firebreak</ent><br/
<hw>firebreak</hw> <pos>n.</pos> <def>a narrow field that has been
cleared to check the spread of a prairie fire or forest fire.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>firebrick</ent><br/
<hw>firebrick</hw> <pos>n.</pos> <def>a brick made of fire clay, used
for lining e.g. furnaces and chimneys.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>firebug</ent><br/
<hw>firebug</hw> <pos>n.</pos> <def>a criminal who illegally sets fire
to property; an arsonist.</def><br/
<syn><b>Syn. --</b> arsonist, incendiary.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>a brightly colored type of true bug that can exude a
stain.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>firebush</ent><br/
<hw>firebush</hw> <pos>n.</pos> <sn>1.</sn> <def>An evergreen South
American shrub *<spn>Streptosolen jamesonii</spn>) having showy
trumpet-shaped orange flowers; grown as an ornamental or
houseplant.</def><br/
<syn><b>Syn. --</b> marmalade bush, <spn>Streptosolen
jamesonii</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>A densely branched Eurasian plant (<spn>Bassia
scoparia</spn>) whose foliage turns purple-red in autumn; also called
<altname>burning bush</altname>.</def><br/
<syn><b>Syn. --</b> summer cypress, burning bush, belvedere, <spn>Bassia
scoparia</spn>, Kochia scoparia.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>fireclay</ent><br/
<hw>fireclay</hw> <pos>n.</pos> <def>a heat-resistant clay.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>firecracker</ent><br/
<hw>fire"crack`er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A small
explosive device consisting of a paper or cardboard cylinder having only
sufficient explosive mixture to make a loud bang, ignited by a short
fuse, and used mostly as an entertainment or in celebrations. Same as
<er>Cracker</er>., <pos>n.</pos>, 3.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Firecrest</ent><br/
<hw>Fire"crest`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>A small European kinglet (<spn>Regulus ignicapillus</spn>), having
a bright red crest; -- called also <altname>fire-crested
wren</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>firedamp</ent><br/
<hw>firedamp</hw> <pos>n.</pos> <def>a mixture of gases (mostly methane)
that forms in coal mines and becomes explosive when mixed with air. It
is a source of serious hazard in coal mining operations.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Firedog</ent><br/
<hw>Fire"dog`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A support for wood
in a fireplace; an andiron.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Firedrake</ent><br/
<hw>Fire"drake`</hw> <pr>(f<imac/r"dr<amac/k`)</pr>, <pos>n.</pos>
<ety>[AS. <ets>f<ymac/rdraca</ets>; <ets>f<ymac/r</ets> fire +
<ets>draca</ets> a dragon. See <er>Fire</er>, and <er>Drake</er> a
dragon.]</ety> <mark>[Obs.]</mark> <sn>1.</sn> <def>A fiery
dragon.</def> <rj><au>Beau. & Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A fiery meteor; an ignis fatuus; a rocket.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A worker at a furnace or fire.</def> <rj><au>B.
Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fire-fanged</ent><br/
<hw>Fire"-fanged`</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Fire</ets>
+ <ets>fanged</ets> seized.]</ety> <def>Injured as by fire; burned; --
said of manure which has lost its goodness and acquired an ashy hue in
consequence of heat generated by decomposition.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>fire fighter</ent><br/
<ent>firefighter</ent><br/
<mhw><hw>fire"fight`er</hw>, <hw>fire" fight`er</hw></mhw>
<pr>(f<imac/r"f<imac/`t<etil/r)</pr>, <pos>n.</pos> <def>A person whose
occupation it is to go to the scene of an unwanted fire and extinguish
it; a member of a fire company; a <stype>fireman{1}</stype> or a woman
who fights fires.</def> <note>Some towns have few or no professional
firefighters, and fire suppression is conducted mostly by groups of
volunteers, called <stype>volunteer firefighters</stype>. The term
fireman{1} was at one time synonymous with firefighter, until women
began to engage in the same occupation.</note><br/
[<source>PJC</source>]</p>

<p><ent>Firefish</ent><br/
<hw>Fire"fish`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>A singular marine fish of the genus <gen>Pterois</gen>, family
<fam>Scorp<ae/nid<ae/</fam>, of several species, inhabiting the
Indo-Pacific region. They are usually red, and have very large spinose
pectoral and dorsal fins.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fireflaire</ent><br/
<hw>Fire"flaire`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Fire</ets>
+ Prov. E. <ets>flaire</ets> a ray.]</ety> <fld>(Zool.)</fld> <def>A
European sting ray of the genus <gen>Trygon</gen> (<spn>T.
pastinaca</spn>); -- called also <altname>fireflare</altname> and
<altname>fiery flaw</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fireflame</ent><br/
<hw>Fire"flame`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>The European band fish (<spn>Cepola rubescens</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Firefly</ent><br/
<hw>Fire"fly`</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Fireflies</plw> <pr>(<?/)</pr>.</plu> <fld>(Zool.)</fld> <def>Any
luminous winged insect, esp. luminous beetles of the family
<fam>Lampyrid<ae/</fam>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The common American species belong to the genera
<gen>Photinus</gen> (especially <spn>Photinus pyralis</spn>) and
<gen>Photuris</gen>, in which both sexes are winged. The name is also
applied to luminous species of <fam>Elaterid<ae/</fam>. See <er>Fire
beetle</er>.</note><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Firefly luciferin</ent><br/
<hw>Fire"fly` lu*cif"er*in</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Biochem.)</fld> <def>a type of <er>luciferin</er> produced by the
firefly <spn>Photinus pyralis</spn>.</def> <note>Its structure has been
elucidated, and chemically it is recognized as
<chname>4,5-Dihydro-2-(6-hydroxy-2-benzothiazol-2-yl)-4-thiazolecarboxylic
acid</chname>, <chform>C11H8N3O2S2</chform>. It has found use in a very
sensitive assay for ATP, in which concentrations of ATP as low as
10<exp>-11</exp> molar can be detected. <au>[MI11]</au></note><br/
[<source>PJC</source>]</p>

<p><ent>firehouse</ent><br/
<hw>firehouse</hw> <pos>n.</pos> <def>a building housing firemen and the
apparatus they use to extinguish fires.</def><br/
<syn><b>Syn. --</b> fire station.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>fire hydrant</ent><br/
<hw>fire hydrant</hw> <pos>n.</pos> <def>an upright hydrant that can
supply large volumes of water to use in fighting a fire. They are
commonly placed at intervals at the street edge of a sidewalk, spaced
for convenience in suppressing fires in towns.</def><br/
<syn><b>Syn. --</b> fireplug, plug.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Fireless</ent><br/
<hw>Fire"less</hw>, <pos>a.</pos> <def>Destitute of fire.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>firelight</ent><br/
<hw>firelight</hw> <pos>n.</pos> <def>the light of a fire (especially in
a fireplace); <as>as, lovers sitting together in the
<ex>firelight</ex></as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>firelighter</ent><br/
<hw>firelighter</hw> <pos>n.</pos> <def>(a piece of) a substance that
burns easily and can be used to start a coal or coke fire.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Firelock</ent><br/
<hw>Fire"lock`</hw>, <pos>n.</pos> <def>An old form of gunlock, as the
flintlock, which ignites the priming by a spark; perhaps originally, a
matchlock. Hence, a gun having such a lock.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fireman</ent><br/
<hw>Fire"man</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Firemen</plw> <pr>(-m<it>e</it>n)</pr>.</plu> <sn>1.</sn> <def>A
man whose business is to extinguish fires in towns; a member of a fire
company.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A man who tends the fires, as of a steam engine; a
stocker.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fire-new</ent><br/
<hw>Fire"-new`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Fresh from the
forge; bright; quite new; brand-new.</def> <rj><au>Charles
reade.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Your <qex>fire-new</qex> stamp of honor is scarce current.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fireplace</ent><br/
<hw>Fire"place`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The part a chimney
appropriated to the fire; a hearth; -- usually an open recess in a wall,
in which a fire may be built.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>fireplug</ent><br/
<hw>fireplug</hw> <pos>n.</pos> <def>an upright hydrant that can supply
large volumes of water to use in fighting a fire. They are commonly
placed at intervals at the street edge of a sidewalk for convenience in
suppressing fires in towns.</def><br/
<syn><b>Syn. --</b> fire hydrant, plug.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>firepower</ent><br/
<hw>firepower</hw> <pos>n.</pos> <sn>1.</sn> <fld>(military)</fld>
<def>The relative capacity for delivering weapons fire on a target;
<as>as, the battleship has more <ex>firepower</ex> than a
cruiser</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <mark>[figurative]</mark> <def>A measure of the resources
available to a group which allows them to achieve their objectives;
capacity for action.</def><br/
[<source>PJC</source>]</p>

<p><ent>Fireproof</ent><br/
<hw>Fire"proof`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Proof against
fire; incombustible.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fireproofing</ent><br/
<hw>Fire"proof`ing</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act or
process of rendering anything incombustible; also, the materials used in
the process.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>fire-raising</ent><br/
<hw>fire-raising</hw> <pos>n.</pos> <def>malicious burning to destroy
property; arson.</def> <mark>[Mostly British usage]</mark> <br/
<syn><b>Syn. --</b> arson, incendiarism.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Firer</ent><br/
<hw>Fir"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who fires or sets
fire to anything; an incendiary.</def> <mark>[R.]</mark> <rj><au>R.
Carew.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>fire-resistive</ent><br/
<ent>fire-resisting</ent><br/
<ent>fire-resistant</ent><br/
<mhw><hw>fire-resistant</hw> <hw>fire-resisting</hw>
<hw>fire-resistive</hw></mhw> <pos>adj.</pos> <def>Not able to burn or
able to burn only with difficulty.</def> [Narrower terms:
<stype>noncombustible (vs. combustible), incombustible</stype>]<br/
<syn><b>Syn. --</b> fireproof.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>fire-retardant</ent><br/
<hw>fire-retardant</hw> <pos>adj.</pos> <def>able to reduce
combustibility or slow the spread of fire; -- of substances that are
added to combustible materials to make them less combustible.</def><br/
<source>PJC</source>]</p>

<p><ent>fire retardant</ent><br/
<hw>fire retardant</hw> <pos>n.</pos> <def>a substance applied or added
to materials or objects, so as to reduce combustibility or slow the
spread of fire.</def><br/
<source>PJC</source>]</p>

<p><ent>Fireroom</ent><br/
<hw>Fire"room`</hw>, <pos>n.</pos> <def>Same as <er>Stokehold</er>,
below.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>fire sale</ent><br/
<hw>fire sale</hw> <pos>n.</pos> <sn>1.</sn> <def>a sale of objects
damaged by fire, usually at much reduced prices.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>A sale of objects or assets at much reduced prices,
often performed to raise money rapidly.</def><br/
[<source>PJC</source>]</p>

<p><ent>fire-sale price</ent><br/
<hw>fire-sale price</hw> <pos>n.</pos> <def>a price much lower than
normal market price; <as>as, the Reagan administration sold off valuable
mineral and timber resources at <ex>fire-sale
prices</ex></as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Fire-set</ent><br/
<hw>Fire"-set`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A set of fire
irons, including, commonly, tongs, shovel, and poker.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fireside</ent><br/
<hw>Fire"side`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A place near the
fire or hearth; home; domestic life or retirement.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Firestone</ent><br/
<hw>Fire"stone`</hw> <pr>(?; 110)</pr>, <pos>n.</pos> <ety>[AS.
<ets>f<ymac/rst<amac/n</ets> flint; <ets>f<ymac/r</ets> fire +
<ets>st<amac/n</ets> stone.]</ety> <sn>1.</sn> <def>Iron pyrites,
formerly used for striking fire; also, a flint.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A stone which will bear the heat of a furnace
without injury; -- especially applied to the sandstone at the top of the
upper greensand in the south of England, used for lining kilns and
furnaces.</def> <rj><au>Ure.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Firetail</ent><br/
<hw>Fire"tail`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>The European redstart; -- called also
<altname>fireflirt</altname>.</def> <mark>[prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>fire-tree</ent><br/
<hw>fire-tree</hw> <pos>n.</pos> <def>a terrestrial evergreen shrub or
small tree (<spn>Nuytsia floribunda</spn>) of West Australia having
brilliant yellow-orange flowers; parasitic on roots of
grasses.</def><br/
<syn><b>Syn. --</b> flame tree, flame-tree, Christmas tree, <spn>Nuytsia
floribunda</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Firewarden</ent><br/
<hw>Fire"ward`en</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An officer who
has authority to direct in the extinguishing of fires, or to order what
precautions shall be taken against fires; -- called also
<altname>fireward</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fireweed</ent><br/
<hw>Fire"weed`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<sd>(a)</sd> <def>An American plant (<spn>Erechthites
hiercifolia</spn>), very troublesome in spots where brushwood has been
burned.</def> <sd>(b)</sd> <def>The great willow-herb (<spn>Epilobium
spicatum</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>firewheel</ent><br/
<hw>firewheel</hw> <pos>n.</pos> <def>An annual of the central U. S.
(<spn>Gaillardia pulchella</spn>) having showy long-stalked yellow
flower heads marked with scarlet or purple in the center.</def><br/
<syn><b>Syn. --</b> blanket flower, Indian blanket, <spn>Gaillardia
pulchella</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Firewood</ent><br/
<hw>Fire"wood`</hw> <pr>(f<imac/r"w<oocr/d`)</pr>, <pos>n.</pos>
<def>Wood for fuel.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>firework</ent><br/
<hw>fire"work`</hw> <pr>(f<imac/r"w<ucir/rk`)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>A device for producing a striking display of light, or
a figure or figures in plain or colored fire, by the combustion of
materials that burn in some peculiar manner, as gunpowder, sulphur,
metallic filings, and various salts; also called a <altname>pyrotechnic
device</altname>. The most common feature of fireworks is a paper or
pasteboard tube filled with the combustible material. A number of these
tubes or cases are often combined so as to make, when kindled, a great
variety of figures in fire, often variously colored. The skyrocket is a
common form of <ex>firework</ex>. The art of designing fireworks for
purposes of entertainment is called <er>pyrotechnics</er>. The name
<ex>firework</ex> is also given to various combustible preparations used
in war.</def></p>

<p><sn>2.</sn> <pluf>pl.</pluf> <def>A pyrotechnic exhibition; an
entertainment consisting of the discharge of fireworks{1}.</def>
<mark>[Obs. in the sing.]</mark><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><q>Night before last, the Duke of Richmond gave a
<qex>firework</qex>.</q> <rj><qau>Walpole.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fireworm</ent><br/
<hw>Fire"worm`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>The larva of a small tortricid moth which eats the leaves of the
cranberry, so that the vines look as if burned; -- called also
<altname>cranberry worm</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Firing</ent><br/
<hw>Fir"ing</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act of discharging
firearms.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The mode of introducing fuel into the furnace and
working it.</def> <rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The application of fire, or of a cautery.</def>
<rj><au>Dunglison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The process of partly vitrifying pottery by exposing
it to intense heat in a kiln.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Fuel; firewood or coal.</def> <mark>[Obs.]</mark>
<rj><au>Mortimer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Firing iron</b></col>, <cd>an instrument used in
cauterizing.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 563 --></p>

<p><ent>Firing pin</ent><br/
<hw>Fir"ing pin`</hw>. <def>In the breech mechanism of a firearm, the
pin which strikes the head of the cartridge and explodes it.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Firk</ent><br/
<hw>Firk</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Cf. OE.
<ets>ferken</ets> to proceed, hasten, AS. <ets>fercian</ets> to bring,
assist; perh. akin to <ets>faran</ets> to go, E. <ets>fare</ets>.]</ety>
<def>To beat; to strike; to chastise.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I'll fer him, and <qex>firk</qex> him, and ferret him.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Firk</ent><br/
<hw>Firk</hw>, <pos>v. i.</pos> <def>To fly out; to turn out; to go
off.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>A wench is a rare bait, with which a man</q><br/
[<source>1913 Webster</source>]</p>

<p><q>No sooner's taken but he straight <qex>firks</qex>
mad.B.Jonson.</q><br/
[<source>1913 Webster</source>]</p>

<p><ent>Firk</ent><br/
<hw>Firk</hw>, <pos>n.</pos> <def>A freak; trick; quirk.</def>
<mark>[Obs.]</mark> <rj><au>Ford.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Firkin</ent><br/
<hw>Fir"kin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From AS.
<ets>fe<oacute/wer</ets> four (or an allied word, perh. Dutch or Danish)
+ <ets>-kin</ets>. See <er>Four</er>.]</ety> <sn>1.</sn> <def>A varying
measure of capacity, usually being the fourth part of a barrel;
specifically, a measure equal to nine imperial gallons.</def>
<mark>[Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A small wooden vessel or cask of indeterminate size,
-- used for butter, lard, etc.</def> <mark>[U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Firlot</ent><br/
<hw>Fir"lot</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Scot., the fourth
part of a boll of grain, from a word equiv. to E. <ets>four + lot</ets>
part, portion. See <er>Firkin</er>.]</ety> <def>A dry measure formerly
used in Scotland; the fourth part of a boll of grain or meal. The
Linlithgow wheat firlot was to the imperial bushel as 998 to 1000; the
barley firlot as 1456 to 1000.</def> <rj><au>Brande & C.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Firm</ent><br/
<hw>Firm</hw> <pr>(?)</pr>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Firmer</adjf> <pr>(?)</pr>; <pos>superl.</pos>
<adjf>Firmest</adjf>.]</amorph> <ety>[OE. <ets>ferme</ets>, F.
<ets>ferme</ets>, fr.L. <ets>firmus</ets>; cf. Skr. <ets>dharman</ets>
support, law, order, <ets>dh<?/</ets> to hold fast, carry. Cf.
<er>Farm</er>, <er>Throne</er>.]</ety> <sn>1.</sn> <def>Fixed; hence,
closely compressed; compact; substantial; hard; solid; -- applied to the
matter of bodies; <as>as, <ex>firm</ex> flesh; <ex>firm</ex> muscles,
<ex>firm</ex> wood.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Not easily excited or disturbed; unchanging in
purpose; fixed; steady; constant; stable; unshaken; not easily changed
in feelings or will; strong; <as>as, a <ex>firm</ex> believer; a
<ex>firm</ex> friend; a <ex>firm</ex> adherent.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Under spread ensigns, moving nigh, in slow<br/
But <qex>firm</qex> battalion.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>By one man's <qex>firm</qex> obediency fully tried.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Solid; -- opposed to <xex>fluid</xex>; <as>as,
<ex>firm</ex> land</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Indicating firmness; <as>as, a <ex>firm</ex> tread;
a <ex>firm</ex> countenance.</as></def></p>

<p><syn><b>Syn.</b> -- Compact; dense; hard; solid; stanch; robust;
strong; sturdly; fixed; steady; resolute; constant.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Firm</ent><br/
<hw>Firm</hw>, <pos>n.</pos> <ety>[It. <ets>firma</ets> the (firm, sure,
or confirming) signature or subscription, or Pg. <ets>firma</ets>
signature, firm, cf. Sp. <ets>firma</ets> signature; all fr. L.
<ets>firmus</ets>, adj., firm. See <er>Firm</er>, <pos>a.</pos>]</ety>
<def>The name, title, or style, under which a company transacts
business; a partnership of two or more persons; a commercial house;
<as>as, the <ex>firm</ex> of Hope & Co.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Firm</ent><br/
<hw>Firm</hw>, <pos>v. t.</pos> <ety>[OE. <ets>fermen</ets> to make
firm, F. <ets>fermer</ets>, fr. L. <ets>firmare</ets> to make firm. See
<er>Firm</er>, <pos>a.</pos>]</ety> <sn>1.</sn> <def>To fix; to settle;
to confirm; to establish.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>And Jove has <qex>firmed</qex> it with an awful nod.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To fix or direct with firmness.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He on his card and compass <qex>firms</qex> his eye.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Firmament</ent><br/
<hw>Fir"ma*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>firmamentum</ets>, fr. <ets>firmare</ets> to make firm: cf. F.
<ets>firmament</ets>. See <er>Firm</er>, <pos>v. & a.</pos>]</ety>
<sn>1.</sn> <def>Fixed foundation; established basis.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Custom is the . . . <qex>firmament</qex> of the law.</q>
<rj><qau>Jer. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The region of the air; the sky or heavens.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And God said, Let there be a <qex>firmament</qex> in the midst of
the waters, and let it divide the waters from the waters.</q>
<rj><qau>Gen. i. 6.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And God said, Let there be lights in the <qex>firmament</qex>.</q>
<rj><qau>Gen. i. 14.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In Scripture, the word denotes an expanse, a wide
extent; the great arch or expanse over out heads, in which are placed
the atmosphere and the clouds, and in which the stars <xex>appear</xex>
to be placed, and are <xex>really</xex> seen.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Old Astron.)</fld> <def>The orb of the fixed stars;
the most remote of the celestial spheres.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Firmamental</ent><br/
<hw>Fir`ma*men"tal</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to
the firmament; celestial; being of the upper regions.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Firman</ent><br/
<hw>Fir"man</hw> <pr>(? <or/ ?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Firmans</plw> <pr>(#)</pr> <xex>or</xex> <pr>(#)</pr>.</plu>
<ety>[Pers. <ets>ferm<amac/n</ets>.]</ety> <def>In Turkey and some other
Oriental countries, a decree or mandate issued by the sovereign; a royal
order or grant; -- generally given for special objects, as to a traveler
to insure him protection and assistance.</def> <altsp>[Written also
<asp>firmaun</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Firmer-chisel</ent><br/
<hw>Firm"er-chis"el</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A chisel, thin
in proportion to its width. It has a tang to enter the handle instead of
a socket for receiving it.</def> <rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Firmitude</ent><br/
<hw>Firm"i*tude</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>firmitudo</ets>. See <er>Firm</er>.]</ety> <def>Strength;
stability.</def> <mark>[Obs.]</mark> <rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Firmity</ent><br/
<hw>Firm"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>firmitas</ets>.]</ety> <def>Strength; firmness; stability.</def>
<mark>[Obs.]</mark> <rj><au>Chillingworth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Firmless</ent><br/
<hw>Firm"less</hw>, <pos>a.</pos> <sn>1.</sn> <def>Detached from
substance.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Does passion still the <qex>firmless</qex> mind control?</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Infirm; unstable.</def> <ldquo/<xex>Firmless</xex>
sands.<rdquo/ <rj><au>Sylvester.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Firmly</ent><br/
<hw>Firm"ly</hw>, <pos>adv.</pos> <def>In a firm manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Firmness</ent><br/
<hw>Firm"ness</hw>, <pos>n.</pos> <def>The state or quality of being
firm.</def></p>

<p><syn><b>Syn.</b> -- <er>Firmness</er>, <er>Constancy</er>.</syn>
<usage> <xex>Firmness</xex> belongs to the will, and
<xex>constancy</xex> to the affections and principles; the former
prevents us from yielding, and the latter from fluctuating. Without
<xex>firmness</xex> a man has no character; <ldquo/without
<xex>constancy</xex>,<rdquo/ says Addison, <ldquo/there is neither love,
friendship, nor virtue in the world.<rdquo/</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Firms</ent><br/
<hw>Firms</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[From <er>Firm</er>,
<pos>a.</pos>]</ety> <fld>(Arch.)</fld> <def>The principal rafters of a
roof, especially a pair of rafters taken together.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Firring</ent><br/
<hw>Fir"ring</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Arch.)</fld>
<def>See <er>Furring</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Firry</ent><br/
<hw>Fir"ry</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Made of fir; abounding
in firs.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In <qex>firry</qex> woodlands making moan.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>First</ent><br/
<hw>First</hw> <pr>(f<etil/rst)</pr>, <pos>a.</pos> <ety>[OE.
<ets>first</ets>, <ets>furst</ets>, AS. <ets>fyrst</ets>; akin to Icel.
<ets>fyrstr</ets>, Sw. & Dan. <ets>f<oum/rste</ets>, OHG.
<ets>furist</ets>, G. <ets>f<uum/rst</ets> prince; a superlatiye form of
E. <ets>for</ets>, <ets>fore</ets>. See <er>For</er>, <er>Fore</er>, and
cf. <er>Formeer</er>, <er>Foremost</er>.]</ety> <sn>1.</sn>
<def>Preceding all others of a series or kind; the ordinal of one;
earliest; <as>as, the <ex>first</ex> day of a month; the <ex>first</ex>
year of a reign.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Foremost; in front of, or in advance of, all
others.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Most eminent or exalted; most excellent; chief;
highest; <as>as, Demosthenes was the <ex>first</ex> orator of
Greece</as>.</def><br/
[<source>1913 Webster</source>]</p>

<cs><p><col><b>At first blush</b></col>. <cd>See under
<er>Blush</er>.</cd> -- <col><b>At first hand</b></col>, <cd>from the
first or original source; without the intervention of any
agent.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>It is the intention of the person to reveal it <qex>at first
hand</qex>, by way of mouth, to yourself.</q>
<rj><qau>Dickens.</qau></rj></p>

<p>-- <col><b>First coat</b></col> <fld>(Plastering)</fld>, <cd>the
solid foundation of coarse stuff, on which the rest is placed; it is
thick, and crossed with lines, so as to give a bond for the next
coat.</cd> -- <col><b>First day</b></col>, <cd>Sunday; -- so called by
the Friends.</cd> -- <col><b>First floor</b></col>. <sd>(a)</sd> <cd>The
ground floor.</cd> <mark>[U.S.]</mark> <sd>(b)</sd> <cd>The floor next
above the ground floor.</cd> <mark>[Eng.]</mark> -- <mcol><col><b>First
fruit</b></col> <it>or</it> <col><b>First fruits</b></col></mcol>.
<sd>(a)</sd> <cd>The fruits of the season earliest gathered.</cd>
<sd>(b)</sd> <fld>(Feudal Law)</fld> <cd>One year's profits of lands
belonging to the king on the death of a tenant who held directly from
him.</cd> <sd>(c)</sd> <fld>(Eng. Eccl. Law)</fld> <cd>The first year's
whole profits of a benefice or spiritual living.</cd> <sd>(d)</sd>
<cd>The earliest effects or results.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>See, Father, what <qex>first fruits</qex> on earth are sprung<br/
From thy implanted grace in man!</q> <rj><qau>Milton.</qau></rj></p>

<p>-- <col><b>First mate</b></col>, <cd>an officer in a merchant vessel
next in rank to the captain.</cd> -- <col><b>First name</b></col>,
<cd>same as <cref>Christian name</cref>. See under <er>Name</er>,
<pos>n.</pos></cd> -- <col><b>First officer</b></col>
<fld>(Naut.)</fld>, <cd>in the merchant service, same as <cref>First
mate</cref> (above).</cd> -- <col><b>First sergeant</b></col>
<fld>(Mil.)</fld>, <cd>the ranking non-commissioned officer in a
company; the orderly sergeant.</cd> <au>Farrow.</au> -- <col><b>First
watch</b></col> <fld>(Naut.)</fld>, <cd>the watch from eight to twelve
at midnight; also, the men on duty during that time.</cd> --
<col><b>First water</b></col>, <cd>the highest quality or purest luster;
-- said of gems, especially of diamond and pearls.</cd></p></cs>

<p><syn><b>Syn.</b> -- Primary; primordial; primitive; primeval;
pristine; highest; chief; principal; foremost.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>First</ent><br/
<hw>First</hw> <pr>(f<etil/rst)</pr>, <pos>adv.</pos> <def>Before any
other person or thing in time, space, rank, etc.; -- much used in
composition with adjectives and participles.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Adam was <qex>first</qex> formed, then Eve.</q> <rj><qau>1 Tim.
ii. 13.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs> <mcol><col><b>At first</b></col>, <col><b>At the
first</b></col></mcol>, <cd>at the beginning or origin.</cd> --
<col><b>First or last</b></col>, <cd>at one time or another; at the
beginning or end.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><q>And all are fools and lovers <qex>first or last</qex>.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>First</ent><br/
<hw>First</hw>, <pos>n.</pos> <fld>(Mus.)</fld> <def>The upper part of a
duet, trio, etc., either vocal or instrumental; -- so called because it
generally expresses the air, and has a pre<eum/minence in the combined
effect.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>first aid</ent><br/
<hw>first` aid"</hw> <pr>(f<etil/rst` <amac/d")</pr>, <pos>n.</pos>
<def>Medical care provided immediately after an injury or sudden illness
for the purpose of minimizing injurious effects, before more complete
medical care becomes available.</def><br/
[<source>PJC</source>]</p>

<p><ent>firstborn</ent><br/
<hw>first"born`</hw> <pr>(f<etil/rst"b<ocir/rn`)</pr>, <pos>n.</pos>
<def>The first child born to a parent; <as>as, his <ex>firstborn</ex>
was showered with gifts from relatives</as>.</def><br/
<syn><b>Syn. --</b> eldest.</syn><br/
[<source>PJC</source>]</p>

<p><ent>Firstborn</ent><br/
<hw>First"born`</hw> <pr>(f<etil/rst"b<ocir/rn`)</pr>, <pos>a.</pos>
<def>First brought forth; first in the order of birth; eldest; hence,
most excellent; most distinguished or exalted; <as>as, the
<ex>firstborn</ex> child</as>.</def><br/
<syn><b>Syn. --</b> eldest.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>first-class</ent><br/
<hw>first"-class`</hw> <pr>(f<etil/rst"kl<acr/s`)</pr>, <pos>a.</pos>
<def>Of the best class; of the highest rank; in the first division; of
the best quality; first-rate; <as>as, a <ex>first-class</ex>
telescope</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>First-class car</b></col> <it>or</it>
<col><b>First-class railway carriage</b></col></mcol>, <cd>any passenger
car of the highest regular class, and intended for passengers who pay
the highest regular rate; -- distinguished from a <xex>second-class
car</xex>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>first-come-first-served</ent><br/
<hw>first-come-first-served</hw> <pos>adj.</pos> <def>distributed in
order to those who request it in person; not subject to reservation for
later delivery. Contrasted with <ant>reservable</ant>.</def>
<mark>[predicate]</mark><br/
<syn><b>Syn. --</b> rush.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>First-hand</ent><br/
<hw>First"-hand`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Obtained directly
from the first or original source; hence, without the intervention of an
agent; -- of information; <as>as, a <ex>firsthand</ex> report;
<ex>firsthand</ex> information; <ex>firsthand</ex>
knowledge</as>.</def><br/
<syn><b>Syn. --</b> direct, original.</syn><br/
[<source>1913 Webster</source>]</p>

<p><q>One sphere there is . . . where the apprehension of him is
<qex>first-hand</qex> and direct; and that is the sphere of our own
mind.</q> <rj><qau>J. Martineau.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Firstling</ent><br/
<hw>First"ling</hw> <pr>(f<etil/rst"l<icr/ng)</pr>, <pos>n.</pos>
<ety>[<ets>First</ets> + <ets>-ling</ets>.]</ety> <sn>1.</sn> <def>The
first produce or offspring; -- said of animals, especially domestic
animals; <as>as, the <ex>firstlings</ex> of his flock</as>.</def>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The thing first thought or done.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The very <qex>firstlings</qex> of my heart shall be<br/
The <qex>firstlings</qex> of my hand.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Firstling</ent><br/
<hw>First"ling</hw>, <pos>a.</pos> <def>Firstborn.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>All the <qex>firstling</qex> males.</q> <rj><qau>Deut. xv.
19.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Firstly</ent><br/
<hw>First"ly</hw>, <pos>adv.</pos> <def>In the first place; before
anything else; -- sometimes improperly used for
<xex>first</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>First-order</ent><br/
<hw>First`-or"der</hw>, <pos>a.</pos> <def>decaying at an exponential
rate; -- a mathematical concept applied to various types of decay, such
as radioactivity and chemical reactions.</def> <note>In first order
decay, the amount of material decaying in a given period of time is
directly proportional to the amount of material remaining. This may be
expressed by the differential equation: <mathex>dA/dt = -kt</mathex>

where dA/dt is the rate per unit time at which the quantity (or
concentration) of material (expressed as A) is increasing, t is the
time, and k is a constant. The minus sign in front of the "kt" assures
that the amount of material remaining will be decreasing as time
progresses. A solution of the differential equation to give the quantity
<it>A</it> shows that: <mathex>A = e<exp>-kt</exp></mathex>

where <it>e</it> is the base for natural logarithms. Thus this type of
decay is called <it>exponential decay</it>. In certain chemical
reactions that are in fact second-order, involving two reactants, the
conditions may be chosen in some cases so that one reactant is vastly in
excess of the other, and its concentration changes very little in the
course of the reaction, so that the reaction rate will be approximately
first order in the more dilute reactant; such reactions are called
<stype>pseudo first order</stype>.</note><br/
[<source>PJC</source>]</p>

<p><ent>First-rate</ent><br/
<hw>First"-rate`</hw> <pr>(f<etil/rst"r<amac/t`)</pr>, <pos>a.</pos>
<def>Of the highest excellence; pre<eum/minent in quality, size, or
estimation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Our only <qex>first-rate</qex> body of contemporary poetry is the
German.</q> <rj><qau>M. Arnold.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Hermocrates . . . a man of <qex>first-rate</qex> ability.</q>
<rj><qau>Jowett (Thucyd).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>First-rate</ent><br/
<hw>First"-rate`</hw>, <pos>n.</pos> <fld>(Naut.)</fld> <def>A war
vessel of the highest grade or the most powerful class.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>first-rate</ent><br/
<hw>first-rate</hw> <pos>adj.</pos> <sn>1.</sn> <def>of the highest
quality; <as>as, a <ex>first-rate</ex> reporter</as>.</def><br/
<syn><b>Syn. --</b> ace, A-one, first-class, super, tip-top, topnotch,
tops(predicate).</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>first-rater</ent><br/
<hw>first-rater</hw> <pos>n.</pos> <def>One who is first-rate.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>first-string</ent><br/
<hw>first-string</hw> <pos>adj.</pos> <def>First to play in a game; not
reserved as a substitute; -- of members of a team. Also used in
non-sports contexts to mean <er>first-rate</er>.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>first-year</ent><br/
<hw>first-year</hw> <pos>adj.</pos> <def>Being in the first year of an
experience especially in a U. S. high school or college; -- of a
person.</def><br/
<syn><b>Syn. --</b> freshman.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Firth</ent><br/
<hw>Firth</hw> <pr>(f<etil/rth)</pr>, <pos>n.</pos> <ety>[Scot. See
<er>Frith</er>.]</ety> <fld>(Geog.)</fld> <def>An arm of the sea; a
frith.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fir tree</ent><br/
<hw>Fir" tree`</hw> <pr>(f<etil/r" tr<emac/`)</pr>. <def>See
<er>Fir</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fisc</ent><br/
<hw>Fisc</hw> <pr>(f<icr/sk)</pr>, <pos>n.</pos> <ety>[F.
<ets>fisc</ets>, fr. L. <ets>fiscus</ets> basket, money basket,
treasury; prob. akin to <ets>fascis</ets> bundle. See
<er>Fasces</er>.]</ety> <def>A public or state treasury.</def>
<rj><au>Burke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fiscal</ent><br/
<hw>Fis"cal</hw> <pr>(f<icr/s"k<ait/l)</pr>, <pos>a.</pos> <ety>[F.
<ets>fiscal</ets>, L. <ets>fiscalis</ets>, fr. <ets>fiscus</ets>. See
<er>Fisc</er>.]</ety> <def>Pertaining to the public treasury or
revenue.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>fiscal</qex> arrangements of government.</q> <rj><qau>A.
Hamilton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fiscal</ent><br/
<hw>Fis"cal</hw>, <pos>n.</pos> <sn>1.</sn> <def>The income of a prince
or a state; revenue; exchequer.</def> <mark>[Obs.]</mark>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A treasurer.</def> <rj><au>H.
Swinburne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A public officer in Scotland who prosecutes in petty
criminal cases; -- called also <altname>procurator
fiscal</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The solicitor in Spain and Portugal; the
attorney-general.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fisetic</ent><br/
<hw>Fi*set"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Chem.)</fld>
<def>Pertaining to fustet or fisetin.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fisetin</ent><br/
<hw>Fis"e*tin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[G.
<ets>fisett</ets>holz a species of fustic.]</ety> <fld>(Chem.)</fld>
<def>A yellow crystalline substance extracted from fustet, and regarded
as its essential coloring principle; -- called also <altname>fisetic
acid</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fish</ent><br/
<hw>Fish</hw> <pr>(f<icr/sh)</pr>, <pos>n.</pos> <ety>[F.
<ets>fiche</ets> peg, mark, fr. <ets>fisher</ets> to fix.]</ety> <def>A
counter, used in various games.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fish</ent><br/
<hw>Fish</hw>, <pos>n.</pos>; <plu><it>pl.</it> <plw>Fishes</plw>
<pr>(f<icr/sh"<ecr/z)</pr>, <xex>or collectively</xex>,
<plw>Fish</plw>.</plu> <ety>[OE. <ets>fisch</ets>, <ets>fisc</ets>,
<ets>fis</ets>, AS. <ets>fisc</ets>; akin to D. <ets>visch</ets>, OS. &
OHG. <ets>fisk</ets>, G. <ets>fisch</ets>, Icel. <ets>fiskr</ets>, Sw. &
Dan. <ets>fisk</ets>, Goth. <ets>fisks</ets>, L. <ets>piscis</ets>, Ir.
<ets>iasg</ets>. Cf. <er>Piscatorial</er>. In some cases, such as
<ets>fish</ets> joint, <ets>fish</ets> plate, this word has prob. been
confused with <ets>fish</ets>, fr. F. <ets>fiche</ets>a peg.]</ety>
<sn>1.</sn> <def>A name loosely applied in popular usage to many animals
of diverse characteristics, living in the water.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>An oviparous, vertebrate animal
usually having fins and a covering scales or plates. It breathes by
means of gills, and lives almost entirely in the water. See
<er>Pisces</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The true fishes include the Teleostei (bony fishes),
Ganoidei, Dipnoi, and Elasmobranchii or Selachians (sharks and skates).
Formerly the leptocardia and Marsipobranciata were also included, but
these are now generally regarded as two distinct classes, below the
fishes.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <pluf>pl.</pluf> <def>The twelfth sign of the zodiac;
Pisces.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The flesh of fish, used as food.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Naut.)</fld> <sd>(a)</sd> <def>A purchase used to
fish the anchor.</def> <sd>(b)</sd> <def>A piece of timber, somewhat in
the form of a fish, used to strengthen a mast or yard.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Fish</xex> is used adjectively or as part of a
compound word; as, <xex>fish</xex> line, <xex>fish</xex> pole,
<xex>fish</xex> spear, <xex>fish</xex>-bellied.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Age of Fishes</b></col>. <cd>See under <er>Age</er>,
<pos>n.</pos>, 8.</cd> -- <col><b>Fish ball</b></col>, <cd>fish (usually
salted codfish) shared fine, mixed with mashed potato, and made into the
form of a small, round cake.</cd> <mark>[U.S.]</mark> -- <col><b>Fish
bar</b></col>. <cd>Same as <cref>Fish plate</cref> (below).</cd> --
<col><b>Fish beam</b></col> <fld>(Mech.)</fld>, <cd>a beam one of whose
sides (commonly the under one) swells out like the belly of a fish.</cd>
<au>Francis.</au> -- <col><b>Fish crow</b></col> <fld>(Zool.)</fld>,
<cd>a species of crow (<spn>Corvus ossifragus</spn>), found on the
Atlantic coast of the United States. It feeds largely on fish.</cd> --
<col><b>Fish culture</b></col>, <cd>the artifical breeding and rearing
of fish; pisciculture.</cd> -- <col><b>Fish davit</b></col>. <cd>See
<er>Davit</er>.</cd> -- <col><b>Fish day</b></col>, <cd>a day on which
fish is eaten; a fast day.</cd> -- <col><b>Fish duck</b></col>
<fld>(Zool.)</fld>, <cd>any species of merganser.</cd> -- <col><b>Fish
fall</b></col>, <cd>the tackle depending from the fish davit, used in
hauling up the anchor to the gunwale of a ship.</cd> -- <col><b>Fish
garth</b></col>, <cd>a dam or weir in a river for keeping fish or taking
them easily.</cd> -- <col><b>Fish glue</b></col>. <cd>See
<er>Isinglass</er>.</cd> -- <col><b>Fish joint</b></col>, <cd>a joint
formed by a plate or pair of plates fastened upon two meeting beams,
plates, etc., at their junction; -- used largely in connecting the rails
of railroads.</cd> -- <col><b>Fish kettle</b></col>, <cd>a long kettle
for boiling fish whole.</cd> -- <col><b>Fish ladder</b></col>, <cd>a dam
with a series of steps which fish can leap in order to ascend falls in a
river.</cd> -- <mcol><col><b>Fish line</b></col>, <it>or</it>
<col><b>Fishing line</b></col></mcol>, <cd>a line made of twisted hair,
silk, etc., used in angling.</cd> -- <col><b>Fish louse</b></col>
<fld>(Zool.)</fld>, <cd>any crustacean parasitic on fishes, esp. the
parasitic Copepoda, belonging to <gen>Caligus</gen>, <gen>Argulus</gen>,
and other related genera. See <er>Branchiura</er>.</cd> -- <col><b>Fish
maw</b></col> <fld>(Zool.)</fld>, <cd>the stomach of a fish; also, the
air bladder, or sound.</cd> -- <col><b>Fish meal</b></col>, <cd>fish
desiccated and ground fine, for use in soups, etc.</cd> -- <col><b>Fish
oil</b></col>, <cd>oil obtained from the bodies of fish and marine
animals, as whales, seals, sharks, from cods' livers, etc.</cd> --
<col><b>Fish owl</b></col> <fld>(Zool.)</fld>, <cd>a fish-eating owl of
the Old World genera <gen>Scotopelia</gen> and <gen>Ketupa</gen>, esp. a
large East Indian species (<spn>K. Ceylonensis</spn>).</cd> --
<col><b>Fish plate</b></col>, <cd>one of the plates of a fish
joint.</cd> -- <col><b>Fish pot</b></col>, <cd>a wicker basket, sunk,
with a float attached, for catching crabs, lobsters, etc.</cd> --
<col><b>Fish pound</b></col>, <cd>a net attached to stakes, for
entrapping and catching fish; a weir.</cd> <mark>[Local, U.S.]</mark>
<au>Bartlett.</au> -- <col><b>Fish slice</b></col>, <cd>a broad knife
for dividing fish at table; a fish trowel.</cd> -- <col><b>Fish
slide</b></col>, <cd>an inclined box set in a stream at a small fall, or
ripple, to catch fish descending the current.</cd> <au>Knight.</au> --
<col><b>Fish sound</b></col>, <cd>the air bladder of certain fishes,
esp. those that are dried and used as food, or in the arts, as for the
preparation of isinglass.</cd> -- <col><b>Fish story</b></col>, <cd>a
story which taxes credulity; an extravagant or incredible
narration.</cd> <mark>[Colloq. U.S.]</mark> <au>Bartlett.</au> --
<col><b>Fish strainer</b></col>. <sd>(a)</sd> <cd>A metal colander, with
handles, for taking fish from a boiler.</cd> <sd>(b)</sd> <cd>A
perforated earthenware slab at the bottom of a dish, to drain the water
from a boiled fish.</cd> -- <col><b>Fish trowel</b></col>, <cd>a fish
slice.</cd> -- <mcol><col><b>Fish weir</b></col> <it>or</it>
<col><b>Fish wear</b></col></mcol>, <cd>a weir set in a stream, for
catching fish.</cd> -- <mcol><col><b>Neither fish nor flesh</b></col>,
<col><b>Neither fish nor fowl</b></col></mcol> (<mark>Fig.</mark>),
<cd>neither one thing nor the other.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fish</ent><br/
<hw>Fish</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Fished</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Fishing</conjf>.]</vmorph> <sn>1.</sn> <def>To attempt to catch
fish; to be employed in taking fish, by any means, as by angling or
drawing a net.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To seek to obtain by artifice, or indirectly to seek
to draw forth; <as>as, to <ex>fish</ex> for compliments</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Any other <qex>fishing</qex> question.</q> <rj><qau>Sir W.
Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fish</ent><br/
<hw>Fish</hw>, <pos>v. t.</pos> <ety>[OE. <ets>fischen</ets>,
<ets>fisken</ets>, <ets>fissen</ets>, AS. <ets>fiscian</ets>; akin to G.
<ets>fischen</ets>, OHG. <ets>fisc<?/n</ets>, Goth. <ets>fisk<?/n</ets>.
See <er>Fish</er> the animal.]</ety> <sn>1.</sn> <def>To catch; to draw
out or up; <as>as, to <ex>fish</ex> up an anchor</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To search by raking or sweeping.</def>
<rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To try with a fishing rod; to catch fish in; <as>as,
to <ex>fish</ex> a stream</as>.</def> <rj><au>Thackeray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To strengthen (a beam, mast, etc.), or unite end to
end (two timbers, railroad rails, etc.) by bolting a plank, timber, or
plate to the beam, mast, or timbers, lengthwise on one or both sides.
See <cref>Fish joint</cref>, under <er>Fish</er>,
<pos>n.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To fish the anchor</b></col>. <fld>(Naut.)</fld> <cd>See
under <er>Anchor</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fish-bellied</ent><br/
<hw>Fish"-bel`lied</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Bellying or
swelling out on the under side; <as>as, a <ex>fish-bellied</ex>
rail</as>.</def> <rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fish-block</ent><br/
<hw>Fish"-block`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Fish-tackle</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>fishbone</ent><br/
<hw>fishbone</hw> <pos>n.</pos> <def>a bone of a fish.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fisher</ent><br/
<hw>Fish"er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS.
<ets>fiscere</ets>.]</ety> <sn>1.</sn> <def>One who fishes.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>A carnivorous animal of the
Weasel family (<spn>Mustela Canadensis</spn>); the pekan; the
<ldquo/black cat.<rdquo/</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fisherman</ent><br/
<hw>Fish"er*man</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Fishermen</plw> <pr>(<?/)</pr>.</plu> <sn>1.</sn> <def>One whose
occupation is to catch fish.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Naut.)</fld> <def>A ship or vessel employed in the
business of taking fish, as in the cod fishery.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fishery</ent><br/
<hw>Fish"er*y</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Fisheries</plw> <pr>(<?/)</pr>.</plu> <sn>1.</sn> <def>The business
or practice of catching fish; fishing.</def>
<rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A place for catching fish.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Law)</fld> <def>The right to take fish at a certain
place, or in particular waters.</def> <rj><au>Abbott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>fishfly</ent><br/
<hw>fishfly</hw> <pos>n.</pos> <fld>(Zool.)</fld> <def>a fly similar to
but smaller than the dobsonfly.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fishful</ent><br/
<hw>Fish"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Abounding with
fish.</def> <mark>[R.]</mark> <ldquo/My <xex>fishful</xex> pond.<rdquo/
<rj><au>R. Carew.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fishgig</ent><br/
<hw>Fish"gig`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A spear with barbed
prongs used for harpooning fish.</def> <rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fishhawk</ent><br/
<hw>Fish"hawk`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>The osprey (<spn>Pandion halia<eum/tus</spn>), found both in Europe
and America; -- so called because it plunges into the water and seizes
fishes in its talons. Called also <altname>fishing eagle</altname>, and
<altname>bald buzzard</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fishhook</ent><br/
<hw>Fish"hook`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A hook
for catching fish.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Naut.)</fld> <def>A hook with a pendant, to the end
of which the fish-tackle is hooked.</def> <rj><au>Dana.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fishify</ent><br/
<hw>Fish"i*fy</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To change to
fish.</def> <mark>[R.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fishiness</ent><br/
<hw>Fish"i*ness</hw>, <pos>n.</pos> <def>The state or quality of being
fishy or fishlike.</def> <rj><au>Pennant.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fishing</ent><br/
<hw>Fish"ing</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act, practice, or
art of one who fishes.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A fishery.</def> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fishing</ent><br/
<hw>Fish"ing</hw>, <pos>a.</pos> <ety>[From <er>Fishing</er>,
<pos>n.</pos>]</ety> <def>Pertaining to fishing; used in fishery;
engaged in fishing; <as>as, <ex>fishing</ex> boat; <ex>fishing</ex>
tackle; <ex>fishing</ex> village.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fishing fly</b></col>, <cd>an artificial fly for
fishing.</cd> -- <col><b>Fishing line</b></col>, <cd>a line used in
catching fish.</cd> -- <col><b>Fishing net</b></col>, <cd>a net of
various kinds for catching fish; including the bag net, casting net,
drag net, landing net, seine, shrimping net, trawl, etc.</cd> --
<col><b>Fishing rod</b></col>, <cd>a long slender rod, to which is
attached the line for angling.</cd> -- <col><b>Fishing smack</b></col>,
<cd>a sloop or other small vessel used in sea fishing.</cd> --
<col><b>Fishing tackle</b></col>, <cd>apparatus used in fishing, as
hook, line, rod, etc.</cd> -- <col><b>Fishing tube</b></col>
<fld>(Micros.)</fld>, <cd>a glass tube for selecting a microscopic
object in a fluid.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>fishing expedition</ent><br/
<hw>fishing expedition</hw> <pos>n.</pos> <def>An investigation
searching for evidence of wrongdoing, with no credible evidence of such
wrongdoing available at the outset of the investigation, and often
without specifying in advance the wrongdoing to be proven.</def>
<mark>[metaphorical]</mark> <br/
[<source>PJC</source>]</p>

<p><-- p. 564 --></p>

<p><ent>Fishlike</ent><br/
<hw>Fish"like</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Like fish;
suggestive of fish; having some of the qualities of fish.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A very ancient and <qex>fishlike</qex> smell.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fishmonger</ent><br/
<hw>Fish"mon`ger</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A dealer in
fish.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>fishpond</ent><br/
<hw>fishpond</hw> <pos>n.</pos> <def>a freshwater pond with
fish.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fishskin</ent><br/
<hw>Fish"skin`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
skin of a fish (dog fish, shark, etc.)</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Med.)</fld> <def>See <er>Ichthyosis</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fish-tackle</ent><br/
<hw>Fish"-tac`kle</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A tackle or
purchase used to raise the flukes of the anchor up to the gunwale. The
block used is called the <xex>fish-block</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fish-tail</ent><br/
<hw>Fish"-tail`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Like the of a
fish; acting, or producing something, like the tail of a fish.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>fishtail</ent><br/
<hw>fishtail</hw> <pos>v. t.</pos> <fld>(aeronautics)</fld> <def>to slow
down by moving the tail sideways, of an airplane.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>fishtail</ent><br/
<hw>fishtail</hw> <pos>v. i.</pos> <def>to have the rear end skid from
side to side, out of control: -- said of automobiles or other
vehicles.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Fish-tail burner</b></col>, <cd>a gas burner that gives a
spreading flame shaped somewhat like the tail of a fish.</cd> --
<col><b>Fish-tail propeller</b></col> <fld>(Steamship)</fld>, <cd>a
propeller with a single blade that oscillates like the tail of a fish
when swimming.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fishwife</ent><br/
<hw>Fish"wife`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A
fishwoman.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A woman who abusively scolds other people, often
using coarse or vulgar language.</def><br/
[<source>PJC</source>]</p>

<p><ent>Fishwoman</ent><br/
<hw>Fish"wom`an</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Fishwomen</plw> <pr>(<?/)</pr>.</plu> <def>A woman who retails
fish; a female <isa>fishmonger</isa>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fishy</ent><br/
<hw>Fish"y</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Consisting
of fish; fishlike; having the qualities or taste of fish; abounding in
fish.</def> <rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Extravagant, like some stories about catching fish;
improbable; also, rank or foul.</def> <mark>[Colloq.]</mark>

<--3. creating suspicion that the surface appearances are misleading --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fisk</ent><br/
<hw>Fisk</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[Cf. Sw. <ets>fjeska</ets> to bustle about.]</ety> <def>To run about; to frisk; to whisk.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He <qex>fisks</qex> abroad, and stirreth up erroneous opinions.</q> <rj><qau>Latimer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fissigemmation</ent><br/
<hw>Fis`si*gem*ma"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>fissus</ets> (p. p. of <ets>findere</ets> to split) + E. <ets>gemmation</ets>.]</ety> <fld>(Biol.)</fld> <def>A process of reproduction intermediate between fission and gemmation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fissile</ent><br/
<hw>Fis"sile</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>fissilis</ets>, fr. <ets>fissus</ets>, p. p. of <ets>findere</ets> to split. See <er>Fissure</er>.]</ety> <sn>1.</sn> <def>Capable of being split, cleft, or divided in the direction of the grain, like wood, or along natural planes of cleavage, like crystals.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This crystal is a pellucid, <xex>fissile</xex> stone.</q> <rj><qau>Sir I. Newton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Fissionable.</def><br/
[<source>PJC</source>]</p>

<p><ent>Fissilingual</ent><br/
<hw>Fis`si*lin"gual</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>fissus</ets> (p. p. of <ets>findere</ets> to split) + E. <ets>lingual</ets>.]</ety> <fld>(Zool.)</fld> <def>Having the tongue forked.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fissilinguia</ent><br/
\'d8<hw>Fis`si*lin"gui*a</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL., fr. L. <ets>fissus</ets> (p. p. o f <ets>findere</ets> to split) + <ets>lingua</ets> tongue.]</ety> <fld>(Zool.)</fld> <def>A group of Lacertilia having the tongue forked, including the common lizards.</def> <altsp>[Written also <asp>Fissilingues</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fissility</ent><br/
<hw>Fis*sil"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Quality of being fissile.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fission</ent><br/
<hw>Fis"sion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>fissio</ets>. See <er>Fissure</er>.]</ety> <sn>1.</sn> <def>A cleaving, splitting, or breaking up into parts.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Biol.)</fld> <def>A method of asexual reproduction among the lowest (unicellular) organisms by means of a process of self-division, consisting of gradual division or cleavage of the into two parts, each of which then becomes a separate and independent organisms; as when a cell in an animal or plant, or its germ, undergoes a spontaneous division, and the parts again subdivide. See <er>Segmentation</er>, and <cref>Cell division</cref>, under <er>Division</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <def>A process by which certain coral polyps, echinoderms, annelids, etc., spontaneously subdivide, each individual thus forming two or more new ones. See <er>Strobilation</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Physics)</fld> <def>The act or process of disintegration of an atomic nucleus into two or more smaller pieces; called also <ecol><b>nuclear fission</b></ecol>.  The process may be spontaneous or induced by capture of neutrons or other smaller nuclei, and usually proceeds with evolution of energy.</def><br/
[<source>PJC</source>]</p>

<p><ent>fissionable</ent><br/
<hw>fis"sion*able</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of undergoing <cref>nuclear fission</cref>; -- a property of certain isotopes of elements with heavy nuclei.</def><br/
<syn><b>Syn. --</b> fissile.</syn><br/
[<source>PJC</source>]</p>

<p><ent>Fissipalmate</ent><br/
<hw>Fis`si*pal"mate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>fissus</ets> (p. p. of <ets>findere</ets> to split) + <ets>palma</ets> palm.]</ety> <fld>(Zool.)</fld> <def>Semipalmate and loboped, as a grebe's foot. See <xex>Illust.</xex> under <er>Aves</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fissipara</ent><br/
\'d8<hw>Fis*sip"a*ra</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL. See <er>Fissiparous</er>.]</ety> <fld>(Zool.)</fld> <def>Animals which reproduce by fission.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fissiparism</ent><br/
<hw>Fis*sip"a*rism</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See <er>Fissiparous</er>.]</ety> <fld>(Biol.)</fld> <def>Reproduction by spontaneous fission.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fissiparity</ent><br/
<hw>Fis`si*par"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Biol.)</fld> <def>Quality of being fissiparous; fissiparism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fissiparous</ent><br/
<hw>Fis*sip"a*rous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>fissus</ets> (p. p. of <ets>findere</ets> to split) + <ets>parere</ets> to bring forth: cf. F. <ets>fissipare</ets>.]</ety> <fld>(Biol.)</fld> <def>Reproducing by spontaneous fission. See <er>Fission</er>.</def> -- <wordforms><wf>Fis*sip"a*rous*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fissipation</ent><br/
<hw>Fis`si*pa"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Biol.)</fld> <def>Reproduction by fission; fissiparism.</def></p>

<p><ent>Fissipedal</ent><br/
<ent>Fissiped</ent><br/
<mhw>{ <hw>Fis"si*ped</hw> <pr>(?)</pr>, <hw>Fis*sip"e*dal</hw> <pr>(?)</pr> }</mhw>, <pos>a.</pos> <ety>[Cf. F. <ets>fissip<egrave/de</ets>.]</ety> <fld>(Zool.)</fld> <def>Having the toes separated to the base. [See <er>Aves</er>.]</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fissiped</ent><br/
<hw>Fis"si*ped</hw>, <pos>n.</pos> <fld>(Zool.)</fld> <def>One of the <ord>Fissipedia</ord>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fissipedia</ent><br/
\'d8<hw>Fis`si*pe"di*a</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL., fr. L. <ets>fissus</ets> (p. p. of <ets>findere</ets> to cleave) + <ets>pes</ets>, <ets>pedis</ets>, a foot.]</ety> <fld>(Zool.)</fld> <def>A division of the <ord>Carnivora</ord>, including the dogs, cats, and bears, in which the feet are not webbed; -- opposed to <contr>Pinnipedia</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fissirostral</ent><br/
<hw>Fis`si*ros"tral</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F. <ets>fissirostre</ets>.]</ety> <fld>(Zool.)</fld> <def>Having the bill cleft beyond the horny part, as in the case of swallows and goatsuckers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fissirostres</ent><br/
\'d8<hw>Fis`si*ros"tres</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL., fr. L. <ets>fissus</ets> (p. p. of <ets>findere</ets> to cleave) + <ets>rostrum</ets> beak.]</ety> <fld>(Zool.)</fld> <def>A group of birds having the bill deeply cleft.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fissural</ent><br/
<hw>Fis"sur*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to a fissure or fissures; <as>as, the <ex>fissural</ex> pattern of a brain</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fissuration</ent><br/
<hw>Fis`su*ra"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Anat.)</fld> <def>The act of dividing or opening; the state of being fissured.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fissure</ent><br/
<hw>Fis"sure</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>fissura</ets>, fr. <ets>findere</ets>, <ets>fissum</ets>, to cleave, split; akin to E. <ets>bite</ets>: cf. F. <ets>fissure</ets>.]</ety> <def>A narrow opening, made by the parting of any substance; a cleft; <as>as, the <ex>fissure</ex> of a rock</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Cerebral fissures</b></col> <fld>(Anat.)</fld>, <cd>the furrows or clefts by which the surface of the cerebrum is divided; esp., the furrows first formed by the infolding of the whole wall of the cerebrum.</cd> -- <col><b>Fissure needle</b></col> <fld>(Surg.)</fld>, <cd>a spiral needle for catching together the gaping lips of wounds.</cd> <au>Knight.</au> -- <col><b>Fissure of rolando</b></col> <fld>(Anat.)</fld>, <cd>the furrow separating the frontal from the parietal lobe in the cerebrum.</cd> -- <col><b>Fissure of Sylvius</b></col> <fld>(Anat.)</fld>, <cd>a deep cerebral fissure separating the frontal from the temporal lobe. See <xex>Illust.</xex> under <er>Brain</er>.</cd> -- <col><b>Fissure vein</b></col> <fld>(Mining)</fld>, <cd>a crack in the earth's surface filled with mineral matter.</cd> <au>Raymond.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fissure</ent><br/
<hw>Fis"sure</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To cleave; to divide; to crack or fracture.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fissurella</ent><br/
\'d8<hw>Fis`su*rel"la</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., dim. of L. <ets>fissura</ets> a fissure.]</ety> <fld>(Zool.)</fld> <def>A genus of marine gastropod mollusks, having a conical or limpetlike shell, with an opening at the apex; -- called also <altname>keyhole limpet</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fissurellidae</ent><br/
<hw>Fissurellidae</hw> <pos>n.</pos> <def>a natural family of marine limpets.</def><br/
<syn><b>Syn. --</b> family <fam>Fissurellidae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fist</ent><br/
<hw>Fist</hw> <pr>(f<icr/st)</pr>, <pos>n.</pos> <ety>[OE. <ets>fist</ets>, <ets>fust</ets>, AS. <ets>f<ymac/st</ets>; akin to D. <ets>vuist</ets>, OHG. <ets>f<umac/st</ets>, G. <ets>faust</ets>, and prob. to L. <ets>pugnus</ets>, Gr. <grk>pygmh`</grk> fist, <grk>py`x</grk> with the fist.  Cf. <er>Pugnacious</er>, <er>Pigmy</er>.]</ety> <sn>1.</sn> <def>The hand with the fingers doubled into the palm; the closed hand, especially as clinched tightly for the purpose of striking a blow.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Who grasp the earth and heaven with my <qex>fist</qex>.</q> <rj><qau>Herbert.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The talons of a bird of prey.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>More light than culver in the falcon's <qex>fist</qex>.</q> <rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(print.)</fld> <def>the index mark [<hand/], used to direct special attention to the passage which follows.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Hand over fist</b></col> <fld>(Naut.)</fld>, <cd>rapidly; hand over hand.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fist</ent><br/
<hw>Fist</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos> <conjf>Fisted</conjf>; <pos>p. pr. & vb. n.</pos> <conjf>Fisting</conjf>.]</vmorph> <sn>1.</sn> <def>To strike with the fist.</def>  <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To gripe with the fist.</def> <mark>[Obs.]</mark>  <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fistic</ent><br/
<hw>Fist"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From <er>Fist</er>.]</ety> <def>Pertaining to boxing, or to encounters with the fists; pugilistic; <as>as, <ex>fistic</ex> exploits; <ex>fistic</ex> heroes.</as></def> <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fisticuff</ent><br/
<hw>Fist"i*cuff</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A cuff or blow with the fist or hand</def>; <def2>(<pluf>pl.</pluf>) <def>a fight with the fists; boxing.</def></def2>  <rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fistinut</ent><br/
<hw>Fis"ti*nut</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. Fr. <ets>fistinq</ets>, <ets>fistuq</ets>. See <er>Pistachio</er>.]</ety> <def>A pistachio nut.</def> <mark>[Obs.]</mark>  <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fistuca</ent><br/
\'d8<hw>Fis*tu"ca</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.]</ety> <def>An instrument used by the ancients in driving piles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fistula</ent><br/
\'d8<hw>Fis"tu*la</hw> <pr>(?; 135)</pr>, <pos>n.</pos>; <plu><it>pl.</it> <plw>Fistul<ae/</plw> <pr>(#)</pr>.</plu> <ety>[L.]</ety> <sn>1.</sn> <def>A reed; a pipe.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A pipe for conveying water.</def> <mark>[Obs.]</mark>  <rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Med.)</fld> <def>A permanent abnormal opening into the soft parts with a constant discharge; a deep, narrow, chronic abscess; an abnormal opening between an internal cavity and another cavity or the surface; <as>as, a salivary <ex>fistula</ex>; an anal <ex>fistula</ex>; a recto-vaginal <ex>fistula</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Incomplete fistula</b></col> <fld>(Med.)</fld>, <cd>a fistula open at one end only.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fistular</ent><br/
<hw>Fis"tu*lar</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>fistularis</ets>: cf. F. <ets>fistulaire</ets>.]</ety> <def>Hollow and cylindrical, like a pipe or reed.</def>  <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fistularia</ent><br/
\'d8<hw>Fis`tu*la"ri*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. L. <ets>fistula</ets> pipe.]</ety> <fld>(Zool.)</fld> <def>A genus of fishes, having the head prolonged into a tube, with the mouth at the extremity.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fistularioid</ent><br/
<hw>Fis`tu*la"ri*oid</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Fistularia</ets> + <ets>-oid</ets>.]</ety> <fld>(Zool.)</fld> <def>Like or pertaining to the genus Fistularia.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fistulate</ent><br/
<hw>Fis"tu*late</hw> <pr>(?; 135)</pr>, <pos>v. t. & i.</pos> <ety>[Cf. L. <ets>fistulatus</ets> furnished with pipes.]</ety> <def>To make hollow or become hollow like a fistula, or pipe.</def> <mark>[Obs.]</mark> <ldquo/A <xex>fistulated</xex> ulcer.<rdquo/  <rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fistule</ent><br/
<hw>Fis"tule</hw> <pr>(?; 135)</pr>, <pos>n.</pos> <def>A fistula.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fistuliform</ent><br/
<hw>Fis"tu*li*form</hw> <pr>(? <or/ ?)</pr>, <pos>a.</pos> <ety>[<ets>Fistula</ets> + <ets>-form</ets>.]</ety> <def>Of a fistular form; tubular; pipe-shaped.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Stalactite often occurs <qex>fistuliform</qex>.</q> <rj><qau>W. Philips.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fistulose</ent><br/
<hw>Fis"tu*lose`</hw> <pr>(?; 135)</pr>, <pos>a.</pos> <ety>[L. <ets>fistulosus</ets>.]</ety> <def>Formed like a fistula; hollow; reedlike.</def>  <rj><au>Craig.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fistulous</ent><br/
<hw>Fis"tu*lous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F. <ets>fistuleux</ets>.]</ety> <sn>1.</sn> <def>Having the form or nature of a fistula; <as>as, a <ex>fistulous</ex> ulcer</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hollow, like a pipe or reed; fistulose.</def>  <rj><au>Lindley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fit</ent><br/
<hw>Fit</hw> <pr>(f<icr/t)</pr>, <def><pos>imp. & p. p.</pos> of <er>Fight</er>.</def> <mark>[Obs. or Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fit</ent><br/
<hw>Fit</hw>, <pos>n.</pos> <ety>[AS. <ets>fitt</ets> a song.]</ety> <def>In Old English, a song; a strain; a canto or portion of a ballad; a passus.</def> <altsp>[Written also <asp>fitte</asp>, <asp>fytte</asp>, etc.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><q>To play some pleasant <qex>fit</qex>.</q> <rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fit</ent><br/
<hw>Fit</hw>, <pos>a.</pos> <amorph>[<pos>Compar.</pos> <adjf>Fitter</adjf> <pr>(f<icr/t"t<etil/r)</pr>; <pos>superl.</pos> <adjf>Fittest</adjf> <pr>(f<icr/t"t<ecr/st)</pr>.]</amorph> <ety>[OE. <ets>fit</ets>, <ets>fyt</ets>; cf. E. <ets>feat</ets> neat, elegant, well made, or icel. <ets>fitja</ets> to web, knit, OD. <ets>vitten</ets> to suit, square, Goth. <ets>f<emac/tjan</ets> to adorn. <root/77.]</ety> <sn>1.</sn> <def>Adapted to an end, object, or design; suitable by nature or by art; suited by character, qualities, circumstances, education, etc.; qualified; competent; worthy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That which ordinary men are <qex>fit</qex> for, I am qualified in.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Fit</qex> audience find, though few.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Prepared; ready.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>So <qex>fit</qex> to shoot, she singled forth among<br/
her foes who first her quarry's strength should feel.</q> <rj><qau>Fairfax.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Conformed to a standard of duty, propriety, or taste; convenient; meet; becoming; proper.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Is it <qex>fit</qex> to say a king, Thou art wicked?</q> <rj><qau>Job xxxiv. 18.</qau></rj></p>

<p><syn><b>Syn.</b> -- Suitable; proper; appropriate; meet; becoming; expedient; congruous; correspondent; apposite; apt; adapted; prepared; qualified; competent; adequate.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fit</ent><br/
<hw>Fit</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos> <conjf>Fitted</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos> <conjf>Fitting</conjf> <pr>(?)</pr>.]</vmorph> <sn>1.</sn> <def>To make fit or suitable; to adapt to the purpose intended; to qualify; to put into a condition of readiness or preparation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The time is <qex>fitted</qex> for the duty.</q> <rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The very situation for which he was peculiarly <qex>fitted</qex> by nature.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To bring to a required form and size; to shape aright; to adapt to a model; to adjust; -- said especially of the work of a carpenter, machinist, tailor, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The carpenter . . . marketh it out with a line; he <qex>fitteth</qex> it with planes.</q> <rj><qau>Is. xliv. 13.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To supply with something that is suitable or fit, or that is shaped and adjusted to the use required.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>No milliner can so <qex>fit</qex> his customers with gloves.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To be suitable to; to answer the requirements of; to be correctly shaped and adjusted to; <as>as, if the coat <ex>fits</ex> you, put it on</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That's a bountiful answer that <qex>fits</qex> all questions.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>That time best <qex>fits</qex> the work.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To fit out</b></col>, <cd>to supply with necessaries or means; to furnish; to equip; as, <xex>to fit out</xex> a privateer.</cd> -- <col><b>To fit up</b></col>, <cd>to furnish with things suitable; to make proper for the reception or use of any person; to prepare; as, <xex>to fit up</xex> a room for a guest.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fit</ent><br/
<hw>Fit</hw> <pr>(?)</pr>, <pos>v. i.</pos> <sn>1.</sn> <def>To be proper or becoming.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Nor <qex>fits</qex> it to prolong the feast.</q> <rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To be adjusted to a particular shape or size; to suit; to be adapted; <as>as, his coat <ex>fits</ex> very well</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fit</ent><br/
<hw>Fit</hw>, <pos>n.</pos> <sn>1.</sn> <def>The quality of being fit; adjustment; adaptedness; as of dress to the person of the wearer.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mach.)</fld> <sd>(a)</sd> <def>The coincidence of parts that come in contact.</def> <sd>(b)</sd> <def>The part of an object upon which anything fits tightly.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fit rod</b></col> <fld>(Shipbuilding)</fld>, <cd>a gauge rod used to try the depth of a bolt hole in order to determine the length of the bolt required.</cd> <au>Knight.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fit</ent><br/
<hw>Fit</hw>, <pos>n.</pos> <ety>[AS. <ets>fit</ets> strife, fight; of uncertain origin. <root/ 77.]</ety> <sn>1.</sn> <def>A stroke or blow.</def> <mark>[Obs. or R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Curse on that cross, quoth then the Sarazin,<br/
That keeps thy body from the bitter <qex>fit</qex>.</q> <rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A sudden and violent attack of a disorder; a stroke of disease, as of epilepsy or apoplexy, which produces convulsions or unconsciousness; a convulsion; a paroxysm; hence, a period of exacerbation of a disease; in general, an attack of disease; <as>as, a <ex>fit</ex> of sickness</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And when the <qex>fit</qex> was on him, I did mark<br/
How he did shake.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A mood of any kind which masters or possesses one for a time; a temporary, absorbing affection; a paroxysm; <as>as, a <ex>fit</ex> of melancholy, of passion, or of laughter</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>All <qex>fits</qex> of pleasure we balanced by an equal degree of pain.</q> <rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The English, however, were on this subject prone to <qex>fits</qex> of jealously.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A passing humor; a caprice; a sudden and unusual effort, activity, or motion, followed by relaxation or inaction; an impulsive and irregular action.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>fits</qex> of the season.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A darting point; a sudden emission.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>A tongue of light, a <qex>fit</qex> of flame.</q> <rj><qau>Coleridge.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>By fits</b></col>, <col><b>By fits and starts</b></col></mcol>, <cd>by intervals of action and repose; impulsively and irregularly; intermittently.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fitch</ent><br/
<hw>Fitch</hw> <pr>(?; 224)</pr>, <pos>n.</pos>; <plu><it>pl.</it> <plw>Fitches</plw> <pr>(#)</pr>.</plu> <ety>[See <er>Vetch</er>.]</ety> <sn>1.</sn> <fld>(Bot.)</fld> <def>A vetch.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <pluf>pl.</pluf> <fld>(Bot.)</fld> <def>A word found in the Authorized Version of the Bible, representing different Hebrew originals. In Isaiah xxviii. 25, 27, it means the black aromatic seeds of <spn>Nigella sativa</spn>, still used as a flavoring in the East. In Ezekiel iv. 9, the Revised Version now reads <xex>spelt</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fitch</ent><br/
<hw>Fitch</hw>, <pos>n.</pos> <ety>[Contr. of fitched.]</ety> <fld>(Zool.)</fld> <def>The European polecat; also, its fur.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>fitche</ent><br/
<hw>Fitch"<eacute/</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F. <ets>fich<eacute/</ets>, lit. p. p. of <ets>ficher</ets> to fasten, OF. <ets>fichier</ets> to pierce.  Cf. 1st <er>Fish</er>.]</ety> <fld>(Her.)</fld> <def>Sharpened to a point; pointed.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Cross fitch<eacute/</b></col>, <cd>a cross having the lower arm pointed.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fitched</ent><br/
<hw>Fitched</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(her.)</fld> <def>Fitch<eacute/.</def> <altsp>[Also <asp>fiched</asp>.]</altsp></p>

<p><ent>Fitchew</ent><br/
<ent>Fitchet</ent><br/
<mhw>{ <hw>Fitch"et</hw> <pr>(?)</pr>, <hw>Fitch"ew</hw> <pr>(?)</pr> }</mhw>, <pos>n.</pos> <ety>[Cf. OF. <ets>fisseau</ets>, <ets>fissel</ets>, OD. <ets>fisse</ets>, <ets>visse</ets>, <ets>vitsche</ets>, D. <ets>vies</ets> nasty, loathsome, E. <ets>fizz</ets>.]</ety> <fld>(Zool.)</fld> <def>The European polecat (<spn>Putorius f<oe/tidus</spn>). See <er>Polecat</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fitchy</ent><br/
<hw>Fitch"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having fitches or vetches.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fitchy</ent><br/
<hw>Fitch"y</hw>, <pos>a.</pos> <ety>[See <er>Fitch<eacute/</er>.]</ety> <fld>(Her.)</fld> <def>Fitch<eacute/.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fitful</ent><br/
<hw>Fit"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From 7th <er>Fit</er>.]</ety> <def>Full of fits; irregularly variable; impulsive and unstable.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>After life's <qex>fitful</qex> fever, he sleeps well.</q> <rj><qau>Shak.</qau></rj></p>

<p>-- <wordforms><wf>Fit"ful*ly</wf>, <pos>adv.</pos> -- <wf>Fit"ful*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><q>The victorious trumpet peal<br/
Dies <qex>fitfully away</qex>.</q> <rj><qau>Macaulay.</qau></rj></p>

<p><ent>Fithul</ent><br/
<ent>Fithel</ent><br/
<mhw>{ <hw>Fith"el</hw> <pr>(?)</pr>, <hw>Fith"ul</hw> <pr>(?)</pr> }</mhw>, <pos>n.</pos> <ety>[OE. See <er>Fiddle</er>.]</ety> <def>A fiddle.</def> <mark>[Obs.]</mark>  <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fitly</ent><br/
<hw>Fit"ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a fit manner; suitably; properly; conveniently; <as>as, a maxim <ex>fitly</ex> applied</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fitment</ent><br/
<hw>Fit"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of fitting; that which is proper or becoming; equipment.</def> <mark>[Obs.]</mark>  <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fitness</ent><br/
<hw>Fit"ness</hw>, <pos>n.</pos> <def>The state or quality of being fit; <as>as, the <ex>fitness</ex> of measures or laws; a person's <ex>fitness</ex> for office.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fitt</ent><br/
<hw>Fitt</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See 2d <er>Fit</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fittable</ent><br/
<hw>Fit"ta*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Suitable; fit.</def> <mark>[Obs.]</mark>  <rj><au>Sherwood.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fittedness</ent><br/
<hw>Fit"ted*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state or quality of being fitted; adaptation.</def> <mark>[Obs.]</mark>  <rj><au>Dr. H. More.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>fitted out</ent><br/
<hw>fitted out</hw> <pos>adj.</pos> <def>same as <er>outfitted</er>, 1.</def><br/
<syn><b>Syn. --</b> outfitted.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fitter</ent><br/
<hw>Fit"ter</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who fits or makes to fit;</def> esp.: <sd>(a)</sd> <def>One who tries on, and adjusts, articles of dress.</def> <sd>(b)</sd> <def>One who fits or adjusts the different parts of machinery to each other.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A coal broker who conducts the sales between the owner of a coal pit and the shipper.</def> <mark>[Eng.]</mark>  <rj><au>Simmonds.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fitter</ent><br/
<hw>Fit"ter</hw>, <pos>n.</pos> <def>A little piece; a flitter; a flinder.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Where's the Frenchman? Alas, he's all <qex>fitters</qex>.</q> <rj><qau>Beau. & Fl.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fitting</ent><br/
<hw>Fit"ting</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Anything used in fitting up</def>; especially <def2>(<pluf>pl.</pluf>), <def>necessary fixtures or apparatus; <as>as, the <ex>fittings</ex> of a church or study; gas <ex>fittings</ex>.</as></def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fitting</ent><br/
<hw>Fit"ting</hw>, <pos>a.</pos> <def>Fit; appropriate; suitable; proper.</def> -- <wordforms><wf>Fit"ting*ly</wf>, <pos>adv.</pos> -- <wf>Fit"ting*ness</wf>, <pos>n.</pos></wordforms>  <rj><au>Jer. Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fitweed</ent><br/
<hw>Fit"weed`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>A plant (<spn>Eryngium f<oe/tidum</spn>) supposed to be a remedy for fits.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fitz</ent><br/
<hw>Fitz</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF. <ets>fils</ets>, <ets>filz</ets>, <ets>fiz</ets>, son, F. <ets>fils</ets>, L. <ets>filius</ets>. See <er>Filial</er>.]</ety> <def>A son; -- used in compound names, to indicate paternity, esp. of the illegitimate sons of kings and princes of the blood; <as>as, <ex>Fitz</ex>roy, the son of the king; <ex>Fitz</ex>clarence, the son of the duke of Clarence.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fitzgerald</ent><br/
<hw>Fitzgerald</hw>, <def>F. Scott, American Novelist (1896-1940).</def></p>

<p><bio><person>F. Scott Fitzgerald</person> was born September 24, 1896 in <city>St. Paul</city>, Minnesota to <person>Molly McQuillan</person> and <person>Edward Fitzgerald</person>.  He was a second cousin, twice removed of <person>Francis Scott Key</person>, the writer of the "Star Spangled Banner", a fact of which he was very proud and for whom he was named.<br/
<br/
His father was a failed businessman and his mother was the doting, smothering kind.  He had one younger sister.  He was extremely ashamed of his mother for her lack of beauty and emasculating of his father.  Both parents were thrilled with <persfn>Scott</persfn> because he was handsome, popular and later, a famous writer.  The family lived off the income of the mother who was the daughter of a wealthy merchant.  All of his life <persfn>Scott</persfn> aspired to be one of the rich people he socialized with in <city>St. Paul</city> and later at <edi>Princeton University</edi>, where he was more successful as a participant in performing and writing musical productions in the <org>Triangle Club</org> than as an academic.<br/
<br/
In 1917 <persfn>Scott</persfn> enlisted in the Army when it was apparent that his Junior year at <edi>Princeton</edi> might be his last, owing to poor grades.  He hoped to make a name for himself in World War I doing something brave and heroic.  His head was always full of notions of becoming famous, popular and sought-after in high social circles, and the darling of the "top girl" among the elite.  Unfortunately for <persfn>Scott</persfn>, the war ended before he had a chance to prove his bravery.  It was a pivotal point in his life and work, however, as it was while he was in the Army that he met <person>Zelda Sayre</person>.<br/
<br/
<person>Zelda Sayre</person> was the belle of <city>Montgomery, Alabama</city>, not yet eighteen and already famous in town for her bucking of authority, drinking, dancing all night and beauty.  <persfn>Scott</persfn> had met his match.  He was stationed in <city>Montgomery</city> when he met her at a dance.  They had a rocky courtship that continued until <persfn>Scott</persfn> mustered out of the Army and got a job in advertising in <city>New York City</city>.  He hated the job and when <persfn>Zelda</persfn> broke off their engagement citing his dim future in business, he was desolate.  He quit his job and went back  home to <city>St. Paul</city> where he stayed with his parents and rewrote a novel about his college days that had earlier been rejected.<br/
<br/
The novel, <booki>This Side of Paradise</booki>, became THE biggest novel of 1920.  <persfn>Fitzgerald</persfn> was an instant success known all around the nation and celebrated as the <it>Voice of His Generation</it>.  He married <persfn>Zelda</persfn> one week after its publication.  They then embarked a life of drinking, wild nights, hobnobbing with the rich and famous and becoming the life of every party.  This continued on for a few years both in the United States and <city>Paris</city> where they sought refuge from their excesses, but only created more.  In <city>Paris</city>, <persfn>Fitzgerald</persfn> wrote what was to become his finest work and because of which his place in literary history is secured.  <booki>The Great Gatsby</booki> was like all of <persfn>Fitzgerald's</persfn> work, based on his own life.  Like the title character, <person>Jay Gatsby</person>, <persfn>Fitzgerald</persfn> wanted to reinvent himself and become the person he always wanted to be in his imagination; rich, brave, successful in life and as important in his mind  if not more, to have the girl of his dreams by his side, appreciating him.<br/
<br/
<persfn>Fitzgerald</persfn> was always sure of one thing -- his own talent.  He had been a writer since he was a child and always received special attention for it.  Writing was something he could do that none of his classmates could.  He reveled in his notoriety and even when his pain of alcoholism and disappointments in life became almost unbearable his talent and belief in it never faltered.<br/
<br/
<persfn>Zelda</persfn> and <persfn>Scott</persfn> had one daughter, <person>Frances Scott Fitzgerald</person>, "Scottie."  Their marriage became a hell for both of them as they descended into alcoholism and <persfn>Zelda's</persfn> mental illness, which surfaced when she was in her late twenties.  Through all of the travails, <persfn>Scott</persfn> stayed a dedicated writer, mostly turning out short stories for the <publ>Saturday Evening Post</publ> and <publ>Esquire</publ> which paid him top dollar.  It was through these stories that <persfn>Fitzgerald</persfn> was able to support himself,  and pay for <persfn>Zelda's</persfn> extended periods in mental hospitals.  He also sent <persfn>Scottie</persfn> to private schools.  His alcoholism frequently caused his own need for drying-out cures in sanitariums, also.<br/
<br/
<person>F. Scott Fitzgerald</person> died of a heart attack on December 21, 1940 in Hollywood in the company of his mistress, gossip columnist <person>Sheilah Graham</person>.  He had finally become sober for one year, but it was too late.  He had ruined his health.  When he died his five novels had been out of print for years and he was considered a relic of the Twenties "Jazz Age", a term he had coined.  He had been in <city>Hollywood</city> the last few years of his life trying to be a movie writer for hire in order to continue to support himself, <persfn>Zelda</persfn>, who was permanently in a mental hospital, and his daughter, who was in college.  It was not until the Fifties that <persfn>Fitzgerald's</persfn> literary legacy finally was appreciated.  He is now considered to be one of the greatest writers of the Twentieth Century.</bio><br/
<br/
<refs>Sources:<br/
<booki>Fool for Love: F. Scott Fitzgerald, A biographical portrait</booki> by <person>Scott Donaldson</person>, Congdon & Weed, New York, NY, 1983.<br/
<br/
<booki>F. Scott Fitgerald in Minnesota: His Homes and Haunts</booki> by <person>John J. Koblas</person>, Minnesota Historical Society Press, St. Paul, MN, 1978.</refs><br/
[<source>Gail Glaser</source>]</p>

<p><ent>Five</ent><br/
<hw>Five</hw> <pr>(f<imac/v)</pr>, <pos>a.</pos> <ety>[OE. <ets>fif</ets>, <ets>five</ets>, AS. <ets>f<imac/f</ets>, <ets>f<imac/fe</ets>; akin to D. <ets>vijf</ets>, OS. <ets>f<imac/f</ets>, OHG. <ets>finf</ets>, <ets>funf</ets>, G. <ets>f<uum/nf</ets>, Icel. <ets>fimm</ets>, Sw. & Sw. Dan. <ets>fem</ets>, Goth. <ets>fimf</ets>, Lith. <ets>penki</ets>, W. <ets>pump</ets>, OIr. <ets>c<oacute/ic</ets>, L. <ets>quinque</ets>, Gr. <grk>pe`nte</grk>, <AE/ol. <grk>pe`mpe</grk>, Skr. <ets>pa<ntil/can</ets>. <root/303.  Cf. <er>Fifth</er>, <er>Cinque</er>, <er>Pentagon</er>, <er>Punch</er> the drink, <er>Quinary</er>.]</ety> <def>Four and one added; one more than four.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 565 --></p>

<p><cs><col><b>Five nations</b></col> <fld>(Ethnol.)</fld>, <cd>a
confederacy of the Huron-Iroquois Indians, consisting of five tribes:
Mohawks, Onondagas, Cayugas, Oneidas, and Senecas. They inhabited the
region which is now the State of new York.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Five</ent><br/
<hw>Five</hw> <pr>(f<imac/v)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
number next greater than four, and less than six; five units or
objects.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Five</qex> of them were wise, and <qex>five</qex> were
foolish.</q> <rj><qau>Matt. xxv. 2.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A symbol representing this number, as 5, or
V.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Five-finger</ent><br/
<hw>Five"-fin`ger</hw> <pr>(f<imac/v"-f<icr/<nsm/`g<etil/r)</pr>,
<pos>n.</pos> <sn>1.</sn> <fld>(Bot.)</fld> <def>See
<er>Cinquefoil</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>A starfish with five rays, esp.
<spn>Asterias rubens</spn>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fivefold</ent><br/
<hw>Five"fold`</hw> <pr>(f<imac/v"-f<omac/ld`)</pr>, <pos>a. &
adv.</pos> <def>In fives; consisting of five in one; five repeated;
quintuple.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>five-hitter</ent><br/
<hw>five`-hit"ter</hw> <pr>(f<imac/v`-h<icr/t"t<etil/r)</pr>,
<pos>n.</pos> <fld>(Baseball)</fld> <def>A game in which a pitcher
allows the opposing team 5 hits.</def><br/
<syn><b>Syn. --</b> 5-hitter.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Five-leaf</ent><br/
<hw>Five"-leaf`</hw> <pr>(f<imac/v"-l<emac/f`)</pr>, <pos>n.</pos>
<def>Cinquefoil; five-finger.</def></p>

<p><ent>Five-leaved</ent><br/
<ent>Five-leafed</ent><br/
<mhw>{ <hw>Five"-leafed`</hw> <pr>(?)</pr>, <hw>Five"-leaved`</hw>
<pr>(?)</pr> }</mhw>, <pos>a.</pos> <fld>(Bot.)</fld> <def>Having five
leaflets, as the Virginia creeper.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fiveling</ent><br/
<hw>Five"ling</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Min.)</fld> <def>A
compound or twin crystal consisting of five individuals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fives</ent><br/
<hw>Fives</hw> <pr>(f<imac/vz)</pr>, <pos>n. pl.</pos> <def>A kind of
play with a ball against a wall, resembling tennis; -- so named because
three <xex>fives</xex>, or <xex>fifteen</xex>, are counted to the
game.</def> <rj><au>Smart.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fives court</b></col>, <cd>a place for playing
fives.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fives</ent><br/
<hw>Fives</hw>, <pos>n.</pos> <ety>[See <er>Vives</er>.]</ety> <def>A
disease of the glands under the ear in horses; the vives.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>five-spot</ent><br/
<hw>five-spot</hw> <pos>n.</pos> <sn>1.</sn> <fld>(Bot.)</fld> <def>A
California annual (<spn>Nemophila maculata</spn>) having white flowers
with a deep purple blotch on each petal.</def><br/
<syn><b>Syn. --</b> five spot, <spn>Nemophila maculata</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>a playing card or a domino or a die whose upward
face shows five pips.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>3.</sn> <def>A five-dollar bill.</def> <mark>[U. S.
slang]</mark><br/
[<source>PJC</source>]</p>

<p><ent>Five-twenties</ent><br/
<hw>Five`-twen"ties</hw> <pr>(?)</pr>, <pos>n. pl.</pos>
<def>Five-twenty bonds of the United States (bearing six per cent
interest), issued in 1862, '64, and '65, redeemable after
<xex>five</xex> and payable in <xex>twenty</xex> years.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fix</ent><br/
<hw>Fix</hw> <pr>(f<icr/ks)</pr>, <pos>a.</pos> <ety>[OE., fr. L.
<ets>fixus</ets>, p. p. of <ets>figere</ets> to fix; cf. F.
<ets>fixe</ets>.]</ety> <def>Fixed; solidified.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fix</ent><br/
<hw>Fix</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Fixed</conjf> <pr>(f<icr/kst)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Fixing</conjf>.]</vmorph> <ety>[Cf. F. <ets>fixer</ets>.]</ety>
<sn>1.</sn> <def>To make firm, stable, or fast; to set or place
permanently; to fasten immovably; to establish; to implant; to secure;
to make definite.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>An ass's nole I <qex>fixed</qex> on his head.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>O, <qex>fix</qex> thy chair of grace, that all my powers<br/
May also <qex>fix</qex> their reverence.</q>
<rj><qau>Herbert.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>His heart is <qex>fixed</qex>, trusting in the Lord.</q>
<rj><qau>Ps. cxii. 7.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And <qex>fix</qex> far deeper in his head their stings.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To hold steadily; to direct unwaveringly; to fasten,
as the eye on an object, the attention on a speaker.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Sat <qex>fixed</qex> in thought the mighty Stagirite.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>One eye on death, and one full <qex>fix'd</qex> on heaven.</q>
<rj><qau>Young.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To transfix; to pierce.</def> <mark>[Obs.]</mark>
<rj><au>Sandys.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Photog.)</fld> <def>To render (an impression)
permanent by treating with a developer to make it insensible to the
action of light.</def> <rj><au>Abney.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To put in order; to arrange; to dispose of; to
adjust; to set to rights; to set or place in the manner desired or most
suitable; hence, to repair; <as>as, to <ex>fix</ex> the clothes; to
<ex>fix</ex> the furniture of a room.</as></def> <mark>[Colloq.
U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Iron Manuf.)</fld> <def>To line the hearth of (a
puddling furnace) with fettling.</def></p>

<p><syn><b>Syn.</b> -- To arrange; prepare; adjust; place; establish;
settle; determine.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fix</ent><br/
<hw>Fix</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To become fixed; to
settle or remain permanently; to cease from wandering; to
rest.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Your kindness banishes your fear,<br/
Resolved to <qex>fix</qex> forever here.</q>
<rj><qau>Waller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To become firm, so as to resist volatilization; to
cease to flow or be fluid; to congeal; to become hard and malleable, as
a metallic substance.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To fix on</b></col>, <cd>to settle the opinion or
resolution about; to determine regarding; <as>as, the contracting
parties have <ex>fixed on</ex> certain leading
points</as>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fix</ent><br/
<hw>Fix</hw>, <pos>n.</pos> <sn>1.</sn> <def>A position of difficulty or
embarrassment; predicament; dilemma.</def> <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Is he not living, then? No. is he dead, then? No, nor dead either.
Poor Aroar can not live, and can not die, -- so that he is in an
almighty <qex>fix</qex>.</q> <rj><qau>De Quincey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Iron Manuf.)</fld> <def>fettling.</def>
<mark>[U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fixable</ent><br/
<hw>Fix"a*ble</hw> <pr>(-<adot/*b'l)</pr>, <pos>a.</pos> <def>Capable of
being fixed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fixation</ent><br/
<hw>Fix*a"tion</hw> <pr>(f<icr/ks*<amac/"sh<ucr/n)</pr>, <pos>n.</pos>
<ety>[Cf. F. <ets>fixation</ets>.]</ety> <sn>1.</sn> <def>The act of
fixing, or the state of being fixed.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>An unalterable <qex>fixation</qex> of resolution.</q>
<rj><qau>Killingbeck.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To light, created in the first day, God gave no proper place or
<qex>fixation</qex>.</q> <rj><qau>Sir W. Raleigh.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Marked stiffness or absolute <qex>fixation</qex> of a joint.</q>
<rj><qau>Quain.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>fixation</qex> and confinement of thought to a few
objects.</q> <rj><qau>Watts.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The act of uniting chemically with a solid substance
or in a solid form; reduction to a non-volatile condition; -- said of
gaseous elements.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The act or process of ceasing to be fluid and
becoming firm.</def> <rj><au>Glanvill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A state of resistance to evaporation or
volatilization by heat; -- said of metals.</def>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fixative</ent><br/
<hw>Fix"a*tive</hw> <pr>(?)</pr>, <pos>n.</pos> <def>That which serves
to set or fix colors or drawings, as a mordant.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fixed</ent><br/
<hw>Fixed</hw> <pr>(f<icr/kst)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Securely placed or fastened; settled; established; firm; immovable;
unalterable.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Chem.)</fld> <def>Stable; non-volatile.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fixed air</b></col> <fld>(Old Chem.)</fld>, <cd>carbonic
acid or carbon dioxide; -- so called by Dr. Black because it can be
absorbed or <xex>fixed</xex> by strong bases. See <cref>Carbonic
acid</cref>, under <er>Carbonic</er>.</cd> -- <col><b>Fixed
alkali</b></col> <fld>(Old Chem.)</fld>, <cd>a non-volatile base, as
soda, or potash, in distinction from the volatile alkali ammonia.</cd>
-- <col><b>Fixed ammunition</b></col> <fld>(Mil.)</fld>, <cd>a
projectile and powder inclosed together in a case ready for
loading.</cd> -- <col><b>Fixed battery</b></col> <fld>(Mil.)</fld>,
<cd>a battery which contains heavy guns and mortars intended to remain
stationary; -- distinguished from <xex>movable</xex> battery.</cd> --
<col><b>Fixed bodies</b></col>, <cd>those which can not be volatilized
or separated by a common menstruum, without great difficulty, as gold,
platinum, lime, etc.</cd> -- <col><b>Fixed capital</b></col>. <cd>See
the Note under <er>Capital</er>, <pos>n.</pos>, 4.</cd> -- <col><b>Fixed
fact</b></col>, <cd>a well established fact.</cd> <mark>[Colloq.]</mark>
-- <col><b>Fixed light</b></col>, <cd>one which emits constant beams; --
distinguished from a flashing, revolving, or intermittent light.</cd> --
<col><b>Fixed oils</b></col> <fld>(Chem.)</fld>, <cd>non-volatile, oily
substances, as stearine and olein, which leave a permanent greasy stain,
and which can not be distilled unchanged; -- distinguished from
<xex>volatile</xex> or <contr>essential oils</contr>.</cd> --
<col><b>Fixed pivot</b></col> <fld>(Mil.)</fld>, <cd>the fixed point
about which any line of troops wheels.</cd> -- <col><b>Fixed
stars</b></col> <fld>(Astron.)</fld>, <cd>such stars as always retain
nearly the same apparent position and distance with respect to each
other, thus distinguished from planets and comets.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fixedly</ent><br/
<hw>Fix"ed*ly</hw> <pr>(f<icr/ks"<ecr/d*l<ycr/)</pr>, <pos>adv.</pos>
<def>In a fixed, stable, or constant manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fixedness</ent><br/
<hw>Fix"ed*ness</hw>, <pos>n.</pos> <sn>1.</sn> <def>The state or
quality of being fixed; stability; steadfastness.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The quality of a body which resists evaporation or
volatilization by heat; solidity; cohesion of parts; <as>as, the
<ex>fixedness</ex> of gold</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fixidity</ent><br/
<hw>Fix*id"i*ty</hw> <pr>(f<icr/ks*<icr/d"<icr/*t<ycr/)</pr>,
<pos>n.</pos> <def>Fixedness.</def> <mark>[Obs.]</mark>
<rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fixing</ent><br/
<hw>Fix"ing</hw> <pr>(f<icr/ks"<icr/ng)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>The act or process of making fixed.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is fixed; a fixture.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <pluf>pl.</pluf> <def>Arrangements; embellishments;
trimmings; accompaniments.</def> <mark>[Colloq. U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fixity</ent><br/
<hw>Fix"i*ty</hw> <pr>(-<icr/*t<ycr/)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>fixit<eacute/</ets>.]</ety> <sn>1.</sn> <def>Fixedness; <as>as,
<ex>fixity</ex> of tenure</as>; also, that which is fixed.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Coherence of parts.</def> <rj><au>Sir I.
Newton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fixture</ent><br/
<hw>Fix"ture</hw> <pr>(f<icr/ks"t<usl/r; 135)</pr>, <pos>n.</pos>
<ety>[Cf. <er>Fixure</er>.]</ety> <sn>1.</sn> <def>That which is fixed
or attached to something as a permanent appendage; <as>as, the
<ex>fixtures</ex> of a pump; the <ex>fixtures</ex> of a farm or of a
dwelling, that is, the articles which a tenant may not take
away.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>State of being fixed; fixedness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The firm <qex>fixture</qex> of thy foot.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Law)</fld> <def>Anything of an accessory character
annexed to houses and lands, so as to constitute a part of them. This
term is, however, quite frequently used in the peculiar sense of
personal chattels annexed to lands and tenements, but removable by the
person annexing them, or his personal representatives. In this latter
sense, the same things may be <ex>fixtures</ex> under some
circumstances, and not <ex>fixtures</ex> under others.</def>
<rj><au>Wharton (Law Dict.).</au> <au>Bouvier.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ This word is frequently substituted for
<xex>fixure</xex> (formerly the word in common use) in new editions of
old works.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fixure</ent><br/
<hw>Fix"ure</hw> <pr>(-<usl/r)</pr>, <pos>n.</pos> <ety>[L.
<ets>fixura</ets> a fastening, fr. <ets>figere</ets> to fix. See
<er>Fix</er>, and cf. <er>Fixture</er>.]</ety> <def>Fixed position;
stable condition; firmness.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>fizgig</ent><br/
<hw>fiz"gig`</hw> <pr>(f<icr/z"g<icr/g)</pr>, <pos>n.</pos> <def>A
fishgig.</def> <mark>[Obs.]</mark> <rj><au>Sandys.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>fizgig</ent><br/
<hw>fiz"gig`</hw>, <pos>n.</pos> <ety>[<ets>Fizz</ets> + <ets>gig</ets>
whirling thing.]</ety> <def>A firework, made of damp powder, which makes
a fizzing or hissing noise when it explodes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>fizgig</ent><br/
<hw>fiz"gig`</hw>, <pos>n.</pos> <ety>[See <er>Gig</er> a flirt.]</ety>
<def>A gadding, flirting girl.</def> <rj><au>Gosson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>fizz</ent><br/
<hw>fizz</hw> <pr>(f<icr/z)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>fizzed</conjf> <pr>(f<icr/zd)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>fizzing</conjf>.]</vmorph> <ety>[Cf. Icel.
<ets>f<imac/sa</ets> to break wind, Dan. <ets>fise</ets> to foist,
fizzle, OSw. <ets>fisa</ets>, G. <ets>fisten</ets>, <ets>feisten</ets>.
Cf. <er>Foist</er>.]</ety> <def>To make a hissing sound, such as that of
a burning fuse or a bubbling carbonated beverage.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Fizz</ent><br/
<hw>Fizz</hw>, <pos>n.</pos> <def>A hissing sound; <as>as, the
<ex>fizz</ex> of a fly</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>fizzy</ent><br/
<ent>fizzing</ent><br/
<mhw><hw>fizzing</hw> <hw>fizzy</hw></mhw> <pos>adj.</pos> <def>Hissing
and bubbling, like a carbonated beverage.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>fizzle</ent><br/
<hw>fiz"zle</hw> <pr>(f<icr/z"z'l)</pr>, <pos>v. i.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>fizzled</conjf>
<pr>(f<icr/z"z'ld)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>fizzling</conjf> <pr>(f<icr/z"zl<icr/ng)</pr>.]</vmorph>
<ety>[See <er>Fizz</er>.]</ety> <sn>1.</sn> <def>To make a hissing
sound.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It is the easiest thing, sir, to be done,<br/
As plain as <qex>fizzling</qex>.</q> <rj><qau>B. Jonson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To make a ridiculous failure in an undertaking,
especially after a good start; to achieve nothing.</def> <mark>[Colloq.
or Low]</mark><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><q>A four-day rally in stocks <qex>fizzled</qex> yesterday amid
renewed fears that strong economic growth may prompt the Federal Reserve
to raise interest rates.</q> <rj><qau>Sharon R. King (N. Y. Times, May
6, 1998).</qau></rj><br/
[<source>PJC</source>]</p>

<p><cs><col><b>To fizzle out</b></col>, <cd>to burn with a hissing noise
and then go out, like wet gunpowder;</cd> <specif>hence:</specif> <cd>to
fail completely and ridiculously; to prove a failure.</cd>
<mark>[Colloq.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>fizzle</ent><br/
<hw>fiz"zle</hw>, <pos>n.</pos> <def>A failure or abortive effort; a
fiasco.</def> <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fjord</ent><br/
\'d8<hw>Fjord</hw> <pr>(fy<ocir/rd)</pr>, <pos>n.</pos> <def>See
<er>Fiord</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>flab</ent><br/
<hw>flab</hw> <pr>(fl<acr/b)</pr>, <pos>n.</pos> <def>Loose or flaccid
body fat.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Flabbergast</ent><br/
<hw>Flab"ber*gast</hw> <pr>(fl<acr/b"b<etil/r*g<acr/st)</pr>, <pos>v.
t.</pos> <ety>[Cf. <er>Flap</er>, and <er>Aghast</er>.]</ety> <def>To
astonish; to strike with wonder, esp. by extraordinary statements.</def>
<mark>[Jocular]</mark> <rj><au>Beaconsfield.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flabbergastation</ent><br/
<hw>Flab`ber*gas*ta"tion</hw>
<pr>(fl<acr/b`b<etil/r*g<acr/s*t<amac/"sh<ucr/n)</pr>, <pos>n.</pos>
<def>The state of being flabbergasted.</def> <mark>[Jocular]</mark>
<rj><au>London Punch.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flabbily</ent><br/
<hw>Flab"bi*ly</hw> <pr>(fl<acr/b"b<icr/*l<ycr/)</pr>, <pos>adv.</pos>
<def>In a flabby manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flabbiness</ent><br/
<hw>Flab"bi*ness</hw>, <pos>n.</pos> <def>Quality or state of being
flabby.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>flabby</ent><br/
<hw>flab"by</hw> <pr>(fl<acr/b"b<ycr/)</pr>, <pos>a.</pos> <ety>[See
<er>Flap</er>.]</ety> <def>Yielding to the touch, and easily moved or
shaken; hanging loose by its own weight; wanting firmness; flaccid;
<as>as, <ex>flabby</ex> flesh</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flabel</ent><br/
<hw>Fla"bel</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>flabellum</ets> a fan, dim. of <ets>flabrum</ets> a breeze, fr.
<ets>flare</ets> to blow.]</ety> <def>A fan.</def> <mark>[Obs.]</mark>
<rj><au>Huloet.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flabellate</ent><br/
<hw>Fla*bel"late</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>flabellatus</ets>, p. p. of <ets>flabellare</ets> to fan, fr.
<ets>flabellum</ets>. See <er>Flabbel</er>.]</ety> <fld>(Bot.)</fld>
<def>Flabelliform.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flabellation</ent><br/
<hw>Flab`el*la"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
keeping fractured limbs cool by the use of a fan or some other
contrivance.</def> <rj><au>Dunglison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flabelliform</ent><br/
<hw>Fla*bel"li*form</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>flabellum</ets> a fan + <ets>-form</ets>: cf. F.
<ets>flabeliforme</ets>.]</ety> <def>Having the form of a fan;
fan-shaped; flabellate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flabellinerved</ent><br/
<hw>Fla*bel"li*nerved`</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>flabellum</ets> a fan + E. <ets>nerve</ets>.]</ety>
<fld>(Bot.)</fld> <def>Having many nerves diverging radiately from the
base; -- said of a leaf.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flabellum</ent><br/
\'d8<hw>Fla*bel"lum</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>See</ets> <er>Flabel</er>.]</ety> <fld>(Eccl.)</fld> <def>A fan;
especially, the fan carried before the pope on state occasions, made in
ostrich and peacock feathers.</def> <rj><au>Shipley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flabile</ent><br/
<hw>Flab"ile</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>flabilis</ets>.]</ety> <def>Liable to be blown about.</def>
<rj><au>Bailey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>flaccid</ent><br/
<hw>flac"cid</hw> <pr>(fl<acr/k"s<icr/d <it>or</it>
fl<acr/s"s<icr/d)</pr>, <pos>a.</pos> <ety>[L. <ets>flaccidus</ets>, fr.
<ets>flaccus</ets> flabby: cf. OF. <ets>flaccide</ets>.]</ety>
<def>Yielding to pressure for want of firmness and stiffness; soft and
weak; limber; lax; drooping; flabby; <as>as, a <ex>flaccid</ex> muscle;
<ex>flaccid</ex> flesh.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Religious profession . . . has become <qex>flacced</qex>.</q>
<rj><qau>I. Taylor.</qau></rj></p>

<p>-- <wordforms><wf>flac"cid*ly</wf> <pr>(fl<acr/k"s<icr/d*l<ycr/
<it>or</it> fl<acr/s"s<icr/d*l<ycr/)</pr>, <pos>adv.</pos> --
<wf>flac"cid*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flaccidity</ent><br/
<hw>Flac*cid"i*ty</hw> <pr>(fl<acr/k*s<icr/d"<icr/*t<ycr/ <it>or</it>
fl<acr/s*s<icr/d"<icr/*t<ycr/)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>flaccidit<eacute/</ets>.]</ety> <def>The state of being
flaccid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flacherie</ent><br/
\'d8<hw>Flache`rie"</hw> <pr>(fl<adot/sh`r<emac/")</pr>, <pos>n.</pos>
<ety>[F.]</ety> <def>A bacterial disease of silkworms, supposed to be
due to eating contaminated mulberry leaves.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Flacker</ent><br/
<hw>Flack"er</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[OE.
<ets>flakeren</ets>, fr. <ets>flacken</ets> to move quickly to and fro;
cf. icel. <ets>flakka</ets> to rove about, AS. <ets>flacor</ets>
fluttering, flying, G. <ets>flackern</ets> to flare, flicker.]</ety>
<def>To flutter, as a bird.</def> <mark>[Prov. Eng.]</mark>
<rj><au>Grose.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flacket</ent><br/
<hw>Flack"et</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>flasquet</ets> little flask, dim. of <ets>flasque</ets> a
flask.]</ety> <def>A barrel-shaped bottle; a flagon.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flacon</ent><br/
\'d8<hw>Fla"con</hw> <pr>(fl<adot/"k<ocir/n)</pr>, <pos>n.</pos>
<ety>[F. See <er>Flagon</er>.]</ety> <def>A small glass bottle with a
stopper; <as>as, a <ex>flacon</ex> for perfume</as>.</def> <ldquo/Two
glass <xex>flacons</xex> for the ink.<rdquo/
<rj><au>Longfellow.</au></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Flacourtiaceae</ent><br/
<hw>Flacourtiaceae</hw> <pos>prop. n.</pos> <def>A natural family of
chiefly tropical trees and shrubs.</def><br/
<syn><b>Syn. --</b> family <fam>Flacourtiaceae</fam>, flacourtia
family.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Flag</ent><br/
<hw>Flag</hw> <pr>(fl<acr/g)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Flagged</conjf> <pr>(fl<acr/gd)</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>Flagging</conjf>
<pr>(fl<acr/g"g<icr/ng)</pr>.]</vmorph> <ety>[Cf. Icel. <ets>flaka</ets>
to droop, hang loosely. Cf. <er>Flacker</er>, <er>Flag</er> an
ensign.]</ety> <sn>1.</sn> <def>To hang loose without stiffness; to bend
down, as flexible bodies; to be loose, yielding, limp.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>As loose it [the sail] <qex>flagged</qex> around the mast.</q>
<rj><qau>T. Moore.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To droop; to grow spiritless; to lose vigor; to
languish; <as>as, the spirits <ex>flag</ex>; the strength
<ex>flags</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>The pleasures of the town begin to <qex>flag</qex>.</q>
<rj><qau>Swift.</qau></rj></p>

<p><syn><b>Syn.</b> -- To droop; decline; fail; languish;
pine.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flag</ent><br/
<hw>Flag</hw> <pr>(fl<acr/g)</pr>, <pos>v. t.</pos> <sn>1.</sn> <def>To
let droop; to suffer to fall, or let fall, into feebleness; <as>as, to
<ex>flag</ex> the wings</as>.</def> <rj><au>prior.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To enervate; to exhaust the vigor or elasticity
of.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Nothing so <qex>flags</qex> the spirits.</q>
<rj><qau>Echard.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flag</ent><br/
<hw>Flag</hw>, <pos>n.</pos> <ety>[Cf. LG. & G. <ets>flagge</ets>, Sw.
<ets>flagg</ets>, Dan. <ets>flag</ets>, D. <ets>vlag</ets>. See
<er>Flag</er> to hang loose.]</ety> <sn>1.</sn> <def>That which flags or
hangs down loosely.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A cloth usually bearing a device or devices and used
to indicate nationality, party, etc., or to give or ask information; --
commonly attached to a staff to be waved by the wind; a standard; a
banner; an ensign; the colors; <as>as, the national <ex>flag</ex>; a
military or a naval <ex>flag</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <sd>(a)</sd> <def>A group of feathers
on the lower part of the legs of certain hawks, owls, etc.</def>
<sd>(b)</sd> <def>A group of elongated wing feathers in certain
hawks.</def> <sd>(c)</sd> <def>The bushy tail of a dog, as of a
setter.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Zool.)</fld> <def>One of the wing feathers next the
body of a bird; -- called also <altname>flag
feather</altname>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><cs><col><b>Black flag</b></col>. <cd>See under <er>Black</er>.</cd>
-- <mcol><col><b>Flag captain</b></col>, <col><b>Flag
leutenant</b></col></mcol>, <cd>etc., special officers attached to the
flagship, as aids to the flag officer.</cd> -- <col><b>Flag
officer</b></col>, <cd>the commander of a fleet or squadron; an admiral,
or commodore.</cd> -- <col><b>Flag of truse</b></col>, <cd>a white flag
carried or displayed to an enemy, as an invitation to conference, or for
the purpose of making some communication not hostile.</cd> --
<col><b>Flag share</b></col>, <cd>the flag officer's share of prize
money.</cd> -- <col><b>Flag station</b></col> <fld>(Railroad)</fld>,
<cd>a station at which trains do not stop unless signaled to do so, by a
flag hung out or waved.</cd> -- <col><b>National flag</b></col>, <cd>a
flag of a particular country, on which some national emblem or device,
is emblazoned.</cd> -- <col><b>Red flag</b></col>, <cd>a flag of a red
color, displayed as a signal of danger or token of defiance; the emblem
of anarchists.</cd> -- <col><b>To dip, the flag</b></col>, <cd>to mlower
it and quickly restore it to its place; -- done as a mark of
respect.</cd> -- <col><b>To hang out the white flag</b></col>, <cd>to
ask truce or quarter, or, in some cases, to manifest a friendly design
by exhibiting a white flag.</cd> -- <mcol><col><b>To hang the flag
half-mast high</b></col> <it>or</it> <col><b>To hang the flag
half-staff</b></col> <it>or</it> <col><b>To hang the flag at
half-staff</b></col></mcol>, <cd>to raise it only half way to the mast
or staff, as a token or sign of mourning.</cd> -- <mcol><col><b>To
strike the flag</b></col> <it>or</it> <col><b>To lower the
flag</b></col></mcol>, <cd>to haul it down, in token of respect,
submission, or, in an engagement, of surrender.</cd> -- <col><b>Yellow
flag</b></col>, <cd>the quarantine flag of all nations; also carried at
a vessel's fore, to denote that an infectious disease is on
board.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flag</ent><br/
<hw>Flag</hw>, <pos>v. t.</pos> <ety>[From <er>Flag</er> an
ensign.]</ety> <sn>1.</sn> <def>To signal to with a flag or by waving
the hand; <as>as, to <ex>flag</ex> a train</as>; also used with
<ptcl>down</ptcl>; <as>as, to <ex>flag down</ex> a cab</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To convey, as a message, by means of flag signals;
<as>as, to <ex>flag</ex> an order to troops or vessels at a
distance</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To decoy (game) by waving a flag, handkerchief, or
the like to arouse the animal's curiosity.</def></p>

<p><q>The antelope are getting continually shyer and more difficult to
<qex>flag</qex>.</q> <rj><qau>T. Roosevelt.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Flag</ent><br/
<hw>Flag</hw>, <pos>n.</pos> <ety>[From <er>Flag</er> to hang loose, to
bend down.]</ety> <fld>(Bot.)</fld> <def>An aquatic plant, with long,
ensiform leaves, belonging to either of the genera <gen>Iris</gen> and
<gen>Acorus</gen>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Cooper's flag</b></col>, <cd>the cat-tail (<spn>Typha
latifolia</spn>), the long leaves of which are placed between the staves
of barrels to make the latter water-tight.</cd> -- <col><b>Corn
flag</b></col>. <cd>See under 2d <er>Corn</er>.</cd> -- <col><b>Flag
broom</b></col>, <cd>a coarse of broom, originally made of flags or
rushes.</cd> -- <col><b>Flag root</b></col>, <cd>the root of the sweet
flag.</cd> -- <col><b>Sweet flag</b></col>. <cd>See <er>Calamus</er>,
<pos>n.</pos>, 2.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flag</ent><br/
<hw>Flag</hw>, <pos>v. t.</pos> <def>To furnish or deck out with
flags.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flag</ent><br/
<hw>Flag</hw>, <pos>n.</pos> <ety>[Icel. <ets>flaga</ets>, cf. Icel.
<ets>flag</ets> spot where a turf has been cut out, and E.
<ets>flake</ets> layer, scale. Cf. <er>Floe</er>.]</ety> <sn>1.</sn>
<def>A flat stone used for paving.</def> <rj><au>Woodward.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Geol.)</fld> <def>Any hard, evenly stratified
sandstone, which splits into layers suitable for flagstones.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flag</ent><br/
<hw>Flag</hw>, <pos>v. t.</pos> <def>To lay with flags of flat
stones.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The sides and floor are all <qex>flagged</qex> with . . .
marble.</q> <rj><qau>Sandys.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flagellant</ent><br/
<hw>Flag"el*lant</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>flagellans</ets>, p. p. of <ets>flagellare</ets>: cf.F.
<ets>flagellant</ets>. See <er>Flagellate</er>.]</ety> <fld>(Eccl.
Hist.)</fld> <def>One of a fanatical sect which flourished in Europe in
the 13th and 14th centuries, and maintained that flagellation was of
equal virtue with baptism and the sacrament; -- called also
<altname>disciplinant</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flagellata</ent><br/
\'d8<hw>Flag`el*la"ta</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
fr.L. <ets>flagellatus</ets>, <ets>p. p</ets>. <ets>See</ets>
<er>Flagellate</er>, <pos>v. t.</pos>]</ety> <fld>(Zool.)</fld> <def>An
order of Infusoria, having one or two long, whiplike cilia, at the
anterior end. It includes monads. See <er>Infusoria</er>, and
<er>Monad</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flagellate</ent><br/
<hw>Flag"el*late</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Flagellated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Flagellating</conjf> <pr>(?)</pr>.]</vmorph> <ety>[L.
<ets>flagellatus</ets>, p. p. of <ets>flagellare</ets> to scoure, fr.
<ets>flagellum</ets> whip, dim. of <ets>flagrum</ets> whip, scoure; cf.
<ets>fligere</ets> to strike. Cf. <er>Flall</er>.]</ety> <def>To whip;
to scourge; to flog.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flagellate</ent><br/
<hw>Fla*gel"late</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Flagelliform.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>Of or pertaining to the
Flagellata.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Having a flagellum or flagella.</def><br/
[<source>PJC</source>]</p>

<p><ent>flagellated</ent><br/
<hw>flagellated</hw> <pos>adj.</pos> <sn>1.</sn> <def>resembling a
flagellum or flagella.</def><br/
<syn><b>Syn. --</b> flagellate{1}.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>having a flagellum or flagella.</def><br/
<syn><b>Syn. --</b> flagellate{3}.</syn><br/
[<source>PJC</source>]</p>

<p><ent>Flagellation</ent><br/
<hw>Flag`el*la"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>flagellatio</ets>: cf. F. <ets>flagellation</ets>.]</ety> <def>A
beating or flogging; a whipping; a scourging.</def>
<rj><au>Garth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flagellator</ent><br/
<hw>Flag"el*la`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
practices flagellation; one who whips or scourges.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flagelliform</ent><br/
<hw>Fla*gel"li*form</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>flagellum</ets> a whip + <ets>-form</ets>.]</ety> <def>Shaped like
a whiplash; long, slender, round, flexible, and (comming)
tapering.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flagellum</ent><br/
\'d8<hw>Fla*gel"lum</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
E. <plw>Flagellums</plw> <pr>(#)</pr>, L. <plw>Flagella</plw>
<pr>(#)</pr>.</plu> <ety>[L., a whip. See <er>Flagellate</er>, <pos>v.
t.</pos>]</ety> <sn>1.</sn> <fld>(Bot.)</fld> <def>A young, flexible
shoot of a plant; esp., the long trailing branch of a vine, or a slender
branch in certain mosses.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <sd>(a)</sd> <def>A long, whiplike
cilium. See <er>Flagellata</er>.</def> <sd>(b)</sd> <def>An appendage of
the reproductive apparatus of the snail.</def> <sd>(c)</sd> <def>A
lashlike appendage of a crustacean, esp. the terminal portion of the
antenn<ae/ and the epipodite of the maxilipeds. See
<er>Maxilliped</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 566 --></p>

<p><ent>Flageolet</ent><br/
<hw>Flag"eo*let`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>flageolet</ets>, dim. of OF. <ets>flaj<?/l</ets> (as if fr. a LL.
<ets>flautio</ets>;<ets>us</ets>), of <ets>fla<uum/te</ets>,
<ets>flahute</ets>, F. <ets>fl<?/te</ets>. See <er>Flute</er>.]</ety>
<fld>(Mus.)</fld> <def>A small wooden pipe, having six or more holes,
and a mouthpiece inserted at one end. It produces a shrill sound, softer
than of the piccolo flute, and is said to have superseded the old
recorder.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Flageolet tones</b></col> <fld>(Mus.)</fld>, <cd>the
naturel harmonics or overtones of stringed instruments.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flagginess</ent><br/
<hw>Flag"gi*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The condition of
being flaggy; laxity; limberness.</def> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flagging</ent><br/
<hw>Flag"ging</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A pavement or
sidewalk of flagstones; flagstones, collectively.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flagging</ent><br/
<hw>Flag"ging</hw>, <pos>a.</pos> <def>Growing languid, weak, or
spiritless; weakening; delaying.</def> --
<wordforms><wf>Flag"ging*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flaggy</ent><br/
<hw>Flag"gy</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Weak;
flexible; limber.</def> <ldquo/<xex>Flaggy</xex> wings.<rdquo/
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Tasteless; insipid; <as>as, a <ex>flaggy</ex>
apple</as>.</def> <mark>[Obs.]</mark> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flaggy</ent><br/
<hw>Flag"gy</hw>, <pos>a.</pos> <ety>[From 5th <er>Flag</er>.]</ety>
<def>Abounding with the plant called <xex>flag</xex>; <as>as, a
<ex>flaggy</ex> marsh</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flagitate</ent><br/
<hw>Flag"i*tate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>flagitatus</ets>, p. p. of <ets>flagitare</ets> to demand. See
<er>Flagitious</er>.]</ety> <def>To importune; to demand fiercely or
with passion.</def> <mark>[Archaic]</mark>
<rj><au>Carcyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flagitation</ent><br/
<hw>Flag`i*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>flagitatio</ets>.]</ety> <def>Importunity; urgent demand.</def>
<mark>[Archaic]</mark> <rj><au>Carlyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flagitious</ent><br/
<hw>Fla*gi"tious</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>flagitiosus</ets>, fr. <ets>flagitium</ets> a shameful or
disgraceful act, orig., a burning desire, heat of passion, from
<ets>flagitare</ets> to demand hotly, fiercely; cf. <ets>flagrare</ets>
to burn, E. <ets>flagrant</ets>.]</ety> <sn>1.</sn> <def>Disgracefully
or shamefully criminal; grossly wicked; scandalous; shameful; -- said of
acts, crimes, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Debauched principles and <qex>flagitious</qex> practices.</q>
<rj><qau>I. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Guilty of enormous crimes; corrupt; profligate; --
said of persons.</def> <rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Characterized by scandalous crimes or vices; <as>as,
<ex>flagitious</ex> times</as>.</def> <rj><au>Pope.</au></rj></p>

<p><syn><b>Syn.</b> -- Atrocious; villainous; flagrant; heinous;
corrupt; profligate; abandoned. See <er>Atrocious</er>.</syn></p>

<p>-- <wordforms><wf>Fla*gi"tious*ly</wf>, <pos>adv.</pos> --
<wf>Fla*gi"tious*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><q>A sentence so <qex>flagitiously</qex> unjust.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flagman</ent><br/
<hw>Flag"man</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Flagmen</plw> <pr>(<?/)</pr>.</plu> <def>One who makes signals with
a flag.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flagon</ent><br/
<hw>Flag"on</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>flacon</ets>,
for <ets>flascon</ets>, fr. OF. <ets>flasche</ets>, from LL.
<ets>flasco</ets>. See <er>Flask</er>.]</ety> <def>A vessel with a
narrow mouth, used for holding and conveying liquors. It is generally
larger than a bottle, and of leather or stoneware rather than of
glass.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A trencher of mutton chops, and a <qex>flagon</qex> of ale.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>flagpole</ent><br/
<hw>flag"pole`</hw> <pr>(fl<acr/g"p<omac/l`)</pr>, <pos>n.</pos> <def>A
pole used to display a flag.</def><br/
[<source>PJC</source>]</p>

<p><ent>Flagpole sitter</ent><br/
<hw>Flag"pole` sit"ter</hw> <pr>(fl<acr/g"p<omac/l`
s<icr/t"t<etil/r)</pr>, <pos>n.</pos> <def>A person who sits for an
extended period of time on top of a flagpole or other high column; -- a
publicity stunt performed for various reasons.</def><br/
[<source>PJC</source>]</p>

<p><q>He [Shipwreck Kelly] was the great <ex>flagpole sitter</ex> of the
thirties, the founding father of the whole discipline, who provided
inspiration for many and even the pseudonym for one -- Van Nolan, who
also called himself Shipwreck. Any serious polesitter believes himself
an avatar of Shipwreck Kelly, and I was then and am now no
exception.</q> <rj><qau>From: John A. Gould, Aerie (Berkshire Review,
Volume XI, Number 1, Spring, 1975).</qau></rj></p>

<p><q>The two other holy men in Gregory's narrative had more exotic
origins than the pair that has just been seen. Gregory encountered one
of them when on a journey to the north-eastern parts of the Frankish
kingdom. This was a Lombard, named Vulfolaic, who had spent some years
in the arduous exercise of being a stylite, the Christian equivalent of
a <ex>flagpole sitter</ex>; in other words, Vulfolaic was a monk whose
main austerity consisted in living on top of a pillar. By carrying out
this feat in the rain, snow, and frost of the Moselle valley, Vulfolaic
had convinced the local population to overthrow and abandon the idol of
Diana to which they were addicted.</q> <rj><qau>Walter Goffart,
FOREIGNERS IN THE HISTORIES OF GREGORY OF TOURS
(https://journals.lib.unb.ca/index.php/flor/article/download/15346/20501).</qau></rj></p>

<p><ent>Flagrance</ent><br/
<hw>Fla"grance</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Flagrancy.</def>
<rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flagrancy</ent><br/
<hw>Fla"gran*cy</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Flagrancies</plw> <pr>(#)</pr>.</plu> <ety>[L.
<ets>flagrantia</ets> a burning. See <er>Flagrant</er>.]</ety>
<sn>1.</sn> <def>A burning; great heat; inflammation.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Lust causeth a <qex>flagrancy</qex> in the eyes.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The condition or quality of being flagrant;
atrocity; heinousness; enormity; excess.</def>
<rj><au>Steele.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flagrant</ent><br/
<hw>Fla"grant</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>flagrans</ets>, <ets>-antis</ets>, p. pr. of <ets>flagrate</ets> to
burn, akin to Gr. <?/: cf. F. <ets>flagrant</ets>. Cf. <er>Flame</er>,
<er>Phlox</er>.]</ety> <sn>1.</sn> <def>Flaming; inflamed; glowing;
burning; ardent.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The beadle's lash still <qex>flagrant</qex> on their back.</q>
<rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A young man yet <qex>flagrant</qex> from the lash of the
executioner or the beadle.</q> <rj><qau>De Quincey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Flagrant</qex> desires and affections.</q>
<rj><qau>Hooker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Actually in preparation, execution, or performance;
carried on hotly; raging.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A war the most powerful of the native tribes was
<qex>flagrant</qex>.</q> <rj><qau>Palfrey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Flaming into notice; notorious; enormous; heinous;
glaringly wicked.</def></p>

<p><syn><b>Syn.</b> -- Atrocious; flagitious; glaring. See
<er>Atrocious</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flagrantly</ent><br/
<hw>Fla"grant*ly</hw>, <pos>adv.</pos> <def>In a flagrant
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flagrate</ent><br/
<hw>Fla"grate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>flagrare</ets>, <ets>flagratum</ets>, v.i. & t., to burn.]</ety>
<def>To burn.</def> <mark>[Obs.]</mark> <rj><au>Greenhill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flagration</ent><br/
<hw>Fla*gra"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A
conflagration.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flagship</ent><br/
<hw>Flag"ship`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Naut.)</fld>
<def>The vessel which carries the commanding officer of a fleet or
squadron and flies his distinctive flag or pennant.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flagstaff</ent><br/
<hw>Flag"staff`</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>-staves</plw> <pr>(<?/)</pr> or <plw>-staffs</plw>
<pr>(<?/)</pr>.</plu> <def>A staff{4} on which a flag is
hoisted.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flagstone</ent><br/
<hw>Flag"stone`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A flat stone used
in paving, or any rock which will split into such stones. See
<er>Flag</er>, a stone.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>flag-waver</ent><br/
<hw>flag-waver</hw> <pos>n.</pos> <def>an extreme bellicose
nationalist.</def><br/
<syn><b>Syn. --</b> chauvinist, jingoist, jingo,
hundred-percenter.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>flag-waving</ent><br/
<hw>flag-waving</hw> <pos>adj.</pos> <def>fanatically patriotic; same as
<er>chauvinistic</er>.</def> <mark>[prenominal]</mark><br/
<syn><b>Syn. --</b> chauvinistic, jingoistic, nationalistic,
superpatriotic.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Flagworm</ent><br/
<hw>Flag"worm`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>A worm or grub found among flags and sedge.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flail</ent><br/
<hw>Flail</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>flagellum</ets>
whip, scourge, in LL., a threshing flail: cf. OF. <ets>flael</ets>,
<ets>flaiel</ets>, F. <ets>fl<eacute/au</ets>. See
<er>Flagellum</er>.]</ety> <sn>1.</sn> <def>An instrument for threshing
or beating grain from the ear by hand, consisting of a wooden staff or
handle, at the end of which a stouter and shorter pole or club, called a
swipe, is so hung as to swing freely.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His shadowy <qex>flail</qex> hath threshed the corn.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An ancient military weapon, like the common flail,
often having the striking part armed with rows of spikes, or
loaded.</def> <rj><au>Fairholt.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>No citizen thought himself safe unless he carried under his coat a
small <qex>flail</qex>, loaded with lead, to brain the Popish
assassins.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flaily</ent><br/
<hw>Flail"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Acting like a
flail.</def> <mark>[Obs.]</mark> <rj><au>Vicars.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flain</ent><br/
<hw>Flain</hw> <pr>(?)</pr>, <mark>obs.</mark> <def><pos>p. p.</pos> of
<er>Flay</er>.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flair</ent><br/
<hw>Flair</hw> <pr>(fl<acir/r)</pr>, <pos>n.</pos> <ety>[OE.
<ets>flaire</ets>odor, fr. OF. & F. <ets>flair</ets>, fr. OF.
<ets>flairier</ets>, F. <ets>flairer</ets>, to smell, LL.
<ets>flagrare</ets> for L. <ets>fragrare</ets>. See
<er>Flagrant</er>.]</ety> <sn>1.</sn> <def>Smell; odor.</def>
<mark>[Obs.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>Sense of smell; scent; fig., discriminating
sense.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>3.</sn> <def>A talent or ability, especially an intuitive one
that makes performance of a task appear easy; an intuitive appreciation;
a knack; <as>as, she has a <ex>flair</ex> for acting</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <def>An attractive way of performing a task;
style.</def><br/
[<source>PJC</source>]</p>

<p><ent>Flake</ent><br/
<hw>Flake</hw> <pr>(fl<amac/k)</pr>, <pos>n.</pos> <ety>[Cf. Icel.
<ets>flaki</ets>, <ets>fleki</ets>, Dan. <ets>flage</ets>, D.
<ets>vlaak</ets>.]</ety> <sn>1.</sn> <def>A paling; a hurdle.</def>
<mark>[prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A platform of hurdles, or small sticks made fast or
interwoven, supported by stanchions, for drying codfish and other
things.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>You shall also, after they be ripe, neither suffer them to have
straw nor fern under them, but lay them either upon some smooth table,
boards, or <qex>flakes</qex> of wands, and they will last the
longer.</q> <rj><qau>English Husbandman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Naut.)</fld> <def>A small stage hung over a
vessel's side, for workmen to stand on in calking, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flake</ent><br/
<hw>Flake</hw> <pr>(fl<amac/k)</pr>, <pos>n.</pos> <ety>[Cf. Icel.
<ets>flakna</ets> to flake off, split, <ets>flagna</ets> to flake off,
Sw. <ets>flaga</ets> flaw, flake, <ets>flake</ets> plate, Dan.
<ets>flage</ets> snowflake. Cf. <er>Flag</er> a flat stone.]</ety>
<sn>1.</sn> <def>A loose filmy mass or a thin chiplike layer of
anything; a film; flock; lamina; layer; scale; <as>as, a <ex>flake</ex>
of snow, tallow, or fish</as>.</def> <ldquo/Lottle <xex>flakes</xex> of
scurf.<rdquo/ <rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Great <qex>flakes</qex> of ice encompassing our boat.</q>
<rj><qau>Evelyn.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A little particle of lighted or incandescent matter,
darted from a fire; a flash.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With <qex>flakes</qex> of ruddy fire.</q>
<rj><qau>Somerville.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Bot.)</fld> <def>A sort of carnation with only two
colors in the flower, the petals having large stripes.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>a person who behaves strangely; a flaky{2}
person.</def> <mark>[Colloq.]</mark> <br/
[<source>PJC</source>]</p>

<p><cs><col><b>Flake knife</b></col> <fld>(Arch<ae/ol.)</fld>, <cd>a
cutting instrument used by savage tribes, made of a flake or chip of
hard stone.</cd> <au>Tylor.</au> -- <col><b>Flake stand</b></col>,
<cd>the cooling tub or vessel of a still worm.</cd> <au>Knight.</au> --
<col><b>Flake white</b></col>. <fld>(Paint.)</fld> <sd>(a)</sd> <cd>The
purest white lead, in the form of flakes or scales.</cd> <sd>(b)</sd>
<cd>The trisnitrate of bismuth.</cd> <au>Ure.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flake</ent><br/
<hw>Flake</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Etym. uncertain; cf.
1st <er>Fake</er>.]</ety> <def>A flat layer, or fake, of a coiled
cable.</def></p>

<p><q><qex>Flake</qex> after <qex>flake</qex> ran out of the tubs, until
we were compelled to hand the end of our line to the second mate.</q>
<rj><qau>F. T. Bullen.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Flake</ent><br/
<hw>Flake</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Flaked</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Flaking</conjf>.]</vmorph> <def>To form into flakes.</def>
<rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flake</ent><br/
<hw>Flake</hw>, <pos>v. i.</pos> <def>To separate in flakes; to peel or
scale off.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flakiness</ent><br/
<hw>Flak"i*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state of being
flaky.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flaky</ent><br/
<hw>Flak"y</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Consisting
of flakes or of small, loose masses; lying, or cleaving off, in flakes
or layers; flakelike.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>What showers of mortal hail, what <qex>flaky</qex> fires!</q>
<rj><qau>Watts.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>flaky</qex> weight of winter's purest snows.</q>
<rj><qau>Wordsworth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>prone to strange or erratic behavior; -- of
persons.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>odd, unpredictable or unconventional; offbeat;
whacky; -- of behavior.</def><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <def>unpredictable, erratic, or unreliable; -- of
machinery, especially electronic devices.</def> <ldquo/a
<xex>flaky</xex> computer board.<rdquo/<br/
[<source>PJC</source>]</p>

<p><ent>Flam</ent><br/
<hw>Flam</hw> <pr>(fl<acr/m)</pr>, <pos>n.</pos> <ety>[Cf. AS.
<er>fle<aacute/m</er>, <er>fl<aemac/m</er>, flight. <root/84 . Cf.
<er>Flimflam</er>.]</ety> <def>A freak or whim; also, a falsehood; a
lie; an illusory pretext; deception; delusion.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>A perpetual abuse and <qex>flam</qex> upon posterity.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flam</ent><br/
<hw>Flam</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Flammed</conjf> ; <pos>p. pr. & vb. n.</pos>
<conjf>Flamming</conjf>.]</vmorph> <def>To deceive with a
falsehood.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>God is not to be <qex>flammed</qex> off with lies.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flambe</ent><br/
\'d8<hw>Flam`b<eacute/"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F., p.p.
of <ets>flamber</ets> to singe, pass (a thing) through flame. Cf.
<er>Flambeau</er>.]</ety> <sn>1.</sn> <fld>(Ceramics)</fld>
<def>Decorated by glaze splashed or irregularly spread upon the surface,
or apparently applied at the top and allowed to run down the sides; --
said of pieces of Chinese porcelain.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <pos>a.</pos> <ety>[F., p.p. of <ets>flamber</ets> to
singe, pass (a thing) through flame.]</ety> <fld>(Cooking)</fld>
<def>Dipped in or covered with a flammable liqueur and set afire when
served; -- usually used postpositively; <as>as, cherries
<ex>flambe</ex></as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Flambeau</ent><br/
<hw>Flam"beau</hw> <pr>(?)</pr>; <pos>n.</pos>; <plu><it>pl.</it>
<plw>Flambeaux</plw> <pr>(#)</pr> or <plw>Flambeaus</plw>
<pr>(#)</pr>.</plu> <ety>[F., fr. OF. <ets>flambe</ets> flame, for
<ets>flamble</ets>, from L. <ets>flammula</ets> a little flame, dim. of
<ets>flamma</ets> flame. See <er>Flame</er>.]</ety> <def>A flaming
torch, esp. one made by combining together a number of thick wicks
invested with a quick-burning substance (anciently, perhaps, wax; in
modern times, pitch or the like); hence, any torch.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flamboyant</ent><br/
<hw>Flam*boy"ant</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F.]</ety>
<fld>(Arch.)</fld> <def>Characterized by waving or flamelike curves, as
in the tracery of windows, etc.; -- said of the later (15th century)
French Gothic style.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flamboyer</ent><br/
<hw>Flam*boy"er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>flamboyer</ets> to be bright.]</ety> <fld>(Bot.)</fld> <def>A name
given in the East and West Indies to certain trees with brilliant
blossoms, probably species of <gen>C<ae/salpinia</gen>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flame</ent><br/
<hw>Flame</hw> <pr>(fl<amac/m)</pr>, <pos>n.</pos> <ety>[OE.
<ets>flame</ets>, <ets>flaume</ets>, <ets>flaumbe</ets>, OF.
<ets>flame</ets>, <ets>flambe</ets>, F. <ets>flamme</ets>, fr. L.
<ets>flamma</ets>, fr. <ets>flamma</ets>, fr. <ets>flagrare</ets> to
burn. See <er>Flagrant</er>, and cf. <er>Flamneau</er>,
<er>Flamingo</er>.]</ety> <sn>1.</sn> <def>A stream of burning vapor or
gas, emitting light and heat; darting or streaming fire; a blaze; a
fire.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Burning zeal or passion; elevated and noble
enthusiasm; glowing imagination; passionate excitement or anger.</def>
<ldquo/In a <xex>flame</xex> of zeal severe.<rdquo/
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Where <qex>flames</qex> refin'd in breasts seraphic glow.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Smit with the love of sister arts we came,<br/
And met congenial, mingling <qex>flame</qex> with <qex>flame</qex>.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Ardor of affection; the passion of love.</def>
<rj><au>Coleridge.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A person beloved; a sweetheart.</def>
<rj><au>Thackeray.</au></rj></p>

<p><syn><b>Syn.</b> -- Blaze; brightness; ardor. See
<er>Blaze</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Flame bridge</b></col>, <cd>a bridge wall. See
<er>Bridge</er>, <pos>n.</pos>, 5.</cd> -- <col><b>Flame
color</b></col>, <cd>brilliant orange or yellow.</cd> <au>B.
Jonson.</au> -- <col><b>Flame engine</b></col>, <cd>an early name for
the gas engine.</cd> -- <col><b>Flame manometer</b></col>, <cd>an
instrument, invented by Koenig, to obtain graphic representation of the
action of the human vocal organs. See <er>Manometer</er>.</cd> --
<col><b>Flame reaction</b></col> <fld>(Chem.)</fld>, <cd>a method of
testing for the presence of certain elements by the characteristic color
imparted to a flame; as, sodium colors a flame yellow, potassium violet,
lithium crimson, boracic acid green, etc. Cf. <cref>Spectrum
analysis</cref>, under <er>Spectrum</er>.</cd> -- <col><b>Flame
tree</b></col> <fld>(Bot.)</fld>, <cd>a tree with showy scarlet flowers,
as the <spn>Rhododendron arboreum</spn> in India, and the
<spn>Brachychiton acerifolium</spn> of Australia.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flame</ent><br/
<hw>Flame</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Flamed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Flaming</conjf>.]</vmorph> <ety>[OE. <ets>flamen</ets>,
<ets>flaumben</ets>, F. <ets>flamber</ets>, OF. also, <ets>flamer</ets>.
See <er>Flame</er>, <pos>n.</pos>]</ety> <sn>1.</sn> <def>To burn with a
flame or blaze; to burn as gas emitted from bodies in combustion; to
blaze.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The main blaze of it is past, but a small thing would make it
<qex>flame</qex> again.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To burst forth like flame; to break out in violence
of passion; to be kindled with zeal or ardor.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He <qex>flamed</qex> with indignation.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flame</ent><br/
<hw>Flame</hw>, <pos>v. t.</pos> <def>To kindle; to inflame; to
excite.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And <qex>flamed</qex> with zeal of vengeance inwardly.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flame-colored</ent><br/
<hw>Flame"-col`ored</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of the color
of flame; of a bright orange yellow color.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>flamefish</ent><br/
<hw>flamefish</hw> <pos>n.</pos> <def>a bright red perchlike fish
(<spn>Apogon maculatus</spn>) found in tropical Atlantic coastal
waters.</def><br/
<syn><b>Syn. --</b> <spn>Apogon maculatus</spn>.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>flame flower</ent><br/
<ent>flameflower</ent><br/
<mhw><hw>flameflower</hw>, <hw>flame flower</hw></mhw> <pos>n.</pos>
<sn>1.</sn> <def>a plant of the genus <gen>Kniphofia</gen> having long
grasslike leaves and tall scapes of red or yellow drooping
flowers.</def><br/
<syn><b>Syn. --</b> kniphofia, tritoma.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>plant of the Southwestern U. S. with fleshy roots
and erect stems with narrow succulent leaves and one reddish-orange
flower in each upper leaf axil. Its fleshy roots were once cooked by
Indians.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Flameless</ent><br/
<hw>Flame"less</hw>, <pos>a.</pos> <def>Destitute of flame.</def>
<rj><au>Sandys.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flamelet</ent><br/
<hw>Flame"let</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Flame</ets> +
<ets>-let</ets>.]</ety> <def>A small flame.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>flamelets</qex> gleamed and flickered.</q>
<rj><qau>Longfellow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flamen</ent><br/
<hw>Fla"men</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it> E.
<plw>Flammens</plw> <pr>(#)</pr>, L. <plw>Flamines</plw>
<pr>(#)</pr>.</plu> <ety>[L.]</ety> <fld>(Rom. Antiq.)</fld> <def>A
priest devoted to the service of a particular god, from whom he received
a distinguishing epithet. The most honored were those of Jupiter, Mars,
and Quirinus, called respectively <stype>Flamen Dialis</stype>,
<stype>Flamen Martialis</stype>, and <stype>Flamen
Quirinalis</stype>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Affrights the <qex>flamens</qex> at their service quaint.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>flamenco</ent><br/
<hw>flamenco</hw> <pos>n.</pos> <sn>1.</sn> <def>a strongly rhythmic and
vigorous style of dancing characteristic of the Andalusian gypsies,
characterized by clapping and stamping of feet.</def><br/
<syn><b>Syn. --</b> gypsy dancing.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <fld>(Mus.)</fld> <def>a strongly rhythmic style of music
originating in southern Spain, often improvisatorial, performed by
itself, often on a guitar, or as an accompaniment to flamenco
dancing.</def><br/
[<source>PJC</source>]</p>

<p><ent>flameproof</ent><br/
<hw>flameproof</hw> <pos>adj.</pos> <def>not susceptible to burning;
noncombustible; fireproof; -- of artifacts. Opposite of
<ant>combustible</ant>.</def><br/
<syn><b>Syn. --</b> flame-retardant.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>flamethrower</ent><br/
<hw>flamethrower</hw> <pos>n.</pos> <fld>(Mil.)</fld> <def>a weapon that
squirts ignited liquid or gelatinous fuel for several yards.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Flamineous</ent><br/
<hw>Fla*min"e*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to a
flamen; flaminical.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flaming</ent><br/
<hw>Flam"ing</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Emitting
flames; afire; blazing; consuming; illuminating.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of the color of flame; high-colored; brilliant;
dazzling.</def> <ldquo/In <xex>flaming</xex> yellow bright.<rdquo/
<rj><au>Prior.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Ardent; passionate; burning with zeal; irrepressibly
earnest; <as>as, a <ex>flaming</ex> proclamation or
harangue</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flamingly</ent><br/
<hw>Flam"ing*ly</hw>, <pos>adv.</pos> <def>In a flaming
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flamingo</ent><br/
<hw>Fla*min"go</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Flamingoes</plw> <pr>(#)</pr>.</plu> <ety>[Sp. <ets>flamenco</ets>,
cf. Pg. <ets>flamingo</ets>, Prov. <ets>flammant</ets>, F.
<ets>flamant</ets>; prop. a p. pr. meaning <ets>flaming</ets>. So called
in allusion to its color. See <er>Flame</er>.]</ety> <fld>(Zool.)</fld>
<def>Any bird of the genus <gen>Ph<oe/nicopterus</gen>. The flamingoes
have webbed feet, very long legs, and a beak bent down as if broken.
Their color is usually red or pink. The American flamingo is <spn>P.
ruber</spn>; the European is <spn>P. antiquorum</spn>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flaminical</ent><br/
<hw>Fla*min"i*cal</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to a
flamen.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flammability</ent><br/
<hw>Flam`ma*bil"ity</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The quality of
being flammable; inflammability.</def> <mark>[Obs.]</mark> <rj><au>Sir
T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flammable</ent><br/
<hw>Flam"ma*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Inflammable.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flammation</ent><br/
<hw>Flam*ma"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
setting in a flame or blaze.</def> <mark>[Obs.]</mark> <rj><au>Sir. T.
Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flammeous</ent><br/
<hw>Flam"me*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>flammeus</ets> from <ets>flamma</ets> flame.]</ety> <def>Pertaining
to, consisting of, or resembling, flame.</def> <mark>[Obs.]</mark>
<rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flammiferous</ent><br/
<hw>Flam*mif"er*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>flammifer</ets>; <ets>flamma</ets> flame + <ets>ferre</ets> to
bear.]</ety> <def>Producing flame.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flammivomous</ent><br/
<hw>Flam*miv"o*mous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>flammivomus</ets>; <ets>flamma</ets> flame + <ets>vomere</ets> to
vomit.]</ety> <def>Vomiting flames, as a volcano.</def> <rj><au>W.
Thompson. (1745).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flammulated</ent><br/
<hw>Flam"mu*la`ted</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>flammula</ets> little flame, dim. fr. <ets>flamma</ets>
flame.]</ety> <def>Of a reddish color.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flamy</ent><br/
<hw>Flam"y</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From
<er>Flame</er>.]</ety> <def>Flaming; blazing; flamelike; flame-colored;
composed of flame.</def> <rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flanch</ent><br/
<hw>Flanch</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Flanches</plw> <pr>(#)</pr>.</plu> <ety>[Prov. E., a projection,
OF. <ets>flanche</ets> flank. See <er>Flank</er>.]</ety> <sn>1.</sn>
<def>A flange.</def> <mark>[R.]</mark>. <def2><fld>(Her.)</fld> <def>A
bearing consisting of a segment of a circle encroaching on the field
from the side.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Flanches</xex> are always in pairs. A pair of
<xex>flanches</xex> is considered one of the subordinaries.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flanched</ent><br/
<hw>Flanched</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Her.)</fld>
<def>Having flanches; -- said of an escutcheon with those
bearings.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flanconade</ent><br/
<hw>Flan`co*nade"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<fld>(Fencing)</fld> <def>A thrust in the side.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flanerie</ent><br/
\'d8<hw>fl<acir/`ne*rie"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>fl<acir/nerie</ets>. See <er>Flaneur</er>.]</ety> <def>Lit.,
strolling; sauntering; hence, aimlessness; idleness; <as>as,
intellectual <ex>fl<acir/nerie</ex></as>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>flaneur</ent><br/
\'d8<hw>fla`neur"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr.
<ets>fl<acir/ner</ets> to stroll.]</ety> <def>One who strolls about
aimlessly; a lounger; a loafer.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flang</ent><br/
<hw>Flang</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A miner's two-pointed
pick.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flange</ent><br/
<hw>Flange</hw> <pr>(fl<acr/nj)</pr>, <pos>n.</pos> <ety>[Prov. E.
<ets>flange</ets> to project, <ets>flanch</ets> a projection. See
<er>Flanch</er>, <er>Flank</er>.]</ety> <sn>1.</sn> <def>An external or
internal rib, or rim, for strength, as the <xex>flange</xex> of an iron
beam; or for a guide, as the <xex>flange</xex> of a car wheel (see
<er>Car wheel</er>.); or for attachment to another object, as the
<xex>flange</xex> on the end of a pipe, steam cylinder, etc.</def>
<rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A plate or ring to form a rim at the end of a pipe
when fastened to the pipe.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Blind flange</b></col>, <cd>a plate for covering or
closing the end of a pipe.</cd> -- <col><b>Flange joint</b></col>, <cd>a
joint, as that of pipes, where the connecting pieces have flanges by
which the parts are bolted together.</cd> <au>Knight.</au> --
<col><b>Flange rail</b></col>, <cd>a rail with a flange on one side, to
keep wheels, etc. from running off.</cd> -- <col><b>Flange
turning</b></col>, <cd>the process of forming a flange on a wrought iron
plate by bending and hammering it when hot.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flange</ent><br/
<hw>Flange</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Flanged</conjf> <pr>(fl<acr/njd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Flanging</conjf> <pr>(fl<acr/n"j<icr/ng)</pr>.]</vmorph>
<fld>(Mach.)</fld> <def>To make a flange on; to furnish with a
flange.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flange</ent><br/
<hw>Flange</hw>, <pos>v. i.</pos> <def>To be bent into a
flange.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flanged</ent><br/
<hw>Flanged</hw> <pr>(fl<acr/njd)</pr>, <pos>a.</pos> <def>Having a
flange or flanges; <as>as, a <ex>flanged</ex> wheel</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flank</ent><br/
<hw>Flank</hw> <pr>(fl<acr/<nsm/k)</pr>, <pos>n.</pos> <ety>[F.
<ets>flanc</ets>, prob. fr. L. <ets>flaccus</ets> flabby, with
<it>n</it> inserted. Cf. <er>Flaccid</er>, <er>Flanch</er>,
<er>Flange</er>.]</ety> <sn>1.</sn> <def>The fleshy or muscular part of
the side of an animal, between the ribs and the hip. See
<xex>Illust.</xex> of <er>Beef</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mil.)</fld> <sd>(a)</sd> <def>The side of an army,
or of any division of an army, as of a brigade, regiment, or battalion;
the extreme right or left; <as>as, to attack an enemy in <ex>flank</ex>
is to attack him on the side</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>When to right and left the front</q> <q>Divided, and to either
<qex>flank</qex> retired.</q> <rj><qau>Milton.</qau></rj></p>

<p><sd>(b)</sd> <fld>(Fort.)</fld> <def>That part of a bastion which
reaches from the curtain to the face, and defends the curtain, the flank
and face of the opposite bastion; any part of a work defending another
by a fire along the outside of its parapet.</def> See <xex>Illust.</xex>
of <er>Bastion</er>.<br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Arch.)</fld> <def>The side of any building.</def>
<rj><au>Brands.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>That part of the acting surface of a gear wheel
tooth that lies within the pitch line.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Flank attack</b></col> <fld>(Mil.)</fld>, <cd>an attack
upon the side of an army or body of troops, distinguished from one upon
its front or rear.</cd> -- <col><b>Flank company</b></col>
<fld>(Mil.)</fld>, <cd>a certain number of troops drawn up on the right
or left of a battalion; usually grenadiers, light infantry, or
riflemen.</cd> -- <col><b>Flank defense</b></col> <fld>(Fort.)</fld>,
<cd>protection of a work against undue exposure to an enemy's direct
fire, by means of the fire from other works, sweeping the ground in its
front.</cd> -- <col><b>Flank en potence</b></col> <fld>(Mil.)</fld>,
<cd>any part of the right or left wing formed at a projecting angle with
the line.</cd> -- <col><b>Flank files</b></col>, <cd>the first men on
the right, and the last on the left, of a company, battalion, etc.</cd>
-- <col><b>Flank march</b></col>, <cd>a march made parallel or obliquely
to an enemy's position, in order to turn it or to attack him on the
flank.</cd> -- <col><b>Flank movement</b></col>, <cd>a change of march
by an army, or portion of one, in order to turn one or both wings of the
enemy, or to take up a new position.</cd> -- <col><b>Flanks of a
frontier</b></col>, <cd>salient points in a national boundary,
strengthened to protect the frontier against hostile incursion.</cd> --
<col><b>Flank patrol</b></col>, <cd>detachments acting independently of
the column of an army, but patrolling along its flanks, to secure it
against surprise and to observe the movements of the
enemy.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 567 --></p>

<p><ent>Flank</ent><br/
<hw>Flank</hw> <pr>(fl<acr/<nsm/k)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Flanked</conjf>
<pr>(fl<acr/<nsm/kt)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Flanking</conjf>.]</vmorph> <ety>[Cf. F. <ets>flanquer</ets>. See
<er>Flank</er>, <pos>n.</pos>, and cf. <er>Flanker</er>, <pos>v.
t.</pos>]</ety> <sn>1.</sn> <def>To stand at the flank or side of; to
border upon.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Stately colonnades are <qex>flanked</qex> with trees.</q>
<rj><qau>Pitt.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To overlook or command the flank of; to secure or
guard the flank of; to pass around or turn the flank of; to attack, or
threaten to attack; the flank of.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flank</ent><br/
<hw>Flank</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To border; to
touch.</def> <rj><au>Bp. Butler.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To be posted on the side.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flanker</ent><br/
<hw>Flank"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, flanks, as a skirmisher or a body of troops sent out upon the
flanks of an army to guard a line of march, or a fort projecting so as
to command the side of an assailing body.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They threw out <qex>flankers</qex>, and endeavored to dislodge
their assailants.</q> <rj><qau>W. Irwing.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flanker</ent><br/
<hw>Flank"er</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Flankered</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Flankering</conjf>.]</vmorph> <ety>[See <er>Flank</er>, <pos>v.
t.</pos>]</ety> <sn>1.</sn> <def>To defend by lateral
fortifications.</def> <mark>[Obs.]</mark> <rj><au>Sir T.
Herbert.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To attack sideways.</def> <mark>[Obs.]</mark>
<rj><au>Evelyn.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flannel</ent><br/
<hw>Flan"nel</hw> <pr>(fl<acr/n"n<ecr/l)</pr>, <pos>n.</pos> <ety>[F.
<ets>flanelle</ets>, cf. OF. <ets>flaine</ets> a pillowcase, a mattress
(?); fr. W. <ets>gwlanen</ets> flannel, fr. <ets>gwlan</ets> wool; prob.
akin to E. <ets>wool</ets>. Cf. <er>Wool</er>.]</ety> <sn>1.</sn> <def>A
soft, nappy, woolen cloth, of loose texture.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>a cotton fabric with a thick nap on one side,
resembling flannel{1}; it is used, <it>e. g.</it> for underwear or
sheets; also called <altname>flannelette</altname>.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <pluf>pl.</pluf> <def>garments made of flannel,
especially underwear.</def><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <def>a washcloth.</def> <mark>[Brit.]</mark><br/
[<source>PJC</source>]</p>

<p><sn>5.</sn> <def>humbug; nonsensical or evasive talk.</def>
<mark>[Brit. informal]</mark><br/
[<source>PJC</source>]</p>

<p><sn>6.</sn> <def>insincere flattery or praise.</def> <mark>[Brit.
informal]</mark><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Adam's flannel</b></col>. <fld>(Bot.)</fld> <cd>See under
<er>Adam</er>.</cd> -- <mcol><col><b>Canton flannel</b></col>,
<col><b>Cotton flannel</b></col></mcol>. <cd>See <cref>Cotton
flannel</cref>, under <er>Cotton</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>flannelbush</ent><br/
<ent>flannelbush</ent><br/
<mhw><hw>flannelbush</hw>, <hw>flannelbush</hw></mhw> <pos>n.</pos>
<fld>(Bot.)</fld> <def>any of several handsome evergreen shrubs of
California and Northern Mexico having downy lobed leaves and showy
yellow flowers.</def><br/
<syn><b>Syn. --</b> California beauty.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>flannelcake</ent><br/
<hw>flannelcake</hw> <pos>n.</pos> <def>a flat cake of thin batter fried
on both sides on a griddle; a pancake; a flapjack.</def><br/
<syn><b>Syn. --</b> pancake, battercake, flapcake, flapjack,
griddlecake, hotcake, hot cake.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Flanneled</ent><br/
<hw>Flan"neled</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Covered or wrapped
in flannel.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>flannelette</ent><br/
<hw>flannelette</hw> <pos>n.</pos> <def>a cotton imitation of
flannel.</def><br/
<syn><b>Syn. --</b> flannel{2}.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Flannel flower</ent><br/
<hw>Flan"nel flow`er</hw>. <fld>(Bot.)</fld> <sd>(a)</sd> <def>The
common mullein.</def> <sd>(b)</sd> <def>A Brazilian apocynaceous vine
(<spn>Macrosiphonia longiflora</spn>) having woolly leaves.</def>
<sd>(c)</sd> <def>An umbelliferous Australian flower (<spn>Actinotus
helianthi</spn>), often erroneously thought to be composite. The
involucre looks as if cut out of white flannel.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Flannen</ent><br/
<hw>Flan"nen</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Made or consisting of
flannel.</def> <mark>[Obs.]</mark> <ldquo/<xex>Flannen</xex>
robes.<rdquo/ <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flap</ent><br/
<hw>Flap</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>flappe</ets>,
<ets>flap</ets>, blow, bly-flap; cf. D. <ets>flap</ets>, and E.
<ets>flap</ets>, <pos>v.</pos>]</ety> <def>Anything broad and limber
that hangs loose, or that is attached by one side or end and is easily
moved; <as>as, the <ex>flap</ex> of a garment</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A cartilaginous <qex>flap</qex> upon the opening of the
larynx.</q> <rj><qau>Sir T. Browne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A hinged leaf, as of a table or shutter.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The motion of anything broad and loose, or a stroke
or sound made with it; <as>as, the <ex>flap</ex> of a sail or of a
wing</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <pluf>pl.</pluf> <fld>(Far.)</fld> <def>A disease in the
lips of horses.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Aeronautics)</fld> <def>a movable part of an
airplane wing, used to increase lift or drag, especially when taking off
or landing. used often in the plural.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><cs><col><b>Flap tile</b></col>, <cd>a tile with a bent up portion,
to turn a corner or catch a drip.</cd> -- <col><b>Flap valve</b></col>
<fld>(Mech.)</fld>, <cd>a valve which opens and shuts upon one hinged
side; a clack valve.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flap</ent><br/
<hw>Flap</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Flapped</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Flapping</conjf> <pr>(?)</pr>.]</vmorph> <ety>[Prob. of imitative
origin; cf. D. <ets>flappen</ets>, E. <ets>flap</ets>, <pos>n.</pos>,
flop, flippant, fillip.]</ety> <sn>1.</sn> <def>To beat with a flap; to
strike.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Yet let me <qex>flap</qex> this bug with gilded wings.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To move, as something broad and flaplike; <as>as, to
<ex>flap</ex> the wings</as>; to let fall, as the brim of a
hat.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To flap in the mouth</b></col>, <cd>to taunt.</cd>
<mark>[Obs.]</mark> <rj><au>W. Cartwright.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flap</ent><br/
<hw>Flap</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To move as do wings, or
as something broad or loose; to fly with wings beating the
air.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The crows <qex>flapped</qex> over by twos and threes.</q>
<rj><qau>Lowell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To fall and hang like a flap, as the brim of a hat,
or other broad thing.</def> <rj><au>Gay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flapdragon</ent><br/
<hw>Flap"drag`on</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A
game in which the players catch raisins out burning brandy, and swallow
them blazing.</def> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The thing thus caught and eaten.</def>
<rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Cakes and ale, and <qex>flapdragons</qex> and mummer's plays, and
all the happy sports of Christians night.</q> <rj><qau>C.
Kingsley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flapdragon</ent><br/
<hw>Flap"drag`on</hw>, <pos>v. t.</pos> <def>To swallow whole, as a
flapdragon; to devour.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>See how the sea <qex>flapdragoned</qex> it.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flap-eared</ent><br/
<hw>Flap"-eared`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having broad,
loose, dependent ears.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flapjack</ent><br/
<hw>Flap"jack`</hw> <pr>(fl<acr/p"j<acr/k`)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>A flat cake turned on the griddle while cooking; a
griddlecake or pancake.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A fried dough cake containing fruit; a
turnover.</def> <mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flap-mouthed</ent><br/
<hw>Flap"-mouthed`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having broad,
hanging lips.</def> <mark>[R.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flapper</ent><br/
<hw>Flap"per</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who,
or that which, flaps.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>See <er>Flipper</er>.</def> <ldquo/The
<xex>flapper</xex> of a porpoise.<rdquo/ <rj><au>Buckley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A flat object used to make a flapping noise by
striking another object.</def> <au>RHUD</au><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <def>A flat and broad object hanging from a larger
object, either flexible like rubber or hinged to allow a swinging
motion; a flap.</def></p>

<p><sn>5.</sn> <def>A young woman who dresses in a modern, stylish
manner and behaves unconventionally in social situations; -- a term used
especially to refer to young women during the 1920's and their peculiar
style of dress.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Flapper skate</b></col> <fld>(Zool.)</fld>, <cd>a
European skate (<spn>Raia intermedia</spn>).</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flare</ent><br/
<hw>Flare</hw> <pr>(fl<acir/r)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Flared</conjf> <pr>(fl<acir/rd)</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>Flaring</conjf>.]</vmorph> <ety>[Cf. Norw.
<ets>flara</ets> to blaze, flame, adorn with tinsel, dial. Sw.
<ets>flasa upp</ets>, and E. <ets>flash</ets>, or
<ets>flacker</ets>.]</ety> <sn>1.</sn> <def>To burn with an unsteady or
waving flame; <as>as, the candle <ex>flares</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To shine out with a sudden and unsteady light; to
emit a dazzling or painfully bright light.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To shine out with gaudy colors; to flaunt; to be
offensively bright or showy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With ribbons pendant, <qex>flaring</qex> about her head.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To be exposed to too much light.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Flaring</qex> in sunshine all the day.</q>
<rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To open or spread outwards; to project beyond the
perpendicular; <as>as, the sides of a bowl <ex>flare</ex>; the bows of a
ship <ex>flare</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To flare up</b></col>, <cd>to become suddenly heated or
excited; to burst into a passion.</cd> <mark>[Colloq.]</mark>
<rj><au>Thackeray.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flare</ent><br/
<hw>Flare</hw>, <pos>n.</pos> <sn>1.</sn> <def>An unsteady, broad,
offensive light.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A spreading outward; <as>as, the <ex>flare</ex> of a
fireplace</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Photog.)</fld> <def>A defect in a photographic
objective such that an image of the stop, or diaphragm, appears as a
fogged spot in the center of the developed negative.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Flare</ent><br/
<hw>Flare</hw>, <pos>n.</pos> <def>Leaf of lard.</def> <ldquo/Pig's
<xex>flare</xex>.<rdquo/ <rj><au>Dunglison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>flared</ent><br/
<hw>flared</hw> <pos>adj.</pos> <def>having a gradual increase in width;
<as>as, <ex>flared</ex> nostrils</as>.</def><br/
<syn><b>Syn. --</b> flaring.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Flare-up</ent><br/
<hw>Flare"-up`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A
sudden burst of anger or passion; an angry dispute.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A sudden bursting into flame; a flaring.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Flaring</ent><br/
<hw>Flar"ing</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>That
flares; flaming or blazing unsteadily; shining out with a dazzling
light.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His [the sun's] <qex>flaring</qex> beams.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Opening or spreading outwards.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flaringly</ent><br/
<hw>Flar"ing*ly</hw>, <pos>adv.</pos> <def>In a flaring
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flash</ent><br/
<hw>Flash</hw> <pr>(fl<acr/sh)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Flashed</conjf> <pr>(fl<acr/sht)</pr>; <pos>p. pr.
& vb. n.</pos> <conjf>Flashing</conjf>.]</vmorph> <ety>[Cf. OE.
<ets>flaskien</ets>, <ets>vlaskien</ets> to pour, sprinkle, dial. Sw.
<ets>flasa</ets> to blaze, E. <ets>flush</ets>, <ets>flare</ets>.]</ety>
<sn>1.</sn> <def>To burst or break forth with a sudden and transient
flood of flame and light; <as>as, the lighting <ex>flashes</ex> vividly;
the powder <ex>flashed</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To break forth, as a sudden flood of light; to burst
instantly and brightly on the sight; to show a momentary brilliancy; to
come or pass like a flash.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Names which have <qex>flashed</qex> and thundered as the watch
words of unnumbered struggles.</q> <rj><qau>Talfourd.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The object is made to <qex>flash</qex> upon the eye of the
mind.</q> <rj><qau>M. Arnold.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A thought <qex>flashed</qex> through me, which I clothed in
act.</q> <rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To burst forth like a sudden flame; to break out
violently; to rush hastily.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Every hour<br/
He <qex>flashes</qex> into one gross crime or other.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>flash in the pan</b></col>, <cd>a failure or a poor
performance, especially after a normal or auspicious start; also, a
person whose initial performance appears augur success but who fails to
achieve anything notable. From 4th <er>pan</er>, <pos>n.</pos>, sense 3
-- part of a flintlock. Occasionally, the powder in the pan of a
flintlock would flash without conveying the fire to the charge, and the
ball would fail to be discharged. Thus, a good or even spectacular
beginning that eventually achieves little came to be called a <ex>flash
in the pan</ex>.</cd> -- <col><b>To flash in the pan</b></col>, <cd>to
fail of success, especially after a normal or auspicious start.
<mark>[Colloq.]</mark> See under <er>Flash</er>, a burst of light.</cd>
<rj><au>Bartlett.</au></rj></cs><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><syn><b>Syn.</b> -- <er>Flash</er>, <er>Glitter</er>, <er>Gleam</er>,
<er>Glisten</er>, <er>Glister</er>.</syn> <usage> <xex>Flash</xex>
differs from <xex>glitter</xex> and <xex>gleam</xex>, denoting a flood
or wide extent of light. The latter words may express the issuing of
light from a small object, or from a pencil of rays. <xex>Flash</xex>
differs from other words, also, in denoting suddenness of appearance and
disappearance. <xex>Flashing</xex> differs from <xex>exploding</xex> or
<xex>disploding</xex> in not being accompanied with a loud report. To
<xex>glisten</xex>, or <xex>glister</xex>, is to shine with a soft and
fitful luster, as eyes suffused with tears, or flowers wet with
dew.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flash</ent><br/
<hw>Flash</hw> <pr>(fl<acr/sh)</pr>, <pos>v. t.</pos> <sn>1.</sn>
<def>To send out in flashes; to cause to burst forth with sudden flame
or light.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The chariot of paternal Deity,<br/
<qex>Flashing</qex> thick flames.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To convey as by a flash; to light up, as by a sudden
flame or light; <as>as, to <ex>flash</ex> a message along the wires; to
<ex>flash</ex> conviction on the mind.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Glass Making)</fld> <def>To cover with a thin
layer, as objects of glass with glass of a different color. See
<er>Flashing</er>, <pos>n.</pos>, 3 <sd>(b)</sd>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To trick up in a showy manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Limning and <qex>flashing</qex> it with various dyes.</q>
<rj><qau>A. Brewer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <ety>[Perh. due to confusion between <ets>flash</ets> of
light and <ets>plash</ets>, <ets>splash</ets>.]</ety> <def>To strike and
throw up large bodies of water from the surface; to splash.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He rudely <qex>flashed</qex> the waves about.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Flashed glass</b></col>. <cd>See <er>Flashing</er>,
<pos>n.</pos>, 3.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flash</ent><br/
<hw>Flash</hw>, <pos>n.</pos>; <plu><it>pl.</it> <plw>Flashes</plw>
<pr>(<?/)</pr>.</plu> <sn>1.</sn> <def>A sudden burst of light; a flood
of light instantaneously appearing and disappearing; a momentary blaze;
<as>as, a <ex>flash</ex> of lightning</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A sudden and brilliant burst, as of wit or genius; a
momentary brightness or show.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>flash</qex> and outbreak of a fiery mind.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>No striking sentiment, no <qex>flash</qex> of fancy.</q>
<rj><qau>Wirt.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The time during which a flash is visible; an
instant; a very brief period; <as>as, I'll be back in a
<ex>flash</ex></as>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><q>The Persians and Macedonians had it for a <qex>flash</qex>.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A preparation of capsicum, burnt sugar, etc., for
coloring and giving a fictitious strength to liquors.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A lamp for providing intense momentary light to take
a photograph; <as>as, to take a picture without a
<ex>flash</ex></as>.</def><br/
<syn><b>Syn. --</b> flashbulb, photoflash, flash lamp,
flashgun.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>6.</sn> <def>Same as <er>flashlight</er>.</def>
<mark>[informal]</mark> <br/
[<source>PJC</source>]</p>

<p><sn>7.</sn> <fld>(Journalism)</fld> <def>A short news item providing
recently received and usually preliminary information about an event
that is considered important enough to interrupt normal broadcasting or
other news delivery services; also called a <altname>news
flash</altname> or <altname>bulletin</altname>.</def><br/
[<source>PJC</source>]</p>

<p><cs><mcol><col><b>Flash light</b></col>, <it>or</it> <col><b>Flashing
light</b></col></mcol>, <cd>a kind of light shown by lighthouses,
produced by the revolution of reflectors, so as to show a flash of light
every few seconds, alternating with periods of dimness.</cd>
<au>Knight.</au> -- <col><b>Flash in the pan</b></col>, <cd>the flashing
of the priming in the pan of a flintlock musket without discharging the
piece; hence, sudden, spasmodic effort that accomplishes
nothing.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flash</ent><br/
<hw>Flash</hw>, <pos>a.</pos> <sn>1.</sn> <def>Showy, but counterfeit;
cheap, pretentious, and vulgar; <as>as, <ex>flash</ex> jewelry;
<ex>flash</ex> finery.</as></def> <-- different from flashy[3]? Not much
used late 1900's. Perh. because of sense 2? --><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Wearing showy, counterfeit ornaments; vulgarly
pretentious; <as>as, <ex>flash</ex> people; <ex>flash</ex> men or
women</as>; -- applied especially to thieves, gamblers, and prostitutes
that dress in a showy way and wear much cheap jewelry.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Flash house</b></col>, <cd>a house frequented by flash
people, as thieves and whores; hence, a brothel.</cd> <ldquo/A gang of
footpads, reveling with their favorite beauties at a <xex>flash
house</xex>.<rdquo/ <rj><au>Macaulay.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flash</ent><br/
<hw>Flash</hw>, <pos>n.</pos> <def>Slang or cant of thieves and
prostitutes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flash</ent><br/
<hw>Flash</hw>, <pos>n.</pos> <ety>[OE. <ets>flasche</ets>,
<ets>flaske</ets>; cf. OF. <ets>flache</ets>, F.
<ets>flaque</ets>.]</ety> <sn>1.</sn> <def>A pool.</def> <mark>[Prov.
Eng.]</mark> <rj><au>Haliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Engineering)</fld> <def>A reservoir and sluiceway
beside a navigable stream, just above a shoal, so that the stream may
pour in water as boats pass, and thus bear them over the
shoal.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Flash wheel</b></col> <fld>(Mech.)</fld>, <cd>a paddle
wheel made to revolve in a breast or curved water way, by which water is
lifted from the lower to the higher level.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>flashback</ent><br/
<hw>flashback</hw> <pos>n.</pos> <sn>1.</sn> <def>a transition (in
literary or theatrical works or films) to an earlier event or scene;
also, the scene thus introduced.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>An unusually vivid recollection of a prior
experience, often one that is traumatic, such as scenes from combat or a
criminal assault, or induced by hallucinogenic drugs such as LSD; when
accompanied by hallucinations it is called <styp><ecol><b>flashback
hallucinosis</b></ecol></styp>.</def><br/
[<source>PJC</source>]</p>

<p><ent>flashbulb</ent><br/
<hw>flash"bulb`</hw> <pos>n.</pos> <def>a lamp for providing intense
momentary light to take a photograph.</def><br/
<syn><b>Syn. --</b> flash, photoflash, flash lamp, flashgun.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Flashboard</ent><br/
<hw>Flash"board`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A board placed
temporarily upon a milldam, to raise the water in the pond above its
usual level; a flushboard.</def> <mark>[U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flash boiler</ent><br/
<hw>Flash boiler</hw>. <def>A variety of water-tube boiler, used chiefly
in steam automobiles, consisting of a nest of strong tubes with very
little water space, kept nearly red hot so that the water as it trickles
drop by drop into the tubes is immediately flashed into steam and
superheated.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Flash burner</ent><br/
<hw>Flash burner</hw>. <def>A gas burner with a device for lighting by
an electric spark.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Flasher</ent><br/
<hw>Flash"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who,
or that which, flashes.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A man of more appearance of wit than
reality.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <sd>(a)</sd> <def>A large sparoid fish
of the Atlantic coast and all tropical seas (<spn>Lobotes
Surinamensis</spn>).</def> <sd>(b)</sd> <def>The European red-backed
shrike (<spn>Lanius collurio</spn>); -- called also
<altname>flusher</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>An exhibitionist{1}, especially a male, who briefly
exposes his private parts in a public place.</def><br/
[<source>PJC</source>]</p>

<p><ent>flash-frozen</ent><br/
<hw>flash-frozen</hw> <pos>adj.</pos> <def>preserved by freezing
sufficiently rapidly to retain flavor and nutritional value; -- used of
foods.</def><br/
<syn><b>Syn. --</b> quick-frozen, frozen.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>flashgun</ent><br/
<hw>flash"gun`</hw> <pos>n.</pos> <def>a lamp for providing intense
momentary light to take a photograph.</def><br/
<syn><b>Syn. --</b> flash, photoflash, flash lamp, flashbulb.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Flashily</ent><br/
<hw>Flash"i*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a flashy
manner; with empty show.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flashiness</ent><br/
<hw>Flash"i*ness</hw>, <pos>n.</pos> <def>The quality of being
flashy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flashing</ent><br/
<hw>Flash"ing</hw>, <pos>n.</pos> <sn>1.</sn> <fld>(Engineering)</fld>
<def>The creation of an artificial flood by the sudden letting in of a
body of water; -- called also <altname>flushing</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Arch.)</fld> <def>Pieces of metal, built into the
joints of a wall, so as to lap over the edge of the gutters or to cover
the edge of the roofing; also, similar pieces used to cover the valleys
of roofs of slate, shingles, or the like. By extension, the metal
covering of ridges and hips of roofs; also, in the United States, the
protecting of angles and breaks in walls of frame houses with waterproof
material, tarred paper, or the like. Cf. <er>Filleting</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Glass Making)</fld> <sd>(a)</sd> <def>The reheating
of an article at the furnace aperture during manufacture to restore its
plastic condition; esp., the reheating of a globe of crown glass to
allow it to assume a flat shape as it is rotated.</def> <sd>(b)</sd>
<def>A mode of covering transparent white glass with a film of colored
glass.</def> <rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Flashing point</b></col> <fld>(Chem.)</fld>, <cd>that
degree of temperature at which a volatile oil gives off vapor in
sufficient quantity to burn, or flash, on the approach of a flame, used
as a test of the comparative safety of oils, esp. kerosene; a flashing
point of 100<deg/ F. is regarded as a fairly safe standard. The burning
point of the oil is usually from ten to thirty degree above the flashing
point of its vapor. Usually called <altname>flash
point</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>flashlight</ent><br/
<hw>flash"light`</hw> <pos>n.</pos> <def>a portable battery-powered
electric lamp, small enough to be held in one hand; -- it is most
commonly cylindrical, but other forms are also made. It is called in
Britain a <altname>torch</altname></def><br/
<syn><b>Syn. --</b> torch.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Flash point</ent><br/
<hw>Flash" point`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>the
lowest temperature at which the vapors given off by a volatile liquid
exposed to air will burst into flame when approached by a flame. Also
called <altname><cref>flashing point</cref></altname>.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>That point in time or that degree of provocation at
which someone will suddenly begin to act vigorously; -- often used in
reference to angry reactions.</def><br/
[<source>PJC</source>]</p>

<p><ent>Flashy</ent><br/
<hw>Flash"y</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Dazzling
for a moment; making a momentary show of brilliancy; transitorily
bright.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A little <qex>flashy</qex> and transient pleasure.</q>
<rj><qau>Barrow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Fiery; vehement; impetuous.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A temper always <qex>flashy</qex>.</q>
<rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Showy; gay; gaudy; <as>as, a <ex>flashy</ex>
dress</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Without taste or spirit.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Lean and <qex>flashy</qex> songs.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flask</ent><br/
<hw>Flask</hw> <pr>(fl<acr/sk or fl<adot/sk)</pr>, <pos>n.</pos>
<ety>[AS. <ets>flasce</ets>, <ets>flaxe</ets>; akin to D.
<ets>flesch</ets>, OHG. <ets>flasca</ets>, G. <ets>flasche</ets>, Icel.
& Sw. <ets>flaska</ets>, Dan. <ets>flaske</ets>, OF. <ets>flasche</ets>,
LL. <ets>flasca</ets>, <ets>flasco</ets>; of uncertain origin; cf. L.
<ets>vasculum</ets>, dim. of <ets>vas</ets> a vessel, Gr.
<grk>fla`skh</grk>, <grk>fla`skwn</grk>, <grk>fla`skion</grk>. Cf.
<er>Flagon</er>, <er>Flasket</er>.]</ety> <sn>1.</sn> <def>A small
bottle-shaped vessel for holding fluids; <as>as, a <ex>flask</ex> of oil
or wine</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A narrow-necked vessel of metal or glass, used for
various purposes; as of sheet metal, to carry gunpowder in; or of
wrought iron, to contain quicksilver; or of glass, to heat water in,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A bed in a gun carriage.</def> <mark>[Obs.]</mark>
<rj><au>Bailey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Founding)</fld> <def>The wooden or iron frame which
holds the sand, etc., forming the mold used in a foundry; it consists of
two or more parts; viz., the <xex>cope</xex> or top; sometimes, the
<xex>cheeks</xex>, or middle part; and the <xex>drag</xex>, or bottom
part. When there are one or more cheeks, the flask is called a
<xex>three part flask</xex>, <xex>four part flask</xex>, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Erlenmeyer flask</b></col>, <cd>a thin glass flask,
flat-bottomed and cone-shaped to allow of safely shaking its contents
laterally without danger of spilling; -- so called from
<etsep>Erlenmeyer</etsep>, a German chemist who invented it.</cd> --
<col><b>Florence flask</b></col>. <ety>[From <ets>Florence</ets> in
Italy.]</ety> <sd>(a)</sd> <cd>Same as <er>Betty</er>, <pos>n.</pos>,
3.</cd> <sd>(b)</sd> <cd>A glass flask, round or pear-shaped, with round
or flat bottom, and usually very thin to allow of heating
solutions.</cd> -- <col><b>Pocket flask</b></col>, <cd>a kind of pocket
dram bottle, often covered with metal or leather to protect it from
breaking.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flasket</ent><br/
<hw>Flask"et</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. W.
<ets>fflasged</ets> a vessel of straw or wickerwork, <ets>fflasg</ets>
flask, basket, and E. <ets>flask</ets>.]</ety> <sn>1.</sn> <def>A long,
shallow basket, with two handles.</def> <mark>[Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>In which they gathered flowers to fill their
<qex>flasket</qex>.</q> <rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A small flask.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A vessel in which viands are served.</def>
<mark>[Obs.]</mark> <rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>flat-bottomed</ent><br/
<ent>flat-bottom</ent><br/
<mhw><hw>flat-bottom</hw> <hw>flat-bottomed</hw></mhw> <pos>adj.</pos>
<sn>1.</sn> <def>having a flat bottom.</def> <illu>a
<ex>flat-bottom</ex> boat</illu><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Flat</ent><br/
<hw>Flat</hw> <pr>(fl<acr/t)</pr>, <pos>a.</pos>
<amorph>[<pos>Compar.</pos> <adjf>Flatter</adjf>
<pr>(fl<acr/t"r<etil/r)</pr>; <pos>superl.</pos> <adjf>Flattest</adjf>
<pr>(fl<acr/t"t<ecr/st)</pr>.]</amorph> <ety>[Akin to Icel.
<ets>flatr</ets>, Sw. <ets>flat</ets>, Dan. <ets>flad</ets>, OHG.
<ets>flaz</ets>, and AS. <ets>flet</ets> floor, G. <ets>fl<oum/tz</ets>
stratum, layer.]</ety> <sn>1.</sn> <def>Having an even and horizontal
surface, or nearly so, without prominences or depressions; level without
inclination; plane.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Though sun and moon<br/
Were in the <qex>flat</qex> sea sunk.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Lying at full length, or spread out, upon the
ground; level with the ground or earth; prostrate; <as>as, to lie
<ex>flat</ex> on the ground</as>; hence, fallen; laid low; ruined;
destroyed.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>What ruins kingdoms, and lays cities <qex>flat</qex>!</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I feel . . . my hopes all <qex>flat</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Fine Arts)</fld> <def>Wanting relief; destitute of
variety; without points of prominence and striking interest.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A large part of the work is, to me, very <qex>flat</qex>.</q>
<rj><qau>Coleridge.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Tasteless; stale; vapid; insipid; dead; <as>as,
fruit or drink <ex>flat</ex> to the taste</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Unanimated; dull; uninteresting; without point or
spirit; monotonous; <as>as, a <ex>flat</ex> speech or
composition</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>How weary, stale, <qex>flat</qex>, and unprofitable<br/
Seem to me all the uses of this world.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Lacking liveliness of commercial exchange and
dealings; depressed; dull; <as>as, the market is
<ex>flat</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>Clear; unmistakable; peremptory; absolute; positive;
downright.</def><br/
<syn><b>Syn. --</b> flat-out.</syn><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Flat</qex> burglary as ever was committed.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A great tobacco taker too, -- that's <qex>flat</qex>.</q>
<rj><qau>Marston.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <fld>(Mus.)</fld> <sd>(a)</sd> <def>Below the true pitch;
hence, as applied to intervals, minor, or lower by a half step; <as>as,
a <ex>flat</ex> seventh; A <ex>flat</ex>.</as></def> <sd>(b)</sd>
<def>Not sharp or shrill; not acute; <as>as, a <ex>flat</ex>
sound</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <fld>(Phonetics)</fld> <def>Sonant; vocal; -- applied to
any one of the sonant or vocal consonants, as distinguished from a
nonsonant (or <xex>sharp</xex>) consonant.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <fld>(Golf)</fld> <def>Having a head at a very obtuse
angle to the shaft; -- said of a club.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>11.</sn> <fld>(Gram.)</fld> <def>Not having an inflectional
ending or sign, as a noun used as an adjective, or an adjective as an
adverb, without the addition of a formative suffix, or an infinitive
without the sign <xex>to</xex>. Many flat adverbs, as in run
<xex>fast</xex>, buy <xex>cheap</xex>, are from AS. adverbs in
<xex>-<eum/</xex>, the loss of this ending having made them like the
adjectives. Some having forms in <xex>ly</xex>, such as
<xex>exceeding</xex>, <xex>wonderful</xex>, <xex>true</xex>, are now
archaic.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>12.</sn> <fld>(Hort.)</fld> <def>Flattening at the ends; -- said
of certain fruits.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<cs><p><col><b>Flat arch</b></col>. <fld>(Arch.)</fld> <cd>See under
<er>Arch</er>, <pos>n.</pos>, 2. (<it>b</it>).</cd> -- <col><b>Flat
cap</b></col>, <cd>cap paper, not folded. See under <er>Paper</er>.</cd>
-- <col><b>Flat chasing</b></col>, <cd>in fine art metal working, a mode
of ornamenting silverware, etc., producing figures by dots and lines
made with a punching tool.</cd> <au>Knight.</au> -- <col><b>Flat
chisel</b></col>, <cd>a sculptor's chisel for smoothing.</cd> --
<col><b>Flat file</b></col>, <cd>a file wider than its thickness, and of
rectangular section. See <er>File</er>.</cd> -- <col><b>Flat
nail</b></col>, <cd>a small, sharp-pointed, wrought nail, with a flat,
thin head, larger than a tack.</cd> <au>Knight.</au> -- <col><b>Flat
paper</b></col>, <cd>paper which has not been folded.</cd> --
<col><b>Flat rail</b></col>, <cd>a railroad rail consisting of a simple
flat bar spiked to a longitudinal sleeper.</cd> -- <col><b>Flat
rods</b></col> <fld>(Mining)</fld>, <cd>horizontal or inclined
connecting rods, for transmitting motion to pump rods at a
distance.</cd> <au>Raymond.</au> -- <col><b>Flat rope</b></col>, <cd>a
rope made by plaiting instead of twisting; gasket; sennit.</cd>
<note>Some flat hoisting ropes, as for mining shafts, are made by sewing
together a number of ropes, making a wide, flat band</note>.
<au>Knight.</au> -- <col><b>Flat space</b></col>. <fld>(Geom.)</fld>
<cd>See <cref>Euclidian space</cref>.</cd> -- <mcol><col><b>Flat
stitch</b></col>, <cd>the process of wood engraving.</cd>
<mark>[Obs.]</mark> -- <col><b>Flat tint</b></col></mcol>
<fld>(Painting)</fld>, <cd>a coat of water color of one uniform
shade.</cd> -- <col><b>To fall flat</b></col> <mark>(Fig.)</mark>,
<cd>to produce no effect; to fail in the intended effect; <as>as, his
speech <ex>fell flat</ex></as>.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>Of all who fell by saber or by shot,<br/
Not one <qex>fell</qex> half so <qex>flat</qex> as Walter Scott.</q>
<rj><qau>Lord Erskine.</qau></rj><br/
[<source>1913 Webster</source>]</p></cs>

<p><ent>Flat</ent><br/
<hw>Flat</hw> <pr>(?)</pr>, <pos>adv.</pos> <sn>1.</sn> <def>In a flat
manner; directly; flatly.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Sin is <qex>flat</qex> opposite to the Almighty.</q>
<rj><qau>Herbert.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Stock Exchange)</fld> <def>Without allowance for
accrued interest.</def> <mark>[Broker's Cant]</mark><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 568 --></p>

<p><ent>Flat</ent><br/
<hw>Flat</hw>, <pos>n.</pos> <sn>1.</sn> <def>A level surface, without
elevation, relief, or prominences; an extended plain; specifically, in
the United States, a level tract along the along the banks of a river;
<as>as, the Mohawk <ex>Flats</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Envy is as the sunbeams that beat hotter upon a bank, or steep
rising ground, than upon a <qex>flat</qex>.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A level tract lying at little depth below the
surface of water, or alternately covered and left bare by the tide; a
shoal; a shallow; a strand.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Half my power, this night<br/
Passing these <qex>flats</qex>, are taken by the tide.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Something broad and flat in form</def>; as:
<sd>(a)</sd> <def>A flat-bottomed boat, without keel, and of small
draught.</def> <sd>(b)</sd> <def>A straw hat, broad-brimmed and
low-crowned.</def> <sd>(c)</sd> <fld>(Railroad Mach.)</fld> <def>A car
without a roof, the body of which is a platform without sides; a
platform car.</def> <sd>(d)</sd> <def>A platform on wheel, upon which
emblematic designs, etc., are carried in processions.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The flat part, or side, of anything; as, the broad
side of a blade, as distinguished from its edge.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Arch.)</fld> <def>A floor, loft, or story in a
building;</def> <specif>especially,</specif> <def>a floor of a house,
which forms a complete residence in itself; an apartment taking up a
whole floor. In this latter sense, the usage is more common in British
English.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>6.</sn> <fld>(Mining)</fld> <def>A horizontal vein or ore deposit
auxiliary to a main vein; also, any horizontal portion of a vein not
elsewhere horizontal.</def> <rj><au>Raymond.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>A dull fellow; a simpleton; a numskull.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Or if you can not make a speech,<br/
Because you are a <qex>flat</qex>.</q> <rj><qau>Holmes.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <fld>(Mus.)</fld> <def>A character [<flat/] before a
note, indicating a tone which is a half step or semitone
lower.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <fld>(Geom.)</fld> <def>A homaloid space or
extension.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flat</ent><br/
<hw>Flat</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Flatted</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Flatting</conjf> <pr>(?)</pr>.]</vmorph> <sn>1.</sn> <def>To make
flat; to flatten; to level.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To render dull, insipid, or spiritless; to
depress.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Passions are allayed, appetites are <qex>flatted</qex>.</q>
<rj><qau>Barrow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To depress in tone, as a musical note; especially,
to lower in pitch by half a tone.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flat</ent><br/
<hw>Flat</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To become flat, or
flattened; to sink or fall to an even surface.</def> <rj><au>Sir W.
Temple.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mus.)</fld> <def>To fall form the pitch.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To flat out</b></col>, <cd>to fail from a promising
beginning; to make a bad ending; to disappoint expectations.</cd>
<mark>[Colloq.]</mark></cs><-- = to fall flat --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flatbill</ent><br/
<hw>Flat"bill`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>Any bird of the genus <gen>Flatyrynchus</gen>. They belong to the
family of flycatchers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flatboat</ent><br/
<hw>Flat"boat`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A boat with a flat
bottom and square ends; -- used for the transportation of bulky freight,
especially in shallow waters.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>flat-bottomed</ent><br/
<ent>flat-bottom</ent><br/
<mhw><hw>flat"-bot`tom</hw> <hw>flat"-bot`tomed</hw></mhw> <pr>(?)</pr>,
<pos>a.</pos> <def>Having an even lower surface or bottom; <as>as, a
<ex>flat-bottomed</ex> boat</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flat-cap</ent><br/
<hw>Flat"-cap`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A kind of
low-crowned cap formerly worn by all classes in England, and continued
in London after disuse elsewhere; -- hence, a citizen of London.</def>
<rj><au>Marston.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>flatcar</ent><br/
<hw>flat"car`</hw> <pos>n.</pos> <fld>(Railroads)</fld> <def>a railroad
car without permanent sides or roof.</def><br/
<syn><b>Syn. --</b> flat.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Flatfish</ent><br/
<hw>Flat"fish`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>Any fish of the family <fam>Pleuronectid<ae/</fam>; esp., the
winter flounder (<spn>Pleuronectes Americanus</spn>). The flatfishes
have the body flattened, swim on the side, and have eyes on one side, as
the flounder, turbot, and halibut. See <er>Flounder</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>flatfoot</ent><br/
<ent>flat foot</ent><br/
<mhw><hw>flat" foot`</hw>, <hw>flat"foot`</hw></mhw> <pr>(?)</pr>.
<fld>(Med.)</fld> <def>A foot in which the arch of the instep is
flattened so that the entire sole of the foot rests upon the ground;
also, the deformity, usually congenital, exhibited by such a foot;
splayfoot.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>flatfoot</ent><br/
<hw>flat"foot`</hw> <pos>n.</pos> <def>a police officer, especially a
foot patrolman.</def> <mark>[slang]</mark><br/
[<source>PJC</source>]</p>

<p><ent>Flat-footed</ent><br/
<hw>Flat"-foot`ed</hw>, <pos>a.</pos> <sn>1.</sn> <def>Having a flat
foot, with little or no arch of the instep; suffering from fallen
arches.</def> <wns>[wns=3]</wns><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Firm-footed; determined.</def> <mark>[Slang,
U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>clumsy; amateurish; pedestrian; unimaginative;
plodding; <as>as, <ex>flatfooted</ex> prose</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <def>Without reservation; without evasion or compromise;
firm; <as>as, a <ex>flat-footed</ex> refusal; a <ex>flatfooted</ex>
denial</as>.</def> <wns>[wns=4]</wns><br/
<syn><b>Syn. --</b> downright, forthright, foursquare, head-on,
straightforward.</syn><br/
[<source>PJC</source>]</p>

<p><sn>5.</sn> <def>With feet flat on the ground; not tiptoe.</def>
<wns>[wns=1]</wns><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>6.</sn> <def>Unprepared and unable to react quickly; <as>as, the
new product caught their competitors <ex>flat-footed</ex></as>.</def>
<wns>[wns=2]</wns><br/
<syn><b>Syn. --</b> unready.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><cs><col><b>To catch (one) flatfooted</b></col> <cd>to catch (a
person) unprepared; to catch (a person) by surprise.</cd></cs><br/
[<source>PJC</source>]</p>

<p><ent>Flathead</ent><br/
<hw>Flat"head`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Characterized by
flatness of head, especially that produced by artificial means, as a
certain tribe of American Indians.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flathead</ent><br/
<hw>Flat"head`</hw>, <pos>n.</pos> <fld>(Ethnol.)</fld> <def>A Chinook
Indian. See <er>Chinook</er>, <pos>n.</pos>, 1.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flat-headed</ent><br/
<hw>Flat"-head`ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having a head
with a flattened top; <as>as, a <ex>flat-headed</ex>
nail</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flatiron</ent><br/
<hw>Flat"i`ron</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An iron with a
flat, smooth surface for ironing clothes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flative</ent><br/
<hw>Fla"tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>flare</ets>,
<ets>flatum</ets> to blow.]</ety> <def>Producing wind; flatulent.</def>
<mark>[Obs.]</mark> <rj><au>A. Brewer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flatling</ent><br/
<hw>Flat"ling</hw> <pr>(?)</pr>, <pos>adv.</pos> <ety>[<ets>Flat</ets>,
<pos>a.</pos> + adverbial suff. <ets>-ling</ets>.]</ety> <def>With the
flat side, as of a sword; flatlong; in a prostrate position.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flatlong</ent><br/
<hw>Flat"long</hw> <pr>(?; 115)</pr>, <pos>adv.</pos> <def>With the flat
side downward; not edgewise.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flatly</ent><br/
<hw>Flat"ly</hw>, <pos>adv.</pos> <sn>1.</sn> <def>In a flat manner;
evenly; horizontally; without spirit; dully; frigidly.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He that does the works of religion slowly, <qex>flatly</qex>, and
without appetite.</q> <rj><qau>Jer. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>peremptorily; positively; plainly;
forthrightly.</def> <ldquo/He <xex>flatly</xex> refused his aid.<rdquo/
<rj><au>Sir P. Sidney.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>flatmate</ent><br/
<hw>flat"mate`</hw> <pos>n.</pos> <def>someone who shares an apartment
with a person.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>flatness</ent><br/
<hw>flat"ness</hw>, <pos>n.</pos> <sn>1.</sn> <def>The quality or state
of being flat.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Evenness of surface; want of relief or prominence;
the state of being plane or level.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Want of vivacity or spirit; prostration; dejection;
depression.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Want of variety or flavor; dullness;
insipidity.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Depression of tone; the state of being below the
true pitch; -- opposed to <contr>sharpness</contr> or
<contr>acuteness</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flatour</ent><br/
<hw>Fla*tour"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.]</ety> <def>A
flatterer.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>flat-out</ent><br/
<hw>flat-out</hw> <pos>adj.</pos> <def>downright; plain; unqualified;
<as>as, a <ex>flat-out</ex> lie</as>.</def><br/
<syn><b>Syn. --</b> out-and-out, outright.</syn><br/
[<source>PJC</source>]</p>

<p><ent>Flatten</ent><br/
<hw>Flat"ten</hw> <pr>(fl<acr/t"t'n)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Flattened</conjf> <pr>(?)</pr>;
<pos>p. pr. & vb. n.</pos> <conjf>Flattening</conjf>.]</vmorph>
<ety>[From <er>Flat</er>, <pos>a.</pos>]</ety> <sn>1.</sn> <def>To
reduce to an even surface or one approaching evenness; to make flat; to
level; to make plane.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To throw down; to bring to the ground; to prostrate;
hence, to depress; to deject; to dispirit.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To make vapid or insipid; to render stale.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Mus.)</fld> <def>To lower the pitch of; to cause to
sound less sharp; to let fall from the pitch.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To flatten a sail</b></col> <fld>(Naut.)</fld>, <cd>to
set it more nearly fore-and-aft of the vessel.</cd> --
<col><b>Flattening oven</b></col>, <cd>in glass making, a heated chamber
in which split glass cylinders are flattened for window
glass.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flatten</ent><br/
<hw>Flat"ten</hw>, <pos>v. i.</pos> <def>To become or grow flat, even,
depressed, dull, vapid, spiritless, or depressed below pitch.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>flattened</ent><br/
<hw>flattened</hw> <pos>adj.</pos> <sn>1.</sn> <def>shaped like a thin
sheet.</def><br/
<syn><b>Syn. --</b> planate.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <fld>(Biol)</fld> <def>flattened laterally along the
whole length e.g. certain leafstalks or flatfishes.</def><br/
<syn><b>Syn. --</b> compressed, flat.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Flatter</ent><br/
<hw>Flat"ter</hw> <pr>(fl<acr/t"t<etil/r)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>One who, or that which, makes flat or
flattens.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Metal Working)</fld> <sd>(a)</sd> <def>A flat-faced
fulling hammer.</def> <sd>(b)</sd> <def>A drawplate with a narrow,
rectangular orifice, for drawing flat strips, as watch springs,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flatter</ent><br/
<hw>Flat"ter</hw> <pr>(fl<acr/t"t<etil/r)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Flattered</conjf> <pr>(?)</pr>;
<pos>p. pr. & vb. n.</pos> <conjf>Flattering</conjf>.]</vmorph>
<ety>[OE. <ets>flateren</ets>, cf. OD. <ets>flatteren</ets>; akin to G.
<ets>flattern</ets> to flutter, Icel. <ets>fla<edh/ra</ets> to fawn,
flatter: cf. F. <ets>flatter</ets>. Cf. <er>Flitter</er>,
<er>Flutter</er>, <er>Flattery</er>.]</ety> <sn>1.</sn> <def>To treat
with praise or blandishments; to gratify or attempt to gratify the
self-love or vanity of, esp. by artful and interested commendation or
attentions; to blandish; to cajole; to wheedle.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>When I tell him he hates flatterers,<br/
He says he does, being then most <qex>flattered</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A man that <qex>flattereth</qex> his neighbor, spreadeth a net for
his feet.</q> <rj><qau>Prov. xxix. 5.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Others he <qex>flattered</qex> by asking their advice.</q>
<rj><qau>Prescott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To raise hopes in; to encourage or favorable, but
sometimes unfounded or deceitful, representations.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To portray too favorably; to give a too favorable
idea of; <as>as, his portrait <ex>flatters</ex> him</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flatter</ent><br/
<hw>Flat"ter</hw>, <pos>v. i.</pos> <def>To use flattery or insincere
praise.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If it may stand him more in stead to lie,<br/
Say and unsay, feign, <qex>flatter</qex>, or adjure.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flatterer</ent><br/
<hw>Flat"ter*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
flatters.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The most abject <qex>flaterers</qex> degenerate into the greatest
tyrants.</q> <rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flattering</ent><br/
<hw>Flat"ter*ing</hw>, <pos>a.</pos> <def>That flatters (in the various
senses of the verb); <as>as, a <ex>flattering</ex>
speech</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Lay not that <qex>flattering</qex> unction to your soul.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>flattering</qex> painter, who made it his care,<br/
To draw men as they ought be, not as they are.</q>
<rj><qau>Goldsmith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flatteringly</ent><br/
<hw>Flat"ter*ing*ly</hw>, <pos>adv.</pos> <def>With flattery.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flattery</ent><br/
<hw>Flat"ter*y</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Flatteries</plw> <pr>(#)</pr>.</plu> <ety>[OE. <ets>flaterie</ets>,
OF. <ets>flaterie</ets>, F. <ets>flaterie</ets>, fr. <ets>flater</ets>
to flatter, F. <ets>flatter</ets>; of uncertain origin. See
<er>Flatter</er>, <pos>v. t.</pos>]</ety> <def>The act or practice of
flattering; the act of pleasing by artful commendation or compliments;
adulation; false, insincere, or excessive praise.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Just praise is only a debt, but <qex>flattery</qex> is a
present.</q> <rj><qau>Rambler.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Flattery</qex> corrupts both the receiver and the giver.</q>
<rj><qau>Burke.</qau></rj></p>

<p><syn><b>Syn.</b> -- Adulation; compliment; obsequiousness. See
<er>Adulation</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flatting</ent><br/
<hw>Flat"ting</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
process or operation of making flat, as a cylinder of glass by opening
it out.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A mode of painting,in which the paint, being mixed
with turpentine, leaves the work without gloss.</def>
<rj><au>Gwilt.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A method of preserving gilding unburnished, by
touching with size.</def> <rj><au>Knolles.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The process of forming metal into sheets by passing
it between rolls.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Flatting coat</b></col>, <cd>a coat of paint so put on as
to have no gloss.</cd> -- <col><b>Flatting furnace</b></col>. <cd>Same
as <cref>flattening oven</cref>, under <er>Flatten</er>.</cd> --
<col><b>Flatting mill</b></col>. <sd>(a)</sd> <cd>A rolling mill
producing sheet metal; esp., in mints, the mill producing the ribbon
from which the planchets are punched.</cd> <sd>(b)</sd> <cd>A mill in
which grains of metal are flatted by steel rolls, and reduced to
metallic dust, used for purposes of ornamentation.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flattish</ent><br/
<hw>Flat"tish</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Somewhat flat.</def>
<rj><au>Woodward.</au></rj></p>

<p><ent>flat-topped</ent><br/
<ent>flat-top</ent><br/
<mhw><hw>flat-top</hw> <hw>flat-topped</hw></mhw> <pos>adj.</pos>
<sn>1.</sn> <def>having a flat or flattened upper surface.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>flattop</ent><br/
<hw>flat"top`</hw> <pos>n.</pos> <fld>(Mil.)</fld> <def>An aircraft
carrier.</def><br/
[<source>PJC</source>]</p>

<p><ent>Flatulency</ent><br/
<ent>Flatulence</ent><br/
<mhw>{ <hw>Flat"u*lence</hw> <pr>(?)</pr>, <hw>Flat"u*len*cy</hw>
<pr>(?)</pr> }</mhw>, <pos>n.</pos> <ety>[Cf. F.
<ets>flatulence</ets>.]</ety> <def>The state or quality of being
flatulent.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flatulent</ent><br/
<hw>Flat"u*lent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>flatus</ets> a blowing, <ets>flatus ventris</ets> windiness,
flatulence, fr. <ets>flare</ets> to blow: cf. F. <ets>flatulent</ets>.
See <er>Blow</er>.]</ety> <sn>1.</sn> <def>Affected with flatus{2} or
gases generated in the alimentary canal; windy.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Generating, or tending to generate, wind in the
stomach.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Vegetables abound more with a<eum/rial particles than animal
substances, and therefore are more <qex>flatulent</qex>.</q>
<rj><qau>Arbuthnot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Turgid with flatus; <as>as, a <ex>flatulent</ex>
tumor</as>.</def> <rj><au>Quincy.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Pretentious without substance or reality; puffy;
empty; vain; <as>as, a <ex>flatulent</ex> vanity</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He is too <qex>flatulent</qex> sometimes, and sometimes too
dry.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flatulently</ent><br/
<hw>Flat"u*lent*ly</hw>, <pos>adv.</pos> <def>In a flatulent manner;
with flatulence.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flatuosity</ent><br/
<hw>Flat`u*os"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>flatuosit<eacute/</ets>.]</ety> <def>Flatulence.</def>
<mark>[Obs.]</mark> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flatuous</ent><br/
<hw>Flat"u*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>flatueux</ets>.]</ety> <def>Windy; generating wind.</def>
<mark>[Obs.]</mark> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flatus</ent><br/
\'d8<hw>Fla"tus</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it> E.
<plw>Flatuses</plw> <pr>(#)</pr>, L. <plw>Flatus</plw>.</plu> <ety>[L.,
fr. <ets>flare</ets> to blow.]</ety> <sn>1.</sn> <def>A breath; a puff
of wind.</def> <rj><au>Clarke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Gas generated in the stomach, intestine, or other
cavities of the body.</def> <rj><au>Quincy.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>flatware</ent><br/
<hw>flat"ware`</hw> <pos>n.</pos> <def>eating utensils such as knives,
forks, and spoons, considered collectively.</def><br/
<syn><b>Syn. --</b> silver.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Flatwise</ent><br/
<hw>Flat"wise`</hw> <pr>(?)</pr>, <pos>a. <or/ adv.</pos> <def>With the
flat side downward, or next to another object; not edgewise.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>flatwork</ent><br/
<hw>flatwork</hw> <pos>n.</pos> <def>Ironing that can be done
mechanically.</def><br/
<syn><b>Syn. --</b> flat wash.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Flatworm</ent><br/
<hw>Flat"worm`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>Any worm belonging to the <phylum>Platyhelminthes</phylum>; also,
sometimes applied to the planarians.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flaundrish</ent><br/
<hw>Flaun"drish</hw> <pr>(? <or/ ?)</pr>, <pos>a.</pos>
<def>Flemish.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flaunt</ent><br/
<hw>Flaunt</hw> <pr>(fl<aum/nt <or/ fl<add/nt; 277)</pr>, <pos>v.
i.</pos> <vmorph>[<pos>imp. & p. p.</pos> <conjf>Flaunted</conjf>;
<pos>p. pr. & vb. n.</pos>. <conjf>Flaunting</conjf>.]</vmorph>
<ety>[Cf. dial. G. <ets>flandern</ets> to flutter, wave; perh. akin to
E. <ets>flatter</ets>, <ets>flutter</ets>.]</ety> <def>To throw or
spread out; to flutter; to move ostentatiously; <as>as, a
<ex>flaunting</ex> show</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>You <qex>flaunt</qex> about the streets in your new gilt
chariot.</q> <rj><qau>Arbuthnot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>One <qex>flaunts</qex> in rags, one flutters in brocade.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flaunt</ent><br/
<hw>Flaunt</hw>, <pos>v. t.</pos> <def>To display ostentatiously; to
make an impudent show of.</def> <ldquo/If you've got it,
<xex>flaunt</xex> it.<rdquo/<br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Flaunt</ent><br/
<hw>Flaunt</hw>, <pos>n.</pos> <def>Anything displayed for show.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>In these my borrowed <qex>flaunts</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flauntingly</ent><br/
<hw>Flaunt"ing*ly</hw>, <pos>adv.</pos> <def>In a flaunting
way.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flautist</ent><br/
<hw>Flau"tist</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[It.
<ets>flauto</ets> a flute See <er>Flute</er>.]</ety> <def>A player on
the flute; a flutist.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flauto</ent><br/
\'d8<hw>Flau"to</hw> <pr>(flou"t<osl/)</pr>, <pos>n.</pos>
<ety>[It.]</ety> <def>A flute.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Flauto piccolo</b></col> <pr>(<?/)</pr> <ety>[It., little
flute]</ety>, <cd>an octave flute.</cd> -- <col><b>Flauto
traverso</b></col> <pr>(<?/)</pr> <ety>[It., transverse flute]</ety>,
<cd>the German flute, held laterally, instead of being played, like the
old <contr>fl<ucir/te <agrave/ bec</contr>, with a mouth piece at the
end.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flavaniline</ent><br/
<hw>Fla*van"i*line</hw> <pr>(? <or/ ?; 104)</pr>, <pos>n.</pos> <ety>[L.
<ets>flavus</ets> yellow + E. <ets>aniline</ets>.]</ety>
<fld>(Chem.)</fld> <def>A yellow, crystalline, organic dyestuff,
<chform>C16H14N2</chform>, of artificial production. It is a strong
base, and is a complex derivative of aniline and quinoline.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flavescent</ent><br/
<hw>Fla*ves"cent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>flavescens</ets>, p. pr. of <ets>flavescere</ets> to turn
yellow.]</ety> <def>Turning yellow; yellowish.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flavicomous</ent><br/
<hw>Fla*vic"o*mous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>flavicomus</ets>; <ets>flavus</ets> yellow + <ets>coma</ets>
hair.]</ety> <def>Having yellow hair.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flavin</ent><br/
<hw>Fla"vin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>flavus</ets>
yellow.]</ety> <fld>(Chem.)</fld> <def>A yellow, vegetable dyestuff,
resembling quercitron.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flavine</ent><br/
<hw>Fla"vine</hw> <pr>(?; 104)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>A yellow, crystalline, organic base, <chform>C13H12N2O</chform>,
obtained artificially.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flavol</ent><br/
<hw>Fla"vol</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>flavus</ets>
yellow + <ets>-oil</ets>.]</ety> <fld>(Chem.)</fld> <def>A yellow,
crystalline substance, obtained from anthraquinone, and regarded as a
hydroxyl derivative of it.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flavor</ent><br/
<hw>Fla"vor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF. <ets>fleur</ets>,
<ets>flaur</ets> (two syllables), odor, cf. F. <ets>fleurer</ets> to
emit an odor, It. <ets>flatore</ets> a bad odor, prob. fr. L.
<ets>flare</ets> to bow, whence the sense of <ets>exhalation</ets>. Cf.
<er>Blow</er>.]</ety> <altsp>[Written also <asp>flavour</asp>.]</altsp>
<sn>1.</sn> <def>That quality of anything which affects the smell; odor;
fragrances; <as>as, the <ex>flavor</ex> of a rose</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That quality of anything which affects the taste;
that quality which gratifies the palate; relish; zest; savor; <as>as,
the <ex>flavor</ex> of food or drink</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which imparts to anything a peculiar odor or
taste, gratifying to the sense of smell, or the nicer perceptions of the
palate; a substance which flavors.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>That quality which gives character to any of the
productions of literature or the fine arts.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flavor</ent><br/
<hw>Fla"vor</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Flavored</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Flavoring</conjf>.]</vmorph> <def>To give flavor to; to add
something (as salt or a spice) to, to give character or zest.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flavored</ent><br/
<hw>Fla"vored</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having a distinct
flavor; <as>as, high-<ex>flavored</ex> wine</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>flavorful</ent><br/
<hw>flavorful</hw> <pos>adj.</pos> <def>tasteful; having a good taste;
-- of food.</def> <ant>tasteless</ant><br/
<syn><b>Syn. --</b> flavourful, flavorous, flavourous, flavorsome,
flavoursome, sapid, saporous.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>flavoring</ent><br/
<hw>flavoring</hw> <pos>n.</pos> <def>something added to food primarily
for the savor it imparts.</def><br/
<syn><b>Syn. --</b> flavorer, flavourer, flavouring, seasoner,
seasoning.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>flavorless</ent><br/
<hw>fla"vor*less</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Without flavor;
tasteless. Opposite of <ant>flavorful</ant>.</def><br/
<syn><b>Syn. --</b> bland, flat, flavourless, insipid,
savorless.</syn><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><ent>Flavorous</ent><br/
<hw>Fla"vor*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Imparting flavor;
pleasant to the taste or smell; sapid.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>flavour</ent><br/
<hw>flavour</hw> <pos>v. t.</pos> <def>same as <er>flavor</er>,
<pos>v.</pos> and <pos>n.</pos>.</def> <mark>[Chiefly Brit.]</mark><br/
<syn><b>Syn. --</b> season, flavor, give flavor.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>flavoured</ent><br/
<hw>flavoured</hw> <pos>adj.</pos> <def>same as <er>flavored</er>; -- of
foods.</def> <mark>[Chiefly Brit.]</mark><br/
<syn><b>Syn. --</b> flavored, seasoned.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>flavourer</ent><br/
<hw>flavourer</hw> <pos>n.</pos> <def>same as <er>flavoring</er>.</def>
<mark>[Chiefly Brit.]</mark><br/
<syn><b>Syn. --</b> flavorer, flavoring, flavouring, seasoner,
seasoning.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>flavourful</ent><br/
<hw>flavourful</hw> <pos>adj.</pos> <def>same as
<er>flavorful</er>.</def> <mark>[Chiefly Brit.]</mark><br/
<syn><b>Syn. --</b> flavorful, flavorous, flavourous, flavorsome,
flavoursome, sapid, saporous.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>flavouring</ent><br/
<hw>flavouring</hw> <pos>n.</pos> <def>same as <er>flavoring</er>.</def>
<mark>[Chiefly Brit.]</mark><br/
<syn><b>Syn. --</b> flavorer, flavourer, flavoring, seasoner,
seasoning.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>flavourless</ent><br/
<hw>flavourless</hw> <pos>adj.</pos> <def>same as
<er>flavorless</er>.</def> <mark>[Chiefly Brit.]</mark><br/
<syn><b>Syn. --</b> bland, flat, flavorless, insipid,
savorless.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>flavourous</ent><br/
<hw>flavourous</hw> <pos>adj.</pos> <def>same as
<er>flavorful</er>.</def> <mark>[Chiefly Brit.]</mark><br/
<syn><b>Syn. --</b> flavorful, flavourful, flavorous, flavorsome,
flavoursome, sapid, saporous.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>flavoursome</ent><br/
<hw>flavoursome</hw> <pos>adj.</pos> <def>same as
<er>flavorful</er>.</def> <mark>[Chiefly Brit.]</mark><br/
<syn><b>Syn. --</b> flavorful, flavourful, flavorous, flavourous,
flavorsome, sapid, saporous.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Flavous</ent><br/
<hw>Fla"vous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>flavus</ets>.]</ety> <def>Yellow.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flaw</ent><br/
<hw>Flaw</hw> <pr>(fl<add/)</pr>, <pos>n.</pos> <ety>[OE.
<ets>flai</ets>, <ets>flaw</ets> flake; cf. Sw. <ets>flaga</ets> flaw,
crack, breach, flake, D. <ets>vlaag</ets> gust of wind, Norw.
<ets>flage</ets>, <ets>flaag</ets>, and E. <ets>flag</ets> a flat
stone.]</ety> <sn>1.</sn> <def>A crack or breach; a gap or fissure; a
defect of continuity or cohesion; <as>as, a <ex>flaw</ex> in a knife or
a vase</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This heart<br/
Shall break into a hundered thousand <qex>flaws</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A defect; a fault; <as>as, a <ex>flaw</ex> in
reputation; a <ex>flaw</ex> in a will, in a deed, or in a
statute.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Has not this also its <qex>flaws</qex> and its dark side?</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A sudden burst of noise and disorder; a tumult;
uproar; a quarrel.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>And deluges of armies from the town<br/
Came pouring in; I heard the mighty <qex>flaw</qex>.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A sudden burst or gust of wind of short
duration.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Snow, and hail, and stormy gust and <qex>flaw</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Like <qex>flaws</qex> in summer laying lusty corn.</q>
<rj><qau>Tennyson.</qau></rj></p>

<p><syn><b>Syn.</b> -- Blemish; fault; imperfection; spot;
speck.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flaw</ent><br/
<hw>Flaw</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Flawed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Flawing</conjf>.]</vmorph> <sn>1.</sn> <def>To crack; to make
flaws in.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The brazen caldrons with the frosts are <qex>flawed</qex>.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To break; to violate; to make of no effect.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>France hath <qex>flawed</qex> the league.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>flawed</ent><br/
<hw>flawed</hw> <pr>(fl<add/d)</pr>, <pos>a.</pos> <def>having flaws or
imperfections; not perfect; -- applied broadly; <as>as, a
<ex>flawed</ex> vase; a <ex>flawed</ex> performance; a <ex>flawed</ex>
character</as>.</def><br/
<syn><b>Syn. --</b> blemished.</syn><br/
[<source>PJC</source>]</p>

<p><ent>Flawless</ent><br/
<hw>Flaw"less</hw>, <pos>a.</pos> <def>Free from flaws.</def>
<rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flawn</ent><br/
<hw>Flawn</hw> <pr>(fl<add/n)</pr>, <pos>n.</pos> <ety>[OF.
<ets>flaon</ets>, F. <ets>flan</ets>, LL. <ets>flado</ets>, fr. OHG.
<ets>flado</ets>, G. <ets>fladen</ets>, a sort of pancake; cf. Gr. <?/
broad. See <er>Place</er>.]</ety> <def>A sort of flat custard or
pie.</def> <mark>[Obs.]</mark> <rj><au>Tusser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flawter</ent><br/
<hw>Flaw"ter</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Cf.
<er>Flay</er>.]</ety> <def>To scrape or pare, as a skin.</def>
<mark>[Obs.]</mark> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flawy</ent><br/
<hw>Flaw"y</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Full of
flaws or cracks; broken; defective; faulty.</def>
<rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Subject to sudden flaws or gusts of wind.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flax</ent><br/
<hw>Flax</hw> <pr>(fl<acr/ks)</pr>, <pos>n.</pos> <ety>[AS.
<ets>fleax</ets>; akin to D. <ets>vlas</ets>, <ets>OHG</ets>.
<ets>flahs</ets>, G. <ets>flachs</ets>, and prob. to <ets>flechten</ets>
to braid, plait,m twist, L. <ets>plectere</ets> to weave,
<ets>plicare</ets> to fold, Gr. <?/ to weave, plait. See
<er>Ply</er>.]</ety> <sn>1.</sn> <fld>(Bot.)</fld> <def>A plant of the
genus <gen>Linum</gen>, esp. the <spn>L. usitatissimum</spn>, which has
a single, slender stalk, about a foot and a half high, with blue
flowers. The fiber of the bark is used for making thread and cloth,
called <xex>linen</xex>, <xex>cambric</xex>, <xex>lawn</xex>,
<xex>lace</xex>, etc. Linseed oil is expressed from the seed.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The skin or fibrous part of the flax plant, when
broken and cleaned by hatcheling or combing.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Earth flax</b></col> <fld>(Min.)</fld>,
<cd>amianthus.</cd> -- <col><b>Flax brake</b></col>, <cd>a machine for
removing the woody portion of flax from the fibrous.</cd> --
<col><b>Flax comb</b></col>, <cd>a hatchel, hackle, or heckle.</cd> --
<col><b>Flax cotton</b></col>, <cd>the fiber of flax, reduced by
steeping in bicarbonate of soda and acidulated liquids, and prepared for
bleaching and spinning like cotton.</cd> <au>Knight.</au> --
<col><b>Flax dresser</b></col>, <cd>one who breaks and swingles flax, or
prepares it for the spinner.</cd> -- <col><b>Flax mill</b></col>, <cd>a
mill or factory where flax is spun or linen manufactured.</cd> --
<col><b>Flax puller</b></col>, <cd>a machine for pulling flax plants in
the field.</cd> -- <col><b>Flax wench</b></col>. <sd>(a)</sd> <cd>A
woman who spins flax.</cd> <mark>[Obs.]</mark> <sd>(b)</sd> <cd>A
prostitute.</cd> <mark>[Obs.]</mark> <au>Shak.</au> -- <col><b>Mountain
flax</b></col> <fld>(Min.)</fld>, <cd>amianthus.</cd> -- <col><b>New
Zealand flax</b></col> <fld>(Bot.)</fld> <cd>See
<er>Flax-plant</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flaxen</ent><br/
<hw>Flax"en</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Made of flax;
resembling flax or its fibers; of the color of flax; of a light soft
straw color; fair and flowing, like flax or tow; <as>as, <ex>flaxen</ex>
thread; <ex>flaxen</ex> hair.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flax-plant</ent><br/
<hw>Flax"-plant`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>A plant in new Zealand (<spn>Phormium tenax</spn>), allied to the
lilies and aloes. The leaves are two inches wide and several feet long,
and furnish a fiber which is used for making ropes, mats, and coarse
cloth.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flaxseed</ent><br/
<hw>Flax"seed`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The seed of the
flax; linseed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flaxweed</ent><br/
<hw>Flax"weed`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>See <er>Toadflax</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flaxy</ent><br/
<hw>Flax"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Like flax;
flaxen.</def> <rj><au>Sir M. Sandys.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flay</ent><br/
<hw>Flay</hw> <pr>(fl<amac/)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Flayed</conjf> <pr>(fl<amac/d)</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>Flaying</conjf>.]</vmorph> <ety>[OE.
<ets>flean</ets>, <ets>flan</ets>, AS. <ets>fle<aacute/n</ets>; akin to
D. <ets>vlaen</ets>, Icel. <ets>fl<amac/</ets>, Sw.
<ets>fl<aring/</ets>, Dan. <ets>flaae</ets>, cf. Lith.
<ets>pleszti</ets> to tear, <ets>plyszti</ets>, v.i., to burst, tear;
perh. akin to E. <ets>flag</ets> a flat stone, <ets>flaw</ets>.]</ety>
<def>To skin; to strip off the skin or surface of; <as>as, to
<ex>flay</ex> an ox; to <ex>flay</ex> the green earth.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>With her nails<br/
She 'll <qex>flay</qex> thy wolfish visage.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 569 --></p>

<p><ent>Flayer</ent><br/
<hw>Flay"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who strips off the
skin.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flea</ent><br/
<hw>Flea</hw> <pr>(fl<emac/)</pr>, <pos>v. t.</pos> <ety>[See
<er>Flay</er>.]</ety> <def>To flay.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He will be <qex>fleaed</qex> first<br/
And horse collars made of's skin.</q> <rj><qau>J.
Fletcher.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flea</ent><br/
<hw>Flea</hw>, <pos>n.</pos> <ety>[OE. <ets>fle</ets>, <ets>flee</ets>,
AS. <ets>fle<aacute/</ets>, <ets>fle<aacute/h</ets>; akin to D.
<ets>vtoo</ets>, OHG. <ets>fl<omac/h</ets>, G. <ets>floh</ets>, Icel.
<ets>fl<omac/</ets>, Russ. <ets>blocha</ets>; prob. from the root of E.
<ets>flee</ets>. <root/84. See <er>Flee</er>.]</ety> <fld>(Zool.)</fld>
<def>An insect belonging to the genus <gen>Pulex</gen>, of the order
<ord>Aphaniptera</ord>. Fleas are destitute of wings, but have the power
of leaping energetically. The bite is poisonous to most persons. The
human flea (<spn>Pulex irritans</spn>), abundant in Europe, is rare in
America, where the dog flea (<spn>Ctenocephalides canis</spn>, formerly
<spn>Pulex canis</spn>) and the smaller cat flea (<spn>Ctenocephalides
felis</spn>) take its place. See <er>Aphaniptera</er>, and <er>Dog
flea</er>. See <xex>Illustration</xex> in Appendix.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>A flea in the ear</b></col>, <cd>an unwelcome hint or
unexpected reply, annoying like a flea; an irritating repulse; as, to
put a <xex>flea in one's ear</xex>; to go away with <xex>a flea in one's
ear</xex>.</cd> -- <mcol><col><b>Beach flea</b></col>, <col><b>Black
flea</b></col></mcol>, <cd>etc. See under <er>Beach</er>,
etc.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fleabane</ent><br/
<hw>Flea"bane`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>One of various plants, supposed to have efficacy in driving away
fleas. They belong, for the most part, to the genera <gen>Conyza</gen>,
<gen>Erigeron</gen>, and <gen>Pulicaria</gen>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flea-beetle</ent><br/
<hw>Flea"-bee`tle</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>A small beetle of the family <fam>Halticid<ae/</fam>, of many
species. They have strong posterior legs and leap like fleas. The turnip
flea-beetle (<spn>Phyllotreta vittata</spn>) and that of the grapevine
(<spn>Graptodera chalybea</spn>) are common injurious species.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flea-bite</ent><br/
<hw>Flea"-bite`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
bite of a flea, or the red spot caused by the bite.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A trifling wound or pain, like that of the bite of a
flea.</def> <rj><au>Harvey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>flea-bitten</ent><br/
<hw>flea"-bit`ten</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Bitten by a flea; <as>as, a <ex>flea-bitten</ex>
face</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>White, flecked with minute dots of bay or sorrel; --
said of the color of a horse.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>same as <er>creaky</er>, 1.</def>
<wns>[wns=1]</wns><br/
<syn><b>Syn. --</b> creaky, decrepit, run-down, rundown,
woebegone.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fleagh</ent><br/
<hw>Fleagh</hw> <pr>(fl<emac/)</pr>, <mark>obs.</mark>
<def><pos>imp.</pos> of <er>Fly</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fleak</ent><br/
<hw>Fleak</hw> <pr>(fl<emac/k)</pr>, <pos>n.</pos> <def>A flake; a
thread or twist.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Little long <qex>fleaks</qex> or threads of hemp.</q> <rj><qau>Dr.
H. More.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fleaking</ent><br/
<hw>Fleak"ing</hw>, <pos>n.</pos> <def>A light covering of reeds, over
which the main covering is laid, in thatching houses.</def> <mark>[Prov.
Eng.]</mark> <rj><au>Wright.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flea-louse</ent><br/
<hw>Flea"-louse`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>A jumping plant louse of the family <fam>Psyllid<ae/</fam>, of many
species. That of the pear tree is <spn>Psylla pyri</spn>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fleam</ent><br/
<hw>Fleam</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>flamme</ets>,
OF. <ets>flieme</ets>, fr. LL. <ets>flevotomum</ets>,
<ets>phlebotomum</ets>; cf. D. <ets>vlijm</ets>. See
<er>Phlebotomy</er>.]</ety> <fld>(Surg. & Far.)</fld> <def>A sharp
instrument used for opening veins, lancing gums, etc.; a kind of
lancet.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fleam tooth</b></col>, <cd>a tooth of a saw shaped like
an isosceles triangle; a peg tooth.</cd>
<rj><au>Knight.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fleamy</ent><br/
<hw>Fleam"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Bloody; clotted.</def>
<mark>[Obs. or Prov.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Foamy bubbling of a <qex>fleamy</qex> brain.</q>
<rj><qau>Marston.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flear</ent><br/
<hw>Flear</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <def>See
<er>Fleer</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fleawort</ent><br/
<hw>Flea"wort`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>An herb used in medicine (<spn>Plantago Psyllium</spn>), named from
the shape of its seeds.</def> <rj><au>Loudon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fleche</ent><br/
\'d8<hw>Fl<egrave/che</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>fl<egrave/che</ets>, prop., an arrow.]</ety> <fld>(Fort.)</fld>
<def>A simple fieldwork, consisting of two faces forming a salient angle
pointing outward and open at the gorge.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fleck</ent><br/
<hw>Fleck</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A flake; also, a lock,
as of wool.</def> <mark>[Obs.]</mark> <rj><au>J. Martin.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fleck</ent><br/
<hw>Fleck</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. Icel.
<ets>flekkr</ets>; akin to Sw. <ets>fl<aum/ck</ets>, D. <ets>vlek</ets>,
G. <ets>fleck</ets>, and perh. to E. <ets>flitch</ets>.]</ety> <def>A
spot; a streak; a speckle.</def> <ldquo/A sunny <xex>fleck</xex>.<rdquo/
<rj><au>Longfellow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Life is dashed with <qex>flecks</qex> of sin.</q>
<rj><qau>tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fleck</ent><br/
<hw>Fleck</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Flecked</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Flecking</conjf>.]</vmorph> <ety>[Cf. Icel. <ets>flekka</ets>,
Sw. <ets>fl<aum/cka</ets>, D. <ets>vlekken</ets>, <ets>vlakken</ets>, G.
<ets>flecken</ets>. See <er>Fleck</er>, <pos>n.</pos>]</ety> <def>To
spot; to streak or stripe; to variegate; to dapple.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Both <qex>flecked</qex> with white, the true Arcadian strain.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A bird, a cloud, <qex>flecking</qex> the sunny air.</q>
<rj><qau>Trench.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flecker</ent><br/
<hw>Fleck"er</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To fleck.</def>
<rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fleckless</ent><br/
<hw>Fleck"less</hw>, <pos>a.</pos> <def>Without spot or blame.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>My consnience will not count me <qex>fleckless</qex>.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flection</ent><br/
<hw>Flec"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Flexion</er>.]</ety> <sn>1.</sn> <def>The act of bending, or state
of being bent.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The variation of words by declension, comparison, or
conjugation; inflection.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flectional</ent><br/
<hw>Flec"tion*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of, or
pertaining to, flection or inflection.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>flectional</qex> word is a phrase in the bud.</q>
<rj><qau>Earle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flector</ent><br/
<hw>Flec"tor</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A flexor.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fled</ent><br/
<hw>Fled</hw> <pr>(?)</pr>, <def><pos>imp. & p. p.</pos> of
<er>Flee</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fledge</ent><br/
<hw>Fledge</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OE. <ets>flegge</ets>,
<ets>flygge</ets>; akin to D. <ets>vlug</ets>, G. <ets>fl<uum/gge</ets>,
<ets>fl<uum/cke</ets>, OHG. <ets>flucchi</ets>, Icel. <ets>fleygr</ets>,
and to E. <ets>fly</ets>. <root/84. See <er>Fly</er>, <pos>v.
i.</pos>]</ety> <def>Feathered; furnished with feathers or wings; able
to fly.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His shoulders, <qex>fledge</qex> with wings.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fledge</ent><br/
<hw>Fledge</hw>, <pos>v. t. & i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Fledged</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Fledging</conjf>.]</vmorph> <sn>1.</sn> <def>To furnish with
feathers; to supply with the feathers necessary for flight.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The birds were not as yet <qex>fledged</qex> enough to shift for
themselves.</q> <rj><qau>L'Estrange.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To furnish or adorn with any soft
covering.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Your master, whose chin is not yet <qex>fledged</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>fledged</ent><br/
<hw>fledged</hw> <pos>adj.</pos> <sn>1.</sn> <def>having developed
feathers or plumage; often used in combination; -- of birds.</def>
[Narrower terms: <stype>fledgling(prenominal),
fledgeling(prenominal)</stype>] <ant>unfledged</ant><br/
<syn><b>Syn. --</b> mature.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>equipped with feathers; -- of an arrow.</def><br/
<syn><b>Syn. --</b> vaned.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>fledgeless</ent><br/
<hw>fledgeless</hw> <pos>adj.</pos> <def>not equipped with feathers; --
of an arrow.</def><br/
<syn><b>Syn. --</b> unfledged, unvaned.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>fledgling</ent><br/
<ent>fledgeling</ent><br/
<mhw><hw>fledgeling</hw>, <hw>fledgling</hw></mhw> <pos>n.</pos> <def>a
new member of a group.</def><br/
<syn><b>Syn. --</b> newcomer, fledgeling, starter, neophyte, freshman,
entrant.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>A young bird just fledged.</def>
<wns>[wns=2]</wns><br/
[<source>1913 Webster</source>]</p>

<p><ent>fledgling</ent><br/
<hw>fledgling</hw> <pos>adj.</pos> <sn>1.</sn> <def>having just acquired
its flight feathers; -- of a young bird; <as>as, a <ex>fledgling</ex>
robin</as>.</def> <mark>[prenominal]</mark><br/
<syn><b>Syn. --</b> fledgeling(prenominal).</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>young and inexperienced; <as>as, a
<ex>fledgling</ex> enterprise; a <ex>fledgling</ex>
skier</as>.</def><br/
<syn><b>Syn. --</b> unfledged.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Flee</ent><br/
<hw>Flee</hw> <pr>(fl<emac/)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Fled</conjf> <pr>(fl<ecr/d)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Fleeing</conjf>.]</vmorph> <ety>[OE. <ets>fleon</ets>,
<ets>fleen</ets>, AS. <ets>fle<oacute/n</ets> (<ets>imperf</ets>.
<ets>fle<aacute/h</ets>); akin to D. <ets>vlieden</ets>, OHG. & OS.
<ets>fliohan</ets>, G. <ets>fliehen</ets>, Icel. <ets>fl<ymac/ja</ets>
(imperf. <ets>fl<ymac/<edh/i</ets>), Dan. <ets>flye</ets>, Sw.
<ets>fly</ets> (imperf. <ets>flydde</ets>), Goth.
<ets><thorn/liuhan</ets>. <root/84. Cf. <er>Flight</er>.]</ety> <def>To
run away, as from danger or evil; to avoid in an alarmed or cowardly
manner; to hasten off; -- usually with <xex>from</xex>. This is
sometimes omitted, making the verb transitive.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>[He] cowardly <qex>fled</qex>, not having struck one stroke.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Flee</qex> fornication.</q> <rj><qau>1 Cor. vi.
18.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>So <qex>fled</qex> his enemies my warlike father.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ When great speed is to be indicated, we commonly use
<xex>fly</xex>, not <xex>flee</xex>; as, <xex>fly</xex> hence to France
with the utmost speed. <ldquo/Whither shall I <xex>fly</xex> to 'scape
their hands?<rdquo/ <au>Shak.</au> See <er>Fly</er>, <pos>v. i.</pos>,
5.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fleece</ent><br/
<hw>Fleece</hw> <pr>(fl<emac/s)</pr>, <pos>n.</pos> <ety>[OE.
<ets>flees</ets>, AS. <ets>fle<oacute/s</ets>; akin to D.
<ets>flies</ets>, <ets>vlies</ets>.]</ety> <sn>1.</sn> <def>The entire
coat of wool that covers a sheep or other similar animal; also, the
quantity shorn from a sheep, or animal, at one time.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Who shore me<br/
Like a tame wether, all my precious <qex>fleece</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Any soft woolly covering resembling a
fleece.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Manuf.)</fld> <def>The fine web of cotton or wool
removed by the doffing knife from the cylinder of a carding
machine.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fleece wool</b></col>, <cd>wool shorn from the
sheep.</cd> -- <col><b>Golden fleece</b></col>. <cd>See under
<er>Golden</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fleece</ent><br/
<hw>Fleece</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Fleeced</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Fleecing</conjf>.]</vmorph> <sn>1.</sn> <def>To deprive of a
fleece, or natural covering of wool.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To strip of money or other property unjustly,
especially by trickery or fraud; to bring to straits by oppressions and
exactions.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Whilst pope and prince shared the wool betwixt them, the people
were finely <qex>fleeced</qex>.</q> <rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To spread over as with wool.</def> <mark>[R.]</mark>
<rj><au>Thomson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fleeced</ent><br/
<hw>Fleeced</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Furnished
with a fleece; <as>as, a sheep is well <ex>fleeced</ex></as>.</def>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Stripped of a fleece; plundered; robbed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fleeceless</ent><br/
<hw>Fleece"less</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Without a
fleece.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fleecer</ent><br/
<hw>Flee"cer</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who fleeces or
strips unjustly, especially by trickery or fraud.</def>
<rj><au>Prynne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fleecy</ent><br/
<hw>Flee"cy</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Covered with, made of,
or resembling, a fleece.</def> <ldquo/<xex>Fleecy</xex> flocks.<rdquo/
<rj><au>Prior.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>fleen</ent><br/
<hw>fleen</hw> <pr>(fl<emac/n)</pr>, <pos>n. pl.</pos>
<def><mark>Obs.</mark> <pos>pl.</pos> of <er>Flea</er>.</def>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>fleer</ent><br/
<hw>fle"er</hw> <pr>(fl<emac/"<etil/r)</pr>, <pos>n.</pos> <def>One who
flees.</def> <rj><au>Ld. Berners.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>fleer</ent><br/
<hw>fleer</hw> <pr>(fl<emac/r)</pr>, <vmorph>[<pos>imp. & p. p.</pos>
<conjf>fleered</conjf> <pr>(fl<emac/rd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>fleering</conjf>.]</vmorph> <ety>[OE. <ets>flerien</ets>; cf.
Scot. <ets>fleyr</ets>, Norw. <ets>flira</ets> to titter, giggle, laugh
at nothing, MHG. <ets>vlerre</ets>, <ets>vlarre</ets>, a wide
wound.]</ety> <sn>1.</sn> <def>To make a wry face in contempt, or to
grin in scorn; to deride; to sneer; to mock; to gibe; <as>as, to
<ex>fleer</ex> and flout</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>fleer</qex> and scorn at our solemnity.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To grin with an air of civility; to leer.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Grinning and <qex>fleering</qex> as though they went to a bear
baiting.</q> <rj><qau>Latimer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fleer</ent><br/
<hw>Fleer</hw>, <pos>v. t.</pos> <def>To mock; to flout at.</def>
<rj><au>Beau. & Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fleer</ent><br/
<hw>Fleer</hw>, <pos>n.</pos> <sn>1.</sn> <def>A word or look of
derision or mockery.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And mark the <qex>fleers</qex>, the gibes, and notable scorn.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A grin of civility; a leer.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>A sly, treacherous <qex>fleer</qex> on the face of deceivers.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>fleerer</ent><br/
<hw>fleer"er</hw> <pr>(fl<emac/r"<etil/r)</pr>, <pos>n.</pos> <def>One
who fleers.</def> <rj><au>Beau. & Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>fleeringly</ent><br/
<hw>fleer"ing*ly</hw>, <pos>adv.</pos> <def>In a fleering
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>fleet</ent><br/
<hw>fleet</hw> <pr>(fl<emac/t)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>fleeted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>fleeting</conjf>.]</vmorph> <ety>[OE. <ets>fleten</ets>,
<ets>fleoten</ets>, to swim, AS. <ets>fle<oacute/tan</ets> to swim,
float; akin to D. <ets>vlieten</ets> to flow, OS. <ets>fliotan</ets>,
OHG. <ets>fliozzan</ets>, G. <ets>fliessen</ets>, Icel.
<ets>flj<omac/ta</ets> to float, flow, Sw. <ets>flyta</ets>, D.
<ets>flyde</ets>, L. <ets>pluere</ets> to rain, Gr. <grk>plei^n</grk> to
sail, swim, float, Skr. <ets>plu</ets> to swim, sail. <root/84. Cf.
<er>Fleet</er>, <pos>n. & a.</pos>, <er>Float</er>, <er>Pluvial</er>,
<er>Flow</er>.]</ety> <sn>1.</sn> <def>To sail; to float.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>And in frail wood on Adrian Gulf doth <qex>fleet</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To fly swiftly; to pass over quickly; to hasten; to
flit as a light substance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>All the unaccomplished works of Nature's hand, . . . <br/
Dissolved on earth, <qex>fleet</qex> hither.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Naut.)</fld> <def>To slip on the whelps or the
barrel of a capstan or windlass; -- said of a cable or hawser.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Naut.)</fld> <def>To move or change in position; --
said of persons; <as>as, the crew <ex>fleeted</ex> aft</as>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Fleet</ent><br/
<hw>Fleet</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To pass over rapidly;
to skin the surface of; <as>as, a ship that <ex>fleets</ex> the
gulf</as>.</def> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To hasten over; to cause to pass away lightly, or in
mirth and joy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Many young gentlemen flock to him, and <qex>fleet</qex> the time
carelessly.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Naut.)</fld> <sd>(a)</sd> <def>To draw apart the
blocks of; -- said of a tackle.</def> <rj><au>Totten.</au></rj></p>

<p><sd>(b)</sd> <def>To cause to slip down the barrel of a capstan or
windlass, as a rope or chain.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Naut.)</fld> <def>To move or change in position;
used only in special phrases; <as>as, of <ex>fleet aft</ex> the
crew</as>.</def></p>

<p><q>We got the long <ldquo/stick<rdquo/ . . . down and
<ldquo/<qex>fleeted</qex><rdquo/ aft, where it was secured.</q>
<rj><qau>F. T. Bullen.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Fleet</ent><br/
<hw>Fleet</hw>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Fleeter</adjf> <pr>(?)</pr>; <pos>superl.</pos>
<adjf>Fleetest</adjf>.]</amorph> <ety>[Cf. Icel. <ets>flj<omac/tr</ets>
quick. See <er>Fleet</er>, <pos>v. i.</pos>]</ety> <sn>1.</sn>
<def>Swift in motion; moving with velocity; light and quick in going
from place to place; nimble.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In mail their horses clad, yet <qex>fleet</qex> and strong.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Light; superficially thin; not penetrating deep, as
soil.</def> <mark>[Prov. Eng.]</mark> <rj><au>Mortimer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fleet</ent><br/
<hw>Fleet</hw>, <pos>n.</pos> <ety>[OE. <ets>flete</ets>,
<ets>fleote</ets>, AS. <ets>fle<oacute/t</ets> ship, fr.
<ets>fle<oacute/tan</ets> to float, swim. See <er>Fleet</er>, <pos>v.
i.</pos> and cf. <er>Float</er>.]</ety> <def>A number of vessels in
company, especially war vessels; also, the collective naval force of a
country, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fleet captain</b></col>, <cd>the senior aid of the
admiral of a fleet, when a captain.</cd> <rj><au>Ham. Nav.
Encyc.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fleet</ent><br/
<hw>Fleet</hw>, <pos>n.</pos> <ety>[AS. <ets>fle<oacute/t</ets> a place
where vessels float, bay, river; akin to D. <ets>vliet</ets> rill,
brook, G. <ets>fliess</ets>. See <er>Fleet</er>, <pos>v. i.</pos>]</ety>
<sn>1.</sn> <def>A flood; a creek or inlet; a bay or estuary; a river;
-- obsolete, except as a place name, -- as <xex>Fleet</xex> Street in
London.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Together wove we nets to entrap the fish<br/
In floods and sedgy <qex>fleets</qex>.</q>
<rj><qau>Matthewes.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A former prison in London, which originally stood
near a stream, the <xex>Fleet</xex> (now filled up).</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fleet parson</b></col>, <cd>a clergyman of low character,
in, or in the vicinity of, the Fleet prison, who was ready to unite
persons in marriage (called <xex>Fleet marriage</xex>) at any hour,
without public notice, witnesses, or consent of parents.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fleet</ent><br/
<hw>Fleet</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[AS.
<ets>fl<emac/t</ets> cream, fr. <ets>fle<oacute/tan</ets> to float. See
<er>Fleet</er>, <pos>v. i.</pos>]</ety> <def>To take the cream from; to
skim.</def> <mark>[Prov. Eng.]</mark> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fleeten</ent><br/
<hw>Fleet"en</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Fleeted or skimmed
milk.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fleeten face</b></col>, <cd>a face of the color of
fleeten, <it>i. e.</it>, blanched; hence, a coward.</cd> <ldquo/You know
where you are, you <xex>fleeten face</xex>.<rdquo/ <rj><au>Beau. &
Fl.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fleet-foot</ent><br/
<hw>Fleet"-foot`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Swift of
foot.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fleeting</ent><br/
<hw>Fleet"ing</hw>, <pos>a.</pos> <def>Passing swiftly away; not
durable; transient; transitory; <as>as, the <ex>fleeting</ex> hours or
moments</as>.</def></p>

<p><syn><b>Syn.</b> -- Evanescent; ephemeral. See
<er>Transient</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fleetingly</ent><br/
<hw>Fleet"ing*ly</hw>, <pos>adv.</pos> <def>In a fleeting manner;
swiftly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fleetings</ent><br/
<hw>Fleet"ings</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <def>A mixture of
buttermilk and boiling whey; curds.</def> <mark>[prov. Eng.]</mark>
<rj><au>Wright.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fleetly</ent><br/
<hw>Fleet"ly</hw>, <pos>adv.</pos> <def>In a fleet manner;
rapidly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fleetness</ent><br/
<hw>Fleet"ness</hw>, <pos>n.</pos> <def>Swiftness; rapidity; velocity;
celerity; speed; <as>as, the <ex>fleetness</ex> of a horse or of
time</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fleigh</ent><br/
<hw>Fleigh</hw> <pr>(?)</pr>, <mark>obs.</mark> <def><pos>imp.</pos> of
<er>Fly</er>.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fleme</ent><br/
<hw>Fleme</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[AS.
<ets>fl<emac/man</ets>, <ets>fl<ymac/man</ets>.]</ety> <def>To banish;
to drive out; to expel.</def> <mark>[Obs.]</mark> <ldquo/Appetite
<xex>flemeth discretion</xex>.<rdquo/ <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flemer</ent><br/
<hw>Flem"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, banishes or expels.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fleming</ent><br/
<hw>Flem"ing</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A native or
inhabitant of Flanders.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flemish</ent><br/
<hw>Flem"ish</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to
Flanders, or the Flemings.</def> -- <def2><pos>n.</pos> <def>The
language or dialect spoken by the Flemings; also, collectively, the
people of Flanders.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Flemish accounts</b></col> <fld>(Naut.)</fld>, <cd>short
or deficient accounts.</cd> <mark>[Humorous]</mark> <au>Ham. Nav.
Encyc.</au> -- <col><b>Flemish beauty</b></col> <fld>(Bot.)</fld>, <cd>a
well known pear. It is one of few kinds which have a red color on one
side.</cd> -- <col><b>Flemish bond</b></col>. <fld>(Arch.)</fld> <cd>See
<er>Bond</er>, <pos>n.</pos>, 8.</cd> -- <col><b>Flemish
brick</b></col>, <cd>a hard yellow paving brick.</cd> -- <col><b>Flemish
coil</b></col>, <cd>a flat coil of rope with the end in the center and
the turns lying against, without riding over, each other.</cd> --
<col><b>Flemish eye</b></col> <fld>(Naut.)</fld>, <cd>an eye formed at
the end of a rope by dividing the strands and lying them over each
other.</cd> -- <col><b>Flemish horse</b></col> <fld>(Naut.)</fld>,
<cd>an additional footrope at the end of a yard.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flench</ent><br/
<hw>Flench</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>Same as
<er>Flence</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flense</ent><br/
<hw>Flense</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Cf. Dan.
<ets>flense</ets>, D. <ets>vlensen</ets>, <ets>vlenzen</ets>, Scot.
<ets>flinch</ets>.]</ety> <def>To strip the blubber or skin from, as
from a whale, seal, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>the <qex>flensed</qex> carcass of a fur seal.</q> <rj><qau>U. S.
Census (1880).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flesh</ent><br/
<hw>Flesh</hw> <pr>(fl<ecr/sh)</pr>, <pos>n.</pos> <ety>[OE.
<ets>flesch</ets>, <ets>flesc</ets>, AS. <ets>fl<aemac/sc</ets>; akin to
OFries. <ets>fl<amac/sk</ets>, D. <ets>vleesch</ets>, OS.
<ets>fl<emac/sk</ets>, OHG. <ets>fleisc</ets>, G. <ets>fleisch</ets>,
Icel. & Dan. <ets>flesk</ets> lard, bacon, pork, Sw.
<ets>fl<aum/sk</ets>.]</ety> <sn>1.</sn> <def>The aggregate of the
muscles, fat, and other tissues which cover the framework of bones in
man and other animals; especially, the muscles.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In composition it is mainly proteinaceous, but contains
in adition a large number of low-molecular-weight subtances, such as
creatin, xanthin, hypoxanthin, carnin, etc. It is also rich in potassium
phosphate.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Animal food, in distinction from vegetable; meat;
especially, the body of beasts and birds used as food, as distinguished
from <contr>fish</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With roasted <qex>flesh</qex>, or milk, and wastel bread.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The human body, as distinguished from the soul; the
corporeal person.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>As if this <qex>flesh</qex>, which walls about our life,<br/
Were brass impregnable.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The human race; mankind; humanity.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>All <qex>flesh</qex> had corrupted his way upon the earth.</q>
<rj><qau>Gen. vi. 12.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Human nature</def>: <sd>(a)</sd> <def>In a good
sense, tenderness of feeling; gentleness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There is no <qex>flesh</qex> in man's obdurate heart.</q>
<rj><qau>Cowper.</qau></rj></p>

<p><sd>(b)</sd> <def>In a bad sense, tendency to transient or physical
pleasure; desire for sensual gratification; carnality.</def>
<sd>(c)</sd> <fld>(Theol.)</fld> <def>The character under the influence
of animal propensities or selfish passions; the soul unmoved by
spiritual influences.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Kindred; stock; race.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He is our brother and our <qex>flesh</qex>.</q> <rj><qau>Gen.
xxxvii. 27.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>The soft, pulpy substance of fruit; also, that part
of a root, fruit, and the like, which is fit to be eaten.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Flesh</xex> is often used adjectively or
self-explaining compounds; as, <xex>flesh</xex> broth or
<xex>flesh</xex>-broth; <xex>flesh</xex> brush or <xex>fleshbrush</xex>;
<xex>flesh</xex> tint or <xex>flesh</xex>-tint; <xex>flesh</xex>
wound.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>After the flesh</b></col>, <cd>after the manner of man;
in a gross or earthly manner.</cd> <ldquo/Ye judge <xex>after the
flesh</xex>.<rdquo/ <au>John viii. 15.</au> -- <col><b>An arm of
flesh</b></col>, <cd>human strength or aid.</cd> -- <col><b>Flesh and
blood</b></col>. <cd>See under <er>Blood</er>.</cd> -- <col><b>Flesh
broth</b></col>, <cd>broth made by boiling flesh in water.</cd> --
<col><b>Flesh fly</b></col> <fld>(Zool.)</fld>, <cd>one of several
species of flies whose larv<ae/ or maggots feed upon flesh, as the
bluebottle fly; -- called also <altname>meat fly</altname>,
<altname>carrion fly</altname>, and <altname>blowfly</altname>. See
<er>Blowly</er>.</cd> -- <col><b>Flesh meat</b></col>, <cd>animal
food.</cd> <au>Swift.</au> -- <col><b>Flesh side</b></col>, <cd>the side
of a skin or hide which was next to the flesh; -- opposed to
<contr>grain side</contr>.</cd> -- <col><b>Flesh tint</b></col>
<fld>(Painting)</fld>, <cd>a color used in painting to imitate the hue
of the living body.</cd> -- <col><b>Flesh worm</b></col>
<fld>(Zool.)</fld>, <cd>any insect larva of a flesh fly. See <cref>Flesh
fly</cref> (above).</cd> -- <col><b>Proud flesh</b></col>. <cd>See under
<er>Proud</er>.</cd> -- <col><b>To be one flesh</b></col>, <cd>to be
closely united as in marriage; to become as one person.</cd> <au>Gen.
ii. 24.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flesh</ent><br/
<hw>Flesh</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Fleshed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Fleshing</conjf>.]</vmorph> <sn>1.</sn> <def>To feed with flesh,
as an incitement to further exertion; to initiate; -- from the practice
of training hawks and dogs by feeding them with the first game they
take, or other flesh. Hence, to use upon flesh (as a murderous weapon)
so as to draw blood, especially for the first time.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Full bravely hast thou <qex>fleshed</qex><br/
Thy maiden sword.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The wild dog<br/
Shall <qex>flesh</qex> his tooth on every innocent.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To glut; to satiate; hence, to harden, to
accustom.</def> <ldquo/<xex>Fleshed</xex> in triumphs.<rdquo/
<rj><au>Glanvill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Old soldiers<br/
<qex>Fleshed</qex> in the spoils of Germany and France.</q>
<rj><qau>Beau. & Fl.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Leather Manufacture)</fld> <def>To remove flesh,
membrance, etc., from, as from hides.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 570 --></p>

<p><ent>Fleshed</ent><br/
<hw>Fleshed</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Corpulent;
fat; having flesh.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Glutted; satiated; initiated.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Fleshed</qex> with slaughter.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flesher</ent><br/
<hw>Flesh"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A
butcher.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>flesher</qex> on a block had laid his whittle down.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A two-handled, convex, blunt-edged knife, for
scraping hides; a fleshing knife.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fleshhood</ent><br/
<hw>Flesh"hood</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state or
condition of having a form of flesh; incarnation.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou, who hast thyself<br/
Endured this <qex>fleshhood</qex>.</q> <rj><qau>Mrs.
Browning.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fleshiness</ent><br/
<hw>Flesh"i*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state of
being fleshy; plumpness; corpulence; grossness.</def>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fleshings</ent><br/
<hw>Flesh"ings</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <def>Flesh-colored
tights, worn by actors and dancers.</def> <rj><au>D.
Jerrold.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fleshless</ent><br/
<hw>Flesh"less</hw>, <pos>a.</pos> <def>Destitute of flesh; lean.</def>
<rj><au>Carlyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fleshliness</ent><br/
<hw>Flesh"li*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state of
being fleshly; carnal passions and appetites.</def>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fleshling</ent><br/
<hw>Flesh"ling</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A person devoted to
fleshly things.</def> <mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fleshly</ent><br/
<hw>Flesh"ly</hw> <pr>(fl<ecr/sh"l<ycr/)</pr>, <pos>a.</pos> <ety>[AS.
<ets>fl<aemac/scl<imac/c</ets>.]</ety> <sn>1.</sn> <def>Of or pertaining
to the flesh; corporeal.</def> <ldquo/<xex>Fleshly</xex> bondage.<rdquo/
<rj><au>Denham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Animal; not vegetable.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Human; not celestial; not spiritual or divine.</def>
<ldquo/<xex>Fleshly</xex> wisdom.<rdquo/ <rj><au>2 Cor. i.
12.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Much ostentation vain of <qex>fleshly</qex> arm<br/
And fragile arms.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Carnal; wordly; lascivious.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Abstain from fleshly lusts, which war against the soul.</q>
<rj><qau>1 Pet. ii. 11.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fleshly</ent><br/
<hw>Flesh"ly</hw>, <pos>adv.</pos> <def>In a fleshly manner; carnally;
lasciviously.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fleshment</ent><br/
<hw>Flesh"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
fleshing, or the excitement attending a successful beginning.</def>
<mark>[R.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fleshmonger</ent><br/
<hw>Flesh"mon`ger</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS.
<ets>fl<aemac/sc mangere</ets>.]</ety> <def>One who deals in flesh;
hence, a pimp; a procurer; a pander.</def> <mark>[R.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fleshpot</ent><br/
<hw>Flesh"pot`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A pot
or vessel in which flesh is cooked.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In the land of Egypt . . . we sat by the <qex>fleshpots</qex>, and
. . . did eat bread to the full.</q> <rj><qau>Ex. xvi. 3.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <specif>hence</specif>, <pluf>pl.</pluf> <def>plenty;
high living.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <pluf>pl.</pluf> <def>Places providing opportunity to
indulge in amusements or pleasures without moral restraints.</def><br/
[<source>PJC</source>]</p>

<p><ent>Fleshquake</ent><br/
<hw>Flesh"quake`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A quaking or
trembling of the flesh; a quiver.</def> <mark>[Obs.]</mark> <rj><au>B.
Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fleshy</ent><br/
<hw>Flesh"y</hw> <pr>(?)</pr>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Fleshier</adjf> <pr>(?)</pr>; <pos>superl.</pos>
<adjf>Fleshiest</adjf> <pr>(?)</pr>.]</amorph> <sn>1.</sn> <def>Full of,
or composed of, flesh; plump; corpulent; fat; gross.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The sole of his foot is fleshy.</q> <rj><qau>Ray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Human.</def> <mark>[Obs.]</mark>
<ldquo/<xex>Fleshy</xex> tabernacle.<rdquo/
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Bot.)</fld> <def>Composed of firm pulp; succulent;
<as>as, the houseleek, cactus, and agave are <ex>fleshy</ex>
plants</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flet</ent><br/
<hw>Flet</hw> <pr>(?)</pr>, <pos>p. p.</pos> <mord>of
<er>Fleet</er></mord>. <def>Skimmed.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fletch</ent><br/
<hw>Fletch</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Fletched</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Fletching</conjf>.]</vmorph> <ety>[F.
<ets>fl<egrave/che</ets> arrow.]</ety> <def>To feather, as an
arrow.</def> <rj><au>Bp. Warburton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>[Congress] <qex>fletched</qex> their complaint, by adding:
<ldquo/America loved his brother.<rdquo/</q>
<rj><qau>Bancroft.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fletcher</ent><br/
<hw>Fletch"er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>flechier</ets>.]</ety> <def>One who fletches or feathers arrows; a
manufacturer of bows and arrows.</def> <mark>[Obs.]</mark>
<rj><au>Mortimer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flete</ent><br/
<hw>Flete</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[See <er>Fleet</er>,
<pos>v. i.</pos>]</ety> <def>To float; to swim.</def>
<mark>[Obs.]</mark> <ldquo/Whether I sink or <xex>flete</xex>.<rdquo/
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fletiferous</ent><br/
<hw>Fle*tif"er*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>fletifer</ets>; <ets>fletus</ets> a weeping (from <ets>flere</ets>,
<ets>fletum</ets>, to weep) + <ets>ferre</ets> to bear.]</ety>
<def>Producing tears.</def> <mark>[Obs.]</mark>
<rj><au>Blount.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fleur-de-lis</ent><br/
\'d8<hw>Fleur`-de-lis`</hw> <pr>(?)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Fleurs-de-lis</plw> <pr>(#)</pr>.</plu> <ety>[F.,
flower of the lily. Cf. <er>Flower-de-luce</er>, <er>Lily</er>.]</ety>
<sn>1.</sn> <fld>(Bot.)</fld> <def>The iris. See
<er>Flower-de-luce</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A conventional flower suggested by the iris, and
having a form which fits it for the terminal decoration of a scepter,
the ornaments of a crown, etc. It is also a heraldic bearing, and is
identified with the royal arms and adornments of France.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fleuron</ent><br/
\'d8<hw>Fleu`ron"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr. OF.
<ets>floron</ets>. Cf. <er>Floroon</er>.]</ety> <def>A flower-shaped
ornament, esp. one terminating an object or forming one of a series, as
a knob of a cover to a dish, or a flower-shaped part in a
necklace.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Fleury</ent><br/
<hw>Fleur"y</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F. <ets>fleuri</ets>
covered with flowers, p. p. of <ets>fleurir</ets>. See
<er>Flourish</er>.]</ety> <fld>(Her.)</fld> <def>Finished at the ends
with fleurs-de-lis; -- said esp. of a cross so decorated.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flew</ent><br/
<hw>Flew</hw> <pr>(?)</pr>, <def><pos>imp.</pos> of
<er>Fly</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flewed</ent><br/
<hw>Flewed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having large
flews.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flews</ent><br/
<hw>Flews</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <def>The pendulous or
overhanging lateral parts of the upper lip of dogs, especially prominent
in hounds; -- called also <altname>chaps</altname>. See
<xex>Illust.</xex> of <er>Bloodhound</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flex</ent><br/
<hw>Flex</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Flexed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Flexing</conjf>.]</vmorph> <ety>[L. <ets>flexus</ets>, p. p. of
<ets>flectere</ets> to bend, perh. <ets>flectere</ets> and akin to
<ets>falx</ets> sickle, E. <ets>falchion</ets>. Cf.
<er>Flinch</er>.]</ety> <def>To bend; <as>as, to <ex>flex</ex> the
arm</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flex</ent><br/
<hw>Flex</hw>, <pos>n.</pos> <def>Flax.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flexanimous</ent><br/
<hw>Flex*an"i*mous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>flexanimus</ets>; <ets>flectere</ets>, <ets>flexum</ets>, to bend +
<ets>animus</ets> mind.]</ety> <def>Having power to change the
mind.</def> <mark>[Obs.]</mark> <rj><au>Howell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flexibility</ent><br/
<hw>Flex`i*bil"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>flexibilitas</ets>: cf. F. <ets>flexibilite</ets>.]</ety> <def>The
state or quality of being flexible; flexibleness; pliancy; pliability;
<as>as, the <ex>flexibility</ex> of strips of hemlock, hickory,
whalebone or metal, or of rays of light</as>.</def> <rj><au>Sir I.
Newton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>All the <qex>flexibility</qex> of a veteran courtier.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flexible</ent><br/
<hw>Flex"i*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>flexibilis</ets>: cf. F. <ets>flexible</ets>.]</ety> <sn>1.</sn>
<def>Capable of being flexed or bent; admitting of being turned, bowed,
or twisted, without breaking; pliable; yielding to pressure; not stiff
or brittle.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>When the splitting wind<br/
Makes <qex>flexible</qex> the knees of knotted oaks.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Willing or ready to yield to the influence of
others; not invincibly rigid or obstinate; tractable; manageable;
ductile; easy and compliant; wavering.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Phocion was a man of great severity, and no ways
<qex>flexible</qex> to the will of the people.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Women are soft, mild, pitiful, and <qex>flexible</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Capable or being adapted or molded; plastic,;
<as>as, a <ex>flexible</ex> language</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This was a principle more <qex>flexible</qex> to their
purpose.</q> <rj><qau>Rogers.</qau></rj></p>

<p><syn><b>Syn.</b> -- Pliant; pliable; supple; tractable; manageable;
ductile; obsequious; inconstant; wavering.</syn></p>

<p>-- <wordforms><wf>Flex"i*ble*ness</wf>, <pos>n.</pos> --
<wf>Flex"i*bly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flexicostate</ent><br/
<hw>Flex`i*cos"tate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>flexus</ets> bent + E. <ets>costate</ets>.]</ety>
<fld>(Anat.)</fld> <def>Having bent or curved ribs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flexile</ent><br/
<hw>Flex"ile</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>flexilis</ets>.]</ety> <def>Flexible; pliant; pliable; easily bent;
plastic; tractable.</def> <rj><au>Wordsworth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flexion</ent><br/
<hw>Flex"ion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>flexio</ets>: cf. F. <ets>flexion</ets>.]</ety> <sn>1.</sn>
<def>The act of flexing or bending; a turning.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A bending; a part bent; a fold.</def>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Gram.)</fld> <def>Syntactical change of form of
words, as by declension or conjugation; inflection.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Express the syntactical relations by <qex>flexion</qex>.</q>
<rj><qau>Sir W. Hamilton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Physiol.)</fld> <def>The bending of a limb or
joint; that motion of a joint which gives the distal member a
continually decreasing angle with the axis of the proximal part; --
distinguished from <xex>extension</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flexor</ent><br/
<hw>Flex"or</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL.]</ety>
<fld>(Anat.)</fld> <def>A muscle which bends or flexes any part; <as>as,
the <ex>flexors</ex> of the arm or the hand</as>; -- opposed to
<contr>extensor</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>flex time</ent><br/
<ent>flextime</ent><br/
<ent>flexitime</ent><br/
<mhw><hw>flex"i*time`</hw>, <hw>flex"time`</hw> <hw>flex"
time`</hw></mhw> <pr>(?)</pr>, <pos>n.</pos> <ety>[short for
<ets>flexible time</ets>.]</ety> <def>A system of scheduling working
hours in places of employment, which allows employees to arrive at and
leave work at times of their own choice, providing that they work the
required number of hours and usually requiring that they be present
during certain hours, called <part>core time</part>.</def> <note>Certain
workers prefer to arrive early and leave early, and others prefer to
arrive late and leave late. <ex>Flex time</ex> is a way to accommodate
such preferences, presumably improving employee morale, and also helps
reduce traffic congestion during commmuting times.</note><br/
[<source>PJC</source>]</p>

<p><ent>Flexuose</ent><br/
<hw>Flex"u*ose`</hw> <pr>(?; 135)</pr>, <pos>a.</pos>
<def>Flexuous.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flexuous</ent><br/
<hw>Flex"u*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>flexuosus</ets>, fr. <ets>flexus</ets> a bending, turning.]</ety>
<sn>1.</sn> <def>Having turns, windings, or flexures.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>Having alternate curvatures in
opposite directions; bent in a zigzag manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Wavering; not steady; flickering.</def>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flexural</ent><br/
<hw>Flex"u*ral</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From
<er>Flexure</er>.]</ety> <def>Of, pertaining to, or resulting from,
flexure; of the nature of, or characterized by, flexure; <as>as,
<ex>flexural</ex> elasticity</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flexure</ent><br/
<hw>Flex"ure</hw> <pr>(?; 135)</pr>, <pos>n.</pos> <ety>[L.
<ets>flexura</ets>.]</ety> <sn>1.</sn> <def>The act of flexing or
bending; a turning or curving; flexion; hence, obsequious bowing or
bending.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Will it give place to <qex>flexure</qex> and low bending?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A turn; a bend; a fold; a curve.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Varying with the <qex>flexures</qex> of the valley through which
it meandered.</q> <rj><qau>British Quart. Rev.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <def>The last joint, or bend, of the
wing of a bird.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Astron.)</fld> <def>The small distortion of an
astronomical instrument caused by the weight of its parts; the amount to
be added or substracted from the observed readings of the instrument to
correct them for this distortion.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>The flexure of a curve</b></col> <fld>(Math.)</fld>,
<cd>the bending of a curve towards or from a straight
line.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flibbergib</ent><br/
<hw>Flib"ber*gib</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A
sycophant.</def> <mark>[Obs. & Humorous.]</mark> <ldquo/Flatterers and
<xex>flibbergibs</xex>.<rdquo/ <rj><au>Latimer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flibbertigibbet</ent><br/
<hw>Flib"ber*ti*gib`bet</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An
imp.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flibustier</ent><br/
\'d8<hw>Fli`bus`tier"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<def>A buccaneer; an American pirate. See <er>Filibuster</er>.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flick</ent><br/
<hw>Flick</hw> <pr>(fl<icr/k)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Flicked</conjf> <pr>(fl<icr/kt)</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>Flicking</conjf>.]</vmorph> <ety>[Cf.
<ets>Flicker</ets>.]</ety> <sn>1.</sn> <def>To whip lightly or with a
quick jerk; to flap; <as>as, to <ex>flick</ex> a horse; to
<ex>flick</ex> the dirt from boots.</as></def>
<rj><au>Thackeray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To throw, snap, or toss with a jerk; to flirt;
<as>as, to <ex>flick</ex> a whiplash</as>.</def></p>

<p><q>Rude boys were <qex>flicking</qex> butter pats across chaos.</q>
<rj><qau>Kipling.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Flick</ent><br/
<hw>Flick</hw>, <pos>n.</pos> <def>A flitch; <as>as, a <ex>flick</ex> of
bacon</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flick</ent><br/
<hw>Flick</hw>, <pos>n.</pos> <ety>[See <er>Flick</er>, <pos>v.
t.</pos>]</ety> <sn>1.</sn> <def>A light quick stroke or blow, esp. with
something pliant; a flirt; also, the sound made by such a
blow.</def></p>

<p><q>She actually took the whip out of his hand and gave a
<qex>flick</qex> to the pony.</q> <rj><qau>Mrs. Humphry
Ward.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>A motion picture; <as>as, I went to see a
<ex>flick</ex> on Friday</as>.</def> <mark>[Colloq.]</mark> <br/
[<source>PJC</source>]</p>

<p><ent>Flicker</ent><br/
<hw>Flick"er</hw> <pr>(fl<icr/k"<etil/r)</pr>, <pos>v. i.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Flickered</conjf>
<pr>(fl<icr/k"<etil/rd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Flickering</conjf>.]</vmorph> <ety>[OE. <ets>flikeren</ets>,
<ets>flekeren</ets>, to flutter, AS. <ets>flicerian</ets>,
<ets>flicorian</ets>, cf. D. <ets>flikkeren</ets> to sparkle. <root/84.
Cf. <ets>Flacker</ets>.]</ety> <sn>1.</sn> <def>To flutter; to flap the
wings without flying.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And <qex>flickering</qex> on her nest made short essays to
sing.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To waver unsteadily, like a flame in a current of
air, or when about to expire; <as>as, the <ex>flickering</ex>
light</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The shadows <qex>flicker</qex> to fro.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flicker</ent><br/
<hw>Flick"er</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act of wavering or
of fluttering; fluctuation; sudden and brief increase of brightness;
<as>as, the last <ex>flicker</ex> of the dying flame</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>The golden-winged woodpecker
(<spn>Colaptes aurutus</spn>); -- so called from its spring note. Called
also <altname>yellow-hammer</altname>, <altname>high-holder</altname>,
<altname>pigeon woodpecker</altname>, and
<altname>yucca</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The cackle of the <qex>flicker</qex> among the oaks.</q>
<rj><qau>Thoureau.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flickeringly</ent><br/
<hw>Flick"ering*ly</hw>, <pos>adv.</pos> <def>In a flickering
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flickermouse</ent><br/
<hw>Flick"er*mouse`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>See <er>Flittermouse</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flidge</ent><br/
<hw>Flidge</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Fledged; fledge.</def>
<mark>[Obs.]</mark> <rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flidge</ent><br/
<hw>Flidge</hw>, <pos>v. i.</pos> <def>To become fledged; to
fledge.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Every day build their nests, every hour <qex>flidge</qex>.</q>
<rj><qau>R. Greene.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flier</ent><br/
<hw>Fli"er</hw> <pr>(fl<imac/"<etil/r)</pr>, <pos>n.</pos> <ety>[Form
<er>Fly</er>, <pos>v.</pos>; cf. <er>Flyer</er>]</ety> <sn>1.</sn>
<def>One who flies or flees; a runaway; a fugitive.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mach.)</fld> <def>A fly. See <er>Fly</er>,
<pos>n.</pos>, 9, and 13 <sd>(b)</sd>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Spinning)</fld> <def>See <er>Flyer</er>,
<pos>n.</pos>, 5.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Arch.)</fld> <def>See <er>Flyer</er>,
<pos>n.</pos>, 4.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>An a<eum/roplane or flying machine.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Flight</ent><br/
<hw>Flight</hw> <pr>(fl<imac/t)</pr>, <pos>n.</pos> <ety>[AS.
<ets>fliht</ets>, <ets>flyht</ets>, a flying, fr.
<ets>fle<oacute/gan</ets> to fly; cf. <ets>flyht</ets> a fleeing, fr.
<ets>fle<oacute/n</ets> to flee, G. <ets>flucht</ets> a fleeing, Sw.
<ets>flykt</ets>, G. <ets>flug</ets> a flying, Sw. <ets>flygt</ets>, D.
<ets>vlugt</ets> a fleeing or flying, Dan. <ets>flugt</ets>. <root/84.
See <er>Flee</er>, <er>Fly</er>.]</ety> <sn>1.</sn> <def>The act of
flying; a passing through the air by the help of wings; volitation; mode
or style of flying.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Like the night owl's lazy <qex>flight</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The act of fleeing; the act of running away, to
escape danger or expected evil; hasty departure.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Pray ye that your <qex>flight</qex> be not in the winter.</q>
<rj><qau>Matt. xxiv. 20.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Fain by <qex>flight</qex> to save themselves.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Lofty elevation and excursion; a mounting; a
soaring; <as>as, a <ex>flight</ex> of imagination, ambition,
folly</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Could he have kept his spirit to that <qex>flight</qex>,<br/
<qex>He had been happy</qex>.</q> <rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>His highest <qex>flights</qex> were indeed far below those of
Taylor.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A number of beings or things passing through the air
together; especially, a flock of birds flying in company; the birds that
fly or migrate together; the birds produced in one season; <as>as, a
<ex>flight</ex> of arrows</as>.</def> <rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Swift <qex>flights</qex> of angels ministrant.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Like a <qex>flight</qex> of fowl<br/
Scattered winds and tempestuous gusts.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A series of steps or stairs from one landing to
another.</def> <rj><au>Parker.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>A kind of arrow for the longbow; also, the sport of
shooting with it. See <er>Shaft</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Challenged Cupid at the <qex>flight</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Not a <qex>flight</qex> drawn home<br/
E'er made that haste that they have.</q> <rj><qau>Beau. &
Fl.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>The husk or glume of oats.</def> <mark>[Prov.
Eng.]</mark> <rj><au>Wright.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>a trip made by or in a flying vehicle, as an
airplane, spacecraft, or aeronautical balloon.</def><br/
[<source>PJC</source>]</p>

<p><sn>9.</sn> <def>A scheduled flight{8} on a commercial airline;
<as>as, the next flight leaves at 8 o'clock</as>.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Flight feathers</b></col> <fld>(Zool.)</fld>, <cd>the
wing feathers of a bird, including the quills, coverts, and bastard
wing. See <er>Bird</er>.</cd> -- <mcol><col><b>To put to
flight</b></col>, <col><b>To turn to flight</b></col></mcol>, <cd>to
compel to run away; to force to flee; to rout.</cd> -- <col><b>to take a
flight{9}</b></col>, <cd>to make a trip in an airplane, especially a
scheduled flight{9}.</cd></cs><br/
[<source>1913 Webster</source> + <source>PJC</source>]</p>

<p><syn><b>Syn.</b> -- Pair; set. See <er>Pair</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flighted</ent><br/
<hw>Flight"ed</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Taking
flight; flying; -- used in composition.</def>
<ldquo/Drowsy-<xex>flighted</xex> steeds.<rdquo/
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Her.)</fld> <def>Feathered; -- said of
arrows.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flighter</ent><br/
<hw>Flight"er</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Brewing)</fld>
<def>A horizontal vane revolving over the surface of wort in a cooler,
to produce a circular current in the liquor.</def>
<rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flightily</ent><br/
<hw>Flight"i*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a flighty
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flightiness</ent><br/
<hw>Flight"i*ness</hw>, <pos>n.</pos> <def>The state or quality of being
flighty.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>flightness</qex> of her temper.</q>
<rj><qau>Hawthorne.</qau></rj></p>

<p><syn><b>Syn.</b> -- Levity; giddiness; volatility; lightness;
wildness; eccentricity. See <er>Levity</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flight-shot</ent><br/
<hw>Flight"-shot`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The distance to
which an arrow or flight may be shot; bowshot, -- about the fifth of a
mile.</def> <mark>[Prov. Eng. & Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Within a <qex>flight-shot</qex> it inthe valley.</q>
<rj><qau>Evelyn.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Half a <qex>flight-shot</qex> from the king's oak.</q>
<rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flighty</ent><br/
<hw>Flight"y</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Fleeting;
swift; transient.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>flighty</qex> purpose never is o'ertook,<br/
Unless the deed go with it.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Indulging in flights, or wild and unrestrained
sallies, of imagination, humor, caprice, etc.; given to disordered
fancies and extravagant conduct; volatile; giddy; eccentric; slightly
delirious.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Proofs of my <qex>flighty</qex> and paradoxical turn of mind.</q>
<rj><qau>Coleridge.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A harsh disciplinarian and a <qex>flighty</qex> enthusiast.</q>
<rj><qau>J. S. Harford.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flimflam</ent><br/
<hw>Flim"flam</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf.
<er>Flam</er>.]</ety> <def>A freak; a trick; a lie.</def> <rj><au>Beau.
& Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flimsily</ent><br/
<hw>Flim"si*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a flimsy
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flimsiness</ent><br/
<hw>Flim"si*ness</hw>, <pos>n.</pos> <def>The state or quality of being
flimsy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flimsy</ent><br/
<hw>Flim"sy</hw> <pr>(?)</pr>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Flimsier</adjf> <pr>(?)</pr>; <pos>superl.</pos>
<adjf>Flimsiest</adjf>.]</amorph> <ety>[Cf. W. <ets>llymsi</ets> naked,
bare, empty, sluggish, spiritless. Cf. <er>Limsy</er>.]</ety> <def>Weak;
feeble; limp; slight; vain; without strength or solidity; of loose and
unsubstantial structure; without reason or plausibility; <as>as, a
<ex>flimsy</ex> argument, excuse, objection</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Proud of a vast extent of <qex>flimsy</qex> lines.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>All the <qex>flimsy</qex> furniture of a country miss's brain.</q>
<rj><qau>Sheridan.</qau></rj></p>

<p><syn><b>Syn.</b> -- Weak; feeble; superficial; shallow;
vain.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flimsy</ent><br/
<hw>Flim"sy</hw>, <pos>n.</pos> <sn>1.</sn> <def>Thin or transfer
paper.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A bank note.</def> <mark>[Slang, Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flinch</ent><br/
<hw>Flinch</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Flinched</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Flinching</conjf>.]</vmorph> <ety>[Prob. fr. OE.
<ets>flecchen</ets> to waver, give way, F. <ets>fl<eacute/chir</ets>,
fr. L. <ets>flectere</ets> to bend; but prob. influenced by E.
<ets>blench</ets>. Cf. <er>Flex</er>.]</ety> <sn>1.</sn> <def>To
withdraw from any suffering or undertaking, from pain or danger; to fail
in doing or preserving; to show signs of yielding or of suffering; to
shrink; to wince; <as>as, one of the parties <ex>flinched</ex> from the
combat</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A child, by a constant course of kindness, may be accustomed to
bear very rough usage without <qex>flinching</qex> or complaining.</q>
<rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Croquet)</fld> <def>To let the foot slip from a
ball, when attempting to give a tight croquet.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flinch</ent><br/
<hw>Flinch</hw>, <pos>n.</pos> <def>The act of flinching.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flincher</ent><br/
<hw>Flinch"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who flinches or
fails.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flinchingly</ent><br/
<hw>Flinch"ing*ly</hw>, <pos>adv.</pos> <def>In a flinching
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flindermouse</ent><br/
<hw>Flin"der*mouse`</hw> <pr>(?)</pr>, <pos>n.</pos><ety>[OE.
<ets>vlindre</ets> moth (cf. D. <ets>vlinder</ets> butterfly) + E.
<ets>mouse</ets>. Cf. <er>Flittermouse</er>, <er>Flinders</er>.]</ety>
<fld>(Zool.)</fld> <def>A bat; a flittermouse.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flinders</ent><br/
<hw>Flin"ders</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[Scot.
<ets>flenders</ets>, <ets>flendris</ets>; perh. akin to E.
<ets>flutter</ets>; cf. D. <ets>flenters</ets> rags, broken
pieces.]</ety> <def>Small pieces or splinters; fragments.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The tough ash spear, so stout and true,<br/
Into a thousand <qex>flinders</qex> flew.</q> <rj><qau>Sir W.
Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flindersia</ent><br/
<hw>Flindersia</hw> <pos>n.</pos> <def>A small genus of Australian
timber trees.</def><br/
<syn><b>Syn. --</b> genus <gen>Flindersia</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>flindosy</ent><br/
<ent>flindosa</ent><br/
<mhw><hw>flindosa</hw>, <hw>flindosy</hw></mhw> <pos>n.</pos> <def>A
tall Australian timber tree (<spn>Flindersia australis</spn>) yielding
tough hard wood used for staves etc.</def><br/
<syn><b>Syn. --</b> native beech, flindosy, <spn>Flindersia
australis</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fling</ent><br/
<hw>Fling</hw> <pr>(fl<icr/ng)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Flung</conjf> <pr>(fl<ucr/ng)</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>Flinging</conjf>.]</vmorph> <ety>[OE.
<ets>flingen</ets>, <ets>flengen</ets>, to rush, hurl; cf. Icel.
<ets>flengia</ets> to whip, ride furiously, OSw. <ets>flenga</ets> to
strike, Sw. <ets>fl<aum/nga</ets> to romp, Dan. <ets>flenge</ets> to
slash.]</ety> <sn>1.</sn> <def>To cast, send, to throw from the hand; to
hurl; to dart; to emit with violence as if thrown from the hand; <as>as,
to <ex>fing</ex> a stone into the pond</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>'T is Fate that <qex>flings</qex> the dice: and, as she
<qex>flings</qex>,<br/
Of kings makes peasants, and of peasants kings.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He . . . like Jove, his lighting <qex>flung</qex>.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I know thy generous temper well.<br/
<qex>Fling</qex> but the appearance of dishonor on it,<br/
It straight takes fire.</q> <rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To shed forth; to emit; to scatter.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The sun begins to <qex>fling</qex><br/
His flaring beams.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Every beam new transient colors <qex>flings</qex>.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To throw; to hurl; to throw off or down; to
prostrate; hence, to baffle; to defeat; <as>as, to <ex>fling</ex> a
party in litigation</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His horse started, <qex>flung</qex> him, and fell upon him.</q>
<rj><qau>Walpole.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 571 --></p>

<cs><p><col><b>To fling about</b></col>, <cd>to throw on all sides; to
scatter.</cd> -- <col><b>To fling away</b></col>, <cd>to reject; to
discard.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>Cromwell, I charge thee, <qex>fling away</qex> ambition.</q>
<rj><qau>Shak.</qau></rj></p>

<p>--<col><b>To fling down</b></col>. <sd>(a)</sd> <cd>To throw to the
ground; esp., to throw in defiance, as formerly knights cast a glove
into the arena as a challenge.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>This question so <qex>flung down</qex> before the guests, . . .
<br/
Was handed over by consent of all<br/
To me who had not spoken.</q> <rj><qau>Tennyson.</qau></rj></p>

<p><sd>(b)</sd> <cd>To overturn; to demolish; to ruin.</cd> --
<col><b>To fling in</b></col>, <cd>to throw in; not to charge in an
account; as, in settling accounts, one party <xex>flings in</xex> a
small sum, or a few days' work.</cd> -- <col><b>To fling off</b></col>,
<cd>to baffle in the chase; to defeat of prey; also, to get rid of.</cd>
<au>Addison.</au> -- <col><b>To fling open</b></col>, <cd>to throw open;
to open suddenly or with violence; as, <xex>to fling open</xex> a
door.</cd> -- <col><b>To fling out</b></col>, <cd>to utter; to speak in
an abrupt or harsh manner; as, <xex>to fling out</xex> hard words
against another.</cd> -- <col><b>To fling up</b></col>, <cd>to
relinquish; to abandon; as, <xex>to fling up</xex> a
design.</cd><br/
[<source>1913 Webster</source>]</p></cs>

<p><ent>Fling</ent><br/
<hw>Fling</hw> <pr>(?)</pr>, <pos>v. i.</pos> <sn>1.</sn> <def>To throw;
to wince; to flounce; <as>as, the horse began to kick and
<ex>fling</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To cast in the teeth; to utter abusive language; to
sneer; <as>as, the scold began to flout and
<ex>fling</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To throw one's self in a violent or hasty manner; to
rush or spring with violence or haste.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And crop-full, out of doors he <qex>flings</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I <qex>flung</qex> closer to his breast,<br/
As sword that, after battle, <qex>flings</qex> to sheath.</q>
<rj><qau>Mrs. Browning.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To fling out</b></col>, <cd>to become ugly and
intractable; to utter sneers and insinuations.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fling</ent><br/
<hw>Fling</hw>, <pos>n.</pos> <sn>1.</sn> <def>A cast from the hand; a
throw; also, a flounce; a kick; <as>as, the <ex>fling</ex> of a
horse</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A severe or contemptuous remark; an expression of
sarcastic scorn; a gibe; a sarcasm.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I, who love to have a <qex>fling</qex>,<br/
Both at senate house and king.</q> <rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A kind of dance; <as>as, the Highland
<ex>fling</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A trifling matter; an object of contempt.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>England were but a <qex>fling</qex><br/
Save for the crooked stick and the gray goose wing.</q> <rj><qau>Old
Proverb.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>a short period during which one indulges one's
wishes, whims, or desires in an unrestrained manner.</def><br/
[<source>PJC</source>]</p>

<p><sn>6.</sn> <def>a love affair.</def><br/
[<source>PJC</source>]</p>

<p><sn>7.</sn> <def>a casual or brief attempt to accomplish
something.</def> <mark>[informal]</mark> <br/
<syn><b>Syn. --</b> shot.</syn><br/
[<source>PJC</source>]</p>

<p><sn>8.</sn> <def>a period during which one tries a new activity;
<as>as, he took a <ex>fling</ex> at playing tennis</as>.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>To have one's fling</b></col>, <cd>to enjoy one's self to
the full; to have a season of dissipation.</cd> <au>J. H. Newman.</au>
<ldquo/When I was as young as you, I <xex>had my fling</xex>. I led a
life of pleasure.<rdquo/ <au>D. Jerrold.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flingdust</ent><br/
<hw>Fling"dust`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who kicks up
the dust; a streetwalker; a low manner.</def> <mark>[Obs.]</mark>
<rj><au>Beau. & Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flinger</ent><br/
<hw>Fling"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who flings; one
who jeers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flint</ent><br/
<hw>Flint</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS. <ets>flint</ets>,
akin to Sw. <ets>flinta</ets>, Dan. <ets>flint</ets>; cf. OHG.
<ets>flins</ets> flint, G. <ets>flinte</ets> gun (cf. E.
<ets>flint</ets>lock), perh. akin to Gr. <?/ brick. Cf.
<er>Plinth</er>.]</ety> <sn>1.</sn> <fld>(Min.)</fld> <def>A massive,
somewhat impure variety of quartz, in color usually of a gray to brown
or nearly black, breaking with a conchoidal fracture and sharp edge. It
is very hard, and strikes fire with steel.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A piece of flint for striking fire; -- formerly much
used, esp. in the hammers of gun locks.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Anything extremely hard, unimpressible, and
unyielding, like flint.</def> <ldquo/A heart of <xex>flint</xex>.<rdquo/
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Flint age</b></col>. <fld>(Geol.)</fld> <cd>Same as
<cref>Stone age</cref>, under <er>Stone</er>.</cd> -- <col><b>Flint
brick</b></col>, <cd>a fire made principially of powdered silex.</cd> --
<col><b>Flint glass</b></col>. <cd>See in the Vocabulary.</cd> --
<col><b>Flint implements</b></col> <fld>(Arch<ae/ol.)</fld>, <cd>tools,
etc., employed by men before the use of metals, such as axes, arrows,
spears, knives, wedges, etc., which were commonly made of flint, but
also of granite, jade, jasper, and other hard stones.</cd> --
<col><b>Flint mill</b></col>. <sd>(a)</sd> <fld>(Pottery)</fld> <cd>A
mill in which flints are ground.</cd> <sd>(b)</sd> <fld>(Mining)</fld>
<cd>An obsolete appliance for lighting the miner at his work, in which
flints on a revolving wheel were made to produce a shower of sparks,
which gave light, but did not inflame the fire damp.</cd>
<au>Knight.</au> -- <col><b>Flint stone</b></col>, <cd>a hard, siliceous
stone; a flint.</cd> -- <col><b>Flint wall</b></col>, <cd>a kind of
wall, common in England, on the face of which are exposed the black
surfaces of broken flints set in the mortar, with quions of
masonry.</cd> -- <col><b>Liquor of flints</b></col>, <cd>a solution of
silica, or flints, in potash.</cd> -- <col><b>To skin a flint</b></col>,
<cd>to be capable of, or guilty of, any expedient or any meanness for
making money.</cd> <mark>[Colloq.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flint glass</ent><br/
<hw>Flint" glass`</hw> <pr>(?)</pr>. <fld>(Chem.)</fld> <def>A soft,
heavy, brilliant glass, consisting essentially of a silicate of lead and
potassium. It is used for tableware, and for optical instruments, as
prisms, its density giving a high degree of dispersive power; -- so
called, because formerly the silica was obtained from pulverized flints.
Called also <altname>crystal glass</altname>. Cf.
<er>Glass</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The concave or diverging half on an achromatic lens is
usually made of <xex>flint glass</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flint-hearted</ent><br/
<hw>Flint"-heart`ed</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Hard-hearted.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flintiness</ent><br/
<hw>Flint"i*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state or
quality of being flinty; hardness; cruelty.</def> <rj><au>Beau. &
Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flintlock</ent><br/
<hw>Flint"lock`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A lock
for a gun or pistol, having a flint fixed in the hammer, which on
striking the steel ignites the priming.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A hand firearm fitted with a flintlock; esp., the
old-fashioned musket of European and other armies.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flintware</ent><br/
<hw>Flint"ware`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A superior kind of
earthenware into whose composition flint enters largely.</def>
<rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flintwood</ent><br/
<hw>Flint"wood`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>An Australian name for the very hard wood of the <spn>Eucalyptus
piluralis</spn>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flinty</ent><br/
<hw>Flint"y</hw> <pr>(?)</pr>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Flintier</adjf> <pr>(?)</pr>; <pos>superl.</pos>
<adjf>Flintiest</adjf>.]</amorph> <def>Consisting of, composed of,
abounding in, or resembling, flint; <as>as, a <ex>flinty</ex> rock;
<ex>flinty</ex> ground; a <ex>flinty</ex> heart.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Flinty rock</b></col>, <it>or</it> <col><b>Flinty
state</b></col></mcol>, <cd>a siliceous slate; -- basanite is here
included. See <er>Basanite</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flip</ent><br/
<hw>Flip</hw> <pr>(fl<icr/p)</pr>, <pos>n.</pos> <ety>[Cf. Prov. E.
<ets>flip</ets> nimble, flippant, also, a slight blow. Cf.
<er>Flippant</er>.]</ety> <def>A mixture of beer, spirit, etc., stirred
and heated by a hot iron.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Flip dog</b></col>, <cd>an iron used, when heated, to
warm flip.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flip</ent><br/
<hw>Flip</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Flipped</conjf> <pr>(fl<icr/pt)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Flipping</conjf>.]</vmorph> <sn>1.</sn> <def>To toss (an object)
into the air so as make it turn over one or more times; to fillip;
<as>as, to <ex>flip</ex> up a cent</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>As when your little ones<br/
Do 'twixt their fingers <qex>flip</qex> their cherry stones.</q>
<rj><qau>W. Browne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To turn (a flat object) over with a quick motion;
<as>as, to <ex>flip</ex> a card over; to <ex>flip</ex> a
pancake</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>To cause (a person) to turn against former
colleagues, such as to become a witness for the state, in a criminal
prosecution in which the person is a defendant.</def>
<mark>[cant]</mark><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <fld>(Finance)</fld> <def>To resell (an asset) rapidly to
make a quick profit.</def> <mark>[cant]</mark><br/
[<source>PJC</source>]</p>

<p><ent>Flip</ent><br/
<hw>Flip</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Flipped</conjf> <pr>(fl<icr/pt)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Flipping</conjf>.]</vmorph> <def>To become insane or irrational;
-- often used with <ptcl>out</ptcl>; <as>as, seeing her mother killed
made the girl <ex>flip out</ex></as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Flipe</ent><br/
<hw>Flipe</hw> <pr>(fl<imac/p)</pr>, <pos>v. t.</pos> <def>To turn
inside out, or with the leg part back over the foot, as a stocking in
pulling off or for putting on.</def> <mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flip-flap</ent><br/
<hw>Flip"-flap`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Flip</er>, and <er>Flap</er>.]</ety> <def>The repeated stroke of
something long and loose.</def> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flip-flap</ent><br/
<hw>Flip"-flap`</hw>, <pos>adv.</pos> <def>With repeated strokes and
noise, as of something long and loose.</def> <rj><au>Ash.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flippancy</ent><br/
<hw>Flip"pan*cy</hw> <pr>(?)</pr>, <pos>n.</pos><ety>[See
<er>Flippant</er>.]</ety> <def>The state or quality of being
flippant.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This <qex>flippancy</qex> of language.</q> <rj><qau>Bp.
Hurd.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flippant</ent><br/
<hw>Flip"pant</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Prov. E.
<ets>flip</ets> to move nimbly; cf. W. <ets>llipa</ets> soft, limber,
pliant, or Icel. <ets>fleipa</ets> to babble, prattle. Cf.
<er>Flip</er>, <er>Fillip</er>, <er>Flap</er>, <er>Flipper</er>.]</ety>
<sn>1.</sn> <def>Of smooth, fluent, and rapid speech; speaking with ease
and rapidity; having a voluble tongue; talkative.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It becometh good men, in such cases, to be <qex>flippant</qex> and
free in their speech.</q> <rj><qau>Barrow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Speaking fluently and confidently, without knowledge
or consideration; empty; trifling; inconsiderate; pert; petulant.</def>
<ldquo/<xex>Flippant</xex> epilogues.<rdquo/
<rj><au>Thomson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To put <qex>flippant</qex> scorn to the blush.</q> <rj><qau>I.
Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A sort of <qex>flippant</qex>, vain discourse.</q>
<rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flippant</ent><br/
<hw>Flip"pant</hw>, <pos>n.</pos> <def>A flippant person.</def>
<mark>[R.]</mark> <rj><au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flippantly</ent><br/
<hw>Flip"pant*ly</hw>, <pos>adv.</pos> <def>In a flippant
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flippantness</ent><br/
<hw>Flip"pant*ness</hw>, <pos>n.</pos> <def>State or quality of being
flippant.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flipper</ent><br/
<hw>Flip"per</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. <er>Flip</er>,
<er>Flippant</er>.]</ety> <sn>1.</sn> <fld>(Zool.)</fld> <def>A broad
flat limb used for swimming, as those of seals, sea turtles, whales,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Naut.)</fld> <def>The hand.</def>
<mark>[Slang]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>flippers</ent><br/
<hw>flippers</hw> <pos>n.</pos> <sing><singw>flipper</singw></sing>
<ety>[By analogy with <ets>flipper</ets>[W13(1)], the limb of an aquatic
animal used for locomotion]</ety> <def>A type of shoe with a paddle-like
front extending well beyond the end of the toe, used an aid in swimming
(especially underwater).</def> <note>They are typically of rubber-like
material, and are not worn when walking on land.</note><br/
<syn><b>Syn. --</b> fin, fins.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Flirt</ent><br/
<hw>Flirt</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Flirted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Flirting</conjf>.]</vmorph> <ety>[Cf. AS. <ets>fleard</ets>
trifle, folly, <ets>fleardian</ets> to trifle.]</ety> <sn>1.</sn>
<def>To throw with a jerk or quick effort; to fling suddenly; <as>as,
they <ex>flirt</ex> water in each other's faces; he <ex>flirted</ex> a
glove, or a handkerchief.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To toss or throw about; to move playfully to and
fro; <as>as, to <ex>flirt</ex> a fan</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To jeer at; to treat with contempt; to mock.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I am ashamed; I am scorned; I am <qex>flirted</qex>.</q>
<rj><qau>Beau. & Fl.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flirt</ent><br/
<hw>Flirt</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To run and dart about;
to act with giddiness, or from a desire to attract notice; especially,
to play the coquette; to play at courtship; to coquet; <as>as, they
<ex>flirt</ex> with the young men</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To utter contemptuous language, with an air of
disdain; to jeer or gibe.</def> <mark>[Obs.]</mark> <rj><au>Beau. &
Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flirt</ent><br/
<hw>Flirt</hw>, <pos>n.</pos> <sn>1.</sn> <def>A sudden jerk; a quick
throw or cast; a darting motion; hence, a jeer.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Several little <qex>flirts</qex> and vibrations.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>With many a <qex>flirt</qex> and flutter.</q> <rj><qau>E. A.
Poe.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <ety>[Cf. LG. <ets>flirtje</ets>, G.
<ets>flirtchen</ets>. See <er>Flirt</er>, <pos>v. t.</pos>]</ety>
<def>One who flirts; esp., a woman who acts with giddiness, or plays at
courtship; a coquette; a pert girl.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Several young <qex>flirts</qex> about town had a design to cast us
out of the fashionable world.</q> <rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flirt</ent><br/
<hw>Flirt</hw>, <pos>a.</pos> <def>Pert; wanton.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flirtation</ent><br/
<hw>Flir*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>Playing at courtship; coquetry.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>flirtations</qex> and jealousies of our ball rooms.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flirt-gill</ent><br/
<hw>Flirt"-gill`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A woman of light
behavior; a gill-flirt.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>You heard him take me up like a <qex>flirt-gill</qex>.</q>
<rj><qau>Beau. & Fl.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flirtigig</ent><br/
<hw>Flirt"i*gig</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A wanton, pert
girl.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flirtingly</ent><br/
<hw>Flirt"ing*ly</hw>, <pos>adv.</pos> <def>In a flirting
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flisk</ent><br/
<hw>Flisk</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To frisk; to skip; to
caper.</def> <mark>[Obs. Scot.]</mark> <ldquo/The <xex>flisking</xex>
flies.<rdquo/ <rj><au>Gosson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flisk</ent><br/
<hw>Flisk</hw>, <pos>n.</pos> <def>A caper; a spring; a whim.</def>
<mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flit</ent><br/
<hw>Flit</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Flitted</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Flitting</conjf> <pr>(?)</pr>.]</vmorph> <ety>[OE.
<ets>flitten</ets>, <ets>flutten</ets>, to carry away; cf. Icel.
<ets>flytja</ets>, Sw. <ets>flytta</ets>, Dan. <ets>flytte</ets>.
<root/84. Cf. <er>Fleet</er>, <pos>v. i.</pos>]</ety> <sn>1.</sn>
<def>To move with celerity through the air; to fly away with a rapid
motion; to dart along; to fleet; <as>as, a bird <ex>flits</ex> away; a
cloud <ex>flits</ex> along.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>A shadow <qex>flits</qex> before me.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To flutter; to rove on the wing.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To pass rapidly, as a light substance, from one
place to another; to remove; to migrate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It became a received opinion, that the souls of men, departing
this life, did <qex>flit</qex> out of one body into some other.</q>
<rj><qau>Hooker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To remove from one place or habitation to
another.</def> <mark>[Scot. & Prov. Eng.]</mark> <rj><au>Wright.
Jamieson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To be unstable; to be easily or often
moved.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And the free soul to <qex>flitting</qex> air resigned.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flit</ent><br/
<hw>Flit</hw>, <pos>a.</pos> <def>Nimble; quick; swift.
<mark>[Obs.]</mark> See <er>Fleet</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flitch</ent><br/
<hw>Flitch</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Flitches</plw> <pr>(#)</pr>.</plu> <ety>[OE. <ets>flicche</ets>,
<ets>flikke</ets>, AS. <ets>flicce</ets>, akin to Icel.
<ets>flikki</ets>; cf. Icel. <ets>fl<imac/k</ets> flap, tatter; perh.
akin to E. <ets>fleck</ets>. Cf. <er>Flick</er>, <pos>n.</pos>]</ety>
<sn>1.</sn> <def>The side of a hog salted and cured; a side of
bacon.</def> <rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One of several planks, smaller timbers, or iron
plates, which are secured together, side by side, to make a large girder
or built beam.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The outside piece of a sawed log; a slab.</def>
<mark>[Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flitch</ent><br/
<hw>Flitch</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Flitched</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Flitching</conjf>.]</vmorph> <ety>[See <er>Flitch</er>,
<pos>n.</pos>]</ety> <def>To cut into, or off in, flitches or strips;
<as>as, to <ex>flitch</ex> logs; to <ex>flitch</ex>
bacon</as>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Flite</ent><br/
<hw>Flite</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[AS.
<ets>fl<imac/tan</ets> to strive, contend, quarrel; akin to G.
<ets>fleiss</ets> industry.]</ety> <def>To scold; to quarrel.</def>
<mark>[Prov. Eng.]</mark> <rj><au>Grose.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flyte</ent><br/
<ent>Flite</ent><br/
<mhw>{ <hw>Flite</hw>, <hw>Flyte</hw> }</mhw> <pr>(?)</pr>,
<pos>n.</pos> <ety>[AS. <ets>fl<imac/t</ets>. See <er>Flite</er>.]</ety>
<def>Strife; dispute; abusive or upbraiding talk, as in fliting;
wrangling.</def> <mark>[Obs. or Scot. & Prov. Eng.]</mark></p>

<p><q>The bird of Pallas has also a good <ldquo/<qex>flyte</qex><rdquo/
on the moral side . . . in his suggestion that the principal effect of
the nightingale's song is to make women false to their husbands.</q>
<rj><qau>Saintsbury.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Flitter</ent><br/
<hw>Flit"ter</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To flutter.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flitter</ent><br/
<hw>Flit"ter</hw>, <pos>v. t.</pos> <def>To flutter; to move quickly;
<as>as, to <ex>flitter</ex> the cards</as>.</def> <mark>[R.]</mark>
<rj><au>Lowell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flitter</ent><br/
<hw>Flit"ter</hw>, <pos>n.</pos> <ety>[Cf. G. <ets>flitter</ets>
spangle, tinsel, <ets>flittern</ets> to make a tremulous motion, to
glitter. Cf. <er>Flitter</er>, <pos>v. i.</pos>]</ety> <def>A rag; a
tatter; a small piece or fragment.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flittermouse</ent><br/
<hw>Flit"ter*mouse`</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Flitter</ets>, v.i. + <ets>mouse</ets>; cf. G.
<ets>fledermaus</ets>, OHG. <ets>fledarm<umac/s</ets>. Cf.
<er>Flickermouse</er>, <er>Flindermouse</er>.]</ety> <fld>(Zool.)</fld>
<def>A bat; -- called also <altname>flickermouse</altname>,
<altname>flindermouse</altname>, and
<altname>flintymouse</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flittern</ent><br/
<hw>Flit"tern</hw> <pr>(?)</pr>, <pos>a.</pos> <def>A term applied to
the bark obtained from young oak trees.</def>
<rj><au>McElrath.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flittiness</ent><br/
<hw>Flit"ti*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<er>Flitty</er>.]</ety> <def>Unsteadiness; levity; lightness.</def>
<mark>[Obs.]</mark> <rj><au>Bp. Hopkins.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flitting</ent><br/
<hw>Flit"ting</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A flying
with lightness and celerity; a fluttering.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A removal from one habitation to another.</def>
<mark>[Scot. & Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>A neighbor had lent his cart for the <qex>flitting</qex>, and it
was now standing loaded at the door, ready to move away.</q>
<rj><qau>Jeffrey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flytting</ent><br/
<ent>Flitting</ent><br/
<mhw>{ <hw>Flitt"ing</hw>, <hw>Flytt"ing</hw> }</mhw> <pr>(?)</pr>,
<pos>n.</pos> <def>Contention; strife; scolding; specif., a kind of
metrical contest between two persons, popular in Scotland in the 16th
century.</def> <mark>[Obs. or Scot.]</mark></p>

<p><q>These <ldquo/<qex>flytings</qex><rdquo/ consisted of alternate
torrents of sheer Billingsgate poured upon each other by the
combatants.</q> <rj><qau>Saintsbury.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Flittingly</ent><br/
<hw>Flit"ting*ly</hw>, <pos>adv.</pos> <def>In a flitting
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flitty</ent><br/
<hw>Flit"ty</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From
<er>Flit</er>.]</ety> <def>Unstable; fluttering.</def>
<mark>[Obs.]</mark> <rj><au>Dr. H. More.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flix</ent><br/
<hw>Flix</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf.
<er>Flax</er>.]</ety> <def>Down; fur.</def> <mark>[Obs. or Eng.]</mark>
<rj><au>J. Dyer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flix</ent><br/
<hw>Flix</hw>, <pos>n.</pos> <def>The flux; dysentery.</def>
<mark>[Obs.]</mark> <rj><au>Udall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Flix weed</b></col> <fld>(Bot.)</fld>, <cd>the
<spn>Sisymbrium Sophia</spn>, a kind of hedge mustard, formerly used as
a remedy for dysentery.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flo</ent><br/
<hw>Flo</hw> <pr>(fl<omac/)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Flon</plw> <pr>(fl<omac/n)</pr>.</plu> <ety>[AS.
<ets>fl<amac/</ets>, <ets>fl<amac/n</ets>.]</ety> <def>An arrow.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Float</ent><br/
<hw>Float</hw> <pr>(fl<omac/t)</pr>, <pos>n.</pos><ety>[OE.
<ets>flote</ets> ship, boat, fleet, AS. <ets>flota</ets> ship, fr.
<ets>fle<oacute/tan</ets> to float; akin to D. <ets>vloot</ets> fleet,
G. <ets>floss</ets> raft, Icel. <ets>floti</ets> float, raft, fleet, Sw.
<ets>flotta</ets>. <root/ 84. See <er>Fleet</er>, <pos>v. i.</pos>, and
cf. <er>Flotilla</er>, <er>Flotsam</er>, <er>Plover</er>.]</ety>
<sn>1.</sn> <def>Anything which floats or rests on the surface of a
fluid, as to sustain weight, or to indicate the height of the liquid
surface, or mark the place of, something.</def> Specifically:
<sd>(a)</sd> <def>A mass of timber or boards fastened together, and
conveyed down a stream by the current; a raft.</def> <sd>(b)</sd>
<def>The hollow, metallic ball of a self-acting faucet, which floats
upon the water in a cistern or boiler.</def> <sd>(c)</sd> <def>The cork
or quill used in angling, to support the bait line, and indicate the
bite of a fish.</def> <sd>(d)</sd> <def>Anything used to buoy up
whatever is liable to sink; an inflated bag or pillow used by persons
learning to swim; a life preserver.</def> <sd>(e)</sd> <def>The hollow,
metallic ball which floats on the fuel in the fuel tank of a vehicle to
indicate the level of the fuel surface, and thus the amount of fuel
remaining.</def> <sd>(f)</sd> <def>A hollow elongated tank mounted under
the wing of a seaplane which causes the plane to float when resting on
the surface of the water.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><q>This reform bill . . . had been used as a <qex>float</qex> by the
conservative ministry.</q> <rj><qau>J. P. Peters.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A float board. See <cref>Float board</cref>
(below).</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Tempering)</fld> <def>A contrivance for affording a
copious stream of water to the heated surface of an object of large
bulk, as an anvil or die.</def> <rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The act of flowing; flux; flow.</def>
<mark>[Obs.]</mark> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A quantity of earth, eighteen feet square and one
foot deep.</def> <mark>[Obs.]</mark> <rj><au>Mortimer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Plastering)</fld> <def>The trowel or tool with
which the floated coat of plastering is leveled and smoothed.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>A polishing block used in marble working; a
runner.</def> <rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>A single-cut file for smoothing; a tool used by
shoemakers for rasping off pegs inside a shoe.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>A coal cart.</def> <mark>[Eng.]</mark>
<rj><au>Simmonds.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <def>The sea; a wave. See <er>Flote</er>,
<pos>n.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>11.</sn> <fld>(Banking)</fld> <def>The free use of money for a
time between occurrence of a transaction (such as depositing a check or
a purchase made using a credit card), and the time when funds are
withdrawn to cover the transaction; also, the money made available
between transactions in that manner.</def><br/
[<source>PJC</source>]</p>

<p><sn>12.</sn> <def>a vehicle on which an exhibit or display is
mounted, driven or pulled as part of a parade. The float often is based
on a large flat platform, and may contain a very elaborate structure
with a tableau or people.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Float board</b></col>, <cd>one of the boards fixed
radially to the rim of an undershot water wheel or of a steamer's paddle
wheel; -- a vane.</cd> -- <col><b>Float case</b></col>
<fld>(Naut.)</fld>, <cd>a caisson used for lifting a ship.</cd> --
<mcol><col><b>Float copper</b></col> <it>or</it> <col><b>Float
gold</b></col></mcol> <fld>(Mining)</fld>, <cd>fine particles of
metallic copper or of gold suspended in water, and thus liable to be
lost.</cd> -- <col><b>Float ore</b></col>, <cd>water-worn particles of
ore; fragments of vein material found on the surface, away from the vein
outcrop.</cd> <au>Raymond.</au> -- <col><b>Float stone</b></col>
<fld>(Arch.)</fld>, <cd>a siliceous stone used to rub stonework or
brickwork to a smooth surface.</cd> -- <col><b>Float valve</b></col>,
<cd>a valve or cock acted upon by a float. See <er>Float</er>, 1
<sd>(b)</sd>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Float</ent><br/
<hw>Float</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Floated</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Floating</conjf>.]</vmorph> <ety>[OE. <ets>flotien</ets>,
<ets>flotten</ets>, AS. <ets>flotian</ets> to float, swim, fr.
<ets>fle<oacute/tan</ets>. See <er>Float</er>, <pos>n.</pos>]</ety>
<sn>1.</sn> <def>To rest on the surface of any fluid; to swim; to be
buoyed up.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The ark no more now <qex>floats</qex>, but seems on ground.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Three blustering nights, borne by the southern blast,<br/
I <qex>floated</qex>.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To move quietly or gently on the water, as a raft;
to drift along; to move or glide without effort or impulse on the
surface of a fluid, or through the air.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They stretch their broad plumes and <qex>float</qex> upon the
wind.</q> <rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>There seems a <qex>floating</qex> whisper on the hills.</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Float</ent><br/
<hw>Float</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To cause to float; to
cause to rest or move on the surface of a fluid; <as>as, the tide
<ex>floated</ex> the ship into the harbor</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Had <qex>floated</qex> that bell on the Inchcape rock.</q>
<rj><qau>Southey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To flood; to overflow; to cover with
water.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Proud Pactolus <qex>floats</qex> the fruitful lands.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Plastering)</fld> <def>To pass over and level the
surface of with a float while the plastering is kept wet.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To support and sustain the credit of, as a
commercial scheme or a joint-stock company, so as to enable it to go
into, or continue in, operation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Floatable</ent><br/
<hw>Float"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>That may be
floated.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Floatage</ent><br/
<hw>Float"age</hw> <pr>(?; 48)</pr>, <pos>n.</pos> <def>Same as
<er>Flotage</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Floatation</ent><br/
<hw>Float*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Flotation</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Floater</ent><br/
<hw>Float"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who
floats or swims.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A float for indicating the height of a liquid
surface.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Politics)</fld> <sd>(a)</sd> <def>A voter who
shifts from party to party, esp. one whose vote is purchasable.</def>
<mark>[U. S.]</mark> <sd>(b)</sd> <def>A person, as a delegate to a
convention or a member of a legislature, who represents an irregular
constituency, as one formed by a union of the voters of two counties
neither of which has a number sufficient to be allowed a (or an extra)
representative of its own.</def> <mark>[U. S.]</mark> <sd>(c)</sd>
<def>A person who votes illegally in various polling places or election
districts, either under false registration made by himself or under the
name of some properly registered person who has not already voted.</def>
<mark>[U. S.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Floating</ent><br/
<hw>Float"ing</hw>, <pos>a.</pos> <sn>1.</sn> <def>Buoyed upon or in a
fluid; a, the <xex>floating</xex> timbers of a wreck;
<xex>floating</xex> motes in the air.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Free or lose from the usual attachment; <as>as, the
<ex>floating</ex> ribs in man and some other animals</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Not funded; not fixed, invested, or determined;
<as>as, <ex>floating</ex> capital; a <ex>floating</ex>
debt.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Trade was at an end. <qex>Floating</qex> capital had been
withdrawn in great masses from the island.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Floating anchor</b></col> <fld>(Naut.)</fld>, <cd>a drag
or sea anchor; drag sail.</cd> -- <col><b>Floating battery</b></col>
<fld>(Mil.)</fld>, <cd>a battery erected on rafts or the hulls of ships,
chiefly for the defense of a coast or the bombardment of a place.</cd>
-- <col><b>Floating bridge</b></col>. <sd>(a)</sd> <cd>A bridge
consisting of rafts or timber, with a floor of plank, supported wholly
by the water; a bateau bridge.</cd> See <er>Bateau</er>. <sd>(b)</sd>
<fld>(Mil.)</fld> <cd>A kind of double bridge, the upper one projecting
beyond the lower one, and capable of being moved forward by pulleys; --
used for carrying troops over narrow moats in attacking the outworks of
a fort.</cd> <sd>(c)</sd> <cd>A kind of ferryboat which is guided and
impelled by means of chains which are anchored on each side of a stream,
and pass over wheels on the vessel, the wheels being driven by stream
power.</cd> <sd>(d)</sd> <cd>The landing platform of a ferry dock.</cd>
-- <col><b>Floating cartilage</b></col> <fld>(Med.)</fld>, <cd>a
cartilage which moves freely in the cavity of a joint, and often
interferes with the functions of the latter.</cd> -- <col><b>Floating
dam</b></col>. <sd>(a)</sd> <cd>An anchored dam.</cd> <sd>(b)</sd> <cd>A
caisson used as a gate for a dry dock.</cd> -- <col><b>Floating
derrick</b></col>, <cd>a derrick on a float for river and harbor use, in
raising vessels, moving stone for harbor improvements, etc.</cd> --
<col><b>Floating dock</b></col>. <fld>(Naut.)</fld> <cd>See under
<er>Dock</er>.</cd> -- <col><b>Floating harbor</b></col>, <cd>a
breakwater of cages or booms, anchored and fastened together, and used
as a protection to ships riding at anchor to leeward.</cd>
<au>Knight.</au> -- <col><b>Floating heart</b></col> <fld>(Bot.)</fld>,
<cd>a small aquatic plant (<spn>Limnanthemum lacunosum</spn>) whose
heart-shaped leaves float on the water of American ponds.</cd> --
<col><b>Floating island</b></col>, <cd>a dish for dessert, consisting of
custard with floating masses of whipped cream or white of eggs.</cd> --
<col><b>Floating kidney</b></col>. <fld>(Med.)</fld> <cd>See
<cref>Wandering kidney</cref>, under <er>Wandering</er>.</cd> --
<col><b>Floating light</b></col>, <cd>a light shown at the masthead of a
vessel moored over sunken rocks, shoals, etc., to warn mariners of
danger; a light-ship; also, a light erected on a buoy or floating
stage.</cd> -- <col><b>Floating liver</b></col>. <fld>(Med.)</fld>
<cd>See <cref>Wandering liver</cref>, under <er>Wandering</er>.</cd> --
<col><b>Floating pier</b></col>, <cd>a landing stage or pier which rises
and falls with the tide.</cd> -- <col><b>Floating ribs</b></col>
<fld>(Anat.)</fld>, <cd>the lower or posterior ribs which are not
connected with the others in front; in man they are the last two
pairs.</cd> -- <col><b>Floating screed</b></col>
<fld>(Plastering)</fld>, <cd>a strip of plastering first laid on, to
serve as a guide for the thickness of the coat.</cd> -- <col><b>Floating
threads</b></col> <fld>(Weaving)</fld>, <cd>threads which span several
other threads without being interwoven with them, in a woven
fabric.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 572 --></p>

<p><ent>Floating</ent><br/
<hw>Float"ing</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<fld>(Weaving)</fld> <def>Floating threads. See <cref>Floating
threads</cref>, above.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The second coat of three-coat plastering.</def>
<rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The process of rendering oysters and scallops plump
by placing them in fresh or brackish water; -- called also
<altname>fattening</altname>, <altname>plumping</altname>, and
<altname>laying out</altname>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>lien</ent><br/
<ent>Floating charge</ent><br/
<mhw>{ <hw>Floating charge</hw>, <hw>lien</hw>, etc. }</mhw>
<fld>(Law)</fld> <def>A charge, lien, etc., that successively attaches
to such assets as a person may have from time to time, leaving him more
or less free to dispose of or encumber them as if no such charge or lien
existed.</def></p>

<p><ent>Floatingly</ent><br/
<hw>Float"ing*ly</hw>, <pos>adv.</pos> <def>In a floating
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>floatplane</ent><br/
<hw>floatplane</hw> <pos>n.</pos> <def>a plane equipped with pontoons
for landing or taking off from water.</def><br/
<syn><b>Syn. --</b> pontoon plane, seaplane.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Floaty</ent><br/
<hw>Float"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Swimming on the
surface; buoyant; light.</def> <rj><au>Sir W. Raleigh.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flobert</ent><br/
<hw>Flo"bert</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Gun.)</fld> <def>A
small cartridge designed for target shooting; -- sometimes called
<altname>ball cap</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Flobert rifle</b></col>, <cd>a rifle adapted to the use
of floberts.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Floccillation</ent><br/
<hw>Floc`cil*la"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>floccus</ets> a flock of wool. Cf. <er>Flock</er> of wool.]</ety>
<fld>(Med.)</fld> <def>A delirious picking of bedclothes by a sick
person, as if to pick off flocks of wool; carphology; -- an alarming
symptom in acute diseases.</def> <rj><au>Dunglison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Floccose</ent><br/
<hw>Floc*cose"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>floccosus</ets>. Cf. 2d <er>Flock</er>, <pos>n.</pos>]</ety>
<sn>1.</sn> <def>Spotted with small tufts like wool.</def>
<rj><au>Wright.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>Having tufts of soft hairs, which
are often deciduous.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Floccular</ent><br/
<hw>Floc"cu*lar</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Anat.)</fld>
<def>Of or pertaining to the flocculus.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flocculate</ent><br/
<hw>Floc"cu*late</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Flocculated</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Flocculating</conjf>.]</vmorph> <fld>(Geol.)</fld> <def>To
aggregate into small lumps.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flocculate</ent><br/
<hw>Floc"cu*late</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Furnished with tufts of curly hairs, as some insects.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flocculate</ent><br/
<hw>Floc"cu*late</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To convert
into floccules or flocculent aggregates; to make granular or crumbly;
<as>as, the <ex>flocculating</ex> of a soil improves its mechanical
condition</as>.</def></p>

<p><q>When applied to clay soils it [lime] binds the small particles
together, or <qex>flocculates</qex> them.</q> <rj><qau>I. P.
Roberts.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Flocculation</ent><br/
<hw>Floc`cu*la"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Geol.)</fld>
<sn>1.</sn> <def>The process by which small particles of fine soils and
sediments aggregate into larger lumps.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The process or event in which masses of a solid
substance of perceptible size form in a liquid by aggregation of smaller
particles, and usually sediment to the bottom of the containing vessel;
<as>as, addition of a cationic polymer can cause <ex>flocculation</ex>
of a negatively charged colloidal suspension</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Floccule</ent><br/
<hw>Floc"cule</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Flocculus</er>.]</ety> <sn>1.</sn> <def>A detached mass of loosely
fibrous structure like a shredded tuft of wool.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <fld>(Chem.)</fld> <def>Specif.: A small particle of an
insoluble substance formed in a liquid by the union of smaller
particles.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Flocculence</ent><br/
<hw>Floc"cu*lence</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state of
being flocculent.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flocculent</ent><br/
<hw>Floc"cu*lent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Flock</er> of wool.]</ety> <sn>1.</sn> <def>Clothed with small
flocks or flakes; woolly.</def> <rj><au>Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>Applied to the down of newly
hatched or unfledged birds.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Chem.)</fld> <def>Having a structure like shredded
wool, as some precipitates.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Flocculus</ent><br/
\'d8<hw>Floc"cu*lus</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Flocculi</plw> <pr>(#)</pr>.</plu> <ety>[NL., dim. of L.
<ets>floccus</ets> a lock or flock of wool.]</ety> <fld>(Anat.)</fld>
<def>A small lobe in the under surface of the cerebellum, near the
middle peduncle; the subpeduncular lobe.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Floccus</ent><br/
\'d8<hw>Floc"cus</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Flocci</plw> <pr>(#)</pr>.</plu> <ety>[L., a flock of wool.]</ety>
<sn>1.</sn> <fld>(Zool.)</fld> <sd>(a)</sd> <def>The tuft of hair
terminating the tail of mammals.</def> <sd>(b)</sd> <def>A tuft of
feathers on the head of young birds.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>A woolly filament sometimes
occurring with the sporules of certain fungi.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flock</ent><br/
<hw>Flock</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS. <ets>flocc</ets>
flock, company; akin to Icel. <ets>flokkr</ets> crowd, Sw.
<ets>flock</ets>, Dan. <ets>flok</ets>; prob. orig. used of flows, and
akin to E. <ets>fly</ets>. See <er>Fly</er>.]</ety> <sn>1.</sn> <def>A
company or collection of living creatures; -- especially applied to
sheep and birds, rarely to persons or (except in the plural) to cattle
and other large animals; <as>as, a <ex>flock</ex> of ravenous
fowl</as>.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The heathen . . . came to Nicanor by <qex>flocks</qex>.</q>
<rj><qau>2 Macc. xiv. 14.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A Christian church or congregation; considered in
their relation to the pastor, or minister in charge.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>As half amazed, half frighted all his <qex>flock</qex>.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flock</ent><br/
<hw>Flock</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Flocked</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Flocking</conjf>.]</vmorph> <def>To gather in companies or
crowds.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Friends daily <qex>flock</qex>.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Flocking fowl</b></col> <fld>(Zool.)</fld>, <cd>the
greater scaup duck.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flock</ent><br/
<hw>Flock</hw>, <pos>v. t.</pos> <def>To flock to; to crowd.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Good fellows, trooping, <qex>flocked</qex> me so.</q>
<rj><qau>Taylor (1609).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flock</ent><br/
<hw>Flock</hw>, <pos>n.</pos> <ety>[OE. <ets>flokke</ets>; cf. D.
<ets>vlok</ets>, G. <ets>flocke</ets>, OHG. <ets>floccho</ets>, Icel.
<ets>fl<omac/ki</ets>, perh. akin to E. <ets>flicker</ets>,
<ets>flacker</ets>, or cf. L. <ets>floccus</ets>, F.
<ets>floc</ets>.]</ety> <sn>1.</sn> <def>A lock of wool or
hair.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I prythee, Tom, beat Cut's saddle, put a few <qex>flocks</qex> in
the point [pommel].</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Woolen or cotton refuse (<pos>sing. <or/ pl.</pos>),
old rags, etc., reduced to a degree of fineness by machinery, and used
for stuffing unpholstered furniture.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Very fine, sifted, woolen refuse, especially that
from shearing the nap of cloths, used as a coating for wall paper to
give it a velvety or clothlike appearance; also, the dust of vegetable
fiber used for a similar purpose.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Flock bed</b></col>, <cd>a bed filled with flocks or
locks of coarse wool, or pieces of cloth cut up fine.</cd> <ldquo/Once a
<xex>flock bed</xex>, but repaired with straw.<rdquo/ <au>Pope.</au> --
<col><b>Flock paper</b></col>, <cd>paper coated with flock fixed with
glue or size.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flock</ent><br/
<hw>Flock</hw>, <pos>v. t.</pos> <def>To coat with flock, as wall paper;
to roughen the surface of (as glass) so as to give an appearance of
being covered with fine flock.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flockling</ent><br/
<hw>Flock"ling</hw>, <pos>n.</pos> <def>A lamb.</def>
<mark>[Obs.]</mark> <rj><au>Brome (1659).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flockly</ent><br/
<hw>Flock"ly</hw>, <pos>adv.</pos> <def>In flocks; in crowds.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flockmel</ent><br/
<hw>Flock"mel</hw> <pr>(?)</pr>, <pos>adv.</pos> <ety>[AS.
<ets>flocm<?/lum</ets>. See <er>Meal</er> part.]</ety> <def>In a flock;
in a body.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>That <qex>flockmel</qex> on a day they to him went.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flocky</ent><br/
<hw>Flock"y</hw>, <pos>a.</pos> <def>Abounding with flocks;
floccose.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Floe</ent><br/
<hw>Floe</hw> <pr>(fl<omac/)</pr>, <pos>n.</pos> <ety>[Cf. Dan.
<ets>flag</ets> af iis, iis<ets>flage</ets>, Sw. <ets>flaga</ets>,
<ets>flake</ets>, is<ets>flaga</ets>, is<ets>flake</ets>. See
<er>Flag</er> a flat stone.]</ety> <def>A low, flat mass of floating
ice.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Floe rat</b></col> <fld>(Zool.)</fld>, <cd>a seal
(<spn>Phoca f<oe/tida</spn>).</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flog</ent><br/
<hw>Flog</hw> <pr>(fl<ocr/g)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Flogged</conjf> <pr>(fl<ocr/gd)</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>Flogging</conjf> <pr>(-g<icr/ng)</pr>.]</vmorph>
<ety>[Cf. Scot. <ets>fleg</ets> blow, stroke, kick, AS.
<ets>flocan</ets> to strike, or perh. fr. L. <ets>flagellare</ets> to
whip. Cf. <er>Flagellate</er>.]</ety> <def>To beat or strike with a rod
or whip; to whip; to lash; to chastise with repeated blows.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flogger</ent><br/
<hw>Flog"ger</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who
flogs.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A kind of mallet for beating the bung stave of a
cask to start the bung.</def> <rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flogging</ent><br/
<hw>Flog"ging</hw> <pr>(?)</pr>, <pos>a. & n.</pos> <def>from
<er>Flog</er>, <pos>v. t.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Flogging chisel</b></col> <fld>(Mach.)</fld>, <cd>a large
cold chisel, used in chipping castings.</cd> -- <col><b>Flogging
hammer</b></col>, <cd>a small sledge hammer used for striking a flogging
chisel.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flon</ent><br/
<hw>Flon</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <def>See
<er>Flo</er>.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flong</ent><br/
<hw>Flong</hw> <pr>(? <or/ ?)</pr>, <mark>obs.</mark> <def><pos>imp. &
p. p.</pos> of <er>Fling</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flong</ent><br/
<hw>Flong</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Of the same origin as
<ets>flawn</ets>, <ets>flan</ets>, a metal disk.]</ety>
<fld>(Stereotyping)</fld> <def>A compressed mass of paper sheets,
forming a matrix or mold for stereotype plates.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Flood</ent><br/
<hw>Flood</hw> <pr>(fl<ucr/d)</pr>, <pos>n.</pos> <ety>[OE.
<ets>flod</ets> a flowing, stream, flood, AS. <ets>fl<omac/d</ets>; akin
to D. <ets>vloed</ets>, OS. <ets>fl<omac/d</ets>, OHG. <ets>fluot</ets>,
G. <ets>flut</ets>, Icel. <ets>fl<omac/<edh/</ets>, Sw. & Dan.
<ets>flod</ets>, Goth. <ets>fl<omac/dus</ets>; from the root of E.
<ets>flow</ets>. <root/80. See <er>Flow</er>, <pos>v. i.</pos>]</ety>
<sn>1.</sn> <def>A great flow of water; a body of moving water; the
flowing stream, as of a river; especially, a body of water, rising,
swelling, and overflowing land not usually thus covered; a deluge; a
freshet; an inundation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A covenant never to destroy<br/
The earth again by <qex>flood</qex>.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The flowing in of the tide; the semidiurnal swell or
rise of water in the ocean; -- opposed to <contr>ebb</contr>; <as>as,
young <ex>flood</ex>; high <ex>flood</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>There is a tide in the affairs of men,<br/
Which, taken at the <qex>flood</qex>, leads on to fortune.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A great flow or stream of any fluid substance;
<as>as, a <ex>flood</ex> of light; a <ex>flood</ex> of lava</as>; hence,
a great quantity widely diffused; an overflowing; a superabundance;
<as>as, a <ex>flood</ex> of bank notes; a <ex>flood</ex> of paper
currency.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Menstrual discharge; menses.</def>
<rj><au>Harvey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Flood anchor</b></col> <fld>(Naut.)</fld> <cd>, the
anchor by which a ship is held while the tide is rising.</cd> --
<col><b>Flood fence</b></col>, <cd>a fence so secured that it will not
be swept away by a flood.</cd> -- <col><b>Flood gate</b></col>, <cd>a
gate for shutting out, admitting, or releasing, a body of water; a tide
gate.</cd> -- <col><b>Flood mark</b></col>, <cd>the mark or line to
which the tide, or a flood, rises; high-water mark.</cd> --
<col><b>Flood tide</b></col>, <cd>the rising tide; -- opposed to
<contr>ebb tide</contr>.</cd> -- <col><b>The Flood</b></col>, <cd>the
deluge in the days of Noah.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flood</ent><br/
<hw>Flood</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Flooded</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Flooding</conjf>.]</vmorph> <sn>1.</sn> <def>To overflow; to
inundate; to deluge; <as>as, the swollen river <ex>flooded</ex> the
valley</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To cause or permit to be inundated; to fill or cover
with water or other fluid; <as>as, to <ex>flood</ex> arable land for
irrigation</as>; to fill to excess or to its full capacity; <as>as, to
<ex>flood</ex> a country with a depreciated currency</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Floodage</ent><br/
<hw>Flood"age</hw> <pr>(?; 48)</pr>, <pos>n.</pos>
<def>Inundation.</def> <mark>[R.]</mark> <rj><au>Carlyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>flooded</ent><br/
<hw>flooded</hw> <pos>adj.</pos> <sn>1.</sn> <def>covered or overflowing
with water.</def><br/
<syn><b>Syn. --</b> afloat(predicate), awash(predicate).</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>filled to overflowing as if with water; <as>as, a
desk flooded with applications</as>.</def><br/
<syn><b>Syn. --</b> inundated, swamped.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Flooder</ent><br/
<hw>Flood"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who floods
anything.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>floodhead</ent><br/
<hw>floodhead</hw> <pos>n.</pos> <def>a wall of water rushing ahead of
the flood; <as>as, we were lucky to be safe when the <ex>floodheads</ex>
hit</as>.</def>.<br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Flooding</ent><br/
<hw>Flood"ing</hw>, <pos>n.</pos> <def>The filling or covering with
water or other fluid; overflow; inundation; the filling anything to
excess.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Med.)</fld> <def>An abnormal or excessive discharge
of blood from the uterus.</def> <rj><au>Dunglison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>floodlit</ent><br/
<hw>floodlit</hw> <pos>adj.</pos> <def>Illuminated by means of
floodlights.</def><br/
<syn><b>Syn. --</b> floodlighted.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Flook</ent><br/
<hw>Flook</hw> <pr>(fl<oomac/k)</pr>, <pos>n.</pos> <def>A fluke of an
anchor.</def></p>

<p><ent>Flukan</ent><br/
<ent>Flookan</ent><br/
<mhw>{ <hw>Flook"an</hw> <pr>(?)</pr>, <hw>Flu"kan</hw> <pr>(?)</pr>
}</mhw>, <pos>n.</pos> <fld>(Mining)</fld> <def>See
<er>Flucan</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flooky</ent><br/
<hw>Flook"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Fluky.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Floor</ent><br/
<hw>Floor</hw> <pr>(fl<omac/r)</pr>, <pos>n.</pos> <ety>[AS.
<ets>fl<omac/r</ets>; akin to D. <ets>vloer</ets>, G. <ets>flur</ets>
field, floor, entrance hall, Icel. <ets>fl<omac/r</ets> floor of a cow
stall, cf. Ir. & Gael. <ets>lar</ets> floor, ground, earth, W.
<ets>llawr</ets>, perh. akin to L. <ets>planus</ets> level. Cf.
<er>Plain</er> smooth.]</ety> <sn>1.</sn> <def>The bottom or lower part
of any room; the part upon which we stand and upon which the movables in
the room are supported.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The structure formed of beams, girders, etc., with
proper covering, which divides a building horizontally into stories.
<xex>Floor</xex> in sense 1 is, then, the upper surface of
<xex>floor</xex> in sense 2.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The surface, or the platform, of a structure on
which we walk or travel; <as>as, the <ex>floor</ex> of a
bridge</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A story of a building. See <er>Story</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Legislative Assemblies)</fld> <sd>(a)</sd> <def>The
part of the house assigned to the members.</def> <sd>(b)</sd> <def>The
right to speak; <as>as, the gentleman from Iowa has the
<ex>floor</ex></as>.</def> <mark>[U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Instead of <xex>he has the floor</xex>, the English say,
<xex>he is in possession of the house</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Naut.)</fld> <def>That part of the bottom of a
vessel on each side of the keelson which is most nearly
horizontal.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Mining)</fld> <sd>(a)</sd> <def>The rock underlying
a stratified or nearly horizontal deposit.</def> <sd>(b)</sd> <def>A
horizontal, flat ore body.</def> <rj><au>Raymond.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Floor cloth</b></col>, <cd>a heavy fabric, painted,
varnished, or saturated, with waterproof material, for covering floors;
oilcloth.</cd> -- <col><b>Floor cramp</b></col>, <cd>an implement for
tightening the seams of floor boards before nailing them in
position.</cd> -- <col><b>Floor light</b></col>, <cd>a frame with glass
panes in a floor.</cd> -- <col><b>Floor plan</b></col>. <sd>(a)</sd>
<fld>(Shipbuilding)</fld> <cd>A longitudinal section, showing a ship as
divided at the water line.</cd> <sd>(b)</sd> <fld>(Arch.)</fld> <cd>A
horizontal section, showing the thickness of the walls and partitions,
arrangement of passages, apartments, and openings at the level of any
floor of a house.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Floor</ent><br/
<hw>Floor</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Floored</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Flooring</conjf>.]</vmorph> <sn>1.</sn> <def>To cover with a
floor; to furnish with a floor; <as>as, to <ex>floor</ex> a house with
pine boards</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To strike down or lay level with the floor; to knock
down; hence, to silence by a conclusive answer or retort; <as>as, to
<ex>floor</ex> an opponent</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Floored</qex> or crushed by him.</q>
<rj><qau>Coleridge.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To finish or make an end of; <as>as, to
<ex>floor</ex> a college examination</as>.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I've <qex>floored</qex> my little-go work.</q> <rj><qau>T.
Hughes.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Floorage</ent><br/
<hw>Floor"age</hw> <pr>(?; 48)</pr>, <pos>n.</pos> <def>Floor
space.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>floorboard</ent><br/
<hw>floorboard</hw> <pos>n.</pos> <sn>1.</sn> <def>a board in the
floor.</def><br/
<syn><b>Syn. --</b> floor board.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>the floor of an automobile.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>floorcover</ent><br/
<hw>floorcover</hw> <pos>n.</pos> <def>a covering for the floor of an
automobile.</def><br/
<syn><b>Syn. --</b> floor covering.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>floored</ent><br/
<hw>floored</hw> <pos>adj.</pos> <sn>1.</sn> <def>provided with a
floor.</def> <ant>ceilinged</ant><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>knocked down to the floor or ground.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>defeated; overwhelmed.</def><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <def>surprised and confounded; nonplused; <as>as, I was
<ex>floored</ex> by the brilliance of the solution</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Floorer</ent><br/
<hw>Floor"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Anything that floors
or upsets a person, as a blow that knocks him down; a conclusive answer
or retort; a task that exceeds one's abilities.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Floorheads</ent><br/
<hw>Floor"heads`</hw>, <pos>n. pl.</pos> <fld>(Naut.)</fld> <def>The
upper extremities of the floor of a vessel.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flooring</ent><br/
<hw>Floor"ing</hw>, <pos>n.</pos> <def>A platform; the bottom of a room;
a floor; pavement. See <er>Floor</er>, <pos>n.</pos></def>
<rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Material for the construction of a floor or
floors.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Floorless</ent><br/
<hw>Floor"less</hw>, <pos>a.</pos> <def>Having no floor.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Floorwalker</ent><br/
<hw>Floor"walk`er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who walks
about in a large retail store as an overseer and director.</def>
<mark>[U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flop</ent><br/
<hw>Flop</hw> <pr>(fl<ocr/p)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Flopped</conjf> <pr>(fl<ocr/pt)</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>Flopping</conjf>.]</vmorph> <ety>[A variant of
<ets>flap</ets>.]</ety> <sn>1.</sn> <def>To clap or strike, as a bird
its wings, a fish its tail, etc.; to flap.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To turn suddenly, as something broad and flat.</def>
<mark>[Colloq.]</mark> <rj><au>Fielding.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flop</ent><br/
<hw>Flop</hw> <pr>(fl<ocr/p)</pr>, <pos>v. i.</pos> <sn>1.</sn> <def>To
strike about with something broad and flat, as a fish with its tail, or
a bird with its wings; to rise and fall; <as>as, the brim of a hat
<ex>flops</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To fall, sink, or throw one's self, heavily,
clumsily, and unexpectedly on the ground.</def> <mark>[Colloq.]</mark>
<rj><au>Dickens.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flop</ent><br/
<hw>Flop</hw>, <pos>n.</pos> <def>Act of flopping.</def>
<mark>[Colloq.]</mark> <rj><au>W. H. Russell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>flophouse</ent><br/
<hw>flophouse</hw> <pos>n.</pos> <def>a cheap and usually seedy lodging
house or hotel.</def><br/
<syn><b>Syn. --</b> dosshouse.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Floppy</ent><br/
<hw>Flop"py</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Having a tendency to
flop or flap; <as>as, a <ex>floppy</ex> hat brim</as>.</def> <rj><au>G.
Eliot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flopwing</ent><br/
<hw>Flop"wing`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>The lapwing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flora</ent><br/
<hw>Flo"ra</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., the goddess of
flowers, from <ets>flos</ets>, <ets>floris</ets>, flower. See
<er>Flower</er>.]</ety> <sn>1.</sn> <fld>(Rom. Myth.)</fld> <def>The
goddess of flowers and spring.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>The complete system of vegetable
species growing without cultivation in a given locality, region, or
period; a list or description of, or treatise on, such plants.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Floral</ent><br/
<hw>Flo"ral</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>Floralis</ets> belonging to <ets>Flora</ets>: cf. F.
<ets>floral</ets>. See <er>Flora</er>.]</ety> <sn>1.</sn>
<def>Pertaining to Flora, or to flowers; made of flowers; <as>as,
<ex>floral</ex> games, wreaths</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>Containing, or belonging to, a
flower; <as>as, a <ex>floral</ex> bud; a <ex>floral</ex> leaf;
<ex>floral</ex> characters.</as></def> <rj><au>Martyn.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Floral envelope</b></col> <fld>(Bot.)</fld>, <cd>the
calyx and corolla, one or the other of which (mostly the corolla) may be
wanting.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Florally</ent><br/
<hw>Flo"ral*ly</hw>, <pos>adv.</pos> <def>In a floral manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Floramour</ent><br/
<hw>Flo"ra*mour</hw> <pr>(?)</pr>, <pos>n.</pos><ety>[L.
<ets>flos</ets>, <ets>floris</ets>, flower + <ets>amor</ets>love.]</ety>
<def>The plant love-lies-bleeding.</def> <mark>[Obs.]</mark>
<rj><au>Prior.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Floran</ent><br/
<hw>Flo"ran</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Mining)</fld>
<def>Tin ore scarcely perceptible in the stone; tin ore stamped very
fine.</def> <rj><au>Pryce.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Floreal</ent><br/
\'d8<hw>Flo`r<eacute/al"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>flor<eacute/al</ets>, fr. L. <ets>flos</ets>, <ets>floris</ets>,
flower.]</ety> <def>The eight month of the French republican calendar.
It began April 20, and ended May 19. See
<er>Vend<eacute/miare</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Floren</ent><br/
<hw>Flor"en</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL.
<ets>florenus</ets>. See <er>Florin</er>.]</ety> <def>A certain gold
coin; a Florence.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Florence</ent><br/
<hw>Flor"ence</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From the city of
<ets>Florence</ets>: cf. F. <ets>florence</ets> a kind of cloth, OF.
<ets>florin</ets>.]</ety> <sn>1.</sn> <def>An ancient gold coin of the
time of Edward III., of six shillings sterling value.</def>
<rj><au>Camden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A kind of cloth.</def>
<rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Florence flask</b></col>. <cd>See under
<er>Flask</er>.</cd> -- <col><b>Florence oil</b></col>, <cd>olive oil
prepared in Florence.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Florentine</ent><br/
<hw>Flor"en*tine</hw> <pr>(? <or/ ?; 277)</pr>, <pos>a.</pos> <ety>[L.
<ets>Florentinus</ets>, fr. <ets>Florentia</ets> Florence: cf. F.
<ets>florentin</ets>.]</ety> <def>Belonging or relating to Florence, in
Italy.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Florentine mosaic</b></col>, <cd>a mosaic of hard or
semiprecious stones, often so chosen and arranged that their natural
colors represent leaves, flowers, and the like, inlaid in a background,
usually of black or white marble.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Florentine</ent><br/
<hw>Flor"en*tine</hw>, <pos>n.</pos> <sn>1.</sn> <def>A native or
inhabitant of Florence, a city in Italy.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A kind of silk.</def> <rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A kind of pudding or tart; a kind of meat pie.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Stealing custards, tarts, and <qex>florentines</qex>.</q>
<rj><qau>Beau. & Fl.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Florescence</ent><br/
<hw>Flo*res"cence</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Florescent</er>.]</ety> <fld>(Bot.)</fld> <def>A bursting into
flower; a blossoming.</def> <rj><au>Martyn.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Florescent</ent><br/
<hw>Flo*res"cent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>florescens</ets>, p. pr. of <ets>florescere</ets> begin to blossom,
incho. fr. <ets>florere</ets> to blossom, fr. <ets>flos</ets>,
<ets>floris</ets>, flower. See <er>Flower</er>.]</ety> <def>Expanding
into flowers; blossoming.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Floret</ent><br/
<hw>Flo"ret</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>florete</ets>, F. <ets>fleurette</ets>, dim. of OF. <ets>lor</ets>,
F. <ets>fleur</ets>. See <er>Flower</er>, and cf. <er>Floweret</er>, 3d
<er>Ferret</er>.]</ety> <sn>1.</sn> <fld>(Bot.)</fld> <def>A little
flower; one of the numerous little flowers which compose the head or
anthodium in such flowers as the daisy, thistle, and dandelion.</def>
<rj><au>Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <ety>[F. <ets>fleuret</ets>.]</ety> <def>A foil; a blunt
sword used in fencing.</def> <mark>[Obs.]</mark>
<rj><au>Cotgrave.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Floriage</ent><br/
<hw>Flo"ri*age</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>flos</ets>, <ets>floris</ets>, flower.]</ety> <def>Bloom;
blossom.</def> <mark>[Obs.]</mark> <rj><au>J. Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Floriated</ent><br/
<hw>Flo"ri*a`ted</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Arch.)</fld>
<def>Having floral ornaments; <as>as, <ex>floriated</ex> capitals of
Gothic pillars</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Floriation</ent><br/
<hw>Flo`ri*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>Ornamentation by means of flower forms, whether closely imitated or
conventionalized.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>Any floral ornament or decoration.</def>
<rj><au>Rock.</au></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Floricomous</ent><br/
<hw>Flo*ric"o*mous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>flos</ets>, <ets>floris</ets>, flower + <ets>coma</ets>
hair.]</ety> <def>Having the head adorned with flowers.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Floricultural</ent><br/
<hw>Flo`ri*cul"tur*al</hw> <pr>(? <or/ ?; 135)</pr>, <pos>a.</pos>
<def>Pertaining to the cultivation of flowering plants.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Floriculture</ent><br/
<hw>Flo"ri*cul`ture</hw> <pr>(? <or/ ?; 135, 277)</pr>, <pos>n.</pos>
<ety>[L. <ets>flos</ets>, <ets>floris</ets>, flower + <ets>cultura</ets>
culture.]</ety> <def>The cultivation of flowering plants.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Floriculturist</ent><br/
<hw>Flo`ri*cul"tur*ist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One skilled
in the cultivation of flowers; a florist.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Florid</ent><br/
<hw>Flor"id</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>floridus</ets>, fr. <ets>flos</ets>, <ets>floris</ets>, flower. See
<er>Flower</er>.]</ety> <sn>1.</sn> <def>Covered with flowers; abounding
in flowers; flowery.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Fruit from a pleasant and <qex>florid</qex> tree.</q>
<rj><qau>Jer. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Bright in color; flushed with red; of a lively
reddish color; <as>as, a <ex>florid</ex> countenance</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Embellished with flowers of rhetoric; enriched to
excess with figures; excessively ornate; <as>as, a <ex>florid</ex>
style; <ex>florid</ex> eloquence.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Mus.)</fld> <def>Flowery; ornamental; running in
rapid melodic figures, divisions, or passages, as in variations; full of
fioriture or little ornamentations.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Florida bean</ent><br/
<hw>Flor"i*da bean"</hw> <pr>(?)</pr>. <fld>(Bot.)</fld> <sd>(a)</sd>
<def>The large, roundish, flattened seed of <spn>Mucuna urens</spn>. See
under <er>Bean</er>.</def> <sd>(b)</sd> <def>One of the very large seeds
of the <spn>Entada scandens</spn>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Florideae</ent><br/
\'d8<hw>Flo*rid"e*<ae/</hw> <pr>(?)</pr>, <pos>prop. n. pl.</pos>
<ety>[NL., from L. <ets>flos</ets>, <ets>floris</ets>, a flower.]</ety>
<fld>(Bot.)</fld> <def>A subclass of alg<ae/ including all the red or
purplish seaweeds; the <subclass>Rhodosperme<ae/</subclass> of many
authors; -- so called from the rosy or florid color of most of the
species.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Floridian</ent><br/
<hw>Floridian</hw> <pos>prop. n.</pos> <def>a resident of
Florida.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Floridity</ent><br/
<hw>Flo*rid"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The quality of
being florid; floridness.</def> <rj><au>Floyer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Floridly</ent><br/
<hw>Flor"id*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a florid
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Floridness</ent><br/
<hw>Flor"id*ness</hw>, <pos>n.</pos> <def>The quality of being
florid.</def> <rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Floriferous</ent><br/
<hw>Flo*rif"er*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>florifer</ets>; <ets>flos</ets>, <ets>floris</ets>, flower +
<ets>ferre</ets> to bear; cf. F. <ets>florif<egrave/re</ets>.]</ety>
<def>Producing flowers.</def> <rj><au>Blount.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 573 --></p>

<p><ent>Florification</ent><br/
<hw>Flo`ri*fi*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>flos</ets>, <ets>floris</ets>, flower + <ets>facere</ets> to
make.]</ety> <def>The act, process, or time of flowering;
florescence.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Floriform</ent><br/
<hw>Flo"ri*form</hw> <pr>(? <or/ ?)</pr>, <pos>a.</pos> <ety>[L.
<ets>flos</ets>, <ets>floris</ets>, flower + <ets>-form</ets>: cf. F.
<ets>floriforme</ets>.]</ety> <def>Having the form of a flower;
flower-shaped.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Floriken</ent><br/
<hw>Flo"ri*ken</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>An Indian bustard (<spn>Otis aurita</spn>). The Bengal floriken is
<spn>Sypheotides Bengalensis</spn>.</def> <altsp>[Written also
<asp>florikan</asp>, <asp>florikin</asp>,
<asp>florican</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Florilege</ent><br/
<hw>Flo"ri*lege</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>florilegus</ets> flower-culling; <ets>flos</ets>,
<ets>floris</ets>, flower + <ets>legere</ets> to gather: cf. F.
<ets>floril<egrave/ge</ets>.]</ety> <def>The act of gathering
flowers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Florimer</ent><br/
<hw>Flo"ri*mer</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>See <er>Floramour</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Florin</ent><br/
<hw>Flor"in</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>florin</ets>,
It. <ets>florino</ets>, orig., a Florentine coin, with a lily on it, fr.
<ets>flore</ets> a flower, fr. L. <ets>flos</ets>. See <er>Flower</er>,
and cf. <er>Floren</er>.]</ety> <def>A silver coin of Florence, first
struck in the twelfth century, and noted for its beauty. The name is
given to different coins in different countries. The florin of England,
first minted in 1849, is worth two shillings, or about 48 cents; the
florin of the Netherlands, about 40 cents; of Austria, about 36
cents.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Florist</ent><br/
<hw>Flo"rist</hw> <pr>(? <or/ ?; 277)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>fleuriste</ets>, <ets>floriste</ets>, fr. F. <ets>fleur</ets>
flower. See <er>Flower</er>.]</ety> <sn>1.</sn> <def>A cultivator of, or
dealer in, flowers.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who writes a flora, or an account of
plants.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Floroon</ent><br/
<hw>Flo*roon"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>fleuron</ets>. See <er>Flower</er>.]</ety> <def>A border worked
with flowers.</def> <rj><au>Wright.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Florulent</ent><br/
<hw>Flor"u*lent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>florulentus</ets>, fr. <ets>flos</ets>, <ets>floris</ets>,
flower.]</ety> <def>Flowery; blossoming.</def> <mark>[Obs.]</mark>
<rj><au>Blount.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Floscular</ent><br/
<hw>Flos"cu*lar</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Bot.)</fld>
<def>Flosculous.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Floscularian</ent><br/
<hw>Flos`cu*la"ri*an</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From L.
<ets>flosculus</ets> a floweret.]</ety> <fld>(Zool.)</fld> <def>One of a
group of stalked rotifers, having ciliated tentacles around the lobed
disk.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Floscule</ent><br/
<hw>Flos*cule</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>flosculus</ets>, dim. of <ets>flos</ets> flower: cf. F.
<ets>floscule</ets>.]</ety> <fld>(Bot.)</fld> <def>A floret.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flosculous</ent><br/
<hw>Flos"cu*lous</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Bot.)</fld>
<def>Consisting of many gamopetalous florets.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flos-ferri</ent><br/
\'d8<hw>Flos`-fer"ri</hw> <pr>(?)</pr>, <pos>n.</pos><ety>[L., flower of
iron.]</ety> <fld>(Min.)</fld> <def>A variety of aragonite, occurring in
delicate white coralloidal forms; -- common in beds of iron
ore.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flosh</ent><br/
<hw>Flosh</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. G.
<ets>fl<oum/sse</ets> a trough in which tin ore is washed.]</ety>
<fld>(Metallurgy)</fld> <def>A hopper-shaped box or mortar in which ore
is placed for the action of the stamps.</def>
<rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Floss</ent><br/
<hw>Floss</hw> <pr>(?; 195)</pr>, <pos>n.</pos> <ety>[It.
<ets>floscio</ets> flabby, soft, fr. L. <ets>fluxus</ets> flowing,
loose, slack. See <er>Flux</er>, <pos>n.</pos>]</ety> <sn>1.</sn>
<fld>(Bot.)</fld> <def>The slender styles of the pistillate flowers of
maize; also called <altname>silk</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Untwisted filaments of silk, used in
embroidering.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A body feather of an ostrich. Flosses are soft, and
gray from the female and black from the male.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><cs><col><b>Floss silk</b></col>, <cd>silk that has been twisted, and
which retains its loose and downy character. It is much used in
embroidery. Called also <altname>floxed silk</altname>.</cd> --
<col><b>Floss thread</b></col>, <cd>a kind of soft flaxen yarn or
thread, used for embroidery; -- called also <altname>linen
floss</altname>, and <altname>floss yarn</altname>.</cd>
<rj><au>McElrath.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Floss</ent><br/
<hw>Floss</hw>, <pos>n.</pos> <ety>[Cf. G. <ets>floss</ets> a
float.]</ety> <sn>1.</sn> <def>A small stream of water.</def>
<mark>[Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Fluid glass floating on iron in the puddling
furnace, produced by the vitrification of oxides and earths which are
present.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Floss hole</b></col>. <sd>(a)</sd> <cd>A hole at the back
of a puddling furnace, at which the slags pass out.</cd> <sd>(b)</sd>
<cd>The tap hole of a melting furnace.</cd>
<rj><au>Knight.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flossification</ent><br/
<hw>Flos`si*fi*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf.
<er>Florification</er>.]</ety> <def>A flowering; florification.</def>
<mark>[R.]</mark> <rj><au>Craig.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flossy</ent><br/
<hw>Floss"y</hw> <pr>(?; 115)</pr>, <pos>a.</pos> <def>Pertaining to,
made of, or resembling, floss; hence, light; downy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flota</ent><br/
\'d8<hw>Flo"ta</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sp. See
<er>Flotilla</er>.]</ety> <def>A fleet; especially, a fleet of Spanish
ships which formerly sailed every year from Cadiz to Vera Cruz, in
Mexico, to transport to Spain the production of Spanish
America.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flotage</ent><br/
<hw>Flo"tage</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>flotage</ets>, F. <ets>flottage</ets>, fr. <ets>flotter</ets> to
float.]</ety> <sn>1.</sn> <def>The state of floating.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which floats on the sea or in rivers.</def>
<altsp>[Written also <asp>floatage</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flotant</ent><br/
<hw>Flo"tant</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OF.
<ets>flotant</ets>, F. <ets>flottant</ets>, p. pr. of <ets>flotter</ets>
to float.]</ety> <fld>(Her.)</fld> <def>Represented as flying or
streaming in the air; <as>as, a banner <ex>flotant</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flotation</ent><br/
<hw>Flo*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>flottation</ets> a floating, <ets>flottaison</ets> water line, fr.
<ets>flotter</ets> to float. See <er>Flotilla</er>.]</ety> <sn>1.</sn>
<def>The act, process, or state of floating.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The science of floating bodies.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Com. & Finance)</fld> <def>Act of financing, or
floating, a commercial venture or an issue of bonds, stock, or the
like.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><cs><col><b>Center of flotation</b></col>. <fld>(Shipbuilding)</fld>
<sd>(a)</sd> <cd>The center of any given plane of flotation.</cd>
<sd>(b)</sd> <cd>More commonly, the middle of the length of the load
water line.</cd> <au>Rankine.</au> -- <mcol><col><b>Plane of
flotation</b></col>, <it>or</it> <col><b>Line of
flotation</b></col></mcol>, <cd>the plane or line in which the
horizontal surface of a fluid cuts a body floating in it. See
<er>Bearing</er>, <pos>n.</pos>, 9 <sd>(c)</sd>.</cd> -- <col><b>Surface
of flotation</b></col> <fld>(Shipbuilding)</fld>, <cd>the imaginary
surface which all the planes of flotation touch when a vessel rolls or
pitches; the envelope of all such planes.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flotation process</ent><br/
<hw>Flotation process</hw>. <def>A process of separating the substances
contained in pulverized ore or the like by depositing the mixture on the
surface of a flowing liquid, the substances that are quickly wet readily
overcoming the surface tension of the liquid and sinking, the others
flowing off in a film or slime on the surface, though, perhaps, having a
greater specific gravity than those that sink.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Flote</ent><br/
<hw>Flote</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To fleet; to
skim.</def> <mark>[Obs.]</mark> <rj><au>Tusser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flote</ent><br/
<hw>Flote</hw>, <pos>n.</pos> <ety>[Cf. F. <ets>flot</ets>, L.
<ets>fluctus</ets>; also cf. <er>Float</er>, <pos>n.</pos>]</ety> <def>A
wave.</def> <mark>[Obs.]</mark> <ldquo/The Mediterranean
<xex>flote</xex>.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flotery</ent><br/
<hw>Flot"er*y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Wavy; flowing.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>With <qex>flotery</qex> beard.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flotilla</ent><br/
<hw>Flo*til"la</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sp.
<ets>flotilla</ets>, dim. of <ets>flota</ets> fleet; akin to F.
<ets>flotte</ets>, It. <ets>flotta</ets>, and F. <ets>flot</ets> wave,
fr. L. <ets>fluctus</ets>, but prob. influenced by words akin to E.
<ets>float</ets>. See <er>Fluctuate</er>, and cf. <er>Float</er>,
<pos>n.</pos>]</ety> <def>A little fleet, or a fleet of small
vessels.</def></p>

<p><ent>Flotson</ent><br/
<ent>Flotsam</ent><br/
<mhw>{ <hw>Flot"sam</hw> <pr>(?)</pr>, <hw>Flot"son</hw> <pr>(?)</pr>
}</mhw>, <pos>n.</pos> <ety>[F. <ets>flotter</ets> to float. See
<er>FFlotilla</er>, and cf. <er>Jetsam</er>.]</ety> <fld>(Law)</fld>
<def>Goods lost by shipwreck, and floating on the sea; -- in distinction
from <xex>jetsam</xex> or <xex>jetson</xex>.</def>
<rj><au>Blackstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flotten</ent><br/
<hw>Flot"ten</hw> <pr>(?)</pr>, <pos>p. p.</pos> <mord>of
<er>Flote</er>, <pos>v. t.</pos></mord> <def>Skimmed.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flounce</ent><br/
<hw>Flounce</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Flounced</conjf> <pr>(flounst)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Flouncing</conjf> <pr>(?)</pr>.]</vmorph> <ety>[Cf. OSw.
<ets>flunsa</ets> to immerge.]</ety> <def>To throw the limbs and body
one way and the other; to spring, turn, or twist with sudden effort or
violence; to struggle, as a horse in mire; to flounder; to throw one's
self with a jerk or spasm, often as in displeasure.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To flutter and <qex>flounce</qex> will do nothing but batter and
bruise us.</q> <rj><qau>Barrow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>With his broad fins and forky tail he laves<br/
The rising sirge, and <qex>flounces</qex> in the waves.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flounce</ent><br/
<hw>Flounce</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of flouncing;
a sudden, jerking motion of the body.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flounce</ent><br/
<hw>Flounce</hw>, <pos>n.</pos> <ety>[Cf. G. <ets>flaus</ets>,
<ets>flausch</ets>, a tuft of wool or hair; akin to <ets>vliess</ets>,
E. <ets>fleece</ets>; or perh. corrupted fr. <ets>rounce</ets>.]</ety>
<def>An ornamental appendage to the skirt of a woman's dress, consisting
of a strip gathered and sewed on by its upper edge around the skirt, and
left hanging.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flounce</ent><br/
<hw>Flounce</hw>, <pos>v. t.</pos> <def>To deck with a flounce or
flounces; <as>as, to <ex>flounce</ex> a petticoat or a
frock</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flounder</ent><br/
<hw>Floun"der</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. Sw.
<ets>flundra</ets>; akin to Dan. <ets>flynder</ets>, Icel.
<ets>fly<?/ra</ets>, G. <ets>flunder</ets>, and perh. to E.
<ets>flounder</ets>, v.i.]</ety> <sn>1.</sn> <fld>(Zool.)</fld> <def>A
flatfish of the family <fam>Pleuronectid<ae/</fam>, of many
species.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The common English flounder is <spn>Pleuronectes
flesus</spn>. There are several common American species used as food; as
the smooth flounder (<spn>P. glabra</spn>); the rough or winter flounder
(<spn>P. Americanus</spn>); the summer flounder, or plaice
(<spn>Paralichthys dentatus</spn>), Atlantic coast; and the starry
flounder (<spn>Pleuronectes stellatus</spn>).</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bootmaking)</fld> <def>A tool used in crimping boot
fronts.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flounder</ent><br/
<hw>Floun"der</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Floundered</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Floundering</conjf>.]</vmorph> <ety>[Cf. D. <ets>flodderen</ets>
to flap, splash through mire, E. <ets>flounce</ets>, v.i., and
<ets>flounder</ets> the fish.]</ety> <def>To fling the limbs and body,
as in making efforts to move; to struggle, as a horse in the mire, or as
a fish on land; to roll, toss, and tumble; to flounce.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They have <qex>floundered</qex> on from blunder to blunder.</q>
<rj><qau>Sir W. Hamilton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flounder</ent><br/
<hw>Floun"der</hw>, <pos>n.</pos> <def>The act of floundering.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flour</ent><br/
<hw>Flour</hw> <pr>(flour)</pr>, <pos>n.</pos> <ety>[F. <ets>fleur de
farine</ets> the flower (<it>i.e.</it>, the best) of meal, cf. Sp.
<ets>flor de la harina</ets> superfine flour, Icel. <ets>fl<uum/r</ets>
flower, flour. See <er>Flower</er>.]</ety> <def>The finely ground meal
of wheat, or of any other grain; especially, the finer part of meal
separated by bolting; hence, the fine and soft powder of any substance;
<as>as, <ex>flour</ex> of emery; <ex>flour</ex> of
mustard.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Flour bolt</b></col>, <cd>in milling, a gauze-covered,
revolving, cylindrical frame or reel, for sifting the flour from the
refuse contained in the meal yielded by the stones.</cd> --
<col><b>Flour box</b></col> <cd>a tin box for scattering flour; a
dredging box.</cd> -- <mcol><col><b>Flour dredge</b></col> <it>or</it>
<col><b>Flour dredger</b></col></mcol>, <cd>a flour box.</cd> --
<col><b>Flour dresser</b></col>, <cd>a mashine for sorting and
distributing flour according to grades of fineness.</cd> --
<col><b>Flour mill</b></col>, <cd>a mill for grinding and sifting
flour.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flour</ent><br/
<hw>Flour</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Floured</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Flouring</conjf>.]</vmorph> <sn>1.</sn> <def>To grind and bolt;
to convert into flour; <as>as, to <ex>flour</ex> wheat</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To sprinkle with flour.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Floured</ent><br/
<hw>Floured</hw> <pr>(?)</pr>, <pos>p. a.</pos> <def>Finely granulated;
-- said of quicksilver which has been granulated by agitation during the
amalgamation process.</def> <rj><au>Raymond.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flourish</ent><br/
<hw>Flour"ish</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Flourished</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Flourishing</conjf>.]</vmorph> <ety>[OE.
<ets>florisshen</ets>, <ets>flurisshen</ets>, OF. <ets>flurir</ets>, F.
<ets>fleurir</ets>, fr. L. <ets>florere</ets> to bloom, fr.
<ets>flos</ets>, <ets>floris</ets>, flower. See <er>Flower</er>, and
<er>-ish</er>.]</ety> <sn>1.</sn> <def>To grow luxuriantly; to increase
and enlarge, as a healthy growing plant; a thrive.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A tree thrives and <qex>flourishes</qex> in a kindly . . .
soil.</q> <rj><qau>Bp. Horne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To be prosperous; to increase in wealth, honor,
comfort, happiness, or whatever is desirable; to thrive; to be prominent
and influential; specifically, of authors, painters, etc., to be in a
state of activity or production.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>When all the workers of iniquity do <qex>flourish</qex>.</q>
<rj><qau>Ps. xcii 7</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Bad men as frequently prosper and <qex>flourish</qex>, and that by
the means of their wickedness.</q> <rj><qau>Nelson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>We say<br/
Of those that held their heads above the crowd,<br/
They <qex>flourished</qex> then or then.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To use florid language; to indulge in rhetorical
figures and lofty expressions; to be flowery.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They dilate . . . and <qex>flourish</qex> long on little
incidents.</q> <rj><qau>J. Watts.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To make bold and sweeping, fanciful, or wanton
movements, by way of ornament, parade, bravado, etc.; to play with
fantastic and irregular motion.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Impetuous spread<br/
The stream, and smoking <qex>flourished</qex> o'er his head.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To make ornamental strokes with the pen; to write
graceful, decorative figures.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To execute an irregular or fanciful strain of music,
by way of ornament or prelude.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Why do the emperor's trumpets <qex>flourish</qex> thus?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>To boast; to vaunt; to brag.</def>
<rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flourish</ent><br/
<hw>Flour"ish</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To adorn with
flowers or beautiful figures, either natural or artificial; to ornament
with anything showy; to embellish.</def> <mark>[Obs.]</mark>
<rj><au>Fenton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To embellish with the flowers of diction; to adorn
with rhetorical figures; to grace with ostentatious eloquence; to set
off with a parade of words.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Sith that the justice of your title to him<br/
Doth <qex>flourish</qex> the deceit.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To move in bold or irregular figures; to swing about
in circles or vibrations by way of show or triumph; to
brandish.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And <qex>flourishes</qex> his blade in spite of me.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To develop; to make thrive; to expand.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Bottoms of thread . . . which with a good needle, perhaps may be
<qex>flourished</qex> into large works.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flourish</ent><br/
<hw>Flour"ish</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Flourishes</plw> <pr>(<?/)</pr>.</plu> <sn>1.</sn> <def>A
flourishing condition; prosperity; vigor.</def>
<mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The Roman monarchy, in her highest <qex>flourish</qex>, never had
the like.</q> <rj><qau>Howell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Decoration; ornament; beauty.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>flourish</qex> of his sober youth<br/
Was the pride of naked truth.</q> <rj><qau>Crashaw.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Something made or performed in a fanciful, wanton,
or vaunting manner, by way of ostentation, to excite admiration, etc.;
ostentatious embellishment; ambitious copiousness or amplification;
parade of words and figures; show; <as>as, a <ex>flourish</ex> of
rhetoric or of wit</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He lards with <qex>flourishes</qex> his long harangue.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A fanciful stroke of the pen or graver; a merely
decorative figure.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The neat characters and <qex>flourishes</qex> of a Bible curiously
printed.</q> <rj><qau>Boyle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A fantastic or decorative musical passage; a strain
of triumph or bravado, not forming part of a regular musical
composition; a cal; a fanfare.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>flourish</qex>, trumpets! strike alarum, drums!</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>The waving of a weapon or other thing; a
brandishing; <as>as, the <ex>flourish</ex> of a sword</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flourisher</ent><br/
<hw>Flour"ish*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
flourishes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flourishingly</ent><br/
<hw>Flour"ish*ing*ly</hw>, <pos>adv.</pos> <def>In a flourishing manner;
ostentatiously.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Floury</ent><br/
<hw>Flour"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or resembling
flour; mealy; covered with flour.</def> <rj><au>Dickens.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flout</ent><br/
<hw>Flout</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Flouted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Flouting</conjf>.]</vmorph> <ety>[OD. <ets>fluyten</ets> to play
the flute, to jeer, D. <ets>fluiten</ets>, fr. <ets>fluit</ets>, fr.
French. See <er>Flute</er>.]</ety> <def>To mock or insult; to treat with
contempt.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Phillida <qex>flouts</qex> me.</q> <rj><qau>Walton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Three gaudy standards <qex>flout</qex> the pale blue sky.</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flout</ent><br/
<hw>Flout</hw>, <pos>v. i.</pos> <def>To practice mocking; to behave
with contempt; to sneer; to fleer; -- often with
<xex>at</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Fleer and gibe, and laugh and <qex>flout</qex>.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flout</ent><br/
<hw>Flout</hw>, <pos>n.</pos> <def>A mock; an insult.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Who put your beauty to this <qex>flout</qex> and scorn.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flouter</ent><br/
<hw>Flout"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who flouts; a
mocker.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Floutingly</ent><br/
<hw>Flout"ing*ly</hw>, <pos>adv.</pos> <def>With flouting; insultingly;
<as>as, to treat a lover <ex>floutingly</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flow</ent><br/
<hw>Flow</hw> <pr>(fl<omac/)</pr>, <mark>obs.</mark> <def><pos>imp.
sing.</pos> of <er>Fly</er>, <pos>v. i.</pos></def>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flow</ent><br/
<hw>Flow</hw> <pr>(fl<omac/)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Flowed</conjf> <pr>(fl<omac/d)</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>Flowing</conjf>.]</vmorph> <ety>[AS.
<ets>fl<omac/wan</ets>; akin to D. <ets>vloeijen</ets>, OHG.
<ets>flawen</ets> to wash, Icel. <ets>fl<omac/a</ets> to deluge, Gr.
<grk>plw`ein</grk> to float, sail, and prob. ultimately to E.
<ets>float</ets>, <ets>fleet</ets>. <root/80. Cf. <er>Flood</er>.]</ety>
<sn>1.</sn> <def>To move with a continual change of place among the
particles or parts, as a fluid; to change place or circulate, as a
liquid; <as>as, rivers <ex>flow</ex> from springs and lakes; tears
<ex>flow</ex> from the eyes.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To become liquid; to melt.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The mountains <qex>flowed</qex> down at thy presence.</q>
<rj><qau>Is. lxiv. 3.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To proceed; to issue forth; <as>as, wealth
<ex>flows</ex> from industry and economy</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Those thousand decencies that daily <qex>flow</qex><br/
From all her words and actions.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To glide along smoothly, without harshness or
asperities; <as>as, a <ex>flowing</ex> period; <ex>flowing</ex>
numbers</as>; to sound smoothly to the ear; to be uttered
easily.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Virgil is sweet and <qex>flowing</qex>in his hexameters.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To have or be in abundance; to abound; to full, so
as to run or flow over; to be copious.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In that day . . . the hills shall <qex>flow</qex> with milk.</q>
<rj><qau>Joel iii. 18.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The exhilaration of a night that needed not the influence of the
<qex>flowing</qex> bowl.</q> <rj><qau>Prof. Wilson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To hang loose and waving; <as>as, a <ex>flowing</ex>
mantle; <ex>flowing</ex> locks.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>The imperial purple <qex>flowing</qex> in his train.</q>
<rj><qau>A. Hamilton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>To rise, as the tide; -- opposed to <xex>ebb</xex>;
<as>as, the tide <ex>flows</ex> twice in twenty-four
hours</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The river hath thrice <qex>flowed</qex>, no ebb between.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>To discharge blood in excess from the
uterus.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flow</ent><br/
<hw>Flow</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To cover with water or
other liquid; to overflow; to inundate; to flood.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To cover with varnish.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flow</ent><br/
<hw>Flow</hw>, <pos>n.</pos> <sn>1.</sn> <def>A stream of water or other
fluid; a current; <as>as, a <ex>flow</ex> of water; a <ex>flow</ex> of
blood.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A continuous movement of something abundant; <as>as,
a <ex>flow</ex> of words</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Any gentle, gradual movement or procedure of
thought, diction, music, or the like, resembling the quiet, steady
movement of a river; a stream.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The feast of reason and the <qex>flow</qex> of soul.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The tidal setting in of the water from the ocean to
the shore. See <cref>Ebb and flow</cref>, under <er>Ebb</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A low-lying piece of watery land; -- called also
<altname>flow moss</altname> and <altname>flow bog</altname>.</def>
<mark>[Scot.]</mark> <rj><au>Jamieson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flowage</ent><br/
<hw>Flow"age</hw> <pr>(?; 48)</pr>, <pos>n.</pos> <def>An overflowing
with water; also, the water which thus overflows.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flowen</ent><br/
<hw>Flow"en</hw> <pr>(?)</pr>, <mark>obs.</mark> <def><pos>imp.
pl.</pos> of <er>Fly</er>, <pos>v. i.</pos></def>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flower</ent><br/
<hw>Flow"er</hw> <pr>(flou"<etil/r)</pr>, <pos>n.</pos> <ety>[OE.
<ets>flour</ets>, OF. <ets>flour</ets>, <ets>flur</ets>,
<ets>flor</ets>, F. <ets>fleur</ets>, fr. L. <ets>flos</ets>,
<ets>floris</ets>. Cf. <er>Blossom</er>, <er>Effloresce</er>,
<er>Floret</er>, <er>Florid</er>, <er>Florin</er>, <er>Flour</er>,
<er>Flourish</er>.]</ety> <sn>1.</sn> <def>In the popular sense, the
bloom or blossom of a plant; the showy portion, usually of a different
color, shape, and texture from the foliage.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>That part of a plant destined to
produce seed, and hence including one or both of the sexual organs; an
organ or combination of the organs of reproduction, whether inclosed by
a circle of foliar parts or not. A complete <xex>flower</xex> consists
of two essential parts, the stamens and the pistil, and two floral
envelopes, the corolla and callyx. In mosses the flowers consist of a
few special leaves surrounding or subtending organs called archegonia.
See <er>Blossom</er>, and <er>Corolla</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 574 --></p>

<p><note><hand/ If we examine a common flower, such for instance as a
geranium, we shall find that it consists of: First, an outer envelope or
<xex>calyx</xex>, sometimes tubular, sometimes consisting of separate
leaves called <xex>sepals</xex>; secondly, an inner envelope or
<xex>corolla</xex>, which is generally more or less colored, and which,
like the calyx, is sometimes tubular, sometimes composed of separate
leaves called <xex>petals</xex>; thirdly, one or more
<xex>stamens</xex>, consisting of a stalk or <xex>filament</xex> and a
head or <xex>anther</xex>, in which the <xex>pollen</xex> is produced;
and fourthly, a <xex>pistil</xex>, which is situated in the center of
the flower, and consists generally of three principal parts; one or more
compartments at the base, each containing one or more seeds; the
<xex>stalk</xex> or <xex>style</xex>; and the <xex>stigma</xex>, which
in many familiar instances forms a small head, at the top of the style
or ovary, and to which the pollen must find its way in order to
fertilize the flower.</note> <rj><au>Sir J. Lubbock.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The fairest, freshest, and choicest part of
anything; <as>as, the <ex>flower</ex> of an army, or of a family</as>;
the state or time of freshness and bloom; <as>as, the <ex>flower</ex> of
life, that is, youth</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The choice and <qex>flower</qex> of all things profitable the
Psalms do more briefly contain.</q> <rj><qau>Hooker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>flower</qex> of the chivalry of all Spain.</q>
<rj><qau>Southey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A simple maiden in her <qex>flower</qex><br/
Is worth a hundred coats of arms.</q> <rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Grain pulverized; meal; flour.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>flowers</qex> of grains, mixed with water, will make a
sort of glue.</q> <rj><qau>Arbuthnot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <pluf>pl.</pluf> <fld>(Old Chem.)</fld> <def>A substance
in the form of a powder, especially when condensed from sublimation;
<as>as, the <ex>flowers</ex> of sulphur</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>A figure of speech; an ornament of style.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <pluf>pl.</pluf> <fld>(Print.)</fld> <def>Ornamental type
used chiefly for borders around pages, cards, etc.</def> <rj><au>W.
Savage.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <pluf>pl.</pluf> <def>Menstrual discharges.</def>
<rj><au>Lev. xv. 24.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Animal flower</b></col> <fld>(Zool.)</fld> <cd>See under
<er>Animal</er>.</cd> -- <col><b>Cut flowers</b></col>, <cd>flowers cut
from the stalk, as for making a bouquet.</cd> -- <col><b>Flower
bed</b></col>, <cd>a plat in a garden for the cultivation of
flowers.</cd> -- <col><b>Flower beetle</b></col> <fld>(Zool.)</fld>,
<cd>any beetle which feeds upon flowers, esp. any one of numerous small
species of the genus <gen>Meligethes</gen>, family
<fam>Nitidulid<ae/</fam>, some of which are injurious to crops.</cd> --
<col><b>Flower bird</b></col> <fld>(Zool.)</fld>, <cd>an Australian bird
of the genus <gen>Anthornis</gen>, allied to the honey eaters.</cd> --
<col><b>Flower bud</b></col>, <cd>an unopened flower.</cd> --
<col><b>Flower clock</b></col>, <cd>an assemblage of flowers which open
and close at different hours of the day, thus indicating the time.</cd>
-- <col><b>Flower head</b></col> <fld>(Bot.)</fld>, <cd>a compound
flower in which all the florets are sessile on their receptacle, as in
the case of the daisy.</cd> -- <col><b>Flower pecker</b></col>
<fld>(Zool.)</fld>, <cd>one of a family (<fam>Dic<ae/id<ae/</fam>) of
small Indian and Australian birds. They resemble humming birds in
habits.</cd> -- <col><b>Flower piece</b></col>. <sd>(a)</sd> <cd>A table
ornament made of cut flowers.</cd> <sd>(b)</sd> <fld>(Fine Arts)</fld>
<cd>A picture of flowers.</cd> -- <col><b>Flower stalk</b></col>
<fld>(Bot.)</fld>, <cd>the peduncle of a plant, or the stem that
supports the flower or fructification.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flower</ent><br/
<hw>Flow"er</hw> <pr>(flou"<etil/r)</pr>, <pos>v. i.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Flowered</conjf>
<pr>(flou"<etil/rd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Flowering</conjf>.]</vmorph> <ety>[From the noun. Cf.
<er>Flourish</er>.]</ety> <sn>1.</sn> <def>To blossom; to bloom; to
expand the petals, as a plant; to produce flowers; <as>as, this plant
<ex>flowers</ex> in June</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To come into the finest or fairest
condition.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Their lusty and <qex>flowering</qex> age.</q> <rj><qau>Robynson
(More's Utopia).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>When <qex>flowered</qex> my youthful spring.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To froth; to ferment gently, as new beer.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That beer did <qex>flower</qex> a little.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To come off as flowers by sublimation.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Observations which have <qex>flowered</qex> off.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flower</ent><br/
<hw>Flow"er</hw>, <pos>v. t.</pos> <def>To embellish with flowers; to
adorn with imitated flowers; <as>as, <ex>flowered</ex>
silk</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flowerage</ent><br/
<hw>Flow"er*age</hw> <pr>(?; 48)</pr>, <pos>n.</pos> <def>State of
flowers; flowers, collectively or in general.</def>
<rj><au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>flowerbed</ent><br/
<hw>flowerbed</hw> <pos>n.</pos> <sn>1.</sn> <def>a bed in which flowers
are growing.</def><br/
<syn><b>Syn. --</b> bed of flowers.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Flower-de-luce</ent><br/
<hw>Flow"er-de-luce"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Corrupted
fr. <ets>fleur-de-lis</ets>.]</ety> <fld>(Bot.)</fld> <def>A genus of
perennial herbs (<gen>Iris</gen>) with swordlike leaves and large
three-petaled flowers often of very gay colors, but probably white in
the plant first chosen for the royal French emblem.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ There are nearly one hundred species, natives of the
north temperate zone. Some of the best known are <spn>Iris
Germanica</spn>, <spn>I. Florentina</spn>, <spn>I. Persica</spn>,
<spn>I. sambucina</spn>, and the American <spn>I. versicolor</spn>,
<spn>I. prismatica</spn>, etc.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>flowered</ent><br/
<hw>flowered</hw> <pos>adj.</pos> <def>resembling or made of or
suggestive of flowers.</def><br/
<syn><b>Syn. --</b> floral.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Flowerer</ent><br/
<hw>Flow"er*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A plant which
flowers or blossoms.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Many hybrids are profuse and persistent <qex>flowerers</qex>.</q>
<rj><qau>Darwin.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Floweret</ent><br/
<hw>Flow"er*et</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A small flower; a
floret.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flower-fence</ent><br/
<hw>Flow"er-fence`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>A tropical leguminous bush (<spn>Poinciana pulcherrima</spn>,
<it>or</it> <spn>C<ae/salpinia, pulcherrima</spn>) with prickly
branches, and showy yellow or red flowers; -- so named from its having
been sometimes used for hedges in the West Indies.</def>
<rj><au>Baird.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flowerful</ent><br/
<hw>Flow"er*ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Abounding with
flowers.</def> <rj><au>Craig.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flower-gentle</ent><br/
<hw>Flow"er-gen`tle</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>A species of amaranth (<spn>Amarantus
melancholicus</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Floweriness</ent><br/
<hw>Flow"er*i*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state of
being flowery.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flowering</ent><br/
<hw>Flow"er*ing</hw>, <pos>a.</pos> <fld>(Bot.)</fld> <def>Having
conspicuous flowers; -- used as an epithet with many names of plants;
<as>as, <ex>flowering</ex> ash; <ex>flowering</ex> dogwood;
<ex>flowering</ex> almond, etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Flowering fern</b></col>, <cd>a genus of showy ferns
(<gen>Osmunda</gen>), with conspicuous bivalvular sporangia. They
usually grow in wet places.</cd> -- <col><b>Flowering plants</b></col>,
<cd>plants which have stamens and pistils, and produce true seeds;
phenogamous plants; -- distinguished from <contr>flowerless
plants</contr>.</cd> -- <col><b>Flowering rush</b></col>, <cd>a European
rushlike plant (<spn>Butomus umbellatus</spn>), with an umbel of rosy
blossoms.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flowering</ent><br/
<hw>Flow"er*ing</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act of
blossoming, or the season when plants blossom; florification.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The act of adorning with flowers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flowerless</ent><br/
<hw>Flow"er*less</hw>, <pos>a.</pos> <def>Having no flowers.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Flowerless plants</b></col>, <cd>plants which have no
true flowers, and produce no seeds; cryptogamous plants.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flowerlessness</ent><br/
<hw>Flow"er*less*ness</hw>, <pos>n.</pos> <def>State of being without
flowers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flowerpot</ent><br/
<hw>Flow"er*pot`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A vessel,
commonly or earthenware, for earth in which plants are grown.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>flowers-of-an-hour</ent><br/
<hw>flowers-of-an-hour</hw> <pos>n.</pos> <def>An annual weedy herb
(<spn>Hibiscus trionum</spn>) with ephemeral yellow purple-eyed flowers,
native to the Old World tropics and naturalized as a weed in North
America.</def><br/
<syn><b>Syn. --</b> flower-of-an-hour, bladder ketmia, black-eyed Susan,
<spn>Hibiscus trionum</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Flower State</ent><br/
<hw>Flow"er State</hw>. <def>Florida; -- a nickname, alluding to sense
of L. <xex>floridus</xex>, from <xex>florida</xex> flowery. See
<er>Florid</er>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Flowery</ent><br/
<hw>Flow"er*y</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Full of
flowers; abounding with blossoms.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Highly embellished with figurative language; florid;
<as>as, a <ex>flowery</ex> style</as>.</def>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>The flowery kingdom</b></col>, <cd>China.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flowery-kirtled</ent><br/
<hw>Flow"er*y-kir`tled</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Dressed
with garlands of flowers.</def> <mark>[Poetic & Rare]</mark>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flowing</ent><br/
<hw>Flow"ing</hw>, <pos>a.</pos> <def>That flows or for flowing (in
various sense of the verb); gliding along smoothly; copious.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Flowing battery</b></col> <fld>(Elec.)</fld>, <cd>a
battery which is kept constant by the flowing of the exciting liquid
through the cell or cells.</cd> <au>Knight.</au> -- <col><b>Flowing
furnace</b></col>, <cd>a furnace from which molten metal, can be drawn,
as through a tap hole; a foundry cupola.</cd> -- <col><b>Flowing
sheet</b></col> <fld>(Naut.)</fld>, <cd>a sheet when eased off, or
loosened to the wind, as when the wind is abaft the beam.</cd>
<rj><au>Totten.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flowing</ent><br/
<hw>Flow"ing</hw> <pr>(?)</pr>, <def><pos>a. & n.</pos> from
<er>Flow</er>, <pos>v. i. & t.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flowingly</ent><br/
<hw>Flow"ing*ly</hw>, <pos>adv.</pos> <def>In a flowing
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flowingness</ent><br/
<hw>Flow"ing*ness</hw>, <pos>n.</pos> <def>Flowing tendency or quality;
fluency.</def> <mark>[R.]</mark> <rj><au>W. Nichols.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flowk</ent><br/
<hw>Flowk</hw> <pr>(? <or/ ?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>See 1st <er>Fluke</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flown</ent><br/
<hw>Flown</hw> <pr>(?)</pr>, <def><pos>p. p.</pos> of <er>Fly</er>; --
often used with the auxiliary verb <xex>to be</xex>; <as>as, the birds
are <ex>flown</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flown</ent><br/
<hw>Flown</hw>, <pos>a.</pos> <def>Flushed, inflated.</def>
<note>[Supposed by some to be a mistake for <xex>blown</xex> or
<xex>swoln</xex>.]</note> <rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Then wander forth the sons<br/
Of Belial, <qex>flown</qex> with insolence and wine.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Floxed silk</ent><br/
<hw>Floxed" silk`</hw> <pr>(?)</pr>. <def>See <cref>Floss silk</cref>,
under <er>Floss</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Floyte</ent><br/
<hw>Floyte</hw> <pr>(?)</pr>, <pos>n. & v.</pos> <def>A variant of
<er>Flute</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluate</ent><br/
<hw>Flu"ate</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>fluate</ets>. See <er>Fluor</er>.]</ety> <fld>(Chem.)</fld> <def>A
fluoride.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluavil</ent><br/
<hw>Flu"a*vil</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Etymol.
uncertain.]</ety> <fld>(Chem.)</fld> <def>A hydrocarbon extracted from
gutta-percha, as a yellow, resinous substance; -- called also
<altname>fluanil</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flucan</ent><br/
<hw>Flu"can</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Mining)</fld>
<def>Soft clayey matter in the vein, or surrounding it.</def>
<altsp>[Written also <asp>flookan</asp>, <asp>flukan</asp>, and
<asp>fluccan</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluctiferous</ent><br/
<hw>Fluc*tif"er*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>fluctus</ets> wave + <ets>-ferous</ets>.]</ety> <def>Tending to
produce waves.</def> <rj><au>Blount.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluctisonous</ent><br/
<hw>Fluc*tis"o*nous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>fluctisonus</ets>; <ets>fluctus</ets> wave + <ets>sonus</ets>
sound.]</ety> <def>Sounding like waves.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluctuability</ent><br/
<hw>Fluc`tu*a*bil"i*ty</hw> <pr>(?; 135)</pr>, <pos>n.</pos> <def>The
capacity or ability to fluctuate.</def> <mark>[R.]</mark> <rj><au>H.
Walpole.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluctuant</ent><br/
<hw>Fluc"tu*ant</hw> <pr>(?; 135)</pr>, <pos>a.</pos> <ety>[L.
<ets>fluctuans</ets>, p. pr. of <ets>fluctuare</ets>. See
<er>Fluctuate</er>.]</ety> <sn>1.</sn> <def>Moving like a wave;
wavering</def>; <def2><fld>(Med.)</fld> <def>showing undulation or
fluctuation; <as>as, a <ex>fluctuant</ex> tumor</as>.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Floating on the waves.</def> <mark>[Obs.]</mark>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluctuate</ent><br/
<hw>Fluc"tu*ate</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Fluctuated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Fluctuating</conjf> <pr>(?)</pr>.]</vmorph> <ety>[L.
<ets>fluctuatus</ets>, p. p. of <ets>fluctuare</ets>, to wave, fr.
<ets>fluctus</ets> wave, fr. <ets>fluere</ets>, <ets>fluctum</ets>, to
flow. See <er>Fluent</er>, and cf. <er>Flotilla</er>.]</ety> <sn>1.</sn>
<def>To move as a wave; to roll hither and thither; to wave; to float
backward and forward, as on waves; <as>as, a <ex>fluctuating</ex> field
of air</as>.</def> <rj><au>Blackmore.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To move now in one direction and now in another; to
be wavering or unsteady; to be irresolute or undetermined; to
vacillate.</def></p>

<p><syn><b>Syn.</b> -- To waver; vacillate; hesitate; scruple.</syn>
<usage> -- To <er>Fluctuate</er>, <er>Vacillate</er>, <er>Waver</er>. --
<xex>Fluctuate</xex> is applied both to things and persons and denotes
that they move as they are acted upon. The stocks <xex>fluctuate</xex>;
a man <xex>fluctuates</xex> between conflicting influences.
<xex>Vacillate</xex> and <xex>waver</xex> are applied to persons to
represent them as acting themselves. A man <xex>vacillates</xex> when he
goes backward and forward in his opinions and purposes, without any
fixity of mind or principles. A man <xex>wavers</xex> when he shrinks
back or hesitates at the approach of difficulty or danger. One who is
<xex>fluctuating</xex> in his feelings is usually <xex>vacillating</xex>
in resolve, and <xex>wavering</xex> in execution.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluctuate</ent><br/
<hw>Fluc"tu*ate</hw>, <pos>v. t.</pos> <def>To cause to move as a wave;
to put in motion.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>And <qex>fluctuate</qex> all the still perfume.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>fluctuating</ent><br/
<hw>fluc"tu*at`ing</hw> <pos>adj.</pos> <def>moving irregularly in an
oscillatory manner, especially up and down; <as>as, <ex>fluctuating</ex>
prices</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fluctuation</ent><br/
<hw>Fluc`tu*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>fluctuatio</ets>; cf. F. <ets>fluctuation</ets>.]</ety> <sn>1.</sn>
<def>A motion like that of waves; a moving in this and that direction;
<as>as, the <ex>fluctuations</ex> of the sea</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A wavering; unsteadiness; <as>as,
<ex>fluctuations</ex> of opinion; <ex>fluctuations</ex> of
prices.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Med.)</fld> <def>The motion or undulation of a
fluid collected in a natural or artificial cavity, which is felt when it
is subjected to pressure or percussion.</def>
<rj><au>Dunglison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flue</ent><br/
<hw>Flue</hw> <pr>(fl<umac/)</pr>, <pos>n.</pos> <ety>[Cf. OF.
<ets>flue</ets> a flowing, fr. <ets>fluer</ets> to flow, fr. L.
<ets>fluere</ets> (cf. <er>Fluent</er>); a perh. a corruption of E.
<ets>flute</ets>.]</ety> <sn>1.</sn> <def>An inclosed passage way for
establishing and directing a current of air, gases, etc.; an air
passage</def>; esp.: <sd>(a)</sd> <def>A compartment or division of a
chimney for conveying flame and smoke to the outer air.</def>
<sd>(b)</sd> <def>A passage way for conducting a current of fresh, foul,
or heated air from one place to another.</def> <sd>(c)</sd> <fld>(Steam
Boiler)</fld> <def>A pipe or passage for conveying flame and hot gases
through surrounding water in a boiler; -- distinguished from a tube
which holds water and is surrounded by fire. Small flues are called
<stype>fire tubes</stype> or simply <xex>tubes</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>In an organ flue pipe, the opening between the lower
lip and the languet.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><cs><col><b>Flue boiler</b></col>. <cd>See under
<er>Boiler</er>.</cd> -- <col><b>Flue bridge</b></col>, <cd>the
separating low wall between the flues and the laboratory of a
reverberatory furnace.</cd> -- <col><b>Flue plate</b></col> <fld>(Steam
Boiler)</fld>, <cd>a plate to which the ends of the flues are fastened;
-- called also <altname>flue sheet</altname>, <altname>tube
sheet</altname>, and <altname>tube plate</altname>.</cd> -- <col><b>Flue
surface</b></col> <fld>(Steam Boiler)</fld>, <cd>the aggregate surface
of flues exposed to flame or the hot gases.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flue</ent><br/
<hw>Flue</hw> <pr>(fl<umac/)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>flou</ets> light, tender, G. <ets>flau</ets> weak, W.
<ets>llwch</ets> dust. <root/84.]</ety> <def>Light down, such as rises
from cotton, fur, etc.; very fine lint or hair.</def>
<rj><au>Dickens.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>fluegelhorn</ent><br/
<hw>fluegelhorn</hw>, <pos>n.</pos> <ety>[from German
<ets>fl<uum/gelhorn</ets>.]</ety> <def>A brass instrument resembling a
cornet but with a wider bore.</def><br/
<syn><b>Syn. --</b> flugelhorn, fl<uum/gelhorn.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fluence</ent><br/
<hw>Flu"ence</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Fluency.</def>
<mark>[Obs.]</mark> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluency</ent><br/
<hw>Flu"en*cy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>fluentia</ets>: cf. F. <ets>fluence</ets>. See
<er>Fluent</er>.]</ety> <def>The quality of being fluent; smoothness;
readiness of utterance; volubility.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The art of expressing with <qex>fluency</qex> and perspicuity.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluent</ent><br/
<hw>Flu"ent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>fluens</ets>,
<ets>-entis</ets>, p. pr. of <ets>fluere</ets> to flow; cf. Gr. <?/ to
boil over. Cf. <er>Fluctuate</er>, <er>Flux</er>.]</ety> <sn>1.</sn>
<def>Flowing or capable of flowing; liquid; glodding; easily
moving.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Ready in the use of words; voluble; copious; having
words at command; and uttering them with facility and smoothness;
<as>as, a <ex>fluent</ex> speaker</as>; hence, flowing; voluble; smooth;
-- said of language; <as>as, <ex>fluent</ex> speech</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With most <qex>fluent</qex> utterance.</q>
<rj><qau>Denham.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Fluent</qex> as the flight of a swallow is the sultan's
letter.</q> <rj><qau>De Quincey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluent</ent><br/
<hw>Flu"ent</hw>, <pos>n.</pos> <sn>1.</sn> <def>A current of water; a
stream.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <ety>[Cf. F. <ets>fluente</ets>.]</ety>
<fld>(Math.)</fld> <def>A variable quantity, considered as increasing or
diminishing; -- called, in the modern calculus, the
<altname>function</altname> or <altname>integral</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluently</ent><br/
<hw>Flu"ent*ly</hw>, <pos>adv.</pos> <def>In a fluent manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluentness</ent><br/
<hw>Flu"ent*ness</hw>, <pos>n.</pos> <def>The quality of being
fluent.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flue pipe</ent><br/
<hw>Flue pipe</hw>. <fld>(Music)</fld> <def>A pipe, esp. an organ pipe,
whose tone is produced by the impinging of a current of air upon an
edge, or lip, causing a wave motion in the air within; a mouth pipe; --
distinguished from <contr>reed pipe</contr>. Flue pipes are either open
or closed (stopped at the distant end). The flute and flageolet are open
pipes; a bottle acts as a closed pipe when one blows across the neck.
The organ has both open and closed flue pipes, those of metal being
usually round in section, and those of wood triangular or
square.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Fluework</ent><br/
<hw>Flue"work`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Mus.)</fld> <def>A
general name for organ stops in which the sound is caused by wind
passing through a flue or fissure and striking an edge above; -- in
distinction from <xex>reedwork</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluey</ent><br/
<hw>Flue"y</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[2d
<er>Flue</er>.]</ety> <def>Downy; fluffy.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluff</ent><br/
<hw>Fluff</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. 2d <er>Flue</er>.
<root/84.]</ety> <sn>1.</sn> <def>Nap or down; flue[2]; soft, downy
feathers.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <specif>Hence:</specif> <def>Anything light and downy,
whose volume consists mostly of air, such as cotton or down.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>Something light and inconsequential; something not
to be taken seriously; -- used commonly of literary or dramatic
productions, and sometimes of people.</def><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <def>A mistake, especially in the recitation of lines in
a drama.</def><br/
[<source>PJC</source>]</p>

<p><ent>Fluff</ent><br/
<hw>Fluff</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <def>To make or
become fluffy; to move lightly like fluff.</def>
<rj><au>Holmes.</au></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Fluff</ent><br/
<hw>Fluff</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To make a mistake in
the performance of; -- used mostly of lines in a drama; <as>as, he
<ex>fluffed</ex> the last line of the act</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Fluffy</ent><br/
<hw>Fluff"y</hw> <pr>(?)</pr>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Fluffier</adjf> <pr>(?)</pr>; <pos>superl.</pos>
<adjf>Fluffiest</adjf>.]</amorph> <def>Pertaining to, or resembling,
fluff or nap; soft and downy.</def> <ldquo/The carpets were
<xex>fluffy</xex>.<rdquo/ <rj><au>Thackeray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The present Barnacle . . . had a youthful aspect, and the
<qex>fluffiest</qex> little whisker, perhaps, that ever was seen.</q>
<rj><qau>Dickens.</qau></rj></p>

<p>-- <wordforms><wf>Fluff"i*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluegel</ent><br/
<ent>Flugel</ent><br/
\'d8<hw>Fl<uum/"gel</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[G., a
wing.]</ety> <fld>(Mus.)</fld> <sn>1.</sn> <def>A grand piano or a
harpsichord, both being wing-shaped.</def> <mark>[archaic]</mark> <br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>A <er>flugelhorn</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>fluegelhorn</ent><br/
<ent>flugelhorn</ent><br/
<mhw><hw>flugelhorn</hw>, <hw>fl<uum/gelhorn</hw></mhw> <ety>[from
German <ets>fl<uum/gelhorn</ets>.]</ety> <pos>n.</pos> <def>A brass wind
instrument resembling a cornet but with a wider bore, and having three
valves.</def><br/
<syn><b>Syn. --</b> fluegelhorn.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Flugelman</ent><br/
<hw>Flu"gel*man</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[G.
<ets>fl<uum/gelman</ets>.]</ety> <fld>(Mil.)</fld> <def>Same as
<er>Fugleman</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluid</ent><br/
<hw>Flu"id</hw> <pr>(fl<umac/"<icr/d)</pr>, <pos>a.</pos> <ety>[L.
<ets>fluidus</ets>, fr. <ets>fluere</ets> to flow: cf. F.
<ets>fluide</ets>. See <er>Fluent</er>.]</ety> <def>Having particles
which easily move and change their relative position without a
separation of the mass, and which easily yield to pressure; capable of
flowing; liquid or gaseous.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluid</ent><br/
<hw>Flu"id</hw>, <pos>n.</pos> <def>A fluid substance; a body whose
particles move easily among themselves.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Fluid</xex> is a generic term, including liquids
and gases as species. Water, air, and steam are <xex>fluids</xex>. By
analogy, the term was sometimes applied to electricity and magnetism, as
in phrases electric <xex>fluid</xex>, magnetic <xex>fluid</xex>, though
not strictly appropriate; such usage has disappeared.</note><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><cs><mcol><col><b>Fluid dram</b></col>, <it>or</it> <col><b>Fluid
drachm</b></col></mcol>, <cd>a measure of capacity equal to one eighth
of a fluid ounce.</cd> -- <col><b>Fluid ounce</b></col>. <sd>(a)</sd>
<cd>In the United States, a measure of capacity, in apothecaries' or
wine measure, equal to one sixteenth of a pint or 29.57 cubic
centimeters. This, for water, is about 1.04158 ounces avoirdupois, or
455.6 grains.</cd> <sd>(b)</sd> <cd>In England, a measure of capacity
equal to the twentieth part of an imperial pint. For water, this is the
weight of the avoirdupois ounce, or 437.5 grains.</cd> -- <col><b>Fluids
of the body</b></col>. <fld>(Physiol.)</fld> <cd>The circulating blood
and lymph, the chyle, the gastric, pancreatic, and intestinal juices,
the saliva, bile, urine, aqueous humor, and muscle serum are the more
important <xex>fluids of the body</xex>. The tissues themselves contain
a large amount of combined water, so much, that an entire human body
dried <xex>in vacuo</xex> with a very moderate degree of heat gives
about 66 per cent of water.</cd> -- <mcol><col><b>Burning
fluid</b></col>, <col><b>Elastic fluid</b></col>, <col><b>Electric
fluid</b></col>, <col><b>Magnetic fluid</b></col>, etc.</mcol> <cd>See
under <er>Burning</er>, <er>Elastic</er>, etc.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluidal</ent><br/
<hw>Flu"id*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to a
fluid, or to its flowing motion.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fluidal structure</b></col> <fld>(Geol.)</fld>, <cd>the
structure characteristic of certain volcanic rocks in which the
arrangement of the minute crystals shows the lines of flow of thew
molten material before solidification; -- also called <altname>fluxion
structure</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluidity</ent><br/
<hw>Flu*id"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>fluidit<eacute/</ets>.]</ety> <def>The quality of being fluid or
capable of flowing; a liquid, a<eum/riform, or gaseous state; -- opposed
to <contr>solidity</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It was this want of organization, this looseness and
<qex>fluidity</qex> of the new movement, that made it penetrate through
every class of society.</q> <rj><qau>J. R. Green.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluidize</ent><br/
<hw>Flu"id*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Fluidized</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Fluidizing</conjf>.]</vmorph> <def>To render
fluid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluidness</ent><br/
<hw>Flu"id*ness</hw>, <pos>n.</pos> <def>The state of being fluid;
fluidity.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluidounce</ent><br/
<hw>Flu"id*ounce`</hw>, <pos>n.</pos> <def>See <cref>Fluid ounce</cref>,
under <er>Fluid</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluidrachm</ent><br/
<hw>Flu"i*drachm`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See <cref>Fluid
dram</cref>, under <er>Fluid</er>.</def> <rj><au>Pharm. of the U.
S.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flukan</ent><br/
<hw>Flu"kan</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Mining)</fld>
<def>Flucan.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluke</ent><br/
<hw>Fluke</hw> <pr>(fl<umac/k <it>or</it> fl<oomac/k)</pr>,
<pos>n.</pos> <ety>[Cf. AS. <ets>fl<omac/c</ets> a kind of flatfish,
Icel. <ets>fl<omac/ki</ets> a kind of halibut.]</ety> <sn>1.</sn>
<fld>(Zool.)</fld> <def>The European flounder. See
<er>Flounder</er>.</def> <altsp>[Written also <asp>fleuk</asp>,
<asp>flook</asp>, and <asp>flowk</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>Any American flounder of the
genus <gen>Paralichthys</gen>, especially <spn>Paralicthys
dentatus</spn>, found in the Atlantic Ocean and in adjacent bays.</def>
<au>RHUD</au><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <def>A parasitic trematode worm of
several species, having a flat, lanceolate body and two suckers. Two
species (<spn>Fasciola hepatica</spn> and <spn>Distoma
lanceolatum</spn>) are found in the livers of sheep, and produce the
disease called <causes>rot</causes>.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 575 --></p>

<p><ent>Fluke</ent><br/
<hw>Fluke</hw> <pr>(fl<umac/k)</pr>, <pos>n.</pos> <ety>[Cf. LG.
<ets>flunk</ets>, <ets>flunka</ets> wing, the palm of an anchor; perh.
akin to E. <ets>fly</ets>.]</ety> <sn>1.</sn> <def>The part of an anchor
which fastens in the ground; a flook. See <er>Anchor</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>One of the lobes of a whale's
tail, so called from the resemblance to the fluke of an
anchor.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>An instrument for cleaning out a hole drilled in
stone for blasting.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>An accidental and favorable stroke at billiards
(called a <xex>scratch</xex> in the United States); hence, any
accidental or unexpected advantage; <as>as, he won by a
<ex>fluke</ex></as>.</def> <mark>[Cant, Eng.]</mark> <rj><au>A.
Trollope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluke</ent><br/
<hw>Fluke</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Fluked</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Fluking</conjf> <pr>(?)</pr>.]</vmorph> <def>To get or
score by a fluke; <as>as, to <ex>fluke</ex> a play in
billiards</as>.</def> <mark>[Slang]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Flukeworm</ent><br/
<hw>Fluke"worm`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>Same as 1st <er>Fluke</er>, 2.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluky</ent><br/
<hw>Fluk"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Formed like, or having,
a fluke.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flume</ent><br/
<hw>Flume</hw> <pr>(f;<umac/m)</pr>, <pos>n.</pos> <ety>[Cf. OE.
<ets>flum</ets> river, OF, <ets>flum</ets>, fr. L. <ets>flumen</ets>,
fr. <ets>fluere</ets> to flow. <root/84. See <er>Fluent</er>.]</ety>
<def>A stream; especially, a passage channel, or conduit for the water
that drives a mill wheel; or an artificial channel of water for
hydraulic or placer mining; also, a chute for conveying logs or lumber
down a declivity.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluminous</ent><br/
<hw>Flu"mi*nous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>flumen</ets>, <ets>fluminis</ets>, river.]</ety> <def>Pertaining to
rivers; abounding in streams.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flummery</ent><br/
<hw>Flum"mer*y</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[W.
<ets>llumru</ets>, or <ets>llumruwd</ets>, a kind of food made of
oatmeal steeped in water until it has turned sour, fr.
<ets>llumrig</ets> harsh, raw, crude, fr. <ets>llum</ets> sharp,
severe.]</ety> <sn>1.</sn> <def>A light kind of food, formerly made of
flour or meal; a sort of pap.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Milk and <qex>flummery</qex> are very fit for children.</q>
<rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Something insipid, or not worth having; empty
compliment; trash; unsubstantial talk of writing.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>flummery</qex> of modern criticism.</q> <rj><qau>J.
Morley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flung</ent><br/
<hw>Flung</hw> <pr>(?)</pr>, <def><pos>imp. & p. p.</pos> of
<er>Fling</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flunk</ent><br/
<hw>Flunk</hw> <pr>(fl<ucr/<nsm/k)</pr>, <pos>v. i.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Flunked</conjf>
<pr>(fl<ucr/<nsm/kt)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Flunking</conjf>.]</vmorph> <ety>[Cf. <er>Funk</er>.]</ety>
<def>To fail, as on a lesson; to back out, as from an undertaking,
through fear.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flunk</ent><br/
<hw>Flunk</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To fail in; to fail to
pass (a test, examination, or course of study).</def> <mark>[Colloq.
U.S.]</mark><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>To shirk, as a task or duty.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flunk</ent><br/
<hw>Flunk</hw>, <pos>n.</pos> <def>A failure or backing out</def>;
specifically (<mark>College cant</mark>), <def>a total failure in a
recitation.</def> <mark>[U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>flunk out</ent><br/
<hw>flunk out</hw> <pos>v. i.</pos> <def>to be dismissed (from a school
or course of study) due to failure to perform up to the minimum
standard.</def><br/
<syn><b>Syn. --</b> fail out; wash out.</syn>
[<source>PJC</source>]</p>

<p><ent>Flunky</ent><br/
<hw>Flun"ky</hw> <pr>(fl<ucr/<nsm/"k<ycr/)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Flunkies</plw>
<pr>(fl<ucr/<nsm/"k<icr/z)</pr>.</plu> <ety>[Prob. fr. or akin to
<ets>flank</ets>.]</ety> <altsp>[Written also
<asp>flunkey</asp>.]</altsp> <sn>1.</sn> <def>A contemptuous name for a
liveried servant or a footman.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who is obsequious or cringing; a snob.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>One easily deceived in buying stocks; an
inexperienced and unwary jobber.</def> <mark>[Cant, U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flunkydom</ent><br/
<hw>Flun"ky*dom</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The place or
region of flunkies.</def> <rj><au>C. Kingsley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flunlyism</ent><br/
<hw>Flun"ly*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The quality or
characteristics of a flunky; readiness to cringe to those who are
superior in wealth or position; toadyism.</def>
<rj><au>Thackeray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluo-</ent><br/
<hw>Flu"o-</hw> <pr>(<?/)</pr>. <fld>(Chem.)</fld> <def>A combining form
indicating <xex>fluorine</xex> as an ingredient; as in
<xex>fluo</xex>silicate, <xex>fluo</xex>benzene.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluoborate</ent><br/
<hw>Flu`o*bo"rate</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>fluoborate</ets>.]</ety> <fld>(Chem.)</fld> <def>A salt of
fluoboric acid; a fluoboride.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluoboric</ent><br/
<hw>Flu`o*bo"ric</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Fluo-</ets>
<ets>boric</ets>: cf. F. <ets>fluoborique</ets>.]</ety>
<fld>(Chem.)</fld> <def>Pertaining to, derived from, or consisting of,
fluorine and boron.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fluoridic acid</b></col> <fld>(Chem.)</fld>, <cd>a double
fluoride, consisting essentially of a solution of boron fluoride, in
hydrofluoric acid. It has strong acid properties, and is the type of the
borofluorides. Called also <altname>borofluoric
acid</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluoboride</ent><br/
<hw>Flu`o*bo"ride</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>See <er>Borofluoride</er>.</def></p>

<p><ent>Fluocerite</ent><br/
<ent>Fluocerine</ent><br/
<mhw>{ <hw>Flu`o*ce"rine</hw> <pr>(?)</pr>, <hw>Flu`o*ce"rite</hw>
<pr>(?)</pr> }</mhw>, <pos>n.</pos> <ety>[<ets>Fluo-</ets> +
<ets>cerium</ets>.]</ety> <fld>(Min.)</fld> <def>A fluoride of cerium,
occurring near Fahlun in Sweden. Tynosite, from Colorado, is probably
the same mineral.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluohydric</ent><br/
<hw>Flu`o*hy"dric</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Fluo-</ets> + <ets>hydro</ets>gen.]</ety> <fld>(Chem.)</fld>
<def>See <er>Hydrofluoric</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluophosphate</ent><br/
<hw>Flu`o*phos"phate</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Fluo-</ets> + <ets>phosphate</ets>.]</ety> <fld>(Chem.)</fld>
<def>A double salt of fluoric and phosphoric acids.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluor</ent><br/
\'d8<hw>Flu"or</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., a flowing, fr.
<ets>fluere</ets> to flow. See <er>Fluent</er>.]</ety> <sn>1.</sn>
<def>A fluid state.</def> <mark>[Obs.]</mark> <rj><au>Sir I.
Newton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Menstrual flux; catamenia; menses.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Min.)</fld> <def>See <er>Fluorite</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluor albus</ent><br/
\'d8<hw>Flu"or albus</hw> <pr>(?)</pr>. <ety>[L., white flow.]</ety>
<fld>(Med.)</fld> <def>The whites; leucorrh<ae/a.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluoranthene</ent><br/
<hw>Flu`or*an"thene</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Fluor</ets>ene + <ets>anth</ets>racene.]</ety>
<fld>(Chem.)</fld> <def>A white crystalline hydrocarbon
<chform>C15H10</chform>, of a complex structure, found as one ingredient
of the higher boiling portion of coal tar.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluorated</ent><br/
<hw>Flu"or*a`ted</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Chem.)</fld>
<def>Combined with fluorine; subjected to the action of fluoride.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluorene</ent><br/
<hw>Flu`or*ene</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>A colorless, crystalline hydrocarbon, <chform>C13H10</chform>
having a beautiful violet <xex>fluorescence</xex>; whence its name. It
occurs in the higher boiling products of coal tar, and is obtained
artificially.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>fluorescein</ent><br/
<ent>fluoresceine</ent><br/
<mhw><hw>fluo`res"ce*in</hw>, <hw>fluo`res"ce*ine</hw>,
<hw>flu`o*res"ce*<ium/n</hw></mhw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Chem.)</fld> <def>A yellowish red, crystalline substance,
<chform>C20H12O5</chform>, produced by heating together phthalic
anhydride and resorcin; -- so called, from the very brilliant yellowish
green <xex>fluorescence</xex> of its alkaline solutions. It has acid
properties, and its salts of the alkalies are known to the trade under
the name of <stype>uranin</stype>.</def><br/
<syn><b>Syn. --</b> fluorescein, fluorescent dye,
resorcinolphthalein.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluorescence</ent><br/
<hw>Flu`o*res"cence</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<er>Fluor</er>.]</ety> <fld>(Chemistry, Optics)</fld> <def>A
luminescence emitted by certain substances due to the absorption of
radiation at one wavelength, and the almost instantaneous re-emission of
radiation at another, usually longer wavelength. The re-radiation stops
almost as soon as the incident radiation is halted, thus distinguishing
this phenomenon from <contr>phosphorescence</contr>, in which
re-radiation of light may continue for some time after the incident
radiation is halted.</def> <note>The color of the radiated light
typically differs from the apparent color of the material, as when green
crystals of fluor spar afford blue reflections. It is due not to the
difference in the color of a distinct surface layer, but to the power
which the substance has of modifying the light incident upon it, by
first absorbing the light to achieve an excited state, and then
radiating light to resume the ground energy level. The light emitted by
fluorescent substances is in general of longer wavelength than the
incident light. The radiation can also be induced by ionizing radiation
which is not electromagnetic, such as alpha or beta rays, and cathode
rays. This property is possessed by fluorspar, uranium glass, sulphide
of calcium, and many other substances. It finds use in analytical
instruments to detect or measure radiation, and in some commercial
applications.</note><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Fluorescent</ent><br/
<hw>Flu`o*res"cent</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having the
property of fluorescence.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluorescin</ent><br/
<hw>Flu`o*res"cin</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>A colorless, amorphous substance which is produced by the reduction
of fluoresce<ium/n, and from which the latter may be formed by
oxidation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluoric</ent><br/
<hw>Flu*or"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>fluorique</ets>.]</ety> <fld>(Chem.)</fld> <def>Pertaining to,
obtained from, or containing, fluorine.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>fluoridate</ent><br/
<hw>fluoridate</hw> <pos>v. t.</pos> <def>To subject to fluoridation, as
of water; to add fluoride to.</def><br/
<syn><b>Syn. --</b> fluoridize.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>fluoridation</ent><br/
<hw>fluoridation</hw> <pos>n.</pos> <def>The addition of a fluoride to
the water supply (to prevent dental decay).</def><br/
<syn><b>Syn. --</b> fluoridization.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fluoride</ent><br/
<hw>Flu"or*ide</hw> <pr>(? <or/ ?; 104)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>fluoride</ets>.]</ety> <fld>(Chem.)</fld> <def>A binary compound of
fluorine with another element or radical.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Calcium fluoride</b></col> <fld>(Min.)</fld>,
<cd>fluorite, <chform>CaF2</chform>. See
<er>Fluorite</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>fluoridization</ent><br/
<hw>fluoridization</hw> <pos>n.</pos> <def>the addition of a fluoride to
the water supply (to prevent dental decay).</def><br/
<syn><b>Syn. --</b> fluoridation.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>fluoridize</ent><br/
<hw>fluoridize</hw> <pos>v. t.</pos> <def>to subject to fluoridation, as
of water.</def><br/
<syn><b>Syn. --</b> fluoridate.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fluorine</ent><br/
<hw>Flu"or*ine</hw> <pr>(fl<umac/"<ocr/r*<icr/n <or/
fl<umac/"<ocr/r*<emac/n; 104)</pr>, <pos>n.</pos> <ety>[NL.
<ets>fluorina</ets>: cf. G. <ets>fluorin</ets>, F. <ets>fluorine</ets>.
So called from its occurrence in the mineral <ets>fluorite</ets>.]</ety>
<fld>(Chem.)</fld> <def>A non-metallic, gaseous element of atomic number
9, strongly acid or negative, and associated with chlorine, bromine, and
iodine, in the halogen group of which it is the first member. It always
occurs combined, is very active chemically, and possesses such an
avidity for most elements, and silicon especially, that it can neither
be prepared nor kept in glass vessels, but may be contained in lead
vessels. If set free it immediately attacks a containing glass vessel,
so that it was not isolated until 1886. It is a pungent, corrosive,
colorless gas. Symbol F. Atomic weight 19.00.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Fluorine</xex> unites with hydrogen to form
hydrofluoric acid, which is the agent employed in etching glass. It
occurs naturally, principally combined as calcium fluoride in
<partof>fluorite</partof>, and as a double fluoride of aluminium and
sodium in <partof>cryolite</partof>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluorite</ent><br/
<hw>Flu"or*ite</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Min.)</fld>
<def>Calcium fluoride (<chform>CaF2</chform>), a mineral of many
different colors, white, yellow, purple, green, red, etc., often very
beautiful, crystallizing commonly in cubes with perfect octahedral
cleavage; also massive. It is used as a flux. Some varieties are used
for ornamental vessels. Also called <altname>fluor spar</altname>, or
simply <altname>fluor</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>fluorochrome</ent><br/
<hw>fluorochrome</hw> <pos>n.</pos> <def>Any of various fluorescent
substances used in fluorescence microscopy to stain specimens.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fluoroid</ent><br/
<hw>Flu"or*oid</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Fluor</ets> +
<ets>-oid</ets>.]</ety> <fld>(Crystallog.)</fld> <def>A tetrahexahedron;
-- so called because it is a common form of fluorite.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluoroscope</ent><br/
<hw>Flu*or"o*scope</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Fluor</ets>escence + <ets>-scope</ets>.]</ety> <sn>1.</sn>
<fld>(Phys.)</fld> <def>An instrument for observing or exhibiting
fluorescence.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Physics)</fld> <def>A fluorescent screen, with hood
to protect the eyes, used for observing the shadows cast by objects
placed in the path of the X rays.</def> --
<wordforms><wf>Flu*or`o*scop"ic</wf> <pr>(#)</pr>,
<pos>a.</pos></wordforms><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Fluoroscopy</ent><br/
<hw>Flu`or*os"co*py</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Examination of
an object, as the human body, by exposing it to the X rays and observing
the shadow cast upon a fluorescent screen; cryptoscopy.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Fluorous</ent><br/
<hw>Flu"or*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to
fluor.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluor spar</ent><br/
<hw>Flu"or spar`</hw> <pr>(?)</pr>. <fld>(Min.)</fld> <def>See
<er>Fluorite</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluosilicate</ent><br/
<hw>Flu`o*sil"i*cate</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>fluosilicate</ets>.]</ety> <fld>(Chem.)</fld> <def>A double
fluoride of silicon and some other (usually basic) element or radical,
regarded as a salt of <xex>fluosilicic acid</xex>; -- called also
<altname>silicofluoride</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluosilicic</ent><br/
<hw>Flu`o*si*lic"ic</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Fluo-</ets> + <ets>silicic</ets>: cf. F.
<ets>fluosilicique</ets>.]</ety> <fld>(Chem.)</fld> <def>Composed of, or
derived from, silicon and fluorine.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fluosilicic acid</b></col>, <cd>a double fluoride of
hydrogen and silicon, <chform>H2F6Si</chform>, obtained in solution in
water as a sour fuming liquid, and regarded as the type of the
fluosilicates; -- called also <altname>silicofluoric acid</altname>, and
<altname>hydrofluosilicic acid</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flurried</ent><br/
<hw>Flur"ried</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Agitated;
excited.</def> -- <wordforms><wf>Flur"ried*ly</wf>
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flurry</ent><br/
<hw>Flur"ry</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Flurries</plw> <pr>(#)</pr>.</plu> <ety>[Prov. E. <ets>flur</ets>
to ruffle.]</ety> <sn>1.</sn> <def>A sudden and brief blast or gust; a
light, temporary breeze; <as>as, a <ex>flurry</ex> of
wind</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A light shower or snowfall accompanied with
wind.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Like a <qex>flurry</qex> of snow on the whistling wind.</q>
<rj><qau>Longfellow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Violent agitation; commotion; bustle;
hurry.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The racket and <qex>flurry</qex> of London.</q> <rj><qau>Blakw.
Mag.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The violent spasms of a dying whale.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flurry</ent><br/
<hw>Flur"ry</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Flurried</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Flurrying</conjf>.]</vmorph> <def>To put in a state of agitation;
to excite or alarm.</def> <rj><au>H. Swinburne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flurt</ent><br/
<hw>Flurt</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A flirt.</def>
<mark>[Obs.]</mark> <rj><au>Quarles.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flush</ent><br/
<hw>Flush</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Flushed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Flushing</conjf>.]</vmorph> <ety>[Cf. OE. <ets>fluschen</ets> to
fly up, penetrate, F. <ets>fluz</ets> a flowing, E. <ets>flux</ets>,
dial. Sw. <ets>flossa</ets> to blaze, and E. <ets>flash</ets>; perh.
influenced by <ets>blush</ets>. <root/84.]</ety> <sn>1.</sn> <def>To
flow and spread suddenly; to rush; <as>as, blood <ex>flushes</ex> into
the face</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>flushing</qex> noise of many waters.</q>
<rj><qau>Boyle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>It <qex>flushes</qex> violently out of the cock.</q>
<rj><qau>Mortimer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To become suddenly suffused, as the cheeks; to turn
red; to blush.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To snow red; to shine suddenly; to glow.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In her cheek, distemper <qex>flushing</qex> glowed.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To start up suddenly; to take wing as a
bird.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Flushing</qex> from one spray unto another.</q> <rj><qau>W.
Browne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flush</ent><br/
<hw>Flush</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To cause to be full;
to flood; to overflow; to overwhelm with water; <as>as, to
<ex>flush</ex> the meadows</as>; to flood for the purpose of cleaning;
<as>as, to <ex>flush</ex> a sewer</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To cause the blood to rush into (the face); to put
to the blush, or to cause to glow with excitement.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Nor <qex>flush</qex> with shame the passing virgin's cheek.</q>
<rj><qau>Gay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Sudden a thought came like a full-blown rose,<br/
<qex>Flushing</qex> his brow.</q> <rj><qau>Keats.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To make suddenly or temporarily red or rosy, as if
suffused with blood.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>How faintly <qex>flushed</qex>. how phantom fair,<br/
Was Monte Rosa, hanging there!</q> <rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To excite; to animate; to stir.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Such things as can only feed his pride and <qex>flush</qex> his
ambition.</q> <rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To cause to start, as a hunter a bird.</def>
<rj><au>Nares.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To cause to flow; to draw water from, or pour it
over or through (a pond, meadow, sewer, etc.); to cleanse by means of a
rush of water.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><cs><col><b>To flush a joints</b></col> <fld>(Masonry)</fld>, <cd>to
fill them in; to point the level; to make them flush.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flush</ent><br/
<hw>Flush</hw>, <pos>v. i.</pos> <fld>(Mining)</fld> <sd>(a)</sd>
<def>To operate a placer mine, where the continuous supply of water is
insufficient, by holding back the water, and releasing it periodically
in a flood.</def> <sd>(b)</sd> <def>To fill underground spaces,
especially in coal mines, with material carried by water, which, after
drainage, constitutes a compact mass.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Flush</ent><br/
<hw>Flush</hw>, <pos>n.</pos> <sn>1.</sn> <def>A sudden flowing; a rush
which fills or overflows, as of water for cleansing purposes.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In manner of a wave or <qex>flush</qex>.</q>
<rj><qau>Ray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A suffusion of the face with blood, as from fear,
shame, modesty, or intensity of feeling of any kind; a blush; a
glow.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>flush</qex> of angered shame.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Any tinge of red color like that produced on the
cheeks by a sudden rush of blood; <as>as, the <ex>flush</ex> on the side
of a peach; the <ex>flush</ex> on the clouds at sunset.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A sudden flood or rush of feeling; a thrill of
excitement. animation, etc.; <as>as, a <ex>flush</ex> of
joy</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A flock of birds suddenly started up or
flushed.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <ety>[From F. or Sp. <ets>flux</ets>. Cf.
<er>Flux</er>.]</ety> <def>A hand of cards, all of the same suit; --
especially significant in poker, where five cards of the same suit
constitute a <ex>flush</ex>, which beats a straight but is beaten by a
full house or four of a kind.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Flush</ent><br/
<hw>Flush</hw>, <pos>a.</pos> <sn>1.</sn> <def>Full of vigor; fresh;
glowing; bright.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With all his crimes broad blown, as <qex>flush</qex> as May.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Affluent; abounding; well furnished or supplied;
hence, liberal; prodigal.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Lord Strut was not very <qex>flush</qex> in ready.</q>
<rj><qau>Arbuthnot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Arch. & Mech.)</fld> <def>Unbroken or even in
surface; on a level with the adjacent surface; forming a continuous
surface; <as>as, a <ex>flush</ex> panel; a <ex>flush</ex>
joint.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Card Playing)</fld> <def>Consisting of cards of one
suit.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Flush bolt</b></col>. <sd>(a)</sd> <cd>A screw bolt whose
head is countersunk, so as to be flush with a surface.</cd> <sd>(b)</sd>
<cd>A sliding bolt let into the face or edge of a door, so as to be
flush therewith.</cd> -- <col><b>Flush deck</b></col>.
<fld>(Naut.)</fld> <cd>See under <er>Deck</er>, <pos>n.</pos>, 1.</cd>
-- <col><b>Flush tank</b></col>, <cd>a water tank which can be emptied
rapidly for flushing drainpipes, etc.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flush</ent><br/
<hw>Flush</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>So as to be level or
even.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flushboard</ent><br/
<hw>Flush"board`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Flashboard</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flusher</ent><br/
<hw>Flush"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A workman
employed in cleaning sewers by flushing them with water.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>The red-backed shrike. See
<er>Flasher</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flushing</ent><br/
<hw>Flush"ing</hw>, <pos>n.</pos> <sn>1.</sn> <def>A heavy, coarse cloth
manufactured from shoddy; -- commonly in the <?/</def>
<mark>[Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Weaving)</fld> <def>A surface formed of floating
threads.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flushingly</ent><br/
<hw>Flush"ing*ly</hw>, <pos>adv.</pos> <def>In a flushing
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flushness</ent><br/
<hw>Flush"ness</hw>, <pos>n.</pos> <def>The state of being flush;
abundance.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluster</ent><br/
<hw>Flus"ter</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Flustered</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Flustering</conjf>.]</vmorph> <ety>[Cf. Icel. <ets>flaustra</ets>
to be flustered, <ets>flaustr</ets> a fluster.]</ety> <def>To make hot
and rosy, as with drinking; to heat; hence, to throw into agitation and
confusion; to confuse; to muddle.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His habit or <qex>flustering</qex> himself daily with claret.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluster</ent><br/
<hw>Flus"ter</hw>, <pos>v. i.</pos> <def>To be in a heat or bustle; to
be agitated and confused.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>flstering</qex>, vainglorious Greeks.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluster</ent><br/
<hw>Flus"ter</hw>, <pos>n.</pos> <def>Heat or glow, as from drinking;
agitation mingled with confusion; disorder.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flusteration</ent><br/
<hw>Flus`ter*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
flustering, or the state of being flustered; fluster.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flustrate</ent><br/
<hw>Flus"trate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[See
<er>Fluster</er>, <pos>v. t.</pos>]</ety> <def>To fluster.</def>
<mark>[Colloq.]</mark> <rj><au>Spectator.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flustration</ent><br/
<hw>Flus*tra"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
flustrating; confusion; flurry.</def> <mark>[Colloq.]</mark>
<rj><au>Richardson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flute</ent><br/
<hw>Flute</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>floute</ets>,
<ets>floite</ets>, fr. OF. <ets>fla<uum/te</ets>, <ets>flahute</ets>,
<ets>flahuste</ets>, F. <ets>fl<?/te</ets>; cf. LL. <ets>flauta</ets>,
D. <ets>fluit</ets>. See <er>Flute</er>, <pos>v. i.</pos>]</ety>
<sn>1.</sn> <def>A musical wind instrument, consisting of a hollow
cylinder or pipe, with holes along its length, stopped by the fingers or
by keys which are opened by the fingers. The modern flute is closed at
the upper end, and blown with the mouth at a lateral hole.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The breathing <qex>flute's</qex> soft notes are heard around.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Arch.)</fld> <def>A channel of curved section; --
usually applied to one of a vertical series of such channels used to
decorate columns and pilasters in classical architecture. See
<xex>Illust.</xex> under <er>Base</er>, <pos>n.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A similar channel or groove made in wood or other
material, esp. in plaited cloth, as in a lady's ruffle.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A long French breakfast roll.</def>
<rj><au>Simonds.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A stop in an organ, having a flutelike
sound.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Flute bit</b></col>, <cd>a boring tool for piercing
ebony, rosewood, and other hard woods.</cd> -- <col><b>Flute
pipe</b></col>, <cd>an organ pipe having a sharp lip or wind-cutter
which imparts vibrations to the column of air in the pipe.</cd>
<rj><au>Knight.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flute</ent><br/
<hw>Flute</hw> <pr>(fl<umac/t)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>fl<ucir/te</ets> a transport, D. <ets>fluit</ets>.]</ety> <def>A
kind of flyboat; a storeship.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Armed en fl<ucir/te</b></col> <pr>(<?/)</pr>
<fld>(Nav.)</fld>, <cd>partially armed.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flute</ent><br/
<hw>Flute</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[OE.
<ets>flouten</ets>, <ets>floiten</ets>, OF. <ets>fla<uum/ter</ets>,
<ets>fle<uum/ter</ets>, <ets>flouster</ets>, F. <ets>fl<ucir/ter</ets>,
cf. D. <ets>fluiten</ets>; ascribed to an assumed LL.
<ets>flautare</ets>, <ets>flatuare</ets>, fr. L. <ets>flatus</ets> a
blowing, fr. <ets>flare</ets> to blow. Cf. <er>Flout</er>,
<er>Flageolet</er>, <er>Flatulent</er>.]</ety> <def>To play on, or as
on, a flute; to make a flutelike sound.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flute</ent><br/
<hw>Flute</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Fluted</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Fluting</conjf> <pr>(?)</pr>.]</vmorph> <sn>1.</sn> <def>To play,
whistle, or sing with a clear, soft note, like that of a
flute.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Knaves are men,<br/
That lute and <qex>flute</qex> fantastic tenderness.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q> The redwing <qex>flutes</qex> his o-ka-lee.</q>
<rj><qau>Emerson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To form flutes or channels in, as in a column, a
ruffle, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flute a bec</ent><br/
\'d8<hw>Fl<ucir/te` <agrave/ bec"</hw> <pr>(?)</pr>. <ety>[F.]</ety>
<fld>(Mus.)</fld> <def>A beak flute, an older form of the flute, played
with a mouthpiece resembling a beak, and held like a
flageolet.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluted</ent><br/
<hw>Flut"ed</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Thin;
fine; clear and mellow; flutelike; <as>as, <ex>fluted</ex>
notes</as>.</def> <rj><au>Busby.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Decorated with flutes; channeled; grooved; <as>as, a
<ex>fluted</ex> column; a <ex>fluted</ex> ruffle; a <ex>fluted</ex>
spectrum.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flutemouth</ent><br/
<hw>Flute"mouth`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>A fish of the genus <gen>Aulostoma</gen>, having a much elongated
tubular snout.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluter</ent><br/
<hw>Flut"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who
plays on the flute; a flutist or flautist.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who makes grooves or flutings.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluting</ent><br/
<hw>Flut"ing</hw>, <pos>n.</pos> <def>Decoration by means of flutes or
channels; a flute, or flutes collectively; <as>as, the <ex>fluting</ex>
of a column or pilaster; the <ex>fluting</ex> of a lady's
ruffle.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fluting iron</b></col>, <cd>a laundry iron for fluting
ruffles; -- called also <altname>Italian iron</altname>, or
<altname>gaufering iron</altname>.</cd> <au>Knight.</au> --
<col><b>Fluting lathe</b></col>, <cd>a machine for forming spiral
flutes, as on balusters, table legs, etc.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flutist</ent><br/
<hw>Flut"ist</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>fl<ucir/tiste</ets>.]</ety> <def>A performer on the flute; a
flautist.</def> <rj><au>Busby.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 576 --></p>

<p><sn>2.</sn> <def>To move with quick vibrations or undulations;
<as>as, a sail <ex>flutters</ex> in the wind; a <ex>fluttering</ex>
fan.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To move about briskly, irregularly, or with great
bustle and show, without much result.</def><br/
[<source>1913 Webster</source>]</p>

<p><q> No rag, no scrap, of all the beau, or wit,<br/
That once so <qex>fluttered</qex>, and that once so writ.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To be in agitation; to move irregularly; to
fluctuate; to be uncertainty.</def><br/
[<source>1913 Webster</source>]</p>

<p><q> Long we <qex>fluttered</qex> on the wings of doubtful
success.</q> <rj><qau>Howell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q> His thoughts are very <qex>fluttering</qex> and wandering.</q>
<rj><qau>I. Watts.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flutter</ent><br/
<hw>Flut"ter</hw> <pr>(?)</pr>, <pos>v. t.</pos> <sn>1.</sn> <def>To
vibrate or move quickly; <as>as, a bird <ex>flutters</ex> its
wings</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To drive in disorder; to throw into
confusion.</def><br/
[<source>1913 Webster</source>]</p>

<p><q> Like an eagle in a dovecote, I<br/
<qex>Fluttered</qex> your Volscians in Corioli.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flutter</ent><br/
<hw>Flut"ter</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act of fluttering;
quick and irregular motion; vibration; <as>as, the <ex>flutter</ex> of a
fan</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q> The chirp and <qex>flutter</qex> of some single bird</q>
<rj><qau>Milnes. .</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hurry; tumult; agitation of the mind; confusion;
disorder.</def> <rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Flutter wheel</b></col>, <cd>a water wheel placed below a
fall or in a chute where rapidly moving water strikes the tips of the
floats; -- so called from the spattering, and the fluttering noise it
makes.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flutterer</ent><br/
<hw>Flut"ter*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, flutters.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flutteringly</ent><br/
<hw>Flut"ter*ing*ly</hw>, <pos>adv.</pos> <def>In a fluttering
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluty</ent><br/
<hw>Flut"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Soft and clear in tone,
like a flute.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluvial</ent><br/
<hw>Flu"vi*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>fluvialis</ets>, from <ets>fluvius</ets> river, fr.
<ets>fluere</ets> to flow: cf.F. <ets>fluvial</ets>. See
<er>Fluent</er>.]</ety> <def>Belonging to rivers; growing or living in
streams or ponds; <as>as, a <ex>fluvial</ex> plant</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluvialist</ent><br/
<hw>Flu"vi*al*ist</hw>, <pos>n.</pos> <def>One who explains geological
phenomena by the action of streams.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluviatic</ent><br/
<hw>Flu`vi*at"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>fluviaticus</ets>. See <er>Fluvial</er>.]</ety> <def>Belonging to
rivers or streams; fluviatile.</def> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluviatile</ent><br/
<hw>Flu"vi*a*tile</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>fluviatilis</ets>, fr. <ets>fluvius</ets> river: cf. F.
<ets>fluviatile</ets>.]</ety> <def>Belonging to rivers or streams;
existing in or about rivers; produced by river action; fluvial; <as>as,
<ex>fluviatile</ex> starta, plants</as>.</def>
<rj><au>Lyell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluviograph</ent><br/
<hw>Flu"vi*o*graph</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>fluvius</ets> river + <ets>-graph</ets>.]</ety> <def>An instrument
for measuring and recording automatically the rise and fall of a
river.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Fluvio-marine</ent><br/
<hw>Flu`vi*o-ma*rine"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>fluvius</ets> river + E. <ets>marine</ets>.]</ety>
<fld>(Geol.)</fld> <def>Formed by the joint action of a river and the
sea, as deposits at the mouths of rivers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluviometer</ent><br/
<hw>Flu`vi*om"e*ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>fluvius</ets> river + <ets>-meter</ets>.]</ety> <def>An instrument
for measuring the height of water in a river; a river gauge.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Flux</ent><br/
<hw>Flux</hw> <pr>(fl<ucr/ks)</pr>, <pos>n.</pos> <ety>[L.
<ets>fluxus</ets>, fr. <ets>fluere</ets>, <ets>fluxum</ets>, to flow:
cf.F. <ets>flux</ets>. See <er>Fluent</er>, and cf. 1st & 2d
<er>Floss</er>, <er>Flush</er>, <pos>n.</pos>, 6.]</ety> <sn>1.</sn>
<def>The act of flowing; a continuous moving on or passing by, as of a
flowing stream; constant succession; change.</def><br/
[<source>1913 Webster</source>]</p>

<p><q> By the perpetual <qex>flux</qex> of the liquids, a great part of
them is thrown out of the body.</q> <rj><qau>Arbuthnot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Her image has escaped the <qex>flux</qex> of things,<br/
And that same infant beauty that she wore<br/
Is fixed upon her now forevermore.</q> <rj><qau>Trench.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q> Languages, like our bodies, are in a continual
<qex>flux</qex>.</q> <rj><qau>Felton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The setting in of the tide toward the shore, -- the
ebb being called the <ant>reflux</ant>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The state of being liquid through heat;
fusion.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Chem. & Metal.)</fld> <def>Any substance or mixture
used to promote the fusion of metals or minerals, as alkalies, borax,
lime, fluorite.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <stype>White flux</stype> is the residuum of the
combustion of a mixture of equal parts of niter and tartar. It consists
chiefly of the carbonate of potassium, and is white. -- <stype>Black
flux</stype> is the ressiduum of the combustion of one part of niter and
two of tartar, and consists essentially of a mixture of potassium
carbonate and charcoal.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Med.)</fld> <sd>(a)</sd> <def>A fluid discharge
from the bowels or other part; especially, an excessive and morbid
discharge; <as>as, the bloody <ex>flux</ex> or dysentery</as>. See
<er>Bloody flux</er>.</def> <sd>(b)</sd> <def>The matter thus
discharged.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Physics)</fld> <def>The quantity of a fluid that
crosses a unit area of a given surface in a unit of time.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flux</ent><br/
<hw>Flux</hw>, <pos>a.</pos> <ety>[L. <ets>fluxus</ets>, p. p. of
<ets>fluere</ets>. See <er>Flux</er>, <pos>n.</pos>]</ety> <def>Flowing;
unstable; inconstant; variable.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>flux</qex> nature of all things here.</q>
<rj><qau>Barrow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flux</ent><br/
<hw>Flux</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Fluxed</conjf> <pr>(fl<ucr/kst)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Fluxing</conjf>.]</vmorph> <sn>1.</sn> <def>To affect, or bring
to a certain state, by flux.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He might fashionably and genteelly . . . have been dueled or<br/
<qex>fluxed</qex> into another world.</q> <rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To cause to become fluid; to fuse.</def>
<rj><au>Kirwan.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Med.)</fld> <def>To cause a discharge from; to
purge.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluxation</ent><br/
<hw>Flux*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
fluxing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluxibility</ent><br/
<hw>Flux`i*bil"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. LL.
<ets>fluxibilitas</ets> fluidity.]</ety> <def>The quality of being
fluxible.</def> <rj><au>Hammond.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluxible</ent><br/
<hw>Flux"i*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf.LL.
<ets>fluxibilis</ets> fluid, OF. <ets>fluxible</ets>.]</ety>
<def>Capable of being melted or fused, as a mineral.</def>
<rj><au>Holland.</au></rj></p>

<p>-- <wordforms><wf>Flux"i*ble*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluxile</ent><br/
<hw>Flux"ile</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>fluxilis</ets>, <pos>a.</pos>, fluid.]</ety> <def>Fluxible.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluxility</ent><br/
<hw>Flux*il"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>State of being
fluxible.</def><mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluxion</ent><br/
<hw>Flux"ion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>fluxion</ets>.]</ety> <def>The act of flowing.</def>
<rj><au>Cotgrave.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The matter that flows.</def>
<rj><au>Wiseman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Fusion; the running of metals into a fluid
state.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Med.)</fld> <def>An unnatural or excessive flow of
blood or fluid toward any organ; a determination.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A constantly varying indication.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Less to be counted than the <qex>fluxions</qex> of sun dials.</q>
<rj><qau>De Quincey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Math.)</fld> <sd>(a)</sd> <def>The infinitely small
increase or decrease of a variable or flowing quantity in a certain
infinitely small and constant period of time; the rate of variation of a
fluent; an increment; a differential.</def> <sd>(b)</sd>
<pluf>pl.</pluf> <def>A method of analysis developed by Newton, and
based on the conception of all magnitudes as generated by motion, and
involving in their changes the notion of velocity or rate of change. Its
results are the same as those of the differential and integral calculus,
from which it differs little except in notation and logical
method.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluxional</ent><br/
<hw>Flux"ion*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to, or
having the nature of, fluxion or fluxions; variable;
inconstant.</def><br/
[<source>1913 Webster</source>]</p>

<p><q> The merely human,the temporary and <qex>fluxional</qex>.</q>
<rj><qau>Coleridge.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fluxional structure</b></col> <fld>(Geol.)</fld>,
<cd>fluidal structure.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluxionary</ent><br/
<hw>Flux"ion*a*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Fluxional.</def> <rj><au>Berkeley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Med.)</fld> <def>Pertaining to, or caused by, an
increased flow of blood to a part; congestive; <as>as, a
<ex>fluxionary</ex> hemorrhage</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluxionist</ent><br/
<hw>Flux"ion*ist</hw>, <pos>n.</pos> <def>One skilled in fluxions.</def>
<rj><au>Berkeley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluxions</ent><br/
<hw>Flux"ions</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <fld>(Math.)</fld>
<def>See <er>Fluxion</er>, 6<sd>(b)</sd>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluxive</ent><br/
<hw>Flux"ive</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Flowing; also,
wanting solidity.</def> <rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fluxure</ent><br/
<hw>Flux"ure</hw> <pr>(?; 138)</pr>, <pos>n.</pos> <ety>[L.
<ets>fluxura</ets> a flowing.]</ety> <sn>1.</sn> <def>The quality of
being fluid.</def> <mark>[Obs.]</mark> <rj><au>Fielding.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Fluid matter.</def> <mark>[Obs.]</mark>
<rj><au>Drayton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fly</ent><br/
<hw>Fly</hw> <pr>(fl<imac/)</pr>, <pos>v. i.</pos>
<vmorph>[<pos>imp.</pos> <conjf>Flew</conjf> <pr>(fl<umac/)</pr>;
<pos>p. p.</pos> <conjf>Flown</conjf> <pr>(fl<omac/n)</pr>; <pos>p. pr.
& vb. n.</pos> <conjf>Flying</conjf>.]</vmorph> <ety>[OE.
<ets>fleen</ets>, <ets>fleen</ets>, <ets>fleyen</ets>,
<ets>flegen</ets>, AS. <ets>fle<oacute/gan</ets>; akin to D.
<ets>vliegen</ets>, OHG. <ets>fliogan</ets>, G. <ets>fliegen</ets>,
Icel. <ets>flj<umac/ga</ets>, Sw. <ets>flyga</ets>, Dan.
<ets>flyve</ets>, Goth. <ets>us-flaugjan</ets> to cause to fly away,
blow about, and perh. to L. <ets>pluma</ets> feather, E.
<ets>plume</ets>. <root/84. Cf. <er>Fledge</er>, <er>Flight</er>,
<er>Flock</er> of animals.]</ety> <sn>1.</sn> <def>To move in or pass
through the air with wings, as a bird.</def></p>

<p><sn>2.</sn> <def>To move through the air or before the wind; esp., to
pass or be driven rapidly through the air by any impulse.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To float, wave, or rise in the air, as sparks or a
flag.</def><br/
[<source>1913 Webster</source>]</p>

<p><q> Man is born unto trouble, as the sparks <qex>fly</qex>
upward.</q> <rj><qau>Job v. 7.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To move or pass swiftly; to hasten away; to
circulate rapidly; <as>as, a ship <ex>flies</ex> on the deep; a top
<ex>flies</ex> around; rumor <ex>flies</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Fly</qex>, envious Time, till thou run out thy race.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The dark waves murmured as the ships <qex>flew</qex> on.</q>
<rj><qau>Bryant.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To run from danger; to attempt to escape; to flee;
<as>as, an enemy or a coward <ex>flies</ex></as>. See Note under
<er>Flee</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Fly</qex>, ere evil intercept thy flight.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Whither shall I <qex>fly</qex> to escape their hands ?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To move suddenly, or with violence; to do an act
suddenly or swiftly; -- usually with a qualifying word; <as>as, a door
<ex>flies</ex> open; a bomb <ex>flies</ex> apart.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To fly about</b></col> <fld>(Naut.)</fld>, <cd>to change
frequently in a short time; -- said of the wind.</cd> -- <col><b>To fly
around</b></col>, <cd>to move about in haste.</cd>
<mark>[Colloq.]</mark> -- <col><b>To fly at</b></col>, <cd>to spring
toward; to rush on; to attack suddenly.</cd> -- <col><b>To fly in the
face of</b></col>, <cd>to insult; to assail; to set at defiance; to
oppose with violence; to act in direct opposition to; to resist.</cd> --
<col><b>To fly off</b></col>, <cd>to separate, or become detached
suddenly; to revolt.</cd> -- <col><b>To fly on</b></col>, <cd>to
attack.</cd> -- <col><b>To fly open</b></col>, <cd>to open suddenly, or
with violence.</cd> -- <col><b>To fly out</b></col>. <sd>(a)</sd> <cd>To
rush out.</cd> <sd>(b)</sd> <cd>To burst into a passion; to break out
into license.</cd> -- <col><b>To let fly</b></col>. <sd>(a)</sd> <cd>To
throw or drive with violence; to discharge.</cd> <ldquo/A man <xex>lets
fly</xex> his arrow without taking any aim.<rdquo/ <au>Addison.</au>
<sd>(b)</sd> <fld>(Naut.)</fld> <cd>To let go suddenly and entirely;
<as>as, <ex>to let fly</ex> the sheets</as>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fly</ent><br/
<hw>Fly</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To cause to fly or to
float in the air, as a bird, a kite, a flag, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The brave black flag I <qex>fly</qex>.</q> <rj><qau>W. S.
Gilbert.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To fly or flee from; to shun; to avoid.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Sleep <qex>flies</qex> the wretch.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>fly</qex> the favors of so good a king.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To hunt with a hawk.</def> <mark>[Obs.]</mark>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To manage (an aircraft) in flight; <as>as, to
<ex>fly</ex> an a<eum/roplane</as>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><cs><col><b>To fly a kite</b></col> <fld>(Com.)</fld>, <cd>to raise
money on commercial notes.</cd> <mark>[Cant or Slang]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fly</ent><br/
<hw>Fly</hw>, <pos>n.</pos>; <plu><it>pl.</it> <plw>Flies</plw>
<pr>(fl<imac/z)</pr>.</plu> <ety>[OE. <ets>flie</ets>, <ets>flege</ets>,
AS. <ets>fl<ymac/ge</ets>, <ets>fle<oacute/ge</ets>, fr.
<ets>fle<oacute/gan</ets> to fly; akin to D. <ets>vlieg</ets>, OHG.
<ets>flioga</ets>, G. <ets>fliege</ets>, Icel. & Sw. <ets>fluga</ets>,
Dan. <ets>flue</ets>. <root/ 84. See <er>Fly</er>, <pos>v.
i.</pos>]</ety> <sn>1.</sn> <fld>(Zool.)</fld> <sd>(a)</sd> <def>Any
winged insect; esp., one with transparent wings; <as>as, the Spanish
<ex>fly</ex>; fire<ex>fly</ex>; gall <ex>fly</ex>; dragon
<ex>fly</ex></as>.</def> <sd>(b)</sd> <def>Any dipterous insect; <as>as,
the house <ex>fly</ex>; flesh <ex>fly</ex>; black <ex>fly</ex>.</as> See
<er>Diptera</er>, and <xex>Illust.</xex> in Append.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A hook dressed in imitation of a fly, -- used for
fishing.</def> <ldquo/The fur-wrought <xex>fly</xex>.<rdquo/
<rj><au>Gay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A familiar spirit; a witch's attendant.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>A trifling <qex>fly</qex>, none of your great familiars.</q>
<rj><qau>B. Jonson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A parasite.</def> <mark>[Obs.]</mark>
<rj><au>Massinger.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A kind of light carriage for rapid transit, plying
for hire and usually drawn by one horse.</def> <mark>[Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>The length of an extended flag from its staff;
sometimes, the length from the <ldquo/union<rdquo/ to the extreme
end.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>The part of a vane pointing the direction from which
the wind blows.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <fld>(Naut.)</fld> <def>That part of a compass on which
the points are marked; the compass card.</def>
<rj><au>Totten.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <fld>(Mech.)</fld> <sd>(a)</sd> <def>Two or more vanes
set on a revolving axis, to act as a fanner, or to equalize or impede
the motion of machinery by the resistance of the air, as in the striking
part of a clock.</def> <sd>(b)</sd> <def>A heavy wheel, or cross arms
with weights at the ends on a revolving axis, to regulate or equalize
the motion of machinery by means of its inertia, where the power
communicated, or the resistance to be overcome, is variable, as in the
steam engine or the coining press. See <cref>Fly wheel</cref>
(below).</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <fld>(Knitting Machine)</fld> <def>The piece hinged to
the needle, which holds the engaged loop in position while the needle is
penetrating another loop; a latch.</def> <rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>11.</sn> <def>The pair of arms revolving around the bobbin, in a
spinning wheel or spinning frame, to twist the yarn.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>12.</sn> <fld>(Weaving)</fld> <def>A shuttle driven through the
shed by a blow or jerk.</def> <rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>13.</sn> <sd>(a)</sd> <def>Formerly, the person who took the
printed sheets from the press.</def> <sd>(b)</sd> <def>A vibrating frame
with fingers, attached to a power to a power printing press for doing
the same work.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>14.</sn> <def>The outer canvas of a tent with double top, usually
drawn over the ridgepole, but so extended as to touch the roof of the
tent at no other place.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>15.</sn> <def>One of the upper screens of a stage in a
theater.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>16.</sn> <def>The fore flap of a bootee; also, a lap on trousers,
overcoats, etc., to conceal a row of buttons.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>17.</sn> <fld>(Baseball)</fld> <def>A batted ball that flies to a
considerable distance, usually high in the air; also, the flight of a
ball so struck; <as>as, it was caught on the <ex>fly</ex></as>. Also
called <altname>fly ball</altname>.</def> <ldquo/a <xex>fly</xex> deep
into right field<rdquo/<br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>18.</sn> <fld>(Cotton Manuf.)</fld> <def>Waste cotton.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><cs><mcol><col><b>Black fly</b></col>, <col><b>Cheese fly</b></col>,
<col><b>Dragon fly, etc.</b></col> <cd>See under <er>Black</er>,
<er>Cheese</er>, etc.</cd> -- <col><b>Fly agaric</b></col>
<fld>(Bot.)</fld>, <cd>a mushroom (<spn>Agaricus muscarius</spn>),
having a narcotic juice which, in sufficient quantities, is
poisonous.</cd> -- <col><b>Fly block</b></col> <fld>(Naut.)</fld>, <cd>a
pulley whose position shifts to suit the working of the tackle with
which it is connected; -- used in the hoisting tackle of yards.</cd> --
<col><b>Fly board</b></col> <fld>(Printing Press)</fld>, <cd>the board
on which printed sheets are deposited by the fly.</cd> -- <col><b>Fly
book</b></col>, <cd>a case in the form of a book for anglers'
flies.</cd> <au>Kingsley.</au> -- <col><b>Fly cap</b></col>, <cd>a cap
with wings, formerly worn by women.</cd> -- <col><b>Fly drill</b></col>,
<cd>a drill having a reciprocating motion controlled by a fly wheel, the
driving power being applied by the hand through a cord winding in
reverse directions upon the spindle as it rotates backward and
forward.</cd> <au>Knight.</au> -- <col><b>Fly fishing</b></col>, <cd>the
act or art of angling with a bait of natural or artificial flies;
fishing using a fly{2} as bait.</cd> <au>Walton.</au> -- -- <col><b>Fly
fisherman</b></col>, <cd>one who fishes using natural or artificial
flies{2} as bait, especially one who fishes exclusively in that
manner.</cd> -- <col><b>Fly flap</b></col>, <cd>an implement for killing
flies.</cd> -- <col><b>Fly governor</b></col>, <cd>a governor for
regulating the speed of an engine, etc., by the resistance of vanes
revolving in the air.</cd> -- <col><b>Fly honeysuckle</b></col>
<fld>(Bot.)</fld>, <cd>a plant of the honeysuckle genus
(<gen>Lonicera</gen>), having a bushy stem and the flowers in pairs, as
<spn>L. ciliata</spn> and <spn>L. Xylosteum</spn>.</cd> -- <col><b>Fly
hook</b></col>, <cd>a fishhook supplied with an artificial fly.</cd> --
<col><b>Fly leaf</b></col>, <cd>an unprinted leaf at the beginning or
end of a book, circular, programme, etc.</cd> -- <col><b>Fly
maggot</b></col></mcol>, <cd>a maggot bred from the egg of a fly.</cd>
<au>Ray.</au> -- <col><b>Fly net</b></col>, <cd>a screen to exclude
insects.</cd> -- <col><b>Fly nut</b></col> <fld>(Mach.)</fld>, <cd>a nut
with wings; a thumb nut; a finger nut.</cd> -- <col><b>Fly
orchis</b></col> <fld>(Bot.)</fld>, <cd>a plant (<spn>Ophrys
muscifera</spn>), whose flowers resemble flies.</cd> -- <col><b>Fly
paper</b></col>, <cd>poisoned or sticky paper for killing flies that
feed upon or are entangled by it.</cd> -- <col><b>Fly powder</b></col>,
<cd>an arsenical powder used to poison flies.</cd> -- <col><b>Fly
press</b></col>, <cd>a screw press for punching, embossing, etc.,
operated by hand and having a heavy fly.</cd> -- <col><b>Fly
rail</b></col>, <cd>a bracket which turns out to support the hinged leaf
of a table.</cd> -- <col><b>Fly rod</b></col>, <cd>a light fishing rod
used in angling with a fly.</cd> -- <col><b>Fly sheet</b></col>, <cd>a
small loose advertising sheet; a handbill.</cd> -- <col><b>Fly
snapper</b></col> <fld>(Zool.)</fld>, <cd>an American bird
(<spn>Phainopepla nitens</spn>), allied to the chatterers and
shrikes.</cd> The male is glossy blue-black; the female brownish gray.
-- <col><b>Fly wheel</b></col> <fld>(Mach.)</fld>, <cd>a heavy wheel
attached to machinery to equalize the movement (opposing any sudden
acceleration by its inertia and any retardation by its momentum), and to
accumulate or give out energy for a variable or intermitting resistance.
See <er>Fly</er>, <pos>n.</pos>, 9.</cd> -- <col><b>On the fly</b></col>
<fld>(Baseball)</fld>, <cd>still in the air; -- said of a batted ball
caught before touching the ground.</cd><-- (b) at the moment needed,
without prior preparation. -- said of objects created as needed in the
course of some activity, rather than having been prepared before the
activity began. A term Much used in computer programming. (c) busy; in
motion. -->.</cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fly</ent><br/
<hw>Fly</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Knowing; wide awake; fully
understanding another's meaning.</def> <mark>[Slang]</mark>
<rj><au>Dickens.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fly fungus</ent><br/
<ent>Fly amanita</ent><br/
<mhw>{ <hw>Fly amanita</hw>, <hw>Fly fungus</hw> }</mhw>.
<fld>(Bot.)</fld> <def>A poisonous mushroom (<spn>Amanita
muscaria</spn>, syn. <spn>Agaricus muscarius</spn>), having usually a
bright red or yellowish cap covered with irregular white spots. It has a
distinct volva at the base, generally an upper ring on the stalk, and
white spores. Called also <altname>fly agaric</altname>, <altname>deadly
amanita</altname>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Flyaway</ent><br/
<hw>Fly"a*way`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Disposed to fly
away; flighty; unrestrained; light and free; -- used of both persons and
things.</def> -- <def2><pos>n.</pos> <def>A flyaway person or
thing.</def> <ldquo/Truth is such a <xex>flyaway</xex>.<rdquo/
<rj><au>Emerson.</au></rj></def2><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Flyaway grass</ent><br/
<hw>Flyaway grass</hw>. <fld>(Bot.)</fld> <def>The hair grass
(<spn>Agrostis scabra</spn>). So called from its light panicle, which is
blown to great distances by the wind.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Flybane</ent><br/
<hw>Fly"bane`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>A
kind of catchfly of the genus <gen>Silene</gen>; also, a poisonous
mushroom (<spn>Agaricus muscarius</spn>); fly agaric.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fly-bitten</ent><br/
<hw>Fly"-bit`ten</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Marked by, or as
if by, the bite of flies.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flyblow</ent><br/
<hw>Fly"blow`</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To deposit eggs
upon, as a flesh fly does on meat; to cause to be maggoty; hence, to
taint or contaminate, as if with flyblows.</def> <rj><au>Bp.
Srillingfleet.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flyblow</ent><br/
<hw>Fly"blow`</hw>, <pos>n.</pos> <fld>(Zool.)</fld> <def>One of the
eggs or young larv<ae/ deposited by a flesh fly, or blowfly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flyblown</ent><br/
<hw>Fly"blown`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Tainted or
contaminated with flyblows; damaged; foul.</def><br/
[<source>1913 Webster</source>]</p>

<p><q> Wherever <qex>flyblown</qex> reputations were assembled.</q>
<rj><qau>Thackeray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flyboat</ent><br/
<hw>Fly"boat`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Fly</ets> +
<ets>boat</ets>: cf. D. <ets>vlieboot</ets>.]</ety> <sn>1.</sn>
<fld>(Naut.)</fld> <def>A large Dutch coasting vessel.</def><br/
[<source>1913 Webster</source>]</p>

<p><q> Captain George Weymouth made a voyage of discovery to the
northwest with two <qex>flyboats</qex>.</q>
<rj><qau>Purchas.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A kind of passenger boat formerly used on
canals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fly-case</ent><br/
<hw>Fly"-case`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>The covering of an insect, esp. the elytra of beetles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flycatcher</ent><br/
<hw>Fly"catch`er</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>One of numerous species of birds that feed upon insects, which they
take on the wing.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The true flycatchers of the Old World are Oscines, and
belong to the family <fam>Muscicapid<ae/</fam>, as the spotted
flycatcher (<spn>Muscicapa grisola</spn>). The American flycatchers, or
tyrant flycatchers, are Clamatores, and belong to the family
<fam>Tyrannid<ae/</fam>, as the kingbird, pewee, crested flycatcher
(<spn>Myiarchus crinitus</spn>), and the vermilion flycatcher or
churinche (<spn>Pyrocephalus rubineus</spn>). Certain American
flycatching warblers of the family <fam>Sylvicolid<ae/</fam> are also
called flycatchers, as the Canadian flycatcher (<spn>Sylvania
Canadensis</spn>), and the hooded flycatcher (<spn>S. mitrata</spn>).
See <er>Tyrant flycatcher</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fly-catching</ent><br/
<hw>Fly"-catch`ing</hw>, <pos>a.</pos> <fld>(Zool.)</fld> <def>Having
the habit of catching insects on the wing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flyer</ent><br/
<hw>Fly"er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Flier</er>.]</ety> <sn>1.</sn> <def>One that uses wings.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The fly of a flag: See <er>Fly</er>, <pos>n.</pos>,
6.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Anything that is scattered abroad in great numbers
as a theatrical programme, an advertising leaf, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Arch.)</fld> <def>One in a flight of steps which
are parallel to each other(as in ordinary stairs), as distinguished from
a <xex>winder</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>The pair of arms attached to the spindle of a
spinning frame, over which the thread passes to the bobbin; -- so called
from their swift revolution. See <er>Fly</er>, <pos>n.</pos>,
11.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>The fan wheel that rotates the cap of a windmill as
the wind veers.</def> <rj><au>Internat. Cyc.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Stock Jobbing)</fld> <def>A small operation not
involving ? considerable part of one's capital, or not in the line of
one's ordinary business; a venture.</def> <mark>[Cant]</mark>
<rj><au>Bartlett.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flyfish</ent><br/
<hw>Fly"fish`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>A
California scorp<ae/noid fish (<spn>Sebastichthys rhodochloris</spn>),
having brilliant colors.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fly-fish</ent><br/
<hw>Fly"-fish</hw>, <pos>v. i.</pos> <def>To angle, using flies for
bait.</def> <rj><au>Walton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flying</ent><br/
<hw>Fly"ing</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From <er>Fly</er>,
<pos>v. i.</pos>]</ety> <def>Moving in the air with, or as with, wings;
moving lightly or rapidly; intended for rapid movement.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 577 --></p>

<p><cs><col><b>Flying army</b></col> <fld>(Mil.)</fld> <cd>a body of
cavalry and infantry, kept in motion, to cover its own garrisons and to
keep the enemy in continual alarm.</cd> <au>Farrow.</au>
--<col><b>Flying artillery</b></col> <fld>(Mil.)</fld>, <cd>artillery
trained to rapid evolutions, -- the men being either mounted or trained
to spring upon the guns and caissons when they change position.</cd> --
<mcol><col><b>Flying bridge</b></col>, <col><b>Flying
camp</b></col></mcol>. <cd>See under <er>Bridge</er>, and
<er>Camp</er>.</cd> -- <col><b>Flying buttress</b></col>
<fld>(Arch.)</fld>, <cd>a contrivance for taking up the thrust of a roof
or vault which can not be supported by ordinary buttresses. It consists
of a straight bar of masonry, usually sloping, carried on an arch, and a
solid pier or buttress sufficient to receive the thrust. The word is
generally applied only to the straight bar with supporting arch.</cd> --
<col><b>Flying colors</b></col>, <cd>flags unfurled and waving in the
air</cd>; hence: <col><b>To come off with flying colors</b></col>,
<cd>to be victorious; to succeed thoroughly in an undertaking.</cd> --
<col><b>Flying doe</b></col> <fld>(Zool.)</fld>, <cd>a young female
kangaroo.</cd> -- <col><b>Flying dragon</b></col>. <sd>(a)</sd>
<fld>(Zool.)</fld> <cd>See <er>Dragon</er>, 6.</cd> <sd>(b)</sd> <cd>A
meteor. See under <er>Dragon</er>.</cd> -- <col><b>Flying
Dutchman</b></col>. <sd>(a)</sd> <cd>A fabled Dutch mariner condemned
for his crimes to sail the seas till the day of judgment.</cd>
<sd>(b)</sd> <cd>A spectral ship.</cd> -- <col><b>Flying fish</b></col>.
<fld>(Zool.)</fld> <cd>See <er>Flying fish</er>, in the Vocabulary.</cd>
-- <col><b>Flying fox</b></col> <fld>(Zool.)</fld>, <cd>see <er>Flying
fox</er> in the vocabulary.</cd> -- <col><b>Flying frog</b></col>
<fld>(Zool.)</fld>, <cd>either of two East Indian tree frogs of the
genus <gen>Rhacophorus</gen> (<spn>Rhacophorus nigrapalmatus</spn> and
<spn>Rhacophorus pardalis</spn>), having very large and broadly webbed
feet, which serve as parachutes, and enable it to make very long
leaps.</cd> -- <col><b>Flying gurnard</b></col> <fld>(Zool.)</fld>,
<cd>a species of gurnard of the genus <gen>Cephalacanthus</gen> or
<gen>Dactylopterus</gen>, with very large pectoral fins, said to be able
to fly like the flying fish, but not for so great a distance.</cd>
<note>Three species are known; that of the Atlantic is
<spn>Cephalacanthus volitans</spn>.</note> -- <col><b>Flying
jib</b></col> <fld>(Naut.)</fld>, <cd>a sail extended outside of the
standing jib, on the flying-jib boom.</cd> -- <col><b>Flying-jib
boom</b></col> <fld>(Naut.)</fld>, <cd>an extension of the jib
boom.</cd> -- <col><b>Flying kites</b></col> <fld>(Naut.)</fld>,
<cd>light sails carried only in fine weather.</cd> -- <col><b>Flying
lemur</b></col>. <fld>(Zool.)</fld> <cd>See <er>Colugo</er>.</cd> --
<col><b>Flying level</b></col> <fld>(Civil Engin.)</fld>, <cd>a
reconnoissance level over the course of a projected road, canal,
etc.</cd> -- <col><b>Flying lizard</b></col>. <fld>(Zool.)</fld> <cd>See
<er>Dragon</er>, <pos>n.</pos> 6.</cd> -- <mcol><col><b>Flying
machine</b></col>, <cd>any apparatus for navigating through the air,
especially a heavier-than-air machine.</cd> -- <col><b>Flying
mouse</b></col> <fld>(Zool.)</fld>, <cd>the opossum mouse
(<spn>Acrobates pygm<ae/us</spn>), a marsupial of Australia. Called also
<altname>feathertail glider</altname>.</cd> <note>It has lateral folds
of skin, like the flying squirrels, and a featherlike tail.</note> --
<col><b>Flying party</b></col> <fld>(Mil.)</fld>, <cd>a body of soldiers
detailed to hover about an enemy.</cd> -- <col><b>Flying
phalanger</b></col> <fld>(Zool.)</fld>, <cd>one of several species of
small marsuupials of the genera <gen>Petaurus</gen> and
<gen>Belideus</gen>, of Australia and New Guinea, having lateral folds
like those of the flying squirrels. The sugar squirrel (<spn>Belideus
sciureus</spn>), and the ariel (<spn>Belideus ariel</spn>), are the best
known; -- called also <altname>squirrel petaurus</altname> and
<altname>flying squirrel</altname>. See <er>Sugar squirrel</er>.</cd> --
<col><b>Flying pinion</b></col>, <cd>the fly of a clock.</cd> --
<col><b>Flying sap</b></col> <fld>(Mil.)</fld>, <cd>the rapid
construction of trenches (when the enemy's fire of case shot precludes
the method of simple trenching), by means of gabions placed in
juxtaposition and filled with earth.</cd> -- <col><b>Flying
shot</b></col>, <cd>a shot fired at a moving object, as a bird on the
wing.</cd> -- <col><b>Flying spider</b></col>. <fld>(Zool.)</fld>
<cd>See <er>Ballooning spider</er>.</cd> -- <col><b>Flying
squid</b></col> <fld>(Zool.)</fld>, <cd>an oceanic squid
(<spn>Ommastrephes Bartramii</spn> syn. <spn>Sthenoteuthis
Bartramii</spn>), abundant in the Gulf Stream, which is able to leap out
of the water with such force that it often falls on the deck of a
vessel.</cd> -- <col><b>Flying squirrel</b></col> <fld>(Zool.)</fld>
<cd>See <er>Flying squirrel</er>, in the Vocabulary.</cd> --
<col><b>Flying start</b></col>, <cd>a start in a sailing race in which
the signal is given while the vessels are under way.</cd> --
<col><b>Flying torch</b></col></mcol> <fld>(Mil.)</fld>, <cd>a torch
attached to a long staff and used for signaling at night.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flying boat</ent><br/
<hw>Flying boat</hw>. <def>A compact form of hydro-a<eum/roplane having
one central body, or hull.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Flying fish</ent><br/
<hw>Fly"ing fish`</hw> <pr>(?)</pr>. <fld>(Zool.)</fld> <def>A fish
which is able to leap from the water, and fly a considerable distance by
means of its large and long pectoral fins. These fishes belong to
several species of the genus <gen>Exoc<oe/tus</gen>, and are found in
the warmer parts of all the oceans.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flying fox</ent><br/
<hw>Fly"ing fox`</hw> <pr>(?)</pr>. <fld>(Zool.)</fld> <sn>1.</sn>
<def>a fruit bat of the genus <gen>Pteropus</gen>, which has a head
resembling that of a fox.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>the <er>colugo</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flying lemur</ent><br/
<hw>Fly"ing le"mur</hw> <pr>(?)</pr>. <fld>(Zool.)</fld> <def>either of
two nocturnal lemurlike mammals inhabiting the East Indies
(<spn>Cynocephalus variegatus</spn>) or the Phillipines
(<spn>Cynocephalus volans</spn>) having broad folds of skin between the
fore and hind limbs on both sides of the body allowing them to make long
gliding leaps; they have been classed in the separate order
<ord>Dermoptera</ord>. They are arboreal and have become rare.</def><br/
[<source>PJC</source>]</p>

<p><ent>Flying squirrel</ent><br/
<hw>Fly"ing squir"rel</hw> <pr>(? or ?)</pr>. <fld>(Zool.)</fld>
<def>One of a group of squirrels, of the genus <gen>Glaucomys</gen>
(formerly <gen>Pteromus</gen> and <gen>Sciuropterus</gen> [1913
Webster]), especially <spn>Glaucomys volans</spn> and <spn>Glaucomys
sabrinus</spn>, having parachute-like folds of skin extending from the
fore to the hind legs, which enable them to make very long, gliding
leaps.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><note><hand/ The species of Pteromys are large, with bushy tails, and
inhabit southern Asia and the East Indies; those of Sciuropterus are
smaller, with flat tails, and inhabit the northern parts of Europe,
Asia, and America. The American species <spn>(Sciuropterus
volucella)</spn> is also called Assapan. The Australian flying
squirrels, or flying phalangers, are marsupials. See <cref>Flying
phalanger</cref> (above).</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>flyleaf</ent><br/
<hw>flyleaf</hw> <pos>n.</pos> <def>A blank leaf in the front of back or
a book.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Flyman</ent><br/
<hw>Fly"man</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Flymen</plw> <pr>(-m?n)</pr>.</plu> <def>The driver of a fly, or
light public carriage.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>flyover</ent><br/
<hw>flyover</hw> <pos>n.</pos> <sn>1.</sn> <def>the upper level of a
crossing of two highways at different levels; called in the United
States an <altname>overpass</altname>; <as>as, an overpass is called a
<ex>flyover</ex> or a flypast in England</as>.</def>
<mark>[Brit.]</mark> <br/
<syn><b>Syn. --</b> overpass, flypast.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>a low-altitude flight (usually of military aircraft)
over spectators on the ground.</def><br/
<syn><b>Syn. --</b> flypast.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>flypaper</ent><br/
<hw>fly"pa`per</hw> <pr>(fl<imac/"p<amac/`p<etil/r)</pr>, <pos>n.</pos>
<def>A strip of paper that is coated with a sticky substance and
suspended from an overhead object to trap and kill flies; also, a
similar paper poisoned so as to kill flies on contact.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>flypast</ent><br/
<hw>fly"past</hw> <pr>(fl<imac/"p<acr/st)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>the upper level of a crossing of two highways at
different levels; same as <altname>flyover</altname>; called in the
United States an <altname>overpass</altname>.</def> <mark>[Brit.]</mark>
<br/
<syn><b>Syn. --</b> overpass, flyover.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>a low-altitude flight (usually of military aircraft)
over spectators on the ground.</def><br/
<syn><b>Syn. --</b> flyover.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Flysch</ent><br/
<hw>Flysch</hw> <pr>(fl<emac/sh)</pr>, <pos>n.</pos> <ety>[A Swiss word,
fr. G. <ets>fliessen</ets> to flow, melt.]</ety> <fld>(Geol.)</fld>
<def>A name given to the series of sandstones and schists overlying the
true nummulitic formation in the Alps, and included in the Eocene
Tertiary.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flyspeck</ent><br/
<hw>Fly"speck</hw> <pr>(fl<imac/"sp<ecr/k)</pr>, <pos>n.</pos> <def>A
speck or stain made by the excrement of a fly; hence, any insignificant
dot.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Flyspeck</ent><br/
<hw>Fly"speck</hw> <pr>(fl<imac/"sp<ecr/k)</pr>, <pos>v. t.</pos>
<def>To soil with flyspecks.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>flyswatter</ent><br/
<ent>flyswat</ent><br/
<mhw><hw>fly"swat</hw> , <hw>fly"swat*ter</hw></mhw> <pos>n.</pos>
<def>An implement with a flat part (a mesh of metal or plastic) and a
long handle, used to kill insects by striking them. The handle is
typically about one foot long and the flat mesh at the end (usually of
plastic) is about 5 inces square.</def><br/
<syn><b>Syn. --</b> swatter.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>flytrap</ent><br/
<hw>fly"trap</hw> <pr>(fl<imac/"tr<acr/p)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>A trap for catching flies.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>A plant <spn>(Dion<ae/a
muscipula)</spn>, called also <altname>Venus's flytrap</altname>, having
two-lobed leaves which are fringed with stiff bristles, and fold
together when certain sensitive hairs on their upper surface are
touched, thus trapping insects that light on them. The insects so caught
are afterwards digested by a secretion from the upper surface of the
leaves. The plant is native to North and South Carolina, growing in
bogs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>flywheel</ent><br/
<hw>flywheel</hw> <pos>n.</pos> <def>A heavy wheel or disk which stores
kinetic energy by rotating on a shaft, and by its momentum smoothes the
operation of a reciprocating engine by reducing fluctuations of speed.
It is used in certain types of machinery, such as automobiles.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><note><hand/ Flywheels rotating at high speed have also been proposed
as a means to store kinetic energy for use as a low-polluting source of
energy in vehicles.</note><br/
[<source>PJC</source>]</p>

<p><ent>FM</ent><br/
<hw>FM</hw> <pos>n.</pos> <ety>[<ets>F</ets>requency
<ets>M</ets>odulaiton.]</ety> <def>A method of transmitting radio
signals by modulating the frequency of the carrier wave; -- opposed to
AM (amplitude modulation), in which the signal modulates the amplitude,
rather than the frequency of the carrier wave.</def>
<mark>[acron.]</mark> <br/
<syn><b>Syn. --</b> frequency modulation.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Fm</ent><br/
<hw>Fm</hw> <pos>prop. n.</pos> <def>The chemical symbol for
<er>Fermium</er>, a transuranic element.</def><br/
<syn><b>Syn. --</b> fermium, atomic number 100.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>fnese</ent><br/
<hw>fnese</hw> <pr>(fn<emac/z)</pr>, <pos>v. i.</pos> <ety>[AS.
<ets>fn<emac/san</ets>, <ets>gefn<emac/san</ets>.]</ety> <def>To breathe
heavily; to snort.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>FNMA</ent><br/
<hw>FNMA</hw> <pos>n.</pos> <def>The <er>Federal National Mortgage
Association</er> a federally chartered corporation that purchases and
resells mortgages.</def> <mark>[acron.]</mark> <br/
<syn><b>Syn. --</b> Federal National Mortgage Association, Fannie
Mae.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fo</ent><br/
<hw>Fo</hw> <pr>(f<omac/)</pr>, <pos>n.</pos> <def>The Chinese name of
Buddha.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foal</ent><br/
<hw>Foal</hw> <pr>(f<omac/l)</pr>, <pos>n.</pos> <ety>[OE.
<ets>fole</ets>, AS. <ets>fola</ets>; akin to OHG. <ets>folo</ets>, G.
<ets>fohlen</ets>, Goth. <ets>fula</ets>, Icel. <ets>foli</ets>, Sw.
<ets>f<aring/le</ets>, Gr. <grk>pw^los</grk>, L. <ets>pullus</ets> a
young animal. Cf. <er>Filly</er>, <er>Poultry</er>,
<er>Pullet</er>.]</ety> <fld>(Zo<oum/.)</fld> <def>The young of any
animal of the Horse family <fam>(Equid<ae/)</fam>; a colt; a
filly.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Foal teeth</b></col> <fld>(Zool.)</fld>, <cd>the first
set of teeth of a horse.</cd> -- <mcol><col><b>In foal</b></col>,
<col><b>With foal</b></col></mcol>, <cd>being with young; pregnant; --
said of a mare or she ass.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foal</ent><br/
<hw>Foal</hw> <pr>(f<omac/l)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Foaled</conjf> <pr>(f<omac/ld)</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>Foaling</conjf>.]</vmorph> <def>To bring forth (a
colt); -- said of a mare or a she ass.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foal</ent><br/
<hw>Foal</hw> <pr>(f<omac/l)</pr>, <pos>v. i.</pos> <def>To bring forth
young, as an animal of the horse kind.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foalfoot</ent><br/
<hw>Foal"foot`</hw> <pr>(f<omac/l"f<oocr/t`)</pr>, <pos>n.</pos>
<fld>(Bot.)</fld> <def>See <er>Coltsfoot</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foam</ent><br/
<hw>Foam</hw> <pr>(f<omac/m)</pr>, <pos>n.</pos> <ety>[OE.
<ets>fam</ets>, <ets>fom</ets>, AS. <ets>f<amac/m</ets>; akin to OHG. &
G. <ets>feim</ets>.]</ety> <def>The white substance, consisting of an
aggregation of bubbles, which is formed on the surface of liquids, or in
the mouth of an animal, by violent agitation or fermentation; froth;
spume; scum; <as>as, the <ex>foam</ex> of the sea</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Foam cock</b></col>, <cd>in steam boilers, a cock at the
water level, to blow off impurities.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foam</ent><br/
<hw>Foam</hw> <pr>(f<omac/m)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Foamed</conjf> <pr>(f<omac/md)</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>Foaming</conjf>.]</vmorph> <ety>[AS.
<ets>f<aemac/man</ets>. See <er>Foam</er>, <pos>n.</pos>]</ety>
<sn>1.</sn> <def>To gather foam; to froth; <as>as, the billows
<ex>foam</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He <qex>foameth</qex>, and gnasheth with his teeth.</q>
<rj><qau>Mark ix. 18.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To form foam, or become filled with foam; -- said of
a steam boiler when the water is unduly agitated and frothy, as because
of chemical action.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foam</ent><br/
<hw>Foam</hw> <pr>(f<omac/m)</pr>, <pos>v. t.</pos> <def>To cause to
foam; <as>as, to <ex>foam</ex> the goblet</as>; also (with out), to
throw out with rage or violence, as foam.</def>
<ldquo/<xex>Foaming</xex> out their own shame.<rdquo/ <rj><qau>Jude
13.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>foaming</ent><br/
<hw>foam"ing</hw> <pos>adj.</pos> <def>Giving off bubbles and developing
a head of foam; <as>as, a <ex>foaming</ex> glass of beer</as>.</def><br/
<syn><b>Syn. --</b> bubbling, frothing.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>foamingly</ent><br/
<hw>foam"ing*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>With foam;
frothily.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>foamless</ent><br/
<hw>foam"less</hw> <pr>(f<omac/m"l<ecr/s)</pr>, <pos>a.</pos>
<def>Having no foam.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>foamy</ent><br/
<hw>foam"y</hw> <pr>(f<omac/m"<ycr/)</pr>, <pos>a.</pos> <def>Covered
with foam; frothy; spumy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Behold how high the <qex>foamy</qex> billows ride!</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fob</ent><br/
<hw>Fob</hw> <pr>(f<ocr/b)</pr>, <pos>n.</pos> <ety>[Cf. Prov. G.
<ets>fuppe</ets> pocket.]</ety> <sn>1.</sn> <def>A little pocket for a
watch; -- callled also a <altname>watch pocket</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>a short chain or ribbon attached to a pocket watch,
usually worn hanging out of the watch pocket, and used to conveniently
remove the watch from the watch pocket.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Fob chain</b></col>, <cd>a short watch chain worn with a
watch carried in the fob; a fob{2}.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fob</ent><br/
<hw>Fob</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Fobbed</conjf> <pr>(#)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Fobbing</conjf>.]</vmorph> <ety>[Cf.Fop.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>To beat; to maul.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To cheat; to trick; to impose on.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To fob off</b></col>, <cd>to shift off by an artifice; to
put aside; to delude with a trick."A conspiracy of bishops could
prostrate and fob off the right of the people."</cd>
<rj><au>Milton.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Focal</ent><br/
<hw>Fo"cal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>focal</ets>. See <er>Focus</er>.]</ety> <def>Belonging to,or
concerning, a focus; as, a focal point.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Focal distance, or length, of a lens or mirror</b></col>
<fld>(Opt.)</fld>, <cd>the distance of the focus from the surface of the
lens or mirror, or more exactly, in the case of a lens, from its optical
center.</cd> --<col><b>Focal distance of a telescope</b></col>, <cd>the
distance of the image of an object from the object glass.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Focalization</ent><br/
<hw>Fo`cal*i*za"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
focalizing or bringing to a focus, or the state of being
focalized.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Focalize</ent><br/
<hw>Fo"cal*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Focalized</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Focalizing</conjf> <pr>(?)</pr>.]</vmorph> <def>To bring
to a focus; to focus; to concentrate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Light is focalized in the eye, sound in the ear.</q> <rj><qau>De
Quincey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Focillate</ent><br/
<hw>Foc"il*late</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>focilatus</ets>, p. p. of focillare.]</ety> <def>To nourish.</def>
<mark>[Obs.]</mark> <rj><au>Blount.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Focillation</ent><br/
<hw>Foc`il*la"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Comfort;
support.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Focimeter</ent><br/
<hw>Fo*cim"e*ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Focus</ets>
+ <ets>-meter</ets>.]</ety> <fld>(Photog.)</fld> <def>An assisting
instrument for focusing an object in or before a camera.</def>
<rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>fo'c's'le</ent><br/
<ent>fo'c'sle</ent><br/
<mhw><hw>fo'c'sle</hw>, <hw>fo'c's'le</hw></mhw>
<pr>(f<omac/k"s'l)</pr>, <pos>n.</pos> <def>The <er>forecastle</er>, a
superstructure in the bow of a merchant ship where the crew is housed;
-- the spelling is intended to reflect the common pronunciation among
seamen.</def><br/
<syn><b>Syn. --</b> forecastle.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Focus</ent><br/
<hw>Fo"cus</hw> <pr>(f<omac/"k<ucr/s)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> E. <plw>Focuses</plw>
<pr>(f<omac/"k<ucr/s*<ecr/z)</pr>, L. <plw>Foci</plw>
<pr>(f<omac/"s<imac/)</pr>.</plu> <ety>[L. <ets>focus</ets> hearth,
fireplace; perh. akin to E. <ets>bake</ets>. Cf. <er>Curfew</er>,
<er>Fuel</er>, <er>Fusil</er> the firearm.]</ety> <sn>1.</sn>
<fld>(Opt.)</fld> <def>A point in which the rays of light meet, after
being reflected or refracted, and at which the image is formed; <as>as,
the <ex>focus</ex> of a lens or mirror.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Geom.)</fld> <def>A point so related to a conic
section and certain straight line called the <xex>directrix</xex> that
the ratio of the distance between any point of the curve and the focus
to the distance of the same point from the directrix is
constant.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Thus, in the ellipse FGHKLM, A is the focus and CD the
directrix, when the ratios FA:FE, GA:GD, MA:MC, etc., are all equal. So
in the hyperbola, A is the focus and CD the directrix when the ratio
HA:HK is constant for all points of the curve; and in the parabola, A is
the focus and CD the directrix when the ratio BA:BC is constant. In the
ellipse this ratio is less than unity, in the parabola equal to unity,
and in the hyperbola greater than unity. The ellipse and hyperbola have
each two foci, and two corresponding directrixes, and the parabola has
one focus and one directrix. In the ellipse the <it>sum</it> of the two
lines from any point of the curve to the two foci is constant; that is:
<mathex>AG + GB = AH + HB</mathex>; and in the hyperbola the
<it>difference</it> of the corresponding lines is constant. The diameter
which passes through the foci of the ellipse is the <xex>major
axis</xex>. The diameter which being produced passes through the foci of
the hyperbola is the <xex>transverse axis</xex>. The middle point of the
major or the transverse axis is the center of the curve. Certain other
curves, as the lemniscate and the Cartesian ovals, have points called
<xex>foci</xex>, possessing properties similar to those of the foci of
conic sections. In an ellipse, rays of light coming from one focus, and
reflected from the curve, proceed in lines directed <it>toward</it> the
other; in an hyperbola, in lines directed <it>from</it> the other; in a
parabola, rays from the focus, after reflection at the curve, proceed in
lines parallel to the axis. Thus rays from A in the ellipse are
reflected to B; rays from A in the hyperbola are reflected toward L and
M away from B.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A central point; a point of concentration.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Aplanatic focus</b></col>. <fld>(Opt.)</fld> <cd>See
under <er>Aplanatic</er>.</cd> -- <col><b>Conjugate focus</b></col>
<fld>(Opt.)</fld>, <cd>the focus for rays which have a sensible
divergence, as from a near object; -- so called because the positions of
the object and its image are interchangeable.</cd> -- <col><b>Focus
tube</b></col> <fld>(Phys.)</fld>, <cd>a vacuum tube for R<oe/ntgen rays
in which the cathode rays are focused upon the anticathode, for
intensifying the effect.</cd> -- <mcol><col><b>Principal
focus</b></col>, <it>or</it> <col><b>Solar focus</b></col></mcol>
<fld>(Opt.)</fld>, <cd>the focus for parallel rays.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Focus</ent><br/
<hw>Fo"cus</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Focused</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Focusing</conjf>.]</vmorph> <def>To bring to a focus; to
focalize; as, to focus a camera.</def> <rj><au>R. Hunt.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>focused</ent><br/
<hw>focused</hw> <pos>adj.</pos> <altsp>[Also spelled
<asp>focussed</asp>.]</altsp> <sn>1.</sn> <def>being in focus or brought
into focus; clearly delineated; -- of an image. Opposite of
<ant>unfocused</ant>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>converging on a point; -- of light rays; <as>as,
<ex>focused</ex> light rays can set something afire</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>3.</sn> <def>concentrated on or clustered around a central point
or purpose.</def><br/
<syn><b>Syn. --</b> centered, centred, centralized.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>focussed</ent><br/
<hw>focussed</hw> <pos>adj.</pos> <sn>1.</sn> <def>same as
<er>focused</er> (in all senses).</def><br/
<syn><b>Syn. --</b> focused.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>focussing</ent><br/
<ent>focusing</ent><br/
<mhw><hw>focusing</hw>, <hw>focussing</hw></mhw> <pos>n.</pos>
<sn>1.</sn> <def>the concentration of attention or energy on
something.</def><br/
<syn><b>Syn. --</b> focus, focussing.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>the act of bringing into focus.</def><br/
<syn><b>Syn. --</b> focalization, focalisation.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fodder</ent><br/
<hw>Fod"der</hw> <pr>(f<ocr/d"d<etil/r)</pr>, <pos>n.</pos> <ety>[See
1st <er>Fother</er>.]</ety> <def>A weight by which lead and some other
metals were formerly sold, in England, varying from 19<frac12/ to 24
cwt.; a fother.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fodder</ent><br/
<hw>Fod"der</hw> <pr>(f<ocr/d"d<etil/r)</pr>, <pos>n.</pos> <ety>[AS.
<ets>f<omac/dder</ets>, f<omac/ddor, fodder (also sheath case), fr.
<ets>f<omac/da</ets> food; akin to D. <ets>voeder</ets>, OHG.
<ets>fuotar</ets>, G. <ets>futter</ets>, Icel. <ets>f<omac/<edh/r</ets>,
Sw. & Dan. <ets>foder</ets>. <root/75. See <er>Food</er> and cf.
<er>Forage</er>, <er>Fur</er>.]</ety> <def>That which is fed out to
cattle horses, and sheep, as hay, cornstalks, vegetables, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fodder</ent><br/
<hw>Fod"der</hw> <pr>(f<ocr/d"d<etil/r)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Foddered</conjf>
<pr>(f<ocr/d"d<etil/rd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Foddering</conjf>.]</vmorph> <def>To feed, as cattle, with dry
food or cut grass, etc.; to furnish with hay, straw, oats,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fodderer</ent><br/
<hw>Fod"der*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who fodders
cattle.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fodient</ent><br/
<hw>Fo"di*ent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>fodiens</ets>, p. pr. of <ets>fodere</ets> to dig.]</ety>
<def>Fitted for, or pertaining to, digging.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fodient</ent><br/
<hw>Fo"di*ent</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>One of the Fodientia.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fodientia</ent><br/
<hw>Fo`di*en"ti*a</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL., fr. L.
<ets>fodiens</ets> p. pr., digging.]</ety> <fld>(Zool.)</fld> <def>A
group of African edentates including the aard-vark.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foe</ent><br/
<hw>Foe</hw> <pr>(f<omac/)</pr>, <pos>n.</pos> <ety>[OE. <ets>fo</ets>,
<ets>fa</ets>, AS. <ets>f<amac/h</ets> hostile; prob. akin to E.
<ets>fiend</ets>. <root/81. See <er>Fiend</er>, and cf. <er>Feud</er> a
quarrel.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>One who entertains personal enmity, hatred, grudge,
or malice, against another; an enemy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A man's <qex>foes</qex> shall be they of his own household.</q>
<rj><qau>Matt. x. 36</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An enemy in war; a hostile army.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>One who opposes on principle; an opponent; an
adversary; an ill-wisher; as, a foe to religion.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>foe</qex> to received doctrines.</q> <rj><qau>I.
Watts</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foe</ent><br/
<hw>Foe</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To treat as an
enemy.</def> <mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foehn</ent><br/
\'d8<hw>Foehn</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[G. dial. (Swiss),
fr. L. <ets>Favonius</ets> west wind. Cf. <er>Favonian</er>.]</ety>
<fld>(Meteor.)</fld> <sd>(a)</sd> <def>A warm dry wind that often blows
in the northern valleys of the Alps, due to the indraught of a storm
center passing over Central Europe. The wind, heated by compression in
its descent from the mountains, reaches the base, particularly in
winter, dry and warm.</def> <sd>(b)</sd> <def>Any similar wind, as the
chinook, in other parts of the world.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Foehood</ent><br/
<hw>Foe"hood</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Enmity.</def>
<rj><au>Bp. Bedell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foeman</ent><br/
<hw>Foe"man</hw> <pr>(f<omac/"m<ait/n)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Foemen</plw> <pr>(-m<eit/n)</pr>.</plu> <ety>[AS.
<ets>f<amac/hman</ets>.]</ety> <def>An enemy in war.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And the stern joy which warriors feel<br/
In <qex>foemen</qex> worthy of their steel.</q> <rj><qau>Sir W.
Scott</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>foetal</ent><br/
<hw>f<oe/"tal</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Same as
<er>fetal</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>foetation</ent><br/
<hw>F<oe/*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Fetation</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>foeticide</ent><br/
<hw>F<oe/"ti*cide</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Feticide</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>foetor</ent><br/
<hw>F<oe/"tor</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Fetor</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>foetus</ent><br/
<ent>foetus</ent><br/
<mhw><hw>foetus</hw>, <hw>F<oe/"tus</hw></mhw> <pr>(?)</pr>,
<pos>n.</pos> <def>Same as <er>Fetus</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fog</ent><br/
<hw>Fog</hw> <pr>(f<ocr/g)</pr>, <pos>n.</pos> <ety>[Cf. Scot.
<ets>fog</ets>, <ets>fouge</ets>, moss, <ets>foggage</ets> rank grass,
LL. <ets>fogagium</ets>, W. <ets>ffwg</ets> dry grass.]</ety>
<fld>(Agric.)</fld> <sd>(a)</sd> <def>A second growth of grass;
aftergrass.</def> <sd>(b)</sd> <def>Dead or decaying grass remaining on
land through the winter; -- called also
<altname>foggage</altname>.</def> <mark>[Prov.Eng.]</mark>
<au>Halliwell.</au> <note>Sometimes called, in New England, <altname>old
tore</altname>. In Scotland, <xex>fog</xex> is a general name for
moss.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fog</ent><br/
<hw>Fog</hw> <pr>(f<ocr/g)</pr>, <pos>v. t.</pos> <fld>(Agric.)</fld>
<def>To pasture cattle on the fog, or aftergrass, of; to eat off the fog
from.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fog</ent><br/
<hw>Fog</hw> <pr>(f<ocr/g)</pr>, <pos>v. i.</pos> <ety>[Etymol.
uncertain.]</ety> <def>To practice in a small or mean way; to
pettifog.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Where wouldst thou fog to get a fee?</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fog</ent><br/
<hw>Fog</hw> <pr>(f<ocr/g)</pr>, <pos>n.</pos> <ety>[Dan.
snee<ets>fog</ets> snow falling thick, drift of snow, driving snow, cf.
Icel. <ets>fok</ets> spray, snowdrift, <ets>fj<umac/k</ets> snowstorm,
<ets>fj<umac/ka</ets> to drift.]</ety> <sn>1.</sn> <def>Watery vapor
condensed in the lower part of the atmosphere and disturbing its
transparency. It differs from cloud only in being near the ground, and
from mist in not approaching so nearly to fine rain. See
<er>Cloud</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A state of mental confusion.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Photog.)</fld> <def>Cloudiness or partial opacity
of those parts of a developed film or a photograph which should be
clear.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><cs><mcol><col><b>Fog alarm</b></col>, <col><b>Fog bell</b></col>,
<col><b>Fog horn</b></col>, etc.</mcol>, <cd>a bell, horn, whistle or
other contrivance that sounds an alarm, often automatically, near places
of danger where visible signals would be hidden in thick weather.</cd>
-- <col><b>Fog bank</b></col>, <cd>a mass of fog resting upon the sea,
and resembling distant land.</cd> -- <col><b>Fog ring</b></col>, <cd>a
bank of fog arranged in a circular form, -- often seen on the coast of
Newfoundland.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fog</ent><br/
<hw>Fog</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Fogged</conjf> <pr>(#)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Fogging</conjf> <pr>(#)</pr>.]</vmorph> <sn>1.</sn> <def>To
envelop, as with fog; to befog; to overcast; to darken; to
obscure.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Photog.)</fld> <def>To render semiopaque or cloudy,
as a negative film, by exposure to stray light, too long an exposure to
the developer, etc.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Fog</ent><br/
<hw>Fog</hw> <pr>(?)</pr>, <pos>v. i.</pos> <fld>(Photog.)</fld> <def>To
show indistinctly or become indistinct, as the picture on a negative
sometimes does in the process of development.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fog belt</ent><br/
<hw>Fog belt</hw>. <def>A region of the ocean where fogs are of marked
frequency, as near the coast of Newfoundland.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Fogbow</ent><br/
<hw>Fog"bow`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A nebulous arch, or
bow, of white or yellowish light sometimes seen in fog, etc.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Foge</ent><br/
<hw>Foge</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The Cornish name for a
forge used for smelting tin.</def> <rj><au>Raymond</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fogey</ent><br/
<hw>Fo"gey</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Fogy</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foggage</ent><br/
<hw>Fog"gage</hw> <pr>(?; 48)</pr>, <pos>n.</pos> <fld>(Agric.)</fld>
<def>See 1st <er>Fog</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fogger</ent><br/
<hw>Fog"ger</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who fogs; a
pettifogger.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>A beggarly <qex>fogger</qex>.</q> <rj><qau>Terence in
English(1614)</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foggily</ent><br/
<hw>Fog"gi*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a foggy manner;
obscurely.</def> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fogginess</ent><br/
<hw>Fog"gi*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state of being
foggy.</def> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foggy</ent><br/
<hw>Fog"gy</hw> <pr>(?)</pr>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Foggier</adjf> <pr>(?)</pr>; <pos>superl.</pos>
<adjf>Foggiest</adjf>.]</amorph> <ety>[From 4th <er>Fog</er>.]</ety>
<sn>1.</sn> <def>Filled or abounding with fog, or watery exhalations;
misty; <as>as, a <ex>foggy</ex> atmosphere; a <ex>foggy</ex>
morning.</as></def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 578 --></p>

<p><sn>2.</sn> <def>Beclouded; dull; obscure; <as>as, <ex>foggy</ex>
ideas</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Your coarse, <qex>foggy</qex>, drowsy conceit.</q>
<rj><qau>Hayward.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>foghorn</ent><br/
<hw>fog"horn</hw> <pos>n.</pos> <def>A horn that emits a loud
low-pitched sound, used on ships navigating in a fog, to warn other
ships of their presence.</def><br/
<syn><b>Syn. --</b> fog signal.</syn><br/
[<source>PJC</source>]</p>

<p><ent>Fogie</ent><br/
<hw>Fo"gie</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Fogy</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fogless</ent><br/
<hw>Fog"less</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Without fog;
clear.</def> <rj><au>Kane.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>fog signal</ent><br/
<hw>fog signal</hw> <pos>n.</pos> <def>a loud low warning sound that can
be heard by fog-bound ships; a foghorn.</def><br/
<syn><b>Syn. --</b> foghorn.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fogy</ent><br/
<hw>Fo"gy</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Fogies</plw> <pr>(<?/)</pr>.</plu> <sn>1.</sn> <def>A dull old
fellow; a person behind the times, over-conservative, or slow; --
usually preceded by <xex>old</xex>; an <altname>old
fogy</altname>.</def> <altsp>[Written also <asp>fogie</asp> and
<asp>fogey</asp>.]</altsp> <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Notorious old bore; regular old <qex>fogy</qex>.</q>
<rj><qau>Thackeray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The word is said to be connected with the German
<xex>vogt</xex>, a guard or protector. By others it is regarded as a
diminutive of <xex>folk</xex> (cf. D. <xex>volkje</xex>). It is defined
by Jamieson, in his Scottish Dictionary, as <ldquo/an invalid or
garrison soldier,<rdquo/ and is applied to the old soldiers of the Royal
Hospital at Dublin, which is called the <xex>Fogies'</xex> Hospital. In
the fixed habits of such persons we see the origin of the present use of
the term.</note> <rj><au>Sir F. Head.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mil.)</fld> <def>In the United States service,
extra pay granted to officers for length of service.</def>
<mark>[Colloq.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Fogyism</ent><br/
<hw>Fo"gy*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The principles and
conduct of a fogy.</def> <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foh</ent><br/
<hw>Foh</hw> <pr>(?)</pr>, <pos>interj.</pos> <ety>[Cf.
<er>Faugh</er>.]</ety> <def>An exclamation of abhorrence or contempt;
poh; fie.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fohist</ent><br/
<hw>Fo"hist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A Buddhist priest. See
<er>Fo</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foible</ent><br/
<hw>Foi"ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OF.
<ets>foible</ets>. See <er>Feeble</er>.]</ety> <def>Weak; feeble.</def>
<mark>[Obs.]</mark> <rj><au>Lord Herbert.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foible</ent><br/
<hw>Foi"ble</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A moral
weakness; a failing; a weak point; a frailty.</def><br/
[<source>1913 Webster</source>]</p>

<p><q> A disposition radically noble and generous, clouded and
overshadowed by superficial <qex>foibles</qex>.</q> <rj><qau>De
Quincey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The half of a <partof>sword blade</partof> or
<partof>foil blade</partof> nearest the point; -- opposed to
<contr>forte</contr>.</def> <altsp>[Written also
<asp>faible</asp>.]</altsp></p>

<p><syn><b>Syn.</b> -- Fault; imperfection; failing; weakness;
infirmity; frailty; defect. See <er>Fault</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foil</ent><br/
<hw>Foil</hw> <pr>(foil)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Foiled</conjf> <pr>(foild)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Foiling</conjf>.]</vmorph> <ety>[F. <ets>fouler</ets> to
tread or trample under one's feet, to press, oppress. See <er>Full</er>,
<pos>v. t.</pos>]</ety> <sn>1.</sn> <def>To tread under foot; to
trample.</def><br/
[<source>1913 Webster</source>]</p>

<p><q> King Richard . . . caused the ensigns of Leopold to be pulled
down and <qex>foiled</qex> under foot.</q>
<rj><qau>Knoless.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q> Whom he did all to pieces breake and <qex>foyle</qex>,<br/
In filthy durt, and left so in the loathely soyle.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To render (an effort or attempt) vain or nugatory;
to baffle; to outwit; to balk; to frustrate; to defeat.</def><br/
[<source>1913 Webster</source>]</p>

<p><q> And by <?/ mortal man at length am <qex>foiled</qex>.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q> Her long locks that <qex>foil</qex> the painter's power.</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To blunt; to dull; to spoil; <as>as, to
<ex>foil</ex> the scent in chase</as>.</def>
<rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foil</ent><br/
<hw>Foil</hw>, <pos>v. t.</pos> <ety>[See 6th <er>File</er>.]</ety>
<def>To defile; to soil.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foil</ent><br/
<hw>Foil</hw>, <pos>n.</pos> <sn>1.</sn> <def>Failure of success when on
the point of attainment; defeat; frustration; miscarriage.</def>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q> Nor e'er was fate so near a <qex>foil</qex>.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A blunt weapon used in fencing, resembling a
smallsword in the main, but usually lighter and having a button at the
point.</def><br/
[<source>1913 Webster</source>]</p>

<p><q> Blunt as the fencer's <qex>foils</qex>, which hit, but hurt
not.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q> Isocrates contended with a <qex>foil</qex> against Demosthenes
with a word.</q> <rj><qau>Mitford.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The track or trail of an animal.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To run a foil</b></col>,<cd>to lead astray; to puzzle; --
alluding to the habits of some animals of running back over the same
track to mislead their pursuers.</cd> <rj><au>Brewer.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foil</ent><br/
<hw>Foil</hw>, <pos>n.</pos> <ety>[OE. <ets>foil</ets> leaf, OF.
<ets>foil</ets>, <ets>fuil</ets>, <ets>fueil</ets>, <ets>foille</ets>,
<ets>fueille</ets>, F. <ets>feuille</ets>, fr. L. <ets>folium</ets>, pl.
<ets>folia</ets>; akin to Gr. <?/ , and perh. to E. <ets>blade</ets>.
Cf. <er>Foliage</er>, <er>Folio</er>.]</ety> <sn>1.</sn> <def>A leaf or
very thin sheet of metal; <as>as, brass <ex>foil</ex>; tin
<ex>foil</ex>; gold <ex>foil</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Jewelry)</fld> <def>A thin leaf of sheet copper
silvered and burnished, and afterwards coated with transparent colors
mixed with isinglass; -- employed by jewelers to give color or
brilliancy to pastes and inferior stones.</def>
<rj><au>Ure.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Anything that serves by contrast of color or quality
to adorn or set off another thing to advantage.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>As she a black silk cap on him began<br/
To set, for <qex>foil</qex> of his milk-white to serve.</q> <rj><qau>Sir
P. Sidney.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Hector has a <qex>foil</qex> to set him off.</q>
<rj><qau>Broome.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A thin coat of tin, with quicksilver, laid on the
back of a looking-glass, to cause reflection.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Arch.)</fld> <def>The space between the cusps in
Gothic architecture; a rounded or leaflike ornament, in windows, niches,
etc. A group of foils is called trefoil, quatrefoil, quinquefoil, etc.,
according to the number of arcs of which it is composed.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Foil stone</b></col>, <cd>an imitation of a jewel or
precious stone.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foilable</ent><br/
<hw>Foil"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of being
foiled.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foiler</ent><br/
<hw>Foil"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who foils or
frustrates.</def> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foiling</ent><br/
<hw>Foil"ing</hw>, <pos>n.</pos> <fld>(Arch.)</fld> <def>A foil.</def>
<rj><au>Simmonds.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foiling</ent><br/
<hw>Foil"ing</hw>, <pos>n.</pos> <ety>[Cf. F. <ets>foul<eacute/es</ets>.
See 1st <er>Foil</er>.]</ety> <fld>(Hunting)</fld> <def>The track of
game (as deer) in the grass.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foin</ent><br/
<hw>Foin</hw> <pr>(foin)</pr>, <pos>n.</pos> <ety>[F. <ets>fouine</ets>
a marten.]</ety> <sn>1.</sn> <fld>(Zool.)</fld> <def>The beech marten
(<spn>Mustela foina</spn>). See <er>Marten</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A kind of fur, black at the top on a whitish ground,
taken from the ferret or weasel of the same
name.</def><mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q> He came to the stake in a fair black gown furred and faced with
<qex>foins</qex>.</q> <rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foin</ent><br/
<hw>Foin</hw>, <pos>v. i.</pos> <ety>[OE. <ets>foinen</ets>,
<ets>foignen</ets>; of uncertain origin; cf. dial. F. <ets>fouiner</ets>
to push for eels with a spear, fr. F. <ets>fouine</ets> an eelspear,
perh. fr. L. <ets>fodere</ets> to dig, thrust.]</ety> <def>To thrust
with a sword or spear; to lunge.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q> He stroke, he soused, he <qex>foynd</qex>, he hewed, he
lashed.</q> <rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>They lash, they <qex>foin</qex>, they pass, they strive to
bore<br/
Their corselets, and the thinnest parts explore.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foin</ent><br/
<hw>Foin</hw>, <pos>v. t.</pos> <def>To prick; to st?ng.</def>
<mark>[Obs.]</mark> <rj><au>Huloet.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foin</ent><br/
<hw>Foin</hw>, <pos>n.</pos> <def>A pass in fencing; a lunge.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foinery</ent><br/
<hw>Foin"er*y</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Thrusting with the
foil; fencing with the point, as distinguished from broadsword
play.</def> <mark>[Obs.]</mark> <rj><au>Marston.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foiningly</ent><br/
<hw>Foin"ing*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>With a push or
thrust.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foison</ent><br/
<hw>Foi"son</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>foison</ets>,
fr. L. <ets>fusio</ets> a pouring, effusion. See <er>Fusion</er>.]</ety>
<def>Rich harvest; plenty; abundance.</def> <mark>[Archaic]</mark>
<rj><au>Lowell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q> That from the seedness the bare fallow brings<br/
To teeming <qex>foison</qex>.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foist</ent><br/
<hw>Foist</hw> <pr>(foist)</pr>, <pos>n.</pos> <ety>[OF.
<ets>fuste</ets> stick, boat, fr. L. <ets>fustis</ets> cudgel. Cf. 1st
<er>Fust</er>.]</ety> <def>A light and fast-sailing ship.</def>
<mark>[Obs.]</mark> <rj><au>Beau. & Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foist</ent><br/
<hw>Foist</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Foisted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Foisting</conjf>.]</vmorph> <ety>[Cf. OD. <ets>vysten</ets> to
fizzle, D. <ets>veesten</ets>, E. <ets>fizz</ets>, <ets>fitchet</ets>,
bull<ets>fist</ets>.]</ety> <def>To insert surreptitiously, wrongfully,
or without warrant; to interpolate; to pass off (something spurious or
counterfeit) as genuine, true, or worthy; -- usually followed by
<xex>in</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q> Lest negligence or partiality might admit or <qex>foist</qex> in
abuses and corruption.</q> <rj><qau>R. Carew.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q> When a scripture has been corrupted . . . by a supposititious
<qex>foisting</qex> of some words in.</q> <rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foist</ent><br/
<hw>Foist</hw>, <pos>n.</pos> <sn>1.</sn> <def>A foister; a
sharper.</def> <mark>[Obs.]</mark> <rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A trick or fraud; a swindle.</def>
<mark>[Obs.]</mark> <rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foister</ent><br/
<hw>Foist"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who foists
something surreptitiously; a falsifier.</def> <rj><au>Mir. for
Mag.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foistied</ent><br/
<hw>Foist"ied</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See 2d
<er>Fust</er>.]</ety> <def>Fusty.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foistiness</ent><br/
<hw>Foist"i*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Fustiness;
mustiness.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foisty</ent><br/
<hw>Foist"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Fusty; musty.</def>
<mark>[Obs.]</mark> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fold</ent><br/
<hw>Fold</hw> <pr>(f<omac/ld)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Folded</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Folding</conjf>.]</vmorph> <ety>[OE. <ets>folden</ets>,
<ets>falden</ets>, AS. <ets>fealdan</ets>; akin to OHG.
<ets>faltan</ets>, <ets>faldan</ets>, G. <ets>falten</ets>, Icel.
<ets>falda</ets>, Dan. <ets>folde</ets>, Sw. <ets>f<aring/lla</ets>,
Goth. <ets>fal<thorn/an</ets>, cf. Gr. <grk>di-pla`sios</grk> twofold,
Skr. <ets>pu<tsdot/a</ets> a fold. Cf. <er>Fauteuil</er>.]</ety>
<sn>1.</sn> <def>To lap or lay in plaits or folds; to lay one part over
another part of; to double; <as>as, to <ex>fold</ex> cloth; to
<ex>fold</ex> a letter.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>As a vesture shalt thou <qex>fold</qex> them up.</q> <rj><qau>Heb.
i. 12.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To double or lay together, as the arms or the hands;
<as>as, he <ex>folds</ex> his arms in despair</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To inclose within folds or plaitings; to envelop; to
infold; to clasp; to embrace.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A face <qex>folded in sorrow</qex>.</q> <rj><qau>J.
Webster.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>We will descend and <qex>fold</qex> him in our arms.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To cover or wrap up; to conceal.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Nor <qex>fold</qex> my fault in cleanly coined excuses.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fold</ent><br/
<hw>Fold</hw>, <pos>v. i.</pos> <def>To become folded, plaited, or
doubled; to close over another of the same kind; to double together;
<as>as, the leaves of the door <ex>fold</ex></as>.</def> <rj><au>1 Kings
vi. 34.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fold</ent><br/
<hw>Fold</hw>, <pos>n.</pos> <ety>[From <er>Fold</er>, <pos>v.</pos> In
sense 2 AS. <ets>-feald</ets>, akin to <ets>fealdan</ets> to
fold.]</ety> <sn>1.</sn> <def>A doubling,esp. of any flexible substance;
a part laid over on another part; a plait; a plication.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Mummies . . . shrouded in a number of <qex>folds</qex> of
linen.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q> <qex>Folds</qex> are most common in the rocks of mountainous
regions.</q> <rj><qau>J. D. Dana.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Times or repetitions; -- used with numerals, chiefly
in composition, to denote multiplication or increase in a geometrical
ratio, the doubling, tripling, etc., of anything; <as>as,
four<ex>fold</ex>, four times, increased in a quadruple ratio,
multiplied by four</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which is folded together, or which infolds or
envelops; embrace.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Shall from your neck unloose his amorous <qex>fold</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fold net</b></col>, <cd>a kind of net used in catching
birds.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fold</ent><br/
<hw>Fold</hw>, <pos>n.</pos> <ety>[OE. <ets>fald</ets>, <ets>fold</ets>,
AS. <ets>fald</ets>, <ets>falod</ets>.]</ety> <sn>1.</sn> <def>An
inclosure for sheep; a sheep pen.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Leaps o'er the fence with ease into the <qex>fold</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A flock of sheep; figuratively, the Church or a
church; <as>as, Christ's <ex>fold</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q> There shall be one <qex>fold</qex> and one shepherd.</q>
<rj><qau>John x. 16.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q> The very whitest lamb in all my <qex>fold</qex>.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A boundary; a limit.</def> <mark>[Obs.]</mark>
<rj><au>Creech.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fold yard</b></col>, <cd>an inclosure for sheep or
cattle.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fold</ent><br/
<hw>Fold</hw>, <pos>v. t.</pos> <def>To confine in a fold, as
sheep.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fold</ent><br/
<hw>Fold</hw>, <pos>v. i.</pos> <def>To confine sheep in a fold.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The star that bids the shepherd <qex>fold</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>foldaway</ent><br/
<ent>foldable</ent><br/
<mhw><hw>foldable</hw> <hw>foldaway</hw></mhw> <pos>adj.</pos>
<def>Capable of being folded into a more compact form.</def><br/
<syn><b>Syn. --</b> folding(prenominal).</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Foldage</ent><br/
<hw>Fold"age</hw>, <pr>(<?/)</pr> <pos>n.</pos> <ety>[See <er>Fold</er>
inclosure, <er>Faldage</er>.]</ety> <fld>(O.Eng.Law.)</fld> <def>See
<er>Faldage</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>folded</ent><br/
<hw>folded</hw> <pos>adj.</pos> <def>made compact by bending or doubling
over.</def> [Narrower terms: <stype>accordion, plicate </stype>;
<stype>bifold </stype>; <stype>closed </stype>; <stype>doubled </stype>;
<stype>pleated </stype>; <stype>rolled, rolled-up(prenominal) </stype>;
<stype>sunburst, sunray </stype>.] <see>Also See: <er>collapsible</er>,
<er>collapsable</er>.</see> Antonym: <ant>unfolded</ant><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Folder</ent><br/
<hw>Fold"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, folds; esp., a flat, knifelike instrument used for folding
paper.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Folderol</ent><br/
<hw>Fol"de*rol`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Nonsense; foolish
talk.</def> <altsp>[Also spelled <asp>falderal</asp> and
<asp>falderol</asp>.]</altsp> <mark>[Colloq.]</mark><br/
<syn><b>Syn. --</b> humbug; balderdash; poppycock.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Folding</ent><br/
<hw>Fold"ing</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The act
of making a fold or folds; also, a fold; a doubling; a
plication.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The lower <qex>foldings</qex> of the vest.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Agric.)</fld> <def>The keepig of sheep in
inclosures on arable land, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Folding boat</b></col>, <cd>a portable boat made by
stretching canvas, etc., over jointed framework, used in campaigning,
and by tourists, etc.</cd> <rj><au>Ham. Nav. Encyc.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Folding chair</b></col>, <cd>a chair which may be shut up
compactly for carriage or stowage; a camp chair.</cd> -- <col><b>Folding
door</b></col>, <cd>one of two or more doors filling a single and hung
upon hinges.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foldless</ent><br/
<hw>Fold"less</hw>, <pos>a.</pos> <def>Having no fold.</def>
<rj><au>Milman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foliaceous</ent><br/
<hw>Fo`li*a"ceous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>foliaceus</ets>, fr. <ets>folium</ets> leaf.]</ety> <sn>1.</sn>
<fld>(Bot.)</fld> <def>Belonging to, or having the texture or nature of,
a leaf; having leaves intermixed with flowers; <as>as, a
<ex>foliaceous</ex> spike</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Min.)</fld> <def>Consisting of leaves or thin
lamin<ae/; having the form of a leaf or plate; <as>as,
<ex>foliaceous</ex> spar</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <def>Leaflike in form or mode of
growth; <as>as, a <ex>foliaceous</ex> coral</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foliage</ent><br/
<hw>Fo"li*age</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>foillage</ets>, <ets>fueillage</ets>, F. <ets>feuillage</ets>, fr.
OF. <ets>foille</ets>, <ets>fueille</ets>, <ets>fueil</ets>, F.
<ets>feulle</ets>, leaf, L. <ets>folium</ets>. See 3d <er>Foil</er>, and
cf. <er>Foliation</er>, <er>Filemot</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Leaves, collectively, as produced or arranged by
nature; leafage; <as>as, a tree or forest of beautiful
<ex>foliage</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A cluster of leaves, flowers, and branches;
especially, the representation of leaves, flowers, and branches, in
architecture, intended to ornament and enrich capitals, friezes,
pediments, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Foliage plant</b></col> <fld>(Bot.)</fld>, <cd>any plant
cultivated for the beauty of its leaves, as many kinds of
<gen>Begonia</gen> and <gen>Coleus</gen>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foliage</ent><br/
<hw>Fo"li*age</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To adorn with
foliage or the imitation of foliage; to form into the representation of
leaves.</def> <mark>[R.]</mark> <rj><au>Drummond.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foliaged</ent><br/
<hw>Fo"li*aged</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Furnished with
foliage; leaved; <as>as, the variously <ex>foliaged</ex>
mulberry</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foliar</ent><br/
<hw>Fo"li*ar</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Bot.)</fld>
<def>Consisting of, or pertaining to, leaves; <as>as, <ex>foliar</ex>
appendages</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Foliar gap</b></col> <fld>(Bot.)</fld>, <cd>an opening in
the fibrovascular system of a stem at the point of origin of a
leaf.</cd> -- <col><b>Foliar trace</b></col> <fld>(Bot.)</fld>, <cd>a
particular fibrovascular bundle passing down into the stem from a
leaf.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foliate</ent><br/
<hw>Fo"li*ate</hw> <pr>(<?/)</pr>, <pos>a.</pos> <ety>[L.
<ets>foliatus</ets> leaved, leafy, fr. <ets>folium</ets> leaf. See
<er>Foliage</er>.]</ety> <fld>(Bot.)</fld> <def>Furnished with leaves;
leafy; as, a <xex>foliate</xex> stalk.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Foliate curve</b></col>. <fld>(Geom.)</fld> <cd>Same as
<er>Folium</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foliate</ent><br/
<hw>Fo"li*ate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Foliated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Foliating</conjf> <pr>(?)</pr>.]</vmorph> <sn>1.</sn>
<def>To beat into a leaf, or thin plate.</def>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To spread over with a thin coat of tin and
quicksilver; <as>as, to <ex>foliate</ex> a looking-glass</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foliated</ent><br/
<hw>Fo"li*a`ted</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Having
leaves, or leaflike projections; <as>as, a <ex>foliated</ex>
shell</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Arch.)</fld> <def>Containing, or consisting of,
foils; <as>as, a <ex>foliated</ex> arch</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Min.)</fld> <def>Characterized by being separable
into thin plates or folia; <as>as, graphite has a <ex>foliated</ex>
structure</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Geol.)</fld> <def>Laminated, but restricted to the
variety of laminated structure found in crystalline schist, as mica
schist, etc.; schistose.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Spread over with an amalgam of tin and
quicksilver.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Foliated telluium</b></col>. <fld>(Min.)</fld> <cd>See
<er>Nagyagite</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foliation</ent><br/
<hw>Fo"li*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>foliation</ets>.]</ety> <sn>1.</sn> <def>The process of forming
into a leaf or leaves.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The manner in which the young leaves are disposed
within the bud.</def><br/
[<source>1913 Webster</source>]</p>

<p><q> The . . . <qex>foliation</qex> must be in relation to the
stem.</q> <rj><qau>De Quincey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The act of beating a metal into a thin plate, leaf,
foil, or lamina.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The act of coating with an amalgam of tin foil and
quicksilver, as in making looking-glasses.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Arch.)</fld> <def>The enrichment of an opening by
means of foils, arranged in trefoils, quatrefoils, etc.; also, one of
the ornaments. See <er>Tracery</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Geol.)</fld> <def>The property, possessed by some
crystalline rocks, of dividing into plates or slabs, which is due to the
cleavage structure of one of the constituents, as mica or hornblende. It
may sometimes include slaty structure or cleavage, though the latter is
usually independent of any mineral constituent, and transverse to the
bedding, it having been produced by pressure.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foliature</ent><br/
<hw>Fo"li*a*ture</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>foliatura</ets> foliage.]</ety> <sn>1.</sn> <def>Foliage;
leafage.</def> <mark>[Obs.]</mark> <rj><au>Shuckford.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The state of being beaten into foil.</def>
<rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Folier</ent><br/
<hw>Fo"li*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Goldsmith's
foil.</def> <mark>[R.]</mark> <rj><au>Sprat.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foliferous</ent><br/
<hw>Fo*lif"er*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>folium</ets> leaf+ <ets>-ferous</ets>: cf. F.
<ets>foliif<egrave/re</ets>.]</ety> <def>Producing leaves.</def>
<altsp>[Written also <asp>foliiferous</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Folily</ent><br/
<hw>Fol"i*ly</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Foolishly.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Folio</ent><br/
<hw>Fol"io</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Folios</plw> <pr>(#)</pr>.</plu> <ety>[Ablative of L.
<ets>folium</ets> leaf. See 4th <er>Foil</er>.]</ety> <sn>1.</sn> <def>A
leaf of a book or manuscript.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A sheet of paper once folded.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A book made of sheets of paper each folded once
(four pages to the sheet); hence, a book of the largest kind. See Note
under <er>Paper</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Print.)</fld> <def>The page number. The even folios
are on the left-hand pages and the odd folios on the
right-hand.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A page of a book; <fld>(Bookkeeping)</fld> a page in
an account book; sometimes, two opposite pages bearing the same serial
number.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Law)</fld> <def>A leaf containing a certain number
of words, hence, a certain number of words in a writing, as in England,
in law proceedings 72, and in chancery, 90; in New York, 100
words.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Folio post</b></col>, <cd>a flat writing paper, usually
17 by 24 inches.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Folio</ent><br/
<hw>Fol"io</hw>, <pos>v. t.</pos> <def>To put a serial number on each
folio or page of (a book); to page.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Folio</ent><br/
<hw>Fol"io</hw>, <pos>a.</pos> <def>Formed of sheets each folded once,
making two leaves, or four pages; <as>as, a <ex>folio</ex> volume</as>.
See <er>Folio</er>, <pos>n.</pos>, 3.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foliolate</ent><br/
<hw>Fo"li*o*late</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining
to leaflets; -- used in composition; <as>as,
bi-<ex>foliolate</ex></as>.</def> <rj><au>Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foliole</ent><br/
<hw>Fo"li*ole</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Dim. of L.
<ets>folium</ets> leaf: cf. F. <ets>foliole</ets>.]</ety>
<fld>(Bot.)</fld> <def>One of the distinct parts of a compound leaf; a
leaflet.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foliomort</ent><br/
<hw>Fo`li*o*mort"</hw> <pr>(?)</pr>, <pos>a.</pos> <def>See
<er>Feuillemort</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foliose</ent><br/
<hw>Fo`li*ose"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>foliosus</ets>, fr. <ets>folium</ets> leaf.]</ety>
<fld>(Bot.)</fld> <def>Having many leaves; leafy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foliosity</ent><br/
<hw>Fo`li*os"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The
ponderousness or bulk of a folio; voluminousness.</def>
<mark>[R.]</mark> <rj><au>De Quincey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Folious</ent><br/
<hw>Fo"li*ous</hw> <pr>(<?/)</pr>, <pos>a.</pos> <ety>[See
<er>Foliose</er>.]</ety> <sn>1.</sn> <def>Like a leaf; thin;
unsubstantial.</def> <mark>[R.]</mark> <rj><au>Sir T.
Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>Foliose.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Folium</ent><br/
<hw>Fo"li*um</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it> E.
<plw>Foliums</plw> <pr>(#)</pr>, L. <plw>Folia</plw> <pr>(#)</pr>.</plu>
<ety>[L., a leaf.]</ety> <sn>1.</sn> <def>A leaf, esp. a thin leaf or
plate.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Geom.)</fld> <def>A curve of the third order,
consisting of two infinite branches, which have a common asymptote. The
curve has a double point, and a leaf-shaped loop; whence the name. Its
equation is <mathex>x<exp>3</exp> + y<exp>3</exp> =
axy</mathex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 579 --></p>

<p><ent>Folks</ent><br/
<ent>Folk</ent><br/
<mhw>{ <hw>Folk</hw> <pr>(f<omac/k)</pr>, <hw>Folks</hw>
<pr>(f<omac/ks)</pr> }</mhw>, <pos>n. collect. & pl.</pos> <ety>[AS.
<ets>folc</ets>; akin to D. <ets>volk</ets>, OS. & OHG. <ets>folk</ets>,
G. <ets>volk</ets>, Icel. <ets>f<omac/lk</ets>, Sw. & Dan.
<ets>folk</ets>, Lith. <ets>pulkas</ets> crowd, and perh. to E.
<ets>follow</ets>.]</ety> <sn>1.</sn> <fld>(Eng. Hist.)</fld> <def>In
Anglo-Saxon times, the people of a group of townships or villages; a
community; a tribe.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The organization of each <qex>folk</qex>, as such, sprang mainly
from war.</q> <rj><qau>J. R. Green.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>People in general, or a separate class of people; --
generally used in the plural form, and often with a qualifying
adjective; <as>as, the old <ex>folks</ex>; poor
<ex>folks</ex>.</as></def> <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>In winter's tedious nights, sit by the fire<br/
With good old <qex>folks</qex>, and let them tell thee tales.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The persons of one's own family; <as>as, our
<ex>folks</ex> are all well</as>.</def> <mark>[Colloq. New Eng.]</mark>
<rj><au>Bartlett.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Folk song</b></col>, <cd>one of a class of songs long
popular with the common people.</cd> -- <col><b>Folk speech</b></col>,
<cd>the speech of the common people, as distinguished from that of the
educated class.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Folkething</ent><br/
\'d8<hw>Fol"ke*thing`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Dan. See
<er>Folk</er>, and <er>Thing</er>.]</ety> <def>The lower house of the
Danish Rigsdag, or Parliament. See <er>Legislature</er>,
below.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Folkland</ent><br/
<hw>Folk"land`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS.
<ets>folcland</ets>.]</ety> <fld>(O.Eng. Law)</fld> <def>Land held in
villenage, being distributed among the <xex>folk</xex>, or people, at
the pleasure of the lord of the manor, and resumed at his discretion.
Not being held by any assurance in writing, it was opposed to
<xex>book</xex>land or <xex>charter</xex> land, which was held by
deed.</def> <rj><au>Mozley & W.</au></rj></p>

<p><ent>Folk lore</ent><br/
<ent>Folklore</ent><br/
<mhw>{ <hw>Folk"lore`</hw> <pr>(?)</pr>, <pos>n.</pos>, <it>or</it>
<hw>Folk" lore`</hw> }</mhw>. <def>Tales, legends, or superstitions long
current among the people; the unwritten literature of a culture, such as
stories, proverbs, riddles and songs.</def>
<rj><au>Trench.</au></rj><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><ent>Folkmote</ent><br/
<hw>Folk"mote`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS.
<ets>folcm<omac/t</ets> folk meeting.]</ety> <def>An assembly of the
people</def>; esp. <fld>(Sax. Law)</fld>, <def>a general assembly of the
people to consider and order matters of the commonwealth; also, a local
court.</def> <mark>[Hist.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>To which <qex>folkmote</qex> they all with one consent<br/
Agreed to travel.</q> <rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Folkmoter</ent><br/
<hw>Folk"mot`er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who takes part
in a folkmote, or local court.</def> <mark>[Obs.]</mark>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>folksy</ent><br/
<hw>folksy</hw> <pos>adj.</pos> <sn>1.</sn> <def>same as
<er>cracker-barrel</er>.</def><br/
<syn><b>Syn. --</b> cracker-barrel, homespun.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>very informal and familiar; <as>as, a
<ex>folksy</ex> radio commentator; a <ex>folksy</ex>
style</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>folk tale</ent><br/
<ent>folktale</ent><br/
<mhw><hw>folktale</hw>, <hw>folk tale</hw></mhw> <pos>n.</pos> <def>a
tale circulated by word of mouth among the common folk, especially one
forming part of the tradition of a culture.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Follicle</ent><br/
<hw>Fol"li*cle</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>folliculus</ets> a small bag, husk, pod, dim of <ets>follis</ets>
bellows, an inflated ball, a leathern money bag, perh. akin to E.
<ets>bellows</ets>: cf. F. <ets>follicule</ets>. Cf. 2d
<er>Fool</er>.]</ety> <sn>1.</sn> <fld>(Bot.)</fld> <def>A simple
podlike pericarp which contains several seeds and opens along the inner
or ventral suture, as in the peony, larkspur and milkweed.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Anat.)</fld> <sd>(a)</sd> <def>A small cavity,
tubular depression, or sac; <as>as, a hair <ex>follicle</ex></as>.</def>
<sd>(b)</sd> <def>A simple gland or glandular cavity; a crypt.</def>
<sd>(c)</sd> <def>A small mass of adenoid tissue; <as>as, a lymphatic
<ex>follicle</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Follicular</ent><br/
<hw>Fol*lic"u*lar</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Like, pertaining to, or consisting of, a follicles or
follicles.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Med.)</fld> <def>Affecting the follicles; <as>as,
<ex>follicular</ex> pharyngitis</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Folliculated</ent><br/
<hw>Fol*lic"u*la`ted</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having
follicles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Folliculous</ent><br/
<hw>Fol*lic"u*lous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>folliculosus</ets> full of husks: cf. F.
<ets>folliculeux</ets>.]</ety> <def>Having or producing
follicles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Folliful</ent><br/
<hw>Fol"li*ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Full of
folly.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Follow</ent><br/
<hw>Fol"low</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Followed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Following</conjf>.]</vmorph><ety>[OE.
<ets>foluwen</ets>, <ets>folwen</ets>, <ets>folgen</ets>, AS.
<ets>folgian</ets>, <ets>fylgean</ets>, <ets>fylgan</ets>; akin to D.
<ets>volgen</ets>, OHG. <ets>folg<emac/n</ets>, G. <ets>folgen</ets>,
Icel. <ets>fylgja</ets>, Sw. <ets>f<oum/lja</ets>, Dan.
<ets>f<oum/lge</ets>, and perh. to E. <ets>folk</ets>.]</ety>
<sn>1.</sn> <def>To go or come after; to move behind in the same path or
direction; hence, to go with (a leader, guide, etc.); to accompany; to
attend.</def><br/
[<source>1913 Webster</source>]</p>

<p><q> It waves me forth again; I'll <qex>follow</qex> it.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To endeavor to overtake; to go in pursuit of; to
chase; to pursue; to prosecute.</def><br/
[<source>1913 Webster</source>]</p>

<p><q> I will harden the hearts of the Egyptians, and they shall
<qex>follow</qex> them.</q> <rj><qau>Ex. xiv. 17.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To accept as authority; to adopt the opinions of; to
obey; to yield to; to take as a rule of action; <as>as, to
<ex>follow</ex> good advice</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Approve the best, and <qex>follow</qex> what I approve</q>.
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Follow</qex> peace with all men.</q> <rj><qau>Heb. xii.
14.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q> It is most agreeable to some men to <qex>follow</qex> their
reason; and to others to <qex>follow</qex> their appetites.</q>
<rj><qau>J. Edwards.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To copy after; to take as an example.</def><br/
[<source>1913 Webster</source>]</p>

<p><q> We had rather <qex>follow</qex> the perfections of them whom we
like not, than in defects resemble them whom we love.</q>
<rj><qau>Hooker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To succeed in order of time, rank, or
office.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To result from, as an effect from a cause, or an
inference from a premise.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>To watch, as a receding object; to keep the eyes
fixed upon while in motion; to keep the mind upon while in progress, as
a speech, musical performance, etc.; also, to keep up with; to
understand the meaning, connection, or force of, as of a course of
thought or argument.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He <qex>followed</qex> with his eyes the flitting shade.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>To walk in, as a road or course; to attend upon
closely, as a profession or calling.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>O, had I but <qex>followed</qex> the arts!</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>O Antony! I have <qex>followed</qex> thee to this.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Follow board</b></col> <fld>(Founding)</fld>, <cd>a board
on which the pattern and the flask lie while the sand is rammed into the
flask.</cd> <au>Knight.</au> -- <col><b>To follow the hounds</b></col>,
<cd>to hunt with dogs.</cd> -- <col><b>To follow suit</b></col>
<fld>(Card Playing)</fld>, <cd>to play a card of the same suit as the
leading card; hence, colloquially, to follow an example set.</cd> --
<col><b>To follow up</b></col>, <cd>to pursue
indefatigably.</cd></cs></p>

<p><syn><b>Syn.</b>- To pursue; chase; go after; attend; accompany;
succeed; imitate; copy; embrace; maintain.</syn> <usage>- To
<er>Follow</er>, <er>Pursue</er>. To <xex>follow</xex> (v.t.) denotes
simply to go after; to <xex>pursue</xex> denotes to follow with
earnestness, and with a view to attain some definite object; <as>as, a
hound <ex>pursues</ex> the deer</as>. So a person <xex>follows</xex> a
companion whom he wishes to overtake on a journey; the officers of
justice <xex>pursue</xex> a felon who has escaped from
prison.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Follow</ent><br/
<hw>Fol"low</hw>, <pos>v. i.</pos> <def>To go or come after; -- used in
the various senses of the transitive verb: To pursue; to attend; to
accompany; to be a result; to imitate.</def></p>

<p><syn><b>Syn.</b> -- To <er>Follow</er>, <er>Succeed</er>,
<er>Ensue</er>.</syn> <usage> To <xex>follow</xex> (v.i.) means simply
to come after; <as>as, a crowd <ex>followed</ex></as>. <xex>To
succeed</xex> means to come after in some regular series or succession;
<as>as, day <ex>succeeds</ex> to day, and night to night</as>. To
<xex>ensue</xex> means to follow by some established connection or
principle of sequence. As wave <xex>follows</xex> wave, revolution
<xex>succeeds</xex> to revolution; and nothing <xex>ensues</xex> but
accumulated wretchedness.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Follow</ent><br/
<hw>Fol"low</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The art or process of
following; specif., in some games, as billiards, a stroke causing a ball
to follow another ball after hitting it. Also used adjectively; <as>as,
<ex>follow</ex> shot</as>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Follower</ent><br/
<hw>Fol"low*er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>folwere</ets>, AS. <ets>folgere</ets>.]</ety> <sn>1.</sn> <def>One
who follows; a pursuer; an attendant; a disciple; a dependent associate;
a retainer.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A sweetheart; a beau.</def> <mark>[Colloq.]</mark>
<rj><au>A. Trollope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Steam Engine)</fld> <sd>(a)</sd> <def>The removable
flange, or cover, of a piston. See <xex>Illust.</xex> of
<er>Piston</er>.</def> <sd>(b)</sd> <def>A gland. See <xex>Illust.</xex>
of <er>Stuffing box</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Mach.)</fld> <def>The part of a machine that
receives motion from another part. See <er>Driver</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Among law stationers, a sheet of parchment or paper
which is added to the first sheet of an indenture or other
deed.</def></p>

<p><syn><b>Syn.</b> -- Imitator; copier; disciple; adherent; partisan;
dependent; attendant.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Following</ent><br/
<hw>Fol"low*ing</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One's
followers, adherents, or dependents, collectively.</def>
<rj><au>Macaulay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Vocation; business; profession.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Following</ent><br/
<hw>Fol"low*ing</hw>, <pos>a.</pos> <sn>1.</sn> <def>Next after;
succeeding; ensuing; <as>as, the assembly was held on the
<ex>following</ex> day</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Astron.)</fld> <def>(In the field of a telescope)
In the direction from which stars are apparently moving (in consequence
of the earth's rotation); <as>as, a small star, north <ex>following</ex>
or south <ex>following</ex></as>. In the direction toward which stars
appear to move is called <xex>preceding</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The four principal directions in the field of a
telescope are <xex>north</xex>, <xex>south</xex>, <xex>following</xex>,
<xex>preceding</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Following edge</ent><br/
<hw>Following edge</hw>. <fld>(A<eum/ronautics)</fld> <def>See
<er>Advancing-edge</er>, above.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Following surface</ent><br/
<hw>Following surface</hw>. <fld>(A<eum/ronautics)</fld> <def>See
<er>Advancing-surface</er>, above.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>follow-on</ent><br/
<hw>follow-on</hw> <pos>n.</pos> <def>an immediate second innings forced
on a cricket team scoring a prescribed number of runs fewer than its
opponents in the first innings.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>follow-on</ent><br/
<hw>follow-on</hw> <pos>a.</pos> <def>Following as a logical consequence
or next step in a process; -- used mostly of voluntary
actions.</def><br/
[<source>PJC</source>]</p>

<p><ent>follow-through</ent><br/
<hw>follow-through</hw> <pos>n.</pos> <sn>1.</sn> <def>Carrying a
process, plan, or project to full completion; <as>as, I appreciated his
<ex>follow-through</ex> on his promise</as>. The term usually is used in
reference to the period after some point in time at which the actor is
given freedom to pursue the project.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <fld>(Golf, Baseball, Tennis)</fld> <def>The remainder of
a stroke with a club, bat, or racket after the ball has been
hit.</def><br/
[<source>PJC</source>]</p>

<p><ent>follow-up</ent><br/
<hw>follow-up</hw> <pos>n.</pos> <sn>1.</sn> <def>a second (or
subsequent) action to increase the effectiveness of an initial action.
Also used attributively; <as>as a <ex>follow-up</ex> visit</as>.</def>
<note>A <ex>follow-up</ex> may be of various types. After a medical
examination, a second examination (or <stype>reexamination</stype>) to
obtain additional information regarding some fact discovered in the
first examination is considered a <ex>follow-up</ex>. A second visit or
phone call in pursuit of a sale or other request would also be a
<ex>follow-up</ex>.</note><br/
<syn><b>Syn. --</b> reexamination, review.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <fld>(Journalism)</fld> <def>A subsequent story providing
information discovered or events happening after a first story was
published.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <fld>(Journalism)</fld> <def>Same as
<er>sidebar</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Folly</ent><br/
<hw>Fol"ly</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Follies</plw> <pr>(#)</pr>.</plu> <ety>[OE. <ets>folie</ets>,
<ets>foli</ets>, F. <ets>folie</ets>, fr. <ets>fol</ets>,
<ets>fou</ets>, foolish, mad. See <er>Fool</er>.]</ety> <sn>1.</sn>
<def>The state of being foolish; want of good sense; levity, weakness,
or derangement of mind.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A foolish act; an inconsiderate or thoughtless
procedure; weak or light-minded conduct; foolery.</def><br/
[<source>1913 Webster</source>]</p>

<p><q> What <qex>folly</qex> 'tis to hazard life for ill.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Scandalous crime; sin; specifically, as applied to a
woman, wantonness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>[Achan] wrought <qex>folly</qex> in Israel.</q> <rj><qau>Josh.
vii. 15.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>When lovely woman stoops to <qex>folly</qex>.</q>
<rj><qau>Goldsmith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The result of a foolish action or
enterprise.</def><br/
[<source>1913 Webster</source>]</p>

<p><q> It is called this man's or that man's
<ldquo/<qex>folly</qex>,<rdquo/ and name of the foolish builder is thus
kept alive for long after years.</q> <rj><qau>Trench.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Folwe</ent><br/
<hw>Fol"we</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To follow.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fomalhaut</ent><br/
<hw>Fo"mal*haut`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Ar., prop.,
mouth of the large fish: cf. F. <ets>Fomalhaut</ets>.]</ety>
<fld>(Astron.)</fld> <def>A star of the first magnitude, in the
constellation <partof>Piscis Australis</partof>, or Southern
Fish.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foment</ent><br/
<hw>Fo*ment"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Fomented</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Fomenting</conjf>.]</vmorph> <ety>[F. <ets>fomenter</ets>, fr. L.
<ets>fomentare</ets>, fr. <ets>fomentum</ets> (for
<ets>fovimentum</ets>) a warm application or lotion, fr.
<ets>fovere</ets> to warm or keep warm; perh. akin to Gr. <?/ to roast,
and E. <ets>bake</ets>.]</ety> <sn>1.</sn> <def>To apply a warm lotion
to; to bathe with a cloth or sponge wet with warm water or medicated
liquid.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To cherish with heat; to foster.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Which these soft fires . . . <qex>foment</qex> and warm.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To nurse to life or activity; to cherish and promote
by excitements; to encourage; to abet; to instigate; -- used often in a
bad sense; <as>as, to <ex>foment</ex> ill humors</as>.</def>
<rj><au>Locke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q> But quench the choler you <qex>foment</qex> in vain.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q> Exciting and <qex>fomenting</qex> a religious rebellion.</q>
<rj><qau>Southey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foment</ent><br/
<hw>Fo"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>Fomentation.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>State of excitation; -- perh. confused with
<xex>ferment</xex>.</def></p>

<p><q>He came in no conciliatory mood, and the <qex>foment</qex> was
kept up.</q> <rj><qau>Julian Ralph.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Fomentation</ent><br/
<hw>Fo`men*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<?/.
<ets>fomentatio</ets>: cf. F. <ets>fomentation</ets>.]</ety> <sn>1.</sn>
<fld>(Med.)</fld> <sd>(a)</sd> <def>The act of fomenting; the
application of warm, soft, medicinal substances, as for the purpose of
easing pain, by relaxing the skin, or of discussing tumors.</def>
<sd>(b)</sd> <def>The lotion applied to a diseased part.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Excitation; instigation; encouragement.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Dishonest <qex>fomentation</qex> of your pride.</q>
<rj><qau>Young.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fomenter</ent><br/
<hw>Fo*ment"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who foments;
one who encourages or instigates; <as>as, a <ex>fomenter</ex> of
sedition</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fomes</ent><br/
\'d8<hw>Fo"mes</hw> <pr>(f<omac/"m<emac/z)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Fomites</plw>
<pr>(f<ocr/m"<icr/*t<emac/z)</pr>.</plu> <ety>[L. <ets>fomes</ets>,
<ets>-itis</ets>, touch-wood, tinder.]</ety> <fld>(Med.)</fld> <def>Any
substance supposed to be capable of absorbing, retaining, and
transporting contagious or infectious germs; <as>as, woolen clothes are
said to be active <ex>fomites</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fomor</ent><br/
<hw>Fomor</hw> <pos>n.</pos> <sn>1.</sn> <def>(Irish) one of a group of
sea demons sometimes associated with the hostile power of
nature.</def><br/
<syn><b>Syn. --</b> Fomorian.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fomorian</ent><br/
<hw>Fomorian</hw> <pos>n.</pos> <sn>1.</sn> <def>(Irish) one of a group
of sea demons sometimes associated with the hostile power of
nature.</def><br/
<syn><b>Syn. --</b> Fomor.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fon</ent><br/
<hw>Fon</hw> <pr>(f<ocr/n)</pr>, <pos>n.</pos> <ety>[Of Scand. origin;
cf. Icel. <ets>f<amac/ni</ets> silly, <ets>f<amac/na</ets> to act silly,
Sw. <ets>f<aring/ne</ets> fool. Cf. <er>Fond</er>, <pos>a.</pos>]</ety>
<def>A fool; an idiot.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fond</ent><br/
<hw>Fond</hw> <pr>(?)</pr>, <mark>obs.</mark> <def><pos>imp.</pos> of
<er>Find</er>. Found.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fond</ent><br/
<hw>Fond</hw>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Fonder</adjf> <pr>(?)</pr>; <pos>superl.</pos>
<adjf>Fondest</adjf>.]</amorph> <ety>[For <ets>fonned</ets>, p. p. of
OE. <ets>fonnen</ets> to be foolish. See <er>Fon</er>.]</ety>
<sn>1.</sn> <def>Foolish; silly; simple; weak.</def>
<mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Grant I may never prove so <qex>fond</qex><br/
To trust man on his oath or bond.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Foolishly tender and loving; weakly indulgent;
over-affectionate.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Affectionate; loving; tender; -- in a good sense;
<as>as, a <ex>fond</ex> mother or wife</as>.</def>
<rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Loving; much pleased; affectionately regardful,
indulgent, or desirous; longing or yearning; -- followed by
<xex>of</xex> (formerly also by <xex>on</xex>).</def><br/
[<source>1913 Webster</source>]</p>

<p><q> More <qex>fond</qex> on her than she upon her love.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q> You are as <qex>fond</qex> of grief as of your child.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q> A great traveler, and <qex>fond</qex> of telling his
adventures.</q> <rj><qau>Irving.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Doted on; regarded with affection.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q> Nor fix on <qex>fond</qex> abodes to circumscribe thy prayer.</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Trifling; valued by folly; trivial.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fond</ent><br/
<hw>Fond</hw>, <pos>v. t.</pos> <def>To caress; to fondle.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q> The Tyrian hugs and <qex>fonds</qex> thee on her breast.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fond</ent><br/
<hw>Fond</hw>, <pos>v. i.</pos> <def>To be fond; to dote.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fond</ent><br/
<hw>Fond</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr. L.
<ets>fundus</ets>. See <er>Fund</er>.]</ety> <mark>[Obs., or used as a
French word]</mark> <sn>1.</sn> <def>Foundation; bottom;
groundwork;</def> <specif>specif.:</specif> <sd>(a)</sd> <fld>(Lace
Making)</fld> <def>The ground.</def> <sd>(b)</sd> <fld>(Cookery)</fld>
<def>The broth or juice from braised flesh or fish, usually served as a
sauce.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>Fund, stock, or store.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Fondant</ent><br/
\'d8<hw>Fon"dant</hw> <pr>(f<ocr/n"d<ait/nt; Fr.
f<ocir/N`d<aum/N")</pr>, <pos>n.</pos> <ety>[F., lit., melting, p. pr.
of <ets>fondre</ets> to melt, L. <ets>fundere</ets>. See <er>Found</er>
to cast.]</ety> <def>A kind of soft candy, made of a thick creamy sugar
paste by boiling solutions to the point of crystallization, and usually
molded; <as>as, cherry <ex>fondant</ex></as>.</def><br/
[<source>Webster 1913 Suppl.</source> + <source>WordNet 1.5</source>]</p>

<p><ent>Fonde</ent><br/
<hw>Fond"e</hw> <pr>(f<ocr/nd"<eit/)</pr>, <pos>v. t. & i.</pos>
<ety>[AS. <ets>fandian</ets> to try.]</ety> <def>To endeavor; to strive;
to try.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fondle</ent><br/
<hw>Fon"dle</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Fondled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Fondling</conjf> <pr>(?)</pr>.]</vmorph> <ety>[From
<er>Fond</er>, <pos>v.</pos>]</ety> <def>To treat or handle with
tenderness or in a loving manner; to caress; <as>as, a nurse
<ex>fondles</ex> a child</as>.</def></p>

<p><syn><b>Syn.</b>- See <er>Caress</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fondler</ent><br/
<hw>Fon"dler</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
fondles.</def> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fondling</ent><br/
<hw>Fon"dling</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<er>Fondle</er>.]</ety> <def>The act of caressing; manifestation of
tenderness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Cyrus made no . . . amorous <qex>fondling</qex><br/
To fan her pride, or melt her guardless heart.</q>
<rj><qau>Mickle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fondling</ent><br/
<hw>Fond"ling</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Fond</ets> +
<ets>-ling</ets>.]</ety> <sn>1.</sn> <def>A person or thing fondled or
caressed; one treated with foolish or doting affection.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Fondlings</qex> are in danger to be made fools.</q>
<rj><qau>L'Estrange.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A fool; a simpleton; a ninny.</def>
<mark>[Obs.]</mark> <rj><au>Chapman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fondly</ent><br/
<hw>Fond"ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <sn>1.</sn>
<def>Foolishly.</def> <mark>[Archaic]</mark> <rj><au>Verstegan
(1673).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q> Make him speak <qex>fondly</qex> like a frantic man.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>In a fond manner; affectionately;
tenderly.</def><br/
[<source>1913 Webster</source>]</p>

<p><q> My heart, untraveled, <qex>fondly</qex> turns to thee.</q>
<rj><qau>Goldsmith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fondness</ent><br/
<hw>Fond"ness</hw>, <pos>n.</pos> <sn>1.</sn> <def>The quality or state
of being fond; foolishness.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q> <qex>Fondness</qex> it were for any, being free,<br/
To covet fetters, though they golden be.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Doting affection; tender liking; strong appetite,
propensity, or relish; <as>as, he had a <ex>fondness</ex> for
truffles</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q> My heart had still some foolish <qex>fondness</qex> for thee.</q>
<rj><qau>Addison.</qau></rj></p>

<p><syn><b>Syn.</b> -- Attachment; affection; love; kindness.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fondon</ent><br/
<hw>Fon"don</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>fondant</ets> flux.]</ety> <fld>(Metal.)</fld> <def>A large copper
vessel used for hot amalgamation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fondu</ent><br/
\'d8<hw>Fon`du"</hw> <pr>(f<ocr/n"d<usdot/")</pr>, <pos>a.</pos>
<ety>[F. <ets>fondu</ets>, p.p. of <ets>fondre</ets> to melt, blend. See
<er>Found</er> to cast.]</ety> <sn>1.</sn> <def>Blended; gradually
changing or passing into each other by subtle gradations; -- said of
colors or of the surface or material on which the colors are
laid.</def></p>

<p><sn>2.</sn> <def>Melted.</def> <altsp>[Also spelled
<asp>fondue</asp>.]</altsp><br/
[<source>PJC</source>]</p>

<p><ent>Fondu</ent><br/
<ent>Fondue</ent><br/
\'d8<hw>Fon`due"</hw> <pr>(?)</pr>, <pos>n.</pos> <altsp>[Also
erroneously <asp><hw>Fon`du"</hw></asp>.]</altsp> <ety>[F. See
<er>Fondu</er>; cf. <er>Fondant</er>.]</ety> <sn>1.</sn>
<fld>(Cookery)</fld> <def>A dish made of cheese, eggs, butter, etc.,
often seasoned with kirsch and white wine, melted together, and usually
used as a dip for pieces of bread.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <fld>(Cookery)</fld> <def>A dish consisting of pieces of
solid food cooked in or dipped into a hot sauce; <as>as, beef
<ex>fondue</ex></as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>fondue</ent><br/
<hw>fon`due"</hw> <pr>(f<ocr/n"d<usdot/")</pr>, <pos>a.</pos> <ety>[F.
<ets>fondu</ets>, p.p. of <ets>fondre</ets> to melt, blend. See
<er>Found</er> to cast.]</ety> <def>Melted.</def> <altsp>[Also spelled
<asp>fondu</asp>.]</altsp><br/
[<source>PJC</source>]</p>

<p><ent>Fondus</ent><br/
\'d8<hw>Fon`dus"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>fondu</ets>, prop. p. p. of <ets>fondre</ets> to melt, blend. See
<er>Found</er> to cast.]</ety> <def>A style of printing calico, paper
hangings, etc., in which the colors are in bands and graduated into each
other.</def> <rj><au>Ure.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fone</ent><br/
<hw>Fone</hw> <pr>(?)</pr>, <pos>n.</pos>; <def><pos>pl.</pos> of
<er>Foe</er>.</def> <mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fonge</ent><br/
<hw>Fong"e</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[See <er>Fang</er>,
<pos>v. t.</pos>]</ety> <def>To take; to receive.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fonly</ent><br/
<hw>Fon"ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <ety>[See
<er>Fon</er>.]</ety> <def>Foolishly; fondly.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fonne</ent><br/
<hw>Fon"ne</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A fon.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Font</ent><br/
<hw>Font</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>fonte</ets>, fr.
<ets>fondre</ets> to melt or cast. See <er>Found</er> to cast, and cf.
<er>Fount</er> a font.]</ety> <fld>(Print.)</fld> <def>A complete
assortment of printing type of one size, including a due proportion of
all the letters in the alphabet, large and small, points, accents, and
whatever else is necessary for printing with that variety of types; a
fount.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Font</ent><br/
<hw>Font</hw>, <pos>n.</pos> <ety>[AS. <ets>font</ets>, <ets>fant</ets>,
fr. L. <ets>fons</ets>, <ets>fontis</ets>, spring, fountain; cf. OF.
<ets>font</ets>, <ets>funt</ets>, F. <ets>fonts</ets>, <ets>fonts
baptismaux</ets>, pl. See <er>Fount</er>.]</ety> <sn>1.</sn> <def>A
fountain; a spring; a source.</def><br/
[<source>1913 Webster</source>]</p>

<p><q> Bathing forever in the <qex>font</qex> of bliss.</q>
<rj><qau>Young.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A basin or stone vessel in which water is contained
for baptizing.</def><br/
[<source>1913 Webster</source>]</p>

<p><q> That name was given me at the <qex>font</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fontal</ent><br/
<hw>Font"al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to a font,
fountain, source, or origin; original; primitive.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q> From the <qex>fontal</qex> light of ideas only can a man draw
intellectual power.</q> <rj><qau>Coleridge.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fontanel</ent><br/
<hw>Fon"ta*nel`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>fontanelle</ets>, prop., a little fountain, fr. <ets>fontaine</ets>
fountain. See <er>Fountain</er>.]</ety> <sn>1.</sn> <fld>(Med.)</fld>
<def>An issue or artificial ulcer for the discharge of humors from the
body.</def><mark>[Obs.]</mark> <rj><au>Wiseman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Anat.)</fld> <def>One of the membranous intervals
between the incompleted angles of the parietal and neighboring bones of
a fetal or young skull; -- so called because it exhibits a rhythmical
pulsation.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In the human fetus there are six fontanels, of which the
anterior, or bregmatic, situated at the junction of the coronal and
sagittal sutures, is much the largest, and remains open a considerable
time after birth.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fontanelle</ent><br/
\'d8<hw>Fon`ta`nelle"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<fld>(Anat.)</fld> <def>Same as <er>Fontanel</er>, 2.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fontange</ent><br/
\'d8<hw>Fon`tange"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., from the
name of the first wearer, Mlle. de <ets>Fontanges</ets>, about
1679.]</ety> <def>A kind of tall headdress formerly worn.</def>
<rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Food</ent><br/
<hw>Food</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>fode</ets>, AS.
<ets>f<omac/da</ets>; akin to Icel. <ets>f<ae/<edh/a</ets>,
<ets>f<ae/<edh/i</ets>, Sw. <ets>f<oum/da</ets>, Dan. & LG.
<ets>f<oum/de</ets>, OHG. <ets>fatunga</ets>, Gr. <grk>patei^sthai</grk>
to eat, and perh. to Skr. <ets>p<amac/</ets> to protect, L.
<ets>pascere</ets> to feed, pasture, <ets>pabulum</ets> food, E.
<ets>pasture</ets>. <root/75. Cf. <er>Feed</er>, <er>Fodder</er> food,
<er>Foster</er> to cherish.]</ety> <sn>1.</sn> <def>What is fed upon;
that which goes to support life by being received within, and
assimilated by, the organism of an animal or a plant; nutriment;
aliment; especially, what is eaten by animals for nourishment.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In a physiological sense, true aliment is to be
distinguished as that portion of the food which is capable of being
digested and absorbed into the blood, thus furnishing nourishment, in
distinction from the indigestible matter which passes out through the
alimentary canal as f<ae/ces.</note><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Foods are divided into two main groups:
<xex>nitrogenous</xex>, or <xex>proteid</xex>, foods, <it>i.e.</it>,
those which contain nitrogen, and <xex>nonnitrogenous</xex>,
<it>i.e.</it>, those which do not contain nitrogen. The latter group
embraces the fats and carbohydrates, which collectively are sometimes
termed <xex>heat producers</xex> or <xex>respiratory foods</xex>, since
by oxidation in the body they especially subserve the production of
heat. The proteids, on the other hand, are known as <xex>plastic
foods</xex> or <xex>tissue formers</xex>, since no tissue can be formed
without them. These latter terms, however, are misleading, since proteid
foods may also give rise to heat both directly and indirectly, and the
fats and carbohydrates are useful in other ways than in producing
heat.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Anything that instructs the intellect, excites the
feelings, or molds habits of character; that which nourishes.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This may prove <qex>food</qex> to my displeasure.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>In this moment there is life and <qex>food</qex><br/
For future years.</q> <rj><qau>Wordsworth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Food</xex> is often used adjectively or in
self-explaining compounds, as in <xex>food</xex> fish or
<xex>food</xex>-fish, <xex>food</xex> supply.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Food vacuole</b></col> <fld>(Zool.)</fld>, <cd>one of the
spaces in the interior of a protozoan in which food is contained, during
digestion.</cd> -- <col><b>Food yolk</b></col>. <fld>(Biol.)</fld>
<cd>See under <er>Yolk</er>.</cd></cs></p>

<p><syn><b>Syn.</b> -- Aliment; sustenance; nutriment; feed; fare;
victuals; provisions; meat.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Food</ent><br/
<hw>Food</hw>, <pos>v. t.</pos> <def>To supply with food.</def>
<mark>[Obs.]</mark> <rj><au>Baret.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 580 --></p>

<p><ent>Foodful</ent><br/
<hw>Food"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Full of food;
supplying food; fruitful; fertile.</def> <ldquo/The <xex>foodful</xex>
earth.<rdquo/ <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Bent by its <qex>foodful</qex> burden [the corn].</q>
<rj><qau>Glover.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foodless</ent><br/
<hw>Food"less</hw>, <pos>a.</pos> <def>Without food; barren.</def>
<rj><au>Sandys.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foody</ent><br/
<hw>Food"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Eatable;
fruitful.</def> <mark>[R.]</mark> <rj><au>Chapman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fool</ent><br/
<hw>Fool</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F. <ets>fouler</ets>
to tread, crush. Cf. 1st <er>Foil</er>.]</ety> <def>A compound of
gooseberries scalded and crushed, with cream; -- commonly called
<xex>gooseberry fool</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fool</ent><br/
<hw>Fool</hw>, <pos>n.</pos> <ety>[OE. <ets>fol</ets>, n. & adj., F.
<ets>fol</ets>, <ets>fou</ets>, foolish, mad; a fool, prob. fr. L.
<ets>follis</ets> a bellows, wind bag, an inflated ball; perh. akin to
E. <ets>bellows</ets>. Cf. <er>Folly</er>, <er>Follicle</er>.]</ety>
<sn>1.</sn> <def>One destitute of reason, or of the common powers of
understanding; an idiot; a natural.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A person deficient in intellect; one who acts
absurdly, or pursues a course contrary to the dictates of wisdom; one
without judgment; a simpleton; a dolt.</def><br/
[<source>1913 Webster</source>]</p>

<p><q> Extol not riches, then, the toil of <qex>fools</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q> Experience keeps a dear school, but <qex>fools</qex> will learn
in no <qex>other</qex>.</q> <rj><qau>Franklin.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Script.)</fld> <def>One who acts contrary to moral
and religious wisdom; a wicked person.</def><br/
[<source>1913 Webster</source>]</p>

<p><q> The <qex>fool</qex> hath said in his heart, There is no God.</q>
<rj><qau>Ps. xiv. 1.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>One who counterfeits folly; a professional jester or
buffoon; a retainer formerly kept to make sport, dressed fantastically
in motley, with ridiculous accouterments.</def><br/
[<source>1913 Webster</source>]</p>

<p><q> Can they think me . . . their <qex>fool</qex> or jester?</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>April fool</b></col>, <col><b>Court fool</b></col>,
etc.</mcol> <cd>See under <er>April</er>, <er>Court</er>, etc.</cd> --
<col><b>Fool's cap</b></col>, <cd>a cap or hood to which bells were
usually attached, formerly worn by professional jesters.</cd> --
<col><b>Fool's errand</b></col>, <cd>an unreasonable, silly, profitless
adventure or undertaking.</cd> -- <col><b>Fool's gold</b></col>,
<cd>iron or copper pyrites, resembling gold in color.</cd> --
<col><b>Fool's paradise</b></col>, <cd>a name applied to a limbo (see
under <er>Limbo</er>) popularly believed to be the region of vanity and
nonsense. Hence, any foolish pleasure or condition of vain
self-satistaction.</cd> -- <col><b>Fool's parsley</b></col>
<fld>(Bot.)</fld>, <cd>an annual umbelliferous plant (<spn>Aethusa
Cynapium</spn>) resembling parsley, but nauseous and poisonous.</cd> --
<col><b>To make a fool of</b></col>, <cd>to render ridiculous; to
outwit; to shame.</cd> <mark>[Colloq.]</mark> -- <col><b>To play the
fool</b></col>, <cd>to act foolishly; to act the buffoon; to act a
foolish part.</cd> <ldquo/I have <xex>played the fool</xex>, and have
erred exceedingly.<rdquo/ <au>1 Sam. xxvi. 21.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fool</ent><br/
<hw>Fool</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Fooled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Fooling</conjf>.]</vmorph> <def>To play the fool.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To waste time in unproductive activity; to spend
time in idle sport or mirth; to trifle; to toy.</def><br/
<syn><b>Syn. --</b> fool around.</syn><br/
[<source>PJC</source>]</p>

<p><q>Is this a time for <qex>fooling</qex>?</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fool</ent><br/
<hw>Fool</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To infatuate; to make
foolish.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>For, <qex>fooled</qex> with hope, men favor the deceit.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To use as a fool; to deceive in a shameful or
mortifying manner; to impose upon; to cheat by inspiring foolish
confidence; <as>as, to <ex>fool</ex> one out of his
money</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>You are <qex>fooled</qex>, discarded, and shook off<br/
By him for whom these shames ye underwent.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To fool away</b></col>, <cd>to get rid of foolishly; to
spend in trifles, idleness, folly, or without advantage.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foolahs</ent><br/
<hw>Foo"lahs`</hw> <pr>(?)</pr>, <pos>n. pl.</pos>; <sing>sing.
<singw>Foolah</singw></sing>. <fld>(Ethnol.)</fld> <def>Same as
<er>Fulahs</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>fool around</ent><br/
<hw>fool` a*round"</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Fooled around</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Fooling around</conjf>.]</vmorph> <sn>1.</sn> <def>To
waste time in idle pursuits; to fool{2}.</def><br/
<syn><b>Syn. --</b> fool{2}.</syn><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>To flirt or philander.</def> <au>RHUD</au>br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>To be sexually promiscuous; to engage in sexual
intercourse with more than one partner; especially, to engage in
adultery; <as>as, to <ex>fool around</ex> with another
woman</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>fool around with</ent><br/
<hw>fool` a*round" with`</hw>, <pos>v. t.</pos> <def>To manipulate (a
machine or device) without proper knowledge of its operation; to
experiment aimlessly with a device; <as>as, don't <ex>fool around
with</ex> the transit</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Fool-born</ent><br/
<hw>Fool"-born`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Begotten by a
fool.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foolery</ent><br/
<hw>Fool"er*y</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Fooleries</plw> <pr>(<?/)</pr>.</plu> <sn>1.</sn> <def>The practice
of folly; the behavior of a fool; foolish behavior; absurdity.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Folly in fools bears not so strong a note,<br/
As <qex>foolery</qex> in the wise, when wit doth dote.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An act of folly or weakness; a foolish practice;
something absurd or nonsensical.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That Pythagoras, Plato, or Orpheus, believed in any of these
<qex>fooleries</qex>, it can not be suspected.</q> <rj><qau>Sir W.
Raleigh.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foolfish</ent><br/
<hw>Fool"fish`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<sd>(a)</sd> <def>The orange filefish<--clownfish?-->. See
<er>Filefish</er>.</def> <sd>(b)</sd> <def>The winter flounder. See
<er>Flounder</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fool-happy</ent><br/
<hw>Fool"-hap`py</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Lucky, without
judgment or contrivance.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foolhardihood</ent><br/
<hw>Fool"har`di*hood</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state of
being foolhardy; foolhardiness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foolhardily</ent><br/
<hw>Fool"har`di*ly</hw>, <pos>adv.</pos> <def>In a foolhardy
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foolhardiness</ent><br/
<hw>Fool"har`di*ness</hw>, <pos>n.</pos> <def>Courage without sense or
judgment; foolish rashness; recklessness.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foolhardise</ent><br/
<hw>Fool"har`dise</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Fool</ets>, F. <ets>fol</ets>, <ets>fou</ets> + F.
<ets>hardiesse</ets> boldness.]</ety> <def>Foolhardiness.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foolhardy</ent><br/
<hw>Fool"har`dy</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OF.
<ets>folhardi</ets>. See <er>Fool</er> idiot, and <er>Hardy</er>.]</ety>
<def>Daring without judgment; foolishly adventurous and bold.</def>
<rj><au>Howell.</au></rj></p>

<p><syn><b>Syn.</b> -- Rash; venturesome; venturous; precipitate;
reckless; headlong; incautious. See <er>Rash</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fool-hasty</ent><br/
<hw>Fool"-has`ty</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Foolishly
hasty.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foolify</ent><br/
<hw>Fool"i*fy</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[<ets>Fool</ets>
+ <ets>-fy</ets>.]</ety> <def>To make a fool of; to befool.</def>
<mark>[R.]</mark> <rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foolish</ent><br/
<hw>Fool"ish</hw>, <pos>a.</pos> <sn>1.</sn> <def>Marked with, or
exhibiting, folly; void of understanding; weak in intellect; without
judgment or discretion; silly; unwise.</def><br/
[<source>1913 Webster</source>]</p>

<p><q> I am a very <qex>foolish</qex> fond old man.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Such as a fool would do; proceeding from weakness of
mind or silliness; exhibiting a want of judgment or discretion; <as>as,
a <ex>foolish</ex> act</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Absurd; ridiculous; despicable;
contemptible.</def><br/
[<source>1913 Webster</source>]</p>

<p><q> A <qex>foolish</qex> figure he must make.</q>
<rj><qau>Prior.</qau></rj></p>

<p><syn><b>Syn.</b> -- Absurd; shallow; shallow-brained; brainless;
simple; irrational; unwise; imprudent; indiscreet; incautious; silly;
ridiculous; vain; trifling; contemptible. See <er>Absurd</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foolishly</ent><br/
<hw>Fool"ish*ly</hw>, <pos>adv.</pos> <def>In a foolish
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foolishness</ent><br/
<hw>Fool"ish*ness</hw>, <pos>n.</pos> <sn>1.</sn> <def>The quality of
being foolish.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A foolish practice; an absurdity.</def><br/
[<source>1913 Webster</source>]</p>

<p><q> The preaching of the cross is to them that perish
<qex>foolishness</qex>.</q> <rj><qau>1 Cor. i. 18.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fool-large</ent><br/
<hw>Fool"-large`</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OF.
<ets>follarge</ets>. See <er>Fool</er>, and <er>Large</er>.]</ety>
<def>Foolishly liberal.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fool-largesse</ent><br/
<hw>Fool"-lar*gesse`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Fool-large</er>, <er>Largess</er>.]</ety> <def>Foolish expenditure;
waste.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foolscap</ent><br/
<hw>Fools"cap`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[So called from the
watermark of a <ets>fool's cap and bells</ets> used by old paper makers.
See <ets>Fool's cap</ets>, under <er>Fool</er>.]</ety> <def>A writing
paper made in sheets, ordinarily 16 x 13 inches, and folded so as to
make a page 13 x 8 inches. See <er>Paper</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foot</ent><br/
<hw>Foot</hw> <pr>(f<oocr/t)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Feet</plw> <pr>(f<emac/t)</pr>.</plu> <ety>[OE. <ets>fot</ets>,
<ets>foot</ets>, pl. <ets>fet</ets>, <ets>feet</ets>. AS.
<ets>f<omac/t</ets>, pl. <ets>f<emac/t</ets>; akin to D.
<ets>voet</ets>, OHG. <ets>fuoz</ets>, G. <ets>fuss</ets>, Icel.
<ets>f<omac/tr</ets>, Sw. <ets>fot</ets>, Dan. <ets>fod</ets>, Goth.
<ets>f<omac/tus</ets>, L. <ets>pes</ets>, Gr. <grk>poy`s</grk>, Skr.
<ets>p<amac/d</ets>, Icel. <ets>fet</ets> step, pace measure of a foot,
<ets>feta</ets> to step, find one's way. <root/77, 250. Cf.
<er>Antipodes</er>, <er>Cap-a-pie</er>, <er>Expedient</er>, <er>Fet</er>
to fetch, <er>Fetlock</er>, <er>Fetter</er>, <er>Pawn</er> a piece in
chess, <er>Pedal</er>.]</ety> <sn>1.</sn> <fld>(Anat.)</fld> <def>The
terminal part of the leg of man or an animal; esp., the part below the
ankle or wrist; that part of an animal upon which it rests when
standing, or moves. See <er>Manus</er>, and <er>Pes</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>The muscular locomotive organ of
a mollusk. It is a median organ arising from the ventral region of body,
often in the form of a flat disk, as in snails. See <xex>Illust.</xex>
of <er>Buccinum</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which corresponds to the foot of a man or
animal; <as>as, the <ex>foot</ex> of a table; the <ex>foot</ex> of a
stocking.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The lowest part or base; the ground part; the
bottom, as of a mountain, column, or page; also, the last of a row or
series; the end or extremity, esp. if associated with inferiority;
<as>as, the <ex>foot</ex> of a hill; the <ex>foot</ex> of the
procession; the <ex>foot</ex> of a class; the <ex>foot</ex> of the bed;
; the <ex>foot</ex> of the page.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>And now at <qex>foot</qex><br/
Of heaven's ascent they lift their feet.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Fundamental principle; basis; plan; -- used only in
the singular.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Answer directly upon the <qex>foot</qex> of dry reason.</q>
<rj><qau>Berkeley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Recognized condition; rank; footing; -- used only in
the singular.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>As to his being on the <qex>foot</qex> of a servant.</q>
<rj><qau>Walpole.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>A measure of length equivalent to twelve inches; one
third of a yard. See <er>Yard</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ This measure is supposed to be taken from the length of
a man's foot. It differs in length in different countries. In the United
States and in England it is 304.8 millimeters.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <fld>(Mil.)</fld> <def>Soldiers who march and fight on
foot; the infantry, usually designated as <xex>the foot</xex>, in
distinction from the cavalry.</def> <ldquo/Both horse and
<xex>foot</xex>.<rdquo/ <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <fld>(Pros.)</fld> <def>A combination of syllables
consisting a metrical element of a verse, the syllables being formerly
distinguished by their quantity or length, but in modern poetry by the
accent.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <fld>(Naut.)</fld> <def>The lower edge of a
sail.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Foot</xex> is often used adjectively, signifying
<xex>of or pertaining to a foot or the feet</xex>, <xex>or to the base
or lower part</xex>. It is also much used as the first of
compounds.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs> <col><b>Foot artillery</b></col>. <fld>(Mil.)</fld> <sd>(a)</sd>
<cd>Artillery soldiers serving in foot.</cd> <sd>(b)</sd> <cd>Heavy
artillery.</cd> <au>Farrow.</au> -- <col><b>Foot bank</b></col>
<fld>(Fort.)</fld>, <cd>a raised way within a parapet.</cd> --
<col><b>Foot barracks</b></col> <fld>(Mil.)</fld>, <cd>barracks for
infantery.</cd> -- <col><b>Foot bellows</b></col>, <cd>a bellows worked
by a treadle.</cd> <au>Knight.</au> -- <col><b>Foot company</b></col>
<fld>(Mil.)</fld>, <cd>a company of infantry.</cd> <au>Milton.</au> --
<col><b>Foot gear</b></col>, <cd>covering for the feet, as stocking,
shoes, or boots.</cd> -- <col><b>Foot hammer</b></col>
<fld>(Mach.)</fld>, <cd>a small tilt hammer moved by a treadle.</cd> --
<col><b>Foot iron</b></col>. <sd>(a)</sd> <cd>The step of a
carriage.</cd> <sd>(b)</sd> <cd>A fetter.</cd> -- <col><b>Foot
jaw</b></col>. <fld>(Zool.)</fld> <cd>See <er>Maxilliped</er>.</cd> --
<col><b>Foot key</b></col> <fld>(Mus.)</fld>, <cd>an organ pedal.</cd>
-- <col><b>Foot level</b></col> <fld>(Gunnery)</fld>, <cd>a form of
level used in giving any proposed angle of elevation to a piece of
ordnance.</cd> <au>Farrow.</au> -- <col><b>Foot mantle</b></col>, <cd>a
long garment to protect the dress in riding; a riding skirt.</cd>
<mark>[Obs.]</mark> -- <col><b>Foot page</b></col>, <cd>an errand boy;
an attendant.</cd> <mark>[Obs.]</mark> -- <col><b>Foot
passenger</b></col>, <cd>one who passes on foot, as over a road or
bridge.</cd> -- <col><b>Foot pavement</b></col>, <cd>a paved way for
foot passengers; a footway; a trottoir.</cd> -- <col><b>Foot
poet</b></col>, <cd>an inferior poet; a poetaster.</cd>
<mark>[R.]</mark> <au>Dryden.</au> -- <col><b>Foot post</b></col>.
<sd>(a)</sd> <cd>A letter carrier who travels on foot.</cd> <sd>(b)</sd>
<cd>A mail delivery by means of such carriers.</cd> -- <mcol><col><b>Fot
pound</b></col>, <and/ <col><b>Foot poundal</b></col></mcol>.
<fld>(Mech.)</fld> <cd>See <er>Foot pound</er> and <er>Foot
poundal</er>, in the Vocabulary.</cd> -- <col><b>Foot press</b></col>
<fld>(Mach.)</fld>, <cd>a cutting, embossing, or printing press, moved
by a treadle.</cd> -- <col><b>Foot race</b></col>, <cd>a race run by
persons on foot.</cd> <au>Cowper.</au> -- <col><b>Foot rail</b></col>,
<cd>a railroad rail, with a wide flat flange on the lower side.</cd> --
<col><b>Foot rot</b></col>, <cd>an ulcer in the feet of sheep; claw
sickness.</cd> -- <col><b>Foot rule</b></col>, <cd>a rule or measure
twelve inches long.</cd> -- <col><b>Foot screw</b></col>, <cd>an
adjusting screw which forms a foot, and serves to give a machine or
table a level standing on an uneven place.</cd> -- <col><b>Foot
secretion</b></col>. <fld>(Zool.)</fld> <cd>See
<er>Sclerobase</er>.</cd> -- <col><b>Foot soldier</b></col>, <cd>a
soldier who serves on foot.</cd> -- <col><b>Foot stick</b></col>
<fld>(Printing)</fld>, <cd>a beveled piece of furniture placed against
the foot of the page, to hold the type in place.</cd> -- <col><b>Foot
stove</b></col>, <cd>a small box, with an iron pan, to hold hot coals
for warming the feet.</cd> -- <col><b>Foot tubercle</b></col>.
<fld>(Zool.)</fld> <cd>See <er>Parapodium</er>.</cd> -- <col><b>Foot
valve</b></col> <fld>(Steam Engine)</fld>, <cd>the valve that opens to
the air pump from the condenser.</cd> -- <col><b>Foot vise</b></col>,
<cd>a kind of vise the jaws of which are operated by a treadle.</cd> --
<col><b>Foot waling</b></col> <fld>(Naut.)</fld>, <cd>the inside planks
or lining of a vessel over the floor timbers.</cd> <au>Totten.</au> --
<col><b>Foot wall</b></col> <fld>(Mining)</fld>, <cd>the under wall of
an inclosed vein.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><cs> <mcol><col><b>By foot</b></col>, <it>or</it> <col><b>On
foot</b></col></mcol>, <cd>by walking; as, to pass a stream <xex>on
foot</xex>.</cd> -- <col><b>Cubic foot</b></col>. <cd>See under
<er>Cubic</er>.</cd> -- <col><b>Foot and mouth disease</b></col>, <cd>a
contagious disease <it>(Eczema epizo<oum/tica)</it> of cattle, sheep,
swine, etc., characterized by the formation of vesicles and ulcers in
the mouth and about the hoofs.</cd> -- <col><b>Foot of the
fine</b></col> <fld>(Law)</fld>, <cd>the concluding portion of an
acknowledgment in court by which, formerly, the title of land was
conveyed. See <cref>Fine of land</cref>, under <er>Fine</er>,
<pos>n.</pos>; also <er>Chirograph</er>. (b).</cd> -- <col><b>Square
foot</b></col>. <cd>See under <er>Square</er>.</cd> -- <col><b>To be on
foot</b></col>, <cd>to be in motion, action, or process of
execution.</cd> -- <col><b>To keep the foot</b></col>
<fld>(Script.)</fld>, <cd>to preserve decorum.</cd> <ldquo/<xex>Keep thy
foot</xex> when thou goest to the house of God.<rdquo/ <au>Eccl. v.
1.</au> -- <col><b>To put one's foot down</b></col>, <cd>to take a
resolute stand; to be determined.</cd> <mark>[Colloq.]</mark> --
<col><b>To put the best foot foremost</b></col>, <cd>to make a good
appearance; to do one's best.</cd> <mark>[Colloq.]</mark> -- <col><b>To
set on foot</b></col>, <cd>to put in motion; to originate; as, <xex>to
set on foot</xex> a subscription.</cd> -- <mcol><col><b>To</b></col>
<col><b>put one on his feet</b></col>, <it>or</it> <col><b>set one on
his feet</b></col></mcol>, <cd>to put one in a position to go on; to
assist to start.</cd> -- <col><b>Under foot</b></col>. <sd>(a)</sd>
<cd>Under the feet; (<mark>Fig.</mark>) at one's mercy; <as>as, to
trample <ex>under foot</ex></as>.</cd> <au>Gibbon.</au> <sd>(b)</sd>
<cd>Below par.</cd> <mark>[Obs.]</mark> <ldquo/They would be forced to
sell . . . far <xex>under foot</xex>.<rdquo/ <au>Bacon.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foot</ent><br/
<hw>Foot</hw> <pr>(f<oocr/t)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Footed</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Footing</conjf>.]</vmorph> <sn>1.</sn> <def>To tread to measure
or music; to dance; to trip; to skip.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To walk; -- opposed to <xex>ride</xex> or
<xex>fly</xex>.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foot</ent><br/
<hw>Foot</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To kick with the foot;
to spurn.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To set on foot; to establish; to land.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>What confederacy have you with the traitors<br/
Late <qex>footed</qex> in the kingdom?</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To tread; <as>as, to <ex>foot</ex> the
green</as>.</def> <rj><au>Tickell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To sum up, as the numbers in a column; -- sometimes
with <xex>up</xex>; <as>as, to <ex>foot</ex> (or <ex>foot</ex> up) an
account</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To seize or strike with the talon.</def>
<mark>[Poet.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To renew the foot of, as of a stocking.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>To foot a bill</b></col>, <cd>to pay it.</cd>
<mark>[Colloq.]</mark> -- <col><b>To foot it</b></col></mcol>, <cd>to
walk; also, to dance.</cd></cs><-- = to hoof it (to walk) --><br/
[<source>1913 Webster</source>]</p>

<p><q>If you are for a merry jaunt, I'll try, for once, who can
<qex>foot it</qex> farthest.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>footage</ent><br/
<hw>footage</hw> <pos>n.</pos> <fld>(Cinematography)</fld> <sn>1.</sn>
<def>the amount of film that has been shot.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>a rate of charging by the linear foot of work
done.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>football</ent><br/
<hw>foot"ball`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An inflated ball to
be kicked in sport, usually made in India rubber, or a bladder incased
in Leather.</def> <rj><au>Waller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><note>The American <ex>football</ex> is an oblate spheroid, with
pointed ends. In other countries, the <ex>football</ex> is the same as a
soccer ball. The games played with the two different balls are
different. In the United States, the game played with a soccer ball is
called soccer.</note><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>The game played with a football{1}, by two opposing
teams of players moving the ball between goals at opposite ends of a
rectangular playing field. Outside the United States <ex>football</ex>
refers to soccer, and in England, also to rugby, but in the United
States the shape of the ball and the rules of the game are
different.</def> <rj><au>Arbuthnot.</au></rj><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>3.</sn> <def>Soccer or rugby.</def> <mark>[Brit.]</mark> <br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <mark>[fig.]</mark> <def>Something which is treated in a
rough manner, usually as part of a dispute; <as>as, a political
<ex>football</ex></as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>footballer</ent><br/
<hw>footballer</hw> <pos>n.</pos> <def>an athlete who plays
football.</def><br/
<syn><b>Syn. --</b> football player.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Footband</ent><br/
<hw>Foot"band`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A band of foot
soldiers.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Footbath</ent><br/
<hw>Foot"bath`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A bath for the
feet; also, a vessel used in bathing the feet.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Footboard</ent><br/
<hw>Foot"board`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A
board or narrow platfrom upon which one may stand or brace his
feet</def>; as: <sd>(a)</sd> <def>The platform for the engineer and
fireman of a locomotive.</def> <sd>(b)</sd> <def>The foot-rest of a
coachman's box.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A board forming the foot of a bedstead.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A treadle.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Footboy</ent><br/
<hw>Foot"boy`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A page; an attendant
in livery; a lackey.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Footbreadth</ent><br/
<hw>Foot"breadth`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The breadth of a
foot; -- used as a measure.</def> <rj><au>Longfellow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Not so much as a <qex>footbreadth</qex>.</q> <rj><qau>Deut. ii.
5.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Footbridge</ent><br/
<hw>Foot"bridge`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A narrow bridge
for foot passengers only.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foot candle</ent><br/
<hw>Foot candle</hw>. <fld>(Photom.)</fld> <def>The amount of
illumination produced by a standard candle at a distance of one
foot.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Footcloth</ent><br/
<hw>Foot"cloth`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Formerly, a
housing or caparison for a horse.</def> <rj><au>Sir W.
Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Footed</ent><br/
<hw>Foot"ed</hw>, <pos>a.</pos> <sn>1.</sn> <def>Having a foot or feet;
shaped in the foot; <as>as, a <ex>footed</ex> candlestick</as>.</def>
<ldquo/<xex>Footed</xex> like a goat.<rdquo/ <rj><au>Grew.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Footed</xex> is often used in composition in the
sense of <xex>having</xex> (<xex>such</xex> or <xex>so many</xex>)
<xex>feet</xex>; as, four<xex>footed</xex> beasts.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Having a foothold; established.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Our king . . . is <qex>footed</qex> in this land already.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>-footer</ent><br/
<hw>-foot"er</hw> <pos>suff.</pos> <def>a suffix designating
<sig>something with a length of (so many) feet</sig>; -- used only in
combinations with a numerical prefix; <as>as, he is a
six-<ex>footer</ex>; the golfer sank a <ex>40-footer</ex>; his yacht is
a <ex>60-footer</ex></as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>footer</ent><br/
<hw>foot"er</hw> <pos>n.</pos> <def>a person who travels by
foot.</def><br/
<syn><b>Syn. --</b> pedestrian, walker.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Footfall</ent><br/
<hw>Foot"fall`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A setting down of
the foot; a footstep; the sound of a footstep.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Seraphim, whose <qex>footfalls</qex> tinkled on the tufted
floor.</q> <rj><qau>Poe.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Footfight</ent><br/
<hw>Foot"fight`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A conflict by
persons on foot; -- distinguished from a fight on horseback.</def>
<rj><au>Sir P. Sidney.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Footglove</ent><br/
<hw>Foot"glove`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A kind of
stocking.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foot Guards</ent><br/
<hw>Foot" Guards`</hw> <pr>(?)</pr>, <pos>pl.</pos> <def>Infantry
soldiers belonging to select regiments called the Guards.</def>
<mark>[Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foothalt</ent><br/
<hw>Foot"halt`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A disease affecting
the feet of sheep.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foothill</ent><br/
<hw>Foot"hill`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A low hill at the
foot of higher hills or mountains.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foothold</ent><br/
<hw>Foot"hold`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A holding with the
feet; firm standing; that on which one may tread or rest securely;
footing.</def> <rj><au>L'Estrange.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foothook</ent><br/
<hw>Foot"hook`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Naut.)</fld>
<def>See <er>Futtock</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foothot</ent><br/
<hw>Foot"hot`</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>Hastily;
immediately; instantly; on the spot; hotfoot.</def>
<rj><au>Gower.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Custance have they taken anon, <qex>foothot</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Footing</ent><br/
<hw>Foot"ing</hw>, <pos>n.</pos> <sn>1.</sn> <def>Ground for the foot;
place for the foot to rest on; firm foundation to stand on.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In ascent, every step gained is a <qex>footing</qex> and help to
the next.</q> <rj><qau>Holder.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Standing; position; established place; basis for
operation; permanent settlement; foothold.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>As soon as he had obtained a <qex>footing</qex> at court, the
charms of his manner . . . made him a favorite.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Relative condition; state.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Lived on a <qex>footing</qex> of equality with nobles.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Tread; step; especially, measured tread.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Hark, I hear the <qex>footing</qex> of a man.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>The act of adding up a column of figures; the amount
or sum total of such a column.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>The act of putting a foot to anything; also, that
which is added as a foot; <as>as, the <ex>footing</ex> of a
stocking</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>A narrow cotton lace, without figures.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>The finer refuse part of whale blubber, not wholly
deprived of oil.</def> <rj><au>Simmonds.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <fld>(Arch. & Enging.)</fld> <def>The thickened or
sloping portion of a wall, or of an embankment at its foot.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Footing course</b></col> <fld>(Arch.)</fld>, <cd>one of
the courses of masonry at the foot of a wall, broader than the courses
above.</cd> -- <col><b>To pay one's footing</b></col>, <cd>to pay a fee
on first doing anything, as working at a trade or in a shop.</cd>
<au>Wright.</au> -- <col><b>Footing beam</b></col>, <cd>the tie beam of
a roof.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Footless</ent><br/
<hw>Foot"less</hw>, <pos>a.</pos> <def>Having no feet.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Footlicker</ent><br/
<hw>Foot"lick`er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A sycophant; a
fawner; a toady. Cf. <er>Bootlick</er>.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Footlight</ent><br/
<hw>Foot"light`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One of a row of
lights in the front of the stage in a theater, etc., and on a level
therewith.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Before the footlights</b></col>, <cd>upon the stage; --
hence, in the capacity of an actor.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>footling</ent><br/
<hw>foot"ling</hw> <pos>adj.</pos> <def>small and of little importance;
<as>as, a <ex>footling</ex> gesture</as>.</def><br/
<syn><b>Syn. --</b> fiddling, lilliputian, little, niggling, paltry,
petty, piddling, picayune, small, trivial.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>footlocker</ent><br/
<hw>foot"lock*er</hw> <pos>n.</pos> <def>a trunk for storing personal
possessions; usually kept at the foot of a bed (as in a military
barracks).</def><br/
<syn><b>Syn. --</b> locker.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>foot-loose</ent><br/
<hw>foot-loose</hw> <pos>adj.</pos> <sn>1.</sn> <def>having no
commitments or restrictions.</def> <ldquo/foot-loose and
fancy-free<rdquo/<br/
<syn><b>Syn. --</b> fancy-free, footloose.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>footloose</ent><br/
<hw>footloose</hw> <pos>adj.</pos> <sn>1.</sn> <def>without ties to a
particular location; free to roam; wandering.</def><br/
<syn><b>Syn. --</b> aimless, drifting, floating, vagabond,
vagrant.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>without dependents or responsibilities.</def><br/
<syn><b>Syn. --</b> untrammeled, untrammelled.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>3.</sn> <def>having no commitments or restrictions.</def><br/
<syn><b>Syn. --</b> fancy-free, foot-loose.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Footman</ent><br/
<hw>Foot"man</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Footmen</plw> <pr>(<?/)</pr>.</plu> <sn>1.</sn> <def>A soldier who
marches and fights on foot; a foot soldier.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A man in waiting; a male servant whose duties are to
attend the door, the carriage, the table, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Formerly, a servant who ran in front of his master's
carriage; a runner.</def> <rj><au>Prior.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A metallic stand with four feet, for keeping
anything warm before a fire.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Zool.)</fld> <def>A moth of the family
<fam>Lithosid<ae/</fam>; -- so called from its livery-like
colors.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Footmanship</ent><br/
<hw>Foot"man*ship</hw>, <pos>n.</pos> <def>Art or skill of a
footman.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Footmark</ent><br/
<hw>Foot"mark`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A footprint; a
track or vestige.</def> <rj><au>Coleridge.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Footnote</ent><br/
<hw>Foot"note`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A note of reference
or comment at the foot{4} of a page.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Footpace</ent><br/
<hw>Foot"pace`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A
walking pace or step.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A dais, or elevated platform; the highest step of
the altar; a landing in a staircase.</def>
<rj><au>Shipley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Footpad</ent><br/
<hw>Foot"pad`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A highwayman or
robber on foot.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Footpath</ent><br/
<hw>Foot"path`</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Footpaths</plw> <pr>(<?/)</pr>.</plu> <def>A narrow path or way for
pedestrains only; a footway.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Footplate</ent><br/
<hw>Foot"plate`</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Locomotives)</fld> <def>See <er>Footboard</er>
<sd>(a)</sd>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foot pound</ent><br/
<hw>Foot" pound`</hw> <pr>(?)</pr>. <fld>(Mech.)</fld> <def>A unit of
energy, or work, being equal to the work done in raising one pound
avoirdupois against the force of gravity through a vertical distance of
one foot.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 581 --></p>

<p><ent>Foot poundal</ent><br/
<hw>Foot" pound`al</hw> <pr>(?)</pr>. <fld>(Mech.)</fld> <def>A unit of
energy or work, equal to the work done in moving a body through one foot
against the force of one poundal.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Footprint</ent><br/
<hw>Foot"print`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The impression of
the foot; a trace or footmark; <as>as, <ldquo/<ex>Footprints</ex> of the
Creator</as>.<rdquo/</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Footrope</ent><br/
<hw>Foot"rope`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Aut.)</fld>
<sd>(a)</sd> <def>The rope rigged below a yard, upon which men stand
when reefing or furling; -- formerly called a
<altname>horse</altname>.</def> <sd>(b)</sd> <def>That part of the
boltrope to which the lower edge of a sail is sewed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foots</ent><br/
<hw>Foots</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <def>The settlings of
oil, molasses, etc., at the bottom of a barrel or hogshead.</def>
<rj><au>Simmonds.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>foot-sore</ent><br/
<ent>footsore</ent><br/
<mhw><hw>foot"sore</hw>, <hw>foot"-sore`</hw></mhw> <pr>(?)</pr>,
<pos>a.</pos> <def>Having sore or tender feet, as by reason of much
walking; <as>as, <ex>foot-sore</ex> cattle</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Footstalk</ent><br/
<hw>Foot"stalk`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<fld>(Bot.)</fld> <def>The stalk of a leaf or of flower; a petiole,
pedicel, or reduncle.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <sd>(a)</sd> <def>The peduncle or stem
by which various marine animals are attached, as certain brachiopods and
goose barnacles.</def> <sd>(b)</sd> <def>The stem which supports which
supports the eye in decapod Crustacea; eyestalk.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Mach.)</fld> <def>The lower part of a millstone
spindle. It rests in a step.</def> <rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Footstall</ent><br/
<hw>Foot"stall`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf.
<er>Pedestal</er>.]</ety> <sn>1.</sn> <def>The stirrup of a woman's
saddle.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Arch.)</fld> <def>The plinth or base of a
pillar.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Footstep</ent><br/
<hw>Foot"step`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
mark or impression of the foot; a track; hence, visible sign of a course
pursued; token; mark; <as>as, the <ex>footsteps</ex> of divine
wisdom</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>How on the faltering <qex>footsteps</qex> of decay<br/
Youth presses.</q> <rj><qau>Bryant.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An inclined plane under a hand printing
press.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Footstone</ent><br/
<hw>Foot"stone`</hw> <pr>(?; 110)</pr>, <pos>n.</pos> <def>The stone at
the foot of a grave; -- opposed to <xex>headstone</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Footstool</ent><br/
<hw>Foot"stool`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A low stool to
support the feet of one when sitting.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foot ton</ent><br/
<hw>Foot ton</hw>. <fld>(Mech.)</fld> <def>A unit of energy or work,
being equal to the work done in raising one ton against the force of
gravity through the height of one foot.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Foot valve</ent><br/
<hw>Foot valve</hw>. <fld>(Mech.)</fld> <def>A suction valve or check
valve at the lower end of a pipe; esp., such a valve in a steam-engine
condenser opening to the air pump.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Footway</ent><br/
<hw>Foot"way`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A passage for
pedestrians only.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Footworn</ent><br/
<hw>Foot"worn`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Worn by, or weared
in, the feet; <as>as, a <ex>footworn</ex> path; a <ex>footworn</ex>
traveler.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Footy</ent><br/
<hw>Foot"y</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Having
<xex>foots</xex>, or settlings; <as>as, <ex>footy</ex> oil, molasses,
etc.</as></def> <mark>[Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Poor; mean.</def> <mark>[Prov. Eng.]</mark>
<rj><au>C. Kingsley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foozle</ent><br/
<hw>Foo"zle</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Foozled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Foozling</conjf> <pr>(?)</pr>.]</vmorph> <ety>[Cf. G.
<ets>fuseln</ets> to work badly or slowly.]</ety> <def>To bungle; to
manage awkwardly; to treat or play unskillfully; <as>as, to
<ex>foozle</ex> a stroke in golf</as>.</def></p>

<p><q>She <qex>foozles</qex> all along the course.</q> <rj><qau>Century
Mag.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Foozle</ent><br/
<hw>Foo"zle</hw>, <pos>n.</pos> <sn>1.</sn> <def>A stupid fellow; a
fogy.</def> <mark>[Colloq.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>Act of foozling; a bungling stroke, as in
golf.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Fop</ent><br/
<hw>Fop</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>foppe</ets>,
<ets>fop</ets>, fool; cf. E. <ets>fob</ets> to cheat, G.
<ets>foppen</ets> to make a fool of one, jeer, D.
<ets>foppen</ets>.]</ety> <def>One whose ambition it is to gain
admiration by showy dress; a coxcomb; an inferior dandy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fop-doodle</ent><br/
<hw>Fop"-doo`dle</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A stupid or
insignificant fellow; a fool; a simpleton.</def> <mark>[R.]</mark>
<rj><au>Hudibras.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fopling</ent><br/
<hw>Fop"ling</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A petty fop.</def>
<rj><au>Landor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foppery</ent><br/
<hw>Fop"per*y</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Fopperies</plw> <pr>(#)</pr>.</plu> <ety>[From <er>Fop</er>.]</ety>
<sn>1.</sn> <def>The behavior, dress, or other indication of a fop;
coxcombry; affectation of show; showy folly.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Folly; foolery.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Let not the sound of shallow <qex>foppery</qex> enter<br/
My sober house.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foppish</ent><br/
<hw>Fop"pish</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Foplike;
characteristic of a top in dress or manners; making an ostentatious
display of gay clothing; affected in manners.</def></p>

<p><syn><b>Syn.</b> -- Finical; spruce; dandyish. See
<er>Finical</er>.</syn></p>

<p>-- <wordforms><wf>Fop"pish*ly</wf>, <pos>adv.</pos> --
<wf>Fop"pish*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>For-</ent><br/
<hw>For-</hw> <pr>(<?/)</pr>. <ety>[AS. <ets>for-</ets>; akin to D. & G.
<ets>ver</ets>-, OHG. <ets>fir</ets>-, Icel. <ets>for</ets>-, Goth.
<ets>fra</ets>-, cf. Skr. <ets>par<amac/-</ets> away, Gr. <?/ beside,
and E. <ets>far</ets>, adj. Cf. <er>Fret</er> to rub.]</ety> <def>A
prefix to verbs, having usually the force of a negative or privative. It
often implies also <xex>loss</xex>, <xex>detriment</xex>, or
<xex>destruction</xex>, and sometimes it is intensive, meaning
<xex>utterly</xex>, <xex>quite thoroughly</xex>, as in
<xex>for</xex>bathe.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>For</ent><br/
<hw>For</hw> <pr>(?)</pr>, <pos>prep.</pos> <ety>[AS. <ets>for</ets>,
<ets>fore</ets>; akin to OS. <ets>for</ets>, <ets>fora</ets>,
<ets>furi</ets>, D. <ets>voor</ets>, OHG. <ets>fora</ets>, G.
<ets>vor</ets>, OHG. <ets>furi</ets>, G. <ets>f<uum/r</ets>, Icel.
<ets>fyrir</ets>, Sw. <ets>f<oum/r</ets>, Dan. <ets>for</ets>, adv.
<ets>f<oum/r</ets>, Goth. <ets>fa<uacute/r</ets>,
<ets>fa<uacute/ra</ets>, L. <ets>pro</ets>, Gr. <?/, Skr.
<ets>pra</ets>-. <root/ 202. Cf. <er>Fore</er>, <er>First</er>,
<er>Foremost</er>, <er>Forth</er>, <er>Pro-</er>.]</ety> <def>In the
most general sense, indicating that in consideration of, in view of, or
with reference to, which anything is done or takes place.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Indicating the antecedent cause or occasion of an
action; the motive or inducement accompanying and prompting to an act or
state; the reason of anything; that on account of which a thing is or is
done.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With fiery eyes sparkling <qex>for</qex> very wrath.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>How to choose dogs <qex>for</qex> scent or speed.</q>
<rj><qau>Waller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Now, <qex>for</qex> so many glorious actions done,<br/
<qex>For</qex> peace at home, and <qex>for</qex> the public wealth,<br/
I mean to crown a bowl <qex>for</qex> C<ae/sar's health.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>That which we, <qex>for</qex> our unworthiness, are afraid to
crave, our prayer is, that God, <qex>for</qex> the worthiness of his
Son, would, notwithstanding, vouchsafe to grant.</q>
<rj><qau>Hooker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Indicating the remoter and indirect object of an
act; the end or final cause with reference to which anything is, acts,
serves, or is done.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The oak <qex>for</qex> nothing ill,<br/
The osier good <qex>for</qex> twigs, the poplar <qex>for</qex> the
mill.</q> <rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>It was young counsel <qex>for</qex> the persons, and violent
counsel <qex>for</qex> the matters.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Shall I think the worls was made <qex>for one</qex>,<br/
And men are born <qex>for</qex> kings, as beasts <qex>for</qex> men,<br/
Not <qex>for</qex> protection, but to be devoured?</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>For he writes not <qex>for</qex> money, nor <qex>for</qex>
praise.</q> <rj><qau>Denham.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Indicating that in favor of which, or in promoting
which, anything is, or is done; hence, in behalf of; in favor of; on the
side of; -- opposed to <xex>against</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We can do nothing against the truth, but <qex>for</qex> the
truth.</q> <rj><qau>2 Cor. xiii. 8.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>It is <qex>for</qex> the general good of human society, and
consequently of particular persons, to be true and just; and it is
<qex>for</qex> men's health to be temperate.</q>
<rj><qau>Tillotson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Aristotle is <qex>for</qex> poetical justice.</q>
<rj><qau>Dennis.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Indicating that toward which the action of anything
is directed, or the point toward which motion is made; intending to go
to.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We sailed from Peru <qex>for</qex> China and Japan.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Indicating that on place of or instead of which
anything acts or serves, or that to which a substitute, an equivalent, a
compensation, or the like, is offered or made; instead of, or place
of.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And if any mischief follow, then thou shalt give life
<qex>for</qex> life, eye <qex>for</qex> eye, tooth <qex>for</qex> tooth,
hand <qex>for</qex> hand, foot <qex>for</qex> foot.</q> <rj><qau>Ex.
xxi. 23, 24.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Indicating that in the character of or as being
which anything is regarded or treated; to be, or as being.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We take a falling meteor <qex>for</qex> a star.</q>
<rj><qau>Cowley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>If a man can be fully assured of anything <qex>for</qex> a truth,
without having examined, what is there that he may not embrace
<qex>for</qex> tru<?/?</q> <rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Most of our ingenious young men take up some cried-up English
poet for</qex> their model.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>But let her go <qex>for</qex> an ungrateful woman.</q>
<rj><qau>Philips.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>Indicating that instead of which something else
controls in the performing of an action, or that in spite of which
anything is done, occurs, or is; hence, equivalent to
<xex>notwithstanding</xex>, <xex>in spite of</xex>; -- generally
followed by <xex>all</xex>, <xex>aught</xex>, <xex>anything</xex>,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The writer will do what she please <qex>for</qex> all me.</q>
<rj><qau>Spectator.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>God's desertion shall, <qex>for</qex> aught he knows, the next
minute supervene.</q> <rj><qau>Dr. H. More.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>For</qex> anything that legally appears to the contrary, it
may be a contrivance to fright us.</q> <rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>Indicating the space or time through which an action
or state extends; hence, during; in or through the space or time
of.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>For</qex> many miles about<br/
There 's scarce a bush.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Since, hired <qex>for</qex> life, thy servile muse sing.</q>
<rj><qau>prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To guide the sun's bright chariot <qex>for</qex> a day.</q>
<rj><qau>Garth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>Indicating that in prevention of which, or through
fear of which, anything is done.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>We 'll have a bib, <qex>for</qex> spoiling of thy doublet.</q>
<rj><qau>Beau. & Fl.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<cs><p><mcol><col><b>For</b></col>, <it>or</it> <col><b>As
for</b></col></mcol>, <cd>so far as concerns; as regards; with reference
to; -- used parenthetically or independently. See under
<er>As</er>.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>As for</qex> me and my house, we will serve the Lord.</q>
<rj><qau>Josh. xxiv. 15.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>For</qex> me, my stormy voyage at an end,<br/
I to the port of death securely tend.</q>
<rj><qau>Dryden.</qau></rj></p>

<p>-- <col><b>For all that</b></col>, <cd>notwithstanding; in spite
of.</cd> -- <col><b>For all the world</b></col>, <cd>wholly;
exactly.</cd> <ldquo/Whose posy was, <xex>for all the world</xex>, like
cutlers' poetry.<rdquo/ <au>Shak.</au> -- <mcol><col><b>For as much
as</b></col>, <it>or</it> <col><b>Forasmuch as</b></col></mcol>, <cd>in
consideration that; seeing that; since.</cd> -- <col><b>For
by</b></col>. <cd>See <er>Forby</er>, <pos>adv.</pos></cd> --
<col><b>For ever</b></col>, <cd>eternally; at all times. See
<er>Forever</er>.</cd> -- <mcol><col><b>For me</b></col>, <it>or</it>
<col><b>For all me</b></col></mcol>, <cd>as far as regards me.</cd> --
<mcol><col><b>For my life</b></col>, <it>or</it> <col><b>For the life of
me</b></col></mcol>, <cd>if my life depended on it.</cd>
<mark>[Colloq.]</mark> <au>T. Hook.</au> -- <mcol><col><b>For
that</b></col>, <col><b>For the reason that</b></col></mcol>,
<cd>because; since.</cd> <mark>[Obs.]</mark> <ldquo/<xex>For that</xex>
I love your daughter.<rdquo/ <au>Shak.</au> -- <mcol><col><b>For
thy</b></col>, <it>or</it> <col><b>Forthy</b></col></mcol> <ety>[AS.
<ets>for<edh/<ymac/</ets>.]</ety>, <cd>for this; on this account.</cd>
<mark>[Obs.]</mark> <ldquo/Thomalin, have no care <xex>for
thy</xex>.<rdquo/ <au>Spenser.</au> -- <col><b>For to</b></col>, <cd>as
sign of infinitive, in order to; to the end of.</cd> <mark>[Obs., except
as sometimes heard in illiterate speech.]</mark> -- <ldquo/What went ye
out <xex>for to</xex> see?<rdquo/ <au>Luke vii. 25.</au> <see>See
<er>To</er>, <pos>prep.</pos>, 4.</see> -- <col><b>O for</b></col>,
<cd>would that I had; may there be granted; -- elliptically expressing
desire or prayer.</cd> <ldquo/<xex>O for</xex> a muse of fire.<rdquo/
<au>Shak.</au> -- <mcol><col><b>Were it not for</b></col>, <it>or</it>
<col><b>If it were not for</b></col></mcol>, <cd>leaving out of account;
but for the presence or action of.</cd> <ldquo/Moral consideration can
no way move the sensible appetite, <xex>were it not for</xex> the
will.<rdquo/ <au>Sir M. Hale.</au><br/
[<source>1913 Webster</source>]</p></cs>

<p><ent>For</ent><br/
<hw>For</hw> <pr>(?)</pr>, <pos>conj.</pos> <sn>1.</sn> <def>Because; by
reason that; for that; indicating, in Old English, the reason of
anything.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And <qex>for</qex> of long that way had walk<eacute/d none,<br/
The vault was hid with plants and bushes hoar.</q>
<rj><qau>Fairfax.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And Heaven defend your good souls, that you think<br/
I will your serious and great business scant,<br/
<qex>For</qex> she with me.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Since; because; introducing a reason of something
before advanced, a cause, motive, explanation, justification, or the
like, of an action related or a statement made. It is logically nearly
equivalent to <xex>since</xex>, or <xex>because</xex>, but connects less
closely, and is sometimes used as a very general introduction to
something suggested by what has gone before.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Give thanks unto the Lord; <qex>for</qex> he is good;
<qex>for</qex> his mercy endureth forever.</q> <rj><qau>Ps. cxxxvi.
1.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Heaven doth with us as we with torches do,<br/
Not light them for themselves; <qex>for</qex> if our virtues<br/
Did not go forth of us, 't were all alike<br/
As if we had them not.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>For because</b></col>, <cd>because.</cd>
<mark>[Obs.]</mark> <ldquo/Nor <xex>for because</xex> they set less
store by their own citizens.<rdquo/ <au>Robynson (More's Utopia).</au>
-- <col><b>For why</b></col>. <sd>(a)</sd> <cd>Why; for that reason;
wherefore.</cd> <mark>[Obs.]</mark> <sd>(b)</sd> <cd>Because.</cd>
<mark>[Obs.]</mark> <see>See <er>Forwhy</er>.</see></cs></p>

<p><syn><b>Syn.</b> -- See <er>Because</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>For</ent><br/
<hw>For</hw>, <pos>n.</pos> <def>One who takes, or that which is said
on, the affrimative side; that which is said in favor of some one or
something; -- the antithesis of <xex>against</xex>, and commonly used in
connection with it.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>The fors and against</b></col>. <cd>those in favor and
those opposed; the pros and the cons; the advantages and the
disadvantages.</cd> <rj><au>Jane Austen.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forage</ent><br/
<hw>For"age</hw> <pr>(?; 48)</pr>, <pos>n.</pos> <ety>[OF.
<ets>fourage</ets>, F. <ets>fourrage</ets>, fr. <ets>forre</ets>,
<ets>fuerre</ets>, fodder, straw, F. <ets>feurre</ets>, fr. LL.
<ets>foderum</ets>, <ets>fodrum</ets>, of German or Scand, origin; cf.
OHG. <ets>fuotar</ets>, G. <ets>futter</ets>. See <er>Fodder</er> food,
and cf. <er>Foray</er>.]</ety> <sn>1.</sn> <def>The act of foraging;
search for provisions, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He [the lion] from <qex>forage</qex> will incline to play.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>One way a band select from <qex>forage</qex> drives<br/
A herd of beeves, fair oxen and fair kine.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Mawhood completed his <qex>forage</qex> unmolested.</q>
<rj><qau>Marshall.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Food of any kind for animals, especially for horses
and cattle, as grass, pasture, hay, corn, oats.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Forage cap</b></col>. <cd>See under <er>Cap</er>.</cd> --
<col><b>Forage master</b></col> <fld>(Mil.)</fld>, <cd>a person charged
with providing forage and the means of transporting it.</cd>
<au>Farrow.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forage</ent><br/
<hw>For"age</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Foraged</conjf> ; <pos>p. pr. & vb. n.</pos>
<conjf>Foraging</conjf> <pr>(?)</pr>.]</vmorph> <def>To wander or rove
in search of food; to collect food, esp. forage, for horses and cattle
by feeding on or stripping the country; to ravage; to feed on
spoil.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His most mighty father on a hill<br/
Stood smiling to behold his lion's whelp<br/
<qex>Forage</qex> in blood of French nobility.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Foraging ant</b></col> <fld>(Zool.)</fld>, <cd>one of
several species of ants of the genus <gen>Eciton</gen>, very abundant in
tropical America, remarkable for marching in vast armies in search of
food.</cd> -- <col><b>Foraging cap</b></col>, <cd>a forage cap.</cd> --
<col><b>Foraging party</b></col>, <cd>a party sent out after
forage.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forage</ent><br/
<hw>For"age</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To strip of
provisions; to supply with forage; <as>as, to <ex>forage</ex>
steeds</as>.</def> <rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forager</ent><br/
<hw>For"a*ger</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
forages.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foralite</ent><br/
<hw>For"a*lite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>forare</ets> to bore + <ets>-lite</ets>.]</ety> <fld>(Geol.)</fld>
<def>A tubelike marking, occuring in sandstone and other
strata.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foramen</ent><br/
\'d8<hw>Fo*ra"men</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it> L.
<plw>Foramina</plw> <pr>(#)</pr>, E. <plw>Foramines</plw>
<pr>(#)</pr>.</plu> <ety>[L., fr. <ets>forare</ets> to bore,
pierce.]</ety> <def>A small opening, perforation, or orifice; a
fenestra.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Foramen of Monro</b></col> <fld>(Anat.)</fld>, <cd>the
opening from each lateral into the third ventricle of the brain.</cd> --
<col><b>Foramen of Winslow</b></col> <fld>(Anat.)</fld>, <cd>the opening
connecting the sac of the omentum with the general cavity of the
peritoneum.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foraminated</ent><br/
<hw>Fo*ram"i*na`ted</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>foraminatus</ets>.]</ety> <def>Having small opening, or
foramina.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foraminifer</ent><br/
<hw>For`a*min"i*fer</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>One of the <ord>Foraminifera</ord>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foraminifera</ent><br/
\'d8<hw>Fo*ram`i*nif"e*ra</hw> <pr>(?)</pr>, <pos>n. pl.</pos>
<ety>[NL., fr. L. <ets>foramen</ets>, <ets>-aminis</ets>, a foramen +
<ets>ferre</ets> to bear.]</ety> <fld>(Zool.)</fld> <def>An extensive
order of rhizopods which generally have a chambered calcareous shell
formed by several united zooids. Many of them have perforated walls,
whence the name. Some species are covered with sand. See
<er>Rhizophoda</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foraminiferous</ent><br/
<hw>Fo*ram`i*nif"er*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Having small openings, or foramina.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Pertaining to, or composed of,
<ord>Foraminifera</ord>; <as>as, <ex>foraminiferous</ex>
mud</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foraminous</ent><br/
<hw>Fo*ram"i*nous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>foraminosus</ets>.]</ety> <def>Having foramina; full of holes;
porous.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forasmuch</ent><br/
<hw>For`as*much"</hw> <pr>(?)</pr>, <pos>conj.</pos> <def>In
consideration that; seeing that; since; because that; -- followed by
<xex>as</xex>. See under <er>For</er>, <pos>prep.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foray</ent><br/
<hw>For"ay</hw> <pr>(f<ocr/r"<asl/ <it>or</it> f<osl/*r<amac/";
277)</pr>, <pos>n.</pos> <ety>[Another form of <ets>forahe</ets>. Cf.
<er>Forray</er>.]</ety> <def>A sudden or irregular incursion in border
warfare; hence, any irregular incursion for war or spoils; a raid.</def>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The huge Earl Doorm, . . . <br/
Bound on a <qex>foray</qex>, rolling eyes of prey.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foray</ent><br/
<hw>For"ay</hw>, <pos>v. t.</pos> <def>To pillage; to ravage.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He might <qex>foray</qex> our lands.</q> <rj><qau>Sir W.
Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forayer</ent><br/
<hw>For"ay*er</hw> <pr>(? <or/ ?)</pr>, <pos>n.</pos> <def>One who makes
or joins in a foray.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They might not choose the lowland road,<br/
For the Merse <qex>forayers</qex> were abroad.</q> <rj><qau>Sir W.
Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forbade</ent><br/
<hw>For*bade"</hw> <pr>(?)</pr>, <def><pos>imp.</pos> of
<er>Forbid</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forbathe</ent><br/
<hw>For*bathe"</hw>, <pos>v. t.</pos> <def>To bathe.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forbear</ent><br/
<hw>For*bear"</hw> <pr>(f<ocr/r*b<acir/r")</pr>, <pos>n.</pos> <ety>[See
<er>Fore</er>, and <er>Bear</er> to produce.]</ety> <def>An ancestor; a
forefather; -- usually in the plural.</def> <mark>[Scot.]</mark>
<altsp>[Also spelled <asp>forebear</asp>.]</altsp> <ldquo/Your
<xex>forbears</xex> of old.<rdquo/ <rj><au>Sir W. Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forbear</ent><br/
<hw>For*bear"</hw> <pr>(f<ocr/r*b<acir/r")</pr>, <pos>v. i.</pos>
<vmorph>[<pos>imp.</pos> <conjf>Forbore</conjf> <pr>(?)</pr>
(<conjf>Forbare</conjf> <pr>(<?/)</pr>, <mark>[Obs.]</mark>); <pos>p.
p.</pos> <conjf>Forborne</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Forbearing</conjf>.]</vmorph> <ety>[OE.
<ets>forberen</ets>, AS. <ets>forberan</ets>; pref. <ets>for-</ets> +
<ets>beran</ets> to bear. See <er>Bear</er> to support.]</ety>
<sn>1.</sn> <def>To refrain from proceeding; to pause; to
delay.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Shall I go against Ramoth-gilead to battle, or shall I
<qex>forbear</qex>?</q> <rj><qau>1 Kings xxii. 6.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To refuse; to decline; to give no heed.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou shalt speak my words unto them, whether they will hear, or
whether they will <qex>forbear</qex>.</q> <rj><qau>Ezek. ii.
7.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To control one's self when provoked.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The kindest and the happiest pair<br/
Will find occasion to <qex>forbear</qex>.</q>
<rj><qau>Cowper.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Both bear and <qex>forbear</qex>.</q> <rj><qau>Old
Proverb.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forbear</ent><br/
<hw>For*bear"</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To keep away from;
to avoid; to abstain from; to give up; <as>as, to <ex>forbear</ex> the
use of a word of doubtful propriety</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>But let me that plunder <qex>forbear</qex>.</q>
<rj><qau>Shenstone.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The King<br/
In open battle or the tilting field<br/
<qex>Forbore</qex> his own advantage.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To treat with consideration or indulgence.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Forbearing</qex> one another in love.</q> <rj><qau>Eph. iv.
2.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To cease from bearing.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Whenas my womb her burden would <qex>forbear</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forbearance</ent><br/
<hw>For*bear"ance</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
forbearing or waiting; the exercise of patience.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He soon shall find<br/
<qex>Forbearance</qex> no acquittance ere day end.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The quality of being forbearing; indulgence toward
offenders or enemies; long-suffering.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Have a continent <qex>forbearance</qex>, till the speed of his
rage goes slower.</q> <rj><qau>Shak.</qau></rj></p>

<p><syn><b>Syn.</b> -- Abstinence; refraining; lenity;
mildness.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forbearant</ent><br/
<hw>For*bear"ant</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Forbearing.</def>
<mark>[R.]</mark> <rj><au>Carlyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forbearer</ent><br/
<hw>For*bear"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
forbears.</def> <rj><au>Tusser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forbearing</ent><br/
<hw>For*bear"ing</hw>, <pos>a.</pos> <def>Disposed or accustomed to
forbear; patient; long-suffering.</def> --
<wordforms><wf>For*bear"ing*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 582 --></p>

<p><ent>Forbid</ent><br/
<hw>For*bid"</hw> <pr>(f<ocr/r*b<icr/d")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp.</pos> <conjf>Forbade</conjf>
<pr>(f<ocr/r*b<acr/d")</pr>; <pos>p. p.</pos> <conjf>Forbidden</conjf>
<pr>(f<ocr/r*b<icr/d"d'n)</pr> (<conjf>Forbid</conjf>,
<mark>[Obs.]</mark>); <pos>p. pr. & vb. n.</pos>
<conjf>Forbidding</conjf> <pr>(f<ocr/r*b<icr/d"d<icr/ng)</pr>.]</vmorph>
<ety>[OE. <ets>forbeden</ets>, AS. <ets>forbe<oacute/dan</ets>; pref.
<ets>for-</ets> + <ets>be<oacute/dan</ets> to bid; akin to D.
<ets>verbieden</ets>, G. <ets>verbieten</ets>, Icel.
<ets>fyrirbj<omac/<edh/a</ets>, <ets>forbo<edh/a</ets>, Sw.
<ets>f<oum/rbjuda</ets>, Dan. <ets>forbyde</ets>. See <er>Bid</er>,
<pos>v. t.</pos>]</ety> <sn>1.</sn> <def>To command against, or contrary
to; to prohibit; to interdict.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>More than I have said . . . <br/
The leisure and enforcement of the time<br/
<qex>Forbids</qex> to dwell upon.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To deny, exclude from, or warn off, by express
command; to command not to enter.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Have I not <qex>forbid</qex> her my house?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To oppose, hinder, or prevent, as if by an effectual
command; <as>as, an impassable river <ex>forbids</ex> the approach of
the army</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A blaze of glory that <qex>forbids</qex> the sight.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To accurse; to blast.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He shall live a man <qex>forbid</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To defy; to challenge.</def> <mark>[Obs.]</mark>
<rj><au>L. Andrews.</au></rj></p>

<p><syn><b>Syn.</b> -- To prohibit; interdict; hinder; preclude;
withhold; restrain; prevent. See <er>Prohibit</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forbid</ent><br/
<hw>For*bid"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To utter a
prohibition; to prevent; to hinder.</def> <ldquo/I did not or
<xex>forbid</xex>.<rdquo/ <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forbiddance</ent><br/
<hw>For*bid"dance</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
forbidding; prohibition; command or edict against a thing.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>How hast thou yield to transgress<br/
The strict <qex>forbiddance</qex>.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forbidden</ent><br/
<hw>For*bid"den</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Prohibited;
interdicted.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I know no spells, use no <qex>forbidden</qex> arts.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Forbidden fruit</b></col>. <sd>(a)</sd> <cd>Any coveted
unlawful pleasure, -- so called with reference to the forbidden fruit of
the Garden of Eden.</cd> <sd>(b)</sd> <fld>(Bot.)</fld> <cd>A small
variety of shaddock (<spn>Citrus decumana</spn>). The name is given in
different places to several varieties of Citrus fruits.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forbiddenly</ent><br/
<hw>For*bid"den*ly</hw>, <pos>adv.</pos> <def>In a forbidden or unlawful
manner.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forbidder</ent><br/
<hw>For*bid"der</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
forbids.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forbidding</ent><br/
<hw>For*bid"ding</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Repelling
approach; repulsive; raising abhorrence, aversion, or dislike;
disagreeable; prohibiting or interdicting; <as>as, a <ex>forbidding</ex>
aspect; a <ex>forbidding</ex> formality; a <ex>forbidding</ex>
air.</as></def></p>

<p><syn><b>Syn.</b> -- Disagreeable; unpleasant; displeasing; offensive;
repulsive; odious; abhorrent.</syn></p>

<p>-- <wordforms><wf>For*bid"ding*ly</wf>, <pos>adv.</pos> --
<wf>For*bid"ding*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forblack</ent><br/
<hw>For*black"</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Very black.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>As any raven's feathers it shone <qex>forblack</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forboden</ent><br/
<hw>For*bo"den</hw> <pr>(?)</pr>, <mark>obs.</mark> <def><pos>p.
p.</pos> of <er>Forbid</er>.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forbore</ent><br/
<hw>For*bore"</hw> <pr>(?)</pr>, <def><pos>imp.</pos> of
<er>Forbear</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forborne</ent><br/
<hw>For*borne"</hw> <pr>(?)</pr>, <def><pos>p. p.</pos> of
<er>Forbear</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forbruise</ent><br/
<hw>For*bruise"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To bruise
sorely or exceedingly.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>All <qex>forbrosed</qex>, both back and side.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forby</ent><br/
<hw>For*by"</hw> <pr>(?)</pr>, <pos>adv. & prep.</pos> <ety>[See
<er>Foreby</er>.]</ety> <def>Near; hard by; along; past.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>To tell her if her child went ought <qex>forby</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To the intent that ships may pass along <qex>forby</qex> all the
sides of the city without let.</q> <rj><qau>Robynson (More's
Utopia).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forcarve</ent><br/
<hw>For*carve"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To cut
completely; to cut off.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Force</ent><br/
<hw>Force</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[See <er>Farce</er>
to stuff.]</ety> <def>To stuff; to lard; to farce.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Wit larded with malice, and malice <qex>forced</qex> with wit.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Force</ent><br/
<hw>Force</hw>, <pos>n.</pos> <ety>[Of Scand. origin; cf. Icel.
<ets>fors</ets>, <ets>foss</ets>, Dan. <ets>fos</ets>.]</ety> <def>A
waterfall; a cascade.</def> <mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>To see the falls for <qex>force</qex> of the river Kent.</q>
<rj><qau>T. Gray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Force</ent><br/
<hw>Force</hw>, <pos>n.</pos> <ety>[F. <ets>force</ets>, LL.
<ets>forcia</ets>, <ets>fortia</ets>, fr. L. <ets>fortis</ets> strong.
See <er>Fort</er>, <pos>n.</pos>]</ety> <sn>1.</sn> <def>Capacity of
exercising an influence or producing an effect; strength or energy of
body or mind; active power; vigor; might; often, an unusual degree of
strength or energy; especially, power to persuade, or convince, or
impose obligation; pertinency; validity; special signification; <as>as,
the <ex>force</ex> of an appeal, an argument, a contract, or a
term</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He was, in the full <qex>force</qex> of the words, a good man.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Power exerted against will or consent; compulsory
power; violence; coercion; <as>as, by <ex>force</ex> of arms; to take by
<ex>force</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Which now they hold by <qex>force</qex>, and not by right.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Strength or power for war; hence, a body of land or
naval combatants, with their appurtenances, ready for action; -- an
armament; troops; warlike array; -- often in the plural; hence, a body
of men prepared for action in other ways; <as>as, the laboring
<ex>force</ex> of a plantation; the armed
<ex>forces</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Is Lucius general of the <qex>forces</qex>?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Law)</fld> <sd>(a)</sd> <def>Strength or power
exercised without law, or contrary to law, upon persons or things;
violence.</def> <sd>(b)</sd> <def>Validity; efficacy.</def>
<rj><au>Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Physics)</fld> <def>Any action between two bodies
which changes, or tends to change, their relative condition as to rest
or motion; or, more generally, which changes, or tends to change, any
physical relation between them, whether mechanical, thermal, chemical,
electrical, magnetic, or of any other kind; <as>as, the <ex>force</ex>
of gravity; cohesive <ex>force</ex>; centrifugal
<ex>force</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Animal force</b></col> <fld>(Physiol.)</fld>,
<cd>muscular force or energy.</cd> -- <col><b>Catabiotic force</b></col>
<ety>[Gr. <?/ down (intens.) + <?/ life.]</ety> <fld>(Biol.)</fld>,
<cd>the influence exerted by living structures on adjoining cells, by
which the latter are developed in harmony with the primary
structures.</cd> -- <mcol><col><b>Centrifugal force</b></col>,
<col><b>Centripetal force</b></col>, <col><b>Coercive force</b></col>,
etc.</mcol> <cd>See under <er>Centrifugal</er>, <er>Centripetal</er>,
etc.</cd> -- <mcol><col><b>Composition of forces</b></col>,
<col><b>Correlation of forces</b></col>, etc.</mcol> <cd>See under
<er>Composition</er>, <er>Correlation</er>, etc.</cd> -- <col><b>Force
and arms</b></col> <ety>[trans. of L. <ets>vi et armis</ets>]</ety>
<fld>(Law)</fld>, <cd>an expression in old indictments, signifying
<xex>violence</xex>.</cd> -- <mcol><col><b>In force</b></col>,
<it>or</it> <col><b>Of force</b></col></mcol>, <cd>of unimpaired
efficacy; valid; of full virtue; not suspended or reversed.</cd>
<ldquo/A testament is <xex>of force</xex> after men are dead.<rdquo/
<au>Heb. ix. 17.</au> -- <col><b>Metabolic force</b></col>
<fld>(Physiol.)</fld>, <cd>the influence which causes and controls the
metabolism of the body.</cd> -- <col><b>No force</b></col>, <cd>no
matter of urgency or consequence; no account; hence, <xex>to do no
force</xex>, to make no account of; not to heed.</cd>
<mark>[Obs.]</mark> <au>Chaucer.</au> -- <col><b>Of force</b></col>,
<cd>of necessity; unavoidably; imperatively.</cd> <ldquo/Good reasons
must, <xex>of force</xex>, give place to better.<rdquo/ <au>Shak.</au>
-- <col><b>Plastic force</b></col> <fld>(Physiol.)</fld>, <cd>the force
which presumably acts in the growth and repair of the tissues.</cd> --
<col><b>Vital force</b></col> <fld>(Physiol.)</fld>, <cd>that force or
power which is inherent in organization; that form of energy which is
the cause of the vital phenomena of the body, as distinguished from the
<xex>physical forces</xex> generally known.</cd></cs></p>

<p><syn><b>Syn.</b> -- Strength; vigor; might; energy; stress;
vehemence; violence; compulsion; coaction; constraint; coercion.</syn>
-- <usage><er>Force</er>, <er>Strength</er>. <xex>Strength</xex> looks
rather to power as an <xex>inward</xex> capability or energy. Thus we
speak of the <xex>strength</xex> of timber, bodily <xex>strength</xex>,
mental <xex>strength</xex>, <xex>strength</xex> of emotion, etc.
<xex>Force</xex>, on the other hand, looks more to the
<xex>outward</xex>; as, the <xex>force</xex> of gravitation,
<xex>force</xex> of circumstances, <xex>force</xex> of habit, etc. We
do, indeed, speak of <xex>strength</xex> of will and <xex>force</xex> of
will; but even here the former may lean toward the internal tenacity of
purpose, and the latter toward the outward expression of it in action.
But, though the two words do in a few cases touch thus closely on each
other, there is, on the whole, a marked distinction in our use of
<xex>force</xex> and <xex>strength</xex>. <ldquo/<xex>Force</xex> is the
name given, in mechanical science, to whatever produces, or can produce,
motion.<rdquo/</usage> <rj><au>Nichol.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Thy tears are of no <qex>force</qex> to mollify<br/
This flinty man.</q> <rj><qau>Heywood.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>More huge in <qex>strength</qex> than wise in works he was.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Adam and first matron Eve<br/
Had ended now their orisons, and found<br/
<qex>Strength</qex> added from above, new hope to spring<br/
Out of despair.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Force</ent><br/
<hw>Force</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Forced</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Forcing</conjf> <pr>(?)</pr>.]</vmorph> <ety>[OF.
<ets>forcier</ets>, F. <ets>forcer</ets>, fr. LL. <ets>forciare</ets>,
<ets>fortiare</ets>. See <er>Force</er>, <pos>n.</pos>]</ety>
<sn>1.</sn> <def>To constrain to do or to forbear, by the exertion of a
power not resistible; to compel by physical, moral, or intellectual
means; to coerce; <as>as, masters <ex>force</ex> slaves to
labor</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To compel, as by strength of evidence; <as>as, to
<ex>force</ex> conviction on the mind</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To do violence to; to overpower, or to compel by
violence to one's will; especially, to ravish; to violate; to commit
rape upon.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>force</qex> their monarch and insult the court.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I should have <qex>forced</qex> thee soon wish other arms.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>force</qex> a spotless virgin's chastity.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To obtain, overcome, or win by strength; to take by
violence or struggle; specifically, to capture by assault; to storm, as
a fortress; <as>as, to <ex>force</ex> the castle; to <ex>force</ex> a
lock</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To impel, drive, wrest, extort, get, etc., by main
strength or violence; -- with a following adverb, as <xex>along</xex>,
<xex>away</xex>, <xex>from</xex>, <xex>into</xex>, <xex>through</xex>,
<xex>out</xex>, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It stuck so fast, so deeply buried lay<br/
That scarce the victor <qex>forced</qex> the steel away.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>force</qex> the tyrant from his seat by war.</q>
<rj><qau>Sahk.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Ethelbert ordered that none should be <qex>forced</qex> into
religion.</q> <rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To put in force; to cause to be executed; to make
binding; to enforce.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>What can the church <qex>force</qex> more?</q> <rj><qau>J.
Webster.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>To exert to the utmost; to urge; hence, to strain;
to urge to excessive, unnatural, or untimely action; to produce by
unnatural effort; <as>as, to <ex>force</ex> a conceit or metaphor; to
<ex>force</ex> a laugh; to <ex>force</ex> fruits.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>High on a mounting wave my head I bore,<br/
<qex>Forcing</qex> my strength, and gathering to the shore.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <fld>(Whist)</fld> <def>To compel (an adversary or
partner) to trump a trick by leading a suit of which he has
none.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>To provide with forces; to re<eum/nforce; to
strengthen by soldiers; to man; to garrison.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <def>To allow the force of; to value; to care for.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>For me, I <qex>force</qex> not argument a straw.</q>
<rj><qau>Shak.</qau></rj></p>

<p><syn><b>Syn.</b> -- To compel; constrain; oblige; necessitate;
coerce; drive; press; impel.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Force</ent><br/
<hw>Force</hw>, <pos>v. i.</pos> <mark>[Obs. in all the senses.]</mark>
<sn>1.</sn> <def>To use violence; to make violent effort; to strive; to
endeavor.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Forcing</qex> with gifts to win his wanton heart.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To make a difficult matter of anything; to labor; to
hesitate; hence, <xex>to force of</xex>, to make much account of; to
regard.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Your oath once broke, you <qex>force</qex> not to forswear.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I <qex>force</qex> not of such fooleries.</q>
<rj><qau>Camden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To be of force, importance, or weight; to
matter.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It is not sufficient to have attained the name and dignity of a
shepherd, not <qex>forcing</qex> how.</q> <rj><qau>Udall.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forced</ent><br/
<hw>Forced</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Done or produced with
force or great labor, or by extraordinary exertion; hurried; strained;
produced by unnatural effort or pressure; <as>as, a <ex>forced</ex>
style; a <ex>forced</ex> laugh.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Forced draught</b></col>. <cd>See under
<er>Draught</er>.</cd> -- <col><b>Forced march</b></col>
<fld>(Mil.)</fld>, <cd>a march of one or more days made with all
possible speed.</cd></cs></p>

<p>-- <wordforms><wf>For"ced*ly</wf> <pr>(#)</pr>, <pos>adv.</pos> --
<wf>For"ced*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>force-feed</ent><br/
<hw>force-feed</hw> <pos>v. t.</pos> <def>to feed (someone) against his
will, as during a hunger strike.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>force-feed</ent><br/
<hw>force-feed</hw> <pos>n.</pos> <def>a method of lubricating internal
combustion engines in which a pump forces oil into the engine
bearings.</def><br/
<syn><b>Syn. --</b> lubricating system, force-feed lubricating system,
force feed, pressure-feed lubricating system, pressure feed.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Forceful</ent><br/
<hw>Force"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Full of or
processing force; exerting force; mighty.</def> --
<wordforms><wf>Force"ful*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><q>Against the steed he threw<br/
His <qex>forceful</qex> spear.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forceless</ent><br/
<hw>Force"less</hw>, <pos>a.</pos> <def>Having little or no force;
feeble.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>These <qex>forceless</qex> flowers like sturdy trees support
me.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>forcefulness</ent><br/
<hw>forcefulness</hw> <pos>n.</pos> <def>physical energy or
intensity.</def><br/
<syn><b>Syn. --</b> force, strength.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Forcemeat</ent><br/
<hw>Force"meat`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Corrupt. for
<ets>farce-meat</ets>, fr. F. <ets>farce</ets> stuffing. See
<er>Farce</er>, <pos>n.</pos>]</ety> <fld>(Cookery)</fld> <def>Meat
chopped fine and highly seasoned, either served up alone, or used as a
stuffing.</def> <altsp>[Written also <asp>forced
meat</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forcement</ent><br/
<hw>Force"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of forcing;
compulsion.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>It was imposed upon us by constraint;<br/
And will you count such <qex>forcement</qex> treachery?</q> <rj><qau>J.
Webster.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forceps</ent><br/
<hw>For"ceps</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>forceps</ets>, <ets>-cipis</ets>, from the root of
<ets>formus</ets> Hot + <ets>capere</ets> to take; akin to E.
<ets>heave</ets>. Cf. <er>Furnace</er>.]</ety> <sn>1.</sn> <def>A pair
of pinchers, or tongs; an instrument for grasping, holding firmly, or
exerting traction upon, bodies which it would be inconvenient or
impracticable to seize with the fingers, especially one for delicate
operations, as those of watchmakers, surgeons, accoucheurs, dentists,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>The caudal forceps-shaped
appendage of earwigs and some other insects. See
<er>Earwig</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dressing forceps</b></col>. <cd>See under
<er>Dressing</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Force pump</ent><br/
<hw>Force" pump`</hw> <pr>(?)</pr>. <fld>(Mach.)</fld> <sd>(a)</sd>
<def>A pump having a solid piston, or plunger, for drawing and forcing a
liquid, as water, through the valves; in distinction from a pump having
a bucket, or valved piston.</def> <sd>(b)</sd> <def>A pump adapted for
delivering water at a considerable height above the pump, or under a
considerable pressure; in distinction from one which lifts the water
only to the top of the pump or delivers it through a spout. See
<xex>Illust.</xex> of <cref>Plunger pump</cref>, under
<er>Plunger</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forcer</ent><br/
<hw>For"cer</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who,
or that which, forces or drives.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mech.)</fld> <sd>(a)</sd> <def>The solid piston of
a force pump; the instrument by which water is forced in a pump.</def>
<sd>(b)</sd> <def>A small hand pump for sinking pits, draining cellars,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forcible</ent><br/
<hw>For"ci*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. OF.
<ets>forcible</ets> forcible, <ets>forceable</ets> that may be
forced.]</ety> <sn>1.</sn> <def>Possessing force; characterized by
force, efficiency, or energy; powerful; efficacious; impressive;
influential.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>How <qex>forcible</qex> are right words!</q> <rj><qau>Job. vi.
2<?/.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Sweet smells are most <qex>forcible</qex> in dry substances, when
broken.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>But I have reasons strong and <qex>forcible</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>That punishment which hath been sometimes <qex>forcible</qex> to
bridle sin.</q> <rj><qau>Hooker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He is at once elegant and sublime, <qex>forcible</qex> and
ornamented.</q> <rj><qau>Lowth (Transl. )</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Violent; impetuous.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Like mingled streams, more <qex>forcible</qex> when joined.</q>
<rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Using force against opposition or resistance;
obtained by compulsion; effected by force; <as>as, <ex>forcible</ex>
entry or abduction</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In embraces of King James . . . <qex>forcible</qex> and
unjust.</q> <rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Forcible entry and detainer</b></col> <fld>(Law)</fld>,
<cd>the entering upon and taking and withholding of land and tenements
by actual force and violence, and with a strong hand, to the hindrance
of the person having the right to enter.</cd></cs></p>

<p><syn><b>Syn.</b> -- Violent; powerful; strong; energetic; mighty;
potent; weighty; impressive; cogent; influential.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forcible-feeble</ent><br/
<hw>For"ci*ble-fee`ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From
<ets>Feeble</ets>, a character in the Second Part of Shakespeare's
<ldquo/King Henry IV.,<rdquo/ to whom Falstaff derisively applies the
epithet <ldquo/<ets>forcible</ets>.<rdquo/]</ety> <def>Seemingly
vigorous, but really weak or insipid.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He [Prof. Ayton] would purge his book of much offensive matter, if
he struck out epithets which are in the bad taste of the
<qex>forcible-feeble</qex> school.</q> <rj><qau>N. Brit.
Review.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forcibleness</ent><br/
<hw>For"ci*ble*ness</hw>, <pos>n.</pos> <def>The quality of being
forcible.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forcibly</ent><br/
<hw>For"ci*bly</hw>, <pos>adv.</pos> <def>In a forcible
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forcing</ent><br/
<hw>For"cing</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
accomplishing of any purpose violently, precipitately, prematurely, or
with unusual expedition.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Gardening)</fld> <def>The art of raising plants,
flowers, and fruits at an earlier season than the natural one, as in a
hitbed or by the use of artificial heat.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Forcing bed</b></col> <it>or</it> <col><b>Forcing
pit</b></col></mcol>, <cd>a plant bed having an under layer of
fermenting manure, the fermentation yielding bottom heat for forcing
plants; a hotbed.</cd> -- <col><b>Forcing engine</b></col>, <cd>a fire
engine.</cd> -- <col><b>Forcing fit</b></col> <fld>(Mech.)</fld>, <cd>a
tight fit, as of one part into a hole in another part, which makes it
necessary to use considerable force in putting the two parts
together.</cd> -- <col><b>Forcing house</b></col>, <cd>a greenhouse for
the forcing of plants, fruit trees, etc.</cd> -- <col><b>Forcing
machine</b></col>, <cd>a powerful press for putting together or
separating two parts that are fitted tightly one into another, as for
forcing a crank on a shaft, or for drawing off a car wheel from the
axle.</cd> -- <col><b>Forcing pump</b></col>. <cd>See <er>Force
pump</er> <sd>(b)</sd>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forcipal</ent><br/
<hw>For"ci*pal</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Forked or branched
like a pair of forceps; constructed so as to open and shut like a pair
of forceps.</def> <rj><au>Sir T. Browne.</au></rj></p>

<p><ent>Forcipated</ent><br/
<ent>Forcipate</ent><br/
<mhw>{ <hw>For"ci*pate</hw> <pr>(?)</pr>, <hw>For"ci*pa`ted</hw>
<pr>(?)</pr> }</mhw>, <pos>a.</pos> <def>Like a pair of forceps; <as>as,
a <ex>forcipated</ex> mouth</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forcipation</ent><br/
<hw>For`ci*pa"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Torture by
pinching with forceps or pinchers.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forcite</ent><br/
<hw>For"cite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From 3d
<er>Force</er>, <pos>n.</pos>]</ety> <fld>(Chem.)</fld> <def>A gelatin
dynamite in which the dope is composed largely of sodium
nitrate.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Forcut</ent><br/
<hw>For*cut"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To cut completely;
to cut off.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ford</ent><br/
<hw>Ford</hw> <pr>(f<omac/rd)</pr>, <pos>n.</pos> <ety>[AS.
<ets>ford</ets>; akin to G. <ets>furt</ets>, Icel.
<ets>fj<oum/r<edh/r</ets> bay, and to E. <ets>fare</ets>. <root/78. See
<er>Fare</er>, <pos>v. i.</pos>, and cf. <er>Frith</er> arm of the
sea.]</ety> <sn>1.</sn> <def>A place in a river, or other water, where
it may be passed by man or beast on foot, by wading.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He swam the Esk river where <qex>ford</qex> there was none.</q>
<rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A stream; a current.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With water of the <qex>ford</qex><br/
Or of the clouds.</q> <rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Permit my ghost to pass the Stygian <qex>ford</qex>.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ford</ent><br/
<hw>Ford</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Forded</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Fording</conjf>.]</vmorph> <def>To pass or cross, as a river or
other water, by wading; to wade through.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His last section, which is no deep one, remains only to be
<qex>forted</qex>.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fordable</ent><br/
<hw>Ford"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of being
forded.</def> -- <wordforms><wf>Ford"a*ble*ness</wf>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fordless</ent><br/
<hw>Ford"less</hw>, <pos>a.</pos> <def>Without a ford.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A deep and <qex>fordless</qex> river.</q>
<rj><qau>Mallock.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fordo</ent><br/
<hw>For*do"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[OE.
<ets>fordon</ets>, AS. <ets>ford<?/n</ets>; pref. <ets>for-</ets> +
<ets>d<?/n</ets> to do. See <er>For-</er>, and <er>Do</er>, <pos>v.
i.</pos>]</ety> <sn>1.</sn> <def>To destroy; to undo; to ruin.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>This is the night<br/
That either makes me or <qex>fordoes</qex> me quite.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To overcome with fatigue; to exhaust.</def>
<rj><au>M. Arnold.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>All with weary task <qex>fordone</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fordone</ent><br/
<hw>For*done"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Fordo</er>.]</ety> <def>Undone; ruined.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fordrive</ent><br/
<hw>For*drive"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To drive about;
to drive here and there.</def> <mark>[Obs.]</mark> <rj><au>Rom. of
R.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fordrunken</ent><br/
<hw>For*drunk"en</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Utterly drunk;
very drunk.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fordry</ent><br/
<hw>For*dry"</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Entirely dry;
withered.</def> <mark>[Obs.]</mark> <ldquo/A tree
<xex>fordry</xex>.<rdquo/ <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fordwine</ent><br/
<hw>For*dwine"</hw> <pr>(f<ocr/r*dw<imac/n")</pr>, <pos>v. i.</pos>
<def>To dwindle away; to disappear.</def> <mark>[Obs.]</mark>
<rj><au>Rom of R.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fore</ent><br/
<hw>Fore</hw> <pr>(f<omac/r)</pr>, <pos>n.</pos> <ety>[AS.
<ets>f<omac/r</ets>, fr. <ets>faran</ets> to go. See <er>Fare</er>,
<pos>v. i.</pos>]</ety> <def>Journey; way; method of proceeding.</def>
<mark>[Obs.]</mark> <ldquo/Follow him and his <xex>fore</xex>.<rdquo/
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 583 --></p>

<p><ent>Fore</ent><br/
<hw>Fore</hw>, <pos>adv.</pos> <ety>[AS. <ets>fore</ets>, adv. & prep.,
another form of <ets>for</ets>. See <er>For</er>, and cf.
<er>Former</er>, <er>Foremost</er>.]</ety> <sn>1.</sn> <def>In the part
that precedes or goes first; -- opposed to <xex>aft</xex>,
<xex>after</xex>, <xex>back</xex>, <xex>behind</xex>, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Formerly; previously; afore.</def> <mark>[Obs. or
Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The eyes, <qex>fore</qex> duteous, now converted are.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Naut.)</fld> <def>In or towards the bows of a
ship.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fore and aft</b></col> <fld>(Naut.)</fld>, <cd>from stem
to stern; lengthwise of the vessel; -- in distinction from
<xex>athwart</xex>.</cd> <au>R. H. Dana, Jr.</au> --
<col><b>Fore-and-aft rigged</b></col> <fld>(Naut.)</fld>, <cd>not rigged
with square sails attached to yards, but with sails bent to gaffs or set
on stays in the midship line of the vessel. See <er>Schooner</er>,
<er>Sloop</er>, <er>Cutter</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fore</ent><br/
<hw>Fore</hw> <pr>(f<omac/r)</pr>, <pos>a.</pos> <ety>[See
<er>Fore</er>, <pos>adv.</pos>]</ety> <def>Advanced, as compared with
something else; toward the front; being or coming first, in time, place,
order, or importance; preceding; anterior; antecedent; earlier; forward;
-- opposed to <ant>back</ant> or <ant>behind</ant>; <as>as, the
<ex>fore</ex> part of a garment; the <ex>fore</ex> part of the day; the
<ex>fore</ex> and of a wagon.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>The free will of the subject is preserved, while it is directed by
the <qex>fore</qex> purpose of the state.</q>
<rj><qau>Southey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Fore</xex> is much used adjectively or in
composition.</note><br/
[<source>1913 Webster</source>]</p>

<cs><p><col><b>Fore bay</b></col>, <cd>a reservoir or canal between a
mill race and a water wheel; the discharging end of a pond or mill
race.</cd> -- <col><b>Fore body</b></col> <fld>(Shipbuilding)</fld>,
<cd>the part of a ship forward of the largest cross-section,
distinguished from <contr>middle body</contr> and <contr>after
body</contr>.</cd> -- <col><b>Fore boot</b></col>, <cd>a receptacle in
the front of a vehicle, for stowing baggage, etc.</cd> -- <col><b>Fore
bow</b></col>, <cd>the pommel of a saddle.</cd> <au>Knight.</au> --
<col><b>Fore cabin</b></col>, <cd>a cabin in the fore part of a ship,
usually with inferior accommodations.</cd> -- <col><b>Fore
carriage</b></col>. <sd>(a)</sd> <cd>The forward part of the running
gear of a four-wheeled vehicle.</cd> <sd>(b)</sd> <cd>A small carriage
at the front end of a plow beam.</cd> -- <col><b>Fore course</b></col>
<fld>(Naut.)</fld>, <cd>the lowermost sail on the foremost of a
square-rigged vessel; the foresail. See <xex>Illust.</xex> under
<er>Sail</er>.</cd> -- <col><b>Fore door</b></col>. <cd>Same as
<er>Front door</er>.</cd> -- <col><b>Fore edge</b></col>, <cd>the front
edge of a book or folded sheet, etc.</cd> -- <col><b>Fore
elder</b></col>, <cd>an ancestor.</cd> <mark>[Prov. Eng.]</mark> --
<col><b>Fore end</b></col>. <sd>(a)</sd> <cd>The end which precedes; the
earlier, or the nearer, part; the beginning.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>I have . . . paid<br/
More pious debts to heaven, than in all<br/
The <qex>fore end</qex> of my time.</q> <rj><qau>Shak.</qau></rj></p>

<p><sd>(b)</sd> <cd>In firearms, the wooden stock under the barrel,
forward of the trigger guard, or breech frame.</cd> -- <col><b>Fore
girth</b></col>, <cd>a girth for the fore part (of a horse, etc.); a
martingale.</cd> -- <col><b>Fore hammer</b></col>, <cd>a sledge hammer,
working alternately, or in time, with the hand hammer.</cd> --
<col><b>Fore leg</b></col>, <cd>one of the front legs of a quadruped, or
multiped, or of a chair, settee, etc.</cd> -- <col><b>Fore
peak</b></col> <fld>(Naut.)</fld>, <cd>the angle within a ship's bows;
the portion of the hold which is farthest forward.</cd> -- <col><b>Fore
piece</b></col>, <cd>a front piece, as the flap in the fore part of a
sidesaddle, to guard the rider's dress.</cd> -- <col><b>Fore
plane</b></col>, <cd>a carpenter's plane, in size and use between a jack
plane and a smoothing plane.</cd> <au>Knight.</au> -- <col><b>Fore
reading</b></col>, <cd>previous perusal.</cd> <mark>[Obs.]</mark>
<au>Hales.</au> -- <col><b>Fore rent</b></col>, <cd>in Scotland, rent
payable before a crop is gathered.</cd> -- <col><b>Fore sheets</b></col>
<fld>(Naut.)</fld>, <cd>the forward portion of a rowboat; the space
beyond the front thwart. See <er>Stern sheets</er>.</cd> -- <col><b>Fore
shore</b></col>. <sd>(a)</sd> <cd>A bank in advance of a sea wall, to
break the force of the surf.</cd> <sd>(b)</sd> <cd>The seaward
projecting, slightly inclined portion of a breakwater.</cd>
<au>Knight.</au> <sd>(c)</sd> <cd>The part of the shore between high and
low water marks.</cd> -- <col><b>Fore sight</b></col>, <cd>that one of
the two sights of a gun which is near the muzzle.</cd> -- <col><b>Fore
tackle</b></col> <fld>(Naut.)</fld>, <cd>the tackle on the foremast of a
ship.</cd> -- <col><b>Fore topmast</b></col>. <fld>(Naut.)</fld> <cd>See
<er>Fore-topmast</er>, in the Vocabulary.</cd> -- <col><b>Fore
wind</b></col>, <cd>a favorable wind.</cd> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Sailed on smooth seas, by <qex>fore winds</qex> borne.</q>
<rj><qau>Sandys.</qau></rj></p>

<p> -- <col><b>Fore world</b></col>, <cd>the antediluvian world.</cd>
<mark>[R.]</mark> <au>Southey.</au><br/
[<source>1913 Webster</source>]</p></cs>

<p><ent>Fore</ent><br/
<hw>Fore</hw>, <pos>n.</pos> <def>The front; hence, that which is in
front; the future.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>At the fore</b></col> <fld>(Naut.)</fld>, <cd>at the fore
royal masthead; -- said of a flag, so raised as a signal for sailing,
etc.</cd> -- <col><b>To the fore</b></col>. <sd>(a)</sd> <cd>In advance;
to the front; to a prominent position; in plain sight; in readiness for
use.</cd> <sd>(b)</sd> <cd>In existence; alive; not worn out, lost, or
spent, as money, etc.</cd> <mark>[Irish]</mark> <ldquo/While I am
<xex>to the fore</xex>.<rdquo/ <au>W. Collins.</au> <ldquo/How many
captains in the regiment had two thousand pounds <xex>to the
fore</xex>?<rdquo/ <au>Thackeray.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fore</ent><br/
<hw>Fore</hw>, <pos>prep.</pos> <def>Before; -- sometimes written
<xex>'fore</xex> as if a contraction of <xex>afore</xex> or
<xex>before</xex>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foreadmonish</ent><br/
<hw>Fore`ad*mon"ish</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To admonish
beforehand, or before the act or event.</def> <rj><au>Bp.
Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foreadvise</ent><br/
<hw>Fore`ad*vise"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To advise or
counsel before the time of action, or before the event.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foreallege</ent><br/
<hw>Fore`al*lege"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Forealleged</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Forealleging</conjf> <pr>(?)</pr>.]</vmorph> <def>To
allege or cite before.</def> <rj><au>Fotherby.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foreappoint</ent><br/
<hw>Fore`ap*point"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To set,
order, or appoint, beforehand.</def> <rj><au>Sherwood.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foreappointment</ent><br/
<hw>Fore`ap*point"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Previous
appointment; preordinantion.</def> <rj><au>Sherwood.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forearm</ent><br/
<hw>Fore*arm"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To arm or prepare
for attack or resistance before the time of need.</def>
<rj><au>South.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forearm</ent><br/
<hw>Fore"arm`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Anat.)</fld>
<def>That part of the arm or fore limb between the elbow and wrist; the
antibrachium.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forebeam</ent><br/
<hw>Fore"beam`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The breast beam of
a loom.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forebear</ent><br/
<hw>Fore*bear"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An ancestor. See
<er>Forbear</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forebode</ent><br/
<hw>Fore*bode"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Foreboded</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Foreboding</conjf>.]</vmorph> <ety>[AS. <ets>forebodian</ets>;
<ets>fore</ets> + <ets>bodian</ets> to announce. See <er>Bode</er>
<pos>v. t.</pos>]</ety> <sn>1.</sn> <def>To foretell.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To be prescient of (some ill or misfortune); to have
an inward conviction of, as of a calamity which is about to happen; to
augur despondingly.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His heart <qex>forebodes</qex> a mystery.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Sullen, desponding, and <qex>foreboding</qex> nothing but wars and
desolation, as the certain consequence of C<ae/sar's death.</q>
<rj><qau>Middleton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I have a sort of <qex>foreboding</qex> about him.</q> <rj><qau>H.
James.</qau></rj></p>

<p><syn><b>Syn.</b> -- To foretell; predict; prognosticate; augur;
presage; portend; betoken.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forebode</ent><br/
<hw>Fore*bode"</hw>, <pos>v. i.</pos> <def>To foretell; to presage; to
augur.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If I <qex>forebode</qex> aright.</q>
<rj><qau>Hawthorne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forebode</ent><br/
<hw>Fore*bode"</hw>, <pos>n.</pos> <def>Prognostication; presage.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forebodement</ent><br/
<hw>Fore*bode"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
foreboding; the thing foreboded.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foreboder</ent><br/
<hw>Fore*bod"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
forebodes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foreboding</ent><br/
<hw>Fore*bod"ing</hw>, <pos>n.</pos> <def>Presage of coming ill;
expectation of misfortune.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forebodingly</ent><br/
<hw>Fore*bod"ing*ly</hw>, <pos>adv.</pos> <def>In a foreboding
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forebrace</ent><br/
<hw>Fore"brace`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Naut.)</fld>
<def>A rope applied to the fore yardarm, to change the position of the
foresail.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forebrain</ent><br/
<hw>Fore"brain`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Anat.)</fld>
<def>The anterior of the three principal divisions of the brain,
including the prosencephalon and thalamencephalon. Sometimes restricted
to the prosencephalon only. See <er>Brain</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foreby</ent><br/
<hw>Fore*by"</hw> <pr>(?)</pr>, <pos>prep.</pos> <ety>[<ets>Fore</ets> +
<ets>by</ets>.]</ety> <def>Near; hard by; along; past. See
<er>Forby</er>.</def> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forecast</ent><br/
<hw>Fore*cast"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <sn>1.</sn> <def>To
plan beforehand; to scheme; to project.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He shall <qex>forecast</qex> his devices against the
strongholds.</q> <rj><qau>Dan. xi. 24.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To foresee; to calculate beforehand, so as to
provide for; <as>as, to <ex>forecast</ex> the weather; to
<ex>forecast</ex> prices</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It is wisdom to consider the end of things before we embark, and
to <qex>forecast</qex> consequences.</q>
<rj><qau>L'Estrange.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forecast</ent><br/
<hw>Fore*cast"</hw>, <pos>v. i.</pos> <def>To contrive or plan
beforehand.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If it happen as I did <qex>forecast</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forecast</ent><br/
<hw>Fore"cast</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Previous contrivance
or determination; predetermination.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He makes this difference to arise from the <qex>forecast</qex> and
predetermination of the gods themselves.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A calculation predicting future events; the
foresight of consequences, and provision against them; prevision;
premeditation; <as>as, the weather <ex>forecast</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His calm, deliberate <qex>forecast</qex> better fitted him for the
council than the camp.</q> <rj><qau>Prescott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forecaster</ent><br/
<hw>Fore*cast"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
forecast.</def> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>forecasting</ent><br/
<hw>fore"cast*ing</hw> <pos>n.</pos> <def>The process of calculating and
predicting future events, usually based on extrapolation from past
experience, and with varying degress of uncertainty.</def><br/
<syn><b>Syn. --</b> prediction, foretelling.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Forecastle</ent><br/
<hw>Fore"cas`tle</hw> <pr>(?; <xex>sailors say</xex> <?/)</pr>,
<pos>n.</pos> <fld>(Naut.)</fld> <sd>(a)</sd> <def>A short upper deck
forward, formerly raised like a castle, to command an enemy's
decks.</def> <sd>(b)</sd> <def>That part of the upper deck of a vessel
forward of the foremast, or of the after part of the fore
channels.</def> <sd>(c)</sd> <def>In merchant vessels, the forward part
of the vessel, under the deck, where the sailors live.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forechosen</ent><br/
<hw>Fore`cho"sen</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Chosen
beforehand.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forecited</ent><br/
<hw>Fore"cit`ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Cited or quoted
before or above.</def> <rj><au>Arbuthnot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foreclose</ent><br/
<hw>Fore*close"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Foreclosed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Foreclosing</conjf> <pr>(?)</pr>.]</vmorph> <ety>[F.
<ets>forclos</ets>, p. p. of <ets>forclore</ets> to exclude; OF.
<ets>fors</ets>, F. <ets>hors</ets>, except, outside (fr. L.
<ets>foris</ets> outside) + F. <ets>clore</ets> to close. See
<er>Foreign</er>, and <er>Close</er>, <pos>v. t.</pos>]</ety> <def>To
shut up or out; to preclude; to stop; to prevent; to bar; to
exclude.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The embargo with Spain <qex>foreclosed</qex> this trade.</q>
<rj><qau>Carew.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To foreclose a mortgager</b></col> <fld>(Law)</fld>,
<cd>to cut him off by a judgment of court from the power of redeeming
the mortgaged premises, termed his <xex>equity of redemption</xex>.</cd>
-- <col><b>To foreclose a mortgage</b></col>, <cd>(not technically
correct, but often used to signify) the obtaining a judgment for the
payment of an overdue mortgage, and the exposure of the mortgaged
property to sale to meet the mortgage debt.</cd>
<rj><au>Wharton.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foreclosure</ent><br/
<hw>Fore*clo"sure</hw> <pr>(?; 135)</pr>, <pos>n.</pos> <def>The act or
process of foreclosing; a proceeding which bars or extinguishes a
mortgager's right of redeeming a mortgaged estate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foreconceive</ent><br/
<hw>Fore`con*ceive"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To
preconceive; to imagine beforehand.</def> <mark>[Obs.]</mark>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foredate</ent><br/
<hw>Fore*date"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To date before
the true time; to antedate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foredeck</ent><br/
<hw>Fore"deck`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Naut.)</fld>
<def>The fore part of a deck, or of a ship.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foredeem</ent><br/
<hw>Fore*deem"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To recognize or
judge in advance; to forebode.</def> <mark>[Obs.]</mark>
<rj><au>Udall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Laugh at your misery, as <qex>foredeeming</qex> you<br/
An idle meteor.</q> <rj><qau>J. Webster.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foredeem</ent><br/
<hw>Fore*deem"</hw>, <pos>v. i.</pos> <ety>[Cf.
<er>Foredoom</er>.]</ety> <def>To know or discover beforehand; to
foretell.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Which [maid] could guess and <qex>foredeem</qex> of things past,
present, and to come.</q> <rj><qau>Genevan Test.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foredesign</ent><br/
<hw>Fore`de*sign"</hw> <pr>(? <or/ ?)</pr>, <pos>v. t.</pos> <def>To
plan beforehand; to intend previously.</def>
<rj><au>Cheyne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foredetermine</ent><br/
<hw>Fore`de*ter"mine</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To
determine or decree beforehand.</def> <rj><au>Bp. Hopkins.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foredispose</ent><br/
<hw>Fore`dis*pose"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To bestow
beforehand.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>King James had by promise <qex>foredisposed</qex> the place on the
Bishop of Meath.</q> <rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foredoom</ent><br/
<hw>Fore*doom"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Cf.
<er>Foredeem</er>.]</ety> <def>To doom beforehand; to
predestinate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou art <qex>foredoomed</qex> to view the Stygian state.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foredoom</ent><br/
<hw>Fore"doom`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Doom or sentence
decreed in advance.</def> <ldquo/A dread <xex>foredoom</xex> ringing in
the ears of the guilty adult.<rdquo/ <rj><au>Southey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forefather</ent><br/
<hw>Fore"fa`ther</hw> <pr>(?; 277)</pr>, <pos>n.</pos> <def>One who
precedes another in the line of genealogy in any degree, but usually in
a remote degree; an ancestor.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Respecting your <qex>forefathers</qex>, you would have been taught
to respect yourselves.</q> <rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Forefathers' Day</b></col>, <cd>the anniversary of the
day (December 21) on which the Pilgrim Fathers landed at Plymouth,
Massachusetts (1620). On account of a mistake in reckoning the change
from Old Style to New Style, it has generally been celebrated on the
22d.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forefeel</ent><br/
<hw>Fore*feel"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To feel
beforehand; to have a presentiment of.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>As when, with unwieldy waves, the great sea <qex>forefeels</qex>
winds.</q> <rj><qau>Chapman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forefence</ent><br/
<hw>Fore`fence"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Defense in
front.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forefend</ent><br/
<hw>Fore*fend"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[OE.
<ets>forfenden</ets>; pref. <ets>for-</ets> + <ets>fenden</ets> to fend.
See <er>Fend</er>, <pos>v. t.</pos>]</ety> <def>To hinder; to fend off;
to avert; to prevent the approach of; to forbid or prohibit. See
<er>Forfend</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>God <qex>forefend</qex> it should ever be recorded in our
history.</q> <rj><qau>Landor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>It would be a far better work . . . to <qex>forefend</qex> the
cruelty.</q> <rj><qau>I. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forefinger</ent><br/
<hw>Fore"fin`ger</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The finger next
to the thumb; the index finger.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foreflow</ent><br/
<hw>Fore*flow"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To flow
before.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forefoot</ent><br/
<hw>Fore"foot`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One of
the anterior feet of a quadruped or multiped; -- usually written
<asp>fore foot</asp>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Shipbuilding)</fld> <def>A piece of timber which
terminates the keel at the fore end, connecting it with the lower end of
the stem.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forefront</ent><br/
<hw>Fore"front`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Foremost part or
place.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Set ye Uriah in the <qex>forefront</qex> of the hottest
battle.</q> <rj><qau>2 Sam. xi. 15.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Socrates, Plato, Aristotle, standing in the <qex>forefront</qex>
for all time, the masters of those who know.</q> <rj><qau>J. C.
Shairp.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foregame</ent><br/
<hw>Fore"game`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A first game; first
plan.</def> <mark>[Obs.]</mark> <rj><au>Whitlock.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foreganger</ent><br/
<hw>Fore"gang`er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Prop., a goer
before cf. G. <ets>voreg<aum/nger</ets>. See <er>Fore</er>, and
<er>Gang</er>.]</ety> <fld>(Naut.)</fld> <def>A short rope grafted on a
harpoon, to which a longer line may be attached.</def>
<rj><au>Totten.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foregather</ent><br/
<hw>Fore*gath"er</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>Same as
<er>Forgather</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foregift</ent><br/
<hw>Fore"gift`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Law)</fld> <def>A
premium paid by a lessee when taking his lease.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foregleam</ent><br/
<hw>Fore"gleam`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An antecedent or
premonitory gleam; a dawning light.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>foregleams</qex> of wisdom.</q>
<rj><qau>Whittier.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forego</ent><br/
<hw>Fore*go"</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp.</pos> <conjf>Forewent 2</conjf>; <pos>p. p.</pos>
<conjf>Foregone</conjf> <pr>(?; 115)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Foregoing</conjf>.]</vmorph> <ety>[See <er>Forgo</er>.]</ety>
<sn>1.</sn> <def>To quit; to relinquish; to leave.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Stay at the third cup, or <qex>forego</qex> the place.</q>
<rj><qau>Herbert.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To relinquish the enjoyment or advantage of; to give
up; to resign; to renounce; -- said of a thing already enjoyed, or of
one within reach, or anticipated.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>All my patrimony,,<br/
If need be, I am ready to <qex>forego</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Thy lovers must their promised heaven <qex>forego</qex>.</q>
<rj><qau>Keble.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>[He] never <qex>forewent</qex> an opportunity of honest
profit.</q> <rj><qau>R. L. Stevenson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Forgo</xex> is the better spelling etymologically,
but the word has been confused with <er>Forego</er>, to go
before.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forego</ent><br/
<hw>Fore*go"</hw>, <pos>v. t.</pos> <ety>[AS. <ets>foreg<amac/n</ets>;
<ets>fore</ets> + <ets>g<amac/n</ets> to go; akin to G.
<ets>vorgehen</ets> to go before, precede. See <er>Go</er>, <pos>v.
i.</pos>]</ety> <def>To go before; to precede; -- used especially in the
present and past participles.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Pleasing remembrance of a thought <qex>foregone</qex>.</q>
<rj><qau>Wordsworth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>For which the very mother's face <qex>forewent</qex><br/
The mother's special patience.</q> <rj><qau>Mrs.
Browning.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Foregone conclusion</b></col>, <cd>a conclusion which has
preceded argument or examination; a predetermined
conclusion.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foregoer</ent><br/
<hw>Fore*go"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who
goes before another; a predecessor; hence, an ancestor; a
progenitor.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A purveyor of the king; -- so called, formerly, from
<xex>going before</xex> to provide for his household.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foregoer</ent><br/
<hw>Fore*go"er</hw>, <pos>n.</pos> <ety>[Etymologically
<ets>forgoer</ets>.]</ety> <def>One who forbears to enjoy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>foregone</ent><br/
<hw>foregone</hw> <pos>adj.</pos> <def>past; -- used of time; <as>as,
<ex>foregone</ex> summers</as>. Contrassted to
<contr>present</contr>.</def><br/
<syn><b>Syn. --</b> bygone, bypast, departed, gone.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>foregone conclusion</ent><br/
<hw>foregone conclusion</hw> <pos>n.</pos> <def>An inevitable outcome; a
certain result; a certainty.</def><br/
[<source>PJC</source>]</p>

<p><ent>Foreground</ent><br/
<hw>Fore"ground`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>On a painting,
and sometimes in a bas-relief, mosaic picture, or the like, that part of
the scene represented, which is nearest to the spectator, and therefore
occupies the lowest part of the work of art itself. Cf.
<er>Distance</er>, <pos>n.</pos>, 6.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foreguess</ent><br/
<hw>Fore*guess"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To
conjecture.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foregut</ent><br/
<hw>Fore"gut`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Anat.)</fld>
<def>The anterior part of the alimentary canal, from the mouth to the
intestine, or to the entrance of the bile duct.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forehand</ent><br/
<hw>Fore"hand`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>All
that part of a horse which is before the rider.</def>
<rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The chief or most important part.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Superiority; advantage; start; precedence.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And, but for ceremony, such a wretch . . . <br/
Had the <qex>forehand</qex> and vantage of a king.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forehand</ent><br/
<hw>Fore"hand`</hw>, <pos>a.</pos> <def>Done beforehand;
anticipative.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And so extenuate the <qex>forehand</qex> sin.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forehanded</ent><br/
<hw>Fore"hand`ed</hw>, <pos>a.</pos> <sn>1.</sn> <def>Early; timely;
seasonable.</def> <ldquo/<xex>Forehanded</xex> care.<rdquo/ <rj><au>Jer.
Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Beforehand with one's needs, or having resources in
advance of one's necessities; in easy circumstances; <as>as, a
<ex>forehanded</ex> farmer</as>.</def> <mark>[U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Formed in the forehand or fore parts.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A substantial, true-bred beast, bravely <qex>forehanded</qex>.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forehead</ent><br/
<hw>Fore"head</hw> <pr>(?; 277)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
front of that part of the head which incloses the brain; that part of
the face above the eyes; the brow.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The aspect or countenance; assurance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To look with <qex>forehead</qex> bold and big enough<br/
Upon the power and puissance of the king.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The front or fore part of anything.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Flames in the <qex>forehead</qex> of the morning sky.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>So rich advantage of a promised glory<br/
As smiles upon the <qex>forehead</qex> of this action.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forehear</ent><br/
<hw>Fore*hear"</hw> <pr>(?)</pr>, <pos>v. i. & t.</pos> <def>To hear
beforehand.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forehearth</ent><br/
<hw>Fore"hearth`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Metal.)</fld>
<def>The forward extension of the hearth of a blast furnace under the
tymp.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forehend</ent><br/
<hw>Fore*hend"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>See
<er>Forhend</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forehew</ent><br/
<hw>Fore*hew"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To hew or cut in
front.</def> <mark>[Obs.]</mark> <rj><au>Sackville.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forehold</ent><br/
<hw>Fore"hold`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Naut.)</fld>
<def>The forward part of the hold of a ship.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foreholding</ent><br/
<hw>Fore*hold"ing</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Ominous
foreboding; superstitious prognostication.</def> <mark>[Obs.]</mark>
<rj><au>L'Estrange.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forehook</ent><br/
<hw>Fore"hook`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Naut.)</fld>
<def>A piece of timber placed across the stem, to unite the bows and
strengthen the fore part of the ship; a breast hook.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foreign</ent><br/
<hw>For"eign</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OE.
<ets>forein</ets>, F. <ets>forain</ets>, LL. <ets>foraneus</ets>, fr. L.
<ets>foras</ets>, <ets>foris</ets>, out of doors, abroad, without; akin
to <ets>fores</ets> doors, and E. <ets>door</ets>. See <er>Door</er>,
and cf. <er>Foreclose</er>, <er>Forfeit</er>, <er>Forest</er>,
<er>Forum</er>.]</ety> <sn>1.</sn> <def>Outside; extraneous; separated;
alien; <as>as, a <ex>foreign</ex> country; a <ex>foreign</ex>
government.</as></def> <ldquo/<xex>Foreign</xex> worlds.<rdquo/
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Not native or belonging to a certain country; born
in or belonging to another country, nation, sovereignty, or locality;
<as>as, a <ex>foreign</ex> language; <ex>foreign</ex> fruits.</as></def>
<ldquo/Domestic and <xex>foreign</xex> writers.<rdquo/
<rj><au>Atterbury.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Hail, <qex>foreign</qex> wonder!<br/
Whom certain these rough shades did never breed.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Remote; distant; strange; not belonging; not
connected; not pertaining or pertient; not appropriate; not harmonious;
not agreeable; not congenial; -- with <xex>to</xex> or <xex>from</xex>;
<as>as, <ex>foreign</ex> to the purpose; <ex>foreign</ex> to one's
nature.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>This design is not <qex>foreign</qex> from some people's
thoughts.</q> <rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Held at a distance; excluded; exiled.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Kept him a <qex>foreign</qex> man still; which so grieved him,<br/
That he ran mad and died.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Foreign attachment</b></col> <fld>(Law)</fld>, <cd>a
process by which the property of a foreign or absent debtor is attached
for the satisfaction of a debt due from him to the plaintiff; an
attachment of the goods, effects, or credits of a debtor in the hands of
a third person; -- called in some States <xex>trustee</xex>, in others
<xex>factorizing</xex>, and in others <xex>garnishee</xex> process.</cd>
<au>Kent.</au> <au>Tomlins.</au> <au>Cowell.</au> -- <col><b>Foreign
bill</b></col>, <cd>a bill drawn in one country, and payable in another,
as distinguished from an inland bill, which is one drawn and payable in
the same country. In this latter, as well as in several other points of
view, the different States of the United States are foreign to each
other. See <er>Exchange</er>, <pos>n.</pos>, 4.</cd> <au>Kent.</au>
<au>Story.</au> -- <col><b>Foreign body</b></col> <fld>(Med.)</fld>,
<cd>a substance occurring in any part of the body where it does not
belong, and usually introduced from without.</cd> -- <col><b>Foreign
office</b></col>, <cd>that department of the government of Great Britain
which has charge British interests in foreign countries.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 584 --></p>

<p><syn><b>Syn.</b> -- Outlandish; alien; exotic; remote; distant;
extraneous; extrinsic.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>foreign-born</ent><br/
<hw>foreign-born</hw> <pos>adj.</pos> <def>born in another area or
country than that lived in; -- of persons.</def><br/
<syn><b>Syn. --</b> nonnative.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Foreigner</ent><br/
<hw>For"eign*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A person belonging
to or owning allegiance to a foreign country; one not native in the
country or jurisdiction under consideration, or not naturalized there;
an alien; a stranger.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Joy is such a <qex>foreigner</qex>,<br/
So mere a stranger to my thoughts.</q> <rj><qau>Denham.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Nor could the majesty of the English crown appear in a greater
luster, either to <qex>foreigners</qex> or subjects.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foreignism</ent><br/
<hw>For"eign*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Anything peculiar
to a foreign language or people; a foreign idiom or custom.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It is a pity to see the technicalities of the so-called liberal
professions distigured by <qex>foreignisms</qex>.</q> <rj><qau>Fitzed.
Hall.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foreignness</ent><br/
<hw>For"eign*ness</hw>, <pos>n.</pos> <def>The quality of being foreign;
remoteness; want of relation or appropriateness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Let not the <qex>foreignness</qex> of the subject hinder you from
endeavoring to set me right.</q> <rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>foreignness</qex> of complexion.</q> <rj><qau>G.
Eliot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forein</ent><br/
<hw>For"ein</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Foreign.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forejudge</ent><br/
<hw>Fore*judge"</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<ety>[<ets>Fore</ets> + <ets>judge</ets>.]</ety> <def>To judge
beforehand, or before hearing the facts and proof; to
prejudge.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forejudge</ent><br/
<hw>Fore*judge"</hw>, <pos>v. t.</pos> <ety>[For <ets>forjudge</ets>,
fr. F. <ets>forjuger</ets>; OF. <ets>fors</ets> outside, except + F.
<ets>juger</ets> to judge.]</ety> <fld>(O. Eng. Law)</fld> <def>To expel
from court for some offense or misconduct, as an attorney or officer; to
deprive or put out of a thing by the judgment of a court.</def>
<rj><au>Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forejudger</ent><br/
<hw>Fore*judg"er</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Eng. Law)</fld>
<def>A judgment by which one is deprived or put out of a right or thing
in question.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forejudgment</ent><br/
<hw>Fore*judg"ment</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Prejudgment.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foreknow</ent><br/
<hw>Fore*know"</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp.</pos> <conjf>Foreknew</conjf> <pr>(?)</pr>; <pos>p.
p.</pos> <conjf>Foreknown</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Foreknowing</conjf>.]</vmorph> <def>To have previous
knowledge of; to know beforehand.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Who would the miseries of man <qex>foreknow</qex>?</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foreknowable</ent><br/
<hw>Fore*know"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>That may be
foreknown.</def> <rj><au>Dr. H. More.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foreknower</ent><br/
<hw>Fore*know"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
foreknows.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foreknowingly</ent><br/
<hw>Fore*know"ing*ly</hw>, <pos>adv.</pos> <def>With
foreknowledge.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He who . . . <qex>foreknowingly</qex> loses his life.</q>
<rj><qau>Jer. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foreknowledge</ent><br/
<hw>Fore*knowl"edge</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Knowledge of a
thing before it happens, or of whatever is to happen;
prescience.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If I foreknew,<br/
<qex>Foreknowledge</qex> had no influence on their fault.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forel</ent><br/
<hw>For"el</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>forel</ets>case, sheath, OF. <ets>forel</ets>, <ets>fourel</ets>,
F. <ets>fourreau</ets>, LL. <ets>forellus</ets>, fr. OF.
<ets>forre</ets>, <ets>fuerre</ets>, sheath, case, of German origin; cf.
OHG. <ets>fuotar</ets>, akin to Goth. <ets>f<omac/dr</ets>; prob. not
the same word as E. <ets>fodder</ets> food. Cf. <er>Fur</er>,
<er>Fodder</er> food.]</ety> <def>A kind of parchment for book covers.
See <er>Forrill</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forel</ent><br/
<hw>For"el</hw>, <pos>v. t.</pos> <def>To bind with a forel.</def>
<mark>[R.]</mark> <rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foreland</ent><br/
<hw>Fore"land`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A
promontory or cape; a headland; <as>as, the North and South
<ex>Foreland</ex> in Kent, England</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Fort.)</fld> <def>A piece of ground between the
wall of a place and the moat.</def> <rj><au>Farrow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Hydraul. Engin.)</fld> <def>That portion of the
natural shore on the outside of the embankment which receives the stock
of waves and deadens their force.</def> <rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forelay</ent><br/
<hw>Fore*lay"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <sn>1.</sn> <def>To
lay down beforehand.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>These grounds being <qex>forelaid</qex> and understood.</q>
<rj><qau>Mede.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To waylay. See <er>Forlay</er>.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foreleader</ent><br/
<hw>Fore*lead"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who leads
others by his example; a guide.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forelend</ent><br/
<hw>Fore*lend"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>See
<er>Forlend</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>As if that life to losse they had <qex>forelent</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forelet</ent><br/
<hw>Fore*let"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>See
<er>Forlet</er>.</def> <mark>[Obs.]</mark>
<rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forelie</ent><br/
<hw>Fore*lie"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To lie in front
of.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Which <qex>forelay</qex><br/
Athwart her snowy breast.</q> <rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forelift</ent><br/
<hw>Fore*lift"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To lift up in
front.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forelock</ent><br/
<hw>Fore"lock`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
lock of hair that grows from the forepart of the head.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mech.)</fld> <def>A cotter or split pin, as in a
slot in a bolt, to prevent retraction; a linchpin; a pin fastening the
cap-square of a gun.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Forelock bolt</b></col>, <cd>a bolt retained by a key,
gib, or cotter passing through a slot.</cd> -- <col><b>Forelock
hook</b></col> <fld>(Rope Making)</fld>, <cd>a winch or whirl by which a
bunch of three yarns is twisted into a standard.</cd> <au>Knight.</au>
-- <mcol><col><b>To take time by the forelock</b></col> <it>or</it>
<col><b>To take occasion by the forelock</b></col></mcol>, <cd>to make
prompt use of anything; not to let slip an opportunity.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><q>Time is painted with a lock before and bald behind, signifying
thereby that we must <qex>take time by the forelock</qex>; for when it
is once past, there is no recalling it.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>On <qex>occasion's forelock</qex> watchful wait.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forelook</ent><br/
<hw>Fore*look"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To look
beforehand or forward.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foreman</ent><br/
<hw>Fore"man</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Foremen</plw> <pr>(<?/)</pr>.</plu> <def>The first or chief
man</def>; as: <sd>(a)</sd> <def>The chief man of a jury, who acts as
their speaker.</def> <sd>(b)</sd> <def>The chief of a set of hands
employed in a shop, or on works of any kind, who superintends the rest;
an overseer.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>foremanship</ent><br/
<hw>fore"man*ship</hw> <pos>n.</pos> <def>The position of a
foreman.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Foremast</ent><br/
<hw>Fore"mast`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Naut.)</fld>
<def>The mast nearest the bow.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Foremast hand</b></col> <it>or</it>
<col><b>Foremast man</b></col></mcol> <fld>(Naut.)</fld>, <cd>a common
sailor; also, a man stationed to attend to the gear of the
foremast.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foremeant</ent><br/
<hw>Fore*meant"</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Intended
beforehand; premeditated.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forementioned</ent><br/
<hw>Fore"men`tioned</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Mentioned
before; already cited; aforementioned.</def>
<rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foremilk</ent><br/
<hw>Fore"milk`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Physiol.)</fld>
<def>The milk secreted just before, or directly after, the birth of a
child or of the young of an animal; colostrum.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foremost</ent><br/
<hw>Fore"most`</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OE.
<ets>formest</ets> first, AS. <ets>formest</ets>, <ets>fyrmest</ets>,
superl. of <ets>forma</ets> first, which is a superl. fr.
<ets>fore</ets> fore; cf. Goth. <ets>frumist</ets>, <ets>fruma</ets>,
first. See <er>Fore</er>, <pos>adv.</pos>, and cf. <er>First</er>,
<er>Former</er>, <er>Frame</er>, <pos>v. t.</pos>, <er>Prime</er>,
<pos>a.</pos>]</ety> <def>First in time or place; most advanced; chief
in rank or dignity; <as>as, the <ex>foremost</ex> troops of an
army</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>THat struck the <qex>foremost</qex> man of all this world.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foremostly</ent><br/
<hw>Fore"most`ly</hw>, <pos>adv.</pos> <def>In the foremost place or
order; among the foremost.</def> <rj><au>J. Webster.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foremother</ent><br/
<hw>Fore"moth`er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A female
ancestor.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forename</ent><br/
<hw>Fore"name`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A name that
precedes the family name or surname; a first name.</def>
<rj><au>Selden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forename</ent><br/
<hw>Fore"name`</hw>, <pos>v. t.</pos> <def>To name or mention
before.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forenamed</ent><br/
<hw>Fore"named`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Named before;
aforenamed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forendihaz</ent><br/
\'d8<hw>F<oum/"ren*di*h<aacute/z`</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[Hung., lit., House of Lords.]</ety> <fld>(Hungary)</fld> <def>See
<er>Legislature</er>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Forenenst</ent><br/
<hw>Fore*nenst"</hw> <pr>(?)</pr>, <pos>prep.</pos> <ety>[See
<er>Fore</er>, and <er>Anent</er>.]</ety> <def>Over against; opposite
to.</def> <mark>[Now dialectic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The land <qex>forenenst</qex> the Greekish shore.</q>
<rj><qau>Fairfax.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fore-night</ent><br/
<hw>Fore"-night`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The evening
between twilight and bedtime.</def> <mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forenoon</ent><br/
<hw>Fore"noon"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The early part of
the day, from morning to meridian, or noon.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forenotice</ent><br/
<hw>Fore"no`tice</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Notice or
information of an event before it happens; forewarning.</def>
<mark>[R.]</mark> <rj><au>Rymer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forensal</ent><br/
<hw>Fo*ren"sal</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Forensic.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forensic</ent><br/
<hw>Fo*ren"sic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>forensis</ets>, fr. <ets>forum</ets> a public place, market place.
See <er>Forum</er>.]</ety> <def>Belonging to courts of judicature or to
public discussion and debate; used in legal proceedings, or in public
discussions; argumentative; rhetorical; <as>as, <ex>forensic</ex>
eloquence or disputes</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Forensic medicine</b></col>, <cd>medical jurisprudence;
medicine in its relations to law.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forensic</ent><br/
<hw>Fo*ren"sic</hw>, <pos>n.</pos> <fld>(Amer. Colleges)</fld> <def>An
exercise in debate; a forensic contest; an argumentative
thesis.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forensical</ent><br/
<hw>Fo*ren"sic*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Forensic.</def>
<rj><au>Berkley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foreordain</ent><br/
<hw>Fore`or*dain"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To ordain or
appoint beforehand; to preordain; to predestinate; to
predetermine.</def> <rj><au>Hooker.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foreordinate</ent><br/
<hw>Fore*or"di*nate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To
foreordain.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foreordination</ent><br/
<hw>Fore*or`di*na"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Previous
ordination or appointment; predetermination; predestination.</def></p>

<p><ent>Forepart</ent><br/
<ent>Fore part</ent><br/
<mhw>{ <hw>Fore" part`</hw> <pr>(f<omac/r"p<aum/rt)</pr>, <it>or</it>
<hw>Fore"part`</hw> }</mhw>, <pos>n.</pos> <def>The part most advanced,
or first in time or in place; the beginning.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>forepast</ent><br/
<hw>fore"past`</hw> <pr>(f<omac/r"p<adot/st)</pr>, <pos>a.</pos>
<def>Bygone.</def> <mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>forepole</ent><br/
<hw>fore"pole`</hw> <pr>(f<omac/r"p<omac/l`)</pr>, <pos>a.</pos>
<fld>(Mining)</fld> <def>One of the thick laths or poles driven
horizontally ahead on top of a set of the main timbering in advancing a
level in loose ground.</def><br/
<syn><b>Syn. --</b> spile{4}; spill{2d}.</syn><br/
[<source>RDH</source>]</p>

<p><ent>Forepossessed</ent><br/
<hw>Fore`pos*sessed"</hw> <pr>(f<omac/r`p<ocr/z*z<ecr/st" or
f<omac/r`p<ocr/s*s<ecr/st")</pr>, <pos>a.</pos> <sn>1.</sn> <def>Holding
or held formerly in possession.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Preoccupied; prepossessed; pre<eum/ngaged.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Not extremely <qex>forepossessed</qex> with prejudice.</q>
<rj><qau>Bp. Sanderson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foreprize</ent><br/
<hw>Fore*prize"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To prize or
rate beforehand.</def> <mark>[Obs.]</mark> <rj><au>Hooker.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forepromised</ent><br/
<hw>Fore`prom"ised</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Promised
beforehand; pre<eum/ngaged.</def> <rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forequoted</ent><br/
<hw>Fore"quot`ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Cited before;
quoted in a foregoing part of the treatise or essay.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foreran</ent><br/
<hw>Fore*ran"</hw> <pr>(?)</pr>, <def><pos>imp.</pos> of
<er>Forerun</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forerank</ent><br/
<hw>Fore"rank`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The first rank; the
front.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forereach</ent><br/
<hw>Fore*reach"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <fld>(Naut.)</fld>
<def>To advance or gain upon; -- said of a vessel that gains upon
another when sailing closehauled.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forereach</ent><br/
<hw>Fore*reach"</hw>, <pos>v. i.</pos> <fld>(Naut.)</fld> <def>To shoot
ahead, especially when going in stays.</def> <rj><au>R. H. Dana,
Jr.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foreread</ent><br/
<hw>Fore*read"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To tell
beforehand; to signify by tokens; to predestine.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forerecited</ent><br/
<hw>Fore`re*cit"ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Named or
recited before.</def> <ldquo/The <xex>forerecited</xex>
practices.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foreremembered</ent><br/
<hw>Fore`re*mem"bered</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Called to
mind previously.</def> <rj><au>Bp. Montagu.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foreright</ent><br/
<hw>Fore"right`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Ready; directly
forward; going before.</def> <mark>[Obs.]</mark> <ldquo/A
<xex>foreright</xex> wind.<rdquo/ <rj><au>Chapman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foreright</ent><br/
<hw>Fore"right`</hw>, <pos>adv.</pos> <def>Right forward; onward.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forerun</ent><br/
<hw>Fore*run"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <sn>1.</sn> <def>To
turn before; to precede; to be in advance of (something
following).</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To come before as an earnest of something to follow;
to introduce as a harbinger; to announce.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>These signs <qex>forerun</qex> the death or fall of kings.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forerunner</ent><br/
<hw>Fore*run"ner</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A
messenger sent before to give notice of the approach of others; a
harbinger; a sign foreshowing something; a prognostic; <as>as, the
<ex>forerunner</ex> of a fever</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Whither the <qex>forerunner</qex> in for us entered, even
Jesus.</q> <rj><qau>Heb. vi. 20.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>My elder brothers, my <qex>forerunners</qex>, came.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A predecessor; an ancestor.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Naut.)</fld> <def>A piece of rag terminating the
log line.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foresaid</ent><br/
<hw>Fore"said`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Mentioned before;
aforesaid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foresail</ent><br/
<hw>Fore"sail`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Naut.)</fld>
<sd>(a)</sd> <def>The sail bent to the foreyard of a square-rigged
vessel, being the lowest sail on the foremast.</def> <sd>(b)</sd>
<def>The gaff sail set on the foremast of a schooner.</def> <sd>(c)</sd>
<def>The fore staysail of a sloop, being the triangular sail next
forward of the mast.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foresay</ent><br/
<hw>Fore*say"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[AS.
<ets>foresecgan</ets>; <ets>fore + secgan</ets> to say. See
<er>Say</er>, <pos>v. t.</pos>]</ety> <def>To foretell.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Her danger nigh that sudden change <qex>foresaid</qex>.</q>
<rj><qau>Fairfax.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foresee</ent><br/
<hw>Fore*see"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[AS.
<ets>forese<oacute/n</ets>; <ets>fore + se<oacute/n</ets> to see. See
<er>See</er>, <pos>v. t.</pos>]</ety> <sn>1.</sn> <def>To see
beforehand; to have prescience of; to foreknow.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A prudent man <qex>foreseeth</qex> the evil.</q> <rj><qau>Prov.
xxii. 3.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To provide.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Great shoals of people, which go on to populate, without
<qex>foreseeing</qex> means of life.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foresee</ent><br/
<hw>Fore*see"</hw>, <pos>v. i.</pos> <def>To have or exercise
foresight.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>foreseeable</ent><br/
<hw>foreseeable</hw> <pos>adj.</pos> <def>being such as may reasonable
be anticipated; <as>as, <ex>foreseeable</ex> costs were well within the
budget</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Foreseen</ent><br/
<hw>Fore*seen"</hw> <pr>(?)</pr>, <pos>conj.</pos>, or (strictly)
<pos>p. p.</pos> <def>Provided; in case that; on condition that.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>One manner of meat is most sure to every complexion,
<qex>foreseen</qex> that it be alway most commonly in conformity of
qualities, with the person that eateth.</q> <rj><qau>Sir T.
Elyot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foreseer</ent><br/
<hw>Fore*se"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who foresees or
foreknows.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foreseize</ent><br/
<hw>Fore*seize"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To seize
beforehand.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foreshadow</ent><br/
<hw>Fore*shad"ow</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To shadow or
typify beforehand; to prefigure.</def> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foreshew</ent><br/
<hw>Fore*shew"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>See
<er>Foreshow</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foreship</ent><br/
<hw>Fore"ship`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The fore part of a
ship.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>foreshore</ent><br/
<hw>foreshore</hw> <pos>n.</pos> <def>the part of the seashore between
the high-water and and low-water marks.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Foreshorten</ent><br/
<hw>Fore*short"en</hw> <pr>(?)</pr>, <pos>v. t.</pos> <sn>1.</sn>
<fld>(Fine Art)</fld> <def>To represent on a plane surface, as if
extended in a direction toward the spectator or nearly so; to shorten by
drawing in perspective.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Fig.: To represent pictorially to the
imagination.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Songs, and deeds, and lives that lie<br/
<qex>Foreshortened</qex> in the tract of time.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foreshortening</ent><br/
<hw>Fore*short"en*ing</hw>, <pos>n.</pos> <fld>(Fine Arts)</fld>
<def>Representation in a foreshortened mode or way.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foreshot</ent><br/
<hw>Fore"shot`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>In distillation of
low wines, the first portion of spirit that comes over, being a fluid
abounding in fusel oil.</def> <rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foreshow</ent><br/
<hw>Fore*show"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[AS.
<ets>foresce<aacute/wian</ets> to foresee, provide; <ets>fore +
sce<aacute/wian</ets> to see. See <er>Show</er>, <pos>v. t.</pos>]</ety>
<def>To show or exhibit beforehand; to give foreknowledge of; to
prognosticate; to foretell.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Your looks <qex>foreshow</qex><br/
You have a gentle heart.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Next, like Aurora, Spenser rose,<br/
Whose purple blush the day <qex>foreshows</qex>.</q>
<rj><qau>Denham.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foreshower</ent><br/
<hw>Fore*show"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
predicts.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foreside</ent><br/
<hw>Fore"side</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
front side; the front; esp., a stretch of country fronting the
sea.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The outside or external covering.</def>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foresight</ent><br/
<hw>Fore"sight`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
act or the power of foreseeing; prescience; foreknowledge.</def>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Action in reference to the future; provident care;
prudence; wise forethought.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This seems an unseasonable <qex>foresight</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A random expense, without plan or <qex>foresight</qex>.</q>
<rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Surv.)</fld> <def>Any sight or reading of the
leveling staff, except the backsight; any sight or bearing taken by a
compass or theodolite in a forward direction.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Gun.)</fld> <def>Muzzle sight. See <cref>Fore
sight</cref>, under <er>Fore</er>, <pos>a.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foresighted</ent><br/
<hw>Fore"sight`ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Sagacious;
prudent; provident for the future.</def> <rj><au>Bartram.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foresightful</ent><br/
<hw>Fore"sight`ful</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Foresighted.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foresignify</ent><br/
<hw>Fore*sig"ni*fy</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To signify
beforehand; to foreshow; to typify.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foreskin</ent><br/
<hw>Fore"skin</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Anat.)</fld>
<def>The fold of skin which covers the glans of the penis; the
prepuce.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foreskirt</ent><br/
<hw>Fore"skirt`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The front skirt of
a garment, in distinction from the <contr>train</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Honor's train<br/
Is longer than his <qex>foreskirt</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foreslack</ent><br/
<hw>Fore*slack"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <mark>[Obs.]</mark>
<def>See <er>Forslack</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foresleeve</ent><br/
<hw>Fore"sleeve`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The sleeve below
the elbow.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foreslow</ent><br/
<hw>Fore*slow"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[See
<er>Forslow</er>.]</ety> <def>To make slow; to hinder; to obstruct.
<mark>[Obs.]</mark> See <er>Forslow</er>, <pos>v. t.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><q>No stream, no wood, no mountain could <qex>foreslow</qex><br/
Their hasty pace.</q> <rj><qau>Fairfax.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foreslow</ent><br/
<hw>Fore*slow"</hw>, <pos>v. i.</pos> <def>To loiter. Same as
<er>Forslow</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forespeak</ent><br/
<hw>Fore*speak"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <mark>[Obs.]</mark>
<def>See <er>Forspeak</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forespeak</ent><br/
<hw>Fore*speak"</hw>, <pos>v. t.</pos> <def>To foretell; to
predict.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>My mother was half a witch; never anything that she
<qex>forespake</qex> but came to pass.</q> <rj><qau>Beau. &
Fl.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forespeaking</ent><br/
<hw>Fore"speak`ing</hw>, <pos>n.</pos> <def>A prediction; also, a
preface.</def> <mark>[Obs.]</mark> <rj><au>Camden. Huloet.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forespeech</ent><br/
<hw>Fore"speech`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A preface.</def>
<mark>[Obs.]</mark> <rj><au>Sherwood.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forespent</ent><br/
<hw>Fore*spent"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Fore</ets> +
<ets>spent</ets>.]</ety> <def>Already spent; gone by; past.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forespent</ent><br/
<hw>Fore*spent"</hw>, <pos>a.</pos> <mark>[Obs.]</mark> <def>See
<er>Forspent</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forespurrer</ent><br/
<hw>Fore*spur"rer</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who rides
before; a harbinger.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forest</ent><br/
<hw>For"est</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>forest</ets>, F. <ets>for<ecir/t</ets>, LL. <ets>forestis</ets>,
also, <ets>forestus</ets>, <ets>forestum</ets>, <ets>foresta</ets>,
prop., open ground reserved for the chase, fr. L. <ets>foris</ets>,
<ets>foras</ets>, out of doors, abroad. See <er>Foreign</er>.]</ety>
<sn>1.</sn> <def>An extensive wood; a large tract of land covered with
trees; in the United States, a wood of native growth, or a tract of
woodland which has never been cultivated.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Eng. Law)</fld> <def>A large extent or precinct of
country, generally waste and woody, belonging to the sovereign, set
apart for the keeping of game for his use, not inclosed, but
distinguished by certain limits, and protected by certain laws, courts,
and officers of its own.</def> <rj><au>Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forest</ent><br/
<hw>For"est</hw>, <pos>a.</pos> <def>Of or pertaining to a forest;
sylvan.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Forest fly</b></col>. <fld>(Zool.)</fld> <sd>(a)</sd>
<cd>One of numerous species of blood-sucking flies, of the family
<fam>Tabanid<ae/</fam>, which attack both men and beasts. See <er>Horse
fly</er>.</cd> <sd>(b)</sd> <cd>A fly of the genus
<gen>Hippobosca</gen>, esp. <spn>H. equina</spn>. See <er>Horse
tick</er>.</cd> -- <col><b>Forest glade</b></col>, <cd>a grassy space in
a forest.</cd> <au>Thomson.</au> -- <col><b>Forest laws</b></col>,
<cd>laws for the protection of game, preservation of timber, etc., in
forests.</cd> -- <col><b>Forest tree</b></col>, <cd>a tree of the
forest, especially a timber tree, as distinguished from a <cref>fruit
tree</cref>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forest</ent><br/
<hw>For"est</hw>, <pos>v. t.</pos> <def>To cover with trees or
wood.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forestaff</ent><br/
<hw>Fore"staff`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Naut.)</fld>
<def>An instrument formerly used at sea for taking the altitudes of
heavenly bodies, now superseded by the sextant; -- called also
<altname>cross-staff</altname>.</def> <rj><au>Brande & C.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forestage</ent><br/
<hw>For"est*age</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>forestage</ets>.]</ety> <fld>(O. Eng. Law)</fld> <sd>(a)</sd>
<def>A duty or tribute payable to the king's foresters.</def>
<sd>(b)</sd> <def>A service paid by foresters to the king.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forestal</ent><br/
<hw>For"est*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining to
forests; <as>as, <ex>forestal</ex> rights</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forestall</ent><br/
<hw>Fore*stall"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Forestalled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Forestalling</conjf>.]</vmorph> <ety>[OE.
<ets>forstallen</ets> to stop, to obstruct; to stop (goods) on the way
to the market by buying them beforehand, from <ets>forstal</ets>
obstruction, AS. <ets>forsteal</ets>, <ets>foresteall</ets>, prop., a
placing one's self before another. See <er>Fore</er>, and
<er>Stall</er>.]</ety> <sn>1.</sn> <def>To take beforehand, or in
advance; to anticipate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>What need a man <qex>forestall</qex> his date of grief,<br/
And run to meet what he would most avoid?</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To take possession of, in advance of some one or
something else, to the exclusion or detriment of the latter; to get
ahead of; to preoccupy; also, to exclude, hinder, or prevent, by prior
occupation, or by measures taken in advance.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 585 --></p>

<p><q>An ugly serpent which <qex>forestalled</qex> their way.</q>
<rj><qau>Fairfax.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>But evermore those damsels did <qex>forestall</qex><br/
Their furious encounter.</q> <rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To be <qex>forestalled</qex> ere we come to fall.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Habit is a <qex>forestalled</qex> and obstinate judge.</q>
<rj><qau>Rush.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To deprive; -- with <xex>of</xex>.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>All the better; may<br/
This night <qex>forestall</qex> him of the coming day!</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Eng. Law)</fld> <def>To obstruct or stop up, as a
way; to stop the passage of on highway; to intercept on the road, as
goods on the way to market.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To forestall the market</b></col>, <cd>to buy or contract
for merchandise or provision on its way to market, with the intention of
selling it again at a higher price; to dissuade persons from bringing
their goods or provisions there; or to persuade them to enhance the
price when there. This was an offense at law in England until 1844.</cd>
<rj><au>Burrill.</au></rj></cs></p>

<p><syn><b>Syn.</b> -- To anticipate; monopolize; engross.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forestaller</ent><br/
<hw>Fore*stall"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
forestalls; esp., one who forestalls the market.</def>
<rj><au>Locke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forestay</ent><br/
<hw>Fore"stay`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Naut.)</fld>
<def>A large, strong rope, reaching from the foremast head to the
bowsprit, to support the mast. See <xex>Illust.</xex> under
<er>Ship</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>forested</ent><br/
<hw>for"est*ed</hw> <pos>adj.</pos> <def>covered with forest; <as>as,
efforts to protect <ex>forested</ex> lands of the
northwest</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Forester</ent><br/
<hw>For"est*er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>forestier</ets>, LL. <ets>forestarius</ets>.]</ety> <sn>1.</sn>
<def>One who has charge of the growing timber on an estate; an officer
appointed to watch a forest and preserve the game.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An inhabitant of a forest.</def>
<rj><au>Wordsworth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A forest tree.</def> <mark>[R.]</mark>
<rj><au>Evelyn.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Zool.)</fld> <def>A lepidopterous insect belonging
to <gen>Alypia</gen> and allied genera; <as>as, the eight-spotted
<ex>forester</ex> (<spn>A. octomaculata</spn>), which in the larval
state is injurious to the grapevine</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forestick</ent><br/
<hw>Fore"stick`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Front stick of a
hearth fire.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forestry</ent><br/
<hw>For"est*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. OF.
<ets>foresterie</ets>.]</ety> <def>The art of forming or of cultivating
forests; the management of growing timber.</def></p>

<p><ent>Foreswart</ent><br/
<ent>Foreswart</ent><br/
<mhw>{ <hw>Fore"swart`</hw> <pr>(?)</pr>, <hw>Fore"swart`</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <mark>[Obs.]</mark> <def>See
<er>Forswat</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foretaste</ent><br/
<hw>Fore"taste`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A taste
beforehand; enjoyment in advance; anticipation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foretaste</ent><br/
<hw>Fore*taste"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <sn>1.</sn> <def>To
taste before full possession; to have previous enjoyment or experience
of; to anticipate.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To taste before another.</def>
<ldquo/<xex>Foretasted</xex> fruit.<rdquo/ <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foretaster</ent><br/
<hw>Fore"tast`er</hw> <pr>(? <or/ ?)</pr>, <pos>n.</pos> <def>One who
tastes beforehand, or before another.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foreteach</ent><br/
<hw>Fore*teach"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To teach
beforehand.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foretell</ent><br/
<hw>Fore*tell"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Foretold</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Foretelling</conjf>.]</vmorph> <def>To predict; to tell
before occurence; to prophesy; to foreshow.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Deeds then undone my faithful tongue <qex>foretold</qex>.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Prodigies, <qex>foretelling</qex> the future eminence and luster
of his character.</q> <rj><qau>C. Middleton.</qau></rj></p>

<p><syn><b>Syn.</b> -- To predict; prophesy; prognosticate;
augur.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foretell</ent><br/
<hw>Fore*tell"</hw>, <pos>v. i.</pos> <def>To utter predictions.</def>
<rj><au>Acts iii. 24.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foreteller</ent><br/
<hw>Fore*tell"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
predicts.</def> <rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forethink</ent><br/
<hw>Fore*think"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <sn>1.</sn> <def>To
think beforehand; to anticipate in the mind; to prognosticate.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The soul of every man<br/
Prophetically doth <qex>forethink</qex> thy fall.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To contrive (something) beforehend.</def>
<mark>[Obs.]</mark> <rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forethink</ent><br/
<hw>Fore*think"</hw>, <pos>v. i.</pos> <def>To contrive
beforehand.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forethought</ent><br/
<hw>Fore"thought`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Thought of, or
planned, beforehand; aforethought; prepense; hence, deliberate.</def>
<ldquo/<xex>Forethought</xex> malice.<rdquo/
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forethought</ent><br/
<hw>Fore"thought`</hw>, <pos>n.</pos> <def>A thinking or planning
beforehand; prescience; premeditation; forecast; provident
care.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A sphere that will demand from him <qex>forethought</qex>,
courage, and wisdom.</q> <rj><qau>I. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forethoughtful</ent><br/
<hw>Fore"thought`ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having
forethought.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foretime</ent><br/
<hw>Fore"time`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The past; the time
before the present.</def> <ldquo/A very dim <xex>foretime</xex>.<rdquo/
<rj><au>J. C. Shairp.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foretoken</ent><br/
<hw>Fore"to`ken</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS.
<ets>foret<amac/cen</ets>. See <er>Token</er>.]</ety> <def>Prognostic;
previous omen.</def> <rj><au>Sir P. Sidney.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foretoken</ent><br/
<hw>Fore*to"ken</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Foretokened</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Foretokening</conjf> <pr>(?)</pr>.]</vmorph> <ety>[AS.
<ets>foret<amac/cnian</ets>; <ets>fore + t<amac/cnian</ets>.]</ety>
<def>To foreshow; to presignify; to prognosticate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Whilst strange prodigious signs <qex>foretoken</qex> blood.</q>
<rj><qau>Daniel.</qau></rj></p>

<p><ent>Foretold</ent><br/
<hw>Fore*told"</hw> <pr>(?)</pr>, <def><pos>imp. & p. p.</pos> of
<er>Foretell</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fore tooth</ent><br/
<hw>Fore" tooth`</hw> <pr>(?)</pr>, <plu><it>pl.</it> <plw>Fore
teeth</plw> <pr>(<?/)</pr>.</plu> <fld>(Anat.)</fld> <def>One of the
teeth in the forepart of the mouth; an incisor.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foretop</ent><br/
<hw>Fore"top`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The hair
on the forepart of the head; esp., a tuft or lock of hair which hangs
over the forehead, as of a horse.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That part of a headdress that is in front; the top
of a periwig.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Naut.)</fld> <def>The platform at the head of the
foremast.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fore-topgallant</ent><br/
<hw>Fore`-top*gal"lant</hw> <pr>(? <or/ ?)</pr>, <pos>a.</pos>
<fld>(Naut.)</fld> <def>Designating the mast, sail, yard, etc., above
the topmast; <as>as, the <ex>fore-topgallant</ex> sail</as>. See
<er>Sail</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fore-topmast</ent><br/
<hw>Fore`-top"mast</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Naut.)</fld>
<def>The mast erected at the head of the foremast, and at the head of
which stands the fore-topgallant mast; the mast next above the foremast.
See <er>Ship</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fore-topsail</ent><br/
<hw>Fore`-top"sail</hw> <pr>(? <or/ ?)</pr>, <pos>n.</pos>
<fld>(Naut.)</fld> <def>the topsail on a foremast. See
<er>Sail</er>.</def><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><ent>Forever</ent><br/
<hw>For*ev"er</hw> <pr>(f<ocr/r*<ecr/v"<etil/r)</pr>, <pos>adv.</pos>
<ety>[<ets>For</ets>, prep. + <ets>ever</ets>.]</ety> <sn>1.</sn>
<def>Through eternity; through endless ages; eternally.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>At all times; always.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In England, <xex>for</xex> and <xex>ever</xex> are
usually written and printed as two separate words; but, in the United
States, the general practice is to make but a single word of
them.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Forever and ever</b></col>, <cd>an emphatic
<ldquo/forever.<rdquo/</cd></cs></p>

<p><syn><b>Syn.</b> -- Constantly; continually; invariably;
unchangeably; incessantly; always; perpetually; unceasingly;
ceaselessly; interminably; everlastingly; endlessly;
eternally.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forevouched</ent><br/
<hw>Fore*vouched"</hw> <pr>(f<omac/r*voucht")</pr>, <pos>a.</pos>
<def>Formerly vouched or avowed; affirmed in advance.</def>
<mark>[R.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foreward</ent><br/
<hw>Fore"ward`</hw> <pr>(f<omac/r"w<add/rd`)</pr>, <pos>n.</pos>
<def>The van; the front.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>My <qex>foreward</qex> shall be drawn out all in length,<br/
Consisting equally of horse and foot.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forewarn</ent><br/
<hw>Fore*warn"</hw> <pr>(f<omac/r*w<add/rn")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Forewarned</conjf>
<pr>(f<omac/r*w<add/rnd")</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Forewarning</conjf>.]</vmorph> <def>To warn beforehand; to give
previous warning, admonition, information, or notice to; to caution in
advance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We were <qex>forewarned</qex> of your coming.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forewaste</ent><br/
<hw>Fore*waste"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>See
<er>Forewaste</er>.</def> <rj><au>Gascoigne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forewend</ent><br/
<hw>Fore*wend"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[<ets>Fore</ets>
+ <ets>wend</ets>.]</ety> <def>To go before.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forewish</ent><br/
<hw>Fore*wish"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To wish
beforehand.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forewit</ent><br/
<hw>Fore"wit`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A
leader, or would-be leader, in matters of knowledge or taste.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Nor that the <qex>forewits</qex>, that would draw the rest unto
their liking, always like the best.</q> <rj><qau>B.
Jonson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Foresight; prudence.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Let this <qex>forewit</qex> guide thy thought.</q>
<rj><qau>Southwell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forewite</ent><br/
<hw>Fore*wite"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>pres.
indic. sing., 1st & 3d pers.</pos> <conjf>Forewot</conjf> <pr>(?)</pr>,
<pos>2d person</pos> <conjf>Forewost</conjf> <pr>(<?/)</pr>,
<pos>pl.</pos> <conjf>Forewiten</conjf> <pr>(<?/)</pr>; <pos>imp.
sing.</pos> <conjf>Forewiste</conjf> <pr>(?)</pr>, <pos>pl.</pos>
<conjf>Forewisten</conjf> <pr>(<?/)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Forewiting</conjf> <pr>(?)</pr>.]</vmorph> <ety>[AS.
<ets>forewitan</ets>. See <er>Wit</er> to know.]</ety> <def>To
foreknow.</def> <mark>[Obs.]</mark> <altsp>[Written also
<asp>forwete</asp>.]</altsp> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forewoman</ent><br/
<hw>Fore"wom`an</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Forewomen</plw> <pr>(<?/)</pr>.</plu> <def>A woman who is chief; a
woman who has charge of the work or workers in a shop or other place; a
head woman.</def> <rj><au>Tatler.</au> <au>W. Besant.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foreword</ent><br/
<hw>Fore"word`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A preface.</def>
<rj><au>Furnvall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foreworn</ent><br/
<hw>Fore*worn"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Forworn</er>.]</ety> <def>Worn out; wasted; used up.</def>
<mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Old <qex>foreworn</qex> stories almost forgotten.</q>
<rj><qau>Brydges.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forewot</ent><br/
<hw>Fore*wot"</hw> <pr>(?)</pr>, <def><pos>pres. indic., 1st & 3d pers.
sing.</pos> of <er>Forewite</er>.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foreyard</ent><br/
<hw>Fore"yard`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Naut.)</fld>
<def>The lowermost yard on the foremast.</def> <note>[See
<xex>Illust.</xex> of <er>Ship</er>.]</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forfalture</ent><br/
<hw>For"fal*ture</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Forfeiture.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forfeit</ent><br/
<hw>For"feit</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>forfet</ets> crime, penalty, F. <ets>forfait</ets> crime (LL.
<ets>forefactum</ets>, <ets>forifactum</ets>), prop. p. p. of
<ets>forfaire</ets> to forfeit, transgress, fr. LL.
<ets>forifacere</ets>, prop., to act beyond; L. <ets>foris</ets> out of
doors, abroad, beyond + <ets>facere</ets> to do. See <er>Foreign</er>,
and <er>Fact</er>.]</ety> <sn>1.</sn> <def>Injury; wrong;
mischief.</def> <mark>[Obs. & R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>To seek arms upon people and country that never did us any
<qex>forfeit</qex>.</q> <rj><qau>Ld. Berners.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A thing forfeit or forfeited; what is or may be
taken from one in requital of a misdeed committed; that which is lost,
or the right to which is alienated, by a crime, offense, neglect of
duty, or breach of contract; hence, a fine; a mulct; a penalty; <as>as,
he who murders pays the <ex>forfeit</ex> of his life</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thy slanders I forgive; and therewithal<br/
Remit thy other <qex>forfeits</qex>.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Something deposited and redeemable by a sportive
fine; -- whence the game of <xex>forfeits</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Country dances and <qex>forfeits</qex> shortened the rest of the
day.</q> <rj><qau>Goldsmith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forfeit</ent><br/
<hw>For"feit</hw>, <pos>a.</pos> <ety>[F. <ets>forfait</ets>, p. p. of
<ets>forfaire</ets>. See <er>Forfeit</er>, <pos>n.</pos>]</ety>
<def>Lost or alienated for an offense or crime; liable to penal
seizure.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thy wealth being <qex>forfeit</qex> to the state.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To tread the <qex>forfeit</qex> paradise.</q>
<rj><qau>Emerson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forfeit</ent><br/
<hw>For"feit</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Forfeited</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Forfeiting</conjf>.]</vmorph> <ety>[OE. <ets>forfeten</ets>. See
<er>Forfeit</er>, <pos>n.</pos>]</ety> <def>To lose, or lose the right
to, by some error, fault, offense, or crime; to render one's self by
misdeed liable to be deprived of; to alienate the right to possess, by
some neglect or crime; <as>as, to <ex>forfeit</ex> an estate by treason;
to <ex>forfeit</ex> reputation by a breach of promise</as>; -- with
<xex>to</xex> before the one acquiring what is forfeited.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>[They] had <qex>forfeited</qex> their property by their
crimes.</q> <rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Undone and <qex>forfeited</qex> to cares forever!</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forfeit</ent><br/
<hw>For"feit</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To be guilty of a
misdeed; to be criminal; to transgress.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To fail to keep an obligation.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I will have the heart of him if he <qex>forfeit</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forfeit</ent><br/
<hw>For"feit</hw>, <pos>p. p. <or/ a.</pos> <def>In the condition of
being forfeited; subject to alienation.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Once more I will renew<br/
His laps<egrave/d powers, though <qex>forfeite</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forfeitable</ent><br/
<hw>For"feit*a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Liable to be
forfeited; subject to forfeiture.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>For the future, uses shall be subject to the statutes of mortmain,
and <qex>forfeitable</qex>, like the lands themselves.</q>
<rj><qau>Blackstone.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forfeiter</ent><br/
<hw>For"feit*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who incurs a
penalty of forfeiture.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forfeiture</ent><br/
<hw>For"fei*ture</hw> <pr>(?; 135)</pr>, <pos>n.</pos> <ety>[F.
<ets>forfeiture</ets>, LL. <ets>forisfactura</ets>.]</ety> <sn>1.</sn>
<def>The act of forfeiting; the loss of some right, privilege, estate,
honor, office, or effects, by an offense, crime, breach of condition, or
other act.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Under pain of <qex>foreiture</qex> of the said goods.</q>
<rj><qau>Hakluyt.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is forfeited; a penalty; a fine or
mulct.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>What should I gain<br/
By the exaction of the <qex>forfeiture</qex>?</q>
<rj><qau>Shak.</qau></rj></p>

<p><syn><b>Syn.</b> -- Fine; mulct; amercement; penalty.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forfend</ent><br/
<hw>For*fend"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>for-</ets> + <ets>fend</ets>. See <er>Forewend</er>.]</ety> <def>To
prohibit; to forbid; to avert.</def> <mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Which peril heaven <qex>forefend</qex>!</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ This is etymologically the preferable
spelling.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forfered</ent><br/
<hw>For*fer"ed</hw> <pr>(f<ocr/r*f<emac/r"<ecr/d)</pr>, <pos>p. p. &
a.</pos> <ety>[See <er>For-</er>, and <er>Fear</er>.]</ety>
<def>Excessively alarmed; in great fear.</def> <mark>[Obs.]</mark>
<ldquo/<xex>Forfered</xex> of his death.<rdquo/
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forfete</ent><br/
<hw>For"fete</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[See
<er>Forfeit</er>.]</ety> <def>To incur a penalty; to transgress.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>And all this suffered our Lord Jesus Christ that never
<qex>forfeted</qex>.</q> <rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forfex</ent><br/
\'d8<hw>For"fex</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.]</ety> <def>A
pair of shears.</def> <rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forficate</ent><br/
<hw>For"fi*cate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>forfex</ets>, <ets>forficis</ets>, shears.]</ety>
<fld>(Zool.)</fld> <def>Deeply forked, as the tail of certain
birds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forficula</ent><br/
\'d8<hw>For*fic"u*la</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., small
shears, scissors, dim. of <ets>forfex</ets> shears.]</ety>
<fld>(Zool.)</fld> <def>A genus of insects including the earwigs. See
<er>Earwig</er>, 1.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forficulidae</ent><br/
<hw>Forficulidae</hw> <pos>n.</pos> <def>A natural family of insects
incliuding the typical earwigs.</def><br/
<syn><b>Syn. --</b> family <fam>Forficulidae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Forgather</ent><br/
<hw>For*gath"er</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To convene; to
gossip; to meet accidentally.</def> <mark>[Scot.]</mark>
<rj><au>Jamieson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Within that circle he <qex>forgathered</qex> with many a fool.</q>
<rj><qau>Wilson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forgave</ent><br/
<hw>For*gave"</hw> <pr>(f<ocr/r*g<amac/v")</pr>, <def><pos>imp.</pos> of
<er>Forgive</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forge</ent><br/
<hw>Forge</hw> <pr>(f<omac/rj)</pr>, <pos>n.</pos> <ety>[F.
<ets>forge</ets>, fr. L. <ets>fabrica</ets> the workshop of an artisan
who works in hard materials, fr. <ets>faber</ets> artisan, smith, as
adj., skillful, ingenious; cf. Gr. <?/ soft, tender. Cf.
<er>Fabric</er>.]</ety> <sn>1.</sn> <def>A place or establishment where
iron or other metals are wrought by heating and hammering; especially, a
furnace, or a shop with its furnace, etc., where iron is heated and
wrought; a smithy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In the quick <qex>forge</qex> and working house of thought.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The works where wrought iron is produced directly
from the ore, or where iron is rendered malleable by puddling and
shingling; a shingling mill.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The act of beating or working iron or steel; the
manufacture of metallic bodies.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>In the greater bodies the <qex>forge</qex> was easy.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>American forge</b></col>, <cd>a forge for the direct
production of wrought iron, differing from the old Catalan forge mainly
in using finely crushed ore and working continuously.</cd>
<au>Raymond.</au> -- <col><b>Catalan forge</b></col>.
<fld>(Metal.)</fld> <cd>See under <er>Catalan</er>.</cd> --
<col><b>Forge cinder</b></col>, <cd>the dross or slag form a forge or
bloomary.</cd> -- <mcol><col><b>Forge rolls</b></col>, <col><b>Forge
train</b></col></mcol>, <cd>the train of rolls by which a bloom is
converted into puddle bars.</cd> -- <col><b>Forge wagon</b></col>
<fld>(Mil.)</fld>, <cd>a wagon fitted up for transporting a blackmith's
forge and tools.</cd> -- <col><b>Portable forge</b></col>, <cd>a light
and compact blacksmith's forge, with bellows, etc., that may be moved
from place to place.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forge</ent><br/
<hw>Forge</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Forged</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Forging</conjf> <pr>(?)</pr>.]</vmorph> <ety>[F.
<ets>forger</ets>, OF. <ets>forgier</ets>, fr. L. <ets>fabricare</ets>,
<ets>fabricari</ets>, to form, frame, fashion, from <ets>fabrica</ets>.
See <er>Forge</er>, <pos>n.</pos>, and cf. <er>Fabricate</er>.]</ety>
<sn>1.</sn> <def>To form by heating and hammering; to beat into any
particular shape, as a metal.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Mars's armor <qex>forged</qex> for proof eterne.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To form or shape out in any way; to produce; to
frame; to invent.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Those names that the schools <qex>forged</qex>, and put into the
mouth of scholars, could never get admittance into common use.</q>
<rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Do <qex>forge</qex> a life-long trouble for ourselves.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To coin.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To make falsely; to produce, as that which is untrue
or not genuine; to fabricate; to counterfeit, as, a signature, or a
signed document.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That paltry story is untrue,<br/
And <qex>forged</qex> to cheat such gulls as you.</q>
<rj><qau>Hudibras.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Forged</qex> certificates of his . . . moral character.</q>
<rj><qau>Macaulay.</qau></rj></p>

<p><syn><b>Syn.</b> -- To fabricate; counterfeit; feign;
falsify.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forge</ent><br/
<hw>Forge</hw>, <pos>v. i.</pos> <ety>[See <er>Forge</er>, <pos>v.
t.</pos>, and for sense 2, cf. <er>Forge</er> compel.]</ety> <sn>1.</sn>
<def>To commit forgery.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Naut.)</fld> <def>To move heavily and slowly, as a
ship after the sails are furled; to work one's way, as one ship in
outsailing another; -- used especially in the phrase <xex>to forge
ahead</xex>.</def> <rj><au>Totten.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And off she [a ship] <qex>forged</qex> without a shock.</q>
<rj><qau>De Quincey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forge</ent><br/
<hw>Forge</hw>, <pos>v. t.</pos> <fld>(Naut.)</fld> <def>To impel
forward slowly; <as>as, to <ex>forge</ex> a ship forward</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>forged</ent><br/
<hw>forged</hw> <pr>(f<omac/rjd)</pr>, <pos>adj.</pos> <sn>1.</sn>
<def>Not genuine; counterfeit; -- used mostly of signatures and
documents. See <er>forge</er>, <pos>v. t.</pos>, 4.</def><br/
<syn><b>Syn. --</b> bad.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>shaped by strong pressure in a press, or by heatng
and hammering; -- of metal objects.</def> <note>Also used metaphorically
of results requiring intense or difficult effort.</note><br/
[<source>PJC</source>]</p>

<p><ent>Forgeman</ent><br/
<hw>Forge"man</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Forgemen</plw> <pr>(<?/)</pr>.</plu> <def>A skilled smith, who has
a hammerer to assist him.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forger</ent><br/
<hw>For"ger</hw> <pr>(?)</pr>, <pos>n.</pos><ety>[Cf. F.
<ets>forgeur</ets> metal worker, L. <ets>fabricator</ets> artificer. See
<er>Forge</er>, <pos>n. & v. t.</pos>, and cf.
<er>Fabricator</er>.]</ety> <def>One who forges, makes, of forms; a
fabricator; a falsifier.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Especially: One guilty of forgery; one who makes or
issues a counterfeit document.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forgery</ent><br/
<hw>For"ger*y</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Forgeries</plw> <pr>(#)</pr>.</plu> <ety>[Cf. F.
<ets>forgerie</ets>.]</ety> <sn>1.</sn> <def>The act of forging metal
into shape.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Useless the <qex>forgery</qex><br/
Of brazen shield and spear.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The act of forging, fabricating, or producing
falsely; esp., the crime of fraudulently making or altering a writing or
signature purporting to be made by another; the false making or material
alteration of or addition to a written instrument for the purpose of
deceit and fraud; <as>as, the <ex>forgery</ex> of a bond</as>.</def>
<rj><au>Bouvier.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which is forged, fabricated, falsely devised,
or counterfeited.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>These are the <qex>forgeries</qex> of jealously.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The writings going under the name of Aristobulus were a
<qex>forgery</qex> of the second century.</q>
<rj><qau>Waterland.</qau></rj></p>

<p><syn><b>Syn.</b> -- <er>Counterfeit</er>; <er>Forgery</er>.</syn>
<usage> <xex>Counterfeit</xex> is chiefly used of imitations of coin, or
of paper money, or of securities depending upon pictorial devices and
engraved designs for identity or assurance of genuineness.
<xex>Forgery</xex> is more properly applied to making a false imitation
of an instrument depending on signatures to show genuineness and
validity.</usage> <rj><au>Abbott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 586 --></p>

<p><ent>Forget</ent><br/
<hw>For*get"</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp.</pos> <conjf>Forgot</conjf> <pr>(?)</pr>
(<conjf>Forgat</conjf> <pr>(<?/)</pr>, <mark>Obs</mark>.); <pos>p.
p.</pos> <conjf>Forgotten</conjf> <pr>(?)</pr>, <conjf>Forgot</conjf>;
<pos>p. pr. & vb. n.</pos> <conjf>Forgetting</conjf>.]</vmorph>
<ety>[OE. <ets>forgeten</ets>, <ets>foryeten</ets>, AS.
<ets>forgietan</ets>, <ets>forgitan</ets>; pref. <ets>for-</ets> +
<ets>gietan</ets>, <ets>gitan</ets> (only in comp.), to get; cf. D.
<ets>vergeten</ets>, G. <ets>vergessen</ets>, Sw.
<ets>f<oum/rg<aum/ta</ets>, Dan. <ets>forgiette</ets>. See
<er>For-</er>, and <er>Get</er>, <pos>v. t.</pos>]</ety> <sn>1.</sn>
<def>To lose the remembrance of; to let go from the memory; to cease to
have in mind; not to think of; also, to lose the power of; to cease from
doing.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Bless the Lord, O my soul, and <qex>forget</qex> not all his
benefits.</q> <rj><qau>Ps. ciii. 2.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Let my right hand <qex>forget</qex> her cunning.</q> <rj><qau>Ps.
cxxxvii. 5.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Hath thy knee <qex>forget</qex> to bow?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To treat with inattention or disregard; to slight;
to neglect.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Can a woman <qex>forget</qex> her sucking child? . . . Yes, they
may <qex>forget</qex>, yet will I not <qex>forget</qex> thee.</q>
<rj><qau>Is. xlix. 15.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To forget one's self</b></col>. <sd>(a)</sd> <cd>To
become unmindful of one's own personality; to be lost in thought.</cd>
<sd>(b)</sd> <cd>To be entirely unselfish.</cd> <sd>(c)</sd> <cd>To be
guilty of what is unworthy of one; to lose one's dignity, temper, or
self-control.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forgetful</ent><br/
<hw>For*get"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Apt to
forget; easily losing remembrance; <as>as, a <ex>forgetful</ex> man
should use helps to strengthen his memory</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Heedless; careless; neglectful;
inattentive.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Be not <qex>forgetful</qex> to entertain strangers.</q>
<rj><qau>Heb. xiii. 2.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Causing to forget; inducing oblivion;
oblivious.</def> <mark>[Archaic or Poetic]</mark> <ldquo/The
<xex>forgetful</xex> wine.<rdquo/ <rj><au>J. Webster.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forgetfully</ent><br/
<hw>For*get"ful*ly</hw>, <pos>adv.</pos> <def>In a forgetful
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forgetfulness</ent><br/
<hw>For*get"ful*ness</hw>, <pos>n.</pos> <sn>1.</sn> <def>The quality of
being forgetful; prononess to let slip from the mind.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Loss of remembrance or recollection; a ceasing to
remember; oblivion.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A sweet <qex>forgetfulness</qex> of human care.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Failure to bear in mind; careless omission;
inattention; <as>as, <ex>forgetfulness</ex> of duty</as>.</def></p>

<p><syn><b>Syn.</b> -- <er>Forgetfulnes</er>, <er>Oblivion</er>.</syn>
<usage> <xex>Forgetfulness</xex> is Anglo-Saxon, and <xex>oblivion</xex>
is Latin. The former commonly has reference to persons, and marks a
state of mind; the latter commonly has reference to things, and
indicates a condition into which they are sunk. We blame a man for his
<xex>forgetfulness</xex>; we speak of some old custom as buried in
<xex>oblivion</xex>. But this discrimination is not strictly adhered
to.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forgetive</ent><br/
<hw>For"ge*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From
<er>Forge</er>.]</ety> <def>Inventive; productive; capable.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forget-me-not</ent><br/
<hw>For*get"-me-not`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. G.
<ets>vergissmeinnicht</ets>.]</ety> <fld>(Bot.)</fld> <def>A small
perennial herb, of the genus <gen>Myosotis</gen> (<spn>Myosotis
scorpiodes</spn>, <spn>Myosotis palustris</spn>, <spn>Myosotis
incespitosa</spn>, etc.), bearing a beautiful bright blue or white
flowers, and extensively considered the emblem of fidelity.</def><br/
<syn><b>Syn. --</b> mouse ear, .</syn><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><note><hand/ Formerly the name was given to the <spn>Ajuga
Cham<ae/pitus</spn>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forgettable</ent><br/
<hw>For*get"ta*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Liable to be,
or that may be, forgotten.</def> <rj><au>Carlyle.</au></rj><-- = not
memorable, undistinguished --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forgetter</ent><br/
<hw>For*get"ter</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who forgets; a
heedless person.</def> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forgettingly</ent><br/
<hw>For*get"ting*ly</hw>, <pos>adv.</pos> <def>By forgetting.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forging</ent><br/
<hw>For"ging</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The act
of shaping metal by hammering or pressing.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The act of counterfeiting.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Mach.)</fld> <def>A piece of forged work in metal;
-- a general name for a piece of hammered iron or steel.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There are very few yards in the world at which such
<qex>forgings</qex> could be turned out.</q> <rj><qau>London
Times.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forgivable</ent><br/
<hw>For*giv"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of being
forgiven; pardonable; venial.</def> <rj><au>Sherwood.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forgive</ent><br/
<hw>For*give"</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp.</pos> <conjf>Forgave</conjf> <pr>(?)</pr>; <pos>p.
p.</pos> <conjf>Forgiven</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Forgiving</conjf>]</vmorph> <ety>[OE.
<ets>forgiven</ets>, <ets>foryiven</ets>, <ets>foryeven</ets>, AS.
<ets>forgiefan</ets>, <ets>forgifan</ets>; perh. <ets>for-</ets> +
<ets>giefan</ets>, <ets>gifan</ets> to give; cf. D. <ets>vergeven</ets>,
G. <ets>vergeben</ets>, Icel. <ets>fyrirgefa</ets>, Sw.
<ets>f<?/rgifva</ets>, Goth. <ets>fragiban</ets> to give, grant. See
<er>For-</er>, and <er>Give</er>, <pos>v. t.</pos>]</ety> <sn>1.</sn>
<def>To give wholly; to make over without reservation; to
resign.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To them that list the world's gay shows I leave,<br/
And to great ones such folly do <qex>forgive</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To give up resentment or claim to requital on
account of (an offense or wrong); to remit the penalty of; to pardon; --
said in reference to the act forgiven.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And their sins should be <qex>forgiven</qex> them.</q>
<rj><qau>Mark iv. 12.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He <qex>forgive</qex> injures so readily that he might be said to
invite them.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To cease to feel resentment against, on account of
wrong committed; to give up claim to requital from or retribution upon
(an offender); to absolve; to pardon; -- said of the person
offending.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Father, <qex>forgive</qex> them; for they know not what they
do.</q> <rj><qau>Luke xxiii. 34.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I as free <qex>forgive</qex> you, as I would be
<qex>fforgiven</qex>.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Sometimes both the person and the offense follow as
objects of the verb, sometimes one and sometimes the other being the
indirect object. <ldquo/<xex>Forgive</xex> us our debts as we
<xex>forgive</xex> our debtors.<rdquo/ <au>Matt. vi. 12.</au> <ldquo/Be
of good cheer; thy sins be <xex>forgiven</xex> thee.<rdquo/ <au>Matt.
ix. 2.</au></note></p>

<p><syn><b>Syn.</b> -- See <er>excuse</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forgiveness</ent><br/
<hw>For*give"ness</hw>, <pos>n.</pos> <ety>[AS.
<ets>forgifnes</ets>.]</ety> <sn>1.</sn> <def>The act of forgiving; the
state of being forgiven; <as>as, the <ex>forgiveness</ex> of sin or of
injuries</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To the Lord our God belong mercies and
<qex>forgivenesses</qex>.</q> <rj><qau>Dan. ix. 9.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>In whom we have . . . the <qex>forgiveness</qex> of sin.</q>
<rj><qau>Eph. i. 7.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Disposition to pardon; willingness to
forgive.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If thou, Lord, shouldest mark iniquities, O Lord, who shall stand?
But there is <qex>forgiveness</qex> with thee, that thou mayest be
feared.</q> <rj><qau>Ps. cxxx. 3, 4.</qau></rj></p>

<p><syn><b>Syn.</b> -- Pardon, remission.</syn> <usage> --
<er>Forgiveness</er>, <er>Pardon</er>. <xex>Forgiveness</xex> is
Anglo-Saxon, and <xex>pardon</xex> Norman French, both implying a
<xex>giving back</xex>. The word <xex>pardon</xex>, being early used in
our Bible, has, in religious matters, the same sense as
<xex>forgiveness</xex>; but in the language of common life there is a
difference between them, such as we often find between corresponding
Anglo-Saxon and Norman words. <xex>Forgive</xex> points to inward
feeling, and suppose alienated affection; when we ask
<xex>forgiveness</xex>, we primarily seek the removal of anger.
<xex>Pardon</xex> looks more to outward things or consequences, and is
often applied to trifling matters, as when we beg <xex>pardon</xex> for
interrupting a man, or for jostling him in a crowd. The civil magistrate
also grants a <xex>pardon</xex>, and not <xex>forgiveness</xex>. The two
words are, therefore, very clearly distinguished from each other in most
cases which relate to the common concerns of life.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forgiver</ent><br/
<hw>For*giv"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
forgives.</def> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forgiving</ent><br/
<hw>For*giv"ing</hw>, <pos>a.</pos> <def>Disposed to forgive; inclined
to overlook offenses; mild; merciful; compassionate; placable; <as>as, a
<ex>forgiving</ex> temper</as>.</def></p>

<p>-- <wordforms><wf>For*giv"ing*ly</wf>, <pos>adv.</pos> --
<wf>For*giv"ing*ness</wf>, <pos>n.</pos></wordforms> <rj><au>J. C.
Shairp.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>forgivingness</ent><br/
<hw>forgivingness</hw> <pos>n.</pos> <def>a tendency to be kind and
forgiving.</def><br/
<syn><b>Syn. --</b> kindness.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Forgo</ent><br/
<hw>For*go"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.</pos>
<conjf>Forwent</conjf>; <pos>p. p.</pos> <conjf>Forgone</conjf>; <pos>p.
pr. & vb. n.</pos> <conjf>Forgoing</conjf>.]</vmorph> <ety>[OE.
<ets>forgan</ets>, <ets>forgon</ets>, <ets>forgoon</ets>, AS.
forg<amac/n, prop., to go past, hence, to abstain from; pref.
<ets>for-</ets> + <ets>g<amac/n</ets> to go; akin to G.
<ets>vergehen</ets> to pass away, to transgress. See <er>Go</er>,
<pos>v. i.</pos>]</ety> <sn>1.</sn> <def>To pass by; to leave. See 1st
<er>Forego</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>For sith [since] I shall <qex>forgoon</qex> my liberty<br/
At your request.</q> <rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And four [days] since Florimell the court <qex>forwent</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>to abstain from; to do without; to refrain from; to
renounce; -- said of a thing already enjoyed, or of one within reach, or
anticipated. See 1st <er>forego</er>, 2.</def><br/
[<source>PJC</source>]</p>

<p><note><hand/ This word in spelling has been confused with, and almost
superseded by, <xex>forego</xex> to go before. Etymologically the form
<xex>forgo</xex> is correct.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forgot</ent><br/
<hw>For*got"</hw> <pr>(?)</pr>, <def><pos>imp. & p. p.</pos> of
<er>Forget</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forgotten</ent><br/
<hw>For*got"ten</hw> <pr>(?)</pr>, <def><pos>p. p.</pos> of
<er>Forget</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forhall</ent><br/
<hw>For*hall"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>for-</ets> + <ets>hale</ets> to draw.]</ety> <def>To harass; to
torment; to distress.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forhend</ent><br/
<hw>For*hend"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To seize
upon.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forinsecal</ent><br/
<hw>Fo*rin"se*cal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>forinsecus</ets> from without.]</ety> <def>Foreign; alien.</def>
<mark>[Obs.]</mark> <rj><au>Bp. Burnet.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forisfamiliate</ent><br/
<hw>Fo`ris*fa*mil"i*ate</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Forisfamiliated</conjf>
<pr>(?)</pr>; <pos>p. pr. & vb. n.</pos> <conjf>Forisfamiliating</conjf>
<pr>(?)</pr>.]</vmorph> <ety>[LL. <ets>forisfamiliatus</ets>, p. p. of
<ets>forisfamiliater</ets> to forisfamiliate; L. <ets>foris</ets>
abroad, without + <ets>familia</ets> family.]</ety> <fld>(LAw)</fld>
<def>Literally, to put out of a family; hence, to portion off, so as to
exclude further claim of inheritance; to emancipate (as a with his own
consent) from paternal authority.</def>
<rj><au>Blackstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forisfamiliate</ent><br/
<hw>Fo`ris*fa*mil"i*ate</hw>, <pos>v. i.</pos> <fld>(Law)</fld> <def>To
renounce a legal title to a further share of paternal
inheritance.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forisfamiliation</ent><br/
<hw>Fo`ris*fa*mil`i*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Law)</fld> <def>The act of forisfamiliating.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fork</ent><br/
<hw>Fork</hw> <pr>(f<ocir/rk)</pr>, <pos>n.</pos> <ety>[AS.
<ets>forc</ets>, fr. L. <ets>furca</ets>. Cf. <er>Fourch<eacute/</er>,
<er>Furcate</er>.]</ety> <sn>1.</sn> <def>An instrument consisting of a
handle with a shank terminating in two or more prongs or tines, which
are usually of metal, parallel and slightly curved; -- used for
piercing, holding, taking up, or pitching anything.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Anything furcate or like a fork in shape, or furcate
at the extremity; <as>as, a tuning <ex>fork</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>One of the parts into which anything is furcated or
divided; a prong; a branch of a stream, a road, etc.; a barbed point, as
of an arrow.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Let it fall . . . though the <qex>fork</qex> invade<br/
The region of my heart.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A thunderbolt with three <qex>forks</qex>.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The place where a division or a union occurs; the
angle or opening between two branches or limbs; <as>as, the
<ex>fork</ex> of a river, a tree, or a road</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>The gibbet.</def> <mark>[Obs.]</mark> <rj><au>Bp.
Butler.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fork beam</b></col> <fld>(Shipbuilding)</fld>, <cd>a half
beam to support a deck, where hatchways occur.</cd> -- <col><b>Fork
chuck</b></col> <fld>(Wood Turning)</fld>, <cd>a lathe center having two
prongs for driving the work.</cd> -- <col><b>Fork head</b></col>.
<sd>(a)</sd> <cd>The barbed head of an arrow.</cd> <sd>(b)</sd> <cd>The
forked end of a rod which forms part of a knuckle joint.</cd> --
<col><b>In fork</b></col>. <fld>(Mining)</fld> <cd>A mine is said to be
<xex>in fork</xex>, or an engine to <ldquo/have the water <xex>in
fork</xex>,<rdquo/ when all the water is drawn out of the mine.</cd>
<au>Ure.</au> -- <mcol><col><b>The forks of a river</b></col>
<it>or</it> <col><b>The forks of a road</b></col></mcol>, <cd>the
branches into which it divides, or which come together to form it; the
place where separation or union takes place.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fork</ent><br/
<hw>Fork</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Forked</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Forking</conjf>.]</vmorph> <sn>1.</sn> <def>To shoot into blades,
as corn.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The corn beginneth to <qex>fork</qex>.</q>
<rj><qau>Mortimer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To divide into two or more branches; <as>as, a road,
a tree, or a stream <ex>forks</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fork</ent><br/
<hw>Fork</hw>, <pos>v. t.</pos> <def>To raise, or pitch with a fork, as
hay; to dig or turn over with a fork, as the soil.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Forking</qex> the sheaves on the high-laden cart.</q>
<rj><qau>Prof. Wilson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>To fork over</b></col> <col><b>To fork
out</b></col></mcol>, <cd>to hand or pay over, as money; to <cref>cough
up</cref>.</cd> <mark>[Slang]</mark> <rj><au>G.
Eliot.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forkbeard</ent><br/
<hw>Fork"beard`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<sd>(a)</sd> <def>A European fish (<spn>Raniceps raninus</spn>), having
a large flat head; -- also called <altname>tadpole fish</altname>, and
<altname>lesser forked beard</altname>.</def> <sd>(b)</sd> <def>The
European forked hake or hake's-dame (<spn>Phycis blennoides</spn>); --
also called <altname>great forked beard</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forked</ent><br/
<hw>Forked</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Formed into
a forklike shape; having a fork; dividing into two or more prongs or
branches; furcated; bifurcated; zigzag; <as>as, the <ex>forked</ex>
lighting</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A serpent seen, with <qex>forked</qex> tongue.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Having a double meaning; ambiguous;
equivocal.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Cross forked</b></col> <fld>(Her.)</fld>, <cd>a cross,
the ends of whose arms are divided into two sharp points; -- called also
<altname>cross double fitch<eacute/</altname>. A <stype>cross forked of
three points</stype> is a cross, each of whose arms terminates in three
sharp points.</cd> -- <col><b>Forked counsel</b></col>, <cd>advice
pointing more than one way; ambiguous advice.</cd> <mark>[Obs.]</mark>
<au>B. Jonson.</au></cs></p>

<p>-- <wordforms><wf>Fork"ed*ly</wf> <pr>(#)</pr>, <pos>adv.</pos> --
<wf>Fork"ed*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forkerve</ent><br/
<hw>For*kerve</hw> <pr>(?)</pr>, <pos>v. t.</pos> <mark>[Obs.]</mark>
<def>See <er>Forcarve</er>, <pos>v. t.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forkiness</ent><br/
<hw>Fork"i*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The quality or
state or dividing in a forklike manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forkless</ent><br/
<hw>Fork"less</hw>, <pos>a.</pos> <def>Having no fork.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forktail</ent><br/
<hw>Fork"tail`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<sd>(a)</sd> <def>One of several Asiatic and East Indian passerine
birds, belonging to <gen>Enucurus</gen>, and allied genera. The tail is
deeply forked.</def> <sd>(b)</sd> <def>A salmon in its fourth year's
growth.</def> <mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fork-tailed</ent><br/
<hw>Fork"-tailed`</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Having the outer tail feathers longer than the median ones;
swallow-tailed; -- said of many birds.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fork-tailed flycatcher</b></col> <fld>(Zool.)</fld>,
<cd>a tropical American flycatcher (<spn>Milvulus tyrannus</spn>).</cd>
-- <col><b>Fork-tailed gull</b></col> <fld>(Zool.)</fld>, <cd>a gull of
the genus <gen>Xema</gen>, of two species, esp. <spn>X. Sabinii</spn> of
the Arctic Ocean.</cd> -- <col><b>Fork-tailed kite</b></col>
<fld>(Zool.)</fld>, <cd>a graceful American kite (<spn>Elanoides
forficatus</spn>); -- called also <altname>swallow-tailed
kite</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forky</ent><br/
<hw>Fork"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Opening into two or
more parts or shoots; forked; furcated.</def> <ldquo/<xex>Forky</xex>
tongues.<rdquo/ <rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forlaft</ent><br/
<hw>For*laft"</hw> <pr>(?)</pr>, <mark>obs.</mark> <def><pos>p. p.</pos>
of <er>Forleave</er>.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forlay</ent><br/
<hw>For*lay"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>for-</ets> + <ets>lay</ets>.]</ety> <def>To lie in wait for; to
ambush.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>An ambushed thief <qex>forlays</qex> a traveler.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forleave</ent><br/
<hw>For*leave"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[OE.
<ets>forleven</ets>; pref. <ets>for-</ets> + <ets>leven</ets> to
leave.]</ety> <def>To leave off wholly.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forlend</ent><br/
<hw>For*lend"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To give up
wholly.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forlese</ent><br/
<hw>For*lese"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>p.
p.</pos> <conjf>Forlore</conjf> <pr>(?)</pr>, <conjf>Forlorn</conjf>
<pr>(<?/)</pr>.]</vmorph> <ety>[OE. <ets>forlesen</ets>. See
<er>Forlorn</er>.]</ety> <def>To lose utterly.</def> <mark>[Obs.]</mark>
<rj><au>haucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forlet</ent><br/
<hw>For*let"</hw>, <pos>v. t.</pos> <ety>[OE. <ets>forleten</ets>, AS.
<ets>forl<aemac/tan</ets>; pref. <ets>for-</ets> +
<ets>l<aemac/tan</ets> to allow; akin to G. <ets>verlassen</ets> to
leave. See <er>Let</er> to allow.]</ety> <def>To give up; to leave; to
abandon.</def> <mark>[Obs.]</mark> <ldquo/To <xex>forlet</xex>
sin.<rdquo/ <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forlie</ent><br/
<hw>For*lie"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>See
<er>Forelie</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forlore</ent><br/
<hw>For*lore"</hw> <pr>(?)</pr>, <def><pos>imp. pl. & p. p.</pos> of
<er>Forlese</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The beasts their caves, the birds their nests
<qex>forlore</qex>.</q> <rj><qau>Fairfax.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forlorn</ent><br/
<hw>For*lorn"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OE., p. p. of
<ets>forlesen</ets> to lose utterly, AS. <ets>forle<oacute/san</ets> (p.
p. <ets>forloren</ets>); pref. <ets>for-</ets> +
<ets>le<oacute/san</ets> (in comp.) to lose; cf. D. <ets>verliezen</ets>
to lose, G. <ets>verlieren</ets>, Sw. <ets>f<oum/rlora</ets>, Dan.
<ets>forloren</ets>, Goth. <ets>fraliusan</ets> to lose. See
<er>For-</er>, and <er>Lorn</er>, <pos>a.</pos>, <er>Lose</er>, <pos>v.
t.</pos>]</ety> <sn>1.</sn> <def>Deserted; abandoned; lost.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Of fortune and of hope at once <qex>forlorn</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Some say that ravens foster <qex>forlorn</qex> children.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Destitute; helpless; in pitiful plight; wretched;
miserable; almost hopeless; desperate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>For here <qex>forlorn</qex> and lost I tread.</q>
<rj><qau>Goldsmith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The condition of the besieged in the mean time was
<qex>forlorn</qex> in the extreme.</q> <rj><qau>Prescott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>She cherished the <qex>forlorn</qex> hope that he was still
living.</q> <rj><qau>Thomson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>A forlorn hope</b></col> <ety>[D. <ets>verloren
hoop</ets>, prop., a lost band or troop; <ets>verloren</ets>, p. p. of
<ets>verliezen</ets> to lose + <ets>hoop</ets> band; akin to E.
<ets>heap</ets>. See <er>For-</er>, and <er>Heap</er>.]</ety>
<fld>(Mil.)</fld>, <cd>a body of men (called in F. <altname>enfants
perdus</altname>, in G. <altname>verlornen posten</altname>) selected,
usually from volunteers, to attempt a breach, scale the wall of a
fortress, or perform other extraordinarily perilous service; also, a
desperate case or enterprise.</cd></cs></p>

<p><syn><b>Syn.</b> -- Destitute, lost; abandoned; forsaken; solitary;
helpless; friendless; hopeless; abject; wretched; miserable;
pitiable.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forlorn</ent><br/
<hw>For*lorn"</hw>, <pos>n.</pos> <sn>1.</sn> <def>A lost, forsaken, or
solitary person.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Forced to live in Scotland a <qex>forlorn</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A forlorn hope; a vanguard.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Our <qex>forlorn</qex> of horse marched within a mile of the
enemy.</q> <rj><qau>Oliver Cromvell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forlornly</ent><br/
<hw>For*lorn"ly</hw>, <pos>adv.</pos> <def>In a forlorn manner.</def>
<rj><au>Pollok.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forlornness</ent><br/
<hw>For*lorn"ness</hw>, <pos>n.</pos> <def>State of being forlorn.</def>
<rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forlye</ent><br/
<hw>For*lye"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>Same as
<er>Forlie</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>-form</ent><br/
<hw>-form</hw> <pr>(<?/)</pr>. <ety>[See <er>Form</er>,
<pos>n.</pos>]</ety> <def>A suffix used to denote <sig>in the form
<it>or</it> shape of</sig>, <sig>resembling</sig>, etc.; <as>as,
vali<ex>form</ex>; ovi<ex>form</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Form</ent><br/
<hw>Form</hw> <pr>(f<omac/rm; <xex>in senses</xex> 8 & 9,
<xex>often</xex> f<omac/rm <xex>in England</xex>)</pr>, <pos>n.</pos>
<ety>[OE. & F. <ets>forme</ets>, fr. L. <ets>forma</ets>; cf. Skr.
<ets>dhariman</ets>. Cf. <er>Firm</er>.]</ety> <sn>1.</sn> <def>The
shape and structure of anything, as distinguished from the material of
which it is composed; particular disposition or arrangement of matter,
giving it individuality or distinctive character; configuration; figure;
external appearance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>form</qex> of his visage was changed.</q> <rj><qau>Dan.
iii. 19.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And woven close close, both matter, <qex>form</qex>, and
style.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Constitution; mode of construction, organization,
etc.; system; <as>as, a republican <ex>form</ex> of
government</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Established method of expression or practice; fixed
way of proceeding; conventional or stated scheme; formula; <as>as, a
<ex>form</ex> of prayer</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Those whom <qex>form</qex> of laws<br/
Condemned to die.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Show without substance; empty, outside appearance;
vain, trivial, or conventional ceremony; conventionality; formality;
<as>as, a matter of mere <ex>form</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Though well we may not pass upon his life<br/
Without the <qex>form</qex> of justice.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Orderly arrangement; shapeliness; also, comeliness;
elegance; beauty.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The earth was without <qex>form</qex> and void.</q> <rj><qau>Gen.
i. 2.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He hath no <qex>form</qex> nor comeliness.</q> <rj><qau>Is. liii.
2.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>A shape; an image; a phantom.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>That by which shape is given or determined; mold;
pattern; model.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>A long seat; a bench; hence, a rank of students in a
school; a class; also, a class or rank in society.</def> <ldquo/Ladies
of a high <xex>form</xex>.<rdquo/ <rj><au>Bp. Burnet.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>The seat or bed of a hare.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>As in a <qex>form</qex> sitteth a weary hare.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <fld>(Print.)</fld> <def>The type or other matter from
which an impression is to be taken, arranged and secured in a
chase.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>11.</sn> <fld>(Fine Arts)</fld> <def>The boundary line of a
material object. In <fld>(painting)</fld>, more generally, the human
body.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>12.</sn> <fld>(Gram.)</fld> <def>The particular shape or
structure of a word or part of speech; <as>as, participial
<ex>forms</ex>; verbal <ex>forms</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>13.</sn> <fld>(Crystallog.)</fld> <def>The combination of planes
included under a general crystallographic symbol. It is not necessarily
a closed solid.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>14.</sn> <fld>(Metaph.)</fld> <def>That assemblage or disposition
of qualities which makes a conception, or that internal constitution
which makes an existing thing to be what it is; -- called
<xex>essential</xex> or <xex>substantial form</xex>, and
contradistinguished from <xex>matter</xex>; hence, active or formative
nature; law of being or activity; subjectively viewed, an idea;
objectively, a law.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>15.</sn> <def>Mode of acting or manifestation to the senses, or
the intellect; <as>as, water assumes the <ex>form</ex> of ice or
snow</as>. In modern usage, the elements of a conception furnished by
the mind's own activity, as contrasted with its object or condition,
which is called the <xex>matter</xex>; subjectively, a mode of
apprehension or belief conceived as dependent on the constitution of the
mind; objectively, universal and necessary accompaniments or elements of
every object known or thought of.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>16.</sn> <fld>(Biol.)</fld> <def>The peculiar characteristics of
an organism as a type of others; also, the structure of the parts of an
animal or plant.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 587 --></p>

<p><cs><mcol><col><b>Good form</b></col> <it>or</it> <col><b>Bad
form</b></col></mcol>, <cd>the general appearance, condition or action,
originally of horses, afterwards of persons; as, the members of a boat
crew are said to be in <ex>good form</ex> when they pull together
uniformly. The phrases are further used colloquially in description of
conduct or manners in society; as, it is not <ex>good form</ex> to smoke
in the presence of a lady.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Form</ent><br/
<hw>Form</hw> <pr>(f<ocir/rm)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Formed</conjf> <pr>(f<ocir/rmd)</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>Forming</conjf>.]</vmorph> <ety>[F.
<ets>former</ets>, L. <ets>formare</ets>, fr. <ets>forma</ets>. See
<er>Form</er>, <pos>n.</pos>]</ety> <sn>1.</sn> <def>To give form or
shape to; to frame; to construct; to make; to fashion.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>God <qex>formed</qex> man of the dust of the ground.</q>
<rj><qau>Gen. ii. 7.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The thought that labors in my <qex>forming</qex> brain.</q>
<rj><qau>Rowe.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To give a particular shape to; to shape, mold, or
fashion into a certain state or condition; to arrange; to adjust; also,
to model by instruction and discipline; to mold by influence, etc.; to
train.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>'T is education <qex>forms</qex> the common mind.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Thus <qex>formed</qex> for speed, he challenges the wind.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To go to make up; to act as constituent of; to be
the essential or constitutive elements of; to answer for; to make the
shape of; -- said of that out of which anything is formed or
constituted, in whole or in part.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The diplomatic politicians . . . who <qex>formed</qex> by far the
majority.</q> <rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To provide with a form, as a hare. See
<er>Form</er>, <pos>n.</pos>, 9.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The melancholy hare is <qex>formed</qex> in brakes and briers.</q>
<rj><qau>Drayton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Gram.)</fld> <def>To derive by grammatical rules,
as by adding the proper suffixes and affixes.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Elec.)</fld> <def>To treat (plates) so as to bring
them to fit condition for introduction into a storage battery, causing
one plate to be composed more or less of spongy lead, and the other of
lead peroxide. This was formerly done by repeated slow alternations of
the charging current, but now the plates or grids are coated or filled,
one with a paste of red lead and the other with litharge, introduced
into the cell, and <ex>formed</ex> by a direct charging
current.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Form</ent><br/
<hw>Form</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To take a form,
definite shape, or arrangement; <as>as, the infantry should
<ex>form</ex> in column</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To run to a form, as a hare.</def> <rj><au>B.
Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To form on</b></col> <fld>(Mil.)</fld>, <cd>to form a
lengthened line with reference to (any given object) as a
basis.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Formal</ent><br/
<hw>For"mal</hw> <pr>(f<ocir/r"m<ait/l)</pr>, <pos>n.</pos> <ety>[L.
<ets>form</ets>ic + <ets>al</ets>cohol.]</ety> <fld>(Chem.)</fld>
<def>See <er>Methylal</er>.</def></p>

<p><ent>Formal</ent><br/
<hw>Form"al</hw> <pr>(f<ocir/rm"<ait/l)</pr>, <pos>a.</pos> <ety>[L.
<ets>formalis</ets>: cf. F. <ets>formel</ets>.]</ety> <sn>1.</sn>
<def>Belonging to the form, shape, frame, external appearance, or
organization of a thing.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Belonging to the constitution of a thing, as
distinguished from the matter composing it; having the power of making a
thing what it is; constituent; essential; pertaining to or depending on
the forms, so called, of the human intellect.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Of [the sounds represented by] letters, the material part is
breath and voice; the <qex>formal</qex> is constituted by the motion and
figure of the organs of speech.</q> <rj><qau>Holder.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Done in due form, or with solemnity; according to
regular method; not incidental, sudden or irregular; express; <as>as, he
gave his <ex>formal</ex> consent</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His obscure funeral . . . <br/
No noble rite nor <qex>formal</qex> ostentation.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Devoted to, or done in accordance with, forms or
rules; punctilious; regular; orderly; methodical; of a prescribed form;
exact; prim; stiff; ceremonious; <as>as, a man <ex>formal</ex> in his
dress, his gait, his conversation</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A cold-looking, <qex>formal</qex> garden, cut into angles and
rhomboids.</q> <rj><qau>W. Irwing.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>She took off the <qex>formal</qex> cap that confined her hair.</q>
<rj><qau>Hawthorne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Having the form or appearance without the substance
or essence; external; <as>as, <ex>formal</ex> duty; <ex>formal</ex>
worship; <ex>formal</ex> courtesy, etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Dependent in form; conventional.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Still in constraint your suffering sex remains,<br/
Or bound in <qex>formal</qex> or in real chains.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>Sound; normal.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>To make of him a <qex>formal</qex> man again.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Formal cause</b></col>. <cd>See under
<er>Cause</er>.</cd></cs></p>

<p><syn><b>Syn.</b> -- Precise; punctilious; stiff; starched; affected;
ritual; ceremonial; external; outward.</syn> <usage> -- <er>Formal</er>,
<er>Ceremonious</er>. When applied to things, these words usually denote
a mere accordance with the rules of form or ceremony; as, to make a
<xex>formal</xex> call; to take a <xex>ceremonious</xex> leave. When
applied to a person or his manners, they are used in a bad sense; a
person being called <xex>formal</xex> who shapes himself too much by
some pattern or set form, and <xex>ceremonious</xex> when he lays too
much stress on the conventional laws of social intercourse.
<xex>Formal</xex> manners render a man stiff or ridiculous; a
<xex>ceremonious</xex> carriage puts a stop to the ease and freedom of
social intercourse.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Formaldehyde</ent><br/
<hw>For*mal"de*hyde</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Form</ets>ic + <ets>aldehyde</ets>.]</ety> <fld>(Chem.)</fld>
<def>A colorless, volatile liquid, <chform>H2CO</chform>, resembling
acetic or ethyl aldehyde, and chemically intermediate between methyl
alcohol and formic acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Formalin</ent><br/
<hw>For"ma*lin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Form</ets>ic
+ <ets>al</ets>dehyde + <ets>-in</ets>.]</ety> <fld>(Chem.)</fld>
<def>An aqueous solution of formaldehyde, used as a preservative in
museums and as a disinfectant.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Formalism</ent><br/
<hw>Form"al*ism</hw> <pr>(f<ocir/rm"<ait/l*<icr/z'm)</pr>, <pos>n.</pos>
<def>The practice or the doctrine of strict adherence to, or dependence
on, external forms, esp. in matters of religion.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Official <qex>formalism</qex>.</q> <rj><qau>Sir H.
Rawlinson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Formalist</ent><br/
<hw>Form"al*ist</hw>, <pos>n.</pos> <ety>[Cf. F.
<ets>formaliste</ets>.]</ety> <def>One overattentive to forms, or too
much confined to them; esp., one who rests in external religious forms,
or observes strictly the outward forms of worship, without possessing
the life and spirit of religion.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>As far a <qex>formalist</qex> from wisdom sits,<br/
In judging eyes, as libertines from wits.</q>
<rj><qau>Young.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Formality</ent><br/
<hw>For*mal"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Formalities</plw> <pr>(#)</pr>.</plu> <ety>[Cf. F.
<ets>formalit<eacute/</ets>.]</ety> <sn>1.</sn> <def>The condition or
quality of being formal, strictly ceremonious, precise, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Form without substance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Such [books] as are mere pieces of <qex>formality</qex>, so that
if you look on them, you look though them.</q>
<rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Compliance with formal or conventional rules;
ceremony; conventionality.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Nor was his attendance on divine offices a matter of
<qex>formality</qex> and custom, but of conscience.</q>
<rj><qau>Atterbury.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>An established order; conventional rule of
procedure; usual method; habitual mode.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He was installed with all the usual <qex>formalities</qex>.</q>
<rj><qau>C. Middleton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <pluf>pl.</pluf> <def>The dress prescribed for any body
of men, academical, municipal, or sacerdotal.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The doctors attending her in their <qex>formalities</qex> as far
as Shotover.</q> <rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>That which is formal; the formal part.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It unties the inward knot of marriage, . . . while it aims to keep
fast the outward <qex>formality</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>The quality which makes a thing what it is;
essence.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The material part of the evil came from our father upon us, but
the <qex>formality</qex> of it, the sting and the curse, is only by
ourselves.</q> <rj><qau>Jer. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>formality</qex> of the vow lies in the promise made to
God.</q> <rj><qau>Bp. Stillingfleet.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <fld>(Scholastic. Philos.)</fld> <def>The manner in which
a thing is conceived or constituted by an act of human thinking; the
result of such an act; <as>as, animality and rationality are
<ex>formalities</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>formalities</ent><br/
<hw>formalities</hw> <pos>n.</pos> <def>a set of procedures required to
make a transaction official.</def><br/
<syn><b>Syn. --</b> form, formality.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Formalize</ent><br/
<hw>Form"al*ize</hw> <pr>(f<ocir/rm"<ait/l*<imac/z)</pr>, <pos>v.
t.</pos> <vmorph>[<pos>imp. & p. p.</pos> <conjf>Formalized</conjf>
<pr>(f<ocir/rm"<ait/l*<imac/zd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Formalizing</conjf>
<pr>(f<ocir/rm"<ait/l*<imac/`z<icr/ng)</pr>.]</vmorph> <sn>1.</sn>
<def>To give form, or a certain form, to; to model.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To render formal.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Formalize</ent><br/
<hw>Form"al*ize</hw>, <pos>v. i.</pos> <def>To affect formality.</def>
<mark>[Obs.]</mark> <rj><au>ales.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>formalized</ent><br/
<hw>formalized</hw> <pos>adj.</pos> <sn>1.</sn> <def>concerned with or
characterized by rigorous adherence to recognized forms, especially in
religion or art; using formalism; <as>as, highly <ex>formalized</ex>
plays like "Waiting for Godot"</as>.</def><br/
<syn><b>Syn. --</b> formalistic.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>given formal standing or endorsement; made official
or legitimate by the observance of proper procedures.</def>
<hascons>official (vs. unofficial) --- (having official authority or
sanction: "official permission"; "an official
representative")</hascons><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Formally</ent><br/
<hw>Form"al*ly</hw>, <pos>adv.</pos> <def>In a formal manner;
essentially; characteristically; expressly; regularly; ceremoniously;
precisely.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That which <qex>formally</qex> makes this [charity] a Christian
grace, is the spring from which it flows.</q>
<rj><qau>Smalridge.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>You and your followers do stand <qex>formally</qex> divided
against the authorized guides of the church and rest of the people.</q>
<rj><qau>Hooker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>formalwear</ent><br/
<hw>formalwear</hw> <pos>n.</pos> <def>attire to wear on formal
occasions in the evening.</def><br/
<syn><b>Syn. --</b> eveningwear, evening dress, evening
clothes.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Format</ent><br/
\'d8<hw>For`mat"</hw> <pr>(f<osl/r`m<adot/" <it>or</it>
f<osl/r`m<aum/t")</pr>, <pos>n.</pos> <ety>[F. or G. Cf.
<er>Formation</er>.]</ety> <sn>1.</sn> <fld>(Print.)</fld> <def>The
shape and size of a book or other printed publication; hence, its
external form.</def> <wns>[wns=2]</wns><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><q>The older manuscripts had been written in a much larger
<qex>format</qex> than that found convenient for university work.</q>
<rj><qau>G. H. Putnam.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><q>One might, indeed, protest that the <qex>format</qex> is a little
too luxurious.</q> <rj><qau>Nature.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <fld>(Print.)</fld> <def>the arrangement of the parts of
a printed page, such as text and graphics; <as>as, text flowing around
an illustration provides a more pleasing <ex>format</ex>; multiple
columns are a more common <ex>format</ex> for large
pages</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <fld>(Computers)</fld> <def>The pattern of organization
of information in an electronic storage medium, such as the number and
size of records, or the size, spacing, or separation symbols for fields
in a record. A computer file, for example, may be in fixed-length
<ex>format</ex>, in which each field or record occupies the same number
of bytes, or in variable-length <ex>format</ex>, in which the lengths of
fields or records varies. The number of <ex>formats</ex> are unlimited,
being specifiable at will by programmers or in some cases by the users
of programs.</def> <wns>[wns=1]</wns><br/
<syn><b>Syn. --</b> data format.</syn><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <specif>Hence,</specif> <def>The general organization,
form, or plan for anything, such as an organized social, political, or
entertainment event.</def><br/
[<source>PJC</source>]</p>

<p><ent>format</ent><br/
<hw>format</hw> <pos>v. t.</pos> <def>to set into a specific format; --
of printed matter or data recorded on a data storage medium.</def><br/
<syn><b>Syn. --</b> arrange.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Formate</ent><br/
<hw>For"mate</hw> <pr>(f<ocir/r"m<asl/t)</pr>, <pos>n.</pos> <ety>[See
<er>Formic</er>.]</ety> <fld>(Chem.)</fld> <def>A salt of formic
acid.</def> <altsp>[Written also <asp>formiate</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Formation</ent><br/
<hw>For*ma"tion</hw> <pr>(f<ocr/r*m<amac/"sh<ucr/n)</pr>, <pos>n.</pos>
<ety>[L. <ets>formatio</ets>: cf. F. <ets>formation</ets>.]</ety>
<sn>1.</sn> <def>The act of giving form or shape to anything; a forming;
a shaping.</def> <rj><au>Beattie.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The manner in which a thing is formed; structure;
construction; conformation; form; <as>as, the peculiar
<ex>formation</ex> of the heart</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A substance formed or deposited.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Geol.)</fld> <sd>(a)</sd> <def>Mineral deposits and
rock masses designated with reference to their origin; <as>as, the
siliceous <ex>formation</ex> about geysers; alluvial
<ex>formations</ex>; marine <ex>formations</ex>.</as></def> <sd>(b)</sd>
<def>A group of beds of the same age or period; <as>as, the Eocene
<ex>formation</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Mil.)</fld> <def>The arrangement of a body of
troops, as in a square, column, etc.</def> <rj><au>Farrow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Formative</ent><br/
<hw>Form"a*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>formatif</ets>.]</ety> <sn>1.</sn> <def>Giving form; having the
power of giving form; plastic; <as>as, the <ex>formative</ex>
arts</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The meanest plant can not be raised without seed, by any
<qex>formative</qex> residing in the soil.</q>
<rj><qau>Bentley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Gram.)</fld> <def>Serving to form; derivative; not
radical; <as>as, a termination merely <ex>formative</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Biol.)</fld> <def>Capable of growth and
development; germinal; <as>as, living or <ex>formative</ex>
matter</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Formative</ent><br/
<hw>Form"a*tive</hw>, <pos>n.</pos> <fld>(Gram.)</fld> <sd>(a)</sd>
<def>That which serves merely to give form, and is no part of the
radical, as the prefix or the termination of a word.</def> <sd>(b)</sd>
<def>A word formed in accordance with some rule or usage, as from a
root.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forme</ent><br/
<hw>For`m<eacute/"</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Her.)</fld>
<def>Same as <er>Pat<eacute/</er> or <er>Patt<eacute/</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forme</ent><br/
<hw>For"me</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OE., fr. AS.
<ets>forma</ets>. See <er>Foremost</er>.]</ety> <def>First.</def>
<mark>[Obs.]</mark> <ldquo/Adam our <xex>forme</xex> father.<rdquo/
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Formed</ent><br/
<hw>Formed</hw> <pr>(f<ocir/rmd)</pr>, <pos>a.</pos> <sn>1.</sn>
<fld>(Astron.)</fld> <def>Arranged, as stars in a constellation; <as>as,
<ex>formed</ex> stars</as>.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Biol.)</fld> <def>Having structure; capable of
growth and development; organized; <as>as, the <ex>formed</ex> or
organized ferments</as>. See <er>Ferment</er>, <pos>n.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Formed material</b></col> <fld>(Biol.)</fld>, <cd>a term
employed by Beale to denote the lifeless matter of a cell, that which is
physiologically dead, in distinction from the truly germinal or living
matter.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Formedon</ent><br/
<hw>For"me*don</hw> <pr>(f<ocir/r"m<esl/*d<ocr/n)</pr>, <pos>n.</pos>
<ety>[OF., fr. Latin. So called because the plaintiff claimed <ldquo/by
the form of the gift,<rdquo/ L. <ets>per formam doni</ets>.]</ety>
<fld>(O. Eng. Law)</fld> <def>A writ of right for a tenant in tail in
case of a discontinuance of the estate tail. This writ has been
abolished.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Formell</ent><br/
<hw>For"mell</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Dim. of F.
<ets>forme</ets> the female of a bird of prey.]</ety> <fld>(Zool.)</fld>
<def>The female of a hawk or falcon.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Former</ent><br/
<hw>Form"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who
forms; a maker; a creator.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mech.)</fld> <sd>(a)</sd> <def>A shape around which
an article is to be shaped, molded, woven wrapped, pasted, or otherwise
constructed.</def> <sd>(b)</sd> <def>A templet, pattern, or gauge by
which an article is shaped.</def> <sd>(c)</sd> <def>A cutting
die.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Former</ent><br/
<hw>For"mer</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[A compar. due to OE.
<ets>formest</ets>. See <er>Foremost</er>.]</ety> <sn>1.</sn>
<def>Preceding in order of time; antecedent; previous; prior; earlier;
hence, ancient; long past.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>For inquire, I pray thee, of the <qex>former</qex> age.</q>
<rj><qau>Job. viii. 8.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The latter and <qex>former</qex> rain.</q> <rj><qau>Hosea vi.
3.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Near the beginning; preceeding; <as>as, the
<ex>former</ex> part of a discourse or argument</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Earlier, as between two things mentioned together;
first mentioned.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A bad author deserves better usage than a bad critic; a man may be
the <qex>former</qex> merely through the misfortune of an ill judgment;
but he can not be latter without both that and an ill temper.</q>
<rj><qau>Pope.</qau></rj></p>

<p><syn><b>Syn.</b> -- Prior; previous; anterior; antecedent; preceding;
foregoing.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Formeret</ent><br/
\'d8<hw>For`me*ret"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<fld>(Arch.)</fld> <def>One of the half ribs against the walls in a
ceiling vaulted with ribs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Formerly</ent><br/
<hw>For"mer*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In time past,
either in time immediately preceding or at any indefinite distance; of
old; heretofore.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Formful</ent><br/
<hw>Form"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Creative;
imaginative.</def> <mark>[R.]</mark> <ldquo/The <xex>formful</xex>
brain.<rdquo/ <rj><au>Thomson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Formic</ent><br/
<hw>For"mic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>formica</ets>
an ant: cf. F. <ets>formique</ets>.]</ety> <fld>(Chem.)</fld>
<def>Pertaining to, or derived from, ants; <as>as, <ex>formic</ex>
acid</as>; in an extended sense, pertaining to, or derived from, formic
acid; <as>as, <ex>formic</ex> ether</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Amido formic acid</b></col>, <cd>carbamic acid.</cd> --
<col><b>Formic acid</b></col>, <cd>a colorless, mobile liquid,
<chform>HCO.OH</chform>, of a sharp, acid taste, occurring naturally in
ants, nettles, pine needles, etc., and produced artifically in many
ways, as by the oxidation of methyl alcohol, by the reduction of
carbonic acid or the destructive distillation of oxalic acid. It is the
first member of the fatty acids in the paraffin series, and is
homologous with acetic acid.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Formica</ent><br/
\'d8<hw>For*mi"ca</hw> <pr>(f<ocir/r*m<imac/"k<adot/)</pr>, <pos>prop.
n.</pos> <ety>[L., an ant.]</ety> <fld>(Zool.)</fld> <def>A Linn<ae/an
genus of hymenopterous insects, including the common ants. See
<er>Ant</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Formica</ent><br/
<hw>For*mi"ca</hw> <pr>(f<ocir/r*m<imac/"k<adot/)</pr>, <pos>prop.
n.</pos> <ety>[a trademark.]</ety> <def>A thermosetting plastic material
composed of melamine resin, having good heat and chemical resistance,
and commonly used as the surface layer in laminated sheets employed as
coverings for counter tops, walls, or furniture.</def><br/
[<source>PJC</source>]</p>

<p><ent>Formicaroid</ent><br/
<hw>For`mi*ca"roid</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[NL.
<ets>Formicarius</ets>, the typical genus + <ets>-oid</ets>.]</ety>
<fld>(Zool.)</fld> <def>Like or pertaining to the family
<fam>Formicarid<ae/</fam> or ant thrushes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Formicary</ent><br/
<hw>For"mi*ca*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL.
<ets>formicarium</ets>, fr. L. <ets>formica</ets> an ant.]</ety>
<fld>(Zool.)</fld> <def>The nest or dwelling of a swarm of ants; an
ant-hill.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Formicate</ent><br/
<hw>For"mi*cate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>formica</ets> an ant.]</ety> <fld>(Zool.)</fld> <def>Resembling, or
pertaining to, an ant or ants.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Formicate</ent><br/
<hw>For"mi*cate</hw> <pr>(f<ocir/r"m<icr/*k<amac/t)</pr>, <pos>v.
i.</pos> <ety>[See <er>Formication</er>.]</ety> <def>To creep or crawl
like ants; swarm with, or as with, ants.</def></p>

<p><q>An open space which <qex>formicated</qex> with peasantry.</q>
<rj><qau>Lowell.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Formication</ent><br/
<hw>For`mi*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>formicatio</ets>, fr. <ets>formicare</ets> to creep like an ant, to
feel as if ants were crawling on one's self, fr. <ets>formica</ets> ant:
cf. F. <ets>formication</ets>.]</ety> <fld>(Med.)</fld> <def>A sensation
resembling that made by the creeping of ants on the skin.</def>
<rj><au>Dunglison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Formicid</ent><br/
<hw>For"mi*cid</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Pertaining to the ants.</def> -- <def2><pos>n.</pos> <def>One of
the family <fam>Formicid<ae/</fam>, or ants.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Formicidae</ent><br/
<hw>Formicidae</hw> <pos>prop. n.</pos> <def>The natural family of
insects comprising the ants.</def><br/
<syn><b>Syn. --</b> family <fam>Formicidae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Formidability</ent><br/
<hw>For`mi*da*bil"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Formidableness.</def> <rj><au>Walpole.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Formidable</ent><br/
<hw>For"mi*da*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>formidabilis</ets>, fr. <ets>formidare</ets> to fear, dread: cf. F.
<ets>formidable</ets>.]</ety> <def>Exciting fear or apprehension;
impressing dread; adapted to excite fear and deter from approach,
encounter, or undertaking; alarming.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They seemed to fear the <qex>formodable</qex> sight.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I swell my preface into a volume, and make it
<qex>formidable</qex>, when you see so many pages behind.</q>
<rj><qau>Drydn.</qau></rj></p>

<p><syn><b>Syn.</b> -- Dreadful; fearful; terrible; frightful; shocking;
horrible; terrific; tremendous.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Formidableness</ent><br/
<hw>For"mi*da*ble*ness</hw>, <pos>n.</pos> <def>The quality of being
formidable, or adapted to excite dread.</def>
<rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Formidably</ent><br/
<hw>For"mi*da*bly</hw>, <pos>adv.</pos> <def>In a formidable
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Formidolose</ent><br/
<hw>For*mid"o*lose</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>formidolosus</ets>, fr. <ets>formido</ets> fear.]</ety> <def>Very
much afraid.</def> <mark>[Obs.]</mark> <rj><au>Bailey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forming</ent><br/
<hw>Form"ing</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act or process of
giving form or shape to anything; as, in shipbuilding, the exact shaping
of partially shaped timbers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Formless</ent><br/
<hw>Form"less</hw>, <pos>a.</pos> <def>Shapeless; without a determinate
form; wanting regularity of shape.</def> --
<wordforms><wf>Form"less*ly</wf>, <pos>adv.</pos> --
<wf>Form"less*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>form-only</ent><br/
<hw>form-only</hw> <pos>adj.</pos> <def>being a matter of form only;
lacking substance.</def> <mark>[prenominal]</mark><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Formosa</ent><br/
<hw>Formosa</hw> <pos>prop. n.</pos> <def>An island off the coast of
China, also called <altname>Taiwan</altname>. It was occupied by Japan
from 1895 to 1945, when it was returned to Chinese sovereignty. After
the Communist revolution which took over the Chinese mainland in 1949,
the Nationalist Chinese under Chang Kai-Shek retreated to the island of
Formosa and established that island as the base of their government,
being recognized for several years as the <ex>de jure</ex> possessor of
the China seat in the United Nations. The capital is Taipei. As of 1998,
both the Taiwan government and the mainland China government recognized
Taiwan as properly a part of China, but the island is currently ruled as
a <ex>de facto</ex> independent nation, though it does not possess a
seat in the United Nations. The question of when and under what
circumstances the island will be reunited with the mainland government
is still unresolved.</def><br/
<syn><b>Syn. --</b> Taiwan.</syn><br/
[<source>PJC</source>]</p>

<p><ent>Formosan</ent><br/
<hw>Formosan</hw> <pos>prop. adj.</pos> <def>of, pertaining to, or
characteristic of, Formosa or the natives of Formosa; <as>as, The native
<ex>Formosan</ex> population now forms a minority on their own
island.</as>.</def><br/
<syn><b>Syn. --</b> Taiwanese, Chinese.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Formula</ent><br/
<hw>For"mu*la</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it> E.
<plw>Formulas</plw> <pr>(#)</pr>, L. <plw>Formul<ae/</plw>
<pr>(#)</pr>.</plu> <ety>[L., dim. of <ets>forma</ets> form, model.
See<er>Form</er>, <pos>n.</pos>]</ety> <sn>1.</sn> <def>A prescribed or
set form; an established rule; a fixed or conventional method in which
anything is to be done, arranged, or said.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Eccl.)</fld> <def>A written confession of faith; a
formal statement of doctrines.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Math.)</fld> <def>A rule or principle expressed in
algebraic language; <as>as, the binominal
<ex>formula</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Med.)</fld> <def>A prescription or recipe for the
preparation of a medicinal compound.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Chem.)</fld> <def>A symbolic expression (by means
of letters, figures, etc.) of the constituents or constitution of a
compound.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Chemical formul<ae/</xex> consist of the
abbreviations of the names of the elements, with a small figure at the
lower right hand, to denote the number of atoms of each element
contained.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Empirical formula</b></col> <fld>(Chem.)</fld>, <cd>an
expression which gives the simple proportion of the constituents;
<as>as, the <ex>empirical formula</ex> of acetic acid is
<chform>C2H4O2</chform></as>.</cd> -- <mcol><col><b>Graphic
formula</b></col>, <col><b>Rational formula</b></col></mcol>
<fld>(Chem.)</fld>, <cd>an expression of the constitution, and in a
limited sense of the structure, of a compound, by the grouping of its
atoms or radicals; <as>as, a <ex>rational formula</ex> of acetic acid is
<chform>CH3.(C:O).OH</chform></as>; -- called also <altname>structural
formula</altname>, <altname>constitutional formula</altname>, etc. See
also the formula of <cref>Benzene nucleus</cref>, under
<er>Benzene</er>.</cd> -- <col><b>Molecular formula</b></col>
<fld>(Chem.)</fld>, <cd>a formula indicating the supposed molecular
constitution of a compound.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Formularistic</ent><br/
<hw>For`mu*la*ris"tic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining
to, or exhibiting, formularization.</def> <rj><au>Emerson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Formularization</ent><br/
<hw>For`mu*lar*i*za"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act
of formularizing; a formularized or formulated statement or
exhibition.</def> <rj><au>C. Kingsley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Formularize</ent><br/
<hw>For"mu*lar*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To reduce to
a forula; to formulate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Formulary</ent><br/
<hw>For"mu*la*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>formulaire</ets>. See <er>Formula</er>.]</ety> <def>Stated;
prescribed; ritual.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Formulary</ent><br/
<hw>For"mu*la*ry</hw>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Formularies</plw> <pr>(#)</pr>.</plu> <ety>[Cf. F.
<ets>formulaire</ets>.]</ety> <sn>1.</sn> <def>A book containing stated
and prescribed forms, as of oaths, declarations, prayers, medical
formula<ae/, etc.; a book of precedents.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Prescribed form or model; formula.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Formulate</ent><br/
<hw>For"mu*late</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Formulated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Formulating</conjf> <pr>(?)</pr>.]</vmorph> <def>To
reduce to, or express in, a formula; to put in a clear and definite form
of statement or expression.</def> <rj><au>G. P. Marsh.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>formulated</ent><br/
<hw>formulated</hw> <pos>adj.</pos> <def>reduced to a systematic form;
reduced to a formula.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Formulation</ent><br/
<hw>For`mu*la"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act,
process, or result of formulating or reducing to a formula.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Formule</ent><br/
<hw>For"mule</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety> <def>A set
or prescribed model; a formula.</def> <mark>[Obs.]</mark>
<rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Formulization</ent><br/
<hw>For`mu*li*za"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act or
process of reducing to a formula; the state of being
formulized.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Formulize</ent><br/
<hw>For"mu*lize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Formulized</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Formulizing</conjf> <pr>(?)</pr>.]</vmorph> <def>To
reduce to a formula; to formulate.</def> <rj><au>Emerson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Formyl</ent><br/
<hw>For"myl</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Form</ets>ic +
<ets>-yl</ets>.]</ety> <fld>(Chem.)</fld> <sd>(a)</sd> <def>A univalent
radical, <chform>H.C:O</chform>, regarded as the essential residue of
<xex>formic</xex> acid and aldehyde.</def> <sd>(b)</sd> <def>Formerly,
the radical methyl, <chform>CH3</chform>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forncast</ent><br/
<hw>Forn*cast"</hw> <pr>(?)</pr>, <pos>p. p.</pos> <ety>[OE. <ets>foren
+ cast</ets>. See <er>Forecast</er>.]</ety> <def>Predestined.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fornical</ent><br/
<hw>For"ni*cal</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Relating to a
fornix.</def></p>

<p><ent>Fornicated</ent><br/
<ent>Fornicate</ent><br/
<mhw>{ <hw>For"ni*cate</hw> <pr>(?)</pr>, <hw>For"ni*ca`ted</hw>
<pr>(?)</pr> }</mhw>, <pos>a.</pos> <ety>[L. <ets>fornicatus</ets>, fr.
<ets>fornix</ets>, <ets>-icis</ets>, an arch, vault.]</ety> <sn>1.</sn>
<def>Vaulted like an oven or furnace; arched.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>Arching over; overarched.</def>
<rj><au>Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 588 --></p>

<p><ent>Fornicate</ent><br/
<hw>For"ni*cate</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[L.
<ets>fornicatus</ets>, <ets>p. p. of fornicari</ets> to fornicate, fr.
<ets>fornix</ets>, <ets>-icis</ets>, a vault, a brothel in an
underground vault.]</ety> <def>To commit fornication; to have unlawful
sexual intercourse.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fornication</ent><br/
<hw>For`ni*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>fornication</ets>, L. <ets>fornicatio</ets>.]</ety> <sn>1.</sn>
<def>Unlawful sexual intercourse on the part of an unmarried person; the
act of such illicit sexual intercourse between a man and a woman as does
not by law amount to adultery.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In England, the offense, though cognizable in the
ecclesiastical courts, was not at common law subject to secular
prosecution. In the United States it is indictable in some States at
common law, in others only by statute.</note>
<rj><au>Whartyon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Script.)</fld> <sd>(a)</sd> <def>Adultery.</def>
<sd>(b)</sd> <def>Incest.</def> <sd>(c)</sd> <def>Idolatry.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fornicator</ent><br/
<hw>For"ni*ca`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>fornicateur</ets>, OF. <ets>fornicator</ets>, from L.
<ets>fornicator</ets>.]</ety> <def>An unmarried person, male or female,
who has criminal intercourse with the other sex; one guilty of
fornication.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fornicatress</ent><br/
<hw>For"ni*ca`tress</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>fornicatrice</ets>, L. <ets>fornicatrix</ets>.]</ety> <def>A woman
guilty of fornication.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fornix</ent><br/
\'d8<hw>For"nix</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Fornices</plw> <pr>(#)</pr>.</plu> <ety>[L., an arch.]</ety>
<fld>(Anat.)</fld> <sd>(a)</sd> <def>An arch or fold; <as>as, the
<ex>fornix</ex>, or vault, of the cranium; the <ex>fornix</ex>, or
reflection, of the conjuctiva.</as></def> <sd>(b)</sd> <def>Esp., two
longitudinal bands of white nervous tissue beneath the lateral
ventricles of the brain.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forold</ent><br/
<hw>For*old"</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Very old.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>A bear's skin, coal-black, <qex>forold</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forpass</ent><br/
<hw>For*pass"</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <def>To pass by
or along; to pass over.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forpine</ent><br/
<hw>For*pine"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To waste away
completely by suffering or torment.</def> <mark>[Archaic]</mark>
<ldquo/Pale as a <xex>forpined</xex> ghost.<rdquo/
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forray</ent><br/
<hw>For"ray</hw> <pr>(? <or/ ?)</pr>, <pos>v. t.</pos> <ety>[OE.
<ets>forrayen</ets>. See <er>Foray</er>.]</ety> <def>To foray; to
ravage; to pillage.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>For they that morn had <qex>forrayed</qex> all the land.</q>
<rj><qau>Fairfax.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forray</ent><br/
<hw>For"ray</hw>, <pos>n.</pos> <def>The act of ravaging; a ravaging; a
predatory excursion. See <er>Foray</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forrill</ent><br/
<hw>For"rill</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Forel</er>.]</ety> <def>Lambskin parchment; vellum; forel.</def>
<rj><au>McElrath.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forsake</ent><br/
<hw>For*sake"</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp.</pos> <conjf>Forsook</conjf> <pr>(?)</pr>; <pos>p.
p.</pos> <conjf>Forsaken</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Forsaking</conjf>.]</vmorph> <ety>[AS.
<ets>forsacan</ets> to oppose, refuse; <ets>for-</ets> +
<ets>sacan</ets> to contend, strive; akin to Goth. <ets>sakan</ets>. See
<er>For-</er>, and <er>Sake</er>.]</ety> <sn>1.</sn> <def>To quit or
leave entirely; to desert; to abandon; to depart or withdraw from; to
leave; <as>as, false friends and flatterers <ex>forsake</ex> us in
adversity</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If his children <qex>forsake</qex> my law, and walk not in my
judgments.</q> <rj><qau>Ps. lxxxix. 30.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To renounce; to reject; to refuse.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If you <qex>forsake</qex> the offer of their love.</q>
<rj><qau>Shak.</qau></rj></p>

<p><syn><b>Syn.</b> -- To abandon; quit; desert; fail; relinquish; give
up; renounce; reject. See <er>Abandon</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forsaker</ent><br/
<hw>For*sak"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who forsakes or
deserts.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forsay</ent><br/
<hw>For*say"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[AS.
<ets>forsecgan</ets> to accuse; pref. <ets>for-</ets> +
<ets>secgan</ets> to say.]</ety> <def>To forbid; to renounce; to
forsake; to deny.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forshape</ent><br/
<hw>For*shape"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>for-</ets> + <ets>shape</ets>, v.t.]</ety> <def>To render
misshapen.</def> <mark>[Obs.]</mark> <rj><au>Gower.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forslack</ent><br/
<hw>For*slack"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>for-</ets> + <ets>slack</ets> to neglect.]</ety> <def>To neglect by
idleness; to delay or to waste by sloth.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forslouthe</ent><br/
<hw>For*slouth"e</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[See
<er>For-</er>, and <er>Slouth</er>.]</ety> <def>To lose by sloth or
negligence.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forslow</ent><br/
<hw>For*slow"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>for-</ets> + <ets>slow</ets>.]</ety> <def>To delay; to hinder; to
neglect; to put off.</def> <mark>[Obs.]</mark>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forslow</ent><br/
<hw>For*slow"</hw>, <pos>v. i.</pos> <def>To loiter.</def>
<mark>[Obs.]</mark> <altsp>[Also spelled
<asp>foreslow</asp>.]</altsp><rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forslugge</ent><br/
<hw>For*slug"ge</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[See
<er>Slug</er> to be idle.]</ety> <def>To lsoe by idleness or
slotch.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forsooth</ent><br/
<hw>For*sooth"</hw> <pr>(?)</pr>, <pos>adv.</pos> <ety>[AS.
<ets>fors<omac/<edh/</ets>; <ets>for</ets>, prep. +
<ets>s<omac/<edh/</ets> sooth, truth. See <er>For</er>,
<ets>prep</ets>., and <er>Sooth</er>.]</ety> <def>In truth; in fact;
certainly; very well; -- formerly used as an expression of deference or
respect, especially to woman; now used ironically or
contemptuously.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A fit man, <qex>forsooth</qex>, to govern a realm!</q>
<rj><qau>Hayward.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Our old English word <qex>forsooth</qex> has been changed for the
French <qex>madam</qex>.</q> <rj><qau>Guardian.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forsooth</ent><br/
<hw>For*sooth"</hw>, <pos>v. t.</pos> <def>To address respectfully with
the term <xex>forsooth</xex>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The captain of the <ldquo/Charles<rdquo/ had <qex>forsoothed</qex>
her, though he knew her well enough and she him.</q>
<rj><qau>Pepys.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forsooth</ent><br/
<hw>For*sooth"</hw>, <pos>n.</pos> <def>A person who used
<xex>forsooth</xex> much; a very ceremonious and deferential
person.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>You sip so like a <qex>forsooth</qex> of the city.</q> <rj><qau>B.
Jonson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forspeak</ent><br/
<hw>For*speak"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>for-</ets> + <ets>speak</ets>.]</ety> <sn>1.</sn> <def>To forbid;
to prohibit.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To bewitch.</def> <mark>[Obs.]</mark>
<rj><au>Drayton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forspent</ent><br/
<hw>For*spent"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[AS.
<ets>forspendan</ets> to consume; pref. <ets>for-</ets> +
<ets>spendan</ets> to spend.]</ety> <def>Wasted in strength; tired;
exhausted.</def> <mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>A gentleman almost <qex>forspent</qex> with speed.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forstall</ent><br/
<hw>For*stall"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To
forestall.</def> <mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forster</ent><br/
<hw>Fors"ter</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A forester.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forstraught</ent><br/
<hw>For*straught"</hw> <pr>(?)</pr>, <pos>p. p. & a.</pos> <ety>[Pref.
<ets>for-</ets> + <ets>straught</ets>; cf. <ets>distraught</ets>.]</ety>
<def>Distracted.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forswat</ent><br/
<hw>For*swat"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Sweat</er>.]</ety> <def>Spent with heat; covered with sweat.</def>
<mark>[Obs.]</mark> <rj><au>P. Sidney.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forswear</ent><br/
<hw>For*swear"</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp.</pos> <conjf>Forswore</conjf> <pr>(?)</pr>; <pos>p.
p.</pos> <conjf>Forsworn</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Forswearing</conjf>.]</vmorph> <ety>[OE.
<ets>forsweren</ets>, <ets>forswerien</ets>, AS. <ets>forswerian</ets>;
pref. <ets>for-</ets> + <ets>swerian</ets> to swear. See <er>For-</er>,
and <er>Swear</er>, <pos>v. i.</pos>]</ety> <sn>1.</sn> <def>To reject
or renounce upon oath; hence, to renounce earnestly, determinedly, or
with protestations.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I . . . do <qex>forswear</qex> her.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To deny upon oath.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Like innocence, and as serenely bold<br/
As truth, how loudly he <qex>forswears</qex> thy gold!</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To forswear one's self</b></col>, <cd>to swear falsely;
to perjure one's self.</cd> <ldquo/Thou shalt not <xex>forswear
thyself</xex>.<rdquo/ <rj><au>Matt. v. 33.</au></rj></cs></p>

<p><syn><b>Syn.</b> -- See <er>Perjure</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forswear</ent><br/
<hw>For*swear"</hw>, <pos>v. i.</pos> <def>To swear falsely; to commit
perjury.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forswearer</ent><br/
<hw>For*swear"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who rejects
of renounces upon oath; one who swears a false oath.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forswonk</ent><br/
<hw>For*swonk"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>for-</ets> + <ets>swonk</ets>, p. p. of <ets>swink</ets>to labor.
See <er>Swink</er>.]</ety> <def>Overlabored; exhausted; worn out.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forswore</ent><br/
<hw>For*swore"</hw> <pr>(?)</pr>, <def><pos>imp.</pos> of
<er>Forswear</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forsworn</ent><br/
<hw>For*sworn"</hw> <pr>(?)</pr>, <def><pos>p. p.</pos> of
<er>Forswear</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forswornness</ent><br/
<hw>For*sworn"ness</hw>, <pos>n.</pos> <def>State of being
forsworn.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forsythia</ent><br/
\'d8<hw>For*syth"i*a</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[NL. Named
after William <ets>Forsyth</ets>, who brought in from China.]</ety>
<fld>(Bot.)</fld> <def>A shrub of the Olive family, with yellow
blossoms.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fort</ent><br/
<hw>Fort</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., from <ets>fort</ets>
strong, L. <ets>fortis</ets>; perh. akin to Skr. <ets>darh</ets> to fix,
make firm, and to E. <ets>firm</ets> Cf. <er>Forte</er>, <er>Force</er>,
<er>Fortalice</er>, <er>Comfort</er>, <er>Effort</er>.]</ety>
<fld>(Mil.)</fld> <def>A strong or fortified place; usually, a small
fortified place, occupied only by troops, surrounded with a ditch,
rampart, and parapet, or with palisades, stockades, or other means of
defense; a fortification.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Detached works, depending solely on their own strength, belong to
the class of works termed <qex>forts</qex>.</q>
<rj><qau>Farrow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fortalice</ent><br/
<hw>Fort"a*lice</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL.
<ets>fortalitia</ets>, or OF. <ets>fortelesce</ets>. See
<er>Fortress</er>.]</ety> <fld>(Mil.)</fld> <def>A small outwork of a
fortification; a fortilage; -- called also
<altname>fortelace</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forte</ent><br/
<hw>Forte</hw> <pr>(f<omac/rt)</pr>, <pos>n.</pos> <ety>[IT.
<ets>forte</ets>: cf. F. <ets>fort</ets>. See <er>Fort</er>.]</ety>
<sn>1.</sn> <def>The strong point; that in which one excels.</def> <--
sense 2 is often pronounced <pr>f<omac/rt"<amac/</pr> --><br/
[<source>1913 Webster</source>]</p>

<p><q>The construction of a fable seems by no means the <qex>forte</qex>
of our modern poetical writers.</q> <rj><qau>Jeffrey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The stronger part of the blade of a sword; the part
of half nearest the hilt; -- opposed to <xex>foible</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forte</ent><br/
\'d8<hw>For"te</hw> <pr>(f<ocir/r"t<asl/ <or/ f<omac/r"t<asl/)</pr>,
<pos>adv.</pos> <ety>[It. <ets>forte</ets>, <pos>a. & adv.</pos>, fr. L.
<ets>fortis</ets> strong.]</ety> <fld>(Mus.)</fld> <def>Loudly;
strongly; powerfully.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forted</ent><br/
<hw>Fort"ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Furnished with, or
guarded by, forts; strengthened or defended, as by forts.</def>
<mark>[R.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forth</ent><br/
<hw>Forth</hw> <pr>(?)</pr>, <pos>v.</pos><ety>[AS. <ets>for<edh/</ets>,
fr. <ets>for</ets> akin to D. <ets>voort</ets>, G. <ets>fort</ets>
<root/78. See <er>Fore</er>, <er>For</er>, and cf. <er>Afford</er>,
<er>Further</er>, <pos>adv.</pos>]</ety> <sn>1.</sn> <def>Forward;
onward in time, place, or order; in advance from a given point; on to
end; <as>as, from that day <ex>forth</ex>; one, two, three, and so
<ex>forth</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Lucas was Paul's companion, at the leastway from the sixteenth of
the Acts <qex>forth</qex>.</q> <rj><qau>Tyndale.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>From this time <qex>forth</qex>, <qex>I never will speak
word</qex>.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I repeated the Ave Maria; the inquisitor bad me say
<qex>forth</qex>; I said I was taught no more.</q>
<rj><qau>Strype.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Out, as from a state of concealment, retirement,
confinement, nondevelopment, or the like; out into notice or view;
<as>as, the plants in spring put <ex>forth</ex> leaves</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>When winter past, and summer scarce begun,<br/
Invites them <qex>forth</qex> to labor in the sun.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Beyond a (certain) boundary; away; abroad;
out.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I have no mind of feasting <qex>forth</qex> to-night.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Throughly; from beginning to end.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>And so forth</b></col>, <col><b>Back and
forth</b></col>, <col><b>From forth</b></col></mcol>. <cd>See under
<er>And</er>, <er>Back</er>, and <er>From</er>.</cd> --
<mcol><col><b>Forth of</b></col>, <col><b>Forth from</b></col></mcol>,
<cd>out of.</cd> <mark>[Obs.]</mark> <au>Shak.</au> -- <col><b>To bring
forth</b></col>. <cd>See under <er>Bring</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forth</ent><br/
<hw>Forth</hw>, <pos>prep.</pos> <def>Forth from; out of.</def>
<mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Some <qex>forth</qex> their cabins peep.</q>
<rj><qau>Donne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forth</ent><br/
<hw>Forth</hw>, <pos>n.</pos> <ety>[OE., a ford. <?/ 78. See
<er>Frith</er>.]</ety> <def>A way; a passage or ford.</def>
<mark>[Obs.]</mark> <rj><au>Todd.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forthby</ent><br/
<hw>Forth`by"</hw> <pr>(?)</pr>, <pos>adv.</pos> <mark>[Obs.]</mark>
<def>See <er>Forby</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>forthcoming</ent><br/
<hw>forth"com`ing</hw> <pr>(f<omac/rth"k<ucr/m`<icr/ng <it>or</it>
f<omac/rth`k<ucr/m"<icr/ng)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Ready
or about to appear; making appearance.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Candid; frank; not withholding relevant information;
cooperative in providing information.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>Having an agreeable and sociable personality;
friendly.</def><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <def>Available or ready at the time required; <as>as,
payment will be <ex>forthcoming</ex> on receipt of the
goods</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Forthgoing</ent><br/
<hw>Forth"go`ing</hw> <pr>(? <or/ ?)</pr>, <pos>n.</pos> <def>A going
forth; an utterance.</def> <rj><au>A. Chalmers.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forthgoing</ent><br/
<hw>Forth"go`ing</hw>, <pos>a.</pos> <def>Going forth.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forthink</ent><br/
<hw>For*think"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To repent; to
regret; to be sorry for; to cause regret.</def> <mark>[Obs.]</mark>
<ldquo/Let it <xex>forthink</xex> you.<rdquo/
<rj><au>Tyndale.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>That me <qex>forthinketh</qex>, quod this January.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forthputing</ent><br/
<hw>Forth"put`ing</hw> <pr>(? <or/ ?)</pr>, <pos>a.</pos> <def>Bold;
forward; aggressive.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forthright</ent><br/
<hw>Forth"right`</hw> <pr>(? <or/ ?)</pr>, <pos>adv.</pos>
<ety>[<ets>Forth</ets>, <pos>adv.</pos> + <ets>right</ets>,
<pos>adv.</pos>]</ety> <def>Straight forward; in a straight
direction.</def> <mark>[Archaic]</mark> <rj><au>Sir P.
Sidney.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forthright</ent><br/
<hw>Forth"right`</hw>, <pos>a.</pos> <def>Direct; straightforward;
<as>as, a <ex>forthright</ex> man</as>.</def> <mark>[Archaic]</mark>
<rj><au>Lowell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>They were Night and Day, and Day and Night,<br/
Piligrims wight with steps <qex>forthright</qex>.</q>
<rj><qau>Emerson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forthright</ent><br/
<hw>Forth"right`</hw>, <pos>n.</pos> <def>A straight path.</def>
<mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Here's a maze trod, indeed,<br/
Through <qex>forthrights</qex> and meanders!</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forthrightness</ent><br/
<hw>Forth"right`ness</hw>, <pos>n.</pos> <def>Straightforwardness;
explicitness; directness.</def> <mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Dante's concise <qex>forthrightness</qex> of phrase.</q>
<rj><qau>Hawthorne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forthward</ent><br/
<hw>Forth"ward</hw> <pr>(?)</pr>, <pos>adv.</pos>
<ety>[<ets>Forth</ets>, adv. + <ets>-ward</ets>.]</ety>
<def>Forward.</def> <mark>[Obs.]</mark> <rj><au>Bp.
Fisher.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forthwith</ent><br/
<hw>Forth`with"</hw> <pr>(? <or/ ?; see <er>With</er>)</pr>,
<pos>adv.</pos> <sn>1.</sn> <def>Immediately; without delay;
directly.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Immediately there fell from his eyes as it had been scales; and he
received sight <qex>forthwith</qex>.</q> <rj><qau>Acts ix.
18.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>As soon as the thing required may
be done by reasonable exertion confined to that object.</def>
<rj><au>Bouvier.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forthy</ent><br/
<hw>For*thy"</hw> <pr>(?)</pr>, <pos>adv.</pos> <ety>[AS.
<ets>for<edh/<ymac/</ets>; <ets>for</ets>, prep. +
<ets><edh/<ymac/</ets>, instrumental neut. of <ets>se</ets>,
<ets>se<oacute/</ets>, <ets><edh/<ae/t</ets>, pron. demonstrative and
article. See <er>The</er>.]</ety> <def>Therefore.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forties</ent><br/
<hw>For"ties</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <def>See
<er>Forty</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fortieth</ent><br/
<hw>For"ti*eth</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[AS.
<ets>fe<oacute/wertigo<?/a</ets>. See <er>Forty</er>.]</ety> <sn>1.</sn>
<def>Following the thirty-ninth, or preceded by thirty-nine units,
things, or parts.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Constituting one of forty equal parts into which
anything is divided.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fortieth</ent><br/
<hw>For"ti*eth</hw>, <pos>n.</pos> <def>One of forty equal parts into
which one whole is divided; the quotient of a unit divided by forty; one
next in order after the thirty-ninth.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fortifiable</ent><br/
<hw>For"ti*fi`a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. OF.
<ets>fortifiable</ets>.]</ety> <def>Capable of being fortified.</def>
<rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fortification</ent><br/
<hw>For`ti*fi*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>fortificatio</ets> : cf. F. <ets>fortification</ets>.]</ety>
<sn>1.</sn> <def>The act of fortifying; the art or science of fortifying
places in order to defend them against an enemy.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which fortifies; especially, a work or works
erected to defend a place against attack; a fortified place; a fortress;
a fort; a castle.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fortification agate</b></col>, <cd>Scotch
pebble.</cd></cs></p>

<p><syn><b>Syn.</b> -- Fortress; citadel; bulwark. See
<er>Fortress</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fortifier</ent><br/
<hw>For"ti*fi`er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, fortifies, strengthens, supports, or upholds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fortify</ent><br/
<hw>For"ti*fy</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Fortified</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Fortifying</conjf>.]</vmorph> <ety>[F.
<ets>fortifier</ets>, L. <ets>fortificare</ets>; <ets>fortis</ets>
strong + <ets>-ficare</ets> (in comp.) to make. See <er>Fort</er>, and
<er>-fy</er>.]</ety> <sn>1.</sn> <def>To add strength to; to strengthen;
to confirm; to furnish with power to resist attack.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Timidity was <qex>fortified</qex> by pride.</q>
<rj><qau>Gibbon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Pride came to the aid of fancy, and both combined to
<qex>fortify</qex> his resolution.</q> <rj><qau>Sir W.
Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To strengthen and secure by forts or batteries, or
by surrounding with a wall or ditch or other military works; to render
defensible against an attack by hostile forces.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fortify</ent><br/
<hw>For"ti*fy</hw>, <pos>v. i.</pos> <def>To raise defensive
works.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fortilage</ent><br/
<hw>For"ti*lage</hw> <pr>(?; 48)</pr>, <pos>n.</pos> <ety>[Cf.
<er>Fortalice</er>.]</ety> <def>A little fort; a blockhouse.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fortin</ent><br/
<hw>Fort"in</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. See <er>Fort</er>,
<pos>n.</pos>]</ety> <def>A little fort; a fortlet.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fortissimo</ent><br/
\'d8<hw>For*tis"si*mo</hw> <pr>(? <or/ ?)</pr>, <pos>adv.</pos>
<ety>[It., superl. of <ets>forte</ets>, adv. See <er>Forte</er>,
<pos>adv.</pos>]</ety> <fld>(Mus.)</fld> <def>Very loud; with the utmost
strength or loudness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fortition</ent><br/
<hw>For*ti"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Fortuitous</er>.]</ety> <def>Casual choice; fortuitous selection;
hazard.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>No mode of election operating in the spirit of
<qex>fortition</qex> or rotation can be generally good.</q>
<rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fortitude</ent><br/
<hw>For"ti*tude</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>fortitudo</ets>, fr. <ets>fortis</ets> strong. See
<er>Fort</er>.]</ety> <sn>1.</sn> <def>Power to resist attack; strength;
firmness.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>fortitude</qex> of the place is best known to you.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That strength or firmness of mind which enables a
person to encounter danger with coolness and courage, or to bear pain or
adversity without murmuring, depression, or despondency; passive
courage; resolute endurance; firmness in confronting or bearing up
against danger or enduring trouble.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Extolling patience as the truest <qex>fortitude</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Fortitude</qex> is the guard and support of the other
virtues.</q> <rj><qau>Locke.</qau></rj></p>

<p><syn><b>Syn.</b> -- Courage; resolution; resoluteness; endurance;
bravery. See <er>Courage</er>, and <er>Heroism</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fortitudinous</ent><br/
<hw>For`ti*tu"di*nous</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having
fortitude; courageous.</def> <mark>[R.]</mark>
<rj><au>Gibbon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fortlet</ent><br/
<hw>Fort"let</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A little fort.</def>
<mark>[R.]</mark> <rj><au>Bailey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fortnight</ent><br/
<hw>Fort"night`</hw> <pr>(?; <it>in</it> U.S. <it>often</it> ?;
277)</pr>, <pos>n.</pos> <ety>[Contr. fr. <ets>fourteen nights</ets>,
our ancestors reckoning time by nights and winters; so, also, <ets>seven
nights</ets>, <ets>sennight</ets>, a week.]</ety> <def>The space of
fourteen days; two weeks.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fortnightly</ent><br/
<hw>Fort"night`ly</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Occurring or
appearing once in a fortnight; <as>as, a <ex>fortnightly</ex> meeting of
a club; a <ex>fortnightly</ex> magazine, or other
publication.</as></def> -- <def2><pos>adv.</pos> <def>Once in a
fortnight; at intervals of a fortnight.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>FORTRAN</ent><br/
<hw>FORTRAN</hw> <pos>n.</pos> <fld>(Computers)</fld>
<ety>[<ets>For</ets>mula <ets>Tran</ets>slation.]</ety> <def>a higher
programming language with an instruction set designed for ease of
expression of mathematical functions, much used in programming of
scientific and mathematical problems.</def><br/
[<source>PJC</source>]</p>

<p><ent>Fortread</ent><br/
<hw>For*tread"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To tread down;
to trample upon.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>In hell shall they be all <qex>fortroden</qex> of devils.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fortress</ent><br/
<hw>For"tress</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Fortresses</plw> <pr>(#)</pr>.</plu> <ety>[F.
<ets>forteresse</ets>, OF. <ets>forteresce</ets>, <ets>fortelesce</ets>,
LL. <ets>foralitia</ets>, fr. L. <ets>fortis</ets> strong. See
<er>Fort</er>, and cf. <er>Fortalice</er>.]</ety> <def>A fortified
place; a large and permanent fortification, sometimes including a town;
a fort; a castle; a stronghold; a place of defense or
security.</def></p>

<p><syn><b>Syn.</b> -- <er>Fortress</er>, <er>Fortification</er>,
<er>Castle</er>, <er>Citadel</er>.</syn> <usage> A <xex>fortress</xex>
is constructed for military purposes only, and is permanently
garrisoned; a <xex>fortification</xex> is built to defend harbors,
cities, etc.; a <xex>castle</xex> is a fortress of early times which was
ordinarily a palatial dwelling; a <xex>citadel</xex> is the stronghold
of a fortress or city, etc.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fortress</ent><br/
<hw>For"tress</hw>, <pos>v. t.</pos> <def>To furnish with a fortress or
with fortresses; to guard; to fortify.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fortuitous</ent><br/
<hw>For*tu"i*tous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>fortuitus</ets>; akin to <ets>forte</ets>, adv., by chance, prop.
abl. of <ets>fors</ets>, <ets>fortis</ets>, chance. See
<er>Fortune</er>.]</ety> <sn>1.</sn> <def>Happening by chance; coming or
occuring unexpectedly, or without any known cause; chance; <as>as, the
<ex>fortuitous</ex> concourse of atoms</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It was from causes seemingly <qex>fortuitous</qex> . . . that all
the mighty effects of the Reformation flowed.</q>
<rj><qau>Robertson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>So as to throw a glancing and <qex>fortuitous</qex> light upon the
whole.</q> <rj><qau>Hazlitt.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(LAw)</fld> <def>Happening independently of human
will or means of foresight; resulting from unavoidable physical
causes.</def> <rj><au>Abbott.</au></rj></p>

<p><syn><b>Syn.</b> -- Accidental; casual; contingent; incidental. See
<er>Accidental</er>.</syn></p>

<p>-- <wordforms><wf>For*tu"i*tous*ly</wf>, <pos>adv.</pos> --
<wf>For*tu"i*tous*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fortuity</ent><br/
<hw>For*tu"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>fortuit<eacute/</ets>.]</ety> <def>Accident; chance;
casualty.</def> <rj><au>D. Forbes (1750).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fortuna</ent><br/
<hw>Fortuna</hw> <pos>prop. n.</pos> <def>the goddess of fortune and
good luck; counterpart of Greek Tyche.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fortunate</ent><br/
<hw>For"tu*nate</hw> <pr>(?; 135)</pr>, <pos>a.</pos> <ety>[L.
<ets>fortunatus</ets>, p. p. of <ets>fortunare</ets> to make fortunate
or prosperous, fr. <ets>fortuna</ets>. See <er>Fortune</er>,
<pos>n.</pos>]</ety> <sn>1.</sn> <def>Coming by good luck or favorable
chance; bringing some good thing not foreseen as certain; presaging
happiness; auspicious; <as>as, a <ex>fortunate</ex> event; a
<ex>fortunate</ex> concurrence of circumstances; a <ex>fortunate</ex>
investment.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Receiving same unforeseen or unexpected good, or
some good which was not dependent on one's own skill or efforts; favored
with good forune; lucky.</def></p>

<p><syn><b>Syn.</b> -- Auspicious; lucky; prosperous; successful;
favored; happy.</syn> <usage> -- <er>Fortunate</er>,
<er>Successful</er>, <er>Prosperous</er>. A man is <xex>fortunate</xex>,
when he is favored of fortune, and has unusual blessings fall to his
lot; <xex>successful</xex> when he gains what he aims at;
<xex>prosperous</xex> when he succeeds in those things which men
commonly desire. One may be <xex>fortunate</xex>, in some cases, where
he is not <xex>successful</xex>; he may be <xex>successful</xex>, but,
if he has been mistaken in the value of what he has aimed at, he may for
that reason fail to be <xex>prosperous</xex>.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fortunately</ent><br/
<hw>For"tu*nate*ly</hw>, <pos>adv.</pos> <def>In a fortunate manner;
luckily; successfully; happily.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fortunateness</ent><br/
<hw>For"tu*nate*ness</hw>, <pos>n.</pos> <def>The condition or quality
of being fortunate; good luck; success; happiness.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 589 --></p>

<p><ent>Fortune</ent><br/
<hw>For"tune</hw> <pr>(f<ocir/r"t<usl/n; 135)</pr>, <pos>n.</pos>
<ety>[F. <ets>fortune</ets>, L. <ets>fortuna</ets>; akin to
<ets>fors</ets>, <ets>fortis</ets>, chance, prob. fr. <ets>ferre</ets>
to bear, bring. See <er>Bear</er> to support, and cf.
<er>Fortuitous</er>.]</ety> <sn>1.</sn> <def>The arrival of something in
a sudden or unexpected manner; chance; accident; luck; hap; also, the
personified or deified power regarded as determining human success,
apportioning happiness and unhappiness, and distributing arbitrarily or
fortuitously the lots of life.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>'T is more by <qex>fortune</qex>, lady, than by merit.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>O <qex>Fortune</qex>, <qex>Fortune</qex>, all men call thee
fickle.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which befalls or is to befall one; lot in life,
or event in any particular undertaking; fate; destiny; <as>as, to tell
one's <ex>fortune</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>You, who men's <qex>fortunes</qex> in their faces read.</q>
<rj><qau>Cowley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which comes as the result of an undertaking or
of a course of action; good or ill success; especially, favorable issue;
happy event; success; prosperity as reached partly by chance and partly
by effort.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Our equal crimes shall equal <qex>fortune</qex> give.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>There is a tide in the affairs of men,<br/
Which, taken at the flood, leads on to <qex>fortune</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>His father dying, he was driven to seek his
<qex>fortune</qex>.</q> <rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Wealth; large possessions; large estate; riches;
<as>as, a gentleman of <ex>fortune</ex></as>.</def></p>

<p><syn><b>Syn.</b> -- Chance; accident; luck; fate.</syn><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fortune book</b></col>, <cd>a book supposed to reveal
future events to those who consult it.</cd> <au>Crashaw.</au> --
<col><b>Fortune hunter</b></col>, <cd>one who seeks to acquire wealth by
marriage.</cd> -- <col><b>Fortune teller</b></col>, <cd>one who
professes to tell future events in the life of another.</cd> --
<col><b>Fortune telling</b></col>, <cd>the practice or art of professing
to reveal future events in the life of another.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fortune</ent><br/
<hw>For"tune</hw>, <pos>v. t.</pos> <ety>[OF. <ets>fortuner</ets>, L.
<ets>fortunare</ets>. See <er>Fortune</er>, <pos>n.</pos>]</ety>
<sn>1.</sn> <def>To make fortunate; to give either good or bad fortune
to.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To provide with a fortune.</def>
<rj><au>Richardson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To presage; to tell the fortune of.</def>
<mark>[Obs.]</mark> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fortune</ent><br/
<hw>For"tune</hw>, <pos>v. i.</pos> <def>To fall out; to
happen.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It <qex>fortuned</qex> the same night that a Christian, serving a
Turk in the camp, secretely gave the watchmen warning.</q>
<rj><qau>Knolles.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fortuneless</ent><br/
<hw>For"tune*less</hw>, <pos>a.</pos> <def>Luckless; also, destitute of
a fortune or portion.</def> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fortunella</ent><br/
<hw>Fortunella</hw> <pos>prop. n.</pos> <def>small genus of shrubs
called kumquats, native to South China, producing small ovoid orangelike
fruits called <prod>kumquats</prod>.</def><br/
<syn><b>Syn. --</b> genus <gen>Fortunella</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>fortuneteller</ent><br/
<hw>for"tune*tel`ler</hw> <pos>n.</pos> <def>a person who claims to be
able to foretell events in the future of another person.</def><br/
<syn><b>Syn. --</b> fortune teller, fortune-teller.</syn><br/
-- <wordforms><wf>for"tune*tel`ling</wf>, <pos>n.</pos></wordforms><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Fortunize</ent><br/
<hw>For"tun*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To regulate the
fortune of; to make happy.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forty</ent><br/
<hw>For"ty</hw> <pr>(f<ocir/r"t<ycr/)</pr>, <pos>a.</pos> <ety>[OE.
<ets>forti</ets>, <ets>fourti</ets>, <ets>fowerti</ets>, AS.
<ets>fe<oacute/wertig</ets>; <ets>fe<oacute/wer</ets> four + suff.
<ets>-tig</ets> ten; akin to OS. <ets>fiwartig</ets>,
<ets>fiartig</ets>, D. <ets>veertig</ets>, G. <ets>vierzig</ets>, Icel.
<ets>fj<oum/rut<imac/u</ets>, Sw. <ets>fyratio</ets>, Dan.
<ets>fyrretyve</ets>, Goth. <ets>fidw<omac/r tigjus</ets>. See
<er>Four</er>, and <er>Ten</er>, and cf. <er>Fourteen</er>.]</ety>
<def>Four times ten; thirty-nine and one more.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forty</ent><br/
<hw>For"ty</hw>, <pos>n.</pos>; <plu><it>pl.</it> <plw>Forties</plw>
<pr>(-t<icr/z)</pr>.</plu> <sn>1.</sn> <def>The sum of four tens; forty
units or objects.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A symbol expressing forty units; as, 40, or
xl.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forty-niner</ent><br/
<hw>For`ty-nin"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One the miners
who took part in the California gold rush in 1849; an argonaut.</def>
<mark>[Colloq., U. S.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Forty-spot</ent><br/
<hw>For"ty-spot`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>The Tasmanian forty-spotted diamond bird (<spn>Pardalotus
quadragintus</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forum</ent><br/
<hw>Fo"rum</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it> E.
<plw>Forums</plw> <pr>(#)</pr>, L. <plw>Fora</plw> <pr>(#)</pr>.</plu>
<ety>[L.; akin to <ets>foris</ets>, <ets>foras</ets>, out of doors. See
<er>Foreign</er>.]</ety> <sn>1.</sn> <def>A market place or public place
in Rome, where causes were judicially tried, and orations delivered to
the people.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A tribunal; a court; an assembly empowered to hear
and decide causes.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He [Lord Camden] was . . . more eminent in the senate than in the
<qex>forum</qex>.</q> <rj><qau>Brougham.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forwaked</ent><br/
<hw>For*waked"</hw> <pr>(? <or/ ?)</pr>, <pos>p. p. & a.</pos>
<def>Tired out with excessive waking or watching.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forwander</ent><br/
<hw>For*wan"der</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To wander away;
to go astray; to wander far and to weariness.</def>
<mark>[Obs.]</mark><-- sic. ? --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forward</ent><br/
<hw>For"ward</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE., fr. AS.
<ets>foreweard</ets>; <ets>fore</ets> before + <ets>weard</ets> a ward.
See <er>Ward</er>, <pos>n.</pos>]</ety> <def>An agreement; a covenant; a
promise.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Tell us a tale anon, as <qex>forward</qex> is.</q>
<rj><qau>Chaucer.</qau></rj></p>

<p><ent>Forwards</ent><br/
<ent>Forward</ent><br/
<mhw>{ <hw>For"ward</hw> <pr>(?)</pr>, <hw>For"wards</hw> <pr>(?)</pr>
}</mhw>, <pos>adv.</pos> <ety>[AS. <ets>forweard</ets>,
<ets>foreweard</ets>; <ets>for</ets>, <ets>fore</ets> +
<ets>-weardes</ets>; akin to G. <ets>vorw<aum/rts</ets>. The <it>s</it>
is properly a genitive ending. See <er>For</er>, <er>Fore</er>, and
<er>-ward</er>, <er>-wards</er>.]</ety> <def>Toward a part or place
before or in front; onward; in advance; progressively; -- opposed to
<xex>backward</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forward</ent><br/
<hw>For"ward</hw>, <pos>a.</pos> <sn>1.</sn> <def>Near, or at the fore
part; in advance of something else; <as>as, the <ex>forward</ex> gun in
a ship, or the <ex>forward</ex> ship in a fleet</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Ready; prompt; strongly inclined; in an ill sense,
overready; too hasty.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Only they would that we should remember the poor; the same which I
also was <qex>forward</qex> to do.</q> <rj><qau>Gal. ii.
10.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Nor do we find him <qex>forward</qex> to be sounded.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Ardent; eager; earnest; in an ill sense, less
reserved or modest than is proper; bold; confident; <as>as, the boy is
too <ex>forward</ex> for his years</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I have known men disagreeably <qex>forward</qex> from their
shyness.</q> <rj><qau>T. Arnold.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Advanced beyond the usual degree; advanced for the
season; <as>as, the grass is <ex>forward</ex>, or <ex>forward</ex> for
the season; we have a <ex>forward</ex> spring.</as></def> <-- the latter
sense is now <er>early.</er> --><br/
[<source>1913 Webster</source>]</p>

<p><q>The most <qex>forward</qex> bud<br/
Is eaten by the canker ere it blow.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forward</ent><br/
<hw>For"ward</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Forwarded</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Forwarding</conjf>.]</vmorph> <sn>1.</sn> <def>To help onward; to
advance; to promote; to accelerate; to quicken; to hasten; <as>as, to
<ex>forward</ex> the growth of a plant; to <ex>forward</ex> one in
improvement.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To send forward; to send toward the place of
destination; to transmit; <as>as, to <ex>forward</ex> a
letter</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forwarder</ent><br/
<hw>For"ward*er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One
who forwards or promotes; a promoter.</def> <rj><au>Udall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who sends forward anything;</def>
<specif>specifically</specif>, <fld>(Com.)</fld> <def>one who transmits
goods; a forwarding merchant, such as a <styp><ecol><b>freight
forwarder</b></ecol></styp>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>3.</sn> <fld>(Bookbinding)</fld> <def>One employed in
forwarding.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forwarding</ent><br/
<hw>For"ward*ing</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act of one who
forwards; the act or occupation of transmitting merchandise or other
property for others.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bookbinding)</fld> <def>The process of putting a
book into its cover, and making it ready for the finisher.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>forward-looking</ent><br/
<hw>forward-looking</hw> <pos>adj.</pos> <def>planning for the future;
concerned primarily with the future; -- contrasted with conern for the
immediate present or reacting to past events.</def>
<contr>backward-looking</contr><br/
[<source>PJC</source>]</p>

<p><ent>Forwardly</ent><br/
<hw>For"ward*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>Eagerly;
hastily; obtrusively.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forwardness</ent><br/
<hw>For"ward*ness</hw>, <pos>n.</pos> <def>The quality of being forward;
cheerful readiness; promtness; <as>as, the <ex>forwardness</ex> of
Christians in propagating the gospel</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An advanced stage of progress or of preparation;
advancement; <as>as, his measures were in great
<ex>forwardness</ex></as>.</def> <rj><au>Robertson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Eagerness; ardor; <as>as, it is difficult to
restrain the <ex>forwardness</ex> of youth</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Boldness; confidence; assurance; want of due reserve
or modesty.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In France it is usual to bring children into company, and cherish
in them, from their infancy, a kind of <qex>forwardness</qex> and
assurance.</q> <rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A state of advance beyond the usual degree;
prematureness; precocity; <as>as, the <ex>forwardness</ex>of spring or
of corn; the <ex>forwardness</ex> of a pupil.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>He had such a dexterous proclivity, as his teachers were fain to
restrain his <qex>forwardness</qex>.</q> <rj><qau>Sir H.
Wotton.</qau></rj></p>

<p><syn><b>Syn.</b> -- Promptness; promptitude; eagerness; ardor; zeal;
assurance; confidence; boldness; impudence; presumption.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forwards</ent><br/
<hw>For"wards</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>Same as
<er>Forward</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forwaste</ent><br/
<hw>For*waste"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>for-</ets> + <ets>waste</ets>.]</ety> <def>To desolate or lay waste
utterly.</def> <mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forweary</ent><br/
<hw>For*wea"ry</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To weary
extremely; to dispirit.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forweep</ent><br/
<hw>For*weep"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To weep
much.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forwete</ent><br/
<hw>For*wete"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>See
<er>Forewite</er>.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forwhy</ent><br/
<hw>For*why"</hw> <pr>(?)</pr>, <pos>conj.</pos> <ety>[<ets>For</ets> +
<ets>why</ets>, AS. <ets>hw<?/</ets>, instrumental case of
<ets>hw<amac/</ets> who.]</ety> <def>Wherefore; because.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forworn</ent><br/
<hw>For*worn"</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Much worn.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>A silly man, in simple weeds <qex>forworn</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forwot</ent><br/
<hw>For*wot"</hw> <pr>(?)</pr>, <def><pos>pres. indic. 1st & 3d pers.
sing.</pos> of <er>Forwete</er>.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forwrap</ent><br/
<hw>For*wrap"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To wrap up; to
conceal.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>All mote be said and nought excused, nor hid, nor
<qex>forwrapped</qex>.</q> <rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foryelde</ent><br/
<hw>For*yelde"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[AS.
<ets>forgieldan</ets>.]</ety> <def>To repay; to requite.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foryete</ent><br/
<hw>For*yete"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To forget.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foryetten</ent><br/
<hw>For*yet"ten</hw> <pr>(?)</pr>, <mark>obs.</mark> <def><pos>p.
p.</pos> of <er>Foryete</er>.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Forzando</ent><br/
\'d8<hw>For*zan"do</hw> <pr>(?)</pr>, <pos>adv.</pos> <ety>[It., prop.
p. p. of <ets>forzare</ets> to force.]</ety> <fld>(Mus.)</fld> <def>See
<er>Sforzato</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>fossa</ent><br/
<ent>fossae</ent><br/
\'d8<hw>fos"sa</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>foss<ae/</plw> <pr>(#)</pr>.</plu> <ety>[L., a ditch. See
<er>Fosse</er>.]</ety> <fld>(Anat.)</fld> <def>A pit, groove, cavity, or
depression, of greater or less depth; <as>as, the temporal
<ex>fossa</ex> on the side of the skull; the nasal <ex>foss<ae/</ex>
containing the nostrils in most birds.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fossane</ent><br/
<hw>Fos"sane`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>fossane</ets>.]</ety> <fld>(Zool.)</fld> <def>A species of civet
(<spn>Viverra fossa</spn>) resembling the genet.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fosse</ent><br/
<hw>Fosse</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr. L.
<ets>fossa</ets>, fr. <ets>fodere</ets>, <ets>fossum</ets>, to
dig.]</ety> <sn>1.</sn> <fld>(Fort.)</fld> <def>A ditch or
moat.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Anat.)</fld> <def>See <er>Fossa</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fosse road</b></col>. <cd>See
<er>Fosseway</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fosset</ent><br/
<hw>Fos"set</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A faucet.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fossette</ent><br/
\'d8<hw>Fos`sette"</hw> <pr>(? <or/ ?)</pr>, <pos>n.</pos> <ety>[F.,
dim. of <ets>fosse</ets> a fosse.]</ety> <sn>1.</sn> <def>A little
hollow; hence, a dimple.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Med.)</fld> <def>A small, deep-centered ulcer of
the transparent cornea.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fosseway</ent><br/
<hw>Fosse"way`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One of the great
military roads constructed by the Romans in England and other parts of
Europe; -- so called from the <xex>fosse</xex> or ditch on each side for
keeping it dry.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fossick</ent><br/
<hw>Fos"sick</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[Dial. E.
<ets>fossick</ets>, <ets>fossuck</ets>, a troublesome person,
<ets>fussick</ets> to potter over one's work, <ets>fussock</ets> to
bustle about; of uncertain origin. Cf. <er>Fuss</er>.]</ety> <sn>1.</sn>
<fld>(Mining)</fld> <def>To search for gold by picking at stone or earth
or among roots in isolated spots, picking over abandoned workings, etc.;
hence, to steal gold or auriferous matter from another's claim.</def>
<mark>[Australia]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>To search about; to rummage.</def></p>

<p><q>A man who has <qex>fossicked</qex> in nature's byways.</q>
<rj><qau>D. Macdonald.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Fossil</ent><br/
<hw>Fos"sil</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>fossilis</ets>, fr. <ets>fodere</ets> to dig: cf. F.
<ets>fossile</ets>. See <er>Fosse</er>.]</ety> <sn>1.</sn> <def>Dug out
of the earth; <as>as, <ex>fossil</ex> coal; <ex>fossil</ex>
salt.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>preserved from a previous geological age; <as>as,
<ex>fossil</ex> water</as> from deep wells; -- usually implying that the
object so described has had its substance modified by long residence in
the ground, but also used (as with fossil water) in cases where chemical
composition is not altered.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <fld>(Paleon.)</fld> <def>Like or pertaining to fossils;
contained in rocks, whether petrified or not; <as>as, <ex>fossil</ex>
plants, shells</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fossil copal</b></col>, <cd>a resinous substance, first
found in the blue clay at Highgate, near London, and apparently a
vegetable resin, partly changed by remaining in the earth.</cd> --
<mcol><col><b>Fossil cork</b></col>, <col><b>Fossil flax</b></col>,
<col><b>Fossil paper</b></col>, <it>or</it> <col><b>Fossil
wood</b></col></mcol>, <cd>varieties of amianthus.</cd> --
<col><b>Fossil farina</b></col>, <cd>a soft carbonate of lime.</cd> --
<col><b>Fossil ore</b></col>, <cd>fossiliferous red hematite.</cd>
<rj><au>Raymond.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fossil</ent><br/
<hw>Fos"sil</hw>, <pos>n.</pos> <sn>1.</sn> <def>A substance dug from
the earth.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Formerly all minerals were called <xex>fossils</xex>,
but the word is now restricted to express the remains of animals and
plants found buried in the earth.</note> <rj><au>Ure.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Paleon.)</fld> <def>The remains of an animal or
plant found in stratified rocks. Most fossils belong to extinct species,
but many of the later ones belong to species still living.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A person whose views and opinions are extremely
antiquated; one whose sympathies are with a former time rather than with
the present.</def> <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fossiliferous</ent><br/
<hw>Fos`sil*if"er*ous</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Fossil</ets> + <ets>-ferous</ets>.]</ety>
<fld>(Paleon.)</fld> <def>Containing or composed of fossils.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fossilification</ent><br/
<hw>Fos*sil`i*fi*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Fossil</ets> + L. <ets>facere</ets> to make.]</ety> <def>The
process of becoming fossil.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fossilism</ent><br/
<hw>Fos"sil*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
science or state of fossils.</def> <rj><au>Coleridge.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The state of being extremely antiquated in views and
opinions.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fossilist</ent><br/
<hw>Fos"sil*ist</hw>, <pos>n.</pos> <def>One who is versed in the
science of fossils; a paleontologist.</def> <rj><au>Joseph
Black.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fossilization</ent><br/
<hw>Fos`sil*i*za"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>fossilisation</ets>.]</ety> <def>The process of converting, or of
being converted, into a fossil.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fossilize</ent><br/
<hw>Fos"sil*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Fossilized</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Fossilizing</conjf> <pr>(?)</pr>.]</vmorph> <ety>[Cf. F.
<ets>fossiliser</ets>.]</ety> <sn>1.</sn> <def>To convert into a fossil;
to petrify; <as>as, to <ex>fossilize</ex> bones or wood</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To cause to become antiquated, rigid, or fixed, as
by fossilization; to mummify; to deaden.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Ten layers of birthdays on a woman's head<br/
Are apt to <qex>fossilize</qex> her girlish mirth.</q> <rj><qau>Mrs.
Browning.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fossilize</ent><br/
<hw>Fos"sil*ize</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To become
fossil.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To become antiquated, rigid, or fixed, beyond the
influence of change or progress.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fossilized</ent><br/
<hw>Fos"sil*ized</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Converted into a
fossil; antiquated; firmly fixed in views or opinions.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>fossilized</qex> sample of confused provincialism.</q>
<rj><qau>Earle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fossores</ent><br/
\'d8<hw>Fos*so"res</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL., fr.
L. <ets>fossor<?/</ets> digger, fr. <ets>fodere</ets> to dig.]</ety>
<fld>(Zool.)</fld> <def>A group of hymenopterous insects including the
sand wasps. They excavate cells in earth, where they deposit their eggs,
with the bodies of other insects for the food of the young when
hatched.</def> <altsp>[Written also <asp>Fossoria</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fossoria</ent><br/
\'d8<hw>Fos*so"ri*a</hw> <pr>(?)</pr>, <pos>n. pl.</pos>
<ety>[NL.]</ety> <fld>(Zool.)</fld> <def>See
<er>Fossores</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fossorial</ent><br/
<hw>Fos*so"ri*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>fossor</ets> a digger.]</ety> <def>Fitted for digging, adapted for
burrowing or digging; <as>as, a <ex>fossorial</ex> foot; a
<ex>fossorial</ex> animal.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fossorious</ent><br/
<hw>Fos*so"ri*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Adapted for digging; -- said of the legs of certain
insects.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fossulate</ent><br/
<hw>Fos"su*late</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>fossula</ets> little ditch, dim. of <ets>fossa</ets>. See
<er>Fosse</er>.]</ety> <def>Having, or surrounded by, long, narrow
depressions or furrows.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foster</ent><br/
<hw>Fos"ter</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Fostered</conjf> <pr>(?)</pr>, <pos>p. pr. & vb.
n.</pos> <conjf>Fostering</conjf>.]</vmorph> <ety>[OE.
<ets>fostren</ets>, fr. AS. <ets>f<omac/ster</ets>,
<ets>f<omac/stor</ets>, food, nourishment, fr. <ets>f<omac/da</ets>
food. <root/75. See <er>Food</er>.]</ety> <sn>1.</sn> <def>To feed; to
nourish; to support; to bring up.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Some say that ravens <qex>foster</qex> forlorn children.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To cherish; to promote the growth of; to encourage;
to sustain and promote; <as>as, to <ex>foster</ex>
genius</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foster</ent><br/
<hw>Fos"ter</hw>, <pos>v. i.</pos> <def>To be nourished or trained up
together.</def> <mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foster</ent><br/
<hw>Fos"ter</hw>, <pos>a.</pos> <ety>[AS. <ets>f<omac/ster</ets>,
<ets>f<omac/stor</ets>, nourishment. See <er>Foster</er>, <pos>v.
t.</pos>]</ety> <def>Relating to nourishment; affording, receiving, or
sharing nourishment or nurture; -- applied to father, mother, child,
brother, etc., to indicate that the person so called stands in the
relation of parent, child, brother, etc., as regards sustenance and
nurture, but not by tie of blood.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Foster babe</b></col> <it>or</it> <col><b>Foster
child</b></col></mcol>, <cd>an infant or child nursed or raised by a
woman not its mother, or bred by a man not its father.</cd> --
<mcol><col><b>Foster brother</b></col>, <col><b>Foster
sister</b></col></mcol>, <cd>one who is, or has been, nursed at the same
breast, or brought up by the same nurse as another, but is not of the
same parentage.</cd> -- <col><b>Foster dam</b></col>, <cd>one who takes
the place of a mother; a nurse.</cd> <au>Dryden.</au> -- <col><b>Foster
earth</b></col>, <cd>earth by which a plant is nourished, though not its
native soil.</cd> <au>J. Philips.</au> -- <col><b>Foster
father</b></col>, <cd>a man who takes the place of a father in caring
for a child.</cd> <au>Bacon.</au> -- <col><b>Foster land</b></col>.
<sd>(a)</sd> <cd>Land allotted for the maintenance of any one.</cd>
<mark>[Obs.]</mark> <sd>(b)</sd> <cd>One's adopted country.</cd> --
<col><b>Foster lean</b></col> <ety>[<ets>foster</ets> + AS.
<ets>l<ae/n</ets> a loan See <er>Loan</er>.]</ety>, <cd>remuneration
fixed for the rearing of a foster child; also, the jointure of a
wife.</cd> <mark>[Obs.]</mark> <au>Wharton.</au> -- <col><b>Foster
mother</b></col>, <cd>a woman who takes a mother's place in the nurture
and care of a child; a nurse.</cd> -- <col><b>Foster nurse</b></col>,
<cd>a nurse; a nourisher.</cd> <mark>[R.]</mark> <au>Shak.</au> --
<col><b>Foster parent</b></col>, <cd>a foster mother or foster
father.</cd> -- <col><b>Foster son</b></col>, <cd>a male foster
child.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foster</ent><br/
<hw>Fos"ter</hw>, <pos>n.</pos> <def>A forester.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fosterage</ent><br/
<hw>Fos"ter*age</hw> <pr>(?; 48)</pr>, <pos>n.</pos> <def>The care of a
foster child; the charge of nursing.</def> <rj><au>Sir W.
Raleigh.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fosterer</ent><br/
<hw>Fos"ter*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, fosters.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fosterling</ent><br/
<hw>Fos"ter*ling</hw>, <pos>n.</pos> <ety>[AS.
<ets>f<omac/storling</ets>.]</ety> <def>A foster child.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fosterment</ent><br/
<hw>Fos"ter*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Food;
nourishment.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fostress</ent><br/
<hw>Fos"tress</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[For
<ets>fosteress</ets>.]</ety> <def>A woman who feeds and cherishes; a
nurse.</def> <rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fother</ent><br/
<hw>Foth"er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>fother</ets>, <ets>foder</ets>, AS. <ets>f<omac/<?/er</ets> a
cartload; akin to G. <ets>fuder</ets> a cartload, a unit of measure,
OHG. <ets>fuodar</ets>, D. <ets>voeder</ets>, and perh. to E.
<ets>fathom</ets>, or cf. Skr. <ets>p<amac/tr<amac/</ets> vessel, dish.
Cf. <er>Fodder</er> a fother.]</ety> <sn>1.</sn> <def>A wagonload; a
load of any sort.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Of dung full many a <qex>fother</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>See <er>Fodder</er>, a unit of weight.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fother</ent><br/
<hw>Foth"er</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Fothered</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Fothering</conjf>.]</vmorph> <ety>[Cf. <er>Fodder</er> food, and
G. <ets>f<uum/ttern</ets>, <ets>futtern</ets>, to cover within or
without, to line. <root/75.]</ety> <def>To stop (a leak in a ship at
sea) by drawing under its bottom a thrummed sail, so that the pressure
of the water may force it into the crack.</def>
<rj><au>Totten.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fotive</ent><br/
<hw>Fo"tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>fovere</ets>,
<ets>fotum</ets>, to keep warm, to cherish.]</ety>
<def>Nourishing.</def> <mark>[Obs.]</mark> <rj><au>T. Carew
(1633).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fotmal</ent><br/
<hw>Fot"mal</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Com.)</fld>
<def>Seventy pounds of lead.</def></p>

<p><ent>Foucault current</ent><br/
<hw>Fou`cault" cur`rent</hw> <pr>(?)</pr>. <ety>[After J. B. L.
<etsep>Foucault</etsep> (1819-68), French physicist.]</ety>
<fld>(Elec.)</fld> <def>An eddy current.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Fougasse</ent><br/
<ent>Fougade</ent><br/
<mhw>{ \'d8<hw>Fou`gade"</hw> <pr>(?)</pr>, \'d8<hw>Fou`gasse"</hw>
<pr>(?)</pr> }</mhw>, <pos>n.</pos> <fld>(Mil.)</fld> <def>A small mine,
in the form of a well sunk from the surface of the ground, charged with
explosive and projectiles. It is made in a position likely to be
occupied by the enemy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fought</ent><br/
<hw>Fought</hw> <pr>(?)</pr>, <def><pos>imp. & p. p.</pos> of
<er>Fight</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foughten</ent><br/
<hw>Fought"en</hw> <pr>(?)</pr>, <def><pos>p. p.</pos> of
<er>Fight</er>.</def> <mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foul</ent><br/
<hw>Foul</hw> <pr>(foul)</pr>, <pos>n.</pos> <ety>[See
<er>Fowl</er>.]</ety> <def>A bird.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foul</ent><br/
<hw>Foul</hw> <pr>(foul)</pr>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
Fouler <pr>(-<etil/r)</pr>; <pos>superl.</pos>
<adjf>Foulest</adjf>.]</amorph> <ety>[OE. <ets>foul</ets>,
<ets>ful</ets>, AS. <ets>f<umac/l</ets>; akin to D. <ets>vuil</ets>, G.
<ets>faul</ets> rotten, OHG. <ets>f<umac/l</ets>, Icel.
<ets>f<umac/l</ets> foul, fetid; Dan. <ets>fuul</ets>, Sw.
<ets>ful</ets> foul, Goth. <ets>f<umac/ls</ets> fetid, Lith.
<ets>puti</ets> to be putrid, L. <ets>putere</ets> to stink, be putrid,
<ets>pus</ets> pus, Gr. <grk>py`on</grk> pus, to cause to rot, Skr.
<ets>p<umac/y</ets> to stink. <root/82. Cf. <er>Defile</er> to foul,
<er>File</er> to foul, <er>Filth</er>, <er>Pus</er>,
<er>Putrid</er>.]</ety> <sn>1.</sn> <def>Covered with, or containing,
extraneous matter which is injurious, noxious, offensive, or
obstructive; filthy; dirty; not clean; polluted; nasty; defiled; <as>as,
a <ex>foul</ex> cloth; <ex>foul</ex> hands; a <ex>foul</ex> chimney;
<ex>foul</ex> air; a ship's bottom is <ex>foul</ex> when overgrown with
barnacles; a gun becomes <ex>foul</ex> from repeated firing; a well is
<ex>foul</ex> with polluted water.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>My face is <qex>foul</qex> with weeping.</q> <rj><qau>Job. xvi.
16.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Scurrilous; obscene or profane; abusive; <as>as,
<ex>foul</ex> words; <ex>foul</ex> language.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Hateful; detestable; shameful; odious;
wretched.</def> <ldquo/The <xex>foul</xex> with Sycorax.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Who first seduced them to that <qex>foul</qex> revolt?</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Loathsome; disgusting; <as>as, a <ex>foul</ex>
disease</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Ugly; homely; poor.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Let us, like merchants, show our <qex>foulest</qex> wares.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Not favorable; unpropitious; not fair or
advantageous; <as>as, a <ex>foul</ex> wind; a <ex>foul</ex> road</as>;
cloudy or rainy; stormy; not fair; -- said of the weather, sky,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>So <qex>foul</qex> a sky clears not without a storm.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>Not conformed to the established rules and customs
of a game, conflict, test, etc.; unfair; dishonest; dishonorable;
cheating; <as>as, <ex>foul</ex> play</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>Having freedom of motion interfered with by
collision or entanglement; entangled; -- opposed to <ant>clear</ant>;
<as>as, a rope or cable may get <ex>foul</ex> while paying it
out</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 590 --></p>

<p><cs><col><b>Foul anchor</b></col>. <fld>(Naut.)</fld> <cd>See under
<er>Anchor</er>.</cd> -- <col><b>Foul ball</b></col>
<fld>(Baseball)</fld>, <cd>a ball that first strikes the ground outside
of the foul ball lines, or rolls outside of certain limits.</cd> --
<col><b>Foul ball lines</b></col> <fld>(Baseball)</fld>, <cd>lines from
the home base, through the first and third bases, to the boundary of the
field.</cd> -- <col><b>Foul berth</b></col> <fld>(Naut.)</fld>, <cd>a
berth in which a ship is in danger of fouling another vesel.</cd> --
<mcol><col><b>Foul bill</b></col>, <it>or</it> <col><b>Foul bill of
health</b></col></mcol>, <cd>a certificate, duly authenticated, that a
ship has come from a place where a contagious disorder prevails, or that
some of the crew are infected.</cd> -- <col><b>Foul copy</b></col>,
<cd>a rough draught, with erasures and corrections; -- opposed to
<xex>fair</xex> or <xex>clean copy</xex>.</cd> <ldquo/Some writers boast
of negligence, and others would be ashamed to show their <xex>foul
copies</xex>.<rdquo/ <au>Cowper.</au> -- <col><b>Foul proof</b></col>,
<cd>an uncorrected proof; a proof containing an excessive quantity of
errors.</cd> -- <col><b>Foul strike</b></col> <fld>(Baseball)</fld>,
<cd>a strike by the batsman when any part of his person is outside of
the lines of his position.</cd> -- <col><b>To fall foul</b></col>,
<cd>to fall out; to quarrel.</cd> <mark>[Obs.]</mark> <ldquo/If they be
any ways offended, they <xex>fall foul</xex>.<rdquo/ <au>Burton.</au> --
<mcol><col><b>To fall foul of</b></col> <it>or</it> <col><b>To run foul
of</b></col></mcol>. <cd>See under <er>Fall</er>.</cd> -- <col><b>To
make foul water</b></col>, <cd>to sail in such shallow water that the
ship's keel stirs the mud at the bottom.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foul</ent><br/
<hw>Foul</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Fouled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Fouling</conjf>.]</vmorph> <sn>1.</sn> <def>To make filthy; to
defile; to daub; to dirty; to soil; <as>as, to <ex>foul</ex> the face or
hands with mire</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mil.)</fld> <def>To incrust (the bore of a gun)
with burnt powder in the process of firing.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To cover (a ship's bottom) with anything that
impered its sailing; <as>as, a bottom <ex>fouled</ex> with
barnacles</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To entangle, so as to impede motion; <as>as, to
<ex>foul</ex> a rope or cable in paying it out</as>; to come into
collision with; <as>as, one boat <ex>fouled</ex> the other in a
race</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foul</ent><br/
<hw>Foul</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To become clogged with
burnt powder in the process of firing, as a gun.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To become entagled, as ropes; to come into collision
with something; <as>as, the two boats <ex>fouled</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foul</ent><br/
<hw>Foul</hw>, <pos>n.</pos> <sn>1.</sn> <def>An entanglement; a
collision, as in a boat race.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Baseball)</fld> <def>See <cref>Foul ball</cref>,
under <er>Foul</er>, <pos>a.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>In various games or sports, an act done contrary to
the rules; a foul stroke, hit, play, or the like.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Foulard</ent><br/
\'d8<hw>Fou`lard"</hw> <pr>(f. f<oomac/`l<adot/r"; E.
f<oomac/`l<aum/rd")</pr>, <pos>n.</pos> <ety>[F.]</ety> <sn>1.</sn>
<def>A thin, washable material of silk, or silk and cotton, usually with
a printed pattern on it. It was originally imported from India, but now
also made elsewhere.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>an article of clothing made of <er>foulard{1}</er>,
such as a neckpiece.</def><br/
[<source>PJC</source>]</p>

<p><ent>Foulder</ent><br/
<hw>Foul"der</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[OE.
<ets>fouldre</ets> lightning, fr. F. <ets>foudre</ets>, OF. also
<ets>fouldre</ets>, fr. L. <ets>fulgur</ets>. See
<er>Fulgor</er>.]</ety> <def>To flash, as lightning; to lighten; to
gleam; to thunder.</def> <mark>[Obs.]</mark> <ldquo/Flames of
<xex>fouldering</xex> heat.<rdquo/ <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foule</ent><br/
<hw>Foul"e</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>Foully.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foully</ent><br/
<hw>Foul"ly</hw> <pr>(?)</pr>, <pos>v.</pos> <def>In a foul manner;
filthily; nastily; shamefully; unfairly; dishonorably.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I <qex>foully</qex> wronged him; do forgive me, do.</q>
<rj><qau>Gay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foul-mouthed</ent><br/
<hw>Foul"-mouthed`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Using language
scurrilous, opprobrious, obscene, or profane; abusive; <as>as, noisy
<ex>foul-mouthed</ex> women all shouting at once</as>.</def><br/
<syn><b>Syn. --</b> foul-spoken.</syn><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><q>So <qex>foul-mouthed</qex> a witness never appeared in any
cause.</q> <rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foulness</ent><br/
<hw>Foul"ness</hw>, <pos>n.</pos> <ety>[AS.
<ets>f<umac/lnes</ets>.]</ety> <def>The quality or condition of being
foul.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>foul-smelling</ent><br/
<hw>foul-smelling</hw> <pos>adj.</pos> <def>emitting an unpleasasnt
odor.</def><br/
<syn><b>Syn. --</b> fetid, foul, funky, noisome, smelly, putrid,
stinking.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Foul-spoken</ent><br/
<hw>Foul"-spo`ken</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Using profane,
scurrilous, slanderous, or obscene language; same as
<er>foul-mouthed</er>.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>foul-up</ent><br/
<hw>foul-up</hw> <pos>n.</pos> <def>an embarrassing mistake.</def><br/
<syn><b>Syn. --</b> blunder, blooper, bungle, flub, botch, boner,
boo-boo, misdoing.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Foumart</ent><br/
<hw>Fou"mart`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>folmard</ets>, <ets>fulmard</ets>; AS. <ets>f<umac/l</ets> foul +
<ets>mear<edh/</ets>, <ets>meard</ets>, marten: cf. F. <ets>marte</ets>,
<ets>martre</ets>. See <er>Foul</er>, <pos>a.</pos>, and <er>Marten</er>
the quadruped.]</ety> <fld>(Zool.)</fld> <def>The European polecat; --
called also <altname>European ferret</altname>, and
<altname>fitchew</altname>. See <er>Polecat</er>.</def> <altsp>[Written
also <asp>foulmart</asp>, <asp>foulimart</asp>, and
<asp>fulimart</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Found</ent><br/
<hw>Found</hw> <pr>(?)</pr>, <def><pos>imp. & p. p.</pos> of
<er>Find</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Found</ent><br/
<hw>Found</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Founded</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Founding</conjf>.]</vmorph> <ety>[F. <ets>fondre</ets>, L.
<ets>fundere</ets> to found, pour.]</ety> <def>To form by melting a
metal, and pouring it into a mold; to cast.</def> <ldquo/Whereof to
<xex>found</xex> their engines.<rdquo/ <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Found</ent><br/
<hw>Found</hw>, <pos>n.</pos> <def>A thin, single-cut file for
combmakers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Found</ent><br/
<hw>Found</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Founded</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Founding</conjf>.]</vmorph> <ety>[F. <ets>fonder</ets>, L.
<ets>fundare</ets>, fr. <ets>fundus</ets> bottom. See 1st
<er>Bottom</er>, and cf. <er>Founder</er>, <pos>v. i.</pos>,
<er>Fund</er>.]</ety> <sn>1.</sn> <def>To lay the basis of; to set, or
place, as on something solid, for support; to ground; to establish upon
a basis, literal or figurative; to fix firmly.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I had else been perfect,<br/
Whole as the marble, <qex>founded</qex> as the rock.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A man that all his time<br/
Hath <qex>founded</qex> his good fortunes on your love.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>It fell not, for it was <qex>founded</qex> on a rock.</q>
<rj><qau>Matt. vii. 25.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To take the ffirst steps or measures in erecting or
building up; to furnish the materials for beginning; to begin to raise;
to originate; <as>as, to <ex>found</ex> a college; to <ex>found</ex> a
family.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>There they shall <qex>found</qex><br/
Their government, and their great senate choose.</q>
<rj><qau>Milton.</qau></rj></p>

<p><syn><b>Syn.</b> -- To base; ground; institute; establish; fix. See
<er>Predicate</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foundation</ent><br/
<hw>Foun*da"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>fondation</ets>, L. <ets>fundatio</ets>. See <er>Found</er> to
establish.]</ety> <sn>1.</sn> <def>The act of founding, fixing,
establishing, or beginning to erect.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That upon which anything is founded; that on which
anything stands, and by which it is supported; the lowest and supporting
layer of a superstructure; groundwork; basis.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Behold, I lay in Zion, for a <qex>foundation</qex>, a stone . . .
a precious corner stone, a sure <qex>foundation</qex>.</q> <rj><qau>Is.
xxviii. 16.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>foundation</qex> of a free common wealth.</q>
<rj><qau>Motley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Arch.)</fld> <def>The lowest and supporting part or
member of a wall, including the base course (see <cref>Base
course</cref> <sd>(a)</sd>, under <er>Base</er>, <pos>n.</pos>) and
footing courses; in a frame house, the whole substructure of
masonry.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A donation or legacy appropriated to support a
charitable institution, and constituting a permanent fund;
endowment.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He was entered on the <qex>foundation</qex> of Westminster.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>That which is founded, or established by endowment;
an endowed institution or charity; <as>as, the Ford
<ex>Foundation</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Against the canon laws of our <qex>foundation</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Foundation course</b></col>. <cd>See <cref>Base
course</cref>, under <er>Base</er>, <pos>n.</pos></cd> --
<col><b>Foundation muslin</b></col>, <cd>an open-worked gummed fabric
used for stiffening dresses, bonnets, etc.</cd> -- <col><b>Foundation
school</b></col>, <cd>in England, an endowed school.</cd> -- <col><b>To
be on a foundation</b></col>, <cd>to be entitled to a support from the
proceeds of an endowment, as a scholar or a fellow of a
college.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foundationer</ent><br/
<hw>Foun*da"tion*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
derives support from the funds or foundation of a college or
school.</def> <mark>[Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foundationless</ent><br/
<hw>Foun*da"tion*less</hw>, <pos>a.</pos> <def>Having no
foundation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>founded</ent><br/
<hw>founded</hw> <pos>adj.</pos> <def>based; -- often used as combining
terms; <as>as, well-<ex>founded</ex> suspicions</as>.</def><br/
<syn><b>Syn. --</b> based.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Founder</ent><br/
<hw>Found"er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. OF.
<ets>fondeor</ets>, F. <ets>fondateur</ets>, L.
<ets>fundator</ets>.]</ety> <def>One who founds, establishes, and
erects; one who lays a foundation; an author; one from whom anything
originates; one who endows.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Founder</ent><br/
<hw>Found"er</hw>, <pos>n.</pos> <ety>[From <er>Found</er> to
cast.]</ety> <def>One who founds; one who casts metals in various forms;
a caster; <as>as, a <ex>founder</ex> of cannon, bells, hardware, or
types</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fonder's dust</b></col>. <cd>Same as <er>Facing</er>,
4.</cd> -- <col><b>Founder's sand</b></col>, <cd>a kind of sand suitable
for purposes of molding.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Founder</ent><br/
<hw>Found"er</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Foundered</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Foundering</conjf>.]</vmorph> <ety>[OF.
<ets>fondrer</ets> to fall in, cf. F. <ets>s'effondrer</ets>, fr.
<ets>fond</ets> bottom, L. <ets>fundus</ets>. See <er>Found</er> to
establish.]</ety> <sn>1.</sn> <fld>(Naut.)</fld> <def>To become filled
with water, and sink, as a ship.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To fall; to stumble and go lame, as a
horse.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>For which his horse fear<eacute/ gan to turn,<br/
And leep aside, and <qex>foundrede</qex> as he leep.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To fail; to miscarry.</def> <ldquo/All his tricks
<xex>founder</xex>.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Founder</ent><br/
<hw>Found"er</hw>, <pos>v. t.</pos> <def>To cause internal inflammation
and soreness in the feet or limbs of (a horse), so as to disable or lame
him.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Founder</ent><br/
<hw>Found"er</hw>, <pos>n.</pos> <fld>(Far.)</fld> <sd>(a)</sd> <def>A
lameness in the foot of a horse, occasioned by inflammation;
closh.</def> <sd>(b)</sd> <def>An inflammatory fever of the body, or
acute rheumatism; <as>as, chest <ex>founder</ex></as>. See <er>Chest
ffounder</er>.</def> <rj><au>James White.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Founderous</ent><br/
<hw>Foun"der*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Difficult to
travel; likely to trip one up; <as>as, a <ex>founderous</ex>
road</as>.</def> <mark>[R.]</mark> <rj><au>Burke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foundershaft</ent><br/
<hw>Found"er*shaft`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Mining)</fld>
<def>The first shaft sunk.</def> <rj><au>Raymond.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foundery</ent><br/
<hw>Found"er*y</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Founderies</plw> <pr>(#)</pr>.</plu> <ety>[F. <ets>fonderie</ets>,
fr. <ets>fondre</ets>. See <er>Found</er> to cast, and cf.
<er>Foundry</er>.]</ety> <def>Same as <er>Foundry</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Founding</ent><br/
<hw>Found"ing</hw>, <pos>n.</pos> <def>The art of smelting and casting
metals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foundling</ent><br/
<hw>Found"ling</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>foundling</ets>, <ets>fundling</ets>; <ets>finden</ets> to find +
<ets>-ling</ets>; cf. <ets>f<uum/ndling</ets>, <ets>findling</ets>. See
<er>Find</er>, <pos>v. t.</pos>, and <er>-ling</er>.]</ety> <def>A
deserted or exposed infant; a child found without a parent or
owner.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Foundling hospital</b></col>, <cd>a hospital for
foundlings.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foundress</ent><br/
<hw>Found"ress</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A female founder; a
woman who founds or establishes, or who endows with a fund.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foundry</ent><br/
<hw>Found"ry</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Foundries</plw> <pr>(#)</pr>.</plu> <ety>[See
<er>Foundery</er>.]</ety> <sn>1.</sn> <def>The act, process, or art of
casting metals.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The buildings and works for casting
metals.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Foundry ladle</b></col>, <cd>a vessel for holding molten
metal and conveying it from cupola to the molds.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fount</ent><br/
<hw>Fount</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Font</er>.]</ety> <fld>(Print.)</fld> <def>A font.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fount</ent><br/
<hw>Fount</hw>, <pos>n.</pos> <ety>[OF. <ets>font</ets>,
<ets>funt</ets>, fr. L. <ets>fons</ets>, <ets>fontis</ets>, a fountain;
of uncertain origin, perh. akin to <ets>fundere</ets> to pour, E.
<ets>found</ets> to cast. Cf. <er>Font</er>.]</ety> <def>A
fountain.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fountain</ent><br/
<hw>Foun"tain</hw> <pr>(foun"t<icr/n)</pr>, <pos>n.</pos> <ety>[F.
<ets>fontaine</ets>, LL. <ets>fontana</ets>, fr. L. <ets>fons</ets>,
<ets>fontis</ets>. See 2d <er>Fount</er>.]</ety> <sn>1.</sn> <def>A
spring of water issuing from the earth.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An artificially produced jet or stream of water;
also, the structure or works in which such a jet or stream rises or
flows; a basin built and constantly supplied with pure water for
drinking and other useful purposes, or for ornament.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A reservoir or chamber to contain a liquid which can
be conducted or drawn off as needed for use; <as>as, the ink
<ex>fountain</ex> in a printing press, etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The source from which anything proceeds, or from
which anything is supplied continuously; origin; source.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Judea, the <qex>fountain</qex> of the gospel.</q>
<rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Author of all being,<br/
<qex>Fountain</qex> of light, thyself invisible.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Air fountain</b></col>. <cd>See under <er>Air</er>.</cd>
-- <col><b>Fountain heead</b></col>, <cd>primary source; original; first
principle.</cd> <au>Young.</au> -- <col><b>Fountain inkstand</b></col>,
<cd>an inkstand having a continual supply of ink, as from elevated
reservoir.</cd> -- <col><b>Fountain lamp</b></col>, <cd>a lamp fed with
oil from an elevated reservoir.</cd> -- <col><b>Fountain pen</b></col>,
<cd>a pen with a reservoir in the handle which furnishes a supply of
ink.</cd> -- <col><b>Fountain pump</b></col>. <sd>(a)</sd> <cd>A
structure for a fountain, having the form of a pump.</cd> <sd>(b)</sd>
<cd>A portable garden pump which throws a jet, for watering plants,
etc.</cd> -- <col><b>Fountain shell</b></col> <fld>(Zool.)</fld>,
<cd>the large West Indian conch shell (<spn>Strombus gigas</spn>).</cd>
-- <col><b>Fountain of youth</b></col>, <cd>a mythical fountain whose
waters were fabled to have the property of renewing youth.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>fountainhead</ent><br/
<hw>fountainhead</hw> <pos>n.</pos> <sn>1.</sn> <def>an abundant
source.</def><br/
<syn><b>Syn. --</b> well, wellspring.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>the source of water from which a stream
arises.</def><br/
<syn><b>Syn. --</b> headspring, head.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fountainless</ent><br/
<hw>Foun"tain*less</hw>, <pos>a.</pos> <def>Having no fountain;
destitute of springs or sources of water.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Barren desert, <qex>fountainless</qex> and dry.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fountful</ent><br/
<hw>Fount"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Full of
fountains.</def> <rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fouquieria</ent><br/
<hw>Fouquieria</hw> <pos>n.</pos> <def>a genus of resinous succulent
trees or shrubs of desert and semi-desert regions of the southwestern U.
S. that are leafless most of the year.</def><br/
<syn><b>Syn. --</b> genus <gen>Fouquieria</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fouquieriaceae</ent><br/
<hw>Fouquieriaceae</hw> <pos>prop. n.</pos> <def>a small natural family
of spiny shrubs or trees of the southwestern U. S.</def><br/
<syn><b>Syn. --</b> family <fam>Fouquieriaceae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Four</ent><br/
<hw>Four</hw> <pr>(f<omac/r)</pr>, <pos>a.</pos> <ety>[OE.
<ets>four</ets>, <ets>fower</ets>, <ets>feower</ets>, AS.
<ets>fe<oacute/wer</ets>; akin to OS. <ets>fiwar</ets>, D. & G.
<ets>vier</ets>, OHG. <ets>fior</ets>, Icel. <ets>fj<omac/rir</ets>, Sw.
<ets>fyra</ets>, Dan. <ets>fire</ets>, Goth. <ets>fidw<omac/r</ets>,
Russ. <ets>chetuire</ets>, <ets>chetvero</ets>, W. <ets>pedwar</ets>, L.
<ets>quatuor</ets>, Gr. <grk>te`ttares</grk>, <grk>te`ssares</grk>,
<grk>pi`syres</grk>, Skr. <ets>catur</ets>. <root/302. Cf.
<er>Farthing</er>, <er>Firkin</er>, <er>Forty</er>, <er>Cater</er> four,
<er>Quater-cousin</er>, <er>Quatuor</er>, <er>Quire</er> of paper,
<er>tetrarch</er>.]</ety> <def>One more than three; twice two.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Four</ent><br/
<hw>Four</hw>, <pos>n.</pos> <sn>1.</sn> <def>The sum of four units;
four units or objects.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A symbol representing four units, as 4 or
iv.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Four things of the same kind, esp. four horses;
<as>as, a chariot and <ex>four</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>All fours</b></col>. <cd>See <er>All fours</er>, in the
Vocabulary.</cd></cs></p>

<p><ent>Fourbe</ent><br/
<ent>Fourb</ent><br/
<mhw>{ <hw>Fourb</hw>, <hw>Fourbe</hw> <pr>(?)</pr> }</mhw>,
<pos>n.</pos> <ety>[F.]</ety> <def>A tricky fellow; a cheat.</def>
<mark>[Obs.]</mark> <rj><au>Evelyn.</au> <au>Denham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fourche</ent><br/
\'d8<hw>Four`ch<eacute/"</hw> <pr>(f<oomac/r`sh<asl/")</pr>,
<pos>a.</pos> <ety>[F. See <er>Fork</er>.]</ety> <fld>(Her.)</fld>
<def>Having the ends forked or branched, and the ends of the branches
terminating abruptly as if cut off; -- said of an ordinary, especially
of a cross.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fourchette</ent><br/
\'d8<hw>Four`chette"</hw> <pr>(f<oomac/r`sh<ecr/t")</pr>, <pos>n.</pos>
<ety>[F., dim. of <ets>fourche</ets>. See <er>Fork</er>.]</ety>
<sn>1.</sn> <def>A table fork.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Anat.)</fld> <sd>(a)</sd> <def>A small fold of
membrane, connecting the labia in the posterior part of the vulva.</def>
<sd>(b)</sd> <def>The wishbone or furculum of birds.</def> <sd>(c)</sd>
<def>The frog of the hoof of the horse and allied animals.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Surg.)</fld> <def>An instrument used to raise and
support the tongue during the cutting of the fr<ae/num.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Glove Making)</fld> <def>The forked piece between
two adjacent fingers, to which the front and back portions are
sewed.</def> <rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Card Playing)</fld> <def>The combination of the
card immediately above and the one immediately below a given
card.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Four-cornered</ent><br/
<hw>Four"-cor`nered</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having four
corners or angles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Four-cycle</ent><br/
<hw>Four"-cy`cle</hw>, <pos>n.</pos> <fld>(Thermodynamics)</fld> <def>A
four-stroke cycle, as the Otto cycle, for an internal-combustion
engine.</def> -- <wordforms><wf>Four"-cy`cle</wf>,
<pos>a.</pos></wordforms><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Fourdrinier</ent><br/
<hw>Four`dri`nier"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A machine used
in making paper; -- so named from an early inventor of improvements in
this class of machinery.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fourfold</ent><br/
<hw>Four"fold`</hw> <pr>(?)</pr>, <pos>a. & adv.</pos> <ety>[AS.
<ets>fe<oacute/werfeold</ets>.]</ety> <def>Four times; quadruple;
<as>as, a <ex>fourfold</ex> division</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He shall restore the lamb <qex>fourfold</qex>.</q> <rj><qau>2 Sam.
xii. 6.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fourfold</ent><br/
<hw>Four"fold`</hw>, <pos>n.</pos> <def>Four times as many or as
much.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fourfold</ent><br/
<hw>Four"fold`</hw>, <pos>v. t.</pos> <def>To make four times as much or
as many, as an assessment; to quadruple.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fourfooted</ent><br/
<hw>Four"foot`ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having four feet;
quadruped; <as>as, <ex>fourfooted</ex> beasts</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fourgon</ent><br/
\'d8<hw>Four`gon"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<fld>(Mil.)</fld> <sd>(a)</sd> <def>An ammunition wagon.</def>
<sd>(b)</sd> <def>A French baggage wagon.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fourhanded</ent><br/
<hw>Four"hand`ed</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Having four hands; quadrumanous.</def>
<rj><au>Goldsmith.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Requiring four <ldquo/hands<rdquo/ or players;
<as>as, a <ex>fourhanded</ex> game at cards</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>four-hitter</ent><br/
<hw>four-hitter</hw> <pos>n.</pos> <fld>(Baseball)</fld> <def>A game in
which a pitcher allows the opposing team four hits; <as>as, he pitched a
<ex>four-hitter</ex></as>.</def><br/
<syn><b>Syn. --</b> 4-hitter.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>four-in-hand</ent><br/
<hw>four-in-hand</hw> <pos>n.</pos> <sn>1.</sn> <def>A long necktie that
is tied in a slipknot with one end hanging in front of the
other.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>a coach pulled by four horses with one
driver.</def><br/
<syn><b>Syn. --</b> coach, coach-and-four.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fourierism</ent><br/
<hw>Fou"ri*er*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The
co<oum/perative socialistic system of <person>Charles
<etsep>Fourier</etsep></person>, a Frenchman, who recommended the
reorganization of society into small communities, living in
common.</def></p>

<p><ent>Fourierite</ent><br/
<ent>Fourierist</ent><br/
<mhw>{ <hw>Fou"ri*er*ist</hw>, <hw>Fou"ri*er*ite</hw> <pr>(?)</pr>
}</mhw>, <pos>n.</pos> <def>One who adopts the views of
<persfn>Fourier</persfn>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Four-in-hand</ent><br/
<hw>Four"-in-hand</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Consisting of
four horses controlled by one person; <as>as, a <ex>four-in-hand</ex>
team</as>; drawn by four horses driven by one person; <as>as, a
<ex>four-in-hand</ex> coach</as>.</def> -- <def2><pos>n.</pos> <def>A
team of four horses driven by one person; also, a vehicle drawn by such
a team.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><q>As quaint a <qex>four-in-hand</qex><br/
As you shall see.</q> <rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>four-lane</ent><br/
<hw>four-lane</hw> <pos>adj.</pos> <def>Having two lanes for traffic in
each direction; -- of paved highways.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fourling</ent><br/
<hw>Four"ling</hw>, <pos>n.</pos> <sn>1.</sn> <def>One of four children
born at the same time; a quadruplet.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Crystallog.)</fld> <def>A compound or twin crystal
consisting of four individuals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fourneau</ent><br/
\'d8<hw>Four`neau"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<fld>(Mil.)</fld> <def>The chamber of a mine in which the powder is
placed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Four-o'clock</ent><br/
<hw>Four"-o'clock`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<fld>(Bot.)</fld> <def>A plant of the genus <gen>Mirabilis</gen>. There
are about half a dozen species, natives of the warmer parts of America.
The common <ex>four-o'clock</ex> is <spn>M. Jalapa</spn>. Its flowers
are white, yellow, and red, and open toward sunset, or earlier in cloudy
weather; hence the name. It is also called <altname>marvel of
Peru</altname>, and <altname>afternoon lady</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>The friar bird; -- so called from
its cry, which resembles these words.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>four-party</ent><br/
<hw>four-party</hw> <pos>adj.</pos> <def>involving four
parties.</def><br/
<syn><b>Syn. --</b> quadripartite.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fourpence</ent><br/
<hw>Four"pence</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A
British silver coin, worth four pence; a groat.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A name formerly given in New England to the Spanish
half real, a silver coin worth six and a quarter cents.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>four-ply</ent><br/
<hw>four-ply</hw> <pos>adj.</pos> <def>having a thickness made up of
four layers or strands; <as>as, <ex>four-ply</ex> yarns</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Four-poster</ent><br/
<hw>Four"-post`er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A large bedstead
with tall posts at the corners to support a canopy or curtains.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>four-pounder</ent><br/
<hw>four-pounder</hw> <pos>n.</pos> <def>a cannon that throws a 4-pound
shot.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fourrier</ent><br/
<hw>Four"rier</hw> <pr>(?; F. <?/)</pr>, <pos>n.</pos> <ety>[F., fr. OF.
<ets>forre</ets>. See <er>Forage</er>, <pos>n.</pos>]</ety> <def>A
harbinger.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fourscore</ent><br/
<hw>Four"score`</hw> <pr>(f<omac/r"sk<omac/r`)</pr>, <pos>a.</pos>
<ety>[<ets>Four</ets> + <ets>core</ets>, <pos>n.</pos>]</ety> <def>Four
times twenty; eighty.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fourscore</ent><br/
<hw>Four"score`</hw>, <pos>n.</pos> <def>The product of four times
twenty; eighty units or objects.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>four-sided</ent><br/
<hw>four-sided</hw> <pos>adj.</pos> <def>Having four sides.</def><br/
<syn><b>Syn. --</b> quadrilateral.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Foursome</ent><br/
<hw>Four"some</hw> <pr>(f<omac/r"s<ucr/m)</pr>, <pos>a.</pos>
<ety>[<ets>Four</ets> + 2d <ets>-some</ets>.]</ety> <def>Consisting of
four; requiring four participants.</def> <mark>[Scot. or
Golf]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Foursome</ent><br/
<hw>Four"some</hw>, <pos>n.</pos> <sn>1.</sn> <fld>(Golf)</fld> <def>A
game between four players, with two on each side and each side playing
but one ball, the partners striking alternately. It is called a
<ecol><b>mixed foursome</b></ecol> when each side consists of a man and
a woman.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>A group of four people or objects; <as>as, we need
another player to make a <ex>foursome</ex> for bridge</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>four-spot</ent><br/
<hw>four-spot</hw> <pos>n.</pos> <def>A playing card or domino or die
whose upward face shows four pips.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Foursquare</ent><br/
<hw>Four"square`</hw> <pr>(f<omac/r"skw<acir/r`)</pr>, <pos>a.</pos>
<def>Having four sides and four equal angles.</def> <rj><au>Sir W.
Raleigh.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fourteen</ent><br/
<hw>Four"teen`</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OE.
<ets>fourtene</ets>, <ets>feowertene</ets>, AS.
<ets>fe<oacute/wert<ymac/ne</ets>, <ets>fe<oacute/wert<emac/ne</ets>.
See <er>Four</er>, and <er>Ten</er>, and cf. <er>Forty</er>.]</ety>
<def>Four and ten more; twice seven.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fourteen</ent><br/
<hw>Four"teen`</hw>, <pos>n.</pos> <sn>1.</sn> <def>The sum of ten and
four; forteen units or objects.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A symbol representing fourteen, as 14 or
xiv.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fourteenth</ent><br/
<hw>Four"teenth`</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. OE.
<ets>fourtende</ets>, <ets>fourtethe</ets>, AS.
<ets>fe<oacute/werteo<edh/a</ets>.]</ety> <sn>1.</sn> <def>Next in order
after the thirteenth; <as>as, the <ex>fourteenth</ex> day of the
month</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Making or constituting one of fourteen equal parts
into which anything may be divided.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fourteenth</ent><br/
<hw>Four"teenth`</hw>, <pos>n.</pos> <sn>1.</sn> <def>One of fourteen
equal parts into which one whole may be divided; the quotient of a unit
divided by fourteen.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mus.)</fld> <def>The octave of the
seventh.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>One next after the thirteenth in a series.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fourth</ent><br/
<hw>Fourth</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OE.
<ets>fourthe</ets>, <ets>ferthe</ets>, <ets>feorthe</ets>, AS.
<ets>fe<oacute/r<edh/a</ets>, fr. <ets>fe<oacute/wer</ets> four.]</ety>
<sn>1.</sn> <def>Next in order after the third; the ordinal of
four.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Forming one of four equal parts into which anything
may be divided.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fourth</ent><br/
<hw>Fourth</hw>, <pos>n.</pos> <sn>1.</sn> <def>One of four equal parts
into which one whole may be divided; the quotient of a unit divided by
four.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mus.)</fld> <def>The interval of two tones and a
semitone, embracing four diatonic degrees of the scale; the subdominant
of any key.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>One coming next in order after the third.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>The Fourth</b></col>, <cd>specifically, in the United
States, the fourth day of July, the anniversary of the declaration of
American independence; <as>as, to celebrate <ex>the
Fourth</ex></as>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fourthly</ent><br/
<hw>Fourth"ly</hw>, <pos>adv.</pos> <def>In the fourth place.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>fourth-year</ent><br/
<hw>fourth-year</hw> <pos>adj.</pos> <def>of or pertaining to the fourth
and final year in a U. S. high school or college.</def><br/
<syn><b>Syn. --</b> senior(prenominal).</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Four-way</ent><br/
<hw>Four"-way`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Allowing passage in
either of four directions; <as>as, a <ex>four-way</ex> cock, or
valve</as>.</def> <rj><au>Francis.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Four-way cock</b></col>, <cd>a cock connected with four
pipes or ports, and having two or more passages in the plug, by which
the adjacent pipes or ports may be made to communicate; formerly used as
a valve in the steam engine, and now for various other purposes. In the
illustration, <xex>a</xex> leads to the upper end of a steam engine
cylinder, and <xex>b</xex> to the lower end; <xex>c</xex> is the steam
pipe, and <xex>d</xex> the exhaust pipe.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Four-way stop</ent><br/
<hw>Four"-way` stop</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An
intersection of two roads having stop signs at all four entry points.
The usual rule for such intersections requires that those entering the
intersection yield the right of way to vehicles entering before
them.</def><br/
[<source>PJC</source>]</p>

<p><-- p. 591 --></p>

<p><ent>Four-wheeled</ent><br/
<hw>Four"-wheeled`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having four
wheels.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Four-wheeler</ent><br/
<hw>Four"-wheel`er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A vehicle
having four wheels;</def> <specif>specifically,</specif> <def>a hackney
carriage with four weels.</def> <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><ent>Foussa</ent><br/
\'d8<hw>Fous"sa</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Natibe
name.]</ety> <fld>(Zool.)</fld> <def>A viverrine animal of Madagascar
(<spn>Cryptoprocta ferox</spn>). It resembles a cat in size and form,
and has retractile claws.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fouter</ent><br/
<hw>Fou"ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>foutre</ets>
to lecher, L. <ets>futuere</ets>. Cf. <er>Fouty</er>.]</ety> <def>A
despicable fellow.</def> <mark>[Prov. Eng.]</mark>
<rj><au>Brockett.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foutra</ent><br/
<hw>Fou"tra</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Fouter</er>.]</ety> <def>A fig; -- a word of contempt.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>foutra</qex> for the world and wordlings base!</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fouty</ent><br/
<hw>Fou"ty</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>foutu</ets>, p. p. of <ets>foutre</ets>; OF. <ets>foutu</ets>
scoundrel. See <er>Fouter</er>.]</ety> <def>Despicable.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fovea</ent><br/
\'d8<hw>Fo"ve*a</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Fove<ae/</plw> <pr>(#)</pr>.</plu> <ety>[L., a small pit.]</ety>
<def>A slight depression or pit; a fossa.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foveate</ent><br/
<hw>Fo"ve*ate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>fovea</ets>
a pit.]</ety> <def>Having pits or depressions; pitted.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foveola</ent><br/
\'d8<hw>Fo*ve"o*la</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Foveol<ae/</plw> <pr>(#)</pr>.</plu> <ety>[NL., dim. of L.
<ets>fovea</ets>.]</ety> <def>A small depression or pit; a
fovea.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foveolate</ent><br/
<hw>Fo"ve*o*late</hw> <pr>(? <or/ ?)</pr>, <pos>a.</pos> <def>Having
small pits or depressions, as the receptacle in some composite
flowers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foveolated</ent><br/
<hw>Fo"ve*o*la`ted</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Foveolate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fovilla</ent><br/
<hw>Fo*vil"la</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Fovill<ae/</plw> <pr>(#)</pr>.</plu> <ety>[Dim. fr. L. <ets>fovere
to cherish</ets>.]</ety> <fld>(Bot.)</fld> <def>One of the fine granules
contained in the protoplasm of a pollen grain.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fowl</ent><br/
<hw>Fowl</hw> <pr>(foul)</pr>, <pos>n.</pos> <plu> <note>Instead of the
<it>pl.</it> <plw>Fowls</plw> the singular is often used
collectively</note>.</plu> <ety>[OE. <ets>foul</ets>, <ets>fowel</ets>,
<ets>foghel</ets>, <ets>fuhel</ets>, <ets>fugel</ets>, AS.
<ets>fugol</ets>; akin to OS. <ets>fugal</ets> D. & G. <ets>vogel</ets>,
OHG. <ets>fogal</ets>, Icel. & Dan. <ets>fugl</ets>, Sw.
<ets>fogel</ets>, <ets>f<aring/gel</ets>, Goth. <ets>fugls</ets>; of
unknown origin, possibly by loss of <it>l</it>, from the root of E.
<ets>fly</ets>, or akin to E. <ets>fox</ets>, as being a tailed
animal.]</ety> <sn>1.</sn> <def>Any bird; esp., any large edible
bird.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Let them have dominion over the fish of the sea, and over the
<qex>fowl</qex> of the air.</q> <rj><qau>Gen. i. 26.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Behold the <qex>fowls</qex> of the air; for they sow not.</q>
<rj><qau>Matt. vi. 26.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Like a flight of <qex>fowl</qex><br/
Scattered by winds and high tempestuous gusts.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Any domesticated bird used as food, as a hen,
turkey, duck; in a more restricted sense, the common domestic cock or
hen (<spn>Gallus domesticus</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Barndoor fowl</b></col>, <it>or</it>
<col><b>Barnyard fowl</b></col></mcol>, <cd>a fowl that frequents the
barnyard; the common domestic cock or hen.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fowl</ent><br/
<hw>Fowl</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Fowled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Fowling</conjf>.]</vmorph> <def>To catch or kill wild fowl, for
game or food, as by shooting, or by decoys, nets, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Such persons as may lawfully hunt, fish, or <qex>fowl</qex>.</q>
<rj><qau>Blackstone.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fowling piece</b></col>, <cd>a light gun with smooth
bore, adapted for the use of small shot in killing birds or small
quadrupeds.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fowler</ent><br/
<hw>Fowl"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A sportsman who
pursues wild fowl, or takes or kills for food.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fowlerite</ent><br/
<hw>Fow"ler*ite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From Dr. Samuel
<ets>Fowler</ets>.]</ety> <fld>(Min.)</fld> <def>A variety of rhodonite,
from Franklin Furnace, New Jersey, containing some zinc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fowler's solution</ent><br/
<hw>Fow"ler's so*lu"tion</hw> <pr>(?)</pr>. <def>An aqueous solution of
arsenite of potassium, of such strength that one hundred parts represent
one part of arsenious acid, or white arsenic; -- named from
<etsep>Fowler</etsep>, an English physician who first brought it into
use.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fox</ent><br/
<hw>Fox</hw> <pr>(f<ocr/ks)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Foxes</plw> <pr>(#)</pr>.</plu> <ety>[AS. <ets>fox</ets>; akin to
D. <ets>vos</ets>, G. <ets>fuchs</ets>, OHG. <ets>fuhs</ets>,
<ets>foha</ets>, Goth. <ets>fa<uacute/h<omac/</ets>, Icel.
<ets>f<omac/a</ets> fox, <ets>fox</ets> fraud; of unknown origin, cf.
Skr. <ets>puccha</ets> tail. Cf. <er>Vixen</er>.]</ety> <sn>1.</sn>
<fld>(Zool.)</fld> <def>A carnivorous animal of the genus
<gen>Vulpes</gen>, family <fam>Canid<ae/</fam>, of many species. The
European fox (<spn>V. vulgaris</spn> or <spn>V. vulpes</spn>), the
American red fox (<spn>V. fulvus</spn>), the American gray fox (<spn>V.
Virginianus</spn>), and the arctic, white, or blue, fox (<spn>V.
lagopus</spn>) are well-known species.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The <xex>black</xex> or <xex>silver-gray</xex> fox is a
variety of the American red fox, producing a fur of great value; the
<xex>cross-gray</xex> and <xex>woods-gray</xex> foxes are other
varieties of the same species, of less value. The common foxes of Europe
and America are very similar; both are celebrated for their craftiness.
They feed on wild birds, poultry, and various small animals.</note><br/
[<source>1913 Webster</source>]</p>

<p><q>Subtle as the <qex>fox</qex> for prey.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>The European dragonet.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <def>The fox shark or thrasher shark;
-- called also <altname>sea fox</altname>. See <cref>Thrasher
shark</cref>, under <er>Shark</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A sly, cunning fellow.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>We call a crafty and cruel man a <qex>fox</qex>.</q>
<rj><qau>Beattie.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Naut.)</fld> <def>Rope yarn twisted together, and
rubbed with tar; -- used for seizings or mats.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>A sword; -- so called from the stamp of a
<xex>fox</xex> on the blade, or perhaps of a wolf taken for a fox.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou diest on point of <qex>fox</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <pluf>pl.</pluf> <fld>(Ethnol.)</fld> <def>A tribe of
Indians which, with the Sacs, formerly occupied the region about Green
Bay, Wisconsin; -- called also <altname>Outagamies</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fox and geese</b></col>. <sd>(a)</sd> <cd>A boy's game,
in which one boy tries to catch others as they run one goal to
another.</cd> <sd>(b)</sd> <cd>A game with sixteen checkers, or some
substitute for them, one of which is called the <xex>fox</xex>, and the
rest the <xex>geese</xex>; the <xex>fox</xex>, whose first position is
in the middle of the board, endeavors to break through the line of the
geese, and the geese to pen up the fox.</cd> -- <col><b>Fox
bat</b></col> <fld>(Zool.)</fld>, <cd>a large fruit bat of the genus
<gen>Pteropus</gen>, of many species, inhabiting Asia, Africa, and the
East Indies, esp. <spn>P. medius</spn> of India. Some of the species are
more than four feet across the outspread wings. See <er>Fruit
bat</er>.</cd> -- <col><b>Fox bolt</b></col>, <cd>a bolt having a split
end to receive a fox wedge.</cd> -- <col><b>Fox brush</b></col>
<fld>(Zool.)</fld>, <cd>the tail of a fox.</cd> -- <col><b>Fox
evil</b></col>, <cd>a disease in which the hair falls off; alopecy.</cd>
-- <col><b>Fox grape</b></col> <fld>(Bot.)</fld>, <cd>the name of two
species of American grapes. The northern fox grape (<spn>Vitis
Labrusca</spn>) is the origin of the varieties called
<stype>Isabella</stype>, <stype>Concord</stype>,
<stype>Hartford</stype>, etc., and the southern fox grape (<spn>Vitis
vulpina</spn>) has produced the <stype>Scuppernong</stype>, and probably
the <stype>Catawba</stype>.</cd> -- <col><b>Fox hunter</b></col>.
<sd>(a)</sd> <cd>One who pursues foxes with hounds.</cd> <sd>(b)</sd>
<cd>A horse ridden in a fox chase.</cd> -- <col><b>Fox shark</b></col>
<fld>(Zool.)</fld>, <cd>the thrasher shark. See <cref>Thrasher
shark</cref>, under <er>Thrasher</er>.</cd> -- <col><b>Fox
sleep</b></col>, <cd>pretended sleep.</cd> -- <col><b>Fox
sparrow</b></col> <fld>(Zool.)</fld>, <cd>a large American sparrow
(<spn>Passerella iliaca</spn>); -- so called on account of its reddish
color.</cd> -- <col><b>Fox squirrel</b></col> <fld>(Zool.)</fld>, <cd>a
large North American squirrel (<spn>Sciurus niger</spn>, or <spn>S.
cinereus</spn>). In the Southern States the black variety prevails;
farther north the fulvous and gray variety, called the <stype>cat
squirrel</stype>, is more common.</cd> -- <col><b>Fox terrier</b></col>
<fld>(Zool.)</fld>, <cd>one of a peculiar breed of terriers, used in
hunting to drive foxes from their holes, and for other purposes. There
are rough- and smooth-haired varieties.</cd> -- <col><b>Fox
trot</b></col>, <cd>a pace like that which is adopted for a few steps,
by a horse, when passing from a walk into a trot, or a trot into a
walk.</cd><-- ???a dance --> -- <col><b>Fox wedge</b></col> <fld>(Mach.
& Carpentry)</fld>, <cd>a wedge for expanding the split end of a bolt,
cotter, dowel, tenon, or other piece, to fasten the end in a hole or
mortise and prevent withdrawal. The wedge abuts on the bottom of the
hole and the piece is driven down upon it. Fastening by fox wedges is
called <xex>foxtail wedging</xex>.</cd> -- <col><b>Fox wolf</b></col>
<fld>(Zool.)</fld>, <cd>one of several South American wild dogs,
belonging to the genus <gen>Canis</gen>. They have long, bushy tails
like a fox.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fox</ent><br/
<hw>Fox</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Foxed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Foxing</conjf>.]</vmorph> <ety>[See <er>Fox</er>, <pos>n.</pos>,
cf. Icel. <ets>fox</ets> imposture.]</ety> <sn>1.</sn> <def>To
intoxicate; to stupefy with drink.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I drank . . . so much wine that I was almost <qex>foxed</qex>.</q>
<rj><qau>Pepys.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To make sour, as beer, by causing it to
ferment.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To repair the feet of, as of boots, with new front
upper leather, or to piece the upper fronts of.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fox</ent><br/
<hw>Fox</hw>, <pos>v. i.</pos> <def>To turn sour; -- said of beer, etc.,
when it sours in fermenting.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foxearth</ent><br/
<hw>Fox"earth`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A hole in the earth
to which a fox resorts to hide himself.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foxed</ent><br/
<hw>Foxed</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Discolored
or stained; -- said of timber, and also of the paper of books or
engravings.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Repaired by foxing; <as>as, <ex>foxed</ex>
boots</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foxery</ent><br/
<hw>Fox"e*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Behavior like that of
a fox; cunning.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foxes</ent><br/
<hw>Fox"es</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <fld>(Ethnol.)</fld>
<def>See <er>Fox</er>, <pos>n.</pos>, 7.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foxfish</ent><br/
<hw>Fox"fish`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<sd>(a)</sd> <def>The fox shark; -- called also <altname>sea
fox</altname>. See <cref>Thrasher shark</cref>, under
<er>Shark</er>.</def> <sd>(b)</sd> <def>The european dragonet. See
<er>Dragonet</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foxglove</ent><br/
<hw>Fox"glove`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS.
<ets>foxes-gl<omac/fa</ets>,
<ets>foxes-cl<omac/fa</ets>,<ets>foxes-clife</ets>.]</ety>
<fld>(Bot.)</fld> <def>Any plant of the genus <gen>Digitalis</gen>. The
common English foxglove (<spn>Digitalis purpurea</spn>) is a handsome
perennial or biennial plant, whose leaves are used as a powerful
medicine, both as a sedative and diuretic. See
<er>Digitalis</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Pan through the pastures oftentimes hath run<br/
To pluck the speckled <qex>foxgloves</qex> from their stem.</q>
<rj><qau>W. Browne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>foxhole</ent><br/
<hw>foxhole</hw> <pos>n.</pos> <fld>(Mil.)</fld> <def>a small pit in the
ground for individual shelter against enemy fire.</def><br/
<syn><b>Syn. --</b> fox hole.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Foxhound</ent><br/
<hw>Fox"hound`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>One of a special breed of hounds used for chasing foxes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fox-hunting</ent><br/
<hw>Fox"-hunt`ing</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to or
engaged in the hunting of foxes; fond of hunting foxes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foxiness</ent><br/
<hw>Fox"i*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
state or quality of being foxy, or foxlike; craftiness;
shrewdness.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The state of being foxed or discolored, as books;
decay; deterioration.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A coarse and sour taste in grapes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foxish</ent><br/
<hw>Fox"ish</hw>, <pos>a.</pos> <def>Foxlike.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foxlike</ent><br/
<hw>Fox"like`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Resembling a fox in
his characteristic qualities; cunning; artful; foxy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foxly</ent><br/
<hw>Fox"ly</hw>, <pos>a.</pos> <def>Foxlike.</def> <mark>[Obs.]</mark>
<ldquo/<xex>Foxly</xex> craft.<rdquo/ <rj><au>Latimer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foxship</ent><br/
<hw>Fox"ship</hw>, <pos>n.</pos> <def>Foxiness; craftiness.</def>
<mark>[R.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foxtail</ent><br/
<hw>Fox"tail`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The tail
or brush of a fox.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>The name of several kinds of grass
having a soft dense head of flowers, mostly the species of
<gen>Alopecurus</gen> and <gen>Setaria</gen>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Metal.)</fld> <def>The last cinders obtained in the
fining process.</def> <rj><au>Raymond.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Foxtail saw</b></col>, <cd>a dovetail saw.</cd> --
<col><b>Foxtail wedging</b></col>. <cd>See <cref>Fox wedge</cref>, under
<er>Fox</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>foxtrot</ent><br/
<ent>fox trot</ent><br/
<mhw><hw>fox" trot`</hw>, <hw>fox"trot`</hw></mhw> <pos>n.</pos> <def>a
ballroom dance for couples in quadruple time, combining short and long
and fast and slow steps in fixed sequences.</def><br/
<syn><b>Syn. --</b> fox-trot.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>foxtrot</ent><br/
<ent>fox-trot</ent><br/
<mhw><hw>fox"-trot`</hw>, <hw>fox"trot`</hw></mhw> <pos>v. i.</pos>
<def>To dance the foxtrot.</def><br/
[<source>PJC</source>]</p>

<p><ent>Foxy</ent><br/
<hw>Fox"y</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Like or
pertaining to the fox; foxlike in disposition or looks; wily;
cunning.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Modred's narrow, <qex>foxy</qex> face.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Having the color of a fox; of a yellowish or reddish
brown color; -- applied sometimes to paintings when they have too much
of this color.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Having the odor of a fox; rank; strong
smelling.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Sour; unpleasant in taste; -- said of wine, beer,
etc., not properly fermented; -- also of grapes which have the coarse
flavor of the fox grape.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Attractive in a sexually appealing way; --of
women.</def> <mark>[Slang]</mark> <br/
[<source>PJC</source>]</p>

<p><sn>6.</sn> <def>Stylish and sexually attractive; -- of women's
clothing; <as>as, wearing a <ex>foxy</ex> new outfit</as>.</def>
<mark>[Slang]</mark> <br/
[<source>PJC</source>]</p>

<p><ent>Foy</ent><br/
<hw>Foy</hw> <pr>(foi)</pr>, <pos>n.</pos> <ety>[F. <ets>foi</ets>, old
spelling <ets>foy</ets>, faith. See <er>Faith</er>.]</ety> <sn>1.</sn>
<def>Faith; allegiance; fealty.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A feast given by one about to leave a place.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He did at the Dog give me, and some other friends of his, his
<qex>foy</qex>, he being to set sail to-day.</q>
<rj><qau>Pepys.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foyer</ent><br/
\'d8<hw>Foy`er"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr. LL.
<ets>focarium</ets> fireplace. See <er>Focus</er>, <pos>n.</pos>]</ety>
<sn>1.</sn> <def>A lobby in a theater; a greenroom.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The crucible or basin in a furnace which receives
the molten metal.</def> <rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foyson</ent><br/
<hw>Foy"son</hw> <pr>(?)</pr>, <pos>n.</pos> <mark>[Obs.]</mark>
<def>See <er>Foison</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Foziness</ent><br/
<hw>Fo"zi*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state of being
fozy; spiritlessness; dullness.</def> <mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>[The Whigs'] <qex>foziness</qex> can no longer be concealed.</q>
<rj><qau>Blackwood's.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fozy</ent><br/
<hw>Fo"zy</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Spongy; soft; fat and
puffy.</def> <mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fra</ent><br/
<hw>Fra</hw> <pr>(fr<adot/)</pr>, <pos>adv. & prep.</pos>
<ety>[OE.]</ety> <def>Fro.</def> <mark>[Old Eng. & Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fra</ent><br/
<hw>Fra</hw> <pr>(fr<adot/)</pr>, <pos>n.</pos> <ety>[It., for
<ets>frate</ets>. See <er>Friar</er>.]</ety> <def>Brother; -- a title of
a monk or friar; <as>as, <ex>Fra</ex> Angelo</as>.</def>
<rj><au>Longfellow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frab</ent><br/
<hw>Frab</hw> <pr>(?)</pr>, <pos>v. i. & t.</pos> <def>To scold; to
nag.</def> <mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frabbit</ent><br/
<hw>Frab"bit</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Crabbed;
peevish.</def> <mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fracas</ent><br/
<hw>Fra"cas</hw> <pr>(fr<amac/"k<ait/s; F. fr<adot/`k<aum/"; 277)</pr>,
<pos>n.</pos> <ety>[F., crash, din, tumult, It. <ets>fracasso</ets>, fr.
<ets>fracassare</ets> to break in pieces, perh. fr. <ets>fra</ets>
within, among (L. <ets>infra</ets>) + <ets>cassare</ets> to annul,
cashier. Cf. <er>Cashier</er>, <pos>v. t.</pos>]</ety> <def>An uproar; a
noisy quarrel; a disturbance; a brawl.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frache</ent><br/
<hw>Frache</hw> <pr>(fr<amac/sh)</pr>, <pos>n.</pos> <def>A shallow iron
pan to hold glass ware while being annealed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fracid</ent><br/
<hw>Frac"id</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>fracidus</ets> mellow, soft.]</ety> <def>Rotten from being too
ripe; overripe.</def> <mark>[Obs.]</mark> <rj><au>Blount.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fract</ent><br/
<hw>Fract</hw> <pr>(fr<acr/kt)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>fractus</ets>, p. p. of <ets>frangere</ets> to break.]</ety>
<def>To break; to violate.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fracted</ent><br/
<hw>Frac"ted</hw>, <pos>a.</pos> <fld>(Her.)</fld> <def>Having a part
displaced, as if broken; -- said of an ordinary.</def>
<rj><au>Macaulay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fraction</ent><br/
<hw>Frac"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>fraction</ets>, L. <ets>fractio</ets> a breaking, fr.
<ets>frangere</ets>, <ets>fractum</ets>, to break. See
<er>Break</er>.]</ety> <sn>1.</sn> <def>The act of breaking, or state of
being broken, especially by violence.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Neither can the natural body of Christ be subject to any
<qex>fraction</qex> or breaking up.</q> <rj><qau>Foxe.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A portion; a fragment.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Some niggard <qex>fractions</qex> of an hour.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Arith. or Alg.)</fld> <def>One or more aliquot
parts of a unit or whole number; an expression for a definite portion of
a unit or magnitude.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Common fraction</b></col>, <it>or</it>
<col><b>Vulgar fraction</b></col></mcol>, <cd>a fraction in which the
number of equal parts into which the integer is supposed to be divided
is indicated by figures or letters, called the <xex>denominator</xex>,
written below a line, over which is the <xex>numerator</xex>, indicating
the number of these parts included in the fraction; as <frac12/, one
half, <frac25/, two fifths.</cd> -- <col><b>Complex fraction</b></col>,
<cd>a fraction having a fraction or mixed number in the numerator or
denominator, or in both.</cd> <au>Davies & Peck.</au> --
<col><b>Compound fraction</b></col>, <cd>a fraction of a fraction; two
or more fractions connected by <xex>of</xex>.</cd> --
<mcol><col><b>Continued fraction</b></col>, <col><b>Decimal
fraction</b></col>, <col><b>Partial fraction</b></col>, etc.</mcol>
<cd>See under <er>Continued</er>, <er>Decimal</er>, <er>Partial</er>,
etc.</cd> -- <col><b>Improper fraction</b></col>, <cd>a fraction in
which the numerator is greater than the denominator.</cd> --
<col><b>Proper fraction</b></col>, <cd>a fraction in which the numerator
is less than the denominator.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fraction</ent><br/
<hw>Frac"tion</hw>, <pos>v. t.</pos> <fld>(Chem.)</fld> <def>To separate
by means of, or to subject to, fractional distillation or
crystallization; to fractionate; -- frequently used with <xex>out</xex>;
<as>as, to <ex>fraction</ex> out a certain grade of oil from
pretroleum</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fractional</ent><br/
<hw>Frac"tion*al</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Of or
pertaining to fractions or a fraction; constituting a fraction; <as>as,
<ex>fractional</ex> numbers</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Relatively small; inconsiderable; insignificant;
<as>as, a <ex>fractional</ex> part of the population</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fractional crystallization</b></col> <fld>(Chem.)</fld>,
<cd>a process of gradual and approximate purification and separation, by
means of repeated solution and crystallization therefrom.</cd> --
<col><b>Fractional currency</b></col>, <cd>small coin, or paper notes,
in circulation, of less value than the monetary unit.</cd> --
<col><b>Fractional distillation</b></col> <fld>(Chem.)</fld>, <cd>a
process of distillation so conducted that a mixture of liquids,
differing considerably from each other in their boiling points, can be
separated into its constituents.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fractionally</ent><br/
<hw>Frac"tion*al*ly</hw>, <pos>adv.</pos> <def>By fractions or separate
portions; <as>as, to distill a liquid <ex>fractionally</ex>, that is, so
as to separate different portions</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fractionary</ent><br/
<hw>Frac"tion*a*ry</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Fractional.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fractionate</ent><br/
<hw>Frac"tion*ate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To separate
(a mixture of chemical substances) into different portions or fractions,
as in the distillation of liquids.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>fractionation</ent><br/
<hw>frac`tion*a"tion</hw> <pos>n.</pos> <def>the act or process of
separating a mixture into portions of different composition, as in
distillation or <cref>fractional crystallization</cref>.</def><br/
<syn><b>Syn. --</b> fractional process.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <fld>(Petroleum industry)</fld> <def>Separation of crude
oil into components of differing composition by <cref>fractional
distillation</cref>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Fractious</ent><br/
<hw>Frac"tious</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. Prov. E.
<ets>frack</ets> forward, eager, E. <ets>freak</ets>, <ets>fridge</ets>;
or Prov. E. <ets>fratch</ets> to squabble, quarrel.]</ety> <def>Apt to
break out into a passion; apt to scold; cross; snappish; ugly; unruly;
<as>as, a <ex>fractious</ex> man; a <ex>fractious</ex>
horse.</as></def></p>

<p><syn><b>Syn.</b> -- Snappish; peevish; waspish; cross; irritable;
perverse; pettish.</syn></p>

<p>-- <wordforms><wf>Frac"tious*ly</wf>, <pos>v.</pos> --
<wf>Frac"tious*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fractural</ent><br/
<hw>Frac"tur*al</hw> <pr>(?; 135)</pr>, <pos>a.</pos> <def>Pertaining
to, or consequent on, a fracture.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fracture</ent><br/
<hw>Frac"ture</hw> <pr>(?; 135)</pr>, <pos>n.</pos> <ety>[L.
<ets>fractura</ets>, fr. <ets>frangere</ets>, <ets>fractum</ets>, to
break: cf. F. <ets>fracture</ets>. See <er>Fraction</er>.]</ety>
<sn>1.</sn> <def>The act of breaking or snapping asunder; rupture;
breach.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Surg.)</fld> <def>The breaking of a bone.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Min.)</fld> <def>The texture of a freshly broken
surface; <as>as, a compact <ex>fracture</ex>; an even, hackly, or
conchoidal <ex>fracture</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Comminuted fracture</b></col> <fld>(Surg.)</fld>, <cd>a
fracture in which the bone is broken into several parts.</cd> --
<col><b>Complicated fracture</b></col> <fld>(Surg.)</fld>, <cd>a
fracture of the bone combined with the lesion of some artery, nervous
trunk, or joint.</cd> -- <col><b>Compound fracture</b></col>
<fld>(Surg.)</fld>, <cd>a fracture in which there is an open wound from
the surface down to the fracture.</cd> -- <col><b>Simple
fracture</b></col> <fld>(Surg.)</fld>, <cd>a fracture in which the bone
only is ruptured. It does not communicate with the surface by an open
wound.</cd></cs></p>

<p><syn><b>Syn.</b> -- <er>Fracture</er>, <er>Rupture</er>.</syn>
<usage>These words denote different kinds of <xex>breaking</xex>,
according to the objects to which they are applied. <xex>Fracture</xex>
is applied to hard substances; as, the <xex>fracture</xex> of a bone.
<xex>Rupture</xex> is oftener applied to soft substances; as, the
<xex>rupture</xex> of a blood vessel. It is also used figuratively.
<ldquo/To be an enemy and once to have been a friend, does it not
embitter the <xex>rupture</xex>?<rdquo/</usage>
<rj><au>South.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 592 --></p>

<p><ent>Fracture</ent><br/
<hw>Frac"ture</hw> <pr>(?; 135)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Fractured</conjf> <pr>(#;
135)</pr>; <pos>p. pr. & vb. n.</pos>.
<conjf>Fracturing</conjf>.]</vmorph> <ety>[Cf. F.
<ets>fracturer</ets>.]</ety> <def>To cause a fracture or fractures in;
to break; to burst asunder; to crack; to separate the continuous parts
of; <as>as, to <ex>fracture</ex> a bone; to <ex>fracture</ex> the
skull.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>fraenulum</ent><br/
<ent>frenulum</ent><br/
\'d8<hw>Fr<ae/n"u*lum</hw> <pr>(?)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Fr<ae/nula</plw> <pr>(#)</pr>.</plu> <ety>[NL.,
dim. of L. <ets>fraenum</ets> a bridle.]</ety> <fld>(Anat.)</fld> <def>A
fr<ae/num.</def></p>

<p><ent>frenum</ent><br/
<ent>fraenum</ent><br/
<mhw>{ <hw>Fr<ae/"num</hw> <pr>(?)</pr>, <it>or</it> <hw>Fre"num</hw>
}</mhw>, <pos>n.</pos>; <plu><it>pl.</it> E. <plw>Fr<ae/nums</plw>
<pr>(#)</pr>, L. <plw>Fr<ae/na</plw> <pr>(#)</pr>.</plu> <ety>[L., a
bridle.]</ety> <fld>(Anat.)</fld> <def>A connecting fold of membrane
serving to support or restrain any part; <as>as, the <ex>fr<ae/num</ex>
of the tongue</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>frag</ent><br/
<hw>frag</hw> <pr>(fr<acr/g)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>fragged</conjf> <pr>(fr<acr/gd)</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>fragging</conjf>.]</vmorph> <ety>[by shortening from
<ets>frag</ets>mentation grenade; ca. 1965.]</ety> <fld>(Mil.)</fld>
<def>To assault, especially to kill or wound, with a fragmentation
grenade.</def> <mark>[Slang]</mark> <note>This term became popularized
when disaffected American troops serving in Vietnam were reported on
occasion to kill unpopular commanders by the use of grenades.</note><br/
[<source>PJC</source>]</p>

<p><ent>Fragaria</ent><br/
<hw>Fragaria</hw> <pos>prop. n.</pos> <def>a genus of plants comprising
the strawberry plants.</def><br/
<syn><b>Syn. --</b> genus <gen>Fragaria</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fragile</ent><br/
<hw>Frag"ile</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>fragilis</ets>, from <ets>frangere</ets> to break; cf. F.
<ets>fragile</ets>. See <er>Break</er>, <pos>v. t.</pos>, and cf.
<er>Frail</er>, <pos>a.</pos>]</ety> <def>Easily broken; brittle; frail;
delicate; easily destroyed.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The state of ivy is tough, and not <qex>fragile</qex>.</q>
<rj><qau>Bacon.</qau></rj></p>

<p><syn><b>Syn.</b> -- Brittle; infirm; weak; frail; frangible;
slight.</syn></p>

<p>-- <wordforms><wf>Frag"ile*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fragility</ent><br/
<hw>Fra*gil"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>fragilitas</ets>: cf. F. <ets>fragilit<eacute/</ets>. Cf.
<er>Frailty</er>.]</ety> <sn>1.</sn> <def>The condition or quality of
being fragile; brittleness; frangibility.</def>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Weakness; feebleness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>An appearance of delicacy, and even of <qex>fragility</qex>, is
almost essential to it [beauty].</q> <rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Liability to error and sin; frailty.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>fragility</qex> and youthful folly of Qu. Fabius.</q>
<rj><qau>Holland.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fragment</ent><br/
<hw>Frag"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>fragmentum</ets>, fr. frangere to break: cf. F.
<ets>fragment</ets>. See <er>Break</er>, <pos>v. t.</pos>]</ety> <def>A
part broken off; a small, detached portion; an imperfect part; <as>as, a
<ex>fragment</ex> of an ancient writing</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Gather up the <qex>fragments</qex> that remain.</q> <rj><qau>John
vi. 12.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fragmental</ent><br/
<hw>Frag*men"tal</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Fragmentary.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Geol.)</fld> <def>Consisting of the pulverized or
fragmentary material of rock, as conglomerate, shale, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fragmental</ent><br/
<hw>Frag*men"tal</hw>, <pos>n.</pos> <fld>(Geol.)</fld> <def>A
fragmentary rock.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fragmentarily</ent><br/
<hw>Frag"men*ta*ri*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a
fragmentary manner; piecemeal.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fragmentariness</ent><br/
<hw>Frag"men*ta*ri*ness</hw>, <pos>n.</pos> <def>The quality or property
of being in fragments, or broken pieces; incompleteness; want of
continuity.</def> <rj><au>G. Eliot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fragmentary</ent><br/
<hw>Frag"men*ta*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>fragmentaire</ets>.]</ety> <sn>1.</sn> <def>Composed of fragments,
or broken pieces; disconnected; not complete or entire.</def>
<rj><au>Donne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Geol.)</fld> <def>Composed of the fragments of
other rocks.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>fragmentation</ent><br/
<hw>fragmentation</hw> <pos>n.</pos> <def>the act or process of
separating something into small pieces or fine particles.</def><br/
<syn><b>Syn. --</b> atomization, atomisation.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>fragmentation grenade</ent><br/
<hw>fragmentation grenade</hw> <pos>n.</pos> <fld>(Mil.)</fld> <def>A
type of hand grenade designed to burst into multiple fragments upon
detonation of the explosive charge; the fragments fly away at high
velocity, killing or wounding persons nearby. Contrasted to
<contr>concussion grenade</contr>. The common type of fragmentation
grenade used by the American military was sometimes jocosely referred to
as a <altname>pineapple</altname> from its reticulated surface
appearance, resembling that of the fruit.</def><br/
[<source>PJC</source>]</p>

<p><ent>Fragmented</ent><br/
<hw>Frag"ment*ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Broken into
fragments.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fragmentist</ent><br/
<hw>Frag"ment*ist</hw>, <pos>n.</pos> <def>A writer of fragments;
<as>as, the <ex>fragmentist</ex> of Wolfenb<uum/ttel</as>.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fragor</ent><br/
\'d8<hw>Fra"gor</hw> <pr>(<?/)</pr>, <pos>n.</pos> <ety>[L., a breaking
to pieces, fr. <ets>frangere</ets> to break.]</ety> <sn>1.</sn> <def>A
loud and sudden sound; the report of anything bursting; a crash.</def>
<rj><au>I. Watts.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <note>[Due to confusion with <xex>fragrant</xex>.]</note>
<def>A strong or sweet scent.</def> <mark>[Obs. & Illegitimate.]</mark>
<rj><au>Sir T. Herbert.</au></rj></p>

<p><ent>Fragrancy</ent><br/
<ent>Fragrance</ent><br/
<mhw>{ <hw>Fra"grance</hw> <pr>(?)</pr>, <hw>Fra"gran*cy</hw>
<pr>(?)</pr> }</mhw>, <pos>n.</pos> <ety>[L. <ets>fragrantia</ets>: cf.
OF. <ets>fragrance</ets>.]</ety> <def>The quality of being fragrant;
sweetness of smell; a sweet smell; a pleasing odor; perfume.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Eve separate he spies,<br/
Veiled in a cloud of <qex>fragrance</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The goblet crowned,<br/
Breathed aromatic <qex>fragrancies</qex> around.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fragrant</ent><br/
<hw>Fra"grant</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>fragrans</ets>. <ets>-antis</ets>, p. pr. of <ets>fragrare</ets> to
emit a smell of fragrance: cf. OF. <ets>fragrant</ets>.]</ety>
<def>Affecting the olfactory nerves agreeably; sweet of smell; odorous;
having or emitting an agreeable perfume.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Fragrant</qex> the fertile earth<br/
After soft showers.</q> <rj><qau>Milton.</qau></rj></p>

<p><syn><b>Syn.</b> -- Sweet-smelling; odorous; odoriferous;
sweet-scented; redolent; ambrosial; balmy; spicy; aromatic.</syn></p>

<p>-- <wordforms><wf>Fra"grant*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fraight</ent><br/
<hw>Fraight</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Same as
<er>Fraught</er>.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>frail</ent><br/
<hw>frail</hw> <pr>(fr<amac/l)</pr>, <pos>n.</pos> <ety>[OE.
<ets>fraiel</ets>, <ets>fraile</ets>, OF. <ets>fraiel</ets>,
<ets>freel</ets>, <ets>frael</ets>, fr. LL. <ets>fraellum</ets>.]</ety>
<def>A basket made of rushes, used chiefly for containing figs and
raisins.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The quantity of raisins -- about thirty-two,
fifty-six, or seventy-five pounds, -- contained in a frail.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A rush for weaving baskets.</def>
<rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>frail</ent><br/
<hw>frail</hw>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>frailer</adjf> <pr>(fr<amac/l"<etil/r)</pr>; <pos>superl.</pos>
<adjf>frailest</adjf>.]</amorph> <ety>[OE. <ets>frele</ets>,
<ets>freile</ets>, OF. <ets>fraile</ets>, <ets>frele</ets>, F.
<ets>fr<ecir/le</ets>, fr. L. <ets>fragilis</ets>. See
<er>Fragile</er>.]</ety> <sn>1.</sn> <def>Easily broken; fragile; not
firm or durable; liable to fail and perish; easily destroyed; not
tenacious of life; weak; infirm.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That I may know how <qex>frail</qex> I am.</q> <rj><qau>Ps. xxxix.
4.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>An old bent man, worn and <qex>frail</qex>.</q>
<rj><qau>Lowell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Tender.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Deep indignation and compassion <qex>frail</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Liable to fall from virtue or be led into sin; not
strong against temptation; weak in resolution; also, unchaste; -- often
applied to fallen women.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Man is <qex>frail</qex>, and prone to evil.</q> <rj><qau>Jer.
Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>frailly</ent><br/
<hw>frail"ly</hw>, <pos>adv.</pos> <def>Weakly; infirmly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>frailness</ent><br/
<hw>frail"ness</hw>, <pos>n.</pos> <def>Frailty.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>frailty</ent><br/
<hw>frail"ty</hw> <pr>(fr<amac/l"t<ycr/)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>frailties</plw>
<pr>(fr<amac/l"t<icr/z)</pr>.</plu> <ety>[OE. <ets>frelete</ets>,
<ets>freilte</ets>, OF. <ets>frailet<eacute/</ets>, fr. L.
<ets>fragilitas</ets>. See <er>Frail</er>, <pos>a.</pos>, and cf.
<er>Fragility</er>.]</ety> <sn>1.</sn> <def>The condition or quality of
being frail, physically, mentally, or morally; frailness; infirmity;
weakness of resolution; liableness to be deceived or seduced.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>God knows our <qex>frailty</qex>, [and] pities our weakness.</q>
<rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A fault proceeding from weakness; foible; sin of
infirmity.</def></p>

<p><syn><b>Syn.</b> -- Frailness; fragility; imperfection;
failing.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fraischeur</ent><br/
\'d8<hw>Frai"scheur</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.; F
<ets>fraicheur</ets>, fr. <ets>frais</ets>, fem.
<ets>fra<icir/che</ets>, fresh; of German origin. See <er>Frash</er>,
<pos>a.</pos>]</ety> <def>Freshness; coolness.</def> <mark>[R.]</mark>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fraise</ent><br/
<hw>Fraise</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Froise</er>.]</ety> <def>A large and thick pancake, with slices of
bacon in it.</def> <mark>[Obs.]</mark> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fraise</ent><br/
\'d8<hw>Fraise</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>fraise</ets>, orig., a ruff, cf. F. <ets>frise</ets> frieze, E.
<ets>frieze</ets> a coarse stuff.]</ety> <sn>1.</sn> <fld>(Fort.)</fld>
<def>A defense consisting of pointed stakes driven into the ramparts in
a horizontal or inclined position.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mech.)</fld> <def>A fluted reamer for enlarging
holes in stone; a small milling cutter.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fraise</ent><br/
<hw>Fraise</hw>, <pos>v. t.</pos> <fld>(Mil.)</fld> <def>To protect, as
a line of troops, against an onset of cavalry, by opposing bayonets
raised obliquely forward.</def> <rj><au>Wilhelm.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fraised</ent><br/
<hw>Fraised</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Fortified with a
fraise.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fraken</ent><br/
<hw>Frak"en</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A freckle.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>A few <qex>fraknes</qex> in his face.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Framable</ent><br/
<hw>Fram"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of being
framed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frambaesia</ent><br/
\'d8<hw>Fram*b<ae/"si*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. & NL.,
fr. F. <ets>framboise</ets> raspberry.]</ety> <fld>(Med.)</fld> <def>The
yaws. See <er>Yaws</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frame</ent><br/
<hw>Frame</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Framed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Framing</conjf>.]</vmorph> <ety>[OE. <ets>framen</ets>,
<ets>fremen</ets>, to execute, build, AS. <ets>fremman</ets> to further,
perform, effect, fr. <ets>fram</ets> strong, valiant; akin to E.
<ets>foremost</ets>, and prob. to AS. <ets>fram</ets> from, Icel.
<ets>fremja</ets>, <ets>frama</ets>, to further, <ets>framr</ets>
forward, G. <ets>fromm</ets> worthy, excellent, pious. See
<er>Foremost</er>, <er>From</er>, and cf. <er>Furnish</er>.]</ety>
<sn>1.</sn> <fld>(Arch. & Engin.)</fld> <def>To construct by fitting and
uniting the several parts of the skeleton of any structure;
specifically, in woodwork, to put together by cutting parts of one
member to fit parts of another. See <er>Dovetail</er>, <er>Halve</er>,
<pos>v. t.</pos>, <er>Miter</er>, <er>Tenon</er>, <er>Tooth</er>,
<er>Tusk</er>, <er>Scarf</er>, and <er>Splice</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To originate; to plan; to devise; to contrive; to
compose; in a bad sense, to invent or fabricate, as something
false.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>How many excellent reasonings are <qex>framed</qex> in the mind of
a man of wisdom and study in a length of years.</q> <rj><qau>I.
Watts.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To fit to something else, or for some specific end;
to adjust; to regulate; to shape; to conform.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And <qex>frame</qex> my face to all occasions.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>We may in some measure <qex>frame</qex> our minds for the
reception of happiness.</q> <rj><qau>Landor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The human mind is <qex>framed</qex> to be influenced.</q>
<rj><qau>I. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To cause; to bring about; to produce.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Fear <qex>frames</qex> disorder, and disorder wounds.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To support.</def> <mark>[Obs. & R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>That on a staff his feeble steps did <qex>frame</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To provide with a frame, as a picture.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>to manufacture false evidence against (an innocent
person), so as to make the person appear guilty of a crime. The act of
<ex>framing</ex> a person is often referred to as a
<er>frame-up</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Frame</ent><br/
<hw>Frame</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To shape; to arrange,
as the organs of speech.</def> <mark>[Obs.]</mark> <rj><au>Judg. xii.
6.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To proceed; to go.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The bauty of this sinful dame<br/
Made many princes thither <qex>frame</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frame</ent><br/
<hw>Frame</hw>, <pos>n.</pos> <sn>1.</sn> <def>Anything composed of
parts fitted and united together; a fabric; a structure; esp., the
constructional system, whether of timber or metal, that gives to a
building, vessel, etc., its model and strength; the skeleton of a
structure.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>These are thy glorious works, Parent of good,<br/
Almighty! thine this universal <qex>frame</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The bodily structure; physical constitution; make or
build of a person.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Some bloody passion shakes your very <qex>frame</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>No <qex>frames</qex> could be strong enough to endure it.</q>
<rj><qau>Prescott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A kind of open case or structure made for admitting,
inclosing, or supporting things, as that which incloses or contains a
window, door, picture, etc.; that on which anything is held or
stretched</def>; as: <sd>(a)</sd> <def>The skeleton structure which
supports the boiler and machinery of a locomotive upon its wheels.</def>
<sd>(b)</sd> <fld>(Founding)</fld> <def>A molding box or flask, which
being filled with sand serves as a mold for castings.</def> <sd>(c)</sd>
<def>The ribs and stretchers of an umbrella or other structure with a
fabric covering.</def> <sd>(d)</sd> <def>A structure of four bars,
adjustable in size, on which cloth, etc., is stretched for quilting,
embroidery, etc.</def> <sd>(e)</sd> <fld>(Hort.)</fld> <def>A glazed
portable structure for protecting young plants from frost.</def>
<sd>(f)</sd> <fld>(Print.)</fld> <def>A stand to support the type cases
for use by the compositor.</def> <sd>(f)</sd> <def>a pair of glasses
without the lenses; that part of a pair of glasses that excludes the
lenses.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>4.</sn> <fld>(Mach.)</fld> <def>A term applied, especially in
England, to certain machines built upon or within framework; <as>as, a
stocking <ex>frame</ex>; lace <ex>frame</ex>; spinning <ex>frame</ex>,
etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Form; shape; proportion; scheme; structure;
constitution; system; <as>as, a <ex>frame</ex>of
government</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>She that hath a heart of that fine <qex>frame</qex><br/
To pay this debt of love but to a brother.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Put your discourse into some <qex>frame</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Particular state or disposition, as of the mind;
humor; temper; mood; <as>as, to be always in a happy
<ex>frame</ex></as>. Same as <altname><er>frame of
mind</er></altname></def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>7.</sn> <def>Contrivance; the act of devising or scheming.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>John the bastard<br/
Whose spirits toil in <qex>frame</qex> of villainies.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>In games: <sd>(a)</sd> In pool, the triangular form
used in setting up the balls; also, the balls as set up, or the round of
playing required to pocket them all; <as>as, to play six <ex>frames</ex>
in a game of 50 points</as>. <sd>(b)</sd> In bowling, as in tenpins, one
of the several innings forming a game.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><cs><mcol><col><b>Balloon frame</b></col>, <col><b>Cant
frames</b></col></mcol>, <cd>etc. See under <er>Balloon</er>,
<er>Cant</er>, etc.</cd> -- <mcol><col><b>Frame building</b></col>
<it>or</it> <col><b>Frame house</b></col>, <cd>a building of which the
form and support is made of framed timbers.</cd> <mark>[U.S.]</mark> --
<col><b>Frame level</b></col></mcol>, <cd>a mason's level.</cd> --
<col><b>Frame saw</b></col>, <cd>a thin saw stretched in a frame to give
it rigidity.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>framed</ent><br/
<hw>framed</hw> <pos>adj.</pos> <def>provided with a frame; <as>as,
there were <ex>framed</ex> snapshots of family and friends on her
desk</as>. Opposite of <ant>unframed</ant>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Frame of mind</ent><br/
<hw>Frame of mind</hw> <pr>(?)</pr>, <pos>n.</pos> <def>mood; mental
attitude; mental disposition; same as <er>frame{6}</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Frame of reference</ent><br/
<hw>Frame of reference</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>an arbitrary set of spatial coordinates used to describe the
position or motion of objects. The coordinates may be fixed or moving;
<as>as, a rotating <ex>frame of reference</ex></as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>a set of assumptions or conditions that are used to
discuss or understand something; <as>as, a religious <ex>frame of
reference</ex></as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Framer</ent><br/
<hw>Fram"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who frames;
<as>as, the <ex>framer</ex> of a building; the <ex>framers</ex> of the
Constitution.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>frameshift</ent><br/
<hw>frame"shift</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Genetics)</fld>
<def>of, pertaining to, or causing a type of mutation consisting of the
insertion or deletion of one or more nucleotides in the nucleic acid
structure of a gene, when the number of base pairs inserted or deleted
is not a multiple of three. If the addition or deletion occurs in
multiples of three, the unaffected nucleotides in the genome remain in
the proper order ("frame") to be correctly translated into protein; in
such cases of insertions or deletions <b>not</b> causing a frame shift,
a functional though altered protein may be produced by the organism.
<ex>Frameshift</ex> mutations cause more profound changes in the
composition of the protein resulting from translation of the mutated
gene.</def><br/
[<source>PJC</source>]</p>

<p><ent>Frame-up</ent><br/
<hw>Frame"-up`</hw>, <pos>n.</pos> <def>A conspiracy or plot for a
malicious or evil purpose;</def> <specif>especially</specif>, <def>an
act that incriminates a person on false evidence.</def>
<mark>[Slang]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Framework</ent><br/
<hw>Frame"work`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
work of framing, or the completed work; the frame or constructional part
of anything; <as>as, the <ex>framework</ex> of society</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A staunch and solid piece of <qex>framework</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Work done in, or by means of, a frame or
loom.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Framing</ent><br/
<hw>Fram"ing</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act, process, or
style of putting together a frame, or of constructing anything; a frame;
that which frames.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Arch. & Engin.)</fld> <def>A framework, or a sy<?/
of frames.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Framing chisel</b></col> <fld>(Carp.)</fld>, <cd>a heavy
chisel with a socket shank for making mortises.</cd></cs></p>

<p><ent>Frampoid</ent><br/
<ent>Frampel</ent><br/
<mhw>{ <hw>Fram"pel</hw> <pr>(?)</pr>, <hw>Fram"poid</hw> <pr>(?)</pr>
}</mhw>, <pos>a.</pos> <ety>[Also written <ets>frampul</ets>,
<ets>frampled</ets>, <ets>framfold</ets>.]</ety> <ety>[Cf. W.
<ets>fframfol</ets> passionate, <ets>ffrom</ets> angry, fretting; or
perh. akin to E. <ets>frump</ets>.]</ety> <def>Peevish; cross;
vexatious; quarrelsome.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Is Pompey grown so malapert, so <qex>frampel</qex>?</q>
<rj><qau>Beau. & Fl.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Franc</ent><br/
<hw>Franc</hw> <pr>(fr<acr/<nsm/k)</pr>, <pos>n.</pos> <ety>[F., fr.
<ets>franc</ets> a Franc. See <er>Frank</er>, <pos>a.</pos>]</ety>
<def>A silver coin of France, and since 1795 the unit of the French
monetary system. It has been adopted by Belgium and Swizerland. In 1913
it was equivalent to about nineteen cents American, or ten pence
British, and is divided into 100 centimes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Franchise</ent><br/
<hw>Fran"chise</hw> <pr>(? <or/ ?; 277)</pr>, <pos>n.</pos> <ety>[F.,
fr. <ets>franc</ets>, fem. <ets>franche</ets>, free. See <er>Frank</er>,
<pos>a.</pos>]</ety> <sn>1.</sn> <def>Exemption from constraint or
oppression; freedom; liberty.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(LAw)</fld> <def>A particular privilege conferred by
grant from a sovereign or a government, and vested in individuals; an
immunity or exemption from ordinary jurisdiction; a constitutional or
statutory right or privilege, esp. the right to vote.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Election by universal suffrage, as modified by the Constitution,
is the one crowning <qex>franchise</qex> of the American people.</q>
<rj><qau>W. H. Seward.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The district or jurisdiction to which a particular
privilege extends; the limits of an immunity; hence, an asylum or
sanctuary.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Churches and mobasteries in Spain are <qex>franchises</qex> for
criminals.</q> <rj><qau>London Encyc.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Magnanimity; generosity; liberality; frankness;
nobility.</def> <ldquo/<xex>Franchise</xex> in woman.<rdquo/
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Elective franchise</b></col>, <cd>the privilege or right
of voting in an election of public officers.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Franchise</ent><br/
<hw>Fran"chise</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Franchised</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Franchising</conjf>.]</vmorph> <ety>[Cf. OF. <ets>franchir</ets>
to free, F., to cross.]</ety> <def>To make free; to enfranchise; to give
liberty to.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Franchisement</ent><br/
<hw>Fran"chise*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. OF.
<ets>franchissement</ets>.]</ety> <def>Release; deliverance;
freedom.</def> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Francic</ent><br/
<hw>Fran"cic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See <er>Frank</er>,
<pos>a.</pos>]</ety> <def>Pertaining to the Franks, or their language;
Frankish.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Franciscan</ent><br/
<hw>Fran*cis"can</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[LL.
<ets>Franciscus</ets> Francis: cf. F. <ets>franciscain</ets>.]</ety>
<fld>(R. C. Ch.)</fld> <def>Belonging to the Order of St. Francis of the
Franciscans.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Franciscan Brothers</b></col>, <cd>pious laymen who
devote themselves to useful works, such as manual labor schools, and
other educational institutions; -- called also <altname>Brothers of the
Third Order of St. Francis</altname>.</cd> -- <col><b>Franciscan
Nuns</b></col>, <cd>nuns who follow the rule of St. Francis, esp. those
of the Second Order of St. Francis, -- called also <altname>Poor
Clares</altname> or <altname>Minoresses</altname>.</cd> --
<col><b>Franciscan Tertiaries</b></col>, <cd>the Third Order of St.
Francis.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Franciscan</ent><br/
<hw>Fran*cis"can</hw>, <pos>n.</pos> <fld>(R.C.Ch.)</fld> <def>A monk or
friar of the Order of St. Francis, a large and zealous order of
mendicant monks founded in 1209 by St. Francis of Assisi. They are
called also <altname>Friars Minor</altname>; and in England,
<altname>Gray Friars</altname>, because they wear a gray
habit.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Francolin</ent><br/
<hw>Fran"co*lin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.; cf. It.
<ets>francolino</ets>, Sp. <ets>francolin</ets>.]</ety>
<fld>(Zool.)</fld> <def>A spurred partidge of the genus
<gen>Francolinus</gen> and allied genera, of Asia and Africa. The common
species (<spn>F. vulgaris</spn>) was formerly common in southern Europe,
but is now nearly restricted to Asia.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Francolite</ent><br/
<hw>Fran"co*lite</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Min.)</fld>
<def>A variety of apatite from Wheal <etsep>Franco</etsep> in
Devonshire.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Francophile</ent><br/
<ent>Francophil</ent><br/
<mhw><hw>Francophil</hw>, <hw>Francophile</hw></mhw> <pos>prop. n.</pos>
<def>An admirer of France and everything French.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Francophobe</ent><br/
<hw>Francophobe</hw> <pos>prop. n.</pos> <def>a person who hates or
fears France, French culture, or the French people.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Francophonic</ent><br/
<ent>Francophone</ent><br/
<mhw><hw>Francophone</hw>, <hw>Francophonic</hw></mhw> <pos>prop.
a.</pos> <def>Able to communicate in the French language; -- used
especially of those whose native language is French.</def><br/
<syn><b>Syn. --</b> French-speaking.</syn><br/
[<source>PJC</source>]</p>

<p><ent>franc-tireur</ent><br/
<hw>franc-tireur</hw> <pos>n.</pos> <def>a sharpshooter (in the French
army).</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Frangent</ent><br/
<hw>Fran"gent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>frangens</ets>, p. pr. of <ets>frangere</ets>. See
<er>Fraction</er>.]</ety> <def>Causing fracture; breaking.</def>
<mark>[R.]</mark> <rj><au>H. Walpole.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frangibility</ent><br/
<hw>Fran`gi*bil"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>frangibilit<eacute/</ets>.]</ety> <def>The state or quality of
being frangible.</def> <rj><au>Fox.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frangible</ent><br/
<hw>Fran"gi*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>frangible</ets>.]</ety> <def>Capable of being broken; brittle;
fragile; easily broken.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frangipane</ent><br/
\'d8<hw>Fran"gi*pane</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>frangipane</ets>; supposed to be called so from the inventor, the
Marquis <etsep>Frangipani</etsep>, major general under Louis XIV.]</ety>
<sn>1.</sn> <def>A perfume of jasmine; frangipani.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A species of pastry, containing cream and
almonds.</def></p>

<p><ent>Frangipanni</ent><br/
<ent>Frangipani</ent><br/
<mhw>{ <hw>Fran`gi*pan"i</hw> <pr>(?)</pr>, <hw>Fran`gi*pan"ni</hw>
<pr>(?)</pr> }</mhw>, <pos>n.</pos> <ety>[Another spelling of
<ets>frangipane</ets>.]</ety> <def>A perfume derived from, or imitating
the odor of, the flower of the red jasmine, a West Indian tree of the
genus <gen>Plumeria</gen>.</def></p>

<p><ent>Frangulinic</ent><br/
<ent>Frangulic</ent><br/
<mhw>{ <hw>Fran*gu"lic</hw> <pr>(?)</pr>, <hw>Fran`gu*lin"ic</hw>
<pr>(?)</pr> }</mhw>, <pos>a.</pos> <fld>(Chem.)</fld> <def>Pertaining
to, or drived from, frangulin, or a species (<spn>Rhamnus
Frangula</spn>) of the buckthorn.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Frangulinic acid</b></col> <fld>(Chem.)</fld>, <cd>a
yellow crystalline substance, resembling alizarin, and obtained by the
decomposition of frangulin.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frangulin</ent><br/
<hw>Fran"gu*lin</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>A yellow crystalline dyestuff, regarded as a glucoside, extracted
from a species (<spn>Rhamnus Frangula</spn>) of the buckthorn; -- called
also <altname>rhamnoxanthin</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Franion</ent><br/
<hw>Fran"ion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Perh. from F.
<ets>fain<eacute/ant</ets> an idler.]</ety> <def>A paramour; a loose
woman; also, a gay, idle fellow.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frank</ent><br/
<hw>Frank</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>franc</ets>.]</ety> <def>A pigsty.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frank</ent><br/
<hw>Frank</hw>, <pos>v. t.</pos> <def>To shut up in a frank or sty; to
pen up; hence, to cram; to fatten.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frank</ent><br/
<hw>Frank</hw>, <pos>n.</pos> <fld>(Zool.)</fld> <def>The common heron;
-- so called from its note.</def> <mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 593 --></p>

<p><ent>frank</ent><br/
<hw>frank</hw> <pr>(fr<acr/<nsm/k)</pr>, <pos>a.</pos>
<amorph>[<pos>Compar.</pos> <adjf>franker</adjf>
<pr>(fr<acr/<nsm/k"<etil/r)</pr>; <pos>superl.</pos>
<adjf>frankest</adjf>.]</amorph> <ety>[F. <ets>franc</ets> free, frank,
L. <ets>Francus</ets> a Frank, fr. OHG. <ets>Franko</ets> the name of a
Germanic people on the Rhine, who afterward founded the French monarchy;
cf. AS. <ets>franca</ets> javelin, Icel. <ets>frakka</ets>. Cf.
<er>Franc</er>, <er>French</er>, <pos>a.</pos>, <er>Franchise</er>,
<pos>n.</pos>]</ety> <sn>1.</sn> <def>Unbounded by restrictions,
limitations, etc.; free.</def> <mark>[R.]</mark> <ldquo/It is of
<xex>frank</xex> gift.<rdquo/ <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Free in uttering one's real sentiments; not
reserved; using no disguise; candid; ingenuous; <as>as, a <ex>frank</ex>
nature, conversation, manner, etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Liberal; generous; profuse.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Frank</qex> of civilities that cost them nothing.</q>
<rj><qau>L'Estrange.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Unrestrained; loose; licentious; -- used in a bad
sense.</def> <rj><au>Spenser.</au></rj></p>

<p><syn><b>Syn.</b> -- Ingenuous; candid; artless; plain; open;
unreserved; undisguised; sincere. See <er>Candid</er>,
<er>Ingenuous</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>frank</ent><br/
<hw>frank</hw> <pr>(fr<acr/<nsm/k)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>franked</conjf>
<pr>(fr<acr/<nsm/kt)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>franking</conjf>.]</vmorph> <sn>1.</sn> <def>To send by public
conveyance free of expense.</def> <rj><au>Dickens.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To extempt from charge for postage, as a letter,
package, or packet, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frank</ent><br/
<hw>Frank</hw>, <pos>n.</pos> <ety>[See <er>Frank</er>,
<pos>a.</pos>]</ety> <def>The privilege of sending letters or other mail
matter, free of postage, or without charge; also, the sign, mark, or
signature denoting that a letter or other mail matter is to go free of
postage. Called also the <altname><ecol><b>franking
privilege</b></ecol></altname>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><q>I have said so much, that, if I had not a <qex>frank</qex>, I must
burn my letter and begin again.</q> <rj><qau>Cowper.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frank</ent><br/
<hw>Frank</hw>, <pos>n.</pos> <ety>[Cf. F. <ets>franc</ets>. See
<er>Frank</er>, <pos>a.</pos>]</ety> <sn>1.</sn> <fld>(Ethnol.)</fld>
<def>A member of one of the German tribes that in the fifth century
overran and conquered Gaul, and established the kingdom of
France.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A native or inhabitant of Western Europe; a
European; -- a term used in the Levant.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A French coin. See <er>Franc</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frankalmoigne</ent><br/
<hw>Frank`al*moigne"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>franc</ets> free + Norm. F. <ets>almoigne</ets> alma, for
<ets>almosne</ets>, F. <ets>aum<ocir/ne</ets>. See <er>Frank</er>,
<pos>a.</pos>, and <er>Almoner</er>.]</ety> <fld>(Eng. Law)</fld> <def>A
tenure by which a religious corporation holds lands given to them and
their successors forever, usually on condition of praying for the soul
of the donor and his heirs; -- called also <altname>tenure by free
alms</altname>.</def> <rj><au>Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frank-chase</ent><br/
<hw>Frank"-chase`</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Frank</ets> free + <ets>chase</ets>.]</ety> <fld>(Eng.
Law)</fld> <def>The liberty or franchise of having a chase; free
chase.</def> <rj><au>Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frank-fee</ent><br/
<hw>Frank"-fee`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Frank</ets>
free + <ets>fee</ets>.]</ety> <fld>(Eng. Law)</fld> <def>A species of
tenure in fee simple, being the opposite of ancient demesne, or
copyhold.</def> <rj><au>Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frankfort black</ent><br/
<hw>Frank"fort black`</hw> <pr>(?)</pr>. <def>A black pigment used in
copperplate printing, prepared by burning vine twigs, the lees of wine,
etc.</def> <rj><au>McElrath.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>frankfurter</ent><br/
<hw>frank"fur*ter</hw> <pr>(?)</pr>. <def>A small cooked sausage of beef
or beef and pork, usually 5 to 6 inches, sometimes as long as 12 inches
in length; called also <altname>frankforter</altname>,
<altname>frankfort</altname>, <altname>frankfurt</altname>. It is
commonly eaten on a roll, called a hot dog bun.</def><br/
<syn><b>Syn. --</b> wiener, hot dog{1}.</syn><br/
[<source>PJC</source>]</p>

<p><ent>Frankincense</ent><br/
<hw>Frank"in*cense</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>franc</ets> free, pure + <ets>encens</ets> incense.]</ety> <def>A
fragrant, aromatic resin, or gum resin, burned as an incense in
religious rites or for medicinal fumigation. The best kinds now come
from East Indian trees, of the genus <gen>Boswellia</gen>; a commoner
sort, from the Norway spruce (<spn>Abies excelsa</spn>) and other
coniferous trees. The frankincense of the ancient Jews is still
unidentified.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Franking</ent><br/
<hw>Frank"ing</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Carp.)</fld> <def>A
method of forming a joint at the intersection of window-sash bars, by
cutting away only enough wood to show a miter.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frankish</ent><br/
<hw>Frank"ish</hw>, <pos>a.</pos> <def>Like, or pertaining to, the
Franks.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frank-law</ent><br/
<hw>Frank"-law`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Frank</ets>
free + <ets>law</ets>.]</ety> <fld>(Eng. Law)</fld> <def>The liberty of
being sworn in courts, as a juror or witness; one of the ancient
privileges of a freeman; free and common law; -- an obsolete expression
signifying substantially the same as the American expression
<altname>civil rights</altname>.</def> <rj><au>Abbot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Franklin</ent><br/
<hw>Frank"lin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>frankelein</ets>; cf. LL. <ets>franchilanus</ets>. See
<er>Frank</er>, <pos>a.</pos>]</ety> <def>An English freeholder, or
substantial householder.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>franklin</qex>, a small landholder of those days.</q>
<rj><qau>Sir J. Stephen.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Franklinic</ent><br/
<hw>Frank*lin"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining
to <person>Benjamin Franklin</person>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Franklinic electricity</b></col>, <cd>electricity
produced by friction; called also <altname>static
electricity</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Franklinite</ent><br/
<hw>Frank"lin*ite</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Min.)</fld>
<def>A kind of mineral of the spinel group.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Franklin stove</ent><br/
<hw>Frank"lin stove`</hw> <pr>(?)</pr>. <def>A kind of open stove
introduced by <person>Benjamin <ets>Franklin</ets></person>, the
peculiar feature of which was that a current of heated air was directly
supplied to the room from an air box; -- now applied to other varieties
of open stoves.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frankly</ent><br/
<hw>Frank"ly</hw>, <pos>adv.</pos> <def>In a frank manner;
freely.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Very <qex>frankly</qex> he confessed his treasons.</q>
<rj><qau>Shak.</qau></rj></p>

<p><syn><b>Syn.</b> -- Openly; ingenuously; plainly; unreservedly;
undisguisedly; sincerely; candidly; artlessly; freely; readily;
unhesitatingly; liberally; willingly.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frank-marriage</ent><br/
<hw>Frank"-mar"riage</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Frank</ets> free + <ets>marriage</ets>.]</ety> <fld>(Eng.
Law)</fld> <def>A certain tenure in tail special; an estate of
inheritance given to a man his wife (the wife being of the blood of the
donor), and descendible to the heirs of their two bodies begotten.</def>
<mark>[Obs.]</mark> <rj><au>Blackstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frankness</ent><br/
<hw>Frank"ness</hw>, <pos>n.</pos> <def>The quality of being frank;
candor; openess; ingenuousness; fairness; liberality.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frankpledge</ent><br/
<hw>Frank"pledge`</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Frank</ets> free + <ets>pledge</ets>.]</ety> <fld>(O. Eng.
Law)</fld> <sd>(a)</sd> <def>A pledge or surety for the good behavior of
freemen, -- each freeman who was a member of an ancient decennary,
tithing, or friborg, in England, being a pledge for the good conduct of
the others, for the preservation of the public peace; a free
surety.</def> <sd>(b)</sd> <def>The tithing itself.</def>
<rj><au>Bouvier.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The servants of the crown were not, as now, bound in
<qex>frankpledge</qex> for each other.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frantic</ent><br/
<hw>Fran"tic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OE.
<ets>frentik</ets>, <ets>frenetik</ets>, F. <ets>frentique</ets>, L.
<ets>phreneticus</ets>, from Gr. <?/. See <er>Frenzy</er>, and cf.
<er>Frenetic</er>, <er>Phrenetic</er>.]</ety> <def>Mad; raving; furious;
violent; wild and disorderly; distracted.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Die, <qex>frantic</qex> wretch, for this accursed deed!</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Torrents of <qex>frantic</qex> abuse.</q>
<rj><qau>Macaulay.</qau></rj></p>

<p>-- <wordforms><wf>Fran"tic*al*ly</wf> <pr>(#)</pr>, <pos>adv.</pos>
-- <wf>Fran"tic*ly</wf> <pr>(#)</pr>, <pos>adv.</pos></wordforms>
<rj><au>Shak.</au></rj></p>

<p>-- <wordforms><wf>Fran"tic*ness</wf>, <pos>n.</pos></wordforms>
<rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frap</ent><br/
<hw>Frap</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Frapped</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Frapping</conjf>.]</vmorph> <ety>[Cf. F. <ets>frapper</ets> to
strike, to seize ropes. Cf. <er>Affrap</er>.]</ety> <sn>1.</sn>
<fld>(Naut.)</fld> <def>To draw together; to bind with a view to secure
and strengthen, as a vessel by passing cables around it; to tighten; as
a tackle by drawing the lines together.</def>
<rj><au>Tottem.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To brace by drawing together, as the cords of a
drum.</def> <rj><au>Knoght.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frape</ent><br/
<hw>Frape</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. <ets>frap</ets>,
and Prov. E. <ets>frape</ets> to scold.]</ety> <def>A crowd, a
rabble.</def> <mark>[Obs.]</mark> <rj><au>ares.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frapler</ent><br/
<hw>Frap"ler</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A blusterer; a
rowdy.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Unpolished, a <qex>frapler</qex>, and base.</q> <rj><qau>B.
Jonson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frappe</ent><br/
<mhw>\'d8<hw>Frap`p<eacute/"</hw> or <hw>Frappe</hw></mhw>
<pr>(fr<adot/`p<amac/")</pr>, <pos>a.</pos> <ety>[F., p.p. of
<ets>frapper</ets> to strike, to chill.]</ety> <def>Iced; frozen;
artificially cooled; <as>as, wine <ex>frapp<eacute/</ex></as>.</def> --
<def2><pr>(fr<adot/`p<amac/" <it>or</it> fr<acr/p)</pr><pos>n.</pos>
<def>A frapp<eacute/ mixture or beverage, as a water ice, variously
flavored, frozen soft, and served in glasses; also, a milk
shake.</def></def2><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Frapping</ent><br/
<hw>Frap"ping</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<er>Frap</er>.]</ety> <fld>(Naut.)</fld> <def>A lashing binding a thing
tightly or binding things together.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Frasera</ent><br/
<hw>Frasera</hw> <pos>n.</pos> <def>A genus of North American herbs:
columbo; it includes some species sometimes placed in the genus
<gen>Swertia</gen>.</def><br/
<syn><b>Syn. --</b> genus <gen>Frasera</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>frat</ent><br/
<hw>frat</hw> <pos>n.</pos> <def>a social club for male college
undergraduates; a shortened form of <er>fraternity</er>.</def><br/
<syn><b>Syn. --</b> fraternity.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>frat house</ent><br/
<hw>frat house</hw> <pos>n.</pos> <def>a house used by a chapter of a
fraternity at a college.</def><br/
<syn><b>Syn. --</b> fraternity house; chapter house.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Frater</ent><br/
\'d8<hw>Fra"ter</hw>, <pos>n.</pos> <ety>[L., a brother.]</ety>
<fld>(Eccl.)</fld> <def>A monk; also, a frater house.</def>
<mark>[R.]</mark> <rj><au>Shipley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Frater house</b></col>, <cd>an apartament in a convent
used as an eating room; a refectory; -- called also a
<altname>fratery</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fratercula</ent><br/
<hw>Fratercula</hw> <pos>n.</pos> <def>a genus of sea birds, one of the
genera of puffins.</def><br/
<syn><b>Syn. --</b> genus <gen>Fratercula</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fraternal</ent><br/
<hw>Fra*ter"nal</hw> <pr>(?)</pr>, <pos>a.</pos><ety>[F.
<ets>fraternel</ets>, LL. <ets>fraternalis</ets>, fr. L.
<ets>fraternus</ets>, fr. <ets>frater</ets> brother. See
<er>Brother</er>.]</ety> <def>Of, pertaining to, or involving, brethren;
becoming to brothers; brotherly; <as>as, <ex>fraternal</ex> affection; a
<ex>fraternal</ex> embrace.</as></def> --
<wordforms><wf>Fra*ter"nal*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><q>An abhorred, a cursed, a <qex>fraternal</qex> war.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Fraternal</qex> love and friendship.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fraternate</ent><br/
<hw>Fra*ter"nate</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To fraternize;
to hold fellowship.</def> <rj><au>Jefferson.</au></rj></p>

<p><ent>Fraternism</ent><br/
<ent>Fraternation</ent><br/
<mhw>{ <hw>Fra`ter*na"tion</hw> <pr>(?)</pr>, <hw>Fra"ter*nism</hw>
<pr>(?)</pr> }</mhw>, <pos>n.</pos> <def>Fraternization.</def>
<mark>[R.]</mark> <rj><au>Jefferson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fraternity</ent><br/
<hw>Fra*ter"ni*ty</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Fraternities</plw> <pr>(#)</pr>.</plu> <ety>[F.
<ets>fraternit<eacute/</ets>, L. <ets>fraternitas</ets>.]</ety>
<sn>1.</sn> <def>The state or quality of being fraternal or brotherly;
brotherhood.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A body of men associated for their common interest,
business, or pleasure; a company; a brotherhood; a society; in the Roman
Catholic Church, an association for special religious purposes, for
relieving the sick and destitute, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Men of the same class, profession, occupation,
character, or tastes.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With what terms of respect knaves and sots will speak of their own
<qex>fraternity</qex>!</q> <rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A social club for male college undergraduates. They
often have secret initiation rites, and are named by the use of two or
three Greek letters. The corresponding association for women students is
called a <contr>sorority</contr>.</def><br/
<syn><b>Syn. --</b> frat.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Fraternization</ent><br/
<hw>Fra`ter*ni*za"tion</hw> <pr>(? <or/ ?)</pr>, <pos>n.</pos> <def>The
act of fraternizing or uniting as brothers.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I hope that no French <qex>fraternization</qex> . . . could so
change the hearts of Englishmen.</q> <rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fraternize</ent><br/
<hw>Fra"ter*nize</hw> <pr>(? <or/ ?; 277)</pr>, <pos>v. i.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Fraternized</conjf>
<pr>(#)</pr>; <pos>p. pr. & vb. n.</pos>. <conjf>Fraternizing</conjf>
<pr>(#)</pr>.]</vmorph> <ety>[Cf. F. <ets>fraterniser</ets>.]</ety>
<def>To associate or hold fellowship as brothers, or as men of like
occupation or character; to have brotherly feelings.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fraternize</ent><br/
<hw>Fra"ter*nize</hw>, <pos>v. t.</pos> <def>To bring into fellowship or
brotherly sympathy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Correspondence for <qex>fraternizing</qex> the two nations.</q>
<rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fraternizer</ent><br/
<hw>Frat"er*ni`zer</hw> <pr>(?; 277)</pr>, <pos>n.</pos> <def>One who
fraternizes.</def> <rj><au>Burke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fratery</ent><br/
<hw>Fra"ter*y</hw> <pr>(? <or/ ?)</pr>, <pos>n.</pos> <ety>[L.
<ets>frater</ets> brother: cf. It. <ets>frateria</ets> a brotherhood of
monks. See <er>Friar</er>.]</ety> <def>A frater house. See under
<er>Frater</er>.</def></p>

<p><-- Frat house. Short for fraternity house, a building owned by a
college fraternity in which members may live. --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fratrage</ent><br/
<hw>Fra"trage</hw> <pr>(? <or/ ?; 48)</pr>, <pos>n.</pos> <ety>[L.
<ets>frater</ets> a brother.]</ety> <fld>(Law)</fld> <def>A sharing
among brothers, or brothers' kin.</def> <mark>[Obs.]</mark>
<rj><au>Crabb.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fratricelli</ent><br/
\'d8<hw>Fra`tri*cel"li</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[It.
<ets>fraticelli</ets>, lit., little brothers, dim. fr. <ets>frate</ets>
brother, L. <ets>frater</ets>.]</ety> <fld>(Eccl. Hist.)</fld>
<sd>(a)</sd> <def>The name which St. Francis of Assisi gave to his
followers, early in the 13th century.</def> <sd>(b)</sd> <def>A sect
which seceded from the Franciscan Order, chiefly in Italy and Sicily, in
1294, repudiating the pope as an apostate, maintaining the duty of
celibacy and poverty, and discountenancing oaths. Called also
<altname>Fratricellians</altname> and
<altname>Fraticelli</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fratricidal</ent><br/
<hw>Frat"ri*ci`dal</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or
pertaining to fratricide; of the nature of fratricide.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fratricide</ent><br/
<hw>Frat"ri*cide</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>fratricidium</ets> a brother's murder, fr. <ets>fratricida</ets> a
brother's murderer; <ets>frater</ets>, <ets>fratris</ets>, brother +
<ets>caedere</ets> to kill: cf. F. <ets>fratricide</ets>.]</ety>
<sn>1.</sn> <def>The act of one who murders or kills his own
brother.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <ety>[L. <ets>fratricida</ets>: cf. F.
<ets>fratricide</ets>.]</ety> <def>One who murders or kills his own
brother.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frau</ent><br/
\'d8<hw>Frau</hw> <pr>(frou)</pr>, <pos>n.</pos>; <plu>pl.
<plw>Frauen</plw> <pr>(frou"<eit/n)</pr></plu>. <ety>[G. Cf. 1st
<er>Frow</er>.]</ety> <def>In Germany, a woman; a married woman; a wife;
-- as a title, equivalent to <xlati>Mrs.</xlati>,
<xlati>Madam</xlati>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Fraud</ent><br/
<hw>Fraud</hw> <pr>(fr<add/d)</pr>, <pos>n.</pos> <ety>[F.
<ets>fraude</ets>, L. <ets>fraus</ets>, <ets>fraudis</ets>; prob. akin
to Skr. <ets>dh<umac/rv</ets> to injure, <ets>dhv<rsdot/</ets> to cause
to fall, and E. <ets>dull</ets>.]</ety> <sn>1.</sn> <def>Deception
deliberately practiced with a view to gaining an unlawful or unfair
advantage; artifice by which the right or interest of another is
injured; injurious stratagem; deceit; trick.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If success a lover's toil attends,<br/
Few ask, if <qex>fraud</qex> or force attained his ends.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>An intentional perversion of truth
for the purpose of obtaining some valuable thing or promise from
another.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A trap or snare.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>To draw the proud King Ahab into <qex>fraud</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Constructive fraud</b></col> <fld>(Law)</fld>, <cd>an
act, statement, or omission which operates as a fraud, although perhaps
not intended to be such.</cd> <au>Mozley & W.</au> -- <col><b>Pious
fraud</b></col> <fld>(Ch. Hist.)</fld>, <cd>a fraud contrived and
executed to benefit the church or accomplish some good end, upon the
theory that the end justified the means.</cd> -- <col><b>Statute of
frauds</b></col> <fld>(Law)</fld>, <cd>an English statute (1676), the
principle of which is incorporated in the legislation of all the States
of this country, by which writing with specific solemnities (varying in
the several statutes) is required to give efficacy to certain
dispositions of property.</cd> <rj><au>Wharton.</au></rj></cs></p>

<p><syn><b>Syn.</b> -- Deception; deceit; guile; craft; wile; sham;
strife; circumvention; stratagem; trick; imposition; cheat. See
<er>Deception</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fraudful</ent><br/
<hw>Fraud"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Full of fraud,
deceit, or treachery; trickish; treacherous; fraudulent; -- applied to
persons or things.</def> <rj><au>I. Taylor.</au></rj></p>

<p>-- <wordforms><wf>Fraud"ful*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fraudless</ent><br/
<hw>Fraud"less</hw>, <pos>a.</pos> <def>Free from fraud.</def> --
<wordforms><wf>Fraud"less*ly</wf>, <pos>adv.</pos> --
<wf>Fraud"less*ness</wf>, <pos>n.</pos></wordforms></p>

<p><ent>Fraudulency</ent><br/
<ent>Fraudulence</ent><br/
<mhw>{ <hw>Fraud"u*lence</hw> <pr>(?; 135)</pr>, <hw>Fraud"u*len*cy</hw>
<pr>(?)</pr> }</mhw>, <pos>n.</pos> <ety>[L.
<ets>fraudulentia</ets>.]</ety> <def>The quality of being fraudulent;
deliberate deceit; trickishness.</def> <rj><au>Hooker.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fraudulent</ent><br/
<hw>Fraud"u*lent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>fraudulentus</ets>, fr. <ets>fraus</ets>, <ets>fraudis</ets>,
fraud: cf. F. <ets>fraudulent</ets>.]</ety> <sn>1.</sn> <def>Using
fraud; tricky; deceitful; dishonest.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Characterized by, founded on, or proceeding from,
fraud; <as>as, a <ex>fraudulent</ex> bargain</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He, with serpent tongue, . . . <br/
His <qex>fraudulent</qex> temptation thus began.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Obtained or performed by artifice; <as>as,
<ex>fraudulent</ex> conquest</as>.</def> <rj><au>Milton.</au></rj></p>

<p><syn><b>Syn.</b> -- Deceitful; fraudful; guileful; crafty; wily;
cunning; subtle; deceiving; cheating; deceptive; insidious; treacherous;
dishonest; designing; unfair.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fraudulently</ent><br/
<hw>Fraud"u*lent*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a
fraudulent manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fraught</ent><br/
<hw>Fraught</hw> <pr>(fr<add/t)</pr>, <pos>n.</pos>
<ety>[OE.<ets>fraight</ets>, <ets>fraght</ets>; akin to Dan.
<ets>fragt</ets>, Sw. <ets>frakt</ets>, D. <ets>vracht</ets>, G.
<ets>fracht</ets>, cf. OHG. <ets>fr<emac/ht</ets> merit, reward; perh.
from a pref. corresponding to E. <ets>for</ets> + The root of E.
<ets>own</ets>. Cf. <er>Freight</er>.]</ety> <def>A freight; a
cargo.</def> <mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fraught</ent><br/
<hw>Fraught</hw>, <pos>a.</pos> <def>Freighted; laden; filled; stored;
charged.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A vessel of our country richly <qex>fraught</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A discourse <qex>fraught</qex> with all the commending excellences
of speech.</q> <rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Enterprises <qex>fraught</qex> with world-wide benefits.</q>
<rj><qau>I. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fraught</ent><br/
<hw>Fraught</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Fraughted</conjf> or <conjf>Fraught</conjf>; <pos>p. pr. & vb.
n.</pos> <conjf>Fraughting</conjf>.]</vmorph> <ety>[Akin to Dan.
<ets>fragte</ets>, Sw. <ets>frakta</ets>, D. <ets>bevrachten</ets>, G.
<ets>frachten</ets>, cf. OHG. <ets>fr<emac/ht<omac/n</ets> to deserve.
See <er>Fraught</er>, <pos>n.</pos>]</ety> <def>To freight; to load; to
burden; to fill; to crowd.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Upon the tumbling billows <qex>fraughted</qex> ride<br/
The armed ships.</q> <rj><qau>Fairfax.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fraughtage</ent><br/
<hw>Fraught"age</hw> <pr>(?; 48)</pr>, <pos>n.</pos> <def>Freight;
loading; cargo.</def> <mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fraughting</ent><br/
<hw>Fraught"ing</hw>, <pos>a.</pos> <def>Constituting the freight or
cargo.</def> <mark>[Obs.]</mark> <ldquo/The <xex>fraughting</xex> souls
within her.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fraulein</ent><br/
\'d8<hw>Fr<aum/u"lein</hw> <pr>(froi"l<imac/n)</pr>, <pos>n. sing. &
pl.</pos> <ety>[G., dim. of <ets>frau</ets> woman. See
<er>Frau</er>.]</ety> <def>In Germany, a young lady; an unmarried woman;
-- as a title, equivalent to <xlati>Miss</xlati>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Fraunhofer lines</ent><br/
<hw>Fraun"ho*fer lines`</hw> <pr>(?)</pr> <pos>prop. n. pl.</pos>.
<fld>(Physics.)</fld> <def>The lines of the spectrum; especially and
properly, the dark lines of the solar spectrum, so called because first
accurately observed and interpreted by
<person><etsep>Fraunhofer</etsep></person>, a German
physicist.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>fraxin</ent><br/
<hw>frax"in</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<er>Fraxinus</er>.]</ety> <fld>(Chem.)</fld> <def>A colorless
crystalline substance (<chform>C16H18O10</chform>) found in the bark of
the ash (<gen>Fraxinus</gen>), and along with esculin in the bark of the
horse-chestnut. It is structurally a derivative of a coumarin glucoside.
It shows a delicate blue-green fluorescence in alkaline solutions; --
called also <altname>paviin</altname> and
<altname>fraxoside</altname>.</def> <au>MI-11</au>br/ <syn><b>Syn. --
</b>
<chname>8-(<beta/-D-Glucopyranosyloxy)-7-hydroxy-6-methoxy-2H-1-benzopyran-2-one</chname>;
also,
<chname>7,8-dihydroxy-6-methoxy-coumarin-8-<beta/-D-glucoside</chname>;
<chname>fraxetin-8-glucoside</chname>.</syn><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Fraxinus</ent><br/
\'d8<hw>Frax"i*nus</hw> <pr>(?)</pr>, <pos>prop. n.</pos> <ety>[L., the
ash tree.]</ety> <fld>(Bot.)</fld> <def>A genus of deciduous forest
trees, found in the north temperate zone, and including the true ash
trees.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <spn>Fraxinus excelsior</spn> is the European ash;
<spn>Fraxinus Americana</spn>, the white ash; <spn>Fraxinus
sambucifolia</spn>, the black ash or water ash.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>fray</ent><br/
<hw>fray</hw> <pr>(fr<amac/)</pr>, <pos>n.</pos> <ety>[Abbreviated from
<ets>affray</ets>.]</ety> <def>An angry quarrel; an affray; contest;
combat; broil.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><q>Who began this bloody <qex>fray</qex>?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fray</ent><br/
<hw>Fray</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Frayed</conjf> <pr>(fr<amac/d)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Fraying</conjf>.]</vmorph> <ety>[See 1st <er>Fray</er>, and cf.
<er>Affray</er>.]</ety> <def>To frighten; to terrify; to alarm.</def>
<rj><au>I. Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>What <qex>frays</qex> ye, that were wont to comfort me
affrayed?</q> <rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fray</ent><br/
<hw>Fray</hw>, <pos>v. t.</pos> <ety>[Cf. OF. <ets>fraier</ets>. See
<er>Defray</er>, <pos>v. t.</pos>]</ety> <def>To bear the expense of; to
defray.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The charge of my most curious and costly ingredients
<qex>frayed</qex>, I shall acknowledge myself amply satisfied.</q>
<rj><qau>Massinger.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fray</ent><br/
<hw>Fray</hw>, <pos>v. t.</pos> <ety>[OF. <ets>freier</ets>,
<ets>fraier</ets>, <ets>froier</ets>, to rub. L. <ets>fricare</ets>; cf.
<ets>friare</ets> to crumble, E. <ets>friable</ets>; perh. akin to Gr.
<grk>chri`ein</grk> to anoint, <grk>chri^sma</grk> an anointing, Skr.
<ets>gh<rsdot/sh</ets> to rub, scratch. Cf. <er>Friction</er>.]</ety>
<def>To rub; to wear off, or wear into shreds, by rubbing; to fret, as
cloth; <as>as, a deer is said to <ex>fray</ex> her head</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fray</ent><br/
<hw>Fray</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To rub.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We can show the marks he made<br/
When 'gainst the oak his antlers <qex>frayed</qex>.</q> <rj><qau>Sir W.
Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To wear out or into shreads, or to suffer injury by
rubbing, as when the threads of the warp or of the woof wear off so that
the cross threads are loose; to ravel; <as>as, the cloth <ex>frays</ex>
badly</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A suit of <qex>frayed</qex> magnificience.</q>
<rj><qau>tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fray</ent><br/
<hw>Fray</hw>, <pos>n.</pos> <def>A fret or chafe, as in cloth; a place
injured by rubbing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fraying</ent><br/
<hw>Fray"ing</hw>, <pos>n.</pos> <fld>(Zool.)</fld> <def>The skin which
a deer frays from his horns.</def> <rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frazzle</ent><br/
<hw>Fraz"zle</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Frazzled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Frazzling</conjf> <pr>(?)</pr>.]</vmorph> <ety>[Cf. G.
<ets>faseln</ets>, and E. <ets>fray</ets>.]</ety> <def>To fray; to wear
or pull into tatters or tag ends; to tatter; -- used literally and
figuratively.</def> <mark>[Prov. Eng. & U. S.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><q>Her hair was of a reddish gray color, and its <qex>frazzled</qex>
and tangled condition suggested that the woman had recently passed
through a period of extreme excitement.</q> <rj><qau>J. C.
Harris.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Frazzle</ent><br/
<hw>Fraz"zle</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act or result of
frazzling; the condition or quality of being frazzled; the tag end; a
frayed-out end.</def> <mark>[Prov. Eng. & U. S.]</mark><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><q>My fingers are all scratched to <qex>frazzles</qex>.</q>
<rj><qau>Kipling.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>a state of extreme exhaustion; -- often used in the
phrase <col><b>worn to a frazzle</b></col>.</def> <wns>[wns=1]</wns><br/
[<source>WordNet 1.5</source>]</p>

<p><q>Gordon had sent word to Lee that he <ldquo/had fought his corps to
a <qex>frazzle</qex>.<rdquo/</q> <rj><qau>Nicolay & Hay (Life of
Lincoln).</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Freak</ent><br/
<hw>Freak</hw> <pr>(fr<emac/k)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Freaked</conjf> <pr>(fr<emac/kt)</pr>; <pos>p. pr.
& vb. n.</pos> <conjf>Freaking</conjf>.]</vmorph> <ety>[Akin to OE.
<ets>frakin</ets>, <ets>freken</ets>, freckle, Icel. <ets>freknur</ets>,
pl., Sw. <ets>fr<aum/kne</ets>, Dan. <ets>fregne</ets>, Gr.
<grk>perkno`s</grk> dark-colored, Skr. <ets>p<rsdot/<cced/ni</ets>
variegated. Cf. <er>Freckle</er>, <er>Freck</er>.]</ety> <def>To
variegate; to checker; to streak.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Freaked</qex> with many a mingled hue.</q>
<rj><qau>Thomson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Freak</ent><br/
<hw>Freak</hw>, <pos>n.</pos> <ety>[Prob. from OE. <ets>frek</ets> bold,
AS. <ets>frec</ets> bold, greedly; akin to OHG. <ets>freh</ets> greedly,
G. <ets>frech</ets> insolent, Icel. <ets>frekr</ets> greedy, Goth.
<ets>fa<iacute/hufriks</ets> avaricious.]</ety> <sn>1.</sn> <def>A
sudden causeless change or turn of the mind; a whim of fancy; a
capricious prank; a vagary or caprice.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>She is restless and peevish, and sometimes in a <qex>freak</qex>
will instantly change her habitation.</q>
<rj><qau>Spectator.</qau></rj></p>

<p><sn>2.</sn> <def>a rare and unpredictable event; <as>as, the July
snowstorm was a <ex>freak</ex> of nature</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>an habitual drug user, especially one who uses
psychedelic drugs.</def><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <def>an animal or person with a visible congenital
abnormality; -- applied especially to those who appear in a circus
sideshow.</def><br/
[<source>PJC</source>]</p>

<p><syn><b>Syn.</b> -- Whim; caprice; folly; sport. See
<er>Whim</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Freak</ent><br/
<hw>Freak</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>to react with
irrationality or extreme emotion; to lose one's composure; -- often used
in the phrase <col><b>freak out</b></col>.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>to become irrational or to experience hallucinations
under the influence of drugs; -- often used in the phrase <col><b>freak
out</b></col>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Freak</ent><br/
<hw>Freak</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>to cause (a person)
react with great distress or extreme emotion; -- often used in the
phrase <col><b>freak out</b></col>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Freaking</ent><br/
<hw>Freak"ing</hw>, <pos>a.</pos> <def>Freakish.</def>
<mark>[Obs.]</mark> <rj><au>Pepys.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Freakish</ent><br/
<hw>Freak"ish</hw>, <pos>a.</pos> <def>Apt to change the mind suddenly;
whimsical; capricious.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It may be a question whether the wife or the woman was the more
<qex>freakish</qex> of the two.</q> <rj><qau>L'Estrange.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Freakish</qex> when well, and fretful when she's sick.</q>
<rj><qau>Pope.</qau></rj></p>

<p><sn>2.</sn> <def>rapidly changing and unpredictable; <as>as,
<ex>freakish</ex> weather</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>markedly abnormal.</def><br/
<syn><b>Syn. --</b> freaky.</syn><br/
[<source>PJC</source>]</p>

<p>-- <wordforms><wf>Freak"ish*ly</wf>, <pos>adv.</pos> --
<wf>Freak"ish*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>freakishness</ent><br/
<hw>freakishness</hw> <pos>n.</pos> <def>marked strangeness or
abnormality.</def><br/
<syn><b>Syn. --</b> abnormality.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>freaky</ent><br/
<hw>freaky</hw> <pos>adj.</pos> <def>markedly unusual or abnormal;
<as>as, <ex>freaky</ex> weather</as>.</def><br/
<syn><b>Syn. --</b> freakish.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Freck</ent><br/
<hw>Freck</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Cf. <er>Freak</er>,
<pos>v. t.</pos>, <er>Freckle</er>.]</ety> <def>To checker; to
diversify.</def> <mark>[R. & Poet.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The painted windows, <qex>frecking</qex> gloom with glow.</q>
<rj><qau>Lowell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Freckle</ent><br/
<hw>Freck"le</hw> <pr>(fr<ecr/k"k'l)</pr>, <pos>n.</pos> <ety>[Dim.,
from the same root as <ets>freak</ets>, <pos>v. t.</pos>]</ety>
<sn>1.</sn> <def>A small yellowish or brownish spot in the skin,
particularly on the face, neck, or hands.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Any small spot or discoloration.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Freckle</ent><br/
<hw>Frec"kle</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Freckled</conjf> <pr>(fr<ecr/k"k'ld)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Freckling</conjf>
<pr>(fr<ecr/k"kl<icr/ng)</pr>.]</vmorph> <def>To sprinkle or mark with
freckles or small discolored spots; to spot.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 594 --></p>

<p><ent>Freckle</ent><br/
<hw>Frec"kle</hw> <pr>(fr<ecr/k"k'l)</pr>, <pos>v. i.</pos> <def>To
become covered or marked with freckles; to be spotted.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Freckled</ent><br/
<hw>Frec"kled</hw> <pr>(fr<ecr/k"k'ld)</pr>, <pos>a.</pos> <def>Marked
with freckles; spotted.</def> <ldquo/The <xex>freckled</xex>
trout.<rdquo/ <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>freckled</qex> cowslip, burnet, and green clover.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Freckledness</ent><br/
<hw>Frec"kled*ness</hw> <pr>(-k'ld*n<ecr/s)</pr>, <pos>n.</pos> <def>The
state of being freckled.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Freckly</ent><br/
<hw>Frec"kly</hw> <pr>(-kl<ycr/)</pr>, <pos>a.</pos> <def>Full of or
marked with freckles; sprinkled with spots; freckled.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fred</ent><br/
<hw>Fred</hw> <pr>(fr<ecr/d)</pr>, <pos>n.</pos> <ety>[AS.
<ets>fri<edh/</ets> peace. See <er>Frith</er> inclosure.]</ety>
<def>Peace; -- a word used in composition, especially in proper names;
<as>as, Al<ex>fred</ex>; <ex>Fred</ex>eric.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fredstole</ent><br/
<hw>Fred"stole`</hw> <pr>(-st<omac/l`)</pr>, <pos>n.</pos>
<mark>[Obs.]</mark> <def>See <er>Fridstol</er>.</def>
<rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Free</ent><br/
<hw>Free</hw> <pr>(fr<emac/)</pr>, <pos>a.</pos>
<amorph>[<pos>Compar.</pos> <adjf>Freer</adjf> <pr>(-<etil/r)</pr>;
<pos>superl.</pos> <adjf>Freest</adjf> <pr>(-<ecr/st)</pr>.]</amorph>
<ety>[OE. <ets>fre</ets>, <ets>freo</ets>, AS. <ets>fre<oacute/</ets>,
<ets>fr<imac/</ets>; akin to D. <ets>vrij</ets>, OS. & OHG.
<ets>fr<imac/</ets>, G. <ets>frei</ets>, Icel. <ets>fr<imac/</ets>, Sw.
& Dan. <ets>fri</ets>, Goth. <ets>freis</ets>, and also to Skr.
<ets>prija</ets> beloved, dear, fr. <ets>pr<imac/</ets> to love, Goth.
<ets>frij<omac/n</ets>. Cf. <er>Affray</er>, <er>Belfry</er>,
<er>Friday</er>, <er>Friend</er>, <er>Frith</er> inclosure.]</ety>
<sn>1.</sn> <def>Exempt from subjection to the will of others; not under
restraint, control, or compulsion; able to follow one's own impulses,
desires, or inclinations; determining one's own course of action; not
dependent; at liberty.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That which has the power, or not the power, to operate, is that
alone which is or is not <qex>free</qex>.</q>
<rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Not under an arbitrary or despotic government;
subject only to fixed laws regularly and fairly administered, and
defended by them from encroachments upon natural or acquired rights;
enjoying political liberty.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Liberated, by arriving at a certain age, from the
control of parents, guardian, or master.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Not confined or imprisoned; released from arrest;
liberated; at liberty to go.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Set an unhappy prisoner <qex>free</qex>.</q>
<rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Not subjected to the laws of physical necessity;
capable of voluntary activity; endowed with moral liberty; -- said of
the will.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Not <qex>free</qex>, what proof could they have given sincere<br/
Of true allegiance, constant faith, or love.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Clear of offense or crime; guiltless;
innocent.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>My hands are guilty, but my heart is <qex>free</qex>.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>Unconstrained by timidity or distrust; unreserved;
ingenuous; frank; familiar; communicative.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He was <qex>free</qex> only with a few.</q>
<rj><qau>Milward.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>Unrestrained; immoderate; lavish; licentious; --
used in a bad sense.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The critics have been very <qex>free</qex> in their censures.</q>
<rj><qau>Felton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A man may live a <qex>free</qex> life as to wine or women.</q>
<rj><qau>Shelley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>Not close or parsimonious; liberal; open-handed;
lavish; <as>as, <ex>free</ex> with his money</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <def>Exempt; clear; released; liberated; not encumbered
or troubled with; <as>as, <ex>free</ex> from pain; <ex>free</ex> from a
burden</as>; -- followed by <xex>from</xex>, or, rarely, by
<xex>of</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Princes declaring themselves <qex>free</qex> from the obligations
of their treaties.</q> <rj><qau>Bp. Burnet.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>11.</sn> <def>Characteristic of one acting without restraint;
charming; easy.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>12.</sn> <def>Ready; eager; acting without spurring or whipping;
spirited; <as>as, a <ex>free</ex> horse</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>13.</sn> <def>Invested with a particular freedom or franchise;
enjoying certain immunities or privileges; admitted to special rights;
-- followed by <xex>of</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He therefore makes all birds, of every sect,<br/
<qex>Free</qex> of his farm.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>14.</sn> <def>Thrown open, or made accessible, to all; to be
enjoyed without limitations; unrestricted; not obstructed, engrossed, or
appropriated; open; -- said of a thing to be possessed or enjoyed;
<as>as, a <ex>free</ex> school</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Why, sir, I pray, are not the streets as <qex>free</qex><br/
For me as for you?</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>15.</sn> <def>Not gained by importunity or purchase; gratuitous;
spontaneous; <as>as, <ex>free</ex> admission; a <ex>free</ex>
gift.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>16.</sn> <def>Not arbitrary or despotic; assuring liberty;
defending individual rights against encroachment by any person or class;
instituted by a free people; -- said of a government, institutions,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>17.</sn> <fld>(O. Eng. Law)</fld> <def>Certain or honorable; the
opposite of <ant>base</ant>; <as>as, <ex>free</ex> service;
<ex>free</ex> socage.</as></def> <rj><au>Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>18.</sn> <fld>(Law)</fld> <def>Privileged or individual; the
opposite of <xex>common</xex>; <as>as, a <ex>free</ex> fishery; a
<ex>free</ex> warren.</as></def> <rj><au>Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>19.</sn> <def>Not united or combined with anything else;
separated; dissevered; unattached; at liberty to escape; <as>as,
<ex>free</ex> carbonic acid gas; <ex>free</ex> cells.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Free agency</b></col>, <cd>the capacity or power of
choosing or acting freely, or without necessity or constraint upon the
will.</cd> -- <col><b>Free bench</b></col> <fld>(Eng. Law)</fld>, <cd>a
widow's right in the copyhold lands of her husband, corresponding to
<xex>dower</xex> in freeholds.</cd> -- <col><b>Free board</b></col>
<fld>(Naut.)</fld>, <cd>a vessel's side between water line and
gunwale.</cd> -- <col><b>Free bond</b></col> <fld>(Chem.)</fld>, <cd>an
unsaturated or unemployed unit, or bond, of affinity or valence, of an
atom or radical.</cd> -- <col><b>Free-borough men</b></col> <fld>(O.Eng.
Law)</fld>. <cd>See <er>Friborg</er>.</cd> -- <col><b>Free
chapel</b></col> <fld>(Eccles.)</fld>, <cd>a chapel not subject to the
jurisdiction of the ordinary, having been founded by the king or by a
subject specially authorized.</cd> <mark>[Eng.]</mark> <au>Bouvier.</au>
-- <col><b>Free charge</b></col> <fld>(Elec.)</fld>, <cd>a charge of
electricity in the free or statical condition; free electricity.</cd> --
<col><b>Free church</b></col>. <sd>(a)</sd> <cd>A church whose sittings
are for all and without charge.</cd> <sd>(b)</sd> <cd>An ecclesiastical
body that left the Church of Scotland, in 1843, to be free from control
by the government in spiritual matters.</cd> -- <mcol><col><b>Free
city</b></col>, <it>or</it> <col><b>Free town</b></col></mcol>, <cd>a
city or town independent in its government and franchises, as formerly
those of the Hanseatic league.</cd> -- <col><b>Free cost</b></col>,
<cd>freedom from charges or expenses.</cd> <au>South.</au> --
<col><b>Free and easy</b></col>, <cd>unconventional; unrestrained;
regardless of formalities.</cd> <mark>[Colloq.]</mark> <ldquo/Sal and
her <xex>free and easy</xex> ways.<rdquo/ <au>W. Black.</au> --
<col><b>Free goods</b></col>, <cd>goods admitted into a country free of
duty.</cd> -- <col><b>Free labor</b></col>, <cd>the labor of freemen, as
distinguished from that of slaves.</cd> -- <col><b>Free port</b></col>.
<fld>(Com.)</fld> <sd>(a)</sd> <cd>A port where goods may be received
and shipped free of custom duty.</cd> <sd>(b)</sd> <cd>A port where
goods of all kinds are received from ships of all nations at equal rates
of duty.</cd> -- <col><b>Free public house</b></col>, <cd>in England, a
tavern not belonging to a brewer, so that the landlord is free to brew
his own beer or purchase where he chooses.</cd> <au>Simmonds.</au> --
<col><b>Free school</b></col>. <sd>(a)</sd> <cd>A school to which pupils
are admitted without discrimination and on an equal footing.</cd>
<sd>(b)</sd> <cd>A school supported by general taxation, by endowmants,
etc., where pupils pay nothing for tuition; a public school.</cd> --
<col><b>Free services</b></col> <fld>(O.Eng. Law)</fld>, <cd>such feudal
services as were not unbecoming the character of a soldier or a freemen
to perform; as, to serve under his lord in war, to pay a sum of money,
etc.</cd> <au>Burrill.</au> -- <col><b>Free ships</b></col>, <cd>ships
of neutral nations, which in time of war are free from capture even
though carrying enemy's goods.</cd> -- <col><b>Free socage</b></col>
<fld>(O.Eng. Law)</fld>, <cd>a feudal tenure held by certain services
which, though honorable, were not military.</cd> <au>Abbott.</au> --
<col><b>Free States</b></col>, <cd>those of the United States before the
Civil War, in which slavery had ceased to exist, or had never
existed.</cd> -- <col><b>Free stuff</b></col> <fld>(Carp.)</fld>,
<cd>timber free from knots; clear stuff.</cd> -- <col><b>Free
thought</b></col>, <cd>that which is thought independently of the
authority of others.</cd> -- <col><b>Free trade</b></col>, <cd>commerce
unrestricted by duties or tariff regulations.</cd> -- <col><b>Free
trader</b></col>, <cd>one who believes in free trade.</cd> -- <col><b>To
make free with</b></col>, <cd>to take liberties with; to help one's self
to.</cd> <mark>[Colloq.]</mark> -- <col><b>To sail free</b></col>
<fld>(Naut.)</fld>, <cd>to sail with the yards not braced in as sharp as
when sailing closehauled, or close to the wind.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Free</ent><br/
<hw>Free</hw> <pr>(?)</pr>, <pos>adv.</pos> <sn>1.</sn> <def>Freely;
willingly.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I as <qex>free</qex> forgive you<br/
As I would be forgiven.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Without charge; <as>as, children admitted
<ex>free</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Free</ent><br/
<hw>Free</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Freed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Freeing</conjf>.]</vmorph> <ety>[OE. <ets>freen</ets>,
<ets>freoien</ets>, AS. <ets>fre<oacute/gan</ets>. See <er>Free</er>,
<pos>a.</pos>]</ety> <sn>1.</sn> <def>To make free; to set at liberty;
to rid of that which confines, limits, embarrasses, oppresses, etc.; to
release; to disengage; to clear; -- followed by <xex>from</xex>, and
sometimes by <xex>off</xex>; <as>as, to <ex>free</ex> a captive or a
slave; to be <ex>freed</ex> of these inconveniences.</as></def>
<rj><au>Clarendon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Our land is from the rage of tigers <qex>freed</qex>.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Arise, . . . <qex>free</qex> thy people from their yoke.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To remove, as something that confines or bars; to
relieve from the constraint of.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This master key<br/
<qex>Frees</qex> every lock, and leads us to his person.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To frank.</def> <mark>[Obs.]</mark>
<rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>free-and-easy</ent><br/
<hw>free-and-easy</hw> <pos>adj.</pos> <sn>1.</sn> <def>unconstrained
and informal; <as>as, an informal <ex>free-and-easy</ex> manner</as>.
Opposite of <ant>stiff</ant>, <ant>starchy</ant>,
<ant>formal</ant>.</def><br/
<syn><b>Syn. --</b> casual.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>lacking normal concern for propriety.</def><br/
<syn><b>Syn. --</b> free-and-easy.</syn><br/
[<source>PJC</source>]</p>

<p><ent>free-associate</ent><br/
<hw>free-associate</hw> <pos>v. i.</pos> <fld>(psychoanalysis)</fld>
<def>to express one's thoughts, ideas, impressions, etc. in an unplanned
and unstructured way, allowing each thought or idea to prompt
recollection of the next one. It is a process used in
psychotherapy.</def><br/
<syn><b>Syn. --</b> associate freely.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>free association</ent><br/
<hw>free association</hw> <pos>n.</pos> <fld>(psychoanalysis)</fld>
<def>The act or process of free-associating. It is a technique used in
psychoanalysis and is supposed to allow the analyst access to the
unconscious thoughts of the analysand. See
<er>free-associate</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Free base</ent><br/
<hw>Free" base`</hw> <pr>(fr<emac/" b<amac/s`)</pr>, <pos>n.</pos>
<sn>1.</sn> <fld>(Chem.)</fld> <def>The basic form of an organic amine
which is capable of forming acid salts such as hydrochlorides.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>The basic form of a drug, often more powerful than a
salt form because it is more readily absorbed into the blood
stream.</def><br/
[<source>PJC</source>]</p>

<p><ent>Free base</ent><br/
<ent>free-base</ent><br/
<mhw><hw>free-base</hw>, <hw>Free" base`</hw></mhw> <pr>(fr<emac/"
b<amac/s`)</pr>, <pos>v. i.</pos> <def>To ingest the basic form of a
narcotic drug, usually by injection.</def><br/
[<source>PJC</source>]</p>

<p><ent>Freebooter</ent><br/
<hw>Free"boot`er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[D.
<ets>vrijbuiter</ets>, fr. <ets>vrijbuiten</ets> to plunder;
<ets>vrij</ets> free + <ets>buit</ets> booty, akin to E.
<ets>booty</ets>. See <er>Free</er>, and <er>Booty</er>, and cf.
<er>Filibuster</er>.]</ety> <def>One who plunders or pillages without
the authority of national warfare; a member of a predatory band; a
pillager; a buccaneer; a sea robber.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Freebootery</ent><br/
<hw>Free"boot`er*y</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act,
practice, or gains of a freebooter; freebooting.</def>
<rj><au>Booth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Freebooting</ent><br/
<hw>Free"boot`ing</hw>, <pos>n.</pos> <def>Robbery; plunder; a
pillaging.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Freebooting</ent><br/
<hw>Free"boot`ing</hw>, <pos>a.</pos> <def>Acting the freebooter;
practicing freebootery; robbing.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Your <qex>freebooting</qex> acquaintance.</q> <rj><qau>Sir W.
Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Freebooty</ent><br/
<hw>Free"boot`y</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Freebootery.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Freeborn</ent><br/
<hw>Free"born`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Born free; not born
in vassalage; inheriting freedom.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>free-burning</ent><br/
<hw>free-burning</hw> <pos>adj.</pos> <def>burning in a continuous
manner; -- of an electric arc; <as>as, heat transfer to the anode in
<ex>free-burning</ex> arcs</as>.</def><br/
<syn><b>Syn. --</b> free burning, sustained.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Free coinage</ent><br/
<hw>Free coinage</hw>. <def>In the fullest sense, the conversion of
bullion (of any specified metal) into legal-tender coins for any person
who chooses to bring it to the mint; in a modified sense, such coinage
when done at a fixed charge proportionate to the cost of the
operation.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Free-denizen</ent><br/
<hw>Free"-den`i*zen</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To make
free.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Freedman</ent><br/
<hw>Freed"man</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Freedmen</plw> <pr>(<?/)</pr>.</plu> <def>A man who has been a
slave, and has been set free.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Freedom</ent><br/
<hw>Free"dom</hw> <pr>(fr<emac/"d<ucr/m)</pr>, <pos>n.</pos> <ety>[AS.
<ets>fre<oacute/d<omac/m</ets>; <ets>fre<oacute/</ets>free +
<ets>-dom</ets>. See <er>Free</er>, and <er>-dom</er>.]</ety>
<sn>1.</sn> <def>The state of being free; exemption from the power and
control of another; liberty; independence.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Made captive, yet deserving <qex>freedom</qex> more.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Privileges; franchises; immunities.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Your charter and your caty's <qex>freedom</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Exemption from necessity, in choise and action;
<as>as, the <ex>freedom</ex> of the will</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Ease; facility; <as>as, he speaks or acts with
<ex>freedom</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Frankness; openness; unreservedness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I emboldened spake and <qex>freedom</qex> used.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Improper familiarity; violation of the rules of
decorum; license.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>Generosity; liberality.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Freedom fine</b></col>, <cd>a sum paid on entry to
incorporations of trades.</cd> -- <col><b>Freedom of the city</b></col>,
<cd>the possession of the rights and privileges of a freeman of the
city; formerly often, and now occasionally, conferred on one not a
resident, as a mark of honorary distinction for public
services.</cd></cs></p>

<p><syn><b>Syn.</b> -- See <er>Liberty</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Freedstool</ent><br/
<hw>Freed"stool`</hw> <pr>(?)</pr>, <pos>n.</pos> <mark>[Obs.]</mark>
<def>See <er>Fridstol</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>freedwoman</ent><br/
<hw>freedwoman</hw> <pos>n.</pos> <def>a woman who has been freed from
slavery. Correlative of <contr>freedman</contr>.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>free enterprise</ent><br/
<hw>free enterprise</hw> <pos>n.</pos> <sn>1.</sn> <def>an economic
system having predominantly private ownership of the means of
production, and relying chiefly on market forces to allocate goods and
resources and to determine prices, and having a minimum of governmental
interference in economic decisions; also, the political doctrine
advocating such a system as the economic system of a country.</def>
<wns>[wns=1]</wns><br/
<syn><b>Syn. --</b> market economy, laissez-faire economy.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>The conduct of business according to the principles
of the free enterprise doctrine; the conduct of economic activity
without governmental interference.</def><br/
[<source>PJC</source>]</p>

<p><ent>free-enterprise</ent><br/
<hw>free-enterprise</hw> <pos>adj.</pos> <def>Of or pertaining to the
<er>free enterprise</er> system having private ownership of the means of
production and competition between enterprises.</def>
<mark>[prenominal]</mark> [Narrower terms: <stype>capitalistic,
capitalist</stype>] <ant>socialistic</ant><br/
<syn><b>Syn. --</b> competitive,
private-enterprise(prenominal).</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>free-for-all</ent><br/
<hw>free-for-all</hw> <pos>n.</pos> <sn>1.</sn> <def>a noisy and
disordered fight conducted without rules.</def><br/
<syn><b>Syn. --</b> brawl.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <specif>Hence:</specif> <def>Any vigorous competition in
which anyone can compete, with few or no rules, and in which the winner
is unpredictable; <as>as, when they began to distribute the free food,
the orderly line of hungry recipients degenerated into a
<ex>free-for-all</ex></as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Free-hand</ent><br/
<hw>Free"-hand`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Done by the hand,
without support, or the guidance of instruments; -- of drawing or
sculpture; <as>as, <ex>free-hand</ex> drawing</as>. See under
<er>Drawing</er>.</def><br/
<syn><b>Syn. --</b> free, freehanded, unguided, untraced.</syn><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><ent>Free-handed</ent><br/
<hw>Free"-hand`ed</hw>, <pos>a.</pos> <sn>1.</sn> <def>Open-handed;
liberal; given or giving freely or liberally; <as>as, a
<ex>freehanded</ex> host</as>.</def> <wns>[wns=2]</wns><br/
<syn><b>Syn. --</b> big, bighearted, bounteous, bountiful, handsome,
giving, liberal, openhanded.</syn><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>same as <er>freehand</er>.</def>
<wns>[wns=1]</wns><br/
<syn><b>Syn. --</b> free, freehand, unguided, untraced.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Free-hearted</ent><br/
<ent>freehearted</ent><br/
<mhw><hw>free"heart`ed</hw>, <hw>Free"-heart`ed</hw></mhw> <pr>(?)</pr>,
<pos>a.</pos> <def>Open; frank; unreserved; liberal; generous; <as>as,
<ex>free-hearted</ex> mirth</as>. Opposite of
<ant>stingy</ant>.</def><br/
<syn><b>Syn. --</b> benevolent.</syn><br/
-- <wordforms><wf>Free"-heart`ed*ly</wf>, <pos>adv.</pos> --
<wf>Free"-heart`ed*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><ent>Freehold</ent><br/
<hw>Free"hold`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Lw)</fld> <def>An
estate in real property, of inheritance (in fee simple or fee tail) or
for life; or the tenure by which such estate is held.</def>
<rj><au>Kent. Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To abate into a freehold</b></col>. <cd>See under
<er>Abate</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Freeholder</ent><br/
<hw>Free"hold`er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<fld>(Law)</fld> <def>The possessor of a freehold.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A person who owns local property and has been a
resident for a certain period of years; -- used in some U.S.
counties.</def> <mark>[U.S., local]</mark> <br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <fld>(Politics, U.S)</fld> <def>A member of the
<org>Board of Chosen Freeholders</org> of some county, such a board
being a form of legislative and administrive body which controls the
government in some counties in the United States.</def> <mark>[U.S.,
local]</mark><br/
[<source>PJC</source>]</p>

<p><ent>Freelance</ent><br/
<hw>Free"lance`</hw> <pr>(fr<emac/"l<acr/ns`)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>a person who acts independently or without
authorization of an organization or of his superiors.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>a person who pursues a profession independently, and
not as the employee of an organization; -- used especially of writers or
photographers who sell their work to organizations of which they are not
employees.</def><br/
[<source>PJC</source>]</p>

<p><ent>Freelance</ent><br/
<hw>Free"lance`</hw> <pr>(fr<emac/"l<acr/ns`)</pr>, <pos>a.</pos>
<def>of or pertaining to a <er>freelance{2}</er>; <as>as, a
<ex>freelance</ex> photographer</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>free-lance</ent><br/
<hw>free-lance</hw> <pos>v. i.</pos> <def>to work on a free-lance basis;
to work as a freelancer.</def><br/
<syn><b>Syn. --</b> freelance.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>free-lancer</ent><br/
<ent>freelancer</ent><br/
<mhw><hw>free"lanc`er</hw>, <hw>free"-lanc`er</hw></mhw>
<pr>(fr<emac/"l<acr/ns`<etil/r)</pr>, <pos>n.</pos> <def>a
<er>freelance{2}</er>, <pos>n.</pos></def><br/
[<source>PJC</source>]</p>

<p><ent>Free-liver</ent><br/
<hw>Free"-liv`er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who gratifies
his physical appetites without stint; one given to indulgence in eating
and drinking.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Free-living</ent><br/
<hw>Free"-liv`ing</hw>, <pos>n.</pos> <def>Unrestrained indulgence of
the appetites as a way of life.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>free-living</ent><br/
<hw>free-living</hw> <pos>adj.</pos> <fld>(Biology)</fld> <def>Living
independently of other organisms; not parasitic or commensal.</def>
<note>eating other organisms is not considered "dependence" in this
sense.</note><br/
<syn><b>Syn. --</b> nonparasitic, nonsymbiotic.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Free-love</ent><br/
<hw>Free"-love`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The doctrine or
practice of consorting with the opposite sex, at pleasure, without
marriage.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Free-lover</ent><br/
<hw>Free"-lov`er</hw>, <pos>n.</pos> <def>One who believes in or
practices free-love.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Freelte</ent><br/
<hw>Freel"te</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Frailty.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Freely</ent><br/
<hw>Free"ly</hw>, <pos>adv.</pos> <ety>[AS.
<ets>fre<oacute/lice</ets>.]</ety> <def>In a free manner; without
restraint or compulsion; abundantly; gratuitously.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Of every tree of the garden thou mayst <qex>freely</qex> eat.</q>
<rj><qau>Gen. ii. 16.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Freely</qex> ye have received, <qex>freely</qex> give.</q>
<rj><qau>Matt. x. 8.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Freely</qex> they stood who stood, and fell who fell.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Freely</qex> we serve<br/
Because we <qex>freely</qex> love.</q> <rj><qau>Milton.</qau></rj></p>

<p><syn><b>Syn.</b> -- Independently; voluntarily; spontaneously;
unconditionally; unobstructedly; willingly; readily; liberally;
generously; bounteously; munificently; bountifully; abundantly; largely;
copiously; plentifully; plenteously.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Freeman</ent><br/
<hw>Free"man</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Freemen</plw> <pr>(#)</pr>.</plu> <ety>[AS.
<ets>fre<oacute/man</ets>; <ets>fre<oacute/</ets>free + <ets>mann</ets>
man.]</ety> <sn>1.</sn> <def>One who enjoys liberty, or who is not
subject to the will of another; one not a slave or vassal.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A member of a corporation, company, or city,
possessing certain privileges; a member of a borough, town, or State,
who has the right to vote at elections. See <er>Liveryman</er>.</def>
<rj><au>Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Both having been made <qex>freemen</qex> on the same day.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Free-martin</ent><br/
<hw>Free"-mar`tin</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>An imperfect female calf, twinborn with a male, which is sterile as
a result of exposure to masculinizing hormones.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Freemason</ent><br/
<hw>Free"ma`son</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One of an ancient
and secret association or fraternity, said to have been at first
composed of masons or builders in stone, but now consisting of persons
who are united for social enjoyment and mutual assistance.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Freemasonic</ent><br/
<hw>Free`ma*son"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to,
or resembling, the institutions or the practices of freemasons; <as>as,
a <ex>freemasonic</ex> signal</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Freemasonry</ent><br/
<hw>Free"ma`son*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The
institutions or the practices of freemasons.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Free-milling</ent><br/
<hw>Free"-mill`ing</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Yielding free
gold or silver; -- said of certain ores which can be reduced by crushing
and amalgamation, without roasting or other chemical treatment.</def>
<rj><au>Raymond.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Free-minded</ent><br/
<hw>Free"-mind`ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Not perplexed;
having a mind free from care.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Freeness</ent><br/
<hw>Free"ness</hw>, <pos>n.</pos> <def>The state or quality of being
free; freedom; liberty; openness; liberality; gratuitousness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Freer</ent><br/
<hw>Fre"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who frees, or sets
free.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>free-range</ent><br/
<hw>free-range</hw> <pos>adj.</pos> <def>permitted to graze or forage
rather than being confined to a feedlot; -- of livestock and domestic
poultry.</def><br/
<syn><b>Syn. --</b> unenclosed.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>free-reed</ent><br/
<hw>free-reed</hw> <pos>n.</pos> <fld>(Music)</fld> <def>a reed that
does not fit closely over the aperture.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Free silver</ent><br/
<hw>Free silver</hw>. <def>The free coinage of silver; often, specif.,
the free coinage of silver at a fixed ratio with gold, as at the ratio
of 16 to 1, which ratio for some time represented nearly or exactly the
ratio of the market values of gold and silver respectively.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Free-soil</ent><br/
<hw>Free"-soil`</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Pertaining to, or advocating, the non-extension of slavery; -- esp.
applied to a party which was active during the period 1846-1856.</def>
<mark>[U.S.]</mark><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>Pertaining to territory where slavery was
prohibited.</def> <mark>[U.S.]</mark> <wns>[wns=1]</wns><br/
<syn><b>Syn. --</b> slaveless.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p> -- <wordforms><wf>Free"soil`er</wf> <pr>(#)</pr>, <pos>n.</pos>
<mark>[U.S.]</mark> -- <wf>Free"-soil`ism</wf> <pr>(#)</pr>,
<pos>n.</pos> <mark>[U.S.]</mark></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Free-spoken</ent><br/
<hw>Free"-spo`ken</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Accustomed to
speak without reserve; willing to speak out without subtlety.</def>
<rj><au>Bacon.</au></rj><br/
<syn><b>Syn. --</b> bluff, blunt, candid, frank, outspoken, plainspoken,
point-blank.</syn><br/
<br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p>-- <wordforms><wf>Free"-spo`ken*ness</wf>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Freestone</ent><br/
<hw>Free"stone`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A stone composed
of sand or grit; -- so called because it is easily cut or
wrought.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Freestone</ent><br/
<hw>Free"stone`</hw>, <pos>a.</pos> <def>Having the flesh readily
separating from the stone, as in certain kinds of peaches.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Free-swimming</ent><br/
<hw>Free"-swim`ming</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<sn>1.</sn> <def>Swimming in the open sea; -- said of certain marine
animals.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zoology)</fld> <def>able to swim about; not
attached to a stationary object; -- of aquatic animals.</def>
<wns>[wns=1]</wns><br/
<syn><b>Syn. --</b> unattached.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>freetail</ent><br/
<hw>freetail</hw> <pos>n.</pos> <def>A small swift bat with leathery
ears and a long tail; common in warm regions.</def><br/
<syn><b>Syn. --</b> freetailed bat.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>freetailed bat</ent><br/
<hw>freetailed bat</hw> <pos>n.</pos> <def>A small swift bat with
leathery ears and a long tail; common in warm regions.</def><br/
<syn><b>Syn. --</b> freetail.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Freethinker</ent><br/
<hw>Free"think`er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
speculates or forms opinions independently of the authority of others;
esp., in the sphere or religion, one who forms opinions independently of
the authority of revelation or of the church; an unbeliever; -- a term
assumed by deists and skeptics in the eighteenth century.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Atheist is an old-fashioned word: I'm a <qex>freethinker</qex>,
child.</q> <rj><qau>Addison.</qau></rj></p>

<p><syn><b>Syn.</b> -- Infidel; skeptic; unbeliever. See
<er>Infidel</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Freethinking</ent><br/
<hw>Free"think`ing</hw>, <pos>n.</pos> <def>Undue boldness of
speculation; unbelief.</def> <au>Berkeley.</au><br/
[<source>1913 Webster</source>]</p>

<p><ent>free-thinking</ent><br/
<hw>free-thinking</hw> <pos>adj.</pos> <def>inclined to forms one's own
opinions rather than depend upon authority, especially about social and
religious issues; exhibiting boldness of speculation; skeptical of
authority.</def><br/
<syn><b>Syn. --</b> latitudinarian, undogmatic, undogmatical.</syn><br/
[<source>WordNet 1.5</source> + <source>1913 Webster</source>]</p>

<p><ent>Free-tongued</ent><br/
<hw>Free"-tongued`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Speaking
without reserve.</def> <rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Freetown</ent><br/
<hw>Freetown</hw> <pos>prop. n.</pos> <fld>(Geography)</fld> <def>The
capital <isa>city</isa> of <country>Sierra Leone</country>. Population
(2000) = 1,300,000.</def><br/
[<source>PJC</source>]</p>

<p><ent>Freewheel</ent><br/
<hw>Free"wheel`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Mach.)</fld>
<def>A clutch fitted in the rear hub of a cycle, which engages the rear
sprocket with the rear wheel when the pedals are rotated forwards, but
permits the rear wheel to run on free from the rear sprocket when the
pedals are stopped or rotated backwards. Freewheelcycles are usually
fitted with hub brakes or rim brakes, operated by back
pedaling.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Freewheel</ent><br/
<hw>Free"wheel`</hw>, <pos>v. i.</pos> <sn>1.</sn> <sd>(a)</sd> <def>Of
a freewheel cycle, to run on while the pedals are held still.</def>
<sd>(b)</sd> <def>Of a person, to ride a cycle of this manner; to coast
in a vehicle having a freewheel. To ride a freewheel cycle.</def>
<wns>[wns=2]</wns><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <fld>(Mach.)</fld> <def>To operate like a freewheel, so
that one part moves freely over another which normally moves with it; --
said of a clutch.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>3.</sn> <def>To act without controls, external or internal; to
live freely, independently, and without concern; -- of people.</def>
<wns>[wns=1]</wns><br/
[<source>PJC</source>]</p>

<p><ent>freewheeler</ent><br/
<hw>freewheeler</hw> <pos>n.</pos> <def>Someone acting freely or even
irresponsibly.</def><br/
<syn><b>Syn. --</b> free agent, free spirit.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>freewheeling</ent><br/
<hw>freewheeling</hw> <pos>adj.</pos> <def>Acting heedless of
consequences; acting without controls, external or internal; <as>as,
<ex>freewheeling</ex> foolishness</as>.</def><br/
<syn><b>Syn. --</b> careless, irresponsible, reckless.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Free will</ent><br/
<hw>Free will</hw> <pr>(?)</pr>. <sn>1.</sn> <def>A will free from
improper coercion or restraint.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To come thus was I not constrained, but did<br/
On my <qex>free will</qex>.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The power asserted of moral beings of willing or
choosing without the restraints of physical or absolute
necessity.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>freewill</ent><br/
<ent>free-will</ent><br/
<mhw><hw>free-will</hw>, <hw>free"will`</hw></mhw> <pr>(?)</pr>,
<pos>a.</pos> <def>Of or pertaining to free will; voluntary;
spontaneous; <as>as, a <ex>freewill</ex> offering</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Freewill Baptists</b></col>. <cd>See under
<er>Baptist</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Freezable</ent><br/
<hw>Freez"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of being
frozen.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Freeze</ent><br/
<hw>Freeze</hw> <pr>(fr<emac/z)</pr>, <pos>n.</pos> <fld>(Arch.)</fld>
<def>A frieze.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Freeze</ent><br/
<hw>Freeze</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp.</pos>
<conjf>Froze</conjf> <pr>(fr<omac/z)</pr>; <pos>p. p.</pos>
<conjf>Frozen</conjf> <pr>(fr<omac/"z'n)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Freezing</conjf>.]</vmorph> <ety>[OE. <ets>fresen</ets>,
<ets>freosen</ets>, AS. <ets>fre<oacute/san</ets>; akin to D.
<ets>vriezen</ets>, OHG. <ets>iosan</ets>, G. <ets>frieren</ets>, Icel.
<ets>frjsa</ets>, Sw. <ets>frysa</ets>, Dan. <ets>fryse</ets>, Goth.
<ets>frius</ets> cold, frost, and prob. to L. <ets>prurire</ets> to
itch, E. <ets>prurient</ets>, cf. L. <ets>prna</ets> a burning coal,
<ets>pruina</ets> hoarfrost, Skr. <ets>prushv<amac/</ets> ice,
<ets>prush</ets> to spirt. <?/ 18. Cf. <er>Frost</er>.]</ety>
<sn>1.</sn> <def>To become congealed by cold; to be changed from a
liquid to a solid state by the abstraction of heat; to be hardened into
ice or a like solid body.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Water <xex>freezes</xex> at 32<deg/ above zero by
Fahrenheit's thermometer; mercury <xex>freezes</xex> at 40<deg/ below
zero.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To become chilled with cold, or as with cold; to
suffer loss of animation or life by lack of heat; <as>as, the blood
<ex>freezes</ex> in the veins</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To freeze up</b></col> (<mark>Fig.</mark>), <cd>to become
formal and cold in demeanor.</cd> <mark>[Colloq.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Freeze</ent><br/
<hw>Freeze</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To congeal; to harden
into ice; to convert from a fluid to a solid form by cold, or
abstraction of heat.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To cause loss of animation or life in, from lack of
heat; to give the sensation of cold to; to chill.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A faint, cold fear runs through my veins,<br/
That almost <qex>freezes</qex> up the heat of life.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<cs><p>-- <col><b>To freeze out</b></col>, <cd>to drive out or exclude
by cold or by cold treatment; to force to withdraw; <as>as, to be
<ex>frozen out</ex> of one's room in winter; to <ex>freeze out</ex> a
competitor</as>.</cd> <mark>[Colloq.]</mark></p>

<p><q>A railroad which had a London connection must not be allowed to
<qex>freeze out</qex> one that had no such connection.</q> <rj><qau>A.
T. Hadley.</qau></rj></p>

<p><q>It is sometimes a long time before a player who is <qex>frozen
out</qex> can get into a game again.</q> <rj><qau>R. F.
Foster.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p></cs>

<p><ent>Freeze</ent><br/
<hw>Freeze</hw>, <pos>n.</pos> <def>The act of congealing, or the state
of being congealed.</def> <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>freeze-dried</ent><br/
<hw>freeze-dried</hw> <pos>adj.</pos> <def>dried by freezing and
applying a vacuum; -- used of tissue or blood or serum or other
biological substances.</def> <note>This technique is gentler than other
drying techniques and caused less damage or deterioration to sensitive
substances. It is used primarily as a method to preserve foods or
substances, and permit storage without deterioration.</note><br/
<syn><b>Syn. --</b> lyophilized, lyophilised.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Freeze-dry</ent><br/
<hw>Freeze"-dry`</hw> <pr>(fr<emac/z"-dr<imac/`)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Freeze-dried</conjf>; <pos>p.
pr. & vb. n.</pos> <conjf>Freeze-drying</conjf>.]</vmorph> <def>to
remove the moisture from (e.g. food) by first freezing and then
subjecting to a high vacuum; -- used as a mild method for drying foods
or chemicals while causing little decomposition, in contrast to
heat-drying.</def> <note>This is a relatively gently drying process used
to preserve food or sensitive biological materials. For biochemical
materials, the term <stype><er>lyophilize</er></stype> is often
used.</note><br/
[<source>PJC</source>]</p>

<p><ent>Freezer</ent><br/
<hw>Freez"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, cools or freezes, as a refrigerator, or the tub and can used in
the process of freezing ice cream.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Freezing</ent><br/
<hw>Freez"ing</hw>, <pos>a.</pos> <def>Tending to freeze; for freezing;
hence, cold or distant in manner.</def> --
<wordforms><wf>Frrez"ing*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Freezing machine</b></col>. <cd>See <cref>Ice
machine</cref>, under <er>Ice</er>.</cd> -- <col><b>Freezing
mixture</b></col>, <cd>a mixture (of salt and snow or of chemical salts)
for producing intense cold.</cd> -- <col><b>Freezing point</b></col>,
<cd>that degree of a thermometer at which a fluid begins to freeze; --
applied particularly to water, whose <ex>freezing point</ex> is at
32<deg/ Fahr., and at 0<deg/ Centigrade.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fregata</ent><br/
<hw>Fregata</hw> <pos>n.</pos> <def>The type genus of the
<fam>Fregatidae</fam>.</def><br/
<syn><b>Syn. --</b> genus <gen>Fregata</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fregatidae</ent><br/
<hw>Fregatidae</hw> <pos>n.</pos> <def>A natural family including the
genus <gen>Fregata</gen>, of frigate birds.</def><br/
<syn><b>Syn. --</b> family <fam>Fregatidae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Freieslebenite</ent><br/
<hw>Frei"es*le`ben*ite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Named
after the German chemist <etsep>Freiesleben</etsep>.]</ety> <def>A
sulphide of antimony, lead, and silver, occuring in monoclinic
crystals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Freight</ent><br/
<hw>Freight</hw> <pr>(fr<amac/t)</pr>, <pos>n.</pos> <ety>[F.
<ets>fret</ets>, OHG. <ets>fr<emac/ht</ets> merit, reward. See
<er>Fraught</er>, <pos>n.</pos>]</ety> <sn>1.</sn> <def>That with which
anything is fraught or laden for transportation; lading; cargo,
especially of a ship, or a car on a railroad, etc.; <as>as, a
<ex>freight</ex> of cotton; a full <ex>freight</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 595 --></p>

<p><sn>2.</sn> <fld>(Law)</fld> <sd>(a)</sd> <def>The sum paid by a
party hiring a ship or part of a ship for the use of what is thus
hired.</def> <sd>(b)</sd> <def>The price paid a common carrier for the
carriage of goods.</def> <rj><au>Wharton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Freight transportation, or freight line.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Freight</ent><br/
<hw>Freight</hw> <pr>(fr<amac/t)</pr>, <pos>a.</pos> <def>Employed in
the transportation of freight; having to do with freight; <as>as, a
<ex>freight</ex> car</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Freight agent</b></col>, <cd>a person employed by a
transportation company to receive, forward, or deliver goods.</cd> --
<col><b>Freight car</b></col>. <cd>See under <er>Car</er>.</cd> --
<col><b>Freight train</b></col>, <cd>a railroad train made up of freight
cars; -- called in England <altname>goods train</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Freight</ent><br/
<hw>Freight</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Freighted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Freighting</conjf>.]</vmorph> <ety>[Cf. F.
<ets>freter</ets>.]</ety> <def>To load with goods, as a ship, or vehicle
of any kind, for transporting them from one place to another; to furnish
with freight; <as>as, to <ex>freight</ex> a ship; to <ex>freight</ex> a
car.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Freightage</ent><br/
<hw>Freight"age</hw> <pr>(fr<amac/t"<asl/j; 48)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>The charge for transportation; the expense of
carriage.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The transportation of freight.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Freight; cargo; lading. Milton.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Freighter</ent><br/
<hw>Freight"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who
loads a ship, or one who charters and loads a ship.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One employed in receiving and forwarding
freight.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>One for whom freight is transported.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A vessel used mainly to carry freight.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Freightless</ent><br/
<hw>Freight"less</hw>, <pos>a.</pos> <def>Destitute of
freight.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Freiherr</ent><br/
\'d8<hw>Frei"herr`</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu>pl.
<plw>Freiherrn</plw> <pr>(#)</pr></plu>. <ety>[G., lit., free
lord.]</ety> <def>In Germany and Austria, a baron.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Frelte</ent><br/
<hw>Frel"te</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Frailty.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj></p>

<p><ent>Fremed</ent><br/
<ent>Fremd</ent><br/
<mhw>{ <hw>Fremd</hw> <pr>(?)</pr>, <hw>Frem"ed</hw> <pr>(?)</pr>
}</mhw> <pos>a.</pos> <ety>[OE., from AS. <ets>fremede</ets>,
<ets>fremde</ets>; akin to G. <ets>fremd</ets>.]</ety> <def>Strange;
foreign.</def> <mark>[Old Eng. & Scot.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fremescent</ent><br/
<hw>Fre*mes"cent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>fremere</ets> to roar, murmur + <ets>-escent</ets>.]</ety>
<def>Becoming murmurous, roaring.</def> <ldquo/<xex>Fremescent</xex>
clangor.<rdquo/ <au>Carlyle</au>. -- <wordforms><wf>Fre*mes"cence</wf>
<pr>(#)</pr>, <pos>n.</pos></wordforms><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Fremitus</ent><br/
\'d8<hw>Frem"i*tus</hw> <pr>(?)</pr>, <pos>n., sing. & pl.</pos>
<ety>[L., a murmuring, roaring.]</ety> <fld>(Med.)</fld> <def>Palpable
vibration or thrill; <as>as, the rhonchial
<ex>fremitus</ex></as>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Fren</ent><br/
<hw>Fren</hw> <pr>(fr<ecr/n)</pr>, <pos>n.</pos> <ety>[OE.
<ets>frenne</ets>, contr. fr. <ets>forrene</ets> foreign. See
<er>Foreign</er>, <pos>a.</pos>]</ety> <def>A stranger.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>French</ent><br/
<hw>French</hw> <pr>(fr<ecr/nch)</pr>, <pos>prop. a.</pos> <ety>[AS.
<ets>frencisc</ets>, LL. <ets>franciscus</ets>, from L.
<ets>Francus</ets> a Frank: cf. OF. <ets>franceis</ets>,
<ets>franchois</ets>, <ets>fran<cced/ois</ets>, F. fran<cced/ais. See
<er>Frank</er>, <pos>a.</pos>, and cf. <er>Frankish</er>.]</ety> <def>Of
or pertaining to France or its inhabitants.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs> <col><b>French bean</b></col> <fld>(Bot.)</fld>, <cd>the common
kidney bean (<spn>Phaseolus vulgaris</spn>).</cd> -- <col><b>French
berry</b></col> <fld>(Bot.)</fld>, <cd>the berry of a species of
buckthorn (<spn>Rhamnus catharticus</spn>), which affords a saffron,
green or purple pigment.</cd> -- <col><b>French casement</b></col>
<fld>(Arch.)</fld> <cd>See <cref>French window</cref>, under
<er>Window</er>.</cd> -- <col><b>French chalk</b></col>
<fld>(Min.)</fld>, <cd>a variety of granular talc; -- used for drawing
lines on cloth, etc. See under <er>Chalk</er>.</cd> -- <col><b>French
cowslip</b></col> <fld>(Bot.)</fld> <cd>The <spn>Primula Auricula</spn>.
See <er>Bear's-ear</er>.</cd> -- <col><b>French fake</b></col>
<fld>(Naut.)</fld>, <cd>a mode of coiling a rope by running it backward
and forward in parallel bends, so that it may run freely.</cd> --
<col><b>French honeysuckle</b></col> <fld>(Bot.)</fld> <cd>a plant of
the genus <gen>Hedysarum</gen> (<spn>H. coronarium</spn>); -- called
also <altname>garland honeysuckle</altname>.</cd> -- <col><b>French
horn</b></col>, <cd>a metallic wind instrument, consisting of a long
tube twisted into circular folds and gradually expanding from the
mouthpiece to the end at which the sound issues; -- called in France
<altname>cor de chasse</altname>.</cd> -- <col><b>French
leave</b></col>, <cd>an informal, hasty, or secret departure; esp., the
leaving a place without paying one's debts.</cd> -- <col><b>French
pie</b></col> <ety>[<ets>French</ets> (here used in sense of
<ldquo/foreign<rdquo/) + <ets>pie</ets> a magpie (in allusion to its
black and white color)]</ety> <fld>(Zool.)</fld>, <cd>the European great
spotted woodpecker (<spn>Dryobstes major</spn>); -- called also
<altname>wood pie</altname>.</cd> -- <col><b>French polish</b></col>.
<sd>(a)</sd> <cd>A preparation for the surface of woodwork, consisting
of gums dissolved in alcohol, either shellac alone, or shellac with
other gums added.</cd> <sd>(b)</sd> <cd>The glossy surface produced by
the application of the above.</cd> -- <col><b>French purple</b></col>,
<cd>a dyestuff obtained from lichens and used for coloring woolen and
silken fabrics, without the aid of mordants.</cd> <au>Ure.</au> --
<col><b>French red</b></col> <cd>rouge.</cd> -- <col><b>French
rice</b></col>, <cd>amelcorn.</cd> -- <col><b>French roof</b></col>
<fld>(Arch.)</fld>, <cd>a modified form of mansard roof having a nearly
flat deck for the upper slope.</cd> -- <col><b>French tub</b></col>,
<cd>a dyer's mixture of protochloride of tin and logwood; -- called also
<altname>plum tub</altname>.</cd> <au>Ure.</au> -- <col><b>French
window</b></col>. <cd>See under <er>Window</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>French</ent><br/
<hw>French</hw>, <pos>prop. n.</pos> <sn>1.</sn> <def>The language
spoken in France.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Collectively, the people of France.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>french-fried potatoes</ent><br/
<ent>french fries</ent><br/
<hw>french fries</hw> <hw>french-fried potatoes</hw> <pos>n. pl.</pos>
<def>Strips of potatoes, usually cut with a rectangular cross-section,
cooked by immersing in hot fat or oil.</def><br/
[<source>PJC</source>]</p>

<p><ent>french-fry</ent><br/
<hw>french-fry</hw> <pos>v. t.</pos> <def>to cook by immersing in hot
fat.</def><br/
<syn><b>Syn. --</b> deep-fry.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Frenchify</ent><br/
<hw>French"i*fy</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Frenchified</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Frenchifying</conjf>.]</vmorph> <ety>[<ets>French</ets>
+ <ets>-fy</ets>.]</ety> <def>To make French; to infect or imbue with
the manners or tastes of the French; to Gallicize.</def>
<rj><au>Burke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frenchism</ent><br/
<hw>French"ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A French mode or
characteristic; an idiom peculiar to the French language.</def>
<rj><au>Earle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frenchman</ent><br/
<hw>French"man</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Frenchmen</plw> <pr>(<?/)</pr>.</plu> <def>A native or one of the
people of France.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>French-speaking</ent><br/
<hw>French-speaking</hw> <pos>adj.</pos> <def>able to communicate in
French.</def><br/
<syn><b>Syn. --</b> Francophone, Francophonic.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Frenetic</ent><br/
<hw>Fre*net"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Frantic</er>, <pos>a.</pos>]</ety> <def>Distracted; mad; frantic;
phrenetic; frenzied.</def> <rj><au>Milton.</au></rj><br/
<syn><b>Syn. --</b> frenetical.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frenetical</ent><br/
<hw>Fre*net"ic*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Frenetic;
frantic; frenzied.</def> -- <wordforms><wf>Frenet"ic*al*ly</wf>,
<pos>adv.</pos></wordforms><br/
<syn><b>Syn. --</b> frenetic; phrenetic.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frenum</ent><br/
<hw>Fre"num</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it> E.
<plw>Frenums</plw> <pr>(#)</pr>, L. <plw>Frena</plw> <pr>(#)</pr>.</plu>
<ety>[L., a bridle.]</ety> <sn>1.</sn> <fld>(Zool.)</fld> <def>A cheek
stripe of color.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Anat.)</fld> <def>Same as
<er>Fr<ae/num</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frenzical</ent><br/
<hw>Fren"zi*cal</hw> <pr>(fr<ecr/n"z<icr/*k<ait/l)</pr>, <pos>a.</pos>
<def>Frantic.</def> <mark>[Obs.]</mark> <rj><au>Orrery.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frenzied</ent><br/
<hw>Fren"zied</hw> <pr>(fr<ecr/n"z<icr/d)</pr>, <pos>p. p. & a.</pos>
<def>Affected with frenzy; frantic; maddened.</def> --
<wordforms><wf>Fren"zied*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><q>The people <qex>frenzied</qex> by centuries of oppression.</q>
<rj><qau>Buckle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Up starting with a <qex>frenzied</qex> look.</q> <rj><qau>Sir W.
Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frenzy</ent><br/
<hw>Fren"zy</hw> <pr>(fr<ecr/n"z<ycr/)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Frenzies</plw> <pr>(fr<ecr/n"z<icr/z)</pr>.</plu>
<ety>[OE. <ets>frenesie</ets>, <ets>fransey</ets>, F.
<ets>fr<eacute/n<eacute/sie</ets>, L. <ets>phrenesis</ets>, fr. Gr.
<grk>fre`nhsis</grk> for <grk>freni^tis</grk> disease of the mind,
phrenitis, fr. <grk>frhn</grk> mind. Cf. <er>Frantic</er>,
<er>Phrenitis</er>.]</ety> <def>Any violent agitation of the mind
approaching to distraction; violent and temporary derangement of the
mental faculties; madness; rage.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>All else is towering <qex>frenzy</qex> and distraction.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The poet's eye in a fine <qex>frenzy</qex> rolling.</q>
<rj><qau>Shak.</qau></rj></p>

<p><syn><b>Syn.</b> -- Insanity; lunacy; madness; derangement;
alienation; aberration; delirium. See <er>Insanity</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frenzy</ent><br/
<hw>Fren"zy</hw>, <pos>a.</pos> <def>Mad; frantic.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>They thought that some <qex>frenzy</qex> distemper had got into
his head.</q> <rj><qau>Bunyan.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frenzy</ent><br/
<hw>Fren"zy</hw>, <pos>v. t.</pos> <def>To affect with frenzy; to drive
to madness</def> <mark>[R.]</mark> <ldquo/<xex>Frenzying</xex>
anguish.<rdquo/ <rj><au>Southey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>frenzy-free</ent><br/
<hw>frenzy-free</hw> <pos>adj.</pos> <def>having passions unrestrained
by reason.</def><br/
<syn><b>Syn. --</b> frenzied.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Frequence</ent><br/
<hw>Fre"quence</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Frequency</er>.]</ety> <sn>1.</sn> <def>A crowd; a throng; a
concourse.</def> <mark>[Archaic.]</mark> <rj><au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Frequency; abundance.</def> <mark>[R.]</mark>
<rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frequency</ent><br/
<hw>Fre"quen*cy</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Frequencies</plw> <pr>(#)</pr>.</plu> <ety>[L.
<ets>frequentia</ets> numerous attendance, multitude: cf. F.
<ets>fr<eacute/quence</ets>. See <er>Frequent</er>.]</ety> <sn>1.</sn>
<def>The condition of returning frequently; occurrence often repeated;
common occurence; <as>as, the <ex>frequency</ex> of crimes; the
<ex>frequency</ex> of miracles.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>The reasons that moved her to remove were, because Rome was a
place of riot and luxury, her soul being almost stifled with, the
<qex>frequencies</qex> of ladies' visits.</q>
<rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A crowd; a throng.</def> <mark>[Obs.]</mark>
<rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frequent</ent><br/
<hw>Fre"quent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>frequens</ets>, <ets>-entis</ets>, crowded, frequent, akin to
<ets>farcire</ets> to stuff: cf. F. <ets>fr<eacute/quent</ets>. Cf.
<er>Farce</er>, <pos>n.</pos>]</ety> <sn>1.</sn> <def>Often to be met
with; happening at short intervals; often repeated or occurring; <as>as,
<ex>frequent</ex> visits</as>.</def> <ldquo/<xex>Frequent</xex> feudal
towers.<rdquo/ <rj><au>Byron.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Addicted to any course of conduct; inclined to
indulge in any practice; habitual; persistent.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He has been loud and <qex>frequent</qex> in declaring himself
hearty for the government.</q> <rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Full; crowded; thronged.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>'T is C<ae/sar's will to have a <qex>frequent</qex> senate.</q>
<rj><qau>B. Jonson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Often or commonly reported.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>'T is <qex>frequent</qex> in the city he hath subdued<br/
The Catti and the Daci.</q> <rj><qau>Massinger.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frequent</ent><br/
<hw>Fre*quent"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Frequented</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Frequenting</conjf>.]</vmorph> <ety>[L. <ets>frequentare</ets>:
cf. F. <ets>fr<eacute/quenter</ets>. See <er>Frequent</er>,
<pos>a.</pos>]</ety> <sn>1.</sn> <def>To visit often; to resort to often
or habitually; <as>as, to <ex>frequent</ex> a tavern</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He <qex>frequented</qex> the court of Augustus.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To make full; to fill.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>With their sighs the air<br/
<qex>Frequenting</qex>, sent from hearts contrite.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frequentable</ent><br/
<hw>Fre*quent"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Accessible.</def> <mark>[R.]</mark> <rj><au>Sidney.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frequentage</ent><br/
<hw>Fre*quent"age</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The practice or
habit of frequenting.</def> <mark>[R.]</mark>
<rj><au>Southey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frequentation</ent><br/
<hw>Fre"quen*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>frequentatio</ets> a crowding together, <ets>frequency</ets>: cf.
F. <ets>fr<eacute/quentation</ets>.]</ety> <def>The act or habit of
frequenting or visiting often; resort.</def>
<rj><au>Chesterfield.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frequentative</ent><br/
<hw>Fre*quent"a*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>frequentativus</ets>: cf. F. <ets>fr<eacute/quentatif</ets>.]</ety>
<fld>(Gram.)</fld> <def>Serving to express the frequent repetition of an
action; <as>as, a <ex>frequentative</ex> verb</as>.</def> --
<def2><pos>n.</pos> <def>A frequentative verb.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frequenter</ent><br/
<hw>Fre*quent*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
frequents; one who often visits, or resorts to customarily.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frequently</ent><br/
<hw>Fre*quent*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>At frequent or
short intervals; many times; often; repeatedly; commonly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frequentness</ent><br/
<hw>Fre"quent*ness</hw>, <pos>n.</pos> <def>The quality of being
frequent.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frere</ent><br/
\'d8<hw>Fr<egrave/re</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. See
<er>Friar</er>.]</ety> <def>A friar.</def>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frescade</ent><br/
<hw>Fres"cade</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Fresco</er>, <er>Fresh</er>, <pos>a.</pos>]</ety> <def>A cool walk;
shady place.</def> <mark>[R.]</mark> <rj><au>Maunder.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fresco</ent><br/
<hw>Fres"co</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Frescoes</plw> or <plw>Frescos</plw> <pr>(#)</pr>.</plu> <ety>[It.,
fr. <ets>fresco</ets> fresh; of German origin. See <er>Fresh</er>,
<pos>a.</pos>]</ety> <sn>1.</sn> <def>A cool, refreshing state of the
air; duskiness; coolness; shade.</def> <mark>[R.]</mark>
<rj><au>Prior.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Fine Arts)</fld> <sd>(a)</sd> <def>The art of
painting on freshly spread plaster, before it dries.</def> <sd>(b)</sd>
<def>In modern parlance, incorrectly applied to painting on plaster in
any manner.</def> <sd>(c)</sd> <def>A painting on plaster in either of
senses <sd>a</sd> and <sd>b</sd>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>al fresco</b></col> <cd>in the open air; out of doors;
outdoors; <as>as, to dine <ex>al fresco</ex></as>.</cd></cs><br/
[<source>PJC</source>]</p>

<p><ent>Fresco</ent><br/
<hw>Fres"co</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Frescoed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Frescoing</conjf>.]</vmorph> <def>To paint in fresco, as
walls.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fresh</ent><br/
<hw>Fresh</hw> <pr>(fr<ecr/sh)</pr>, <pos>a.</pos>
<amorph>[<pos>Compar.</pos> <adjf>Fresher</adjf>
<pr>(fr<ecr/sh"<etil/r)</pr>; <pos>superl.</pos>
<adjf>Freshest</adjf>.]</amorph> <ety>[OE. <ets>fresch</ets>, AS.
<ets>fersc</ets>; akin to D. <ets>versch</ets>, G. <ets>frisch</ets>,
OHG. <ets>frisc</ets>, Sw. <ets>frisk</ets>, Dan. <ets>frisk</ets>,
<ets>fersk</ets>, Icel. <ets>fr<imac/skr</ets> frisky, brisk,
<ets>ferskr</ets> fresh; cf. It. <ets>fresco</ets>, OF. <ets>fres</ets>,
<ets>freis</ets>, fem. <ets>freske</ets>, <ets>fresche</ets>, F.
<ets>frais</ets>, fem. <ets>fra<icir/che</ets>, which are of German
origin. Cf. <er>Fraischeur</er>, <er>Fresco</er>, <er>Frisk</er>.]</ety>
<sn>1.</sn> <def>Possessed of original life and vigor; new and strong;
unimpaired; sound.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>New; original; additional.</def> <ldquo/Fear of
<xex>fresh</xex> mistakes.<rdquo/ <rj><au>Sir W. Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>fresh</qex> pleasure in every fresh posture of the
limbs.</q> <rj><qau>Landor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Lately produced, gathered, or prepared for market;
not stale; not dried or preserved; not wilted, faded, or tainted; in
good condition; <as>as, <ex>fresh</ex> vegetables, flowers, eggs, meat,
fruit, etc.</as>; recently made or obtained; occurring again; repeated;
<as>as, a <ex>fresh</ex> supply of goods; <ex>fresh</ex> tea, raisins,
etc.</as>; lately come or made public; <as>as, <ex>fresh</ex> news</as>;
recently taken from a well or spring; <as>as, <ex>fresh</ex>
water</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Youthful; florid; <as>as, these <ex>fresh</ex>
nymphs</as>.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>In a raw, green, or untried state; uncultivated;
uncultured; unpracticed; <as>as, a <ex>fresh</ex> hand on a
ship</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Renewed in vigor, alacrity, or readiness for action;
<as>as, <ex>fresh</ex> for a combat</as>; hence, tending to renew in
vigor; rather strong; cool or brisk; <as>as, a <ex>fresh</ex>
wind</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>Not salt; <as>as, <ex>fresh</ex> water, in
distinction from that which is from the sea, or brackish; <ex>fresh</ex>
meat, in distinction from that which is pickled or
salted.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fresh breeze</b></col> <fld>(Naut.)</fld>, <cd>a breeze
between a moderate and a strong breeze; one blowinq about twenty miles
an hour.</cd> -- <col><b>Fresh gale</b></col>, <cd>a gale blowing about
forty-five miles an hour.</cd> -- <col><b>Fresh way</b></col>
<fld>(Naut.)</fld>, <cd>increased speed.</cd></cs></p>

<p><syn><b>Syn.</b> -- Sound; unimpaired; recent; unfaded: ruddy;
florid; sweet; good: inexperienced; unpracticed: unused; lively;
vigorous; strong.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fresh</ent><br/
<hw>Fresh</hw>, <pos>n.</pos>; <plu><it>pl.</it> <plw>Freshes</plw>
<pr>(<?/)</pr>.</plu> <sn>1.</sn> <def>A stream or spring of fresh
water.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He shall drink naught but brine; for I'll not show him<br/
Where the quick <qex>freshes</qex> are.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A flood; a freshet.</def> <mark>[Prov. Eng.]</mark>
<rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The mingling of fresh water with salt in rivers or
bays, as by means of a flood of fresh water flowing toward or into the
sea.</def> <rj><au>Beverly.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fresh</ent><br/
<hw>Fresh</hw>, <pos>v. t.</pos> <def>To refresh; to freshen.</def>
<mark>[Obs.]</mark> <rj><au>Rom. of R.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>fresh-cut</ent><br/
<hw>fresh-cut</hw> <pos>adj.</pos> <def>recently cut; -- of flowers;
<as>as, a <ex>fresh-cut</ex> bouquet</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Freshen</ent><br/
<hw>Fresh"en</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Freshened</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Freshening</conjf> <pr>(?)</pr>]</vmorph> <sn>1.</sn>
<def>To make fresh; to separate, as water, from saline ingredients; to
make less salty; <as>as, to <ex>freshen</ex> water, fish, or
flesh</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To refresh; to revive.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Naut.)</fld> <def>To relieve, as a rope, by change
of place where friction wears it; or to renew, as the material used to
prevent chafing; <as>as, to <ex>freshen</ex> a hawse</as>.</def>
<rj><au> Totten.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To freshen ballast</b></col> <fld>(Naut.)</fld>, <cd>to
shift Or restore it.</cd> -- <col><b>To freshen the hawse</b></col>,
<cd>to pay out a little more cable, so as to bring the chafe on another
part.</cd> -- <col><b>To freshen the way</b></col>, <cd>to increase the
speed of a vessel.</cd> <rj><au>Ham. Nav. Encyc.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Freshen</ent><br/
<hw>Fresh"en</hw> <pr>(?)</pr>, <pos>v. i.</pos> <sn>1.</sn> <def>To
grow fresh; to lose saltness.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To grow brisk or strong; <as>as, the wind
<ex>freshens</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>fresher</ent><br/
<hw>fresher</hw> <pos>n.</pos> <def>a first-year undergraduate.</def>
<mark>[Brit. slang]</mark><br/
<syn><b>Syn. --</b> freshman.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Freshet</ent><br/
<hw>Fresh"et</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>fresche</ets> flood + <ets>-et</ets>. See <er>Fresh</er>,
<pos>a.</pos>]</ety> <sn>1.</sn> <def>A stream of fresh water.</def>
<mark>[Obs.]</mark> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A flood or overflowing of a stream caused by heavy
rains or melted snow; a sudden inundation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Cracked the sky, as ice in rivers<br/
When the <qex>freshet</qex> is at highest.</q>
<rj><qau>Longfellow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Freshly</ent><br/
<hw>Fresh"ly</hw>, <pos>adv.</pos> <def>In a fresh manner; vigorously;
newly, recently; brightly; briskly; coolly; <as>as, <ex>freshly</ex>
gathered; <ex>freshly</ex> painted; the wind blows
<ex>freshly</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Looks he as <xex>freshly</xex> as he did?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Freshman</ent><br/
<hw>Fresh"man</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Freshmen</plw> <pr>(<?/)</pr>.</plu> <def>A novice; one in the
rudiments of knowledge; especially, a student during his first year in a
high school, college, or university.</def><br/
<syn><b>Syn. --</b> frosh.</syn><br/
[<source>1913 Webster</source>]</p>

<p><q>He drank his glass and cracked his joke,<br/
And <qex>freshmen</qex> wondered as he spoke.</q>
<rj><qau>Goldsmith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Freshman class</b></col>, <cd>the lowest of the four
classes in an American college.</cd> <mark>[ U. S.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Freshmanship</ent><br/
<hw>Fresh"man*ship</hw>, <pos>n.</pos> <def>The state of being a
freshman.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Freshment</ent><br/
<hw>Fresh"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Refreshment.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Freshness</ent><br/
<hw>Fresh"ness</hw>, <pos>n.</pos> <def>The state of being
fresh.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The Scots had the advantage both for number and
<qex>freshness</qex><br/
of men.</q> <rj><qau>Hayward.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And breathe the <qex>freshness</qex> of the open air.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Her cheeks their <qex>freshness</qex> lose and wonted grace.</q>
<rj><qau>Granville.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fresh-new</ent><br/
<hw>Fresh"-new`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Unpracticed.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fresh-water</ent><br/
<hw>Fresh"-wa`ter</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Of,
pertaining to, or living in, water which is not salty; <as>as,
<ex>fresh-water</ex> geological deposits; a <ex>fresh-water</ex> fish;
<ex>fresh-water</ex> mussels.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Accustomed to sail on fresh water only; unskilled as
a seaman; <as>as, a <ex>fresh-water</ex> sailor</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Unskilled; raw.</def> <mark>[Colloq.]</mark>
<ldquo/<qex>Fresh-water</qex> soldiers.<rdquo/
<rj><au>Knolles.</au></rj></p>

<p><ent>Fres'nel' lan'tern</ent><br/
<ent>Fresnel lamp</ent><br/
<mhw>{ <hw>Fres`nel" lamp"</hw> <pr>(?)</pr>, <hw>Fres'nel'
lan'tern</hw> <pr>(?)</pr>.}</mhw> <ety>[From <etsep>Fresnel</etsep> the
inventor, a French physicist.]</ety> <def>A lantern having a lamp
surrounded by a hollow cylindrical Fresnel lens.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fresnel lens</ent><br/
<hw>Fres`nel" lens"</hw> <pr>(?)</pr>. <ety>[See <er>Fresnel
lamp</er>.]</ety> <fld>(Optics)</fld> <def>See under
<er>Lens</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>fress</ent><br/
<hw>fress</hw> <pos>v. i.</pos> <ety>[Yiddish, <ets>fresn</ets> fr. G.
<ets>fressen</ets> to eat (used of animals).]</ety> <def>to eat
copiously and without restraint; to snack frequently.</def>
<mark>[slang]</mark> <br/
<syn><b>Syn. --</b> gluttonize.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fret</ent><br/
<hw>Fret</hw> <pr>(fr<ecr/t)</pr>, <pos>n.</pos> <mark>[Obs.]</mark>
<def>See 1st <er>Frith</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fret</ent><br/
<hw>Fret</hw> <pr>(fr<ecr/t)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Fretted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Fretting</conjf>.]</vmorph> <ety>[OE. <ets>freten</ets> to eat,
consume; AS. <ets>fretan</ets>, for <ets>foretan</ets>; pref.
<ets>for-</ets> + <ets>etan</ets> to eat; akin to D. <ets>vreten</ets>,
OHG. <ets>frezzan</ets>, G. <ets>fressen</ets>, Sw.
<ets>fr<aum/ta</ets>, Goth. <ets>fra-itan</ets>. See <er>For</er>, and
<er>Eat</er>, <pos>v. t.</pos>]</ety> <sn>1.</sn> <def>To devour.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The sow <qex>frete</qex> the child right in the cradle.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To rub; to wear away by friction; to chafe; to gall;
hence, to eat away; to gnaw; <as>as, to <ex>fret</ex> cloth; to fret a
piece of gold or other metal; a worm <ex>frets</ex> the plants of a
ship.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>With many a curve my banks I <qex>fret</qex>.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To impair; to wear away; to diminish.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>By starts<br/
His <qex>fretted</qex> fortunes give him hope and fear.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To make rough, agitate, or disturb; to cause to
ripple; <as>as, to <ex>fret</ex> the surface of water</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To tease; to irritate; to vex.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Fret</qex> not thyself because of evil doers.</q>
<rj><qau>Ps. xxxvii. 1.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fret</ent><br/
<hw>Fret</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To be worn away; to
chafe; to fray; <as>as, a wristband <ex>frets</ex> on the
edges</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To eat in; to make way by corrosion.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Many wheals arose, and <qex>fretted</qex> one into another with
great excoriation.</q> <rj><qau>Wiseman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To be agitated; to be in violent commotion; to
rankle; <as>as, rancor <ex>frets</ex> in the malignant
breast</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To be vexed; to be chafed or irritated; to be angry;
to utter peevish expressions.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He <qex>frets</qex>, he fumes, he stares, he stamps the
ground.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fret</ent><br/
<hw>Fret</hw>, <pos>n.</pos> <sn>1.</sn> <def>The agitation of the
surface of a fluid by fermentation or other cause; a rippling on the
surface of water.</def> <rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Agitation of mind marked by complaint and
impatience; disturbance of temper; irritation; <as>as, he keeps his mind
in a continual <ex>fret</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Yet then did Dennis rave in furious <qex>fret</qex>.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Herpes; tetter.</def>
<rj><au>Dunglison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <pluf>pl.</pluf> <fld>(Mining)</fld> <def>The worn sides
of river banks, where ores, or stones containing them, accumulate by
being washed down from the hills, and thus indicate to the miners the
locality of the veins.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fret</ent><br/
<hw>Fret</hw>, <pos>v. t.</pos> <ety>[OE. <ets>fretten</ets> to adorn,
AS. <ets>fr<ae/twan</ets>, <ets>fr<ae/twian</ets>; akin to OS.
<ets>fratah<omac/n</ets>, cf. Goth. <ets>us-fratwjan</ets> to make wise,
also AS. <ets>fr<ae/twe</ets> ornaments, OS. <ets>fratah<imac/</ets>
adornment.]</ety> <def>To ornament with raised work; to variegate; to
diversify.</def><br/
[<source>1913 Webster</source>]</p>

<p><q> Whose skirt with gold was <qex>fretted</qex> all about.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Yon gray lines,<br/
That <qex>fret</qex> the clouds, are messengers of day.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fret</ent><br/
<hw>Fret</hw>, <pos>n.</pos> <sn>1.</sn> <def>Ornamental work in relief,
as carving or embossing. See <er>Fretwork</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Arch.)</fld> <def>An ornament consisting of small
fillets or slats intersecting each other or bent at right angles, as in
classical designs, or at oblique angles, as often in Oriental
art.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His lady's cabinet is a adorned on the <qex>fret</qex>, ceiling,
and chimney-piece with . . . carving.</q>
<rj><qau>Evelyn.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 596 --></p>

<p><sn>3.</sn> <def>The reticulated headdress or net, made of gold or
silver wire, in which ladies in the Middle Ages confined their
hair.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>fret</qex> of gold she had next her hair.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fret saw</b></col>, <cd>a saw with a long, narrow blade,
used in cutting frets, scrolls, etc.; a scroll saw; a keyhole saw; a
compass saw.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fret</ent><br/
<hw>Fret</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>frette</ets> a
saltire, also a hoop, ferrule, prob. a dim. of L. <ets>ferrum</ets>
iron. For sense 2, cf. also E. <ets>fret</ets> to rub.]</ety>
<sn>1.</sn> <fld>(Her.)</fld> <def>A saltire interlaced with a
mascle.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mus.)</fld> <def>A short piece of wire, or other
material fixed across the finger board of a guitar or a similar
instrument, to indicate where the finger is to be placed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fret</ent><br/
<hw>Fret</hw>, <pos>v. t.</pos> <def>To furnish with frets, as an
instrument of music.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fretful</ent><br/
<hw>Fret"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See 2d
<er>Fret</er>.]</ety> <def>Disposed to fret; ill-humored; peevish;
angry; in a state of vexation; <as>as, a <ex>fretful</ex>
temper</as>.</def> -- <wordforms><wf>Fret"ful*ly</wf>, <pos>adv.</pos>
-- <wf>Fret"ful*ness</wf>, <pos>n.</pos></wordforms></p>

<p><syn><b>Syn.</b> -- Peevish; ill-humored; ill-natured; irritable;
waspish; captious; petulant; splenetic; spleeny; passionate;
angry.</syn> -- <usage><er>Fretful</er>, <er>Peevish</er>,
<er>Cross</er>. These words all indicate an unamiable working and
expression of temper. <xex>Peevish</xex> marks more especially the
inward spirit: a <xex>peevish</xex> man is always ready to find fault.
<xex>Fretful</xex> points rather to the outward act, and marks a
complaining impatience: sickly children are apt to be
<xex>fretful</xex>. <xex>Crossness</xex> is peevishness mingled with
vexation or anger.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>fretsaw</ent><br/
<hw>fretsaw</hw> <pos>n.</pos> <def>A narrow-bladed fine-toothed saw for
cutting curved outlines.</def><br/
<syn><b>Syn. --</b> jigsaw, scroll saw.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Frett</ent><br/
<hw>Frett</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See 2d
<er>Fret</er>.]</ety> <fld>(Mining)</fld> <def>The worn side of the bank
of a river. See 4th <er>Fret</er>, <pos>n.</pos>, 4.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frett</ent><br/
<hw>Frett</hw>, <pos>n.</pos> <ety>[See <er>Frit</er>.]</ety> <def>A
vitreous compound, used by potters in glazing, consisting of lime,
silica, borax, lead, and soda.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fretted</ent><br/
<hw>Fret"ted</hw> <pr>(?)</pr>, <pos>p. p. & a.</pos> <ety>[From 2d
<er>Fret</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Rubbed or worn away; chafed.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Agitated; vexed; worried.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fretted</ent><br/
<hw>Fret"ted</hw>, <pos>p. p. & a.</pos> <ety>[See 5th
<er>Fret</er>.]</ety> <sn>1.</sn> <def>Ornamented with fretwork;
furnished with frets; variegated; made rough on the surface.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Her.)</fld> <def>Interlaced one with another; --
said of charges and ordinaries.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fretten</ent><br/
<hw>Fret"ten</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[The old p. p. of
fret to rub.]</ety> <def>Rubbed; marked; <as>as, pock-<ex>fretten</ex>,
marked with the smallpox</as>.</def> <mark>[Obs.]</mark>
<rj><au>Wright.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fretter</ent><br/
<hw>Fret"ter</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, frets.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fretty</ent><br/
<hw>Fret"ty</hw>, <pos>a.</pos> <ety>[See 5th <er>Fret</er>.]</ety>
<def>Adorned with fretwork.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fretum</ent><br/
\'d8<hw>Fre"tum</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Freta</plw> <pr>(#)</pr>.</plu> <ety>[L.]</ety> <def>A strait, or
arm of the sea.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fretwork</ent><br/
<hw>Fret"work</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[6th <ets>fret +
work</ets>.]</ety> <def>Work adorned with frets; ornamental openwork or
work in relief, esp. when elaborate and minute in its parts. Hence, any
minute play of light and shade, dark and light, or the like.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Banqueting on the turf in the <qex>fretwork</qex> of shade and
sunshine.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Freud</ent><br/
<hw>Freud</hw> <pos>prop. n.</pos> <def><person>Sigmund Freud</person>,
the founder of the practise of psychoanalysis. Born 1856, died
1939.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Freudian</ent><br/
<hw>Freudian</hw> <pos>prop. a.</pos> <def>of or pertaining to Sigmund
<etsep>Freud</etsep>; <as>as, <ex>Freudian</ex> theories</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Freyr</ent><br/
<ent>Frey</ent><br/
<mhw><hw>Frey</hw>, <hw>Freyr</hw></mhw> <pr>(fr<imac/)</pr>, <pos>prop.
n.</pos> <fld>(Norse Mythology)</fld> <def>The god of earth's fertility
and peace and prosperity, presiding over rain, sunshine, and all the
fruits of the earth, dispensing wealth among men; son of Njorth (Njord)
and brother of Freya; originally of the Vanir; later with the Aesir. He
was especially worshipped in the temple at Upsala in Sweden</def><br/
[<source>WordNet 1.5</source> + <source>Century Dict. 1906</source>]</p>

<p><ent>Freya</ent><br/
<hw>Frey"a</hw> <pr>(fr<imac/"<adot/)</pr>, <pos>prop. n.</pos>
<ety>[Icel. <ets>Freyja</ets>.]</ety> <fld>(Scand. Myth.)</fld> <def>The
daughter of Nj<oum/rd, and goddess of love and beauty; the Scandinavian
Venus; -- in Teutonic myths confounded with Frigga, but in Scandinavian,
distinct.</def> <altsp>[Written also <asp>Frea</asp>, <asp>Freyia</asp>,
and <asp>Freyja</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Friabiiity</ent><br/
<hw>Fri"a*bii"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>friabilit<eacute/</ets>.]</ety> <def>The quality of being friable;
friableness.</def> <rj><au>Locke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Friable</ent><br/
<hw>Fri"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>friabilis</ets>, fr. <ets>friare</ets> to rub, break, or crumble
into small pieces, cf. <ets>fricare</ets> to rub, E. <ets>fray</ets>:
cf. F. <ets>friable</ets>.]</ety> <def>Easily crumbled, pulverized, or
reduced to powder.</def> <ldquo/<xex>Friable</xex> ground.<rdquo/
<au>Evelyn.</au> <ldquo/Soft and <xex>friable</xex> texture.<rdquo/
<au>Paley.</au> -- <wordforms><wf>Fri'a*ble*ness</wf>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Friar</ent><br/
<hw>Fri"ar</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OR. <ets>frere</ets>,
F. <ets>fr<egrave/re</ets> brother, <ets>friar</ets>, fr. L.
<ets>frater</ets> brother. See <er>Brother</er>.]</ety> <sn>1.</sn>
<fld>(R. C. Ch.)</fld> <def>A brother or member of any religious order,
but especially of one of the four mendicant orders, viz: <stype>(a)
Minors, Gray Friars, or Franciscans.</stype> <stype>(b)
Augustines</stype>. <stype>(c) Dominicans or Black Friars.</stype>
<stype>(d) White Friars or Carmelites.</stype> See these names in the
Vocabulary.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Print.)</fld> <def>A white or pale patch on a
printed page.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <def>An American fish; the
silversides.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Friar bird</b></col> <fld>(Zool.)</fld>, <cd>an
Australian bird (<spn>Tropidorhynchus corniculatus</spn>), having the
head destitute of feathers; -- called also <altname>coldong</altname>,
<altname>leatherhead</altname>, <altname>pimlico</altname>;
<altname>poor soldier</altname>, and
<altname>four-o'clock</altname>.</cd> The name is also applied to
several other species of the same genus. -- <col><b>Friar's
balsam</b></col> <fld>(Med.)</fld>, <cd>a stimulating application for
wounds and ulcers, being an alcoholic solution of benzoin, styrax, tolu
balsam, and aloes; compound tincture of benzoin.</cd> <au>Brande &
C.</au> -- <col><b>Friar's cap</b></col> <fld>(Bot.)</fld>, <cd>the
monkshood.</cd> -- <col><b>Friar's cowl</b></col> <fld>(Bot.)</fld>,
<cd>an arumlike plant (<spn>Arisarum vulgare</spn>) with a spathe or
involucral leaf resembling a cowl.</cd> -- <col><b>Friar's
lantern</b></col>, <cd>the ignis fatuus or Will-o'-the-wisp.</cd>
<au>Milton.</au> -- <col><b>Friar skate</b></col> <fld>(Zool.)</fld>,
<cd>the European white or sharpnosed skate (<spn>Raia alba</spn>); --
called also <altname>Burton skate</altname>, <altname>border
ray</altname>, <altname>scad</altname>, and
<altname>doctor</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Friarly</ent><br/
<hw>Fri"ar*ly</hw>, <pos>a.</pos> <def>Like a friar;
inexperienced.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>friar's-cowls</ent><br/
<ent>friar's-cowl</ent><br/
<mhw><hw>friar's-cowl</hw>, <hw>friar's-cowls</hw></mhw> <pos>n.</pos>
<fld>(Bot.)</fld> <def>A tuberous perennial (<spn>Arisarum
vulgare</spn>) having a cowl-shaped maroon or violet-black spathe; --
found in the Mediterranean, Canaries, and Azores.</def><br/
<syn><b>Syn. --</b> friars' cowl, <spn>Arisarum vulgare</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Friary</ent><br/
<hw>Fri"ar*y</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From <er>Friar</er>,
<pos>n.</pos>]</ety> <def>Like a friar; pertaining to friars or to a
convent.</def> <mark>[Obs.]</mark> <rj><au>Camden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Friary</ent><br/
<hw>Fri"ar*y</hw>, <pos>n.</pos> <ety>[OF. <ets>frerie</ets>,
<ets>frairie</ets>, fr. <ets>fr<egrave/re</ets>. See
<er>Friar</er>.]</ety> <sn>1.</sn> <def>A monastery; a convent of
friars.</def> <rj><au>Drugdale.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The institution or practices of friars.</def>
<rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Friation</ent><br/
<hw>Fri*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Friable</er>.]</ety> <def>The act of breaking up or
pulverizing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fribble</ent><br/
<hw>Frib"ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>frivole</ets>, L. <ets>frivolus</ets>, or E.
<ets>frippery</ets>.]</ety> <def>Frivolous; trifling; silly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fribble</ent><br/
<hw>Frib"ble</hw>, <pos>n.</pos> <def>A frivolous, contemptible fellow;
a fop.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A pert <qex>fribble</qex> of a peer.</q>
<rj><qau>Thackeray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fribble</ent><br/
<hw>Frib"ble</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To act in a
trifling or foolish manner; to act frivolously.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The fools that are <qex>fribbling</qex> round about you.</q>
<rj><qau>Thackeray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To totter.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fribbler</ent><br/
<hw>Frib"bler</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A trifler; a
fribble.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fribbling</ent><br/
<hw>Frib"bling</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Frivolous; trining;
toolishly captious.</def></p>

<p><ent>Friborgh</ent><br/
<ent>Friborg</ent><br/
<mhw>{ <hw>Fri"borg</hw> , <hw>Fri"borgh</hw> }</mhw> <pr>(?)</pr>,
<pos>n.</pos> <ety>[AS. <ets>fri<edh/borh</ets>, lit., peace pledge;
<ets>fri<edh/</ets> peace + <ets>borh</ets>, <ets>borg</ets>, pledge,
akin to E. <ets>borrow</ets>. The first part of the word was confused
with <ets>free</ets>, the last part, with borough.]</ety> <fld>(Old Eng.
Law)</fld> <def>The pledge and tithing, afterwards called by the Normans
<altname>frankpledge</altname>. See <er>Frankpledge</er>.</def>
<altsp>[Written also <asp>friburgh</asp> and
<asp>fribourg</asp>.]</altsp> <rj><au>Burril.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fricace</ent><br/
<hw>Fric"ace</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Fricassee</er>.]</ety> <sn>1.</sn> <def>Meat sliced and dressed with
strong sauce.</def> <mark>[Obs.]</mark> <rj><au>King.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An unguent; also, the act of rubbing with the
unguent.</def></p>

<p><ent>Fricando</ent><br/
<ent>Fricandeau</ent><br/
<mhw>\'d8<hw>Fri`can`deau"</hw> <pr>(?)</pr>, \'d8<hw>Fric`an*do"</hw>
<pr>(<?/)</pr></mhw>, <pos>n.</pos> <ety>[F. <ets>fricandeau</ets>; cf.
Sp. <ets>fricand<oacute/</ets>.]</ety> <fld>(Cookery)</fld> <def>A
ragout or fricassee of veal; a fancy dish of veal or of boned turkey,
served as an <it>entr<eacute/e</it>, -- called also
<altname>fricandel</altname>.</def> <rj><au>A. J. Cooley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fricassee</ent><br/
<hw>Fric"as*see`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>fricass<eacute/e</ets>, fr. <ets>fricasser</ets> to <ets>fry</ets>,
<ets>fricassee</ets>; cf. LL. <ets>fricare</ets>, perh. for
<ets>frictare</ets>, <ets>fricare</ets>, <ets>frictum</ets>, to rub. Cf.
<er>Fry</er>, <er>Friction</er>.]</ety> <fld>(Cookery)</fld> <def>A dish
made of fowls, veal, or other meat of small animals cut into pieces, and
stewed in a gravy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fricassee</ent><br/
<hw>Fric"as*see`</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Fricasseed</conjf> <pr>(?)</pr>; <pos>p. pr. &. vb. n.</pos>
<conjf>Fricasseeing</conjf>.]</vmorph> <def>To dress like a
fricassee.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frication</ent><br/
<hw>Fri*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>fricatio</ets>, fr. <ets>fricare</ets>, <ets>fricatum</ets>, to
rub. ]</ety> <def>Friction.</def> <mark>[Obs.]</mark>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fricative</ent><br/
<hw>Fric"a*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Frication</er>.]</ety> <fld>(Phon.)</fld> <def>Produced by the
friction or rustling of the breath, intonated or unintonated, through a
narrow opening between two of the mouth organs; uttered through a close
approach, but not with a complete closure, of the organs of
articulation, and hence capable of being continued or prolonged; -- said
of certain consonantal sounds, as <xex>f</xex>, <xex>v</xex>,
<xex>s</xex>, <xex>z</xex>, etc.</def> -- <def2><pos>n.</pos> <def>A
fricative consonant letter or sound. See <xex>Guide to
Pronunciation</xex>, <sect/<sect/ 197-206, etc.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fricatrice</ent><br/
<hw>Fric"a*trice</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. L.
<ets>frictrix</ets>, fr. <ets>fricare</ets> to rub.]</ety> <def>A lewd
woman; a harlot.</def> <mark>[Obs.]</mark> <rj><au>B.
Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frickle</ent><br/
<hw>Fric"kle</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A bushel
basket.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Friction</ent><br/
<hw>Fric"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>frictio</ets>, fr. <ets>fricare</ets>, <ets>frictum</ets>,to rub:
cf. F. <ets>friction</ets>. See <er>Fray</er> to rub, arid cf.
<er>Dentifrice</er>.]</ety> <sn>1.</sn> <def>The act of rubbing the
surface of one body against that of another; attrition; in hygiene, the
act of rubbing the body with the hand, with flannel, or with a brush
etc., to excite the skin to healthy action.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mech.)</fld> <def>The resistance which a body meets
with from the surface on which it moves. It may be resistance to sliding
motion, or to rolling motion.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A clashing between two persons or parties in
opinions or work; a disagreement tending to prevent or retard
progress.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Angle of friction</b></col> <fld>(Mech.)</fld>, <cd>the
angle which a plane onwhich a body is lying makes with a horizontal
plane,when the hody is just ready to slide dewn the plane.</cd>
<note>This angle varies for different bodies, and for planes of
different materials.</note> -- <col><b>Anti-friction wheels</b></col>
<fld>(Mach.)</fld>, <cd>wheels turning freely on small pivots, and
sustaining, at the angle formed by their circumferences, the pivot or
journal of a revolving shaft, to relieve it of friction; -- called also
<altname>friction wheels</altname>.</cd> -- <col><b>Friction
balls</b></col>, or <col><b>Friction rollers</b></col>, <cd>balls or
rollers placed so as to receive the pressure or weight of bodies in
motion, and relieve friction, as in the hub of a bicycle wheel.</cd> --
<col><b>Friction brake</b></col> <fld>(Mach.)</fld>, <cd>a form of
dynamometer for measuring the power a motor exerts. A clamp around the
revolving shaft or fly wheel of the motor resists the motion by its
friction, the work thus absorbed being ascertained by observing the
force required to keep the clamp from revolving with the shaft; a Prony
brake.</cd> -- <col><b>Friction chocks</b></col>, <cd>brakes attached to
the common standing garrison carriages of guns, so as to raise the
trucks or wheels off the platform when the gun begins to recoil, and
prevent its running back.</cd> <au>Earrow.</au> --
<mcol><col><b>Friction clutch</b></col>, <col><b>Friction
coupling</b></col></mcol>, <cd>an engaging and disengaging gear for
revolving shafts, pulleys, etc., acting by friction</cd>; esp.:
<sd>(a)</sd> <cd>A device in which a piece on one shaft or pulley is so
forcibly pressed against a piece on another shaft that the two will
revolve together; as, in the illustration, the cone <it>a</it> on one
shaft, when thrust forcibly into the corresponding hollow cone
<it>b</it> on the other shaft, compels the shafts to rotate together, by
the hold the friction of the conical surfaces gives.</cd> <sd>(b)</sd>
<cd>A toothed clutch, one member of which, instead of being made fast on
its shaft, is held by friction and can turn, by slipping, under
excessive strain or in starting.</cd> -- <col><b>Friction drop
hammer</b></col>, <cd>one in which the hammer is raised for striking by
the friction of revolving rollers which nip the hammer rod.</cd> --
<col><b>Friction gear</b></col>. <cd>See <cref>Frictional
gearing</cref>, under <er>Frictional</er>.</cd> -- <col><b>Friction
machine</b></col>, <cd>an electrical machine, generating electricity by
friction.</cd> -- <col><b>Friction meter</b></col>, <cd>an instrument
for measuring friction, as in testing lubricants.</cd> --
<mcol><col><b>Friction powder</b></col>, <col><b>Friction
composition</b></col></mcol>, <cd>a composition of chlorate of
potassium, antimony, sulphide, etc, which readily ignites by
friction.</cd> -- <mcol><col><b>Friction primer</b></col>,
<col><b>Friction tube</b></col></mcol>, <cd>a tube used for firing
cannon by means of the friction of a roughened wire in the friction
powder or composition with which the tube is filled.</cd> --
<col><b>Friction wheel</b></col> <fld>(Mach.)</fld>, <cd>one of the
wheels in frictional gearing. See under
<er>Frictional</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frictional</ent><br/
<hw>Fric"tion*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Relating to
friction; moved by friction; produced by friction; <as>as,
<ex>frictional</ex> electricity</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Frictional gearing</b></col>, <cd>wheels which transmit
motion by surface friction instead of teeth. The faces are sometimes
made more or less V-shaped to increase or decrease friction, as
required.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frictionless</ent><br/
<hw>Fric"tion*less</hw>, <pos>a.</pos> <def>Having no
friction.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Friday</ent><br/
<hw>Fri"day</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS.
<ets>friged<ae/g</ets>, fr. <ets>Frigu</ets>, the gooddes of marriage;
<ets>friqu</ets> love + <ets>d<ae/g</ets> day; cf. Icel.
<ets>Frigg</ets> name of a goddess, the wife of Odin or Wodan, OHG.
<ets>Fr<imac/atag</ets>, Icel. <ets>Frj<amac/dagr</ets>. AS.
<ets>frigu</ets> is prob. from the root of E. <ets>friend</ets>,
<ets>free</ets>. See <er>Free</er>, and <er>Day</er>.]</ety> <def>The
sixth day of the week, following Thursday and preceding
Saturday.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fridge</ent><br/
<hw>Fridge</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[AS.
<ets>frician</ets> to dance, from <ets>free</ets> bold. Cf.
<er>Freak</er>, <pos>n.</pos>]</ety> <def>To rub; to fray.</def>
<mark>[Obs.]</mark> <rj><au>Sterne.</au></rj></p>

<p><ent>Frithstool</ent><br/
<ent>Fridstol</ent><br/
<mhw>{ <hw>Frid"stol`</hw> <pr>(fr<icr/d"st<omac/l`)</pr>,
<hw>Frith`stool"</hw> <pr>(fr<icr/th"st<oomac/l`)</pr> }</mhw>,
<pos>n.</pos> <ety>[AS. <ets>fri<edh/st<omac/</ets>l. See <er>Fred</er>,
and <er>Stool</er>.]</ety> <def>A seat in churches near the altar, to
which offenders formerly fled for sanctuary.</def> <altsp>[Written
variously <asp>fridstool</asp>, <asp>freedstool</asp>, etc.]</altsp>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fried</ent><br/
<hw>Fried</hw> <pr>(fr<imac/d)</pr>, <def><pos>imp. & p. p.</pos> of
<er>Fry</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>friedcake</ent><br/
<hw>fried"cake</hw> <pos>n.</pos> <def>A small cake fried in deep
fat.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Friend</ent><br/
<hw>Friend</hw> <pr>(fr<ecr/nd)</pr>, <pos>n.</pos> <ety>[OE.
<ets>frend</ets>, <ets>freond</ets>, AS. <ets>fre<oacute/nd</ets>, prop.
p. pr. of <ets>fre<oacute/n</ets>, <ets>fre<oacute/gan</ets>, to love;
akin to D. <ets>vriend</ets> friend, OS. <ets>friund</ets> friend,
<ets>friohan</ets> to love, OHG. <ets>friunt</ets> friend, G.
<ets>freund</ets>, Icel. <ets>fr<ae/ndi</ets> kinsman, Sw.
<ets>fr<aum/nde</ets>. Goth. <ets>frij<omac/nds</ets> friend,
<ets>frij<omac/n</ets> to love. <root/83. See <er>Free</er>, and cf.
<er>Fiend</er>.]</ety> <sn>1.</sn> <def>One who entertains for another
such sentiments of esteem, respect, and affection that he seeks his
society and welfare; a wellwisher; an intimate associate; sometimes, an
attendant.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Want gives to know the flatterer from the <qex>friend</qex>.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>friend</qex> that sticketh closer than a brother.</q>
<rj><qau>Prov. xviii. 24.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One not inimical or hostile; one not a foe or enemy;
also, one of the same nation, party, kin, etc., whose friendly feelings
may be assumed. The word is some times used as a term of friendly
address.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Friend</qex>, how camest thou in hither?</q> <rj><qau>Matt.
xxii. 12.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>One who looks propitiously on a cause, an
institution, a project, and the like; a favorer; a promoter; <as>as, a
<ex>friend</ex> to commerce, to poetry, to an
institution</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>One of a religious sect characterized by disuse of
outward rites and an ordained ministry, by simplicity of dress and
speech, and esp. by opposition to war and a desire to live at peace with
all men. They are popularly called Quakers.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>America was first visited by <qex>Friends</qex> in 1656.</q>
<rj><qau>T. Chase.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A paramour of either sex.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>A friend at court</b></col> <it>or</it> <col><b>A
friend in court</b></col></mcol>, <cd>one disposed to act as a friend in
a place of special opportunity or influence.</cd> -- <col><b>To be
friends with</b></col>, <cd>to have friendly relations with.</cd>
<ldquo/He's . . . <xex>friends with</xex> C<ae/sar.<rdquo/
<au>Shak.</au> -- <col><b>To make friends with</b></col>, <cd>to become
reconciled to or on friendly terms with.</cd> <ldquo/Having now
<xex>made friends with</xex> the Athenians.<rdquo/ <au>Jowett
(Thucyd.).</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Friend</ent><br/
<hw>Friend</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Friended</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Friending</conjf>.]</vmorph> <def>To act as the friend of; to
favor; to countenance; to befriend.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Fortune <qex>friends</qex> the bold.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Friended</ent><br/
<hw>Friend"ed</hw>, <pos>a.</pos> <sn>1.</sn> <def>Having friends;</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Inclined to love; well-disposed.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Friending</ent><br/
<hw>Friend"ing</hw>, <pos>n.</pos> <def>Friendliness.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Friendless</ent><br/
<hw>Friend"less</hw>, <pos>a.</pos> <ety>[AS.
<ets>fre<oacute/ndle<aacute/s</ets>.]</ety> <def>Destitute of friends;
forsaken.</def> -- <wordforms><wf>Friend"less*ness</wf>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Friendlily</ent><br/
<hw>Friend"li*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a friendly
manner.</def> <rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Friendliness</ent><br/
<hw>Friend"li*ness</hw>, <pos>n.</pos> <def>The condition or quality of
being friendly.</def> <rj><au>Sir P. Sidney.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Friendly</ent><br/
<hw>Friend"ly</hw>, <pos>a.</pos> <ety>[AS.
<ets>fre<eacute/ndl<imac/ce</ets>.]</ety> <sn>1.</sn> <def>Having the
temper and disposition of a friend; disposed to promote the good of
another; kind; favorable.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Appropriate to, or implying, friendship; befitting
friends; amicable.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In <qex>friendly</qex> relations with his moderate opponents.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Not hostile; <as>as, a <ex>friendly</ex> power or
state</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Promoting the good of any person; favorable;
propitious; serviceable; <as>as, a <ex>friendly</ex> breeze or
gale</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>On the first <qex>friendly</qex> bank he throws him down.</q>
<rj><qau>Addison.</qau></rj></p>

<p><syn><b>Syn.</b> -- Amicable; kind; conciliatory; propitious;
favorable. See <er>Amicable</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Friendly</ent><br/
<hw>Friend"ly</hw>, <pos>adv.</pos> <def>In the manner of friends;
amicably; like friends.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>In whom all graces that can perfect beauty<br/
Are <qex>friendly</qex> met.</q> <rj><qau>Beau. & Fl.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Friendly</ent><br/
<hw>Friend"ly</hw>, <pos>n.</pos> <sn>1.</sn> <def>A friendly person; --
usually applied to natives friendly to foreign settlers or
invaders.</def></p>

<p><q>These were speedily routed by the <qex>friendlies</qex>, who
attacked the small force before them in fine style.</q> <rj><qau>E. N.
Bennett.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <fld>(Mil.)</fld> <def>A member of one's own military
forces, or of allied forces.</def><br/
[<source>PJC</source>]</p>

<p><ent>friendly fire</ent><br/
<hw>friend"ly fire`</hw>, <pos>n.</pos> <fld>(Mil.)</fld> <def>Weapons
fire{9}, such as artillery or aerial bombardment, from one's own forces;
-- used mostly when troops do damage or cause casualties among their own
forces; <as>as, the tank was hit by <ex>friendly
fire</ex></as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Friendship</ent><br/
<hw>Friend"ship</hw>, <pos>n.</pos> <ety>[AS.
<ets>fre<oacute/ndscipe</ets>. See <er>Friend</er>, and
<er>-ship</er>.]</ety> <sn>1.</sn> <def>The state of being friends;
friendly relation, or attachment, to a person, or between persons;
affection arising from mutual esteem and good will; friendliness; amity;
good will.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There is little <qex>friendship</qex> in the world.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>There can be no <qex>friendship</qex> without confidence, and no
confidence without integrity.</q> <rj><qau>Rambler.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Preferred by <qex>friendship</qex>, and not chosen by
sufficiency.</q> <rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Kindly aid; help; assistance,</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Some <qex>friendship</qex> will it [a hovel] lend you gainst the
tempest.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Aptness to unite; conformity; affinity; harmony;
correspondence.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Those colors . . . have a <qex>friendship</qex> with each
other.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frier</ent><br/
<hw>Fri"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who
fries.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>same as <er>fryer</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Friese</ent><br/
<hw>Friese</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Friesic</er>, <pos>n.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Friesic</ent><br/
<hw>Fries"ic</hw> <pr>(?)</pr>, <pos>prop. a.</pos> <def>Of or
pertaining to Friesland, a province in the northern part of the
Netherlands.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Friesic</ent><br/
<hw>Fries"ic</hw>, <pos>prop. n.</pos> <def>The language of the
Frisians, a Teutonic people formerly occupying a large part of the coast
of Holland and Northwestern Germany. The modern dialects of Friesic are
spoken chiefly in the province of Friesland, and on some of the islands
near the coast of Germany and Denmark.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Friesish</ent><br/
<hw>Fries"ish</hw>, <pos>a.</pos> <def>Friesic.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frieze</ent><br/
<hw>Frieze</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Perh. the same word as
frieze a, kind of cloth. Cf. <er>Friz</er>.]</ety> <fld>(Arch.)</fld>
<sd>(a)</sd> <def>That part of the entablature of an order which is
between the architrave and cornice. It is a flat member or face, either
uniform or broken by triglyphs, and often enriched with figures and
other ornaments of sculpture.</def> <sd>(b)</sd> <def>Any sculptured or
richly ornamented band in a building or, by extension, in rich pieces of
furniture. See <xex>Illust.</xex> of <er>Column</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Cornice or <qex>frieze</qex> with bossy sculptures graven.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frieze</ent><br/
<hw>Frieze</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>frise</ets>,
perh. originally a woolen cloth or stuff from <ets>Friesland</ets> (F.
<ets>Frise</ets>); cf. LL. <ets>frisii panni</ets> and <ets>frissatus
pannus</ets>, a shaggy woolen cloth, F. <ets>friser</ets> to friz, curl.
Cf. <er>Friz</er>.]</ety> <def>A kind of coarse woolen cloth or stuff
with a shaggy or tufted (friezed) nap on one side.</def> <ldquo/Robes of
<xex>frieze</xex>.<rdquo/ <rj><au>Goldsmith.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frieze</ent><br/
<hw>Frieze</hw>, <pos>v. t.</pos> <def>To make a nap on (cloth); to
friz. See <er>Friz</er>, <pos>v. t.</pos>, 2.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Friezing machine</b></col>, <cd>a machine for friezing
cloth; a friezing machine.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 597 --></p>

<p><ent>Friezed</ent><br/
<hw>Friezed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Gathered, or having
the map gathered, into little tufts, knots, or protuberances. Cf.
<er>Frieze</er>, <pos>v. t.</pos>, and <er>Friz</er>, <pos>v. t.</pos>,
2.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Friezer</ent><br/
<hw>Frie"zer</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, friezes or frizzes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frigate</ent><br/
<hw>Frig"ate</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>fr<eacute/gate</ets>, It. <ets>fregata</ets>, prob. contracted fr.
L. <ets>fabricata</ets> something constructed or built. See
<er>Fabricate</er>.]</ety> <sn>1.</sn> <def>Originally, a vessel of the
Mediterranean propelled by sails and by oars. The French, about 1650,
transferred the name to larger vessels, and by 1750 it had been
appropriated for a class of war vessels intermediate between corvettes
and ships of the line. Frigates, from about 1750 to 1850, had one full
battery deck and, often, a spar deck with a lighter battery. They
carried sometimes as many as fifty guns. After the application of steam
to navigation <xex>steam frigates</xex> of largely increased size and
power were built, and formed the main part of the navies of the world
till about 1870, when the introduction of ironclads superseded
them.</def> <altsp>[Formerly spelled <asp>frigat</asp> and
<asp>friggot</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Any small vessel on the water.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Frigate bird</b></col> <fld>(Zool.)</fld>, <cd>a
web-footed rapacious bird, of the genus <gen>Fregata</gen>; -- called
also <altname>man-of-war bird</altname>, and <altname>frigate
pelican</altname>. Two species are known; that of the Southern United
States and West Indies is <spn>F. aquila</spn>. They are remarkable for
their long wings and powerful flight. Their food consists of fish which
they obtain by robbing gulls, terns, and other birds, of their prey.
They are related to the pelicans.</cd> -- <col><b>Frigate
mackerel</b></col> <fld>(Zool.)</fld>, <cd>an oceanic fish (<spn>Auxis
Rochei</spn>) of little or no value as food, often very abundant off the
coast of the United States.</cd> -- <col><b>Frigate pelican</b></col>.
<fld>(Zool.)</fld> <cd>Same as <er>Frigate bird</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frigate-built</ent><br/
<hw>Frig"ate-built"</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Naut.)</fld>
<def>Built like a frigate with a raised quarter-deck and
forecastle.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frigatoon</ent><br/
<hw>Frig"a*toon`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[It.
<ets>fregatone</ets>: cf. F.<ets>fr<eacute/gaton</ets>. See
<er>Frigate</er>.]</ety> <fld>(Naut.)</fld> <def>A Venetian vessel, with
a square stern, having only a mainmast, jigger mast, and bowsprit; also
a sloop of war ship-rigged.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frigefaction</ent><br/
<hw>Frig"e*fac`tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>frigere</ets> to be cold + <ets>facere</ets> to make.]</ety>
<def>The act of making cold. <mark>[Obs.]</mark> </def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frigefactive</ent><br/
<hw>Frig"e*fac`tive</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Cooling.</def>
<mark>[Obs.]</mark> <rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frigerate</ent><br/
<hw>Frig"er*ate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>frigerare</ets>, fr. <ets>frigus</ets> cold.]</ety> <def>To make
cool.</def> <mark>[Obs.]</mark> <rj><au>Blount.</au></rj></p>

<p><ent>Frigga</ent><br/
<ent>Frigg</ent><br/
<mhw>{ <hw>Frigg</hw> <pr>(?)</pr>, <hw>Frig"ga</hw> <pr>(?)</pr>
}</mhw> <pos>n.</pos> <ety>[Icel. <ets>Frigg</ets>. See
<er>Friday</er>.]</ety> <fld>(Scand. Myth.)</fld> <def>The wife of Odin
and mother of the gods; the supreme goddess; the Juno of the Valhalla.
Cf. <er>Freya</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fright</ent><br/
<hw>Fright</hw> <pr>(fr<imac/t)</pr>, <pos>n.</pos> <ety>[OE.
<ets>frigt</ets>, <ets>freyht</ets>, AS. <ets>fyrhto</ets>,
<ets>fyrhtu</ets>; akin to OS. <ets>forhta</ets>, OHG.
<ets>forhta</ets>, <ets>forahta</ets>, G. <ets>furcht</ets>, Dan.
<ets>frygt</ets>, Sw. <ets>fruktan</ets>, Goth.
<ets>fa<uacute/rhtei</ets> fear, <ets>fa<uacute/rhts</ets>
timid.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>A state of terror excited by the sudden appearance
of danger; sudden and violent fear, usually of short duration; a sudden
alarm.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Anything strange, ugly or shocking, producing a
feeling of alarm or aversion.</def> <mark>[Colloq.]</mark></p>

<p><syn><b>Syn.</b> -- Alarm; terror; consternation. See
<er>Alarm</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fright</ent><br/
<hw>Fright</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.</pos>
<conjf>Frighted</conjf>; <pos>p. pr. & vb. n.</pos>.
<conjf>Frighting</conjf>.]</vmorph> <ety>[OE. <ets>frigten</ets> to
fear, frighten, AS. <ets>fyrhtan</ets> to frighten, <ets>forhtian</ets>
to fear; akin to OS. <ets>forhtian</ets>, OHG. <ets>furihten</ets>,
<ets>forahtan</ets>, G. <ets>f<uum/rchten</ets>, Sw. <ets>frukta</ets>,
Dan. <ets>frygte</ets>, Goth. <ets>faurhtjan</ets>. See <er>Fright</er>,
<pos>n.</pos>, and cf. <er>Frighten</er>.]</ety> <def>To alarm suddenly;
to shock by causing sudden fear; to terrify; to scare.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Nor exile or danger can <qex>fright</qex> a brave spirit.</q>
<rj><qau>Dryden.</qau></rj></p>

<p><syn><b>Syn.</b> -- To affright; dismay; daunt; intimidate.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frighten</ent><br/
<hw>Fright"en</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp.</pos> <conjf>Frightened</conjf> <pr>(#)</pr>; <pos>p.
pr. & vb. n.</pos> <conjf>Frightening</conjf> <pr>(#)</pr>.]</vmorph>
<ety>[See <er>Fright</er>, <pos>v. t.</pos>]</ety> <def>To disturb with
fear; to throw into a state of alarm or fright; to affright; to
terrify.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>More <qex>frightened</qex> than hurt.</q> <rj><qau>Old
Proverb.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frightful</ent><br/
<hw>Fright"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Full of
fright; affrighted; frightened.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>See how the <qex>frightful</qex> herds run from the wood.</q>
<rj><qau>W. Browne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Full of that which causes fright; exciting alarm;
impressing terror; shocking; <as>as, a <ex>frightful</ex> chasm, or
tempest; a <ex>frightful</ex> appearance</as>.</def></p>

<p><syn><b>Syn.</b> -- Terrible; dreadful; alarming; fearful; terrific;
awful; horrid; horrible; shocking.</syn> <usage> -- <er>Frightful</er>,
<er>Dreadful</er>, <er>Awful</er>. These words all express fear. In
<xex>frightful</xex>, it is a sudden emotion; in <xex>dreadful</xex>, it
is deeper and more prolonged; in <xex>awful</xex>, the fear is mingled
with the emotion of awe, which subdues us before the presence of some
invisible power. An accident may be <xex>frightful</xex>; the approach
of death is <xex>dreadful</xex> to most men; the convulsions of the
earthquake are <xex>awful</xex>.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frightfully</ent><br/
<hw>Fright"ful*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a frightful
manner; to a frightful dagree.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frightfulness</ent><br/
<hw>Fright"ful*ness</hw>, <pos>n.</pos> <def>The quality of being
frightful.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frightless</ent><br/
<hw>Fright"less</hw>, <pos>a.</pos> <def>Free from fright;
fearless.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frightment</ent><br/
<hw>Fright"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Fear;
terror.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frigid</ent><br/
<hw>Frig"id</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>frigidus</ets>, fr. <ets>frigere</ets> to be cold; prob. akin to
Gr. <?/ to shudder, or perh. to <?/ cold. Cf. <er>Frill</er>.]</ety>
<sn>1.</sn> <def>Cold; wanting heat or warmth; of low temperature;
<as>as, a frigid climate</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Wanting warmth, fervor, ardor, fire, vivacity, etc.;
unfeeling; forbidding in manner; dull and unanimated; stiff and formal;
<as>as, a <ex>frigid</ex> constitution; a <ex>frigid</ex> style; a
<ex>frigid</ex> look or manner; <ex>frigid</ex> obedience or
service.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Wanting natural heat or vigor sufficient to excite
the generative power; impotent.</def> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Frigid zone</b></col>, <cd>that part of the earth which
lies between either polar circle and its pole. It extends 23<?/ 28<?/
from the pole. See the Note under <er>Arctic</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frigidarium</ent><br/
\'d8<hw>Frig"i*da`ri*um</hw> <pr>(?)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Frigidaria</plw> <pr>(#)</pr>.</plu> <ety>[L.,
neut. of <ets>frigidarium</ets> cooling.]</ety> <def>The cooling room of
the Roman therm<ae/, furnished with a cold bath.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frigidity</ent><br/
<hw>Fri*gid"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>frigiditas</ets>: cf. F. <ets>frigidit<eacute/</ets>.]</ety>
<sn>1.</sn> <def>The condition or quality of being frigid; coldness;
want of warmth.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Ice is water congealed by the <qex>frigidity</qex> of the air.</q>
<rj><qau>Sir T. Browne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Want of ardor, animation, vivacity, etc.; coldness
of affection or of manner; dullness; stiffness and formality; <as>as,
<ex>frigidity</ex> of a reception, of a bow, etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Want of heat or vigor; <as>as, the
<ex>frigidity</ex> of old age</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frigidly</ent><br/
<hw>Frig"id*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a frigid
manner; coldly; dully; without affection.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frigidness</ent><br/
<hw>Frig"id*ness</hw>, <pos>n.</pos> <def>The state of being frigid;
want of heat, vigor, or affection; coldness; dullness.</def></p>

<p><ent>Frigorifical</ent><br/
<ent>Frigorific</ent><br/
<mhw>{ <hw>Frig"o*rif"ic</hw> <pr>(?)</pr>, <hw>Frig"o*rif`ic*al</hw>
<pr>(?)</pr> }</mhw> <pos>a.</pos> <ety>[L. <ets>frigorificus</ets>;
<ets>frigus</ets>, <ets>frigoris</ets>, cold + <ets>facere</ets> to
make: cf. F. <ets>frigorifique</ets>.]</ety> <def>Causing cold;
producing or generating cold.</def> <rj><au>Quincy.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frejol</ent><br/
<ent>Frijole</ent><br/
<ent>Frijol</ent><br/
<mhw>{ <hw>Fri"jol</hw>, <hw>Fri"jole</hw> <pr>(?)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Frijoles</plw> <pr>(<?/)</pr></plu>. Also
<hw>Fre"jol</hw> }</mhw>. <ety>[Sp. <ets>fr<iacute/jol</ets>,
<ets>fr<eacute/jol</ets>.]</ety> <sn>1.</sn> <def>In Mexico, the
southwestern United States, and the West Indies, any cultivated bean of
the genus <gen>Phaseolus</gen>, esp. the black seed of a variety of
<spn>P. vulgaris</spn>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>The beanlike seed of any of several related plants,
as the cowpea. Frijoles are an important article of diet among
Spanish-American peoples, being used as an ingredient of many
dishes.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>frijolito</ent><br/
<ent>frijolillo</ent><br/
<mhw><hw>frijolillo</hw>, <hw>frijolito</hw></mhw> <pos>n.</pos> <def>A
shrub or small tree(<spn>Sophora secundiflora</spn>) having pinnate
leaves poisonous to livestock and dense racemes of intensely fragrant
blue flowers and red beans.</def><br/
<syn><b>Syn. --</b> mescal bean, coral bean, <spn>Sophora
secundiflora</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>frill</ent><br/
<hw>frill</hw> <pr>(fr<icr/l)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>frilled</conjf> <pr>(fr<icr/ld)</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>frilling</conjf>.]</vmorph> <ety>[OF.
<ets>friller</ets>, fr. L. <ets>frigidulus</ets> somewhat cold, dim. of
<ets>frigidus</ets> cold; akin to F. <ets>frileux</ets> chilly.]</ety>
<sn>1.</sn> <def>To shake or shiver as with cold; <as>as, the hawk
<ex>frills</ex></as>.</def> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Photog.)</fld> <def>To wrinkle; -- said of the
gelatin film.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frill</ent><br/
<hw>Frill</hw>, <pos>v. t.</pos> <def>To provide or decorate with a
frill or frills; to turn back. in crimped plaits; <as>as, to
<ex>frill</ex> a cap</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frill</ent><br/
<hw>Frill</hw>, <pos>n.</pos> <ety>[See <er>Frill</er>, <pos>v.
i.</pos>]</ety>. <fld>(Zool.)</fld> <sd>(a)</sd> <def>A ruffing of a
bird's feathers from cold.</def> <sd>(b)</sd> <def>A ruffle, consisting
of a fold of membrane, of hairs, or of feathers, around the neck of an
animal.</def> See <cref>Frilled lizard</cref> (below). <sd>(c)</sd>
<def>A similar ruffle around the legs or other appendages of
animals.</def> <sd>(d)</sd> <def>A ruffled varex or fold on certain
shells.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A border or edging secured at one edge and left free
at the other, usually fluted or crimped like a very narrow
flounce.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <specif>Hence:</specif> <def>Something superfluous, such
as an ornament, or an additional function on a device or in a system not
essential to the basic operation. -- Commonly used in the phrase
<ecol><b>no frills</b></ecol>, used adjectively to indicate a fully
functional but economical device or service; <as>as, an economical
no-<ex>frills</ex> airline</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>frilled</ent><br/
<hw>frilled</hw> <pr>(fr<icr/ld)</pr>, <pos>a.</pos> <def>Furnished with
a frill or frills.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Frilled lizard</b></col> <fld>(Zool.)</fld>, <cd>a large
Australian lizard (<spn>Chlamydosaurus Kingii</spn>) about three feet
long, which has a large, erectile frill on each side of the
neck.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>frills</ent><br/
<hw>frills</hw> <pos>n.</pos> <def>Ornamental objects of no great
value.</def><br/
<syn><b>Syn. --</b> falderal, folderol, gimcrackery, gimcracks,
nonsense, trumpery.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>frilly</ent><br/
<hw>frilly</hw> <pos>adj.</pos> <def>Having decorative ruffles or
frills.</def><br/
<syn><b>Syn. --</b> frilled, ruffled.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>frim</ent><br/
<hw>frim</hw> <pr>(fr<icr/m)</pr>, <pos>a.</pos> <ety>[Cf. AS.
<ets>freme</ets> good, bold, and E. <ets>frame</ets>.]</ety>
<def>Flourishing; thriving; fresh; in good condition; vigorous.</def>
<mark>[Obs.]</mark> <ldquo/Frim pastures.<rdquo/
<rj><au>Drayton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frimaire</ent><br/
\'d8<hw>Fri"maire`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr.
<ets>frimas</ets> hoarfrost.]</ety> <def>The third month of the French
republican calendar. It commenced November 21, and ended December 20.,
See <er>Vend<eacute/miaire</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fringe</ent><br/
<hw>Fringe</hw> <pr>(fr<icr/nj)</pr>, <pos>n.</pos> <ety>[OF,
<ets>fringe</ets>, F. <ets>frange</ets>, prob. fr. L. <ets>fimbria</ets>
fiber, thread, fringe, cf. <ets>fibra</ets> fiber, E. <ets>fiber</ets>,
<ets>fimbriate</ets>.]</ety> <sn>1.</sn> <def>An ornamental appendage to
the border of a piece of stuff, originally consisting of the ends of the
warp, projecting beyond the woven fabric; but more commonly made
separate and sewed on, consisting sometimes of projecting ends, twisted
or plaited together, and sometimes of loose threads of wool, silk, or
linen, or narrow strips of leather, or the like.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Something resembling in any respect a fringe; a line
of objects along a border or edge; a border; an edging; a margin; a
confine.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The confines of grace and the <qex>fringes</qex> of
repentance.</q> <rj><qau>Jer. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Opt.)</fld> <def>One of a number of light or dark
bands, produced by the interference of light; a diffraction band; --
called also <altname>interference fringe</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Bot.)</fld> <def>The peristome or fringelike
appendage of the capsules of most mosses. See
<er>Peristome</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fringe</ent><br/
<hw>Fringe</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Fringed</conjf> <pr>(fr<icr/njd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Fringing</conjf>.]</vmorph> <def>To adorn the edge of with a
fringe or as with a fringe.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Precipices <qex>fringed</qex> with grass.</q> <rj><qau>
Bryant.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fringing reef</b></col>. <cd>See <cref>Coral
reefs</cref>, under <er>Coral</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fringed</ent><br/
<hw>Fringed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Furnished with a
fringe.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fringed lear</b></col> <fld>(Bot.)</fld>, <cd>a leaf
edged with soft parallel hairs.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fringeless</ent><br/
<hw>Fringe"less</hw>, <pos>a.</pos> <def>Having no fringe.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fringent</ent><br/
<hw>Frin"gent</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Encircling like a
fringe; bordering.</def> <mark>[R.]</mark> <ldquo/The fringent
air.<rdquo/ <rj><au>Emerson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>fringepod</ent><br/
<hw>fringepod</hw> <pos>n.</pos> <def>An annual herb having pinnatifid
basal leaves and slender racemes of small white flowers followed by
one-seeded winged silicles.</def><br/
<syn><b>Syn. --</b> lacepod.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fringe tree</ent><br/
<hw>Fringe tree</hw>. <def>A small oleaceous tree (<spn>Chionanthus
virginica</spn>), of the southern United States, having clusters of
snow-white flowers with slender petals. It is often
cultivated.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Fringilla</ent><br/
\'d8<hw>Frin*gil"la</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[NL., fr. L.
<ets>fringilla</ets> a <ets>chaffinch</ets>.]</ety> <fld>(Zool.)</fld>
<def>A genus of birds, with a short, conical, pointed bill. It formerly
included all the sparrows and finches, but is now restricted to certain
European finches, like the chaffinch and brambling.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fringillaceous</ent><br/
<hw>Frin`gil*la"ceous</hw> <pr>(?)</pr>, <pos>a.</pos>
<fld>(Zool.)</fld> <def>Fringilline.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fringillidae</ent><br/
<hw>Fringillidae</hw> <pos>n.</pos> <def>A natural family of birds of
the finch group having short conical bills adapted for eating seeds,
including finches, goldfinches, bullfinches, chaffinches, siskins,
canaries, cardinals, grosbeaks, crossbills, linnets, and buntings. This
family at one time included the sparrows of the family
<fam>Emberizinae</fam>, but has more recently been restricted in
usage.</def><br/
<syn><b>Syn. --</b> family <fam>Fringillidae</fam>.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Fringilline</ent><br/
<hw>Frin*gil"line</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Pertaining to the family <fam>Fringillid<ae/</fam>; characteristic
of finches; sparrowlike.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fringy</ent><br/
<hw>Frin"gy</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Adorned with
fringes.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fripper</ent><br/
<hw>Frip"per</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>fripier</ets>, fr. <ets>friper</ets> to rumple, fumble,
waste.]</ety> <def>One who deals in frippery or in old clothes.</def>
<mark>[Obs.]</mark> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fripperer</ent><br/
<hw>Frip"per*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A fripper.</def>
<mark>[Obs.]</mark> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frippery</ent><br/
<hw>Frip"per*y</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>friperie</ets>, fr. <ets>fruper</ets>. See <er>Fripper</er>.]</ety>
<sn>1.</sn> <def>Coast-off clothes.</def> <mark>[Obs.]</mark> <rj><au>B.
Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence: Secondhand finery; cheap and tawdry
decoration; affected elegance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Fond of gauze and French <qex>frippery</qex>.</q>
<rj><qau>Goldsmith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The gauzy <qex>frippery</qex> of a French translation.</q>
<rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A place where old clothes are sold.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The trade or traffic in old clothes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frippery</ent><br/
<hw>Frip"per*y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Trifling;
contemptible.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>fritz out</ent><br/
<hw>frits` out"</hw> <pr>(fr<icr/ts out)</pr>, <pos>v. i.</pos> <def>To
become inoperable; of devices. See also <er>on the fritz</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Frisette</ent><br/
<ent>Frizette</ent><br/
<mhw>{ <hw>Fri*sette"</hw>, <hw>Fri*zette"</hw> }</mhw> <pr>(?)</pr>,
<pos>n.</pos> <ety>[F. <ets>frisette</ets> curl.]</ety> <def>a fringe of
hair or curls worn about the forehead by women.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Friseur'</ent><br/
\'d8<hw>Fri"seur'</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr.
<ets>friser</ets> to curl, frizzle. See <er>Frizzle</er>.]</ety> <def>A
hairdresser.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frisian</ent><br/
<hw>Fri"sian</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining to
Friesland, a province of the Netherlands; Friesic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frisian</ent><br/
<hw>Fri"sian</hw>, <pos>n.</pos> <def>A native or inhabitant of
Friesland; also, the language spoken in Friesland. See <er>Friesic</er>,
<pos>n.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frisk</ent><br/
<hw>Frisk</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OF. <ets>frieque</ets>,
cf. OHG. <ets>frise</ets> lively, brisk, fresh, Dan. & Sw.
<ets>frisk</ets>, Icel. <ets>friskr</ets>. See <er>Fresh</er>,
<pos>a.</pos>]</ety> <def>Lively; brisk; frolicsome; frisky.</def>
<mark>[Obs.]</mark> <rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frisk</ent><br/
<hw>Frisk</hw>, <pos>a.</pos> <def>A frolic; a fit of wanton gayety; a
gambol: a little playful skip or leap.</def>
<rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frisk</ent><br/
<hw>Frisk</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Frisked</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Frisking</conjf>.]</vmorph> <def>To leap, skip, dance, or gambol,
in fronc and gayety.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>frisking</qex> satyrs on the summits danced.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>frisk</ent><br/
<hw>frisk</hw> <pr>(fr<icr/sk)</pr>, <pos>v. t.</pos> <def>To search (a
person) for concealed weapons or other objects, by patting the clothing
to detect objects underneath; <as>as, the police pulled the car over and
<ex>frisked</ex> the occupants</as>.</def><br/
<syn><b>Syn. --</b> frisk.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Friskal</ent><br/
<hw>Frisk"al</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A leap or
caper.</def> <mark>[Obs.]</mark> <rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frisker</ent><br/
<hw>Frisker</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who frisks; one
who leaps of dances in gayety; a wanton; an inconstant or unsettled
person.</def> <rj><au>Camden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frisket</ent><br/
<hw>Fris"ket</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>frisguette</ets>. Perhaps so named from the velocity or frequency
of its motion. See <er>Frisk</er> <pos>a.</pos>]</ety>
<fld>(Print.)</fld> <def>The light frame which holds the sheet of paper
to the tympan in printing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Friskful</ent><br/
<hw>Frisk"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Brisk; lively;
frolicsome.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Friskily'</ent><br/
<hw>Frisk"i*ly'</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a frisky
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Friskiness</ent><br/
<hw>Frisk"i*ness</hw>, <pos>n.</pos> <def>State or quality of being
frisky.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>frisking</ent><br/
<hw>frisking</hw> <pos>n.</pos> <def>The act or process of searching
someone for concealed weapons.</def><br/
<syn><b>Syn. --</b> frisk.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Frisky</ent><br/
<hw>Frisk"y</hw>, <pos>a.</pos> <def>Inclined to frisk; frolicsome;
gay.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He is too <qex>frisky</qex> for an old man.</q>
<rj><qau>Jeffrey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frislet</ent><br/
<hw>Fris"let</hw> <pr>(fr<icr/z"l<ecr/t)</pr>, <pos>n.</pos> <ety>[Cf.
<er>Fraise</er> a kind of defense; also <er>Friz</er>.]</ety> <def>A
kind of small ruffle.</def> <rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frist</ent><br/
<hw>Frist</hw> <pr>(fr<icr/st)</pr>, <pos>v. t.</pos> <ety>[OE.
<ets>fristen</ets>, <ets>firsten</ets>, to lend, give respite, postpone,
AS. <ets>firstan</ets> to give respite to; akin to first time, G.
<ets>frist</ets>, Icel. <ets>frest</ets> delay.]</ety> <def>To sell upon
credit, as goods.</def> <mark>[R.]</mark> <rj><au>Crabb.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frisure</ent><br/
\'d8<hw>Fri"sure`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<def>The dressing of the hair by crisping or curling.</def>
<rj><au>Smollett.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frit</ent><br/
<hw>Frit</hw> <pr>(fr<icr/t)</pr>, <pos>n.</pos> <ety>[F.
<ets>fritte</ets>, fr. <ets>frit</ets> fried, p. p. of <ets>frire</ets>
to fry. See <er>Far</er>, <pos>v. t.</pos>]</ety> <sn>1.</sn>
<fld>(Glass Making)</fld> <def>The material of which glass is made,
after having been calcined or partly fused in a furnace, but before
vitrification. It is a composition of silex and alkali, occasionally
with other ingredients.</def> <rj><au>Ure.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Ceramics)</fld> <def>The material for glaze of
pottery.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Frit brick</b></col>, <cd>a lump of calcined glass
materials, brought to a pasty condition in a reverberatory furnace,
preliminary to the perfect vitrification in the melting
pot.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frit</ent><br/
<hw>Frit</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Fritted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Fritting</conjf>.]</vmorph> <def>To prepare by heat (the
materials for making glass); to fuse partially.</def>
<rj><au>Ure.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frit</ent><br/
<hw>Frit</hw>, <pos>v. t.</pos> <def>To fritter; -- with away.</def>
<mark>[R.]</mark> <rj><au>Ld. Lytton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fritfly</ent><br/
<hw>Frit"fly`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>A
small dipterous fly of the genus <gen>Oscinis</gen>, esp. <spn>O.
vastator</spn>, injurious to grain in Europe, and <spn>O. Trifole</spn>,
injurious to clover in America.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Frith</ent><br/
<hw>Frith</hw> <pr>(fr<icr/th)</pr>, <pos>n.</pos> <ety>[OE.
<ets>firth</ets>, Icel. <ets>fj<oum/r<edh/r</ets>; akin to Sw.
<ets>fj<aum/rd</ets>, Dan. <ets>fiord</ets>, E. <ets>ford</ets>.
<root/78. See <er>Ford</er>, <pos>n.</pos>, and cf. <er>Firth</er>,
<er>Fiord</er>, <er>Fret</er> a frith, <er>Port</er> a
harbor.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <fld>(Geog.)</fld> <def>A narrow arm of the sea; an
estuary; the opening of a river into the sea; <as>as, the <ex>Frith</ex>
of Forth</as>. Also called <altname>firth</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A kind of weir for catching fish.</def>
<mark>[Eng.]</mark> <rj><au>Carew.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frith</ent><br/
<hw>Frith</hw>, <pos>n.</pos> <ety>[OE. <ets>frith</ets> peace,
protection, land inclosed for hunting, park, forest, AS.
<ets>fri<edh/</ets> peace; akin to <ets>freno<edh/</ets> peace,
protection, asylum, G. <ets>friede</ets> peace, Icel.
<ets>fri<edh/r</ets>, and from the root of E. free, friend. See
<er>Free</er>, <pos>a.</pos>, and cf. <er>Affray</er>,
<er>Defray</er>.]</ety> <sn>1.</sn> <def>A forest; a woody place.</def>
<mark>[Obs.]</mark> <rj><au>Drayton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A small field taken out of a common, by inclosing
it; an inclosure.</def> <mark>[Obs.]</mark> <rj><au>Sir J.
Wynne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frithy</ent><br/
<hw>Frith"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Woody.</def>
<mark>[Obs.]</mark> <rj><au>Skelton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fritillaria</ent><br/
\'d8<hw>Frit"il*la`ri*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
L. <ets>fritillus</ets> dicebox: cf. F. <ets>fritillaire</ets>. So named
from the checkered markings of the petals.]</ety> <fld>(Bot.)</fld>
<def>A genus of liliaceous plants, of which the crown-imperial
(<spn>Fritillaria imperialis</spn>) is one species, and the Guinea-hen
flower (<spn>F. Meleagris</spn>) another. See
<er>Crown-imperial</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fritillary</ent><br/
<hw>Frit"il*la*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<fld>(Bot.)</fld> <def>A plant with checkered petals, of the genus
Fritillaria: the Guinea-hen flower. See <er>Fritillaria</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>One of several species of
butterflies belonging to <gen>Argynnis</gen> and allied genera; -- so
called because the coloring of their wings resembles that of the common
<gen>Fritillaria</gen>. See <er>Aphrodite</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fritinancy</ent><br/
<hw>Frit"i*nan*cy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>fritinnire</ets> to twitter.]</ety> <def>A chirping or creaking, as
of a cricket.</def> <mark>[Obs.]</mark> <rj><au>Sir T.
Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fritter</ent><br/
<hw>Frit"ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OR.
<ets>fritour</ets>, <ets>friture</ets>, pancake, F. <ets>friture</ets>
frying, a thing fried, from <ets>frire</ets> to fry. See <er>Far</er>,
<pos>v. t.</pos>]</ety> <sn>1.</sn> <def>A small quantity of batter,
fried in boiling lard or in a frying pan. Fritters are of various kinds,
named from the substance inclosed in the batter; <as>as, apple
<ex>fritters</ex>, clam <ex>fritters</ex>, oyster
<ex>fritters</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A fragment; a shred; a small piece.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And cut whole giants into <qex>fritters</qex>.</q>
<rj><qau>Hudibras.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Corn fritter</b></col>. <cd>See under
<er>Corn</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fritter</ent><br/
<hw>Frit"ter</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Frittered</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Frittering</conjf>.]</vmorph> <sn>1.</sn> <def>To cut, as meat,
into small pieces, for frying.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To break into small pieces or fragments.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Break all nerves, and <qex>fritter</qex> all their sense.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To fritter away</b></col>, <cd>to diminish; to pare off;
to reduce to nothing by taking away a little at a time; also, to waste
piecemeal; <as>as, <ex>to fritter away</ex> time, strength, credit,
etc.</as></cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fritting</ent><br/
<hw>Frit"ting</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See <er>Frit</er>
to expose to heat.]</ety> <def>The formation of frit or slag by heat
with but incipient fusion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frivol</ent><br/
<hw>Friv"ol</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To act frivolously;
to trifle.</def> <au>Kipling</au>. -- <wordforms><wf>Friv"ol*er</wf>
<pr>(#)</pr>, <wf>Friv"ol*ler</wf>, <pos>n.</pos> <mark>[All
Colloq.]</mark></wordforms><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Frivolism</ent><br/
<hw>Friv"o*lism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Frivolity.</def>
<mark>[R.]</mark> <rj><au>Pristley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frivolity</ent><br/
<hw>Fri*vol"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Frivolities</plw> <pr>(#)</pr>.</plu> <ety>[Cg. F.
<ets>frivolit<eacute/</ets>. See <er>Frivolous</er>.]</ety> <def>The
condition or quality of being frivolous; also, acts or habits of
trifling; unbecoming levity of disposition.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 598 --></p>

<p><ent>Frivolous</ent><br/
<hw>Friv"o*lous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>frivolus</ets>; prob. akin to <ets>friare</ets> to rub, crumble, E.
<ets>friable</ets>: cf. F. <ets>frivole</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Of little weight or importance; not worth notice;
slight; <as>as, a <ex>frivolous</ex> argument</as>.</def>
<rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Given to trifling; marked with unbecoming levity;
silly; interested especially in trifling matters.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His personal tastes were low and <qex>frivolous</qex>.</q>
<rj><qau>Macaulay.</qau></rj></p>

<p><syn><b>Syn.</b> -- Trifling; trivial; slight; petty;
worthless.</syn></p>

<p>-- <wordforms><wf>Friv"o*lous*ly</wf>, <pos>adv.</pos> --
<wf>Friv"o*lous*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Friz</ent><br/
<hw>Friz</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Frizzed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Frizzing</conjf> <pr>(?)</pr>.]</vmorph> <ety>[Cf. F.
<ets>friser</ets> to curl, crisp, <ets>frizzle</ets>, to raise the nap
(on certain stuffs); prob.akin to OFries. <ets>frisle</ets> hair of the
head. Cf. <er>Frieze</er> kind of cloth.]</ety> <altsp>[Written also
<asp>frizz</asp>.]</altsp> <sn>1.</sn> <def>To curl or form into small
curls, as hair, with a crisping pin; to crisp.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With her hair <qex>frizzed</qex> short up to her ears.</q>
<rj><qau>Pepys.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To form into little burs, prominences, knobs, or
tufts, as the nap of cloth.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Leather Manufacture)</fld> <def>To soften and make
of even thickness by rubbing, as with pumice stone or a blunt
instrument.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Frizzing machine</b></col>. <sd>(a)</sd>
<fld>(Fabrics)</fld> <cd>A machine for frizzing the surface of
cloth.</cd> <sd>(b)</sd> <fld>(Wood Working)</fld> <cd>A bench with a
revolving cutter head slightly protruding above its surface, for
dressing boards.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Friz</ent><br/
<hw>Friz</hw>, <pos>n.</pos>; <plu><it>pl.</it> <plw>Frizzes</plw>
<pr>(<?/)</pr>.</plu> <def>That which is frizzed; anything crisped or
curled, as a wig; a frizzle.</def> <altsp>[Written also
<asp>frizz</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><q>He [Dr. Johnson], who saw in his glass how his wig became his face
and head, might easily infer that a similar fullbottomed, well-curled
<qex>friz</qex> of words would be no less becoming to his thoughts.</q>
<rj><qau>Hare.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frize</ent><br/
<hw>Frize</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Arch.)</fld> <def>See
1st <er>Frieze</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frizel</ent><br/
<hw>Friz"el</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Firearms)</fld>
<def>A movable furrowed piece of steel struck by the flint, to throw
sparks into the pan, in an early form of flintlock.</def>
<rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frizette</ent><br/
<hw>Fri*zette"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>frisette</ets> curl.]</ety> <def>A curl of hair or silk; a pad of
frizzed hair or silk worn by women under the hair to stuff it
out.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frizz</ent><br/
<hw>Frizz</hw> <pr>(?)</pr>, <pos>v. t. & n.</pos> <def>See
<er>Friz</er>, <pos>v. t. & n.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frizz</ent><br/
<hw>Frizz</hw>, <pos>v. t. & i.</pos> <ety>[Partly imitative, but cf.
<er>Fry</er>.]</ety> <def>To fry, cook, or sear with a sizzling noise;
to sizzle.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Frizzle</ent><br/
<hw>Friz"zle</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Frizzled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Frizzling</conjf> <pr>(?)</pr>.]</vmorph> <ety>[Dim. of
<er>friz</er>.]</ety> <def>To curl or crisp, as hair; to friz; to
crinkle.</def> <rj><au>Gay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To frizzle up</b></col>, <cd>to crinkle or crisp
excessively.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frizzle</ent><br/
<hw>Friz"zle</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Frizzled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Frizzling</conjf> <pr>(?)</pr>.]</vmorph> <ety>[Freq. of
an imitative word <ets>frizz</ets>, in dial. use.]</ety> <sn>1.</sn>
<def>To fry, toast, or broil with a sputtering sound to cook with a
sizzling noise. Also fig.</def> <rj><au>Hawthorne.</au></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>To cook, in certain way, so as to curl or crinkle
up.</def></p>

<p><q>Drain and heat it [shaved smoked beef] in one tablespoonful of hot
butter, to curl or <qex>frizzle</qex> it.</q> <rj><qau>Mrs. Lincoln
(Cook Book).</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Frizzle</ent><br/
<hw>Friz"zle</hw>, <pos>n.</pos> <def>A curl; a lock of hair
crisped.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frizzler</ent><br/
<hw>Friz"zler`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
frizzles.</def></p>

<p><ent>Frizzy</ent><br/
<ent>Frizzly</ent><br/
<mhw>{ <hw>Friz"zly</hw> <pr>(?)</pr>, <hw>Friz"zy</hw> <pr>(?)</pr>,
}</mhw> <pos>a.</pos> <def>Curled or crisped; <as>as, <ex>frizzly</ex>,
hair</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fro</ent><br/
<hw>Fro</hw> <pr>(fr<omac/)</pr>, <pos>adv.</pos> <ety>[OE.
<ets>fra</ets>, <ets>fro</ets>, adv. & prep., Icel. <ets>fr<amac/</ets>,
akin to Dan. <ets>fra</ets> from, E. <ets>from</ets>. See
<er>From</er>.]</ety> <def>From; away; back or backward; -- now used
only in opposition to the word <xex>to</xex>, in the phrase to and
<xex>fro</xex>, that is, <xex>to and from</xex>. See <er>To and fro</er>
under <er>To</er>.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fro</ent><br/
<hw>Fro</hw>, <pos>prep.</pos> <def>From.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frock</ent><br/
<hw>Frock</hw> <pr>(fr<ocr/k)</pr>, <pos>n.</pos> <ety>[F.
<ets>froc</ets> a monk's cowl, coat, garment, LL. <ets>frocus</ets>,
<ets>froccus</ets>, <ets>flocus</ets>, <ets>floccus</ets>, fr. L.
<ets>floccus</ets> a flock of wool; hence orig., a flocky cloth or
garment; cf. L. <ets>flaccus</ets> flabby, E. <ets>flaccid</ets>.]</ety>
<sn>1.</sn> <def>A loose outer garment; especially, a gown forming a
part of European modern costume for women and children; also, a coarse
shirtlike garment worn by some workmen over their other clothes; a smock
frock; <as>as, a marketman's <ex>frock</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A coarse gown worn by monks or friars, and supposed
to take the place of all, or nearly all, other garments. It has a hood
which can be drawn over the head at pleasure, and is girded by a
cord.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Frock coat</b></col>, <cd>a body coat for men, usually
double-breasted, the skirts not being in one piece with the body, but
sewed on so as to be somewhat full.</cd> -- <col><b>Smock
frock</b></col>. <cd>See in the Vocabulary.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frock</ent><br/
<hw>Frock</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To clothe in a
frock.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To make a monk of. Cf. <er>Unfrock</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frocked</ent><br/
<hw>Frocked</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Clothed in a
frock.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frockless</ent><br/
<hw>Frock"less</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Destitute of a
frock.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Froe</ent><br/
<hw>Froe</hw> <pr>(fr<omac/)</pr>, <pos>n.</pos> <ety>[See
<er>Frow</er>.]</ety> <def>A dirty woman; a slattern; a frow.</def>
<mark>[Obs.]</mark> <ldquo/Raging frantic <xex>froes</xex>.<rdquo/
<rj><au>Draylon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Froe</ent><br/
<hw>Froe</hw>, <pos>n.</pos> <ety>[See <er>Frow</er> the tool]</ety>
<def>An iron cleaver or splitting tool; a frow.</def> <mark>[U.
S.]</mark> <rj><au>Bartlett.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Froebelian</ent><br/
<hw>Froe*bel"i*an</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to,
or derived from, Friedrich <etsep>Froebel</etsep>, or the kindergarten
system of education, which he organized.</def> -- <def2><pos>n.</pos>
<def>One who teaches by, or advocates the use of, the kindergarten
system.</def></def2><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Frog</ent><br/
<hw>Frog</hw> <pr>(fr<ocr/g)</pr>, <pos>n.</pos> <ety>[AS.
<ets>froggu</ets>, <ets>frocga</ets> a frog (in sensel); akin to D.
<ets>vorsch</ets>, OHG. <ets>frosk</ets>, G. <ets>frosch</ets>, Icel.
<ets>froskr</ets>, <ets>fraukr</ets>, Sw. & Dan.
<ets>fr<oum/</ets>.]</ety> <sn>1.</sn> <fld>(Zool.)</fld> <def>An
amphibious animal of the genus <gen>Rana</gen> and related genera, of
many species. Frogs swim rapidly, and take long leaps on land. Many of
the species utter loud notes in the springtime.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The edible frog of Europe (<spn>Rana esculenta</spn>) is
extensively used as food; the American bullfrog (<spn>R.
Catesbiana</spn>) is remarkable for its great size and loud
voice.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <ety>[Perh. akin to E. <ets>fork</ets>, cf.
<ets>frush</ets> frog of a horse.]</ety> <fld>(Anat.)</fld> <def>The
triangular prominence of the hoof, in the middle of the sole of the foot
of the horse, and other animals; the fourchette.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Railroads)</fld> <def>A supporting plate having
raised ribs that form continuations of the rails, to guide the wheels
where one track branches from another or crosses it.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <ety>[Cf. <ets>fraco</ets> of wool or silk, L.
<ets>floccus</ets>, E. <ets>frock</ets>.]</ety> <def>An oblong cloak
button, covered with netted thread, and fastening into a loop instead of
a button hole.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>The loop of the scabbard of a bayonet or
sword.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Cross frog</b></col> <fld>(Railroads)</fld>, <cd>a frog
adapted for tracks that cross at right angles.</cd> -- <col><b>Frog
cheese</b></col>, <cd>a popular name for a large puffball.</cd> --
<col><b>Frog eater</b></col>, <cd>one who eats frogs; -- a term of
contempt applied to a Frenchman by the vulgar class of English.</cd> --
<col><b>Frog fly</b></col>. <fld>(Zool.)</fld> <cd>See <er>Frog</er>
hopper.</cd> -- <col><b>Frog hopper</b></col> <fld>(Zool.)</fld>, <cd>a
small, leaping, hemipterous insect living on plants. The larv<ae/ are
inclosed in a frothy liquid called <cref>cuckoo spit</cref> or
<cref>frog spit</cref>.</cd> -- <col><b>Frog lily</b></col>
<fld>(Bot.)</fld>, <cd>the yellow water lily (<gen>Nuphar</gen>).</cd>
-- <col><b>Frog spit</b></col> <fld>(Zool.)</fld>, <cd>the frothy
exudation of the <cref>frog hopper</cref>; -- called also <altname>frog
spittle</altname>. See <cref>Cuckoo spit</cref>, under
<er>Cuckoo</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frog</ent><br/
<hw>Frog</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To ornament or fasten
(a coat, etc.) with trogs. See <er>Frog</er>, <pos>n.</pos>,
4.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>frogmarch</ent><br/
<hw>frogmarch</hw> <pos>v.</pos> <sn>1.</sn> <def>to march a person
against his will by any method.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>to carry someone against his will upside down such
that each limb is held by one person.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>frog's-bit</ent><br/
<ent>frogbit</ent><br/
<mhw><hw>frog"bit`</hw>, <hw>frog's-bit</hw></mhw> <pr>(?)</pr>,
<pos>n.</pos> <fld>(Bot.)</fld> <sd>(a)</sd> <def>A European plant
(<spn>Hydrocharis Morsus-ran<ae/</spn>), floating on still water and
propagating itself by runners. It has roundish heart-shaped leaves and
small white flowers.</def> <sd>(b)</sd> <def>An American plant
(<spn>Limnobium Spongia</spn>), with similar habits.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frog-eyed</ent><br/
<hw>Frog"-eyed`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Spotted with
whitish specks due to a disease, or produced artificially by spraying;
-- said of tobacco used for cigar wrappers.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Frogfish</ent><br/
<hw>Frog"fish`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<sd>(a)</sd> <def>See <er>Angler</er>, <pos>n.</pos>, 2.</def>
<sd>(b)</sd> <def>An oceanic fish of the genus <gen>Antennarius</gen> or
<gen>Pterophrynoides</gen>; -- called also mousefish and
toadfish.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frogged</ent><br/
<hw>Frogged</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Provided or ornamented
with frogs; <as>as, a <ex>frogged</ex> coat</as>. See <er>Frog</er>,
<pos>n.</pos>, 4.</def> <rj><au>Ld. Lytton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Froggy</ent><br/
<hw>Frog"gy</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Abounding in
frogs.</def> <rj><au>Sherwood.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frogmouth</ent><br/
<hw>Frog"mouth`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>One of several species of Asiatic and East Indian birds of the
genus <gen>Batrachostomus</gen> (family <fam>Podargid<ae/</fam>); -- so
called from their very broad, flat bills.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frogs-bit</ent><br/
<hw>Frog"s`-bit"</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>Frogbit.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frogshell</ent><br/
<hw>Frog"shell`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>One of numerous species of marine gastropod shells, belonging to
<gen>Ranella</gen> and allied genera.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Froise</ent><br/
<hw>Froise</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>froise</ets>
cf. F. <ets>froisser</ets> to bruise, E. <ets>frush</ets> to
bruise,]</ety> <def>A kind of pancake. See 1st <er>Fraise</er>.</def>
<altsp>[Written also <asp>fraise</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frolic</ent><br/
<hw>Frol"ic</hw> <pr>(fr<ocr/l"<icr/k)</pr>, <pos>a.</pos> <ety>[D.
<ets>vroolijk</ets>; akin to G. <ets>fr<oum/lich</ets>, fr.
<ets>froh</ets>, OHG. <ets>fr<omac/</ets>, Dan. <ets>fro</ets>, OS.
<ets>fr<amac/h</ets>, cf. Icel. <ets>fr<amac/r</ets> swift; all perh.
akin to Skr. <ets>pru</ets> to spring up.]</ety> <def>Full of levity;
dancing, playing, or frisking about; full of pranks; frolicsome; gay;
merry.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>frolic</qex> wind that breathes the spring.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The gay, the <qex>frolic</qex>, and the loud.</q>
<rj><qau>Waller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frolic</ent><br/
<hw>Frol"ic</hw>, <pos>n.</pos> <sn>1.</sn> <def>A wild prank; a flight
of levity, or of gayety and mirth.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He would be at his <qex>frolic</qex> once again.</q>
<rj><qau>Roscommon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A scene of gayety and mirth, as in lively play, or
in dancing; a merrymaking.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frolic</ent><br/
<hw>Frol"ic</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Frolicked</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Frolicking</conjf>.]</vmorph> <def>To play wild pranks; to play
tricks of levity, mirth, and gayety; to indulge in frolicsome play; to
sport.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Hither, come hither, and <qex>frolic</qex> and play.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frolicful</ent><br/
<hw>Frol"ic*ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Frolicsome.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frolicky</ent><br/
<hw>Frol"ick*y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Frolicsome.</def>
<mark>[Obs.]</mark> <rj><au>Richardson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frolicly</ent><br/
<hw>Frol"ic*ly</hw>, <pos>adv.</pos> <def>In a frolicsome manner; with
mirth and gayety.</def> <mark>[Obs.]</mark> <rj><au>Beau. &
Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frolicsome</ent><br/
<hw>Frol"ic*some</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Full of gayety
and mirth; given to pranks; sportive.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Old England, who takes a <qex>frolicsome</qex> brain fever once
every two or three years, for the benefit of her doctors.</q>
<rj><qau>Sir W. Scott.</qau></rj></p>

<p>-- <wordforms><wf>Frol"ic*some*ly</wf>, <pos>adv.</pos> --
<wf>Frol"ic*some*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>From</ent><br/
<hw>From</hw> <pr>(fr<ocr/m)</pr>, <pos>prep.</pos> <ety>[AS.
<ets>fram</ets>, <ets>from</ets>; akin to OS. <ets>fram</ets> out, OHG.
& Icel. <ets>fram</ets> forward, Sw. <ets>fram</ets>, Dan.
<ets>frem</ets>, Goth. <ets>fram</ets> from, prob. akin to E.
<ets>forth</ets>. <?/202. Cf. <er>Fro</er>, <er>Foremost</er>.]</ety>
<def>Out of the neighborhood of; lessening or losing proximity to;
leaving behind; by reason of; out of; by aid of; -- used whenever
departure, setting out, commencement of action, being, state,
occurrence, etc., or procedure, emanation, absence, separation, etc.,
are to be expressed. It is construed with, and indicates, the point of
space or time at which the action, state, etc., are regarded as setting
out or beginning; also, less frequently, the source, the cause, the
occasion, out of which anything proceeds; -- the antithesis and
correlative of <ant>to</ant>; <as>as, it, is one hundred miles
<ex>from</ex> Boston to Springfield; he took his sword <ex>from</ex> his
side; light proceeds <ex>from</ex> the sun; separate the coarse wool
<ex>from</ex> the fine; men have all sprung <ex>from</ex> Adam, and
often go <ex>from</ex> good to bad, and <ex>from</ex> bad to worse; the
merit of an action depends on the principle <ex>from</ex> which it
proceeds; men judge of facts <ex>from</ex> personal knowledge, or
<ex>from</ex> testimony.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Experience <qex>from</qex> the time past to the time present.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The song began <qex>from</qex> Jove.</q>
<rj><qau>Drpden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>From</qex> high M<ae/onia's rocky shores I came.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>If the wind blow any way <qex>from</qex> shore.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>From</xex> sometimes denotes <xex>away from</xex>,
<xex>remote from</xex>, <xex>inconsistent with</xex>. <ldquo/Anything so
overdone is <xex>from</xex> the purpose of playing.<rdquo/
<au>Shak.</au> <xex>From</xex>, when joined with another preposition or
an adverb, gives an opportunity for abbreviating the sentence.
<ldquo/There followed him great multitudes of people . . .
<xex>from</xex> [the land] <xex>beyond</xex> Jordan.<rdquo/ <au>Math.
iv. 25.</au> In certain constructions, as <xex>from forth</xex>,
<xex>from out</xex>, etc., the ordinary and more obvious arrangment is
inverted, the sense being more distinctly <xex>forth from</xex>,
<xex>out from</xex> -- <xex>from</xex> being virtually the governing
preposition, and the word the adverb. See <cref>From off</cref>, under
<er>Off</er>, <pos>adv.</pos>, and <cref>From afar</cref>, under
<er>Afar</er>, <pos>adv.</pos></note><br/
[<source>1913 Webster</source>]</p>

<p><q>Sudden partings such as press<br/
The life <qex>from out</qex> young hearts.</q>
<rj><qau>Byron.</qau></rj></p>

<p><ent>Fromwards</ent><br/
<ent>Fromward</ent><br/
<mhw>{ <hw>From"ward</hw> <pr>(?)</pr>, <hw>From"wards</hw>
<pr>(?)</pr>, }</mhw> <pos>prep.</pos> <ety>[AS. <ets>framweard</ets>
about to depart. Cf. <er>Froward</er>]</ety> <def>A way from; -- the
contrary of toward.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Towards or <qex>fromwards</qex> the zenith.</q>
<rj><qau>Cheyne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frond</ent><br/
<hw>Frond</hw> <pr>(fr<ocr/nd)</pr>, <pos>n.</pos> <ety>[L.
<ets>frons</ets>, <ets>frondis</ets>, a leafy branch, foliage.]</ety>
<fld>(Bot.)</fld> <def>The organ formed by the combination or union into
one body of stem and leaf, and often bearing the fructification; <as>as,
the <ex>frond</ex> of a fern or of a lichen or seaweed</as>; also, the
peculiar leaf of a palm tree.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frondation</ent><br/
<hw>Fron*da"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>frondatio</ets>, from <ets>frons</ets>. See <er>Frond</er>.]</ety>
<def>The act of stripping, as trees, of leaves or branches; a kind of
pruning.</def> <rj><au>Evelyn.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fronde</ent><br/
\'d8<hw>Fronde</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety> <fld>(F.
Hist.)</fld> <def>A political party in France, during the minority of
Louis XIV., who opposed the government, and made war upon the court
party.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fronded</ent><br/
<hw>Frond"ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Furnished with
fronds.</def> <ldquo/Fronded palms.<rdquo/
<rj><au>Whittier.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frondent</ent><br/
<hw>Fron"dent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>frondens</ets>, p. pr. of <ets>frondere</ets> to put forth leaves.
See <er>Frond</er>.]</ety> <def>Covered with leaves; leafy; <as>as, a
<ex>frondent</ex> tree</as>.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frondesce</ent><br/
<hw>Fron*desce"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[L.
<ets>frondescere</ets>, inchoative fr. <ets>frondere</ets>. See
<er>Frondent</er>.]</ety> <def>To unfold leaves, as plants.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frondescence</ent><br/
<hw>Fron*des"cence</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<sd>(a)</sd> <def>The time at which each species of plants unfolds its
leaves.</def> <sd>(b)</sd> <def>The act of bursting into leaf.</def>
<rj><au>Milne. Martyn.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frondeur</ent><br/
\'d8<hw>Fron"deur`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<fld>(F. Hist.)</fld> <def>A member of the Fronde.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frondiferous</ent><br/
<hw>Fron*dif"er*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>frondifer frons</ets> a leafy branch + ferre to bear: cf. F.
<ets>frondifere</ets>.]</ety> <def>Producing fronds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frondlet</ent><br/
<hw>Frond"let</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>A
very small frond, or distinct portion of a compound frond.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frondose</ent><br/
<hw>Fron*dose"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>frondosus</ets> leafy.]</ety> <fld>(Bot.)</fld> <sd>(a)</sd>
<def>Frond bearing; resembling a frond; having a simple expansion not
separable into stem and leaves.</def> <sd>(b)</sd> <def>Leafy.</def>
<rj><au>Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frondous</ent><br/
<hw>Fron"dous</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Bot.)</fld>
<def>Frondose.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frons</ent><br/
\'d8<hw>Frons</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.,
<ets>front</ets>.]</ety> <fld>(Anal.)</fld> <def>The forehead; the part
of the cranium between the orbits and the vertex.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Front</ent><br/
<hw>Front</hw> <pr>(fr<ucr/nt)</pr>, <pos>n.</pos> <ety>[F.
<ets>frant</ets> forehead, L. <ets>frons</ets>, <ets>frontis</ets>;
perh. akin to E. <ets>brow</ets>.]</ety> <sn>1.</sn> <def>The forehead
or brow, the part of the face above the eyes; sometimes, also, the whole
face.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Bless'd with his father's <qex>front</qex>, his mother's
tongue.</q> <rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Grim-visaged war hath smoothed his wrinkled <qex>front</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>His <qex>front</qex> yet threatens, and his frowns command.</q>
<rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The forehead, countenance, or personal presence, as
expressive of character or temper, and especially, of boldness of
disposition, sometimes of impudence; seeming; <as>as, a bold
<ex>front</ex>; a hardened <ex>front</ex></as>;</def>
<specif>hence,</specif> <def>an attitude and demeanor intended to
represent one's feelings, even if not actually felt; <as>as, to put on a
good <ex>front</ex></as>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><q>With smiling <qex>fronts</qex> encountering.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The inhabitants showed a bold <qex>front</qex>.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The part or surface of anything which seems to look
out, or to be directed forward; the fore or forward part; the foremost
rank; the van; -- the opposite to back or rear; <as>as, the
<ex>front</ex> of a house; the <ex>front</ex> of an army</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Had he his hurts before?<br/
Ay, on the <qex>front</qex>.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A position directly before the face of a person, or
before the foremost part of a thing; <as>as, in <ex>front</ex> of un
person, of the troops, or of a house</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>The most conspicuous part.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The very head and <qex>front</qex> of my offending.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>That which covers the foremost part of the head: a
front piece of false hair worn by women.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Like any plain Miss Smith's, who wears s front.</q> <rj><qau>Mrs.
Browning.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>The beginning.</def> <ldquo/Summer's
<xex>front</xex>.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <fld>(Fort.)</fld> <def>All the works along one side of
the polygon inclosing the site which is fortified.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>9.</sn> <fld>(Phon.)</fld> <def>The middle of the upper part of
the tongue, -- the part of the tongue which is more or less raised
toward the palate in the pronunciation of certain sounds, as the vowel
<it>i</it> in <it>machine</it>, <it>e</it> in <it>bed</it>, and
consonant <it>y</it> in <it>you.</it> See Guide to Pronunciation,
<sect/10.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>10.</sn> <def>The call boy whose turn it is to answer the call,
which is often the word <ldquo/front,<rdquo/ used as an
exclamation.</def> <mark>[Hotel Cant]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><cs><col><b>Bastioned front</b></col> <fld>(Mil.)</fld>, <cd>a
curtain connerting two half bastions.</cd> -- <col><b>Front
door</b></col>, <cd>the door in the front wall of a building, usually
the principal entrance.</cd> -- <col><b>Front of
fortification</b></col>, <cd>the works constructed upon any one side of
a polygon.</cd> <au>Farrow.</au> -- <col><b>Front of
operations</b></col>, <cd>all that part of the field of operations in
front of the successive positions occupied by the army as it moves
forward.</cd> <au>Farrow.</au> -- <col><b>To come to the
front</b></col>, <cd>to attain prominence or leadership.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Front</ent><br/
<hw>Front</hw>, <pos>a.</pos> <def>Of or relating to the front or
forward part; having a position in front; foremost; <as>as, a
<ex>front</ex> view</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Front</ent><br/
<hw>Front</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Fronted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Fronting</conjf>.]</vmorph> <sn>1.</sn> <def>To oppose face to
face; to oppose directly; to meet in a hostile manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>You four shall <qex>front</qex> them in the narrow lane.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To appear before; to meet.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>[Enid] daily <qex>fronted</qex> him<br/
In some fresh splendor.</q> <rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To face toward; to have the front toward; to
confront; <as>as, the house <ex>fronts</ex> the street</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And then suddenly <qex>front</qex> the changed reality.</q>
<rj><qau>J. Morley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To stand opposed or opposite to, or over against as,
his house fronts the church.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To adorn in front; to supply a front to; <as>as, to
<ex>front</ex> a house with marble; to <ex>front</ex> a head with
laurel</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Yonder walls, that pertly <qex>front</qex> your town.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Front</ent><br/
<hw>Front</hw>, <pos>v. t.</pos> <def>To have or turn the face or front
in any direction; <as>as, the house <ex>fronts</ex> toward the
east</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frontage</ent><br/
<hw>Front"age</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The front part of an
edifice or lot; extent of front.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frontal</ent><br/
<hw>Fron"tal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>frontal</ets>.]</ety> <def>Belonging to the front part; being in
front</def>; esp. <fld>(Anat.)</fld>, <def>Of or pertaining to the
forehead or the anterior part of the roof of the brain case; <as>as, the
<ex>frontal</ex> bones</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frontal</ent><br/
<hw>Fron"tal</hw>, <pos>n.</pos> <ety>[F. <ets>frontal</ets>,
<ets>fronteau</ets>, OF. <ets>Frontel</ets>, <ets>frontal</ets>, L.
<ets>frontale</ets> an ornament for the forehead, frontlet. See
<er>Front</er>.]</ety> <sn>1.</sn> <def>Something worn on the forehead
or face; a frontlet</def>; as: <sd>(a)</sd> <def>An ornamental band for
the hair.</def> <sd>(b)</sd> <fld>(Mil.)</fld> <def>The metal face guard
of a soldier.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 599 --></p>

<p><sn>2.</sn> <fld>(Arch.)</fld> <def>A little pediment over a door or
window.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Eccl.)</fld> <def>A movable, decorative member in
metal, carved wood, or, commonly, in rich stuff or in embroidery,
covering the front of the altar. Frontals are usually changed according
to the different ceremonies.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Med.)</fld> <def>A medicament or application for
the forehead.</def> <mark>[Obs.]</mark> <rj><au>Quincy.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Anat.)</fld> <def>The frontal bone, or one of the
two frontal bones, of the cranium.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Frontal hammer</b></col> <it>or</it>
<col><b>Frontal helve</b></col></mcol>, <cd>a forge hammer lifted by a
cam, acting upon a <ldquo/tongue<rdquo/ immediately in front of the
hammer head.</cd> <rj><au>Raymond.</au></rj></cs></p>

<p><ent>Fron'tated</ent><br/
<ent>Frontate</ent><br/
<mhw>{ <hw>Fron"tate</hw> <pr>(?)</pr>, <hw>Fron'ta*ted</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <def>Growing broader and broader, as
a leaf; truncate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>frontbench</ent><br/
<hw>frontbench</hw> <pos>n.</pos> <def>any of the front seats in the
House of Commons of Great Britain that are reserved for ministers or
ex-ministers.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>frontbencher</ent><br/
<hw>frontbencher</hw> <pos>n.</pos> <def>a member of the House of
Commons of Great Britain who is a minister or an ex-minister.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fronted</ent><br/
<hw>Front"ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Formed with a front;
drawn up in line.</def> <ldquo/Fronted brigades.<rdquo/
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frontier</ent><br/
<hw>Fron"tier</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>fronti<egrave/re</ets>, LL. <ets>frontaria</ets>. See
<er>Front</er>.]</ety> <sn>1.</sn> <def>That part of a country which
fronts or faces another country or an unsettled region; the marches; the
border, confine, or extreme part of a country, bordering on another
country; the border of the settled and cultivated part of a country;
<as>as, the <ex>frontier</ex> of civilization</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Fort.)</fld> <def>An outwork.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Palisadoes, <qex>frontiers</qex>, parapets.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frontier</ent><br/
<hw>Fron"tier</hw>, <pos>a.</pos> <sn>1.</sn> <def>Lying on the exterior
part; bordering; conterminous; <as>as, a <ex>frontier</ex>
town</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of or relating to a frontier.</def> <ldquo/Frontier
experience.<rdquo/ <rj><au>W. Irving.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frontier</ent><br/
<hw>Fron"tier</hw>, <pos>v. i.</pos> <def>To constitute or form a
frontier; to have a frontier; -- with on.</def> <mark>[Obs.]</mark>
<rj><au>Sir W. Temple.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frontiered</ent><br/
<hw>Fron"tiered</hw> <pr>(?)</pr>, <pos>p. a.</pos> <def>Placed on the
frontiers.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frontiersman</ent><br/
<hw>Fron"tiers*man</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Frontiersmen</plw> <pr>(<?/)</pr>.</plu> <def>A man living on the
frontier.</def></p>

<p><ent>Frontignan</ent><br/
<ent>Frontignac</ent><br/
<mhw>\'d8<hw>Fron`ti*gnac"</hw> <pr>(?)</pr>, <hw>Fron`ti`gnan"</hw>
<pr>(<?/)</pr></mhw>, <pos>n.</pos> <ety>[So called from
<ets>Frontignan</ets>, a town in Southern France.]</ety> <sn>1.</sn>
<def>A sweet muscadine wine made in Frontignan (Languedoc),
France.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>A grape of many varieties and
colors.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frontingly</ent><br/
<hw>Front"ing*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a fronting
or facing position; opposingly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frontiniac</ent><br/
<hw>Fron`tin*iac"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Frontignac</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frontispiece</ent><br/
<hw>Fron"tis*piece</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>frontispice</ets>, LL. <ets>frontispicium</ets> beginning, front of
a church, fr. L. <ets>frons</ets> front + <ets>spicere</ets>,
<ets>specere</ets>, to look at, view: cf. It. <ets>frontispizio</ets>.
See <er>Front</er> and <er>Spy</er>.]</ety> <def>The part which first
meets the eye</def>; as: <sd>(a)</sd> <fld>(Arch.)</fld> <def>The
principal front of a building.</def> <mark>[Obs. or R.]</mark>
<sd>(b)</sd> <def>An ornamental figure or illustration fronting the
first page, or titlepage, of a book; formerly, the titlepage
itself.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frontless</ent><br/
<hw>Front"less</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Without face or
front; shameless; not diffident; impudent.</def> <mark>[Obs.]</mark>
<ldquo/<xex>Frontless</xex> vice.<rdquo/ <au>Dryden.</au>
<ldquo/<xex>Frontless</xex> flattery.<rdquo/ <au>Pope.</au><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frontlessly</ent><br/
<hw>Front"less*ly</hw>, <pos>adv.</pos> <def>Shamelessly;
impudently.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frontlet</ent><br/
<hw>Front"let</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF. frontelet brow
band, dim. of <ets>frontel</ets>, <ets>frontal</ets>. See
<er>Frontal</er>, <pos>n.</pos>]</ety> <sn>1.</sn> <def>A frontal or
brow band; a fillet or band worn on the forehead.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They shall be as <qex>frontlets</qex> between thine eyes.</q>
<rj><qau>Deut. vi. 8.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A frown (likened to a frontlet).</def> <mark>[R. &
Poetic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>What makes that <qex>frontlet</qex> on? Methinks you are too much
of late i' the frown.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <def>The margin of the head, behind
the bill of birds, often bearing rigid bristles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fronto-</ent><br/
<hw>Fron"to-</hw> <pr>(?)</pr>. <ety>[L. <ets>frons</ets>,
<ets>frontis</ets>, the forehead.]</ety> <fld>(Anat.)</fld> <def>A
combining form signifying <xex>relating to the forehead</xex> or
<xex>the frontal bone</xex>; <as>as, <ex>fronto-</ex>parietal, relating
to the frontal and the parietal bones; <ex>fronto-</ex>nasal,
etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fronton</ent><br/
\'d8<hw>Fron`ton"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., a pediment.
See <er>Front</er>.]</ety> <fld>(Arch.)</fld> <def>Same as
<er>Frontal</er>, 2.</def> <--2. a jai-alai fronton --><br/
[<source>1913 Webster</source>]</p>

<p><ent>front-runner</ent><br/
<hw>front-runner</hw> <pos>n.</pos> <def>a competitor thought to be most
likely to win.</def><br/
<syn><b>Syn. --</b> favorite, favourite.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Froppish</ent><br/
<hw>Frop"pish</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. <er>Frap</er>,
<er>Frape</er>.]</ety> <def>Peevish; froward.</def> <mark>[Obs.]</mark>
<rj><au>Clarendon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frore</ent><br/
<hw>Frore</hw> <pr>(?)</pr>, <pos>adv.</pos> <ety>[See
<er>Frorn</er>.]</ety> <def>Frostily.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The parching air<br/
Burns <qex>frore</qex>, and cold performs the effect of fire.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frorn</ent><br/
<hw>Frorn</hw> <pr>(?)</pr>, <pos>p. a.</pos> <ety>[AS.
<ets>froren</ets>, p. p. of <ets>fre<oacute/sun</ets> to freeze. See
<er>Freeze</er>.]</ety> <def>Frozen.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Well nigh <qex>frorn</qex> I feel.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frory</ent><br/
<hw>Fro"ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[AS.
<ets>fre<oacute/rig</ets>. See <er>Frorn</er>.]</ety> <sn>1.</sn>
<def>Frozen; stiff with cold.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Covered with a froth like hoarfrost.</def>
<mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The foaming steed with <qex>frory</qex> bit to steer.</q>
<rj><qau>Fairfax.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>frosh</ent><br/
<hw>frosh</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>frosh</plw> <pr>(<?/)</pr>.</plu> <ety>[from <ets>freshman</ets> by
shortening.]</ety> <def>a student during his first year in a high
school, college, or university; a <er>freshman</er>.</def>
<mark>[informal]</mark><br/
[<source>PJC</source>]</p>

<p><ent>Frost</ent><br/
<hw>Frost</hw> <pr>(fr<ocr/st; 115)</pr>, <pos>n.</pos> <ety>[OE.
<ets>frost</ets>, <ets>forst</ets>, AS. <ets>forst</ets>,
<ets>frost</ets>. fr. <ets>fre<oacute/san</ets> to freeze; akin to D.
<ets>varst</ets>, G., OHG., Icel., Dan., & Sw. <ets>frost</ets>.
<root/18. See <er>Freeze</er>, <pos>v. i.</pos>]</ety> <sn>1.</sn>
<def>The act of freezing; -- applied chiefly to the congelation of
water; congelation of fluids.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The state or temperature of the air which occasions
congelation, or the freezing of water; severe cold or freezing
weather.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The third bay comes a <qex>frost</qex>, a killing
<qex>frost</qex>.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Frozen dew; -- called also
<altname>hoarfrost</altname> or <altname>white
frost</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He scattereth the hoar<qex>frost</qex> like ashes.</q>
<rj><qau>Ps. cxlvii. 16.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Coldness or insensibility; severity or rigidity of
character.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>It was of those moments of intense feeling when the
<qex>frost</qex> of the Scottish people melts like a snow wreath.</q>
<rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<cs><p><col><b>Black frost</b></col>, <cd>cold so intense as to freeze
vegetation and cause it to turn black, without the formation of
hoarfrost.</cd> -- <col><b>Frost bearer</b></col> <fld>(Physics)</fld>,
<cd>a philosophical instrument illustrating the freezing of water in a
vacuum; a cryophorus.</cd> -- <col><b>Frost grape</b></col>
<fld>(Bot.)</fld>, <cd>an American grape, with very small, acid
berries.</cd> -- <col><b>Frost lamp</b></col>, <cd>a lamp placed below
the oil tube of an Argand lamp to keep the oil limpid on cold nights; --
used especially in lighthouses.</cd> <au>Knight.</au> -- <col><b>Frost
nail</b></col>, <cd>a nail with a sharp head driven into a horse's shoe
to keep him from slipping.</cd> -- <col><b>Frost smoke</b></col>, <cd>an
appearance resembling smoke, caused by congelation of vapor in the
atmosphere in time of severe cold.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>The brig and the ice round her are covered by a strange black<br/
obscurity: it is the <qex>frost</qex> smoke of arctic winters.</q>
<rj><qau>Kane.</qau></rj></p>

<p>-- <col><b>Frost valve</b></col>, <cd>a valve to drain the portion of
a pipe, hydrant, pump, etc., where water would be liable to freeze.</cd>
-- <col><b>Jack Frost</b></col>, <cd>a popular personification of
frost.</cd><br/
[<source>1913 Webster</source>]</p></cs>

<p><ent>Frost</ent><br/
<hw>Frost</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Frosted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Frosting</conjf>.]</vmorph> <sn>1.</sn> <def>To injure by frost;
to freeze, as plants.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To cover with hoarfrost; to produce a surface
resembling frost upon, as upon cake, metals, or glass; <as>as, glass may
be <ex>frosted</ex> by exposure to hydrofluoric acid</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>While with a hoary light she <qex>frosts</qex> the ground.</q>
<rj><qau>Wordsworth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To roughen or sharpen, as the nail heads or calks of
horseshoes, so as to fit them for frosty weather.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frostbird</ent><br/
<hw>Frost"bird</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>The golden plover.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frostbite</ent><br/
<hw>Frost"bite</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The freezing, or
effect of a freezing, of some part of the body, as the ears, fingers,
toes, or nose. Severe frostbite can lead to the loss of fingers or
toes.</def> <rj><au>Kane.</au></rj></p>

<p><ent>Frostbite</ent><br/
<hw>Frost`bite"</hw>, <pos>v. t.</pos> <def>To expose to the effect of
frost, or a frosty air; to blight or nip with frost.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>My wife up and with Mrs. Pen to walk in the fields to
<qex>frostbite</qex> themselves.</q> <rj><qau>Pepys.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frost-bitten</ent><br/
<hw>Frost`-bit"ten</hw> <pr>(?)</pr>, <pos>p. a.</pos> <def>Nipped,
withered, or injured, by frost or freezing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frost-blite</ent><br/
<hw>Frost`-blite"</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<sd>(a)</sd> <def>A plant of the genus <gen>Atriplex</gen>;
orache.</def> <au>Gray.</au> <sd>(b)</sd> <def>The lamb's-quarters
(<spn>Chenopodium album</spn>).</def> <rj><au>Dr. Prior.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frostbow</ent><br/
<hw>Frost"bow`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A white arc or
circle in the sky attending frosty weather and formed by reflection of
sunlight from ice crystals floating in the air; the parhelic circle
whose center is at the zenith.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Frosted</ent><br/
<hw>Frost"ed</hw>, <pos>a.</pos> <sn>1.</sn> <def>Covered with hoarfrost
or anything resembling hoarfrost; ornamented with frosting; also,
frost-bitten; <as>as, a <ex>frosted</ex> cake; <ex>frosted</ex>
donuts</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Provided with a surface finish which is matte or
with a very fine grain, reminiscent of the surface texture of frost;
<as>as, <ex>frosted</ex> glass</as>. Opposed to <ant>polished</ant> or
<ant>burnished</ant>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><q><qex>Frosted</qex> work is introduced as a foil or contrast to
burnished work.</q> <rj><qau>Knight.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frostfish</ent><br/
<hw>Frost`fish"</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<sd>(a)</sd> <def>The tomcod; -- so called because it is abundant on the
New England coast in autumn at about the commencement of frost. See
<er>Tomcod</er>.</def> <sd>(b)</sd> <def>The smelt.</def> <mark>[Local,
U. S.]</mark> <sd>(c)</sd> <def>A name applied in New Zealand to the
scabbard fish (<gen>Lepidotus</gen>) valued as a food fish.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frostian</ent><br/
<hw>Frostian</hw> <pos>prop. a.</pos> <def>of or pertaining to
<person>Robert Frost</person> (definition 4).</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Frostily</ent><br/
<hw>Frost"i*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a frosty
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frostiness</ent><br/
<hw>Frost"i*ness</hw>, <pos>n.</pos> <def>State or quality of being
frosty.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frosting</ent><br/
<hw>Frost"ing</hw>, <pos>n.</pos> <sn>1.</sn> <def>A composition of
sugar and beaten egg, used to cover or ornament cake, pudding,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A lusterless finish of metal or glass; the process
of producing such a finish.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>the lightened color on part of an object, as of
hair, produced by treatment with bleach or other chemicals; as only part
of the object is thus treated, the final color of the object is
two-toned; also, the process of producing such a two-toned
effect.</def><br/
[<source>PJC</source>]</p>

<p><ent>Frostless</ent><br/
<hw>Frost"less</hw>, <pos>a.</pos> <sn>1.</sn> <def>Free from frost;
<as>as, a <ex>frostless</ex> winter</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>same as <er>frost-free</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Frost-free</ent><br/
<hw>Frost"-free</hw>, <pos>a.</pos> <def>not accumulating frost; -- used
especially of refrigerators with an automatic defrost cycle such that
the freezer compartment remains free of ice without need for a manual
defrosting.</def><br/
[<source>PJC</source>]</p>

<p><ent>Frost signal</ent><br/
<hw>Frost" sig`nal</hw>. <fld>(Meteor.)</fld> <def>A signal consisting
of a white flag with a black center, used by the United States Weather
Bureau to indicate that a local frost is expected. It is used only in
Florida and along the coasts of the Pacific and the Gulf
Mexico.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Frostweed</ent><br/
<hw>Frost"weed`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>An American species of rockrose (<spn>Helianthemum
Canadense</spn>), sometimes used in medicine as an astringent or
aromatic tonic.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ It has large yellow flowers which are often sterile, and
later it has abundant but inconspicuous flowers which bear seed. It is
so called because, late in autumn, crystals of ice shoot from the
cracked bark at the root; -- called also frostwort.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frostwork</ent><br/
<hw>Frost`work"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The figurework,
often fantastic and delicate, which moisture sometimes forms in
freezing, as upon a window pane or a flagstone.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frostwort</ent><br/
<hw>Frost`wort"</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>Same as <er>Frostweed</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frosty</ent><br/
<hw>Frost"y</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. AS.
<ets>fyrstig</ets>.]</ety> <sn>1.</sn> <def>Attended with, or producing,
frost; having power to congeal water; cold; freezing; <as>as, a
<ex>frosty</ex> night</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Covered with frost; <as>as, the grass is
<ex>frosty</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Chill in affection; without warmth of affection or
courage.</def> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Appearing as if covered with hoarfrost; white;
gray-haired; <as>as, a <ex>frosty</ex> head</as>.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frote</ent><br/
<hw>Frote</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[F.
<ets>frotter</ets>.]</ety> <def>To rub or wear by rubbing; to
chafe.</def> <mark>[Obs.]</mark> <rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Froterer</ent><br/
<hw>Fro"ter*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who frotes; one
who rubs or chafes.</def> <mark>[Obs.]</mark>
<rj><au>Marston.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Froth</ent><br/
<hw>Froth</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>frothe</ets>,
Icel. <ets>fro<edh/a</ets>; akin to Dan. <ets>fraade</ets>, Sw.
<ets>fradga</ets>, AS. <ets><amac/freo<edh/an</ets> to froth.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>The bubbles caused in fluids or liquors by
fermentation or agitation; spume; foam; esp., a spume of saliva caused
by disease or nervous excitement.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Any empty, senseless show of wit or eloquence;
rhetoric without thought.</def> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>It was a long speech, but all <qex>froth</qex>.</q>
<rj><qau>L'Estrange.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Light, unsubstantial matter.</def>
<rj><au>Tusser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Froth insect</b></col> <fld>(Zool.)</fld>, <cd>the cuckoo
spit or frog hopper; -- called also <altname>froth spit</altname>,
<altname>froth worm</altname>, and <altname>froth fly</altname>.</cd> --
<col><b>Froth spit</b></col>. <cd>See <cref>Cuckoo spit</cref>, under
Cuckoo.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Froth</ent><br/
<hw>Froth</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Frothed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>.
<conjf>Frothing</conjf>.]</vmorph> <sn>1.</sn> <def>To cause to
foam.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To spit, vent, or eject, as froth.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He . . . <qex>froths</qex> treason at his mouth.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Is your spleen <qex>frothed</qex> out, or have ye more?</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To cover with froth; <as>as, a horse <ex>froths</ex>
his chain</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Froth</ent><br/
<hw>Froth</hw>, <pos>v. i.</pos> <def>To throw up or out spume, foam, or
bubbles; to foam; as beer <xex>froths</xex>; a horse
<xex>froths</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frothily</ent><br/
<hw>Froth"i*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a frothy
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frothiness</ent><br/
<hw>Froth"i*ness</hw>, <pos>n.</pos> <def>State or quality of being
frothy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frothing</ent><br/
<hw>Froth"ing</hw>, <pos>n.</pos> <def>Exaggerated declamation;
rant.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frothless</ent><br/
<hw>Froth"less</hw>, <pos>a.</pos> <def>Free from froth.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frothy</ent><br/
<hw>Froth"y</hw> <pr>(?)</pr>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Frothier</adjf> <pr>(?)</pr>; <pos>superl.</pos>
<adjf>Frothiest</adjf>.]</amorph> <sn>1.</sn> <def>Full of foam or
froth, or consisting of froth or light bubbles; spumous;
foamy.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Not firm or solid; soft; unstable.</def>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Of the nature of froth; light; empty; unsubstantial;
<as>as, a <ex>frothy</ex> speaker or harangue</as>.</def>
<rj><au>Tillotson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Froufrou</ent><br/
\'d8<hw>Frou"frou`</hw> <pr>(fr<oomac/"fr<oomac/`)</pr>, <pos>n.</pos>
<ety>[F., of imitative origin.]</ety> <sn>1.</sn> <def>A rustling, esp.
the rustling of a woman's dress.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>showy or frilly ornamentation.</def>
<au>MW10</au><br/
[<source>PJC</source>]</p>

<p><ent>Frounce</ent><br/
<hw>Frounce</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Frounced</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Frouncing</conjf> <pr>(?)</pr>.]</vmorph> <ety>[OE.
<ets>frouncen</ets>, <ets>fronsen</ets>, to told, wrinkle, OF.
<ets>froncier</ets>, F. <ets>froncer</ets>, perh. fr. an assumed LL.
<ets>frontiare</ets> to wrinkle the forehead, L. <ets>frons</ets>
forehead. See <er>Front</er>, and cf. <er>Flounce</er> part of a
dress.]</ety> <def>To gather into or adorn with plaits, as a dress; to
form wrinkles in or upon; to curl or frizzle, as the hair.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Not tricked and <qex>frounced</qex>, as she was wont.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frounce</ent><br/
<hw>Frounce</hw>, <pos>v. i.</pos> <def>To form wrinkles in the
forehead; to manifest displeasure; to frown.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The Commons <qex>frounced</qex> and stormed.</q> <rj><qau>
Holland.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frounce</ent><br/
<hw>Frounce</hw>, <pos>n.</pos> <sn>1.</sn> <def>A wrinkle, plait, or
curl; a flounce; -- also, a frown.</def> <mark>[Obs.]</mark>
<rj><au>Beau. & Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An affection in hawks, in which white spittle
gathers about the hawk's bill.</def> <rj><au>Booth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frounceless</ent><br/
<hw>Frounce"less</hw>, <pos>a.</pos> <def>Without frounces.</def>
<rj><au>Rom. of R.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frouzy</ent><br/
<hw>Frou"zy</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Prov. E.
<ets>frouzy</ets> froward, peevish, offensive to the eye or smell; cf.
<ets>froust</ets> a musty smell, frouse to rumple, frouze to curl, and
E. <ets>frounce</ets>, <ets>frowy</ets>.]</ety> <def>Fetid, musty; rank;
disordered and offensive to the smell or sight; slovenly; dingy. See
<er>Frowzy</er>.</def> <ldquo/Petticoats in <xex>frouzy</xex>
heaps.<rdquo/ <rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frow</ent><br/
<hw>Frow</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[D. <ets>vrouw</ets>;
akin to G. <ets>frau</ets> woman, wife, goth, <ets>fr<aacute/uja</ets>
master, lord, AS. <ets>fre<aacute/</ets>.]</ety> <sn>1.</sn> <def>A
woman; especially, a Dutch or German woman.</def> <rj><au>Beau. &
Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A dirty woman; a slattern.</def> <mark>[Prov.
Eng.]</mark> <rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frow</ent><br/
<hw>Frow</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf.
<er>Frower</er>.]</ety> <def>A cleaving tool with handle at right angles
to the blade, for splitting cask staves and shingles from the block; a
frower.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frow</ent><br/
<hw>Frow</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Brittle.</def>
<mark>[Obs.]</mark> <rj><au>Evelyn.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Froward</ent><br/
<hw>Fro"ward</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Fro</ets> +
<ets>-ward</ets>. See <er>Fro</er>, and cf. <er>Fromward</er>.]</ety>
<def>Not willing to yield or comply with what is required or is
reasonable; perverse; disobedient; peevish; <as>as, a <ex>froward</ex>
child</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>froward</qex> man soweth strife.</q> <rj><qau>Prov. xvi.
28.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>froward</qex> retention of custom is as turbulent a thing
as innovation.</q> <rj><qau>Bacon.</qau></rj></p>

<p><syn><b>Syn.</b> -- Untoward; wayward; unyielding; ungovernable:
refractory; obstinate; petulant; cross; peevish. See
<er>Perverse</er>.</syn></p>

<p>-- <wordforms><wf>Fro"ward*ly</wf>, <pos>adv.</pos> --
<wf>Fro"ward*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frower</ent><br/
<hw>Frow"er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. <ets>frow</ets> a
frower, and Prov. E, <ets>frommard</ets>.]</ety> <def>A tool. See 2d
<er>Frow</er>.</def> <rj><au>Tusser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frowey</ent><br/
<hw>Frow"ey</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See <er>Frow</er>,
<pos>a.</pos>]</ety> <fld>(Carp.)</fld> <def>Working smoothly, or
without splitting; -- said of timber.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frown</ent><br/
<hw>Frown</hw> <pr>(froun)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Frowned</conjf> <pr>(fround)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Frowning</conjf>.]</vmorph> <ety>[OF.
<ets>froignier</ets>, F. <ets>frogner</ets>, <ets>in se refrogner</ets>,
<ets>se renfrogner</ets>, to knit the brow, to frown; perh. of Teutonic
origin; cf. It. <ets>in frigno</ets> wrinkled, frowning, Prov. It.
<ets>frignare</ets> to cringe the face, to make a wry face, dial. Sw.
<ets>fryna</ets> to make a wry face,]</ety> <sn>1.</sn> <def>To contract
the brow in displeasure, severity, or sternness; to scowl; to put on a
stern, grim, or surly look.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>frowning</qex> wrinkle of her brow.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To manifest displeasure or disapprobation; to look
with disfavor or threateningly; to lower; <as>as, polite society
<ex>frowns</ex> upon rudeness</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The sky doth <qex>frown</qex> and lower upon our army.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frown</ent><br/
<hw>Frown</hw>, <pos>v. t.</pos> <def>To repress or repel by expressing
displeasure or disapproval; to rebuke with a look; <as>as,
<ex>frown</ex> the impudent fellow into silence</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frown</ent><br/
<hw>Frown</hw>, <pos>n.</pos> <sn>1.</sn> <def>A wrinkling of the face
in displeasure, rebuke, etc.; a sour, severe, or stern look; a
scowl.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His front yet threatens, and his <qex>frowns</qex> command.</q>
<rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Her very <qex>frowns</qex> are fairer far<br/
Than smiles of other maidens are.</q> <rj><qau>H.
Coleridge.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Any expression of displeasure; <as>as, the
<ex>frowns</ex> of Providence; the <ex>frowns</ex> of
Fortune.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frowningly</ent><br/
<hw>Frown"ing*ly</hw>, <pos>adv.</pos> <def>In a frowning
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frowny</ent><br/
<hw>Frown"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Frowning;
scowling.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Her <qex>frowny</qex> mother's ragged shoulder.</q> <rj><qau>Sir
F. Palgrave.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frowy</ent><br/
<hw>Frow"y</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. <er>Frowzy</er>,
<er>Frouzy</er>.]</ety> <def>Musty; rancid; <as>as, <ex>frowy</ex>
butter</as>.</def> <ldquo/<xex>Frowy</xex> feed.<rdquo/
<rj><au>Spenser</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frowzy</ent><br/
<hw>Frow"zy</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Frouzy</er>.]</ety> <def>Slovenly; unkempt; untidy; frouzy.</def>
<ldquo/With head all <xex>frowzy</xex>.<rdquo/
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>frowzy</qex> soldiers' wives hanging out clothes.</q>
<rj><qau>W. D. Howells.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Froze</ent><br/
<hw>Froze</hw> <pr>(?)</pr>, <def><pos>imp.</pos> of
<er>Freeze</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frozen</ent><br/
<hw>Fro"zen</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Congealed
with cold; affected by freezing; <as>as, a <ex>frozen</ex>
brook</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They warmed their <qex>frozen</qex> feet.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Subject to frost, or to long and severe cold;
chilly; <as>as, the <ex>frozen</ex> north; the <ex>frozen</ex>
zones.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Cold-hearted; unsympathetic; unyielding.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Be not ever <qex>frozen</qex>, coy.</q> <rj><qau>T.
Carew.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frozenness</ent><br/
<hw>Fro"zen*ness</hw>, <pos>n.</pos> <def>A state of being
frozen.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frubish</ent><br/
<hw>Frub"ish</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[See
<er>Furbish</er>.]</ety> <def>To rub up: to furbish.</def>
<mark>[Obs.]</mark> <rj><au>Beau. & Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fructed</ent><br/
<hw>Fruc"ted</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>fructus</ets> fruit. See <er>Fruit</er>.]</ety> <fld>(Her.)</fld>
<def>Bearing fruit; -- said of a tree or plant so represented upon an
escutcheon.</def> <rj><au>Cussans.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fructescence</ent><br/
<hw>Fruc*tes"cence</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>fructus</ets> fruit.]</ety> <fld>(Bot.)</fld> <def>The maturing or
ripening of fruit.</def> <mark>[R.]</mark> <rj><au>Martyn.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fructiculose</ent><br/
<hw>Fruc*tic"u*lose`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Fruitful;
full of fruit.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fructidor</ent><br/
\'d8<hw>Fruc`ti`dor"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr. L.
<ets>fructus</ets> fruit.]</ety> <def>The twelfth month of the French
republican calendar; -- commencing August 18, and ending September 16.
See <er>Vend<eacute/miaire</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fructiferuos</ent><br/
\'d8<hw>Fruc*tif"er*uos</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>fructifer</ets>; <ets>fructus</ets> fruit + <ets>ferre</ets> to
bear; cf. F. <ets>fructif<egrave/re</ets>.]</ety> <def>Bearing or
producing fruit.</def> <rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fructification</ent><br/
\'d8<hw>Fruc`ti*fi*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>fructificatio</ets>: cf. F. <ets>fructification</ets>.]</ety>
<sn>1.</sn> <def>The act of forming or producing fruit; the act of
fructifying, or rendering productive of fruit; fecundation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The prevalent <qex>fructification</qex> of plants.</q>
<rj><qau>Sir T. Brown.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <sd>(a)</sd> <def>The collective organs
by which a plant produces its fruit, or seeds, or reproductive
spores.</def> <sd>(b)</sd> <def>The process of producing fruit, or
seeds, or spores.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 600 --></p>

<p><ent>Fructify</ent><br/
<hw>Fruc"ti*fy</hw> <pr>(fr<ucr/k"t<icr/*f<imac/)</pr>, <pos>v. i.</pos>
<ety>[F. <ets>fructifier</ets>, L. <ets>fructificare</ets>;
<ets>fructus</ets> fruit + <ets>-ficare</ets> (only in comp.), akin to
L. <ets>facere</ets> to make. See <er>Fruit</er>, and
<er>Fact</er>.]</ety> <def>To bear fruit.</def> <ldquo/Causeth the earth
to <xex>fructify</xex>.<rdquo/ <rj><au>Beveridge.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fructify</ent><br/
<hw>Fruc"ti*fy</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Fructified</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Fructifying</conjf>.]</vmorph> <def>To make fruitful; to render
productive; to fertilize; <as>as, to <ex>fructify</ex> the
earth</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fructose</ent><br/
<hw>Fruc*tose"</hw> <pr>(fr<ucr/k*t<omac/s" <it>or</it>
fr<ucr/k"t<omac/s)</pr>, <pos>n.</pos> <ety>[L. <ets>fructus</ets>
fruit.]</ety> <fld>(Chem.)</fld> <def>Fruit sugar; levulose.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fructuary</ent><br/
<hw>Fruc"tu*a*ry</hw> <pr>(fr<ucr/k"t<usl/*<asl/*r<ycr/)</pr>,
<pos>n.</pos>; <plu><it>pl.</it> <plw>Fructuaries</plw>
<pr>(-r<icr/z)</pr>.</plu> <ety>[L. <ets>fructuarius</ets>.]</ety>
<def>One who enjoys the profits, income, or increase of
anything.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Kings are not proprietors nor <qex>fructuaries</qex>.</q>
<rj><qau>Prynne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fructuation</ent><br/
<hw>Fruc"tu*a`tion</hw> <pr>(-<amac/"sh<ucr/n)</pr>, <pos>n.</pos>
<def>Produce; fruit.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fructuous</ent><br/
<hw>Fruc"tu*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>fructuosus</ets>: cf, F. <ets>fructueux</ets>.]</ety>
<def>Fruitful; productive; profitable.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Nothing <qex>fructuous</qex> or profitable.</q>
<rj><qau>Chaucer.</qau></rj></p>

<p>-- <wordforms><wf>Fruc"tu*ous*ly</wf>, <pos>adv.</pos> --
<wf>Fruc"tu*ous*ness</wf>, <pos>n.</pos>
<mark>[Obs.]</mark></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fructure</ent><br/
<hw>Fruc"ture</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>frui</ets>,
<ets>p. p. fructus</ets>, to enjoy. See <er>Fruit</er>,
<pos>n.</pos>]</ety> <def>Use; fruition; enjoyment.</def>
<mark>[Obs.]</mark> <rj><au>Cotgrave.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frue vanner</ent><br/
<hw>Frue" van"ner</hw> <pr>(?)</pr>. <ety>[Etymol. uncertain.]</ety>
<fld>(Mining)</fld> <def>A moving, inclined, endless apron on which ore
is concentrated by a current of water; a kind of buddle.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frugal</ent><br/
<hw>Fru"gal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>frugalis</ets>, fr. <ets>frugi</ets>, lit., for <ets>fruit</ets>;
hence, fit for food, useful, proper, temperate, the dative of
<ets>frux</ets>, <ets>frugis</ets>, fruit, akin to E. <ets>fruit</ets>:
cf. F. <ets>frugal</ets>. See <er>Fruit</er>, <pos>n.</pos>]</ety>
<sn>1.</sn> <def>Economical in the use or appropriation of resources;
not wasteful or lavish; wise in the expenditure or application of force,
materials, time, etc.; characterized by frugality; sparing; economical;
saving; <as>as, a <ex>frugal</ex> housekeeper; <ex>frugal</ex> of
time.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>I oft admire<br/
How Nature, wise and <qex>frugal</qex>, could commit<br/
Such disproportions.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Obtained by, or appropriate to, economy; <as>as, a
frugal fortune</as>.</def> <ldquo/<xex>Frugal</xex> fare.<rdquo/
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frugality</ent><br/
<hw>Fru*gal"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Frugalities</plw> <pr>(#)</pr>.</plu> <ety>[L.
<ets>frugalitas</ets>: cf. F. <ets>frugalit<eacute/</ets>.]</ety>
<sn>1.</sn> <def>The quality of being frugal; prudent economy; that
careful management of anything valuable which expends nothing
unnecessarily, and applies what is used to a profitable purpose; thrift;
--- opposed to <xex>extravagance</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Frugality</qex> is founded on the principle that all riches
have<br/
limits.</q> <rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A sparing use; sparingness; <as>as, frugality of
praise</as>.</def></p>

<p><syn><b>Syn.</b> -- Economy; parsimony. See
<er>Economy</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frugally</ent><br/
<hw>Fru"gal*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>Thriftily;
prudently.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frugalness</ent><br/
<hw>Fru"gal*ness</hw>, <pos>n.</pos> <def>Quality of being frugal;
frugality.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frugiferous</ent><br/
<hw>Fru*gif"er*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>frugifer</ets>; <ets>frux</ets>, <ets>frugis</ets>, fruit +
<ets>ferre</ets> to bear: cf. F. <ets>frugifere</ets>.]</ety>
<def>Producing fruit; fruitful; fructiferous.</def> <rj><au>Dr. H.
More.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frugivora</ent><br/
\'d8<hw>Fru*giv"o*ra</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL. See
<er>Frugivorous</er>.]</ety> <fld>(Zool.)</fld> <def>The fruit bate; a
group of the Cheiroptera, comprising the bats which live on fruits. See
<cref>Fruit bat</cref>, under <er>Fruit</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frugivorous</ent><br/
<hw>Fru*giv"o*rous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>frux</ets>, <ets>frugis</ets>, fruit + <ets>vorare</ets> to
devour.: cf. F. <ets>frugivore</ets>.]</ety> <def>Feeding on fruit, as
birds and other animals.</def> <rj><au>Pennant.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fruit</ent><br/
<hw>Fruit</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>fruit</ets>,
<ets>frut</ets>, F. <ets>fruit</ets>, from L. <ets>fructus</ets>
enjoyment, product, fruit, from <ets>frui</ets>, p. p.
<ets>fructus</ets>, to enjoy; akin to E. <ets>brook</ets>, <pos>v.
t.</pos> See <er>Brook</er>, <pos>v. t.</pos>, and cf.
<er>Fructify</er>, <er>Frugal</er>.]</ety> <sn>1.</sn> <def>Whatever is
produced for the nourishment or enjoyment of man or animals by the
processes of vegetable growth, as corn, grass, cotton, flax, etc.; --
commonly used in the plural.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Six years thou shalt sow thy land, and shalt gather in the<br/
<qex>fruits</qex> thereof.</q> <rj><qau>Ex. xxiii. 10.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Hort.)</fld> <def>The pulpy, edible seed vessels of
certain plants, especially those grown on branches above ground, as
apples, oranges, grapes, melons, berries, etc. See 3.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Bot.)</fld> <def>The ripened ovary of a flowering
plant, with its contents and whatever parts are consolidated with
it.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Fruits are classified as <xex>fleshy</xex>,
<xex>drupaceous</xex>, and <xex>dry</xex>. <stype>Fleshy fruits</stype>
include berries, gourds, and melons, orangelike fruits and pomes;
<stype>drupaceous fruits</stype> are stony within and fleshy without, as
peaches, plums, and cherries; and <stype>dry fruits</stype> are further
divided into <stype>achenes</stype>, <stype>follicles</stype>,
<stype>legumes</stype>, <stype>capsules</stype>, <stype>nuts</stype>,
and several other kinds.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Bot.)</fld> <def>The spore cases or conceptacles of
flowerless plants, as of ferns, mosses, algae, etc., with the spores
contained in them.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>The produce of animals; offspring; young; <as>as,
the <ex>fruit</ex> of the womb, of the loins, of the
body</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>King Edward's <qex>fruit</qex>, true heir to the English
crown.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>That which is produced; the effect or consequence of
any action; advantageous or desirable product or result; disadvantageous
or evil consequence or effect; <as>as, the <ex>fruits</ex> of labor, of
self-denial, of intemperance</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>fruit</qex> of rashness.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>What I obtained was the <qex>fruit</qex> of no bargain.</q>
<rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>They shall eat the <qex>fruit</qex> of their doings.</q>
<rj><qau>Is. iii 10.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>fruits</qex> of this education became visible.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Fruit</xex> is frequently used adjectively,
signifying <xex>of</xex>, <xex>for</xex>, <xex>or pertaining to</xex> a
<xex>fruit</xex> or <xex>fruits</xex>; as, <xex>fruit</xex> bud;
<xex>fruit</xex> frame; <xex>fruit</xex> jar; <xex>fruit</xex> knife;
<xex>fruit</xex> loft; <xex>fruit</xex> show; <xex>fruit</xex> stall;
<xex>fruit</xex> tree; etc.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fruit bat</b></col> <fld>(Zool.)</fld>, <cd>one of the
Frugivora; -- called also <altname>fruit-eating bat</altname>.</cd> --
<col><b>Fruit bud</b></col> <fld>(Bot.)</fld>, <cd>a bud that produces
fruit; -- in most oplants the same as the power bud.</cd> <col><b>Fruit
dot</b></col> <fld>(Bot.)</fld>, <cd>a collection of fruit cases, as in
ferns.</cd> See <er>Sorus</er>. -- <col><b>Fruit fly</b></col>
<fld>(Zool.)</fld>, <cd>a small dipterous insect of the genus
<gen>Drosophila</gen>, which lives in fruit, in the larval state. There
are seveal species, some of which are very damaging to fruit crops. One
species, <spn>Drosophila melanogaster</spn>, has been intensively
studied as a model species for genetic reserach.</cd> -- <col><b>Fruit
jar</b></col>, <cd>a jar for holding preserved fruit, usually made of
glass or earthenware.</cd> -- <col><b>Fruit pigeon</b></col>
<fld>(Zool.)</fld>, <cd>one of numerous species of pigeons of the family
<fam>Carpophagid<ae/</fam>, inhabiting India, Australia, and the Pacific
Islands. They feed largely upon fruit. and are noted for their beautiful
colors.</cd> -- <col><b>Fruit sugar</b></col> <fld>(Chem.)</fld>, <cd>a
kind of sugar occurring, naturally formed, in many ripe fruits, and in
honey; levulose. The name is also, though rarely, applied to
<cref>invert sugar</cref>, or to the natural mixture or dextrose and
levulose resembling it, and found in fruits and honey.</cd> --
<col><b>Fruit tree</b></col> <fld>(Hort.)</fld>, <cd>a tree cultivated
for its edible fruit.</cd> -- <col><b>Fruit worm</b></col>
<fld>(Zool.)</fld>, <cd>one of numerous species of insect larv<ae/:
which live in the interior of fruit. They are mostly small species of
Lepidoptera and Diptera.</cd> -- <col><b>Small fruits</b></col>
<fld>(Hort.)</fld>, <cd>currants, raspberries, strawberries,
etc.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fruit</ent><br/
<hw>Fruit</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To bear fruit.</def>
<rj><au>Chesterfield.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fruitage</ent><br/
<hw>Fruit"age</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>fruitage</ets>.]</ety> <sn>1.</sn> <def>Fruit, collectively; fruit,
in general; fruitery.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The trees . . . ambrosial <qex>fruitage</qex> bear.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Product or result of any action; effect, good or
ill.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fruiter</ent><br/
<hw>Fruit"er</hw> <pr>(?)</pr>, <pos>a.</pos> <def>A ship for carrying
fruit.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fruiterer</ent><br/
<hw>Fruit"er*er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>fruitier</ets>.]</ety> <def>One who deals in fruit; a seller of
fruits.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fruiteress</ent><br/
<hw>Fruit"er*ess</hw>, <pos>n.</pos> <def>A woman who sells
fruit.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fruitery</ent><br/
<hw>Fruit"er*y</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Fruiteries</plw> <pr>(#)</pr>.</plu> <ety>[F. <ets>fruiterie</ets>
place where fruit is kept, in OF. also, <ets>fruitage</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Fruit, taken collectively; fruitage.</def>
<rj><au>J. Philips.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A repository for fruit.</def>
<rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fruitestere</ent><br/
<hw>Fruit"es*tere</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A
fruiteress.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fruitful</ent><br/
<hw>Fruit"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Full of fruit;
producing fruit abundantly; bearing results; prolific; fertile; liberal;
bountiful; <as>as, a <ex>fruitful</ex> tree, or season, or soil; a
<ex>fruitful</ex> wife.</as></def> -- <wordforms><wf>Fruit"ful*ly</wf>,
<pos>adv.</pos> -- <wf>Fruit"ful*ness</wf>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><q>Be <qex>fruitful</qex> and multiply and replenish the earth.</q>
<rj><qau>Gen. i. 28.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>[Nature] By disburdening grows<br/
More <qex>fruitful</qex>.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The great <qex>fruitfulness</qex> of the poet's fancy.</q>
<rj><qau>Addison.</qau></rj></p>

<p><syn><b>Syn.</b> -- Fertile; prolific; productive; fecund; plentiful;
rich; abundant; plenteous. See <er>Fertile</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fruiting</ent><br/
<hw>Fruit"ing</hw>, <pos>a.</pos> <def>Pertaining to, or producing,
fruit.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fruiting</ent><br/
<hw>Fruit"ing</hw>, <pos>n.</pos> <def>The bearing of fruit.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fruition</ent><br/
<hw>Fru*i"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>fruition</ets>, L. <ets>fruitio</ets>, enjoyment, fr. L.
<ets>frui</ets>, p. p. <ets>fruitus</ets>, to use or enjoy. See
<er>Fruit</er>, <pos>n.</pos>]</ety> <def>Use or possession of anything,
especially such as is accompanied with pleasure or satisfaction;
pleasure derived from possession or use.</def> <ldquo/Capacity of
<xex>fruition</xex>.<rdquo/ <au>Rogers.</au> <ldquo/Godlike
<xex>fruition</xex>.<rdquo/ <au>Milton.</au><br/
[<source>1913 Webster</source>]</p>

<p><q>Where I may have <qex>fruition</qex> of her love.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fruitive</ent><br/
<hw>Fru"i*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Fruition</er>.]</ety> <def>Enjoying; possessing.</def>
<mark>[Obs.]</mark> <rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fruitless</ent><br/
<hw>Fruit"less</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Lacking, or not bearing, fruit; barren; destitute of offspring;
<as>as, a <ex>fruitless</ex> tree or shrub; a <ex>fruitless</ex>
marriage.</as></def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Productive of no advantage or good effect; vain;
idle; useless; unprofitable; <as>as, a <ex>fruitless</ex> attempt; a
<ex>fruitless</ex> controversy.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>They in mutual accusation spent<br/
The <qex>fruitless</qex> hours.</q> <rj><qau>Milton.</qau></rj></p>

<p><syn><b>Syn.</b> -- Useless; barren; unprofitable; abortive;
ineffectual; vain; idle; profitless. See <er>Useless</er>.</syn></p>

<p>-- <wordforms><wf>Fruit"less*ly</wf>, <pos>adv.</pos> --
<wf>Fruit"lness*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fruit'y</ent><br/
<hw>Fruit'y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having the odor,
taste, or appearance of fruit; also, fruitful.</def>
<rj><au>Dickens.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frumentaceous</ent><br/
<hw>Fru"men*ta"ceous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>frumentaceus</ets>, fr. <ets>frumentum</ets> corn or grain, from
the root of <ets>frux</ets> fruit: cf. F. <ets>frumentac<eacute/</ets>.
See <er>Frugal</er>.]</ety> <def>Made of, or resembling, wheat or other
grain.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frumentarious</ent><br/
<hw>Fru`men*ta"ri*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
frumentarius.]</ety> <def>Of or pertaining to wheat or grain.</def>
<mark>[R.]</mark> <rj><au>Coles.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frumentation</ent><br/
<hw>Fru`men*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>frumentatio</ets>.]</ety> <fld>(Rom. Antiq.)</fld> <def>A largess
of grain bestowed upon the people, to quiet them when uneasy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frumenty</ent><br/
<hw>Fru"men*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>froment<eacute/e</ets>, fr. L. <ets>frumentum</ets>. See
<er>Frumentaceous</er>.]</ety> <def>Food made of hulled wheat boiled in
milk, with sugar, plums, etc.</def> <altsp>[Written also
<asp>furmenty</asp> and <asp>furmity</asp>.]</altsp>
<rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frump</ent><br/
<hw>Frump</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Cf. Prov. E.
<ets>frumple</ets> to wrinkle, ruffle, D. <ets>frommelen</ets>.]</ety>
<def>To insult; to flout; to mock; to snub.</def> <mark>[Obs.]</mark>
<rj><au>Beau. & Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frump</ent><br/
<hw>Frump</hw>, <pos>n.</pos> <sn>1.</sn> <def>A contemptuous speech or
piece of conduct; a gibe or flout.</def> <mark>[Obs.]</mark>
<rj><au>Beau. & Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A cross, old-fashioned person; esp., an old woman; a
gossip.</def> <mark>[Colloq.]</mark> <rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frumper</ent><br/
<hw>Frump"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A mocker.</def>
<mark>[Obs.]</mark> <rj><au>Cotgrave.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frumpish</ent><br/
<hw>Frump"ish</hw>, <pos>a.</pos> <sn>1.</sn> <def>Cross-tempered;
scornful.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Old-fashioned, as a woman's dress.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Our Bell . . . looked very <qex>frumpish</qex>.</q>
<rj><qau>Foote.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frush</ent><br/
<hw>Frush</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[F.
<ets>froisser</ets> to bruise. Cf. <er>Froise</er>.]</ety> <def>To
batter; to break in pieces.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I like thine armor well;<br/
I'll <qex>frush</qex> it and unlock the rivets all.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frush</ent><br/
<hw>Frush</hw>, <pos>a.</pos> <def>Easily broken; brittle;
crisp.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frush</ent><br/
<hw>Frush</hw>, <pos>n.</pos> <def>Noise; clatter; crash.</def>
<mark>[R.]</mark> <rj><au>Southey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frush</ent><br/
<hw>Frush</hw>, <pos>n.</pos> <ety>[Cf. OE. <ets>frosch</ets>,
<ets>frosk</ets>, a frog (the animal), G. <ets>frosch</ets> frog (the
animal), also carney or lampass of horses. See <er>Frog</er>,
<pos>n.</pos>, 2.]</ety> <sn>1.</sn> <fld>(Far.)</fld> <def>The frog of
a horse's foot.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A discharge of a fetid or ichorous matter from the
frog of a horse's foot; -- also called
<altname>thrush.</altname></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frustrable</ent><br/
<hw>Frus"tra*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>frustrabilis</ets>: cf. F. <ets>frustable</ets>.]</ety>
<def>Capable of being frustrated or defeated.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frustraneous</ent><br/
<hw>Frus*tra"ne*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Frustrate</er>, <pos>a.</pos>]</ety> <def>Vain; useless;
unprofitable.</def> <mark>[Obs.]</mark> <rj><au>South.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frustrate</ent><br/
<hw>Frus"trate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>frustratus</ets>, p. p. of <ets>frustrare</ets>,
<ets>frustrari</ets>, to deceive, frustrate, fr. <ets>frustra</ets> in
vain, witout effect, in erorr, prob. for <ets>frudtra</ets> and akin to
<ets>fraus</ets>, E. <ets>fraud</ets>.]</ety> <def>Vain; ineffectual;
useless; unprofitable; null; void; nugatory; of no effect.</def>
<ldquo/Our <xex>frustrate</xex> search.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frustrate</ent><br/
<hw>Frus"trate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Frustrated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Frustrating</conjf>.]</vmorph> <sn>1.</sn> <def>To bring
to nothing; to prevent from attaining a purpose; to disappoint; to
defeat; to baffle; <as>as, to <ex>frustrate</ex> a plan, design, or
attempt; to <ex>frustrate</ex> the will or purpose.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Shall the adversary thus obtain<br/
His end and <qex>frustrate</qex> thine ?</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To make null; to nullify; to render invalid or of no
effect; <as>as, to <ex>frustrate</ex> a conveyance or
deed</as>.</def></p>

<p><syn><b>Syn.</b> -- To balk; thwart; foil; baffle; defeat.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frustrately</ent><br/
<hw>Frus"trate*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In vain.</def>
<mark>[Obs.]</mark> <rj><au>Vicars.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>frustrating</ent><br/
<hw>frustrating</hw> <pos>n.</pos> <def>an act of hindering someone's
plans or efforts.</def><br/
<syn><b>Syn. --</b> frustration, thwarting, foiling.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>frustrating</ent><br/
<hw>frustrating</hw> <pos>adj.</pos> <sn>1.</sn> <def>preventing
realization or attainment of a desire; causing frustration.</def><br/
<syn><b>Syn. --</b> frustrative, thwarting.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>discouraging. Opposite of
<ant>encouraging</ant>.</def><br/
<syn><b>Syn. --</b> disappointing.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Frustration</ent><br/
<hw>Frus*tra"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>frustratio</ets>: cf. OF. <ets>frustration</ets>.]</ety> <def>The
act of frustrating; disappointment; defeat; <as>as, the
<ex>frustration</ex> of one's designs</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frustrative</ent><br/
<hw>Frus"tra*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Tending to
defeat; fallacious.</def> <mark>[Obs.]</mark>
<rj><au>Ainsworth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frustratory</ent><br/
<hw>Frus"tra*to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>frustratorius</ets>: cf. F. <ets>frustratoire</ets>.]</ety>
<def>Making void; rendering null; <as>as, a frustratory
appeal</as>.</def> <mark>[Obs.]</mark> <rj><au>Ayliffe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frustule</ent><br/
<hw>Frus"tule</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>frustulum</ets>, dim. fr. <ets>frustum</ets> a piece: cf. F.
<ets>frustule</ets>.]</ety> <fld>(Bot.)</fld> <def>The siliceous shell
of a diatom. It is composed of two valves, one overlapping the other,
like a pill box and its cover.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frustulent</ent><br/
<hw>Frus"tu*lent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>frustulentus</ets>. See <er>Frustule</er>.]</ety> <def>Abounding in
fragments.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frustum</ent><br/
\'d8<hw>Frus"tum</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it> L.
<plw>Frusta</plw> <pr>(#)</pr>, E. <plw>Frustums</plw>
<pr>(#)</pr>.</plu> <ety>[L. <ets>fruslum</ets> piece, bit.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <fld>(Geom.)</fld> <def>The part of a solid next the
base, formed by cutting off the, top; or the part of any solid, as of a
cone, pyramid, etc., between two planes, which may be either parallel or
inclined to each other.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Arch.)</fld> <def>One of the drums of the shaft of
a column.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frutage</ent><br/
<hw>Frut"age</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf.
<er>Fruitage</er>.]</ety> <sn>1.</sn> <def>A picture of fruit;
decoration by representation of fruit.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The cornices consist of <qex>frutages</qex> and festoons.</q>
<rj><qau>Evelyn.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A confection of fruit.</def> <mark>[Obs.]</mark>
<rj><au>Nares.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frutescent</ent><br/
<hw>Fru*tes"cent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>frutex</ets>, <ets>fruticis</ets>, shrub, bush: cf. F.
<ets>frutescent</ets>, L. <ets>fruticescens</ets>, <ets>p.
pr.</ets>]</ety> <fld>(Bot.)</fld> <def>Somewhat shrubby in character;
imperfectly shrubby, as the American species of
<gen>Wisteria</gen>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Frutex</ent><br/
\'d8<hw>Fru"tex</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.]</ety>
<fld>(Bot.)</fld> <def>A plant having a woody, durable stem, but less
than a tree; a shrub.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fruticant</ent><br/
<hw>Fru"ti*cant</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>fruticans</ets>, <ets>p. pr.</ets> of <ets>fruticare</ets>, to
become bushy, fr. <ets>frutex</ets>, fruticis, shrub.]</ety> <def>Full
of shoots.</def> <mark>[Obs.]</mark> <rj><au>Evelyn.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fruticose</ent><br/
<hw>Fru"ti*cose`</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>fruticosus</ets>, from frutex, <ets>fruticis</ets>, shrub]</ety>
<fld>(Bot.)</fld> <def>Pertaining to a shrub or shrubs; branching like a
shrub; shrubby; shrublike; <as>as, a <ex>fruticose</ex> stem</as>.</def>
<rj><au>Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fruticous</ent><br/
<hw>Fru"ti*cous</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Bot.)</fld>
<def>Fruticose.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fruticulose</ent><br/
<hw>Fru*tic"u*lose`</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Dim. fr. L.
<ets>fruticosus</ets> bushy: cf. F. <ets>fruticuleux</ets>.]</ety>
<fld>(Bot.)</fld> <def>Like, or pertaining to, a small shrub.</def>
<rj><au>Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fry</ent><br/
<hw>Fry</hw> <pr>(fr<imac/)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Fried</conjf> <pr>(fr<imac/d)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Frying</conjf>.]</vmorph> <ety>[OE. <ets>frien</ets>, F.
<ets>frire</ets>, fr. L. frigere to roast, parch, <ets>fry</ets>, cf.
Gr. <?/, Skr. <ets>bhrajj</ets>. Cf. <er>Fritter</er>.]</ety> <def>To
cook in a pan or on a griddle (esp. with the use of fat, butter, or
olive oil) by heating over a fire; to cook in boiling lard or fat;
<as>as, to <ex>fry</ex> fish; to <ex>fry</ex> doughnuts.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fry</ent><br/
<hw>Fry</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To undergo the process
of frying; to be subject to the action of heat in a frying pan, or on a
griddle, or in a kettle of hot fat.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To simmer; to boil.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>With crackling flames a caldron <qex>fries</qex>.</q>
<rj><qau>Dryden</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The frothy billows <qex>fry</qex>.</q>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To undergo or cause a disturbing action accompanied
with a sensation of heat.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To keep the oil from <qex>frying</qex> in the stomach.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To be agitated; to be greatly moved.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>What kindling motions in their breasts do <qex>fry</qex>.</q>
<rj><qau>Fairfax.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fry</ent><br/
<hw>Fry</hw>, <pos>n.</pos> <sn>1.</sn> <def>A dish of anything
fried.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A state of excitement; <as>as, to be in a
<ex>fry</ex></as>.</def> <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fry</ent><br/
<hw>Fry</hw>, <pos>n.</pos> <ety>[OE. <ets>fri</ets>, <ets>fry</ets>,
seed, descendants, cf. OF. <ets>froye</ets> spawning, spawn of. fishes,
little fishes, fr. L. <ets>fricare</ets> tosub (see <er>Friction</er>),
but cf. also Icel. <ets>fr<ae/</ets>, <ets>frj<omac/</ets>, seed, Sw. &
Dan. <ets>fr<oum/</ets>, Goth. <ets>fraiw</ets> seed,
descendants.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <fld>(Zool.)</fld> <def>The young of any fish.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A swarm or crowd, especially of little fishes; young
or small things in general.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>fry</qex> of children young.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To sever . . . the good fish from the other <qex>fry</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>We have burned two frigates, and a hundred and twenty small
<qex>fry</qex>.</q> <rj><qau>Walpole.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fryer</ent><br/
<hw>Fry"er</hw>, <pos>n.</pos> <sn>1.</sn> <def>Something or someone
that fries.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A young chicken or other food item suitable to be
cooked by frying.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>A pot equipped with a removable basket, designed to
be used for frying objects; -- also called <altname>deep
fryer</altname>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Frying</ent><br/
<hw>Fry"ing</hw>, <pos>n.</pos> <def>The process denoted by the verb
<xex>fry</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Frying pan</b></col>, <cd>an iron pan with a long handle,
used for frying meat, vegetables, etc.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>FTP</ent><br/
<ent>ftp</ent><br/
<mhw><hw>ftp</hw>, <hw>FTP</hw></mhw>
<pr>(<ecr/f`t<emac/*p<emac/")</pr>, <pos>n.</pos> <ety>[acronym from
<ets>F</ets>ile <ets>T</ets>ransfer <ets>P</ets>rotocol.]</ety>
<fld>(Computers)</fld> <def>An acronym for <altname>file transfer
protocol</altname>, a standardized protocol used to allow transmission
of files between computers; <as>as, send me the file by
<ex>ftp</ex></as>. It consists of a set of coded signals which are
transmitted between computers, and which inform the receiving computer
of the nature of a packet of information to be transmitted, and inform
the transmitting computer when a packet has been successfully
received.</def> <mark>[acronym]</mark> <br/
[<source>PJC</source>]</p>

<p><ent>FTP</ent><br/
<ent>ftp</ent><br/
<mhw><hw>ftp</hw>, <hw>FTP</hw></mhw>
<pr>(<ecr/f`t<emac/*p<emac/")</pr>, <pos>prop. v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>ftp'd</conjf> <it>or</it>
<conjf>FTP'd</conjf> <pr>(<ecr/f`t<emac/*p<emac/d")</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>FTPing</conjf> <it>or</it> <conjf>ftp'ing</conjf>
<it>or</it> <conjf>ftp-ing</conjf>
<pr>(<ecr/f`t<emac/*p<emac/"<icr/ng)</pr>.]</vmorph> <ety>[acronym from
<ets>F</ets>ile <ets>T</ets>ransfer <ets>P</ets>rotocol.]</ety>
<fld>(Computers)</fld> <def>To send from one computer to another by
means of the standard file transfer protocol (ftp); <as>as, he
<ex>ftp'd</ex> me the file yesterday</as>.</def> <mark>[acronym]</mark>
<note>The participle forms have not been standardized, and either
lower-case or upper-case may be used, but when lower-case is used,
either a hyphen or apostrophe is used before the <it>ed</it> or
<it>ing</it> endings.</note><br/
[<source>PJC</source>]</p>

<p><ent>Fu</ent><br/
<hw>Fu</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Chin.]</ety> <def>A
department in China comprising several <part>hsein</part>; also, the
chief city of a department; -- often forming the last part of a name;
<as>as, Paoting-<ex>fu</ex></as>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Fuage</ent><br/
<hw>Fu"age</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Fumage</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fuar</ent><br/
<hw>Fu"ar</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Feuar</er>.</def></p>

<p><ent>Fubs</ent><br/
<ent>Fub</ent><br/
<mhw><hw>Fub</hw> <pr>(?)</pr>, <hw>Fubs</hw> <pr>(<?/)</pr></mhw>,
<pos>n.</pos> <ety>[Cf. <er>Fob</er> a pocket.]</ety> <def>A plump young
person or child.</def> <mark>[Obs.]</mark> <rj><au>Smart.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fub</ent><br/
<hw>Fub</hw>, <pos>v. t.</pos> <ety>[The same word as <ets>fob</ets> to
cheat.]</ety> <def>To put off by trickery; to cheat.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I have been <qex>fubbed</qex> off, and <qex>fubbed</qex> off, and
fabbed off, from this day to that day.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fubbery</ent><br/
<hw>Fub"ber*y</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Cheating;
deception.</def> <rj><au>Marston.</au></rj></p>

<p><ent>Fubsy</ent><br/
<ent>Fubby</ent><br/
<mhw>{ <hw>Fub"by</hw> <pr>(?)</pr>, <hw>Fub"sy</hw> <pr>(?)</pr>
}</mhw> <pos>a.</pos> <def>Plump; chubby; short and stuffy; as a
<xex>fubsy</xex> sofa.</def> <mark>[Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>fubsy</qex>, good-humored, silly . . . old maid.</q>
<rj><qau>Mme. D'Arblay.</qau></rj></p>

<p><ent>Fucales</ent><br/
<hw>Fucales</hw> <pos>n.</pos> <def>An order coextensive with the family
<fam>Fucaceae</fam>.</def><br/
<syn><b>Syn. --</b> order <ord>Fucales</ord>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fucated</ent><br/
<ent>Fucate</ent><br/
<mhw>{ <hw>Fu"cate</hw> <pr>(?)</pr>, <hw>Fu"ca*ted</hw> <pr>(?)</pr>
}</mhw> <pos>a.</pos> <ety>[L. <ets>fucatus</ets>, p. p. of
<ets>fucare</ets> to color, paint, fr. <ets>fucus</ets>.]</ety>
<def>Painted; disguised with paint, or with false show.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fuchs</ent><br/
\'d8<hw>Fuchs</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[G., prop., a
fox.]</ety> <fld>(German Univ.)</fld> <def>A student of the first
year.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fuchsia</ent><br/
<hw>Fuch"si*a</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it> E.
<plw>Fuchsias</plw> <pr>(#)</pr>, L. <plw>Fuchsi<ae/</plw>
<pr>(#)</pr>.</plu> <ety>[NL. Named after <person>Leonard
<etsep>Fuchs</etsep></person>, a German botanist.]</ety> <sn>1.</sn>
<fld>(Bot.)</fld> <def>A genus of flowering plants having elegant
drooping flowers, with four sepals, four petals, eight stamens, and a
single pistil. They are natives of Mexico and South America.
Double-flowered varieties are now common in cultivation.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A plant belonging to the genus
<gen>Fuschia</gen>.</def><br/
[<source>PJC</source>]</p>

<p><-- p. 601 --></p>

<p><ent>Fuchsine</ent><br/
<hw>Fuch"sine</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Named by the French
inventor, from <ets>Fuchs</ets> a fox, the German equivalent of his own
name, <ets>Renard</ets>.]</ety> <fld>(Chem.)</fld> <def>Aniline red; an
artificial coal-tar dyestuff, of a metallic green color superficially,
resembling cantharides, but when dissolved forming a brilliant dark red.
It consists of a hydrochloride or acetate of rosaniline. See
<er>Rosaniline</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fucivorous</ent><br/
<hw>Fu*civ"o*rous</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Fucus</ets> + L. <ets>vorare</ets> to eat.]</ety>
<fld>(Zool.)</fld> <def>Eating fucus or other seaweeds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>fuck</ent><br/
<hw>fuck</hw> <pos>n.</pos> <def>A slang term for sexual
intercourse.</def> <mark>[vulgar slang]</mark><br/
<syn><b>Syn. --</b> fucking, screw, screwing, ass, piece of ass, roll in
the hay, shag.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>fuck</ent><br/
<hw>fuck</hw> <pos>v. t. & i.</pos> <def>to have sexual intercourse
(with).</def> <mark>[vulgar slang]</mark><br/
<syn><b>Syn. --</b> love, make love, sleep with, get laid, have sex,
know, do it, be intimate, have intercourse, have it away, have it off,
screw, jazz, eff, have, hump, lie with, bed, have a go at it, get it on,
bonk.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>fucked-up</ent><br/
<hw>fucked-up</hw> <pos>adj.</pos> <def>snarled or stalled in complete
confusion.</def> <mark>[Vulgar slang]</mark><br/
<syn><b>Syn. --</b> snafued, fouled up.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>fucker</ent><br/
<hw>fucker</hw> <pos>n.</pos> <def>a stupid foolish man.</def>
<mark>[vulgar slang]</mark><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>fuckhead</ent><br/
<hw>fuckhead</hw> <pos>n.</pos> <sn>1.</sn> <def>a stupid person; --
disparaging and vulgar.</def> <mark>[disparaging, vulgar
slang]</mark><br/
<syn><b>Syn. --</b> dunce, dunderhead, numskull, blockhead, bonehead,
lunkhead, hammerhead, knucklehead, loggerhead, muttonhead,
shithead.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>fucking</ent><br/
<hw>fucking</hw> <pos>n.</pos> <def>the act of sexual intercourse.</def>
<mark>[vulgar slang]</mark><br/
<syn><b>Syn. --</b> fuck, screw, screwing, ass, piece of ass, roll in
the hay, shag.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>fucking</ent><br/
<hw>fucking</hw> <pos>adj.</pos> <def>unpleasant; annoying; -- also used
as an informal intensifier.</def> <mark>[Vulgar slang,
prenominal]</mark><br/
<syn><b>Syn. --</b> bally(prenominal), blinking(prenominal),
bloody(prenominal), crashing(prenominal), flaming(prenominal).</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fucoid</ent><br/
<hw>Fu"coid</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Fucus</ets> +
<ets>-oid</ets>.]</ety> <fld>(Bot.)</fld> <sd>(a)</sd> <def>Properly,
belonging to an order of alga: (<ord>Fucoide<ae/</ord>) which are
blackish in color, and produce o<oum/spores which are not fertilized
until they have escaped from the conceptacle. The common rockweeds and
the gulfweed (<gen>Sargassum</gen>) are fucoid in character.</def>
<sd>(b)</sd> <def>In a vague sense, resembling seaweeds, or of the
nature of seaweeds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fucoid</ent><br/
<hw>Fu"coid</hw>, <pos>n.</pos> <fld>(Bot.)</fld> <def>A plant, whether
recent or fossil, which resembles a seaweed. See <er>Fucoid</er>,
<pos>a.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fucoidal</ent><br/
<hw>Fu*coid"al</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<fld>(Bot.)</fld> <def>Fucoid.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Geol.)</fld> <def>Containing impressions of fossil
fucoids or seaweeds; <as>as, fucoidal sandstone</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fucus</ent><br/
<hw>Fu"cus</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Fuci</plw> <pr>(#)</pr>.</plu> <ety>[L. rock lichen, orchil, used
as a red dye, red or purple color, disguise, deceit.]</ety> <sn>1.</sn>
<def>A paint; a dye; also, false show.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>A genus of tough, leathery
seaweeds, usually of a dull brownish green color; rockweed.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Formerly most marine alg<ae/ were called
<xex>fuci</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fucusol</ent><br/
<hw>Fu"cu*sol</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Fucus</ets> +
L. <ets>oleum</ets> oil.]</ety> <fld>(Chem.)</fld> <def>An oily liquid,
resembling, and possibly identical with, furfurol, and obtained from
fucus, and other seaweeds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fud</ent><br/
<hw>Fud</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Of uncertain
origin.]</ety> <sn>1.</sn> <def>The tail of a hare, coney, etc.</def>
<mark>[Prov. Eng. & Scot.]</mark> <rj><au>Burns.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Woolen waste, for mixing with mungo and
shoddy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fudder</ent><br/
<hw>Fud"der</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See <er>Fodder</er>, a
weight.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fuddle</ent><br/
<hw>Fud"dle</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Fuddled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Fuddling</conjf> <pr>(?)</pr>.]</vmorph> <ety>[Perh. formed as a
kind of dim. of full. Cf. <er>Fuzzle</er>.]</ety> <def>To make foolish
by drink; to cause to become intoxicated.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I am too <qex>fuddled</qex> to take care to observe your
orders.</q> <rj><qau>Steele.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fuddle</ent><br/
<hw>Fud"dle</hw>, <pos>v. i.</pos> <def>To drink to excess.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fuddler</ent><br/
<hw>Fud"dler</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A drunkard.</def>
<mark>[Colloq.]</mark> <rj><au>Baxter.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fudge</ent><br/
<hw>Fudge</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. Prov. F.
<ets>fuche</ets>, <ets>feuche</ets>, an interj. of contempt.]</ety>
<def>A made-up story; stuff; nonsense; humbug; -- often an exclamation
of contempt.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fudge</ent><br/
<hw>Fudge</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Fudged</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Fudging</conjf>.]</vmorph> <sn>1.</sn> <def>To make up; to
devise; to contrive; to fabricate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Fudged</qex> up into such a smirkish liveliness.</q>
<rj><qau>N. Fairfax.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To foist; to interpolate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That last <ldquo/suppose<rdquo/ is <qex>fudged</qex> in.</q>
<rj><qau>Foote.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fudge</ent><br/
<hw>Fudge</hw>, <pos>n.</pos> <def>A kind of soft candy composed of
sugar or maple sugar, milk, and butter, and often chocolate or nuts,
boiled and stirred to a proper consistency.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>fudge factor</ent><br/
<hw>fudge factor</hw>, <pos>n.</pos> <def>a term or factor inserted into
a calculation to compensate for anticipated errors, or to arbitrarily
make the result conform to some desired conclusion.</def><br/
[<source>PJC</source>]</p>

<p><ent>Fudge wheel</ent><br/
<hw>Fudge" wheel"</hw> <pr>(?)</pr>. <fld>(Shoemaking)</fld> <def>A tool
for ornamenting the edge of a sole.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fuegian</ent><br/
<hw>Fu*e"gi*an</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining to
Terra del Fuego.</def> -- <def2><pos>n.</pos> <def>A native of Terra del
Fuego.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fuel</ent><br/
<hw>Fu"el</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF. <ets>fouail</ets>,
<ets>fuail</ets>, or <ets>fouaille</ets>, <ets>fuaille</ets>, LL.
<ets>focalium</ets>, <ets>focale</ets>, fr. L. <ets>focus</ets> hearth,
fireplace, in LL., fire. See <er>Focus</er>.]</ety> <altsp>[Formerly
written also <asp>fewel.</asp>]</altsp> <sn>1.</sn> <def>Any matter used
to produce heat by burning; that which feeds fire; combustible matter
used for fires, as wood, coal, peat, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Anything that serves to feed or increase passion or
excitement.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Artificial fuel</b></col>, <cd>fuel consisting of small
particles, as coal dust, sawdust, etc., consolidated into lumps or
blocks.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fuel</ent><br/
<hw>Fu"el</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To feed with
fuel.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Never, alas I the dreadful name,<br/
That <qex>fuels</qex> the infernal flame.</q>
<rj><qau>Cowley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To store or furnish with fuel or firing.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Well watered and well <qex>fueled</qex>.</q> <rj><qau>Sir H.
Wotton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fueler</ent><br/
<hw>Fu"el*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, supplies fuel.</def> <mark>[R.]</mark> <altsp>[Written also
<asp>fueller</asp>.]</altsp> <rj><au>Donne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fuero</ent><br/
\'d8<hw>Fu*e"ro</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sp., fr. L.
<ets>forum</ets>.]</ety> <fld>(Sp. Law)</fld> <sd>(a)</sd> <def>A code;
a charter; a grant of privileges.</def> <sd>(b)</sd> <def>A custom
having the force of law.</def> <sd>(c)</sd> <def>A declaration by a
magistrate.</def> <sd>(d)</sd> <def>A place where justice is
administered.</def> <sd>(e)</sd> <def>The jurisdiction of a
tribunal.</def> <rj><au>Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fuff</ent><br/
<hw>Fuff</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <ety>[Of imitative
origin. Cf. <er>Puff</er>.]</ety> <def>To puff.</def> <mark>[Prov. Eng.
A Local, U. S.]</mark> <rj><au>Halliwel.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fuffy</ent><br/
<hw>Fuff"y</hw>, <pos>a.</pos> <def>Light; puffy.</def> <mark>[Prov.
Eng. & Local, U. S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fuga</ent><br/
\'d8<hw>Fu"ga</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[It.]</ety>
<fld>(Mus.)</fld> <def>A fugue.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fugacious</ent><br/
<hw>Fu*ga"cious</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>fugax</ets>, <ets>fugacis</ets>, from <ets>fugere</ets>: cf. F.
<ets>fugace</ets>. See <er>Fugitive</er>.]</ety> <sn>1.</sn>
<def>Flying, or disposed to fly; fleeing away; lasting but a short time;
volatile.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Much of its possessions is so hid, so fugacious, and of so
uncertain purchase.</q> <rj><qau>Jer. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Biol.)</fld> <def>Fleeting; lasting but a short
time; -- applied particularly to organs or parts which are short-lived
as compared with the life of the individual.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fugaciousness</ent><br/
<hw>Fu*ga"cious*ness</hw>, <pos>n.</pos> <def>Fugacity.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fugacity</ent><br/
<hw>Fu*gac"i*ty</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L
<ets>fugacitas</ets>: cf. F. <ets>fugacit<eacute/</ets>.]</ety>
<sn>1.</sn> <def>The quality of being fugacious; fugaclousness;
volatility; <as>as, <ex>fugacity</ex> of spirits</as>.</def>
<rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Uncertainty; instability.</def>
<rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fugacy</ent><br/
<hw>Fu"ga*cy</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Banishment.</def>
<mark>[Obs.]</mark> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fugato</ent><br/
\'d8<hw>Fu*ga"to</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Mus.)</fld>
<def>in the fugue style, but not strictly like a fugue.</def> --
<def2><pos>n.</pos> <def>A composition resembling a
fugue.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fugh</ent><br/
<hw>Fugh</hw> <pr>(?)</pr>, <pos>interj.</pos> <def>An exclamation of
disgust; foh; faugh.</def> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fughetta</ent><br/
\'d8<hw>Fu*ghet"ta</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[It.]</ety>
<fld>(Mus.)</fld> <def>a short, condensed fugue.</def>
<rj><au>Grove.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fugitive</ent><br/
<hw>Fu"gi*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OE.
<ets>fugitif</ets>, F. <ets>fugitif</ets>, fr. L. <ets>fugitivus</ets>,
fr. <ets>fugere</ets> to flee. See <er>Bow</er> to bend, and cf.
<er>Feverfew</er>.]</ety> <sn>1.</sn> <def>Fleeing from pursuit, danger,
restraint, etc., escaping, from service, duty etc.; <as>as, a
<ex>fugitive</ex> solder; a <ex>fugitive</ex> slave; <ex>a fugitive</ex>
debtor.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>fugitive</qex> Parthians follow.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Can a <qex>fugitive</qex> daughter enjoy herself while her parents
are in tear?</q> <rj><qau>Richardson</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A libellous pamphlet of a fugitive physician.</q> <rj><qau>Sir H.
Wotton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Not fixed; not durable; liable to disappear or fall
away; volatile; uncertain; evanescent; liable to fade; -- applied to
material and immaterial things; <as>as, <ex>fugitive</ex> colors; a
<ex>fugitive</ex> idea.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>The me more tender and fugitive parts, the leaves . . . of
vegatables.</q> <rj><qau>Woodward.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fugitive compositions</b></col>, <cd>Such as are short
and occasional, and so published that they quickly escape
notice.</cd></cs></p>

<p><syn><b>Syn.</b> -- Fleeting; unstable; wandering; uncertain;
volatile; fugacious; fleeing; evanescent.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fugitive</ent><br/
<hw>Fu"gi*tive</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who
flees from pursuit, danger, restraint, service, duty, etc.; a deserter;
<as>as, a <ex>fugitive</ex> from justice</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Something hard to be caught or detained.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Or Catch that airy <qex>fugitive</qex> called wit.</q>
<rj><qau>Harte.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fugitive from justice</b></col> <fld>(Law)</fld>, <cd>one
who, having committed a crime in one jurisdiction, flees or escapes into
another to avoid punishment.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fugitively</ent><br/
<hw>Fu"gi*tive*ly</hw>, <pos>adv.</pos> <def>In a fugitive
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fugitiveness</ent><br/
<hw>Fu"gi*tive*ness</hw>, <pos>n.</pos> <def>The quality or condition of
being fugitive; evanescence; volatility; fugacity;
instability.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fugle</ent><br/
<hw>Fu"gle</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To maneuver; to move
hither and thither.</def> <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Wooden arms with elbow joints jerking and <qex>fugling</qex> in
the<br/
air.</q> <rj><qau>Carlyle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fugleman</ent><br/
<hw>Fu"gle*man</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Fuglemen</plw> <pr>(#)</pr>.</plu> <ety>[G.
<ets>fl<uum/gelmann</ets> file leader; <ets>fl<uum/gel</ets> wing (akin
to E. fly) + <ets>mann</ets> man. Cf. <er>Flugrelman</er>.]</ety>
<sn>1.</sn> <fld>(Mil.)</fld> <def>A soldier especially expert and well
drilled, who takes his place in front of a military company, as a guide
for the others in their exercises; a file leader. He originally stood in
front of the right wing.</def> <altsp>[Written also
<asp>flugelman</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence, one who leads the way.</def>
<mark>[Jocose]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fugue</ent><br/
<hw>Fugue</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr. It.
<ets>fuga</ets>, fr. L. <ets>fuga</ets> a fleeing, flight, akin to
<ets>fugere</ets> to fiee. See <er>Fugitive</er>.]</ety>
<fld>(Mus.)</fld> <def>A polyphonic composition, developed from a given
theme or themes, according to strict contrapuntal rules. The theme is
first given out by one voice or part, and then, while that pursues its
way, it is repeated by another at the interval of a fifth or fourth, and
so on, until all the parts have answered one by one, continuing their
several melodies and interweaving them in one complex progressive whole,
in which the theme is often lost and reappears.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>All parts of the scheme are eternally chasing each other, like the
parts of a <qex>fugue</qex>.</q> <rj><qau>Jer. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fuguist</ent><br/
<hw>Fu"guist</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Mus.)</fld> <def>A
musician who composes or performs fugues.</def>
<rj><au>Busby.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>-ful</ent><br/
<hw>-ful</hw> <pr>(?)</pr>. <ety>[See <er>Full</er>,
<pos>a.</pos>]</ety> <def>A suffix signifying <xex>full of</xex>,
<xex>abounding with</xex>; <as>as, boast<ex>ful</ex>, harm<ex>ful</ex>,
woe<ex>ful</ex></as>.</def></p>

<p><ent>Fulani</ent><br/
<ent>Foolahs</ent><br/
<ent>Fulahs</ent><br/
<mhw><hw>Fu"lahs`</hw>, <hw>Foo"lahs`</hw>, <hw>Fu"la*ni</hw></mhw>
<pr>(<?/)</pr>, <pos>n. pl.</pos>; <sing>sing. <singw>Fulah</singw>,
<singw>Foolah</singw> <pr>(<?/)</pr></sing>. <fld>(Ethnol.)</fld> <def>A
peculiar African race of uncertain origin, but distinct from the negro
tribes, inhabiting an extensive region of Western Soudan. Their color is
brown or yellowish bronze. They are Muslims. Called also
<altname>Fellatahs</altname>, <altname>Foulahs</altname>, and
<altname>Fellani</altname>. Fulah and Fulani are also used adjectively;
<as>as, <ex>Fulah</ex> or <ex>Fulani</ex> empire, tribes,
language</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fulani</ent><br/
<hw>Fu"la*ni</hw> <pos>n.</pos> <def>The language of the Fulani people,
a member of the Niger-Congo family of languages.</def> <au>RHUD</au><br/
[<source>PJC</source>]</p>

<p><ent>Fulbe</ent><br/
<hw>Ful"be</hw> <pr>(f<oocr/l"b<asl/)</pr>, <pos>n.</pos>
<fld>(Ethnol.)</fld> <def>Same as <er>Fulahs</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fulcible</ent><br/
<hw>Ful"ci*ble</hw> <pr>(f<ucr/l"s<icr/*b'l)</pr>, <pos>a.</pos>
<ety>[L. <ets>fulcire</ets> to prop.]</ety> <def>Capable of being
propped up.</def> <mark>[Obs.]</mark> <rj><au>Cockeram.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fulciment</ent><br/
<hw>Ful"ci*ment</hw> <pr>(f<ucr/l"s<icr/*m<eit/nt)</pr>, <pos>n.</pos>
<ety>[L. <ets>fulcimentum</ets>, fr. <ets>fulcire</ets> to prop.]</ety>
<def>A prop; a fulcrum.</def> <mark>[Obs.]</mark> <rj><au>Bp.
Wilkins.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fulcra</ent><br/
<hw>Ful"cra</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <def>See
<er>Fulcrum</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fulcrate</ent><br/
<hw>Ful"crate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Fulcrum</er>.]</ety> <sn>1.</sn> <fld>(Bot.)</fld> <def>Propped;
supported by accessory organs.</def> <mark>[R.]</mark>
<rj><au>Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Furnished with fulcrums.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fulcrum</ent><br/
<hw>Ful"crum</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it> L.
<plw>Fulcra</plw> <pr>(#)</pr>, E. <plw>Fulcrums</plw>
<pr>(#)</pr>.</plu> <ety>[L., bedpost, fr. <ets>fulcire</ets> to
prop.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>A prop or support.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mech.)</fld> <def>That by which a lever is
sustained, or about which it turns in lifting or moving a
body.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Bot.)</fld> <def>An accessory organ such as a
tendril, stipule, spine, and the like.</def> <mark>[R.]</mark>
<rj><au>Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Zool.)</fld> <sd>(a)</sd> <def>The horny inferior
surface of the lingua of certain insects.</def> <sd>(b)</sd> <def>One of
the small, spiniform scales found on the front edge of the dorsal and
caudal fins of many ganoid fishes.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Anat.)</fld> <def>The connective tissue supporting
the framework of the retina of the eye.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fulfill</ent><br/
<hw>Ful*fill"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Fulfilled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Fulfilling</conjf>.]</vmorph> <ety>[OE.
<ets>fulfillen</ets>, <ets>fulfullen</ets>, AS. <ets>fulfyllan</ets>;
<ets>ful</ets> full + <ets>fyllan</ets> to fill. See <er>Full</er>,
<pos>a.</pos>, and <er>Fill</er>, <pos>v. t.</pos>]</ety>
<altsp>[Written also <asp>fulfil.</asp>]</altsp> <sn>1.</sn> <def>To
fill up; to make full or complete.</def> <mark>[Obs.]</mark>
<ldquo/<xex>Fulfill</xex> her week<rdquo/ <rj><au>Gen. xxix.
27.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Suffer thou that the children be <qex>fulfilled</qex> first, for
it is not good to take the bread of children and give to hounds.</q>
<rj><qau>Wyclif (Mark vii. 27).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To accomplish or carry into effect, as an intention,
promise, or prophecy, a desire, prayer, or requirement, etc.; to
complete by performance; to answer the requisitions of; to bring to
pass, as a purpose or design; to effectuate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He will, <qex>fulfill</qex> the desire of them fear him.</q>
<rj><qau>Ps. cxlv. 199.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Here Nature seems <qex>fulfilled</qex> in all her ends.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Servants must their masters' minds <qex>fulfill</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fulfiller</ent><br/
<hw>Ful*fill"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
fulfills.</def> <rj><au>South.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fulfillment</ent><br/
<hw>Ful*fill"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Written also
<ets>fulfilment</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>The act of fulfilling; accomplishment; completion;
<as>as, the <ex>fulfillment</ex> of prophecy</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Execution; performance; <as>as, the
<ex>fulfillment</ex> of a promise</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fulgency</ent><br/
<hw>Fulgen*cy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>fulgent</er>.]</ety> <def>Brightness; splendor; glitter;
effulgence.</def> <rj><au>Bailey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fulgent</ent><br/
<hw>Ful"gent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>fulgens</ets>, <ets>-entis</ets>, <ets>p. pr.</ets> of
<ets>fulgere</ets> to flash, glitter, shine, akin to Gr. <?/ to burn.
See <er>Phlox</er>, <er>Flagrant</er>.]</ety> <def>Exquisitely bright;
shining; dazzling; effulgent.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Other Thracians . . . <qex>fulgent</qex> morions wore.</q>
<rj><qau>Glower.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fulgently</ent><br/
<hw>Ful"gent*ly</hw>, <pos>adv.</pos> <def>Dazzlingly;
glitteringly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fulgid</ent><br/
<hw>Ful"gid</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>fulgidus</ets>. See <er>Fulgent</er>.]</ety> <def>Shining;
glittering; dazzling.</def> <mark>[R.]</mark>
<rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fulgidity</ent><br/
<hw>Ful*gid"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Splendor;
resplendence; effulgence.</def> <mark>[R.]</mark>
<rj><au>Bailey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fulgor</ent><br/
<hw>Ful"gor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>fulgor</ets>,
fr. <ets>fulgere</ets> to shine.]</ety> <def>Dazzling brightness;
splendor.</def> <mark>[R.]</mark> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fulgurant</ent><br/
<hw>Ful"gu*rant</hw> <pr>(?)</pr> <pos>a.</pos> <ety>[L.
<ets>fulgurans</ets>, <ets>p. pr.</ets> of <ets>fulgurare</ets>.]</ety>
<def>Lightening.</def> <mark>[R.]</mark> <rj><au>Dr. H.
More.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fulgurata</ent><br/
\'d8<hw>Ful"gu*ra"ta</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL.]</ety>
<fld>(Electricity)</fld> <def>A spectro-electric tube in which the
decomposition of a liquid by the passage of an electric spark is
observed.</def> <rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fulgurate</ent><br/
<hw>Ful"gu*rate</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[L.
<ets>fulguratus</ets>, p. p. of <ets>fulgurare</ets> to flash, fr.
<ets>fulgur</ets> lightning, fr. <ets>fulgere</ets> to shine. See
<er>Fulgent</er>.]</ety> <def>To flash as lightning.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fulgurating</ent><br/
<hw>Ful"gu*ra`ting</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Med.)</fld>
<def>Resembling lightning; -- used to describe intense lancinating pains
accompanying locomotor ataxy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fulguration</ent><br/
<hw>Ful"gu*ra`tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>fulguratio</ets>: cf. F. <ets>fulguration</ets>.]</ety> <sn>1.</sn>
<def>The act of lightening.</def> <mark>[R.]</mark>
<rj><au>Donne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Assaying)</fld> <def>The sudden brightening of a
fused globule of gold or silver, when the last film of the oxide of lead
or copper leaves its surface; -- also called
<altname>blick</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A phenomenon called, by the old chemists,
<qex>fulguration</qex>.</q> <rj><qau>Ure.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fulgurite</ent><br/
<hw>Ful"gu*rite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>fulguritus</ets>, p. p. of <ets>fulgurire</ets> to strike with
lightning, fr. <ets>fulgur</ets> lightning: cf. F.
<ets>fulgurite</ets>.]</ety> <def>A vitrified sand tube produced by the
striking of lightning on sand; a lightning tube; also, the portion of
rock surface fused by a lightning discharge.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fulgury</ent><br/
<hw>Ful"gu*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>fulgur</ets>.]</ety> <def>Lightning.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fulham</ent><br/
<hw>Ful"ham</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[So named because
supposed to have been chiefly made at <etsep>Fulham</etsep>, in
Middlesex, Eng.]</ety> <def>A false die.</def> <mark>[Cant]</mark>
<altsp>[Written also <asp>fullam</asp>.]</altsp>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fuliginosity</ent><br/
<hw>Fu*lig"i*nos"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>fuliginosit<eacute/</ets>.]</ety> <def>The condition or quality of
being fuliginous; sootiness; matter deposited by smoke.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fuliginous</ent><br/
<hw>Fu*lig"i*nous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>fuliginosus</ets>, from <ets>fuligo</ets> soot: cf. F.
<ets>fuligineux</ets>. See <er>Fume</er>.]</ety> <sn>1.</sn>
<def>Pertaining to soot; sooty; dark; dusky.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Pertaining to smoke; resembling smoke.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fuliginously</ent><br/
<hw>Fu*lig"i*nous*ly</hw>, <pos>adv.</pos> <def>In a smoky
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fulimart</ent><br/
<hw>Fu"li*mart</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Foumart</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Full</ent><br/
<hw>Full</hw> <pr>(f<usdot/l)</pr>, <pos>a.</pos>
<amorph>[<pos>Compar.</pos> <adjf>Fuller</adjf>
<pr>(f<usdot/l"<etil/r)</pr>; superl. <adjf>Fullest</adjf>.]</amorph>
<ety>[OE. & AS. <ets>ful</ets>; akin to OS. <ets>ful</ets>, D.
<ets>vol</ets>, OHG. <ets>fol</ets>, G. <ets>voll</ets>, Icel.
<ets>fullr</ets>, Sw. <ets>full</ets>, Dan. <ets>fuld</ets>, Goth.
<ets>fulls</ets>, L. <ets>plenus</ets>, Gr. <grk>plh`rhs</grk>, Skr.
<ets>p<umac/<rsdot/na</ets> full, <ets>pr<amac/</ets> to fill, also to
Gr. <grk>poly`s</grk> much, E. <ets>poly-</ets>, pref., G.
<ets>viel</ets>, AS. <ets>fela</ets>. <root/80. Cf. <er>Complete</er>,
<er>Fill</er>, <er>Plenary</er>, <er>Plenty</er>.]</ety> <sn>1.</sn>
<def>Filled up, having within its limits all that it can contain;
supplied; not empty or vacant; -- said primarily of hollow vessels, and
hence of anything else; <as>as, a cup <ex>full</ex> of water; a house
<ex>full</ex> of people.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Had the throne been <qex>full</qex>, their meeting would not have
been regular.</q> <rj><qau>Blackstone.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Abundantly furnished or provided; sufficient in
quantity, quality, or degree; copious; plenteous; ample; adequate;
<as>as, a <ex>full</ex> meal; a <ex>full</ex> supply; a <ex>full</ex>
voice; a <ex>full</ex> compensation; a house <ex>full</ex> of
furniture.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Not wanting in any essential quality; complete;
entire; perfect; adequate; <as>as, a <ex>full</ex> narrative; a person
of <ex>full</ex> age; a <ex>full</ex> stop; a <ex>full</ex> face; the
<ex>full</ex> moon.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>It came to pass, at the end of two <qex>full</qex> years, that
Pharaoh<br/
dreamed.</q> <rj><qau>Gen. xii. 1.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The man commands<br/
Like a <qex>full</qex> soldier.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I can not<br/
Request a <qex>fuller</qex> satisfaction<br/
Than you have freely granted.</q> <rj><qau>Ford.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Sated; surfeited.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I am <qex>full</qex> of the burnt offerings of rams.</q>
<rj><qau>Is. i. 11.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Having the mind filled with ideas; stocked with
knowledge; stored with information.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Reading maketh a <qex>full</qex> man.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Having the attention, thoughts, etc., absorbed in
any matter, and the feelings more or less excited by it, <as>as, to be
<ex>full</ex> of some project</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Every one is <qex>full</qex> of the miracles done by cold baths on
decayed and weak constitutions.</q> <rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>Filled with emotions.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The heart is so <qex>full</qex> that a drop overfills it.</q>
<rj><qau>Lowell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>Impregnated; made pregnant.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Ilia, the fair, . . . <qex>full</qex> of Mars.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>At full</b></col>, <cd>when full or complete.</cd>
<au>Shak.</au> -- <col><b>Full age</b></col> <fld>(Law)</fld> <cd>the
age at which one attains full personal rights; majority; -- in England
and the United States the age of 21 years.</cd> <au>Abbott.</au> --
<col><b>Full and by</b></col> <fld>(Naut.)</fld>, <cd>sailing
closehauled, having all the sails <xex>full</xex>, and lying as near the
wind as poesible.</cd> -- <col><b>Full band</b></col> <fld>(Mus.)</fld>,
<cd>a band in which all the instruments are employed.</cd> --
<col><b>Full binding</b></col>, <cd>the binding of a book when made
wholly of leather, as distinguished from half binding.</cd> --
<col><b>Full bottom</b></col>, <cd>a kind of wig <xex>full</xex> and
large at the bottom.</cd> -- <mcol><col><b>Full brother</b></col>
<it>or</it> <col><b>Full sister</b></col></mcol>, <cd>a brother or
sister having the same parents as another.</cd> -- <col><b>Full
cry</b></col> <fld>(Hunting)</fld>, <cd>eager chase; -- said of hounds
that have caught the scent, and give tongue together.</cd> --
<col><b>Full dress</b></col>, <cd>the dress prescribed by authority or
by etiquette to be worn on occasions of ceremony.</cd> -- <col><b>Full
hand</b></col> <fld>(Poker)</fld>, <cd>three of a kind and a pair.</cd>
-- <col><b>Full moon</b></col>. <sd>(a)</sd> <cd>The moon with its whole
disk illuminated, as when opposite to the sun.</cd> <sd>(b)</sd> <cd>The
time when the moon is full.</cd> -- <col><b>Full organ</b></col>
<fld>(Mus.)</fld>, <cd>the organ when all or most stops are out.</cd> --
<col><b>Full score</b></col> <fld>(Mus.)</fld>, <cd>a score in which all
the parts for voices and instruments are given.</cd> -- <col><b>Full
sea</b></col>, <cd>high water.</cd> -- <col><b>Full swing</b></col>,
<cd>free course; unrestrained liberty; <ldquo/Leaving corrupt nature to
. . . the <xex>full swing</xex> and freedom of its own extravagant
actings.<rdquo/ South (<mark>Colloq</mark>.)</cd> -- <col><b>In
full</b></col>, <cd>at length; uncontracted; unabridged; written out in
words, and not indicated by figures.</cd> -- <col><b>In full
blast</b></col>. <cd>See under <er>Blast</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 602 --></p>

<p><ent>Full</ent><br/
<hw>Full</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Complete measure; utmost
extent; the highest state or degree.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The swan's-down feather,<br/
That stands upon the swell at <qex>full</qex> of tide.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Full of the moon</b></col>, <cd>the time of full
moon.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Full</ent><br/
<hw>Full</hw>, <pos>adv.</pos> <def>Quite; to the same degree; without
abatement or diminution; with the whole force or effect; thoroughly;
completely; exactly; entirely.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The pawn I proffer shall be <qex>full</qex> as good.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The diapason closing <qex>full</qex> in man.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Full</qex> in the center of the sacred wood.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<note><p><hand/ Full is placed before adjectives and adverbs to heighten
or strengthen their signification. <ldquo/Full sad.<rdquo/
<au>Milton.</au> <ldquo/Master of a <xex>full</xex> poor cell.<rdquo/
<au>Shak.</au> <ldquo/<xex>Full</xex> many a gem of purest ray
serene.<rdquo/ <au>T. Gray.</au></p>

<p><xex>Full</xex> is also prefixed to participles to express utmost
extent or degree; as, <xex>full</xex>-bloomed, <xex>full</xex>-blown,
<xex>full</xex>-crammed <xex>full</xex>-grown, <xex>full</xex>-laden,
<xex>full</xex>-stuffed, etc. Such compounds, for the most part, are
self-defining.<br/
[<source>1913 Webster</source>]</p></note>

<p><ent>Full</ent><br/
<hw>Full</hw>, <pos>v. i.</pos> <def>To become full or wholly
illuminated; <as>as, the moon fulls at midnight</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Full</ent><br/
<hw>Full</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Fulled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Fulling</conjf>.]</vmorph> <ety>[OE. <ets>fullen</ets>, OF.
<ets>fuler</ets>, <ets>fouler</ets>, F. <ets>fouler</ets>, LL.
<ets>fullare</ets>, fr. L. <ets>fullo</ets> fuller, cloth fuller, cf.
Gr. <?/ shining, white, AS. <ets>fullian</ets> to whiten as a fuller, to
baptize, <ets>fullere</ets> a fuller. Cf. <er>Defile</er> to foul,
<er>Foil</er> to frustrate, <er>Fuller</er>. <pos>n.</pos> ]</ety>
<def>To thicken by moistening, heating, and pressing, as cloth; to mill;
to make compact; to scour, cleanse, and thicken in a mill.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Full</ent><br/
<hw>Full</hw>, <pos>v. i.</pos> <def>To become fulled or thickened;
<as>as, this material <ex>fulls</ex> well</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fullage</ent><br/
<hw>Full"age</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The money or price
paid for fulling or cleansing cloth.</def>
<rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fullam</ent><br/
<hw>Ful"lam</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A false die. See
<er>Fulham</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>fullback</ent><br/
<hw>fullback</hw> <pos>n.</pos> <def>an offensive football player who
plays farther behind the line of scrimmage than the half-back. They are
used primarily for blocking and line plunges.</def><br/
<syn><b>Syn. --</b> fullback.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>fullback</ent><br/
<hw>fullback</hw> <pos>v.</pos> <sn>1.</sn> <fld>(Football)</fld>
<def>To play the position of fullback on a football team; to be the
fullback.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Full-blooded</ent><br/
<hw>Full"-blood`ed</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Having a full supply of blood.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of pure blood; thoroughbred; <as>as, a
<ex>full-blooded</ex> horse</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Full-bloomed</ent><br/
<hw>Full"-bloomed`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Like a perfect
blossom.</def> <ldquo/<xex>Full-bloomed</xex> lips.<rdquo/
<rj><au>Crashaw.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Full-blown</ent><br/
<hw>Full"-blown`</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Fully
expanded, as a blossom; completely developed; <as>as, a
<ex>full-blown</ex> rose</as>.</def> <rj><au>Denham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Fully distended with wind, as a sail.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <specif>Hence:</specif> <def>Of full intensity; <as>as,
the recession developed into <ex>full-blown</ex> depression; a
<ex>full-blown</ex> international crisis</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>full-bosomed</ent><br/
<hw>full-bosomed</hw> <pos>adj.</pos> <def>having a pronounced womanly
shape, with well-developed breasts.</def> <mark>[informal]</mark><br/
<syn><b>Syn. --</b> bosomy, buxom, curvaceous, sonsie, sonsy,
voluptuous.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Full-bottomed</ent><br/
<hw>Full"-bot"tomed</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Full and large at the bottom, as wigs worn by certain civil
officers in Great Britain.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Naut.)</fld> <def>Of great capacity below the water
line.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Full-butt</ent><br/
<hw>Full"-butt"</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>With direct and
violent opposition; with sudden collision.</def> <mark>[Colloq.]</mark>
<rj><au>L'Estrange.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>full-dress</ent><br/
<hw>full-dress</hw> <pos>n.</pos> <def>full evening dress for
men.</def><br/
<syn><b>Syn. --</b> dress suit, full dress, tailcoat, tail coat, tails,
white tie, white tie and tails.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>full-dress</ent><br/
<hw>full-dress</hw> <pos>adj.</pos> <sn>1.</sn> <def>suitable for formal
occasions; <as>as, a <ex>full-dress</ex> uniform</as>.</def><br/
<syn><b>Syn. --</b> dress.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>requiring formal clothes; -- of a social event;
<as>as, a <ex>full-dress</ex> ceremony</as>.</def><br/
<syn><b>Syn. --</b> dress.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>3.</sn> <def>complete in every respect, including formalities;
<as>as, a <ex>full-dress</ex> debate</as>; a <ex>full-dress</ex>
investigation.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Full-drive</ent><br/
<hw>Full`-drive"</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>With full
speed.</def> <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fuller</ent><br/
<hw>Full"er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS.
<ets>fullere</ets>, fr. L. <ets>fullo</ets>. See <er>Full</er>, <pos>v.
t.</pos>]</ety> <def>One whose occupation is to full cloth.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fuller's earth</b></col>, <cd>a variety of clay, used in
scouring and cleansing cloth, to imbibe grease.</cd> -- <col><b>Fuller's
herb</b></col> <fld>(Bot.)</fld>, <cd>the soapwort (<spn>Saponaria
officinalis</spn>), formerly used to remove stains from cloth.</cd> --
<mcol><col><b>Fuller's thistle</b></col> <it>or</it> <col><b>Fuller's
weed</b></col></mcol> <fld>(Bot.)</fld>, <cd>the teasel (<spn>Dipsacus
fullonum</spn>) whose burs are used by fullers in dressing cloth. See
<er>Teasel</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fuller</ent><br/
<hw>Full"er</hw>, <pos>n.</pos> <ety>[From <er>Full</er>,
<pos>a.</pos>]</ety> <fld>(Blacksmith's Work)</fld> <def>A die; a
half-round set hammer, used for forming grooves and spreading iron; --
called also a <altname>creaser</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fuller</ent><br/
<hw>Full"er</hw>, <pos>v. t.</pos> <def>To form a groove or channel in,
by a fuller or set hammer; <as>as, to <ex>fuller</ex> a
bayonet</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fullery</ent><br/
<hw>Full"er*y</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Fulleries</plw> <pr>(<?/)</pr>.</plu> <def>The place or the works
where the fulling of cloth is carried on.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>full-face</ent><br/
<hw>full-face</hw> <pos>adj.</pos> <fld>(Heraldry)</fld> <def>looking
forward.</def><br/
<syn><b>Syn. --</b> guardant(postnominal),
gardant(postnominal).</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>full-fashioned</ent><br/
<hw>full-fashioned</hw> <pos>adj.</pos> <def>knitted to fit the shape of
the body; <as>as, <ex>full-fashioned</ex> hosiery</as>.</def><br/
<syn><b>Syn. --</b> fully fashioned.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>full-fledged</ent><br/
<hw>full-fledged</hw> <pos>adj.</pos> <sn>1.</sn> <def>having reached
full development with fully grown adult plumage; ready to fly; -- of a
bird.</def> <contr>fledgling</contr><br/
<syn><b>Syn. --</b> fully fledged.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>having gained full status; -- of persons in respect
to human roles; <as>as, a <ex>full-fledged</ex> lawyer; by the age of
seventeen I was a full-fledged <ex>atheist</ex></as>.</def><br/
<syn><b>Syn. --</b> fully fledged.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Full-formed</ent><br/
<hw>Full"-formed`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Full in form or
shape; rounded out with flesh.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>full-formed</qex> maids of Afric.</q>
<rj><qau>Thomson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>full-grown</ent><br/
<hw>full-grown</hw> <pos>adj.</pos> <sn>1.</sn> <def> .</def>
<illu></illu><br/
[]</p>

<p><ent>Full-grown</ent><br/
<hw>Full"-grown`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having reached
the limits of growth; mature; fully developed; -- used mostly of living
organisms; <as>as, A <ex>full-grown</ex> lion can easily kill an unarmed
man.</as>.</def> <ldquo/<xex>Full-grown</xex> wings.<rdquo/
<rj><au>Lowell.</au></rj><br/
<syn><b>Syn. --</b> adult, big, fully grown, grown,
grownup.</syn>[<source>1913 Webster</source> + <source>WordNet
1.5</source>]</p>

<p><ent>Full-hearted</ent><br/
<hw>Full"-heart`ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Full of courage
or confidence.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Full-hot</ent><br/
<hw>Full"-hot`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Very fiery.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Full house</ent><br/
<hw>Full house</hw>. <fld>(Poker)</fld> <def>A hand containing three of
a kind and a pair, as three kings and two tens. It ranks above a flush
and below four of a kind.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Fulling</ent><br/
<hw>Full"ing</hw>, <pos>n.</pos> <def>The process of cleansing,
shrinking, and thickening cloth by moisture, heat, and
pressure.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fulling mill</b></col>, <cd>a mill for fulling cloth as
by means of pesties or stampers, which alternately fall into and rise
from troughs where the cloth is placed with hot water and fuller's
earth, or other cleansing materials.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>full-length</ent><br/
<hw>full-length</hw> <pos>adj.</pos> <sn>1.</sn> <def>accommodating the
full height of the human figure; <as>as, a <ex>full-length</ex>
mirror</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>representing the full height of the human figure;
<as>as, a <ex>full-length</ex> portrait</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>3.</sn> <def>unabridged; <as>as, the <ex>full-length</ex>
play</as>. Opposite of <ant>abridged</ant>.</def><br/
<syn><b>Syn. --</b> complete, uncut.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Full-manned</ent><br/
<hw>Full"-manned`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Completely
furnished with men, as a ship.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fullmart</ent><br/
<hw>Full"mart"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Foumart</er>.</def> <rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fullness</ent><br/
<hw>Full"ness</hw>, <pos>n.</pos> <def>The state of being full, or of
abounding; abundance; completeness.</def> <altsp>[Written also
<asp>fulness</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><q><ldquo/In thy presence is <qex>fullness</qex> of joy.<rdquo/</q>
<rj><qau>Ps. xvi. 11.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>full-of-the-moon</ent><br/
<hw>full-of-the-moon</hw> <pos>n.</pos> <def>the time when the moon is
fully illuminated.</def><br/
<syn><b>Syn. --</b> full moon, full-of-the-moon.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fullonical</ent><br/
<hw>Ful*lon"i*cal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>fullonicus</ets>, from fullo a cloth fuller.]</ety> <def>Pertaining
to a fuller of cloth.</def> <mark>[Obs.]</mark>
<rj><au>Blount.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Full-orbed</ent><br/
<hw>Full"-orbed`</hw> <pr>(<?/)</pr>, <pos>a.</pos> <def>Having the orb
or disk complete or fully illuminated; like the full moon.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>full-page</ent><br/
<hw>full-page</hw> <pos>adj.</pos> <sn>1.</sn> <def>occupying an entire
page in a book or paper; <as>as, a <ex>full-page</ex> ad</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Full-sailed</ent><br/
<hw>Full"-sailed`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having all its
sails set,; hence, without restriction or reservation.</def>
<rj><au>Massinger.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>full-scale</ent><br/
<hw>full-scale</hw> <pos>adj.</pos> <def>using all available resources;
-- of actions; <as>as, a <ex>full-scale</ex> effort to find the
perpetrator</as>.</def><br/
<syn><b>Syn. --</b> all-out.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>full-size</ent><br/
<hw>full-size</hw> <pos>adj.</pos> <def>Being of the same size as an
original.</def><br/
<syn><b>Syn. --</b> life-size, life-sized.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>full-strength</ent><br/
<hw>full-strength</hw> <pos>adj.</pos> <def>Undiluted; -- of liquids.
Opposite of <ant>diluted</ant>.</def><br/
<syn><b>Syn. --</b> neat, straight.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>full-term</ent><br/
<hw>full-term</hw> <pos>adj.</pos> <def>Gestated for the entire duration
of normal pregnancy; <as>as, a healthy <ex>full-term</ex> baby</as>; --
of new-born infants. Opposite of <ant>premature</ant>.</def> <see>Also
See: <er>mature</er>.</see><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>full-time</ent><br/
<hw>full-time</hw> <pos>adj.</pos> <def>spending or requiring all of the
time normally given to an activity; <as>as, <ex>full-time</ex> students;
a <ex>full-time</ex> job</as>. Opposite of
<ant>part-time</ant>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Full-winged</ent><br/
<hw>Full"-winged`</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Having large and strong or complete wings.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Ready for flight; eager.</def>
<mark>[Archaic]</mark> <rj><au>Beau. & Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fully</ent><br/
<hw>Ful"ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a full manner or
degree; completely; entirely; without lack or defect; adequately;
satisfactorily; <as>as, to be <ex>fully</ex> persuaded of the truth of a
proposition</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fully committed</b></col> <fld>(Law)</fld>, <cd>committed
to prison for trial, in distinction from being detained for
examination.</cd></cs></p>

<p><syn><b>Syn.</b> -- Completely; entirely; maturely; plentifully;
abundantly; plenteously; copiously; largely; amply; sufficiently;
clearly; distinctly; perfectly.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fulmar</ent><br/
<hw>Ful"mar</hw> <pr>(f<ucr/lm<aum/r)</pr>, <pos>n.</pos> <ety>[Icel.
<ets>f<umac/lm<amac/r</ets>. See <er>foul</er>, and <er>Man</er> a
gull.]</ety> <fld>(Zool.)</fld> <def>One of several species of sea
birds, of the family <fam>Procellariid<ae/</fam>, allied to the
albatrosses and petrels. Among the well-known species are the
<stype>arctic fulmar</stype> (<spn>Fulmarus glacialis</spn>) (called
also <stype>fulmar petrel</stype>, <stype>malduck</stype>, and
<stype>mollemock</stype>), and the giant fulmar (<spn>Ossifraga
gigantea</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fulmarus</ent><br/
<hw>Fulmarus</hw> <pos>n.</pos> <def>A genus of birds including many of
the fulmars.</def><br/
<syn><b>Syn. --</b> genus <gen>Fulmarus</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fulminant</ent><br/
<hw>Ful"mi*nant</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>fulminans</ets>, <ets>p. pr.</ets> of <ets>fulminare</ets> to
lighten: cf. F. <ets>fulminant</ets>.]</ety> <def>Thundering;
fulminating.</def> <mark>[R.]</mark> <rj><au>Bailey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fulminate</ent><br/
<hw>Ful"mi*nate</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Fulminated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Fulminating</conjf>.]</vmorph> <ety>[L.
<ets>fulminatus</ets>, p. p. of <ets>fulminare</ets> to lighten, strike
with lightning, fr. <ets>fulmen</ets> thunderbolt, fr.
<ets>fulgere</ets> to shine. See <er>Fulgent</er>, and cf.
<er>Fulmine</er>.]</ety> <sn>1.</sn> <def>To thunder; hence, to make a
loud, sudden noise; to detonate; to explode with a violent
report.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To issue or send forth decrees or censures with the
assumption of supreme authority; to thunder forth menaces.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fulminate</ent><br/
<hw>Ful"mi*nate</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To cause to
explode.</def> <rj><au>Sprat.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To utter or send out with denunciations or censures;
-- said especially of menaces or censures uttered by ecclesiastical
authority.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They <qex>fulminated</qex> the most hostile of all decrees.</q>
<rj><qau>De Quincey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fulminate</ent><br/
<hw>Ful"mi*nate</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. P.
<ets>fulminate</ets>. See <er>Fulminate</er>, <pos>v. i.</pos>]</ety>
<fld>(Chem.)</fld> <sd>(a)</sd> <def>A salt of fulminic acid. See under
<er>Fulminic</er>.</def> <sd>(b)</sd> <def>A fulminating
powder.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fulminate of gold</b></col>, <cd>an explosive compound of
gold; -- called also <altname>fulminating gold</altname>, and
<altname>aurum fulminans</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>fulminate of mercury</ent><br/
<hw>ful"mi*nate of mer"cu*ry</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Chem.)</fld> <def>The mercury salt of fulminic acid
(<chform>Hg(CNO)2</chform>), called also <altname>mercury
fulminate</altname>. It is prepared as gray crystals, and is used
primarily in detonators for detonating high explosives, such as dynamite
or TNT.</def><br/
[<source>PJC</source>]</p>

<p><ent>Fulminating</ent><br/
<hw>Ful"mi*na"ting</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Thundering; exploding in a peculiarly sudden or violent
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hurling denunciations, menaces, or
censures.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fulminating oil</b></col>, <cd>nitroglycerin.</cd> --
<col><b>Fulminating powder</b></col> <fld>(Chem.)</fld> <cd>any
violently explosive powder, but especially one of the fulminates, as
mercuric fulminate.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fulmination</ent><br/
<hw>Ful"mi*na`tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>fulminatio</ets> a darting of lightning: cf. F.
<ets>fulmination</ets>.]</ety> <sn>1.</sn> <def>The act of fulminating
or exploding; detonation.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The act of thundering forth threats or censures, as
with authority.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which is fulminated or thundered forth;
vehement menace or censure.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>fulminations</qex> from the Vatican were turned into
ridicule.</q> <rj><qau>Ayliffe.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fulminatory</ent><br/
<hw>Ful"mi*na*to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>fulminatoire</ets>.]</ety> <def>Thundering; striking terror.</def>
<rj><au>Cotgrave.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fulmine</ent><br/
<hw>Ful"mine</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[F.
<ets>fulminer</ets>. See <er>Fulminate</er>, <pos>v.</pos>]</ety>
<def>To thunder.</def> <mark>[Obs.]</mark> <rj><au>Spenser.
Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fulmine</ent><br/
<hw>Ful"mine</hw>, <pos>v. t.</pos> <def>To shoot; to dart like
lightning; to fulminate; to utter with authority or vehemence.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>She <qex>fulmined</qex> out her scorn of laws Salique.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fulmineous</ent><br/
<hw>Ful*min"e*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. fulmen
thunder.]</ety> <def>Of, or concerning thunder.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fulmiaic</ent><br/
<hw>Ful*mia"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>fulminique</ets>.]</ety> <def>Pertaining to fulmination;
detonating; specifically <fld>(Chem.)</fld>, pertaining to, derived
from, or denoting, an acid, so called; <as>as, fulminic
acid</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fulminic acid</b></col> <fld>(Chem.)</fld>, <cd>a complex
acid, <chform>H2C2N2O2</chform>, isomeric with cyanic and cyanuric
acids, and not known in the free state, but forming a large class of
highly explosive salts, the fulminates. Of these, mercuric fulminate,
the most common, is used, mixed with niter, to fill percussion caps,
charge cartridges, etc. Fulminic acid is made by the action of nitric
acid on alcohol.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fulminuric</ent><br/
<hw>Ful"mi*nu"ric</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Fulmin</ets>ic + cya<ets>nuric</ets>.]</ety>
<fld>(Chem.)</fld> <def>Pertaining to fulminic and cyanuric acids, and
designating an acid so called.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fulminuric acid</b></col> <fld>(Chem.)</fld>, <cd>a
white, crystalline, explosive substance, <chform>H3C3N3O3</chform>,
forming well known salts, and obtained from the fulminates. It is
isomeric with cyanuric acid, and hence is also called
<altname>isocyanuric acid</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fulness</ent><br/
<hw>Ful"ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Fullness</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fulsamic</ent><br/
<hw>Ful*sam"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Fulsome</er>.]</ety> <def>Fulsome.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fulsome</ent><br/
<hw>Ful"some</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Full</ets>, a.
+ <ets>-some</ets>.]</ety> <sn>1.</sn> <def>Full; abundant; plenteous;
not shriveled.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>His lean, pale, hoar, and withered corpse grew <qex>fulsome</qex>,
fair, and fresh.</q> <rj><qau>Golding.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Offending or disgusting by overfullness, excess, or
grossness; cloying; gross; nauseous; esp., offensive from excess of
praise; <as>as, <ex>fulsome</ex> flattery</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And lest the <qex>fulsome</qex> artifice should fail<br/
Themselves will hide its coarseness with a veil.</q>
<rj><qau>Cowper.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Lustful; wanton; obscene; also, tending to
obscenity.</def> <mark>[Obs.]</mark> <ldquo/Fulsome ewes.<rdquo/
<rj><au>Shak.</au></rj></p>

<p>-- <wordforms><wf>Ful"some*ly</wf>, <pos>adv.</pos> --
<wf>Ful"some*ness</wf>, <pos>n.</pos></wordforms>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fulvid</ent><br/
<hw>Ful"vid</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[LL.
<ets>fulvidus</ets>, fr. L. <ets>fulvus</ets>.]</ety>
<def>Fulvous.</def> <mark>[R.]</mark> <rj><au>Dr. H. More.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fulvous</ent><br/
<hw>Ful"vous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>fulvus</ets>.]</ety> <def>Tawny; dull yellow, with a mixture of
gray and brown.</def> <rj><au>Lindley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fum</ent><br/
<hw>Fum</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To play upon a
fiddle.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Follow me, and <qex>fum</qex> as you go.</q> <rj><qau>B.
Jonson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fumacious</ent><br/
<hw>Fu*ma"cious</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From Fume.]</ety>
<def>Smoky; hence, fond of smoking; addicted to smoking
tobacco.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fumado</ent><br/
<ent>Fumade</ent><br/
<mhw><hw>Fu*made"</hw> <pr>(?)</pr>, <hw>Fu*ma"do</hw>
<pr>(<?/)</pr></mhw>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Fumades</plw> <pr>(#)</pr>, <plw>Fumadoes</plw> <pr>(#)</pr>.</plu>
<ety>[Sp. <ets>fumodo</ets> smoked, p. p. of <ets>fumar</ets> to smoke,
fr. L. <ets>fumare</ets>. See <er>Fume</er>, <pos>v. i.</pos>]</ety>
<def>A salted and smoked fish, as the pilchard.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fumage</ent><br/
<hw>Fu"mage</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>fumage</ets>, <ets>fumaige</ets>, fr. L. <ets>fumus</ets>
smoke.]</ety> <def>Hearth money.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Fumage</qex>, or fuage, vulgarly called smoke farthings.</q>
<rj><qau>Blackstone.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fumarate</ent><br/
<hw>Fu"ma*rate</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>A salt of fumaric acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fumaric</ent><br/
<hw>Fu*mar"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Chem.)</fld>
<def>Pertaining to, or derived from, fumitory (<spn>Fumaria
officinalis</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fumaric acid</b></col> <fld>(Chem.)</fld>, <cd>a widely
occurring organic acid, extracted from fumitory as a white crystallline
substance, <chform>C2H2(CO2H)2</chform>, and produced artificially in
many ways, as by the distillation of malic acid; boletic acid. It is
found also in the lichen, Iceland moss, and hence was also called
<altname>lichenic acid</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fumarine</ent><br/
<hw>Fu"ma*rine</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>fumus</ets> smoke, fume.]</ety> <fld>(Chem.)</fld> <def>An alkaloid
extracted from fumitory, as a white crystalline substance.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fumarole</ent><br/
<hw>Fu"ma*role</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[It.
<ets>fumaruola</ets>, fr. <ets>fumo</ets> smoke, L. <ets>fumus</ets>:
cf. F. <ets>fumerolle</ets>, <ets>fumarolle</ets>.]</ety> <def>A hole or
spot in a volcanic or other region, from which fumes issue.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fumatorium</ent><br/
\'d8<hw>Fu`ma*to"ri*um</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>L.
pl.</it> <plw>-ria</plw> <pr>(#)</pr></plu>. <ety>[NL., fr. L.
<ets>fumare</ets>, <ets>fumatum</ets>, to smoke.]</ety> <def>An
air-tight compartment in which vapor may be generated to destroy germs
or insects; esp., the apparatus used to destroy San Jos<eacute/ scale on
nursery stock, with hydrocyanic acid vapor.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Fumatory</ent><br/
<hw>Fu"ma*to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Fumatorium</er>.]</ety> <def>Pert. to, or concerned with,
smoking.</def> -- <def2><pos>n.</pos>; <plu><it>pl.</it>
<plw>-ries</plw> <pr>(<?/)</pr></plu>. <def>A place for subjecting
things to smoke or vapor.</def></def2><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Fumatory</ent><br/
<hw>Fu"ma*to*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Fumitory</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fumble</ent><br/
<hw>Fum"ble</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Fumbled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Fumbling</conjf> <pr>(?)</pr>.]</vmorph> <ety>[Akin to D.
<ets>fommelen</ets> to crumple, fumble, Sw. <ets>fumla</ets> to fusuble,
<ets>famla</ets> to grope, Dan. <ets>famle</ets> to grope,
<ets>fumble</ets>, Icel. <ets>falme</ets>, AS. <ets>folm</ets> palm of
the hand. See <er>Feel</er>, and cf. <er>Fanble</er>,
<er>Palm</er>.]</ety> <sn>1.</sn> <def>To feel or grope about; to make
awkward attempts to do or find something.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Adams now began to <qex>fumble</qex> in his pockets.</q>
<rj><qau>Fielding.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To grope about in perplexity; to seek awkwardly;
<as>as, to <ex>fumble</ex> for an excuse</as>.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>My understanding flutters and my memory <qex>fumbles</qex>.</q>
<rj><qau>Chesterfield.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Alas! how he <qex>fumbles</qex> about the domains.</q>
<rj><qau>Wordsworth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To handle much; to play childishly; to turn over and
over.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I saw him <qex>fumble</qex> with the sheets, and play with
flowers.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fumble</ent><br/
<hw>Fum"ble</hw>, <pos>v. t.</pos> <def>To handle or manage awkwardly;
to crowd or tumble together.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fumbler</ent><br/
<hw>Fum"bler</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
fumbles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fumblingly</ent><br/
<hw>Fum"bling*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In the manner
of one who fumbles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fume</ent><br/
<hw>Fume</hw> <pr>(f<umac/m)</pr>, <pos>n.</pos> <ety>[L.
<ets>fumus</ets>; akin to Skr. <ets>dh<umac/ma</ets> smoke,
<ets>dh<umac/</ets> to shake, fan a flame, cf. Gr. <grk>qy`ein</grk> to
sacrifice, storm, rage, <grk>qy`mon</grk>, <grk>qy`mos</grk>, thyme, and
perh. to E. dust: cf. OF. <ets>fum</ets> smoke, F.
<ets>fum<eacute/e</ets>. Cf. <er>Dust</er>, <pos>n.</pos>,
<er>Femerell</er>, <er>Thyme</er>.]</ety> <sn>1.</sn> <def>Exhalation;
volatile matter (esp. noxious vapor or smoke) ascending in a dense body;
smoke; vapor; reek; <as>as, the <ex>fumes</ex> of
tobacco</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>fumes</qex> of new shorn hay.</q> <rj><qau>T.
Warton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>fumes</qex> of undigested wine.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Rage or excitement which deprives the mind of
self-control; <as>as, the fumes of passion</as>.</def>
<rj><au>South.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Anything vaporlike, unsubstantial, or airy; idle
conceit; vain imagination.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A show of fumes and fancies.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The incense of praise; inordinate
flattery.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To smother him with <qex>fumes</qex> and eulogies.</q>
<rj><qau>Burton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Metal.)</fld> <def>Solid material deposited by
condensation of fumes; <as>as, lead <ex>fume</ex> (a grayish powder
chiefly lead sulphate)</as>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><cs><col><b>In a fume</b></col>, <cd>in ill temper, esp. from
impatience.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fume</ent><br/
<hw>Fume</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Fumed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Fuming</conjf>.]</vmorph> <ety>[Cf. F. <ets>fumer</ets>, L.
<ets>fumare</ets> to smoke. See <er>Fume</er>, <pos>n.</pos>]</ety>
<sn>1.</sn> <def>To smoke; to throw off fumes, as in combustion or
chemical action; to rise up, as vapor.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Where the golden altar <qex>fumed</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Silenus lay,<br/
Whose constant cups lay <qex>fuming</qex> to his brain.</q>
<rj><qau>Roscommon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To be as in a mist; to be dulled and
stupefied.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Keep his brain <qex>fuming</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To pass off in fumes or vapors.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Their parts are kept from <qex>fuming</qex> away by their
fixity.</q> <rj><qau>Cheyne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To be in a rage; to be hot with anger.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He frets, he <qex>fumes</qex>, he stares, he stamps the
ground.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>While her mother did fret, and her father did <qex>fume</qex>.</q>
<rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To fume away</b></col>, <cd>to give way to excitement and
displeasure; to storm; also, to pass off in fumes.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fume</ent><br/
<hw>Fume</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To expose to the action
of fumes; to treat with vapors, smoke, etc.; <as>as, to bleach straw by
<ex>fuming</ex> it with sulphur</as>; to fill with fumes, vapors, odors,
etc., as a room.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>She <qex>fumed</qex> the temple with an odorous flame.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To praise inordinately; to flatter.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They demi-deify and <qex>fume</qex> him so.</q>
<rj><qau>Cowper.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To throw off in vapor, or as in the form of
vapor.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The heat will <qex>fume</qex> away most of the scent.</q>
<rj><qau>Montimer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>How vicious hearts <qex>fume</qex> frenzy to the brain!</q>
<rj><qau>Young.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fumed oak</ent><br/
<hw>Fumed oak</hw> <pr>(?)</pr>. <fld>(Cabinetwork)</fld> <def>Oak given
a weathered appearance by exposure in an air-tight compartment to fumes
of ammonia from uncorked cans, being first given a coat of
filler.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Fumeless</ent><br/
<hw>Fume"less</hw>, <pos>a.</pos> <def>Free from fumes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fumer</ent><br/
<hw>Fum"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One that
fumes.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who makes or uses perfumes.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Embroiderers, feather makers, <qex>fumers</qex>.</q>
<rj><qau>Beau. & Fl.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fumerell</ent><br/
<hw>Fu"mer*ell</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Arch.)</fld>
<def>See <er>Femerell</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fumet</ent><br/
<hw>Fu"met</hw> <pr>(f<umac/"m<ecr/t)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>fumier</ets> dung, OF. <ets>femier</ets>, fr. L. <ets>fimus</ets>
dung.]</ety> <def>The dung of deer.</def> <rj><au>B. Jonson.</au></rj>
<altsp>[Sometimes spelled <asp>fewmet</asp>.]</altsp></p>

<p><ent>Fumette</ent><br/
<ent>Fumet</ent><br/
<mhw>{ <hw>Fu"met</hw> <pr>(?)</pr> \'d8<hw>Fu*mette"</hw> <pr>(?)</pr>,
}</mhw> <pos>n.</pos> <ety>[F. <ets>fumet</ets> odor, <ets>fume</ets> of
wine or meat, fr. L. <ets>fumus</ets> smoke. See <er>Fume</er>,
<pos>n.</pos>]</ety> <def>The stench or high flavor of game or other
meat when kept long.</def> <rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fumet</ent><br/
\'d8<hw>Fu`met"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety> <def>A
high-flavored substance, such as extract of game, for flavoring dishes
of food; less properly, a ragout of partridge and rabbit braised in
wine.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Fumetere</ent><br/
<hw>Fu"me*tere"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Fumitory.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fumid</ent><br/
<hw>Fu"mid</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>fumidus</ets>,
fr. <ets>fumus</ets> smoke. See <er>Fume</er>.]</ety> <def>Smoky;
vaporous.</def> <rj><au>Sir T. Broune.</au></rj></p>

<p><ent>Fumidness</ent><br/
<ent>Fumidity</ent><br/
<mhw>{ <hw>Fu*mid"i*ty</hw> <pr>(?)</pr>, <hw>Fu"mid*ness</hw>
<pr>(?)</pr> }</mhw> <pos>n.</pos> <def>The state of being fumid;
smokiness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fumiferous</ent><br/
<hw>Fu*mif"er*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>fumifer</ets>; <ets>fumus</ets> smoke + <ets>ferre</ets> to
bear.]</ety> <def>Producing smoke.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fumifugist</ent><br/
<hw>Fu*mif"u*gist</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>fumus</ets> smoke + <ets>fugare</ets> to put to flight, fugere to
flee.]</ety> <def>One who, or that which, drives away smoke or
fumes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fumify</ent><br/
<hw>Fu"mi*fy</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[<ets>Fume</ets> +
<ets>-fy</ets>.]</ety> <def>To subject to the action of smoke.</def>
<mark>[Obs.]</mark> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fumigant</ent><br/
<hw>Fu"mi*gant</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>fumigans</ets>, <ets>p. pr.</ets> of <ets>fumigare</ets>. See
<er>Fumigate</er>.]</ety> <def>Fuming.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fumigate</ent><br/
<hw>Fu"mi*gate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Fumigated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Fumigating</conjf> <pr>(?)</pr>.]</vmorph> <ety>[L.
<ets>fumigate</ets>, p. p. of <ets>fumigare</ets> to fumigate, fr.
<ets>fumus</ets> smoke. See <er>Fume</er>, <pos>n.</pos>]</ety>
<sn>1.</sn> <def>To apply smoke to; to expose to smoke or vapor; to
purify, or free from infection, by the use of smoke or vapors.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To smoke; to perfume.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fumigation</ent><br/
<hw>Fum`iga"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>fumigation</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>The act of fumigating, or applying smoke or vapor,
as for disinfection.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Vapor raised in the process of fumigating.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fumigator</ent><br/
<hw>Fu"mi*ga`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, fumigates; an apparatus for fumigating.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fumigatory</ent><br/
<hw>Fu"mi*ga*to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>fumigatoire</ets>.]</ety> <def>Having the quality of purifying by
smoke.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 603 --></p>

<p><ent>Fumily</ent><br/
<hw>Fum"i*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>Smokily; with
fume.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fuming</ent><br/
<hw>Fum"ing</hw>, <pos>a.</pos> <def>Producing fumes, or
vapors.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Cadet's fuming liquid</b></col> <fld>(Chem.)</fld>,
<cd>alkarsin.</cd> -- <col><b>Fuming liquor of Libavius</b></col>
<fld>(Old Chem.)</fld>, <cd>stannic chloride; the chloride of tin,
<chform>SnCl4</chform>, forming a colorless, mobile liquid which fumes
in the air. Mixed with water it solidifies to the so-called <xex>butter
of tin</xex>.</cd> -- <col><b>Fuming sulphuric acid</b></col>.
<fld>(Chem.)</fld> <cd>Same as <cref>Disulphuric acid</cref>, uder
<er>Disulphuric</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fumingly</ent><br/
<hw>Fum"ing*ly</hw>, <pos>adv.</pos> <def>In a fuming manner;
angrily.</def> <ldquo/They answer <xex>fumingly</xex>.<rdquo/
<rj><au>Hooker.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fumish</ent><br/
<hw>Fum"ish</hw>, <pos>a.</pos> <def>Smoky; hot; choleric.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fumishness</ent><br/
<hw>Fum"ish*ness</hw>, <pos>n.</pos> <def>Choler; fretfulness;
passion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fumiter</ent><br/
<hw>Fu"mi*ter`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>Fumitory.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fumitory</ent><br/
<hw>Fu"mi*to*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>fumetere</ets>, F. <ets>fumeterre</ets>, prop., smoke of the
ground, fr. L. <ets>fumus</ets> smoke + <ets>terra</ets> earth. See
<er>Fume</er>, and <er>Terrace</er>.]</ety> <fld>(Bot.)</fld> <def>The
common name of several species of the genus Fumaria, annual herbs of the
Old World, with finely dissected leaves and small flowers in dense
racemes or spikes. <spn>F. officinalis</spn> is a common species, and
was formerly used as an antiscorbutic.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Climbing fumitory</b></col> <fld>(Bot.)</fld>, <cd>the
Alleghany vine (<spn>Adlumia cirrhosa</spn>); a biennial climbing plant
with elegant feathery leaves and large clusters of pretty white or
pinkish flowers looking like grains of rice.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fummel</ent><br/
<hw>Fum"mel</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>A
hinny.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fumosity</ent><br/
<hw>Fu*mos"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. OF.
<ets>fumosit<eacute/</ets>.]</ety> <def>The fumes of drink.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fumous</ent><br/
<hw>Fum"ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>fumosus</ets>, fr. <ets>fumus</ets> smoke: cf. F.
<ets>fumeux</ets>.]</ety> <sn>1.</sn> <def>Producing smoke;
smoky.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Producing fumes; full of fumes.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Garlic, onions, mustard, and such-like fumous things.</q>
<rj><qau>Barough (1625).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fumy</ent><br/
<hw>Fum"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Producing fumes;
fumous.</def> <ldquo/Drowned in <xex>fumy</xex> wine.<rdquo/ <rj><au>H.
Brooke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fun</ent><br/
<hw>Fun</hw> <pr>(f<ucr/n)</pr>, <pos>n.</pos> <ety>[Perh. of Celtic
origin; cf. Ir. & Gael. <ets>fonn</ets> pleasure.]</ety> <def>Sport;
merriment; frolicsome amusement.</def> <ldquo/Oddity, frolic, and
<xex>fun</xex>.<rdquo/ <rj><au>Goldsmith.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To make fun of</b></col>, <cd>to hold up to, or turn
into, ridicule.</cd></cs> -- <col><b>in fun</b></col>, <cd>jokingly; not
seriously; for amusement.</cd> -- <col><b>like fun</b></col>,
<cd>definitely not; -- used adverbially, mostly to contradict a prior
assertion; A: <ldquo/He says he won't do it again.<rdquo/ -- B:
<ldquo/<xex>Like fun</xex> he won't.<rdquo/.</cd><br/
[<source>1913 Webster</source> + <source>PJC</source>]</p>

<p><ent>fun</ent><br/
<hw>fun</hw> <pr>(f<ucr/n)</pr>, <pos>adj.</pos>
<amorph>[<pos>Compar.</pos> <adjf>funner</adjf>
<pr>(f<ucr/n"n<etil/r)</pr> <mark>(colloquial or jocular)</mark>;
<pos>superl.</pos> <adjf>funnest</adjf> <pr>(f<ucr/n"n<ecr/st)</pr>
<mark>(colloquial or jocular)</mark>.]</amorph> <def>Of or pertaining to
fun; causing pleasure or amusement; <as>as, a <ex>fun</ex> thing to
do</as>.</def> <mark>[informal]</mark><br/
[<source>PJC</source>]</p>

<p><ent>Funafuti</ent><br/
<hw>Funafuti</hw> <pos>prop. n.</pos> <fld>(Geography)</fld> <def>The
capital <isa>city</isa> of <country>Tuvalu</country>. Population (2000)
= 3,839.</def><br/
[<source>PJC</source>]</p>

<p><ent>Funambulate</ent><br/
<hw>Fu*nam"bu*late</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[See
<er>Funambulo</er>.]</ety> <def>To walk or to dance on a rope.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Funambulation</ent><br/
<hw>Fu*nam"bu*la`tion</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Ropedancing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Funambulatory</ent><br/
<hw>Fu*nam"bu*la`to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Performing like a ropedancer.</def> <rj><au>Chambers.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Narrow, like the walk of a ropedancer.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This funambulatory track.</q> <rj><qau>Sir T.
Browne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Funambulist</ent><br/
<hw>Fu*nam"bu*list</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A ropewalker or
ropedancer.</def></p>

<p><ent>Funambulus</ent><br/
<ent>Funambulo</ent><br/
<mhw>{ \'d8<hw>Fu*nam"bu*lo</hw> <pr>(?)</pr>,
\'d8<hw>Fu*nam"bu*lus</hw> <pr>(?)</pr> }</mhw> <pos>n.</pos> <ety>[Sp.
<ets>funambulo</ets>, or It. <ets>funambolo</ets>, fr. L.
<ets>funambulus</ets>; <ets>funis</ets> rope (perh. akin to E.
<ets>bind</ets>) + <ets>ambulare</ets> to walk. See <er>Amble</er>, and
cf. <er>Funambulist</er>.]</ety> <def>A ropewalker or ropedancer.</def>
<mark>[Obs.]</mark> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Function</ent><br/
<hw>Func"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>functio</ets>, fr. <ets>fungi</ets> to perform, execute, akin to
Skr. <ets>bhuj</ets> to enjoy, have the use of: cf. F.
<ets>fonction</ets>. Cf. <er>Defunct</er>.]</ety> <sn>1.</sn> <def>The
act of executing or performing any duty, office, or calling;
performance.</def> <ldquo/In the <xex>function</xex> of his public
calling.<rdquo/ <rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Physiol.)</fld> <def>The appropriate action of any
special organ or part of an animal or vegetable organism; <as>as, the
<ex>function</ex> of the heart or the limbs; the <ex>function</ex> of
leaves, sap, roots, etc.; life is the sum of the <ex>functions</ex> of
the various organs and parts of the body.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The natural or assigned action of any power or
faculty, as of the soul, or of the intellect; the exertion of an energy
of some determinate kind.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>As the mind opens, and its <qex>functions</qex> spread.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The course of action which peculiarly pertains to
any public officer in church or state; the activity appropriate to any
business or profession.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Tradesmen . . . going about their <qex>functions</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The malady which made him incapable of performing his<br/
regal <qex>functions.</qex></q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Math.)</fld> <def>A quantity so connected with
another quantity, that if any alteration be made in the latter there
will be a consequent alteration in the former. Each quantity is said to
be a <xex>function</xex> of the other. Thus, the circumference of a
circle is a <xex>function</xex> of the diameter. If <it>x</it> be a
symbol to which different numerical values can be assigned, such
expressions as x<exp>2</exp>, 3<exp>x</exp>, Log. <it>x</it>, and Sin.
<it>x</it>, are all <ex>functions</ex> of <it>x</it>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Eccl.)</fld> <def>A religious ceremony, esp. one
particularly impressive and elaborate.</def></p>

<p><q>Every solemn <lsquo/<qex>function</qex>' performed with the
requirements of the liturgy.</q> <rj><qau>Card. Wiseman.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>7.</sn> <def>A public or social ceremony or gathering; a
festivity or entertainment, esp. one somewhat formal.</def></p>

<p><q>This <qex>function</qex>, which is our chief social event.</q>
<rj><qau>W. D. Howells.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><cs><col><b>Algebraic function</b></col>, <cd>a quantity whose
connection with the variable is expressed by an equation that involves
only the algebraic operations of addition, subtraction, multiplication,
division, raising to a given power, and extracting a given root; --
opposed to <xex>transcendental function</xex>.</cd> -- <col><b>Arbitrary
function</b></col>. <cd>See under <er>Arbitrary</er>.</cd> --
<col><b>Calculus of functions</b></col>. <cd>See under
<er>Calculus</er>.</cd> -- <col><b>Carnot's function</b></col>
<fld>(Thermo-dynamics)</fld>, <cd>a relation between the amount of heat
given off by a source of heat, and the work which can be done by it. It
is approximately equal to the mechanical equivalent of the thermal unit
divided by the number expressing the temperature in degrees of the air
thermometer, reckoned from its zero of expansion.</cd> --
<col><b>Circular functions</b></col>. <cd>See <cref>Inverse
trigonometrical functions</cref> (below). -- Continuous function, a
quantity that has no interruption in the continuity of its real values,
as the variable changes between any specified limits.</cd> --
<col><b>Discontinuous function</b></col>. <cd>See under
<er>Discontinuous</er>.</cd> -- <col><b>Elliptic functions</b></col>,
<cd>a large and important class of functions, so called because one of
the forms expresses the relation of the arc of an ellipse to the
straight lines connected therewith.</cd> -- <col><b>Explicit
function</b></col>, <cd>a quantity directly expressed in terms of the
independently varying quantity; thus, in the equations <mathex>y =
6x<exp>2</exp></mathex>, <mathex>y = 10 -x<exp>3</exp></mathex>, the
quantity <it>y</it> is an explicit function of <it>x</it>.</cd> --
<col><b>Implicit function</b></col>, <cd>a quantity whose relation to
the variable is expressed indirectly by an equation; thus, <it>y</it> in
the equation <mathex>x<exp>2</exp> + y<exp>2</exp> = 100</mathex> is an
implicit function of <it>x</it>.</cd> -- <mcol><col><b>Inverse
trigonometrical functions</b></col>, <it>or</it> <col><b>Circular
functions</b></col></mcol>, <cd>the lengths of arcs relative to the
sines, tangents, etc. Thus, AB is the arc whose sine is BD, and (if the
length of BD is <it>x</it>) is written <fexp>sin <exp>-1</exp>x</fexp>,
and so of the other lines. See <cref>Trigonometrical function</cref>
(below). Other transcendental functions are the <xex>exponential
functions</xex>, the <xex>elliptic functions</xex>, the <xex>gamma
functions</xex>, the <xex>theta functions</xex>, etc.</cd> --
<mcol><col><b>One-valued function</b></col>, <cd>a quantity that has
one, and only one, value for each value of the variable.</cd> --
<col><b>Transcendental functions</b></col>, <cd>a quantity whose
connection with the variable cannot be expressed by algebraic
operations; thus, <it>y</it> in the equation <mathex>y =
10<exp>x</exp></mathex> is a transcendental function of <it>x.</it> See
<cref>Algebraic function</cref> (above).</cd> -- <col><b>Trigonometrical
function</b></col></mcol>, <cd>a quantity whose relation to the variable
is the same as that of a certain straight line drawn in a circle whose
radius is unity, to the length of a corresponding are of the circle. Let
AB be an arc in a circle, whose radius OA is unity let AC be a quadrant,
and let OC, DB, and AF be drawnpependicular to OA, and EB and CG
parallel to OA, and let OB be produced to G and F. E Then BD is the sine
of the arc AB; OD or EB is the cosine, AF is the tangent, CG is the
cotangent, OF is the secant OG is the cosecant, AD is the versed sine,
and CE is the coversed sine of the are AB. If the length of AB be
represented by <it>x</it> (OA being unity) then the lengths of
Functions. these lines (OA being unity) are the trigonometrical
functions of <it>x</it>, and are written <fexp>sin x</fexp>, <fexp>cos
x</fexp>, <fexp>tan x</fexp> (or <fexp>tang x</fexp>), <fexp>cot
x</fexp>, <fexp>sec x</fexp>, <fexp>cosec x</fexp>, <fexp>versin
x</fexp>, <fexp>coversin x</fexp>. These quantities are also considered
as functions of the angle BOA.</cd></cs></p>

<p><ent>Functionate</ent><br/
<ent>Function</ent><br/
<mhw>{ <hw>Func"tion</hw> <pr>(f<ucr/<nsm/k"sh<ucr/n)</pr>,
<hw>Func"tion*ate</hw> <pr>(?)</pr>, }</mhw> <pos>v. i.</pos> <def>To
execute or perform a function; to transact one's regular or appointed
business.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Functional</ent><br/
<hw>Func"tion*al</hw> <pr>(f<ucr/<nsm/k"sh<ucr/n*<ait/l)</pr>,
<pos>a.</pos> <sn>1.</sn> <def>Pertaining to, or connected with, a
function or duty; official.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Pathology, Physiol.)</fld> <def>Pertaining to the
function of an organ or part, or to the functions in general; involving
or affecting function rather than physiology; <as>as,
<ex>functional</ex> deafness; a <ex>functional</ex> disease</as>. See
<cref>functional disease</cref>, below.</def> <wn16s>[wns=2]</wn16s><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Designed for or capable of a particular function or
use; <as>as, a style of writing in which every word is
<ex>functional</ex>; <ex>functional</ex> architecture</as>.</def>
<wn16s>[wns=1]</wn16s><br/
[<source>WordNet 1.6</source>]</p>

<p><sn>4.</sn> <def>Fit or ready for use or service; useable; in working
order; <as>as, the toaster was still <ex>functional</ex> even after
being dropped; the lawnmower is a bit rusty but still
<ex>functional</ex></as>. Antonym of <ant>out of order</ant> and
<ant>nonfunctional</ant>.</def> <wn16s>[wns=4 & 6]</wn16s><br/
<syn><b>Syn. --</b> usable, useable, in working order(predicate),
operable, operational, running(prenominal), operative.</syn><br/
[<source>WordNet 1.6</source>]</p>

<p><sn>5.</sn> <def>Designed to emphasize practical utility rather than
artistic or aesthetic purposes; <as>as, <ex>functional</ex> education
selects knowledge that is concrete and usable rather than abstract and
theoretical; <ex>functional</ex> architecture; an amateurish device,
crude but <ex>functional</ex></as>.</def><br/
[<source>WordNet 1.6</source>]</p>

<p><cs><col><b>Functional disease</b></col> <fld>(Med.)</fld>, <cd>a
disease of which the symptoms cannot be referred to any appreciable
lesion or change of structure; the derangement of an organ arising from
a cause, often unknown, external to itself opposed to <contr>organic
disease</contr>, in which the organ itself is affected.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>functionalism</ent><br/
<hw>functionalism</hw> <pos>n.</pos> <sn>1.</sn> <def>a psychology based
on the assumption that all mental process are useful to an organism in
adapting to the environment.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>any doctrine that stresses utility or
purpose.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>functionalist</ent><br/
<hw>functionalist</hw> <pos>n.</pos> <def>an adherent of
functionalism.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Functionalize</ent><br/
<hw>Func"tion*al*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To assign
to some function or office.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Functionally</ent><br/
<hw>Func"tion*al*ly</hw>, <pos>adv.</pos> <def>In a functional manner;
as regards normal or appropriate activity.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The organ is said to be <qex>functionally</qex> disordered.</q>
<rj><qau>Lawrence.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Functionary</ent><br/
<hw>Func"tion*a*ry</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Functionaries</plw> <pr>(#)</pr>.</plu> <ety>[Cf. F.
<ets>fonctionnaire</ets>.]</ety> <def>One charged with the performance
of a function or office; <as>as, a public <ex>functionary</ex>; secular
<ex>functionaries</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Functionless</ent><br/
<hw>Func"tion*less</hw>, <pos>a.</pos> <def>Destitute of function, or of
an appropriate organ. Darwin.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fund</ent><br/
<hw>Fund</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF. <ets>font</ets>,
<ets>fond</ets>, nom. <ets>fonz</ets>, bottom, ground, F.
<ets>fond</ets> bottom, foundation, <ets>fonds</ets> fund, fr. L.
<ets>fundus</ets> bottom, ground, foundation, piece of land. See
<er>Found</er> to establish.]</ety> <sn>1.</sn> <def>An aggregation or
deposit of resources from which supplies are or may be drawn for
carrying on any work, or for maintaining existence.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A stock or capital; a sum of money appropriated as
the foundation of some commercial or other operation undertaken with a
view to profit; that reserve by means of which expenses and credit are
supported; <as>as, the <ex>fund</ex> of a bank, commercial house,
manufacturing corporation, etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <pluf>pl.</pluf> <def>The stock of a national debt;
public securities; evidences (stocks or bonds) of money lent to
government, for which interest is paid at prescribed intervals; --
called also <altname>public funds</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>An invested sum, whose income is devoted to a
specific object; <as>as, the <ex>fund</ex> of an ecclesiastical society;
a <ex>fund</ex> for the maintenance of lectures or poor students</as>;
also, money systematically collected to meet the expenses of some
permanent object.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A store laid up, from which one may draw at
pleasure; a supply; a full provision of resources; <as>as, a
<ex>fund</ex> of wisdom or good sense</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>An inexhaustible <qex>fund</qex> of stories.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Sinking fund</b></col>, <cd>the aggregate of sums of
money set apart and invested, usually at fixed intervals, for the
extinguishment of the debt of a government, or of a corporation, by the
accumulation of interest.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fund</ent><br/
<hw>Fund</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Funded</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Funding</conjf>.]</vmorph> <sn>1.</sn> <def>To provide and
appropriate a fund or permanent revenue for the payment of the interest
of; to make permanent provision of resources (as by a pledge of revenue
from customs) for discharging the interest of or principal of; <as>as,
to <ex>fund</ex> government notes</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To place in a fund, as money.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To put into the form of bonds or stocks bearing
regular interest; <as>as, to <ex>fund</ex> the floating
debt</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fundable</ent><br/
<hw>Fund"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of being
funded, or converted into a fund; convertible into bonds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fundament</ent><br/
<hw>Fun"da*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>fundament</ets>, <ets>fundement</ets>, <ets>fondement</ets>, OF.
<ets>fundement</ets>, <ets>fondement</ets>, F. <ets>fondement</ets>, fr.
L. <ets>fundamentum</ets> foundation, fr. <ets>fundare</ets> to lay the
bottom, to found, fr. <ets>fundus</ets> bottom. See
<er>Fund</er>.]</ety> <sn>1.</sn> <def>Foundation.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The part of the body on which one sits; the
buttocks; specifically <fld>(Anat.)</fld>, the anus.</def>
<rj><au>Hume.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fundamental</ent><br/
<hw>Fun`da*men"tal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>fondamental</ets>.]</ety> <def>Pertaining to the foundation or
basis; serving for the foundation.</def> <specif>Hence:</specif>
<def>Essential, as an element, principle, or law; important; original;
elementary; <as>as, a <ex>fundamental</ex> truth; a <ex>fundamental</ex>
axiom.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>fundamental</qex> reasons of this war.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Some <qex>fundamental</qex> antithesis in nature.</q>
<rj><qau>Whewell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fundamental bass</b></col> <fld>(Mus.)</fld>, <cd>the
root note of a chord; a bass formed of the roots or fundamental tones of
the chords.</cd> -- <col><b>Fundamental chord</b></col>
<fld>(Mus.)</fld>, <cd>a chord, the lowest tone of which is its
root.</cd> -- <col><b>Fundamental colors</b></col>, <cd>red, green, and
violet-blue. See <cref>Primary colors</cref>, under
<er>Color</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fundamental</ent><br/
<hw>Fun"da*men`tal</hw>, <pos>n.</pos> <def>A leading or primary
principle, rule, law, or article, which serves as the groundwork of a
system; essential part, <as>as, the <ex>fundamentals</ex> of the
Christian faith</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>fundamentalism</ent><br/
<hw>fundamentalism</hw> <pos>n.</pos> <sn>1.</sn> <def>A system of
beliefs based on the interpretation of every word in the Bible, both old
and new testaments, as literal truth. It is primarily held by a branch
of American Protestants.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>The beliefs or practices based on a rigid adherence
to some traditional doctrine; extreme conservatism; <as>as, Moslem
<ex>fundamentalism</ex>; the political <ex>fundamentalism</ex> of the
Christian right</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>fundamentalistic</ent><br/
<ent>fundamentalist</ent><br/
<mhw><hw>fundamentalist</hw> <hw>fundamentalistic</hw></mhw>
<pos>adj.</pos> <sn>1.</sn> <def>of or pertaining to fundamentalists or
fundamentalism.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>characteristic of a fundamentalist; -- especially,
resembling the behavior of a fundamentalist; <as>as, a
<ex>fundamentalist</ex> dislike of new ideas</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>fundamentalist</ent><br/
<hw>fundamentalist</hw> <pos>n.</pos> <def>a supporter of
fundamentalism.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fundamentally</ent><br/
<hw>Fun`da*men"tal*ly</hw>, <pos>adv.</pos> <def>Primarily; originally;
essentially; radically; at the foundation; in origin or
constituents.</def> <ldquo/<xex>Fundamentally</xex> defective.<rdquo/
<rj><au>Burke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Funded</ent><br/
<hw>Fund"ed</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Existing
in the form of bonds bearing regular interest; <as>as, <ex>funded</ex>
debt</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Invested in public funds; <as>as, funded
money</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fundholder</ent><br/
<hw>Fund"hold"er</hw> <pr>(?)</pr>, <pos>a.</pos> <def>One who has money
invested in the public funds.</def> <rj><au>J. S. Mill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Funding</ent><br/
<hw>Fund"ing</hw>, <pos>a.</pos> <sn>1.</sn> <def>Providing a fund for
the payment of the interest or principal of a debt.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Investing in the public funds.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Funding system</b></col>, <cd>a system or scheme of
finance or revenue by which provision is made for paying the interest or
principal of a public debt.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fundless</ent><br/
<hw>Fund"less</hw>, <pos>a.</pos> <def>Destitute of funds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fundus</ent><br/
\'d8<hw>Fun"dus</hw> <pr>(f<ucr/n"d<ucr/s)</pr>, <pos>n.</pos> <ety>[L.,
bottom.]</ety> <fld>(Anat.)</fld> <def>The bottom or base of any hollow
organ; <as>as, the <ex>fundus</ex> of the bladder; the <ex>fundus</ex>
of the eye; the <ex>fundus</ex> of the uterus.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Funebrial</ent><br/
<hw>Fu*ne"bri*al</hw> <pr>(f<usl/*n<emac/"br<icr/*<ait/l)</pr>,
<pos>a.</pos> <ety>[L. <ets>funebris</ets> belonging to a funeral, fr.
<ets>funus</ets> funeral.]</ety> <def>Pertaining to a funeral or
funerals; funeral; funereal.</def> <mark>[Obs.]</mark> <altsp>[Written
also <asp>funebral</asp>.]</altsp> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Funebrious</ent><br/
<hw>Fu*ne"bri*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Funebrial.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Funeral</ent><br/
<hw>Fu"ner*al</hw> <pr>(f<umac/"n<etil/r*<ait/l)</pr>, <pos>n.</pos>
<ety>[LL. <ets>funeralia</ets>, prop. neut. pl. of <ets>funeralis</ets>
of a funeral, fr. L. <ets>funus</ets>, <ets>funeris</ets>, funeral: cf.
F. <ets>fun<eacute/railles</ets>.]</ety> <sn>1.</sn> <def>The solemn
rites used in the disposition of a dead human body, whether such
disposition be by interment, burning, or otherwise; esp., the ceremony
or solemnization of interment; obsequies; burial; -- formerly used in
the plural.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>King James his <qex>funerals</qex> were performed very solemnly in
the collegiate church at Westminster.</q>
<rj><qau>Euller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The procession attending the burial of the dead; the
show and accompaniments of an interment.</def> <ldquo/The long
<xex>funerals</xex>.<rdquo/ <rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A funeral sermon; -- usually in the plural.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Mr. Giles Lawrence preached his <qex>funerals</qex>.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Funeral</ent><br/
<hw>Fu"ner*al</hw>, <pos>a.</pos> <ety>[LL. <ets>funeralis</ets>. See
<er>Funeral</er>, <pos>n.</pos>]</ety> <def>Pertaining to a funeral;
used at the interment of the dead; <as>as, <ex>funeral</ex> rites,
honors, or ceremonies</as>.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Funeral pile</b></col> <it>or</it> <col><b>Funeral
pyre</b></col></mcol>, <cd>a structure of combustible material, upon
which a dead body is placed to be reduced to ashes, as part of a funeral
rite; a pyre.</cd></cs></p>

<p>-- <wordforms><wf>Fu"ner*al*ly</wf>, <pos>adv.</pos>
<mark>[Obs.]</mark></wordforms> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>funeral home</ent><br/
<hw>fu"ner*al home`</hw>, <pos>n.</pos> <def>An establishment, usually
commercial, where the bodies of dead persons are prepared for viewing
before burial or cremation; called also <altname>funeral
parlor</altname>, <altname>mortuary</altname>, <altname>funeral
chapel</altname> and informally, <altname>undertaker's</altname>. The
body may or may not be preserved by embalming before viewing or burial,
and in some cases the body is not exposed for viewing, though present in
a casket. Often, some form of memorial service is held for the deceased
at the funeral home, where friends and relatives may come to pay their
respects to the dead, and express condolence to the family. The work of
preparation of the body and many other arrangements related to the
funeral and burial are carried out by an undertaker or mortician who
manages the <ex>funeral home</ex>.</def><br/
[<source>PJC</source>]</p>

<p><ent>funeral parlor</ent><br/
<hw>fu"ner*al par"lor</hw>, <pos>n.</pos> <def>Same as <er>funeral
home</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>funerary</ent><br/
<hw>fu"ner*ar`y</hw> <pr>(f<umac/"n<adot/*r<etil/r`<ycr/)</pr>,
<pos>adj.</pos> <def>of or pertaining to a funeral or to burial of human
remains; <as>as, <ex>funerary</ex> urn</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Funerate</ent><br/
<hw>Fu"ner*ate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>funeratus</ets>, p. p. of <ets>funerare</ets> to funerate, fr.
<ets>funus</ets>. See <er>Funeral</er>.]</ety> <def>To bury with funeral
rites.</def> <mark>[Obs.]</mark> <rj><au>Cockeram.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Funeration</ent><br/
<hw>Fu`ner*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>funeratio</ets>.]</ety> <def>The act of burying with funeral
rites.</def> <mark>[Obs.]</mark> <rj><au>Knatchbull.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Funereal</ent><br/
<hw>Fu*ne"re*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>funereus</ets>, fr. <ets>fentus</ets> a funeral.]</ety>
<def>Suiting a funeral; pertaining to burial; solemn; <as>as, at a
<ex>funereal</ex> pace</as>.</def> <specif>Hence:</specif> <def>Dark;
dismal; mournful.</def> <rj><au>Jer. Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>What seem to us but sad <qex>funereal</qex> tapers May be heaven's
distant lamps.</q> <rj><qau>Longfellow.</qau></rj></p>

<p>-- <wordforms><wf>Fu*ne"re*al*ly</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Funest</ent><br/
<hw>Fu*nest"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>funestus</ets>, fr. <ets>funus</ets> a funeral, destruction: cf. F.
<ets>funeste</ets>.]</ety> <def>Lamentable; doleful.</def>
<mark>[R.]</mark> <ldquo/<xex>Funest</xex> and direful deaths.<rdquo/
<rj><au>Coleridge.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A forerunner of something very <qex>funest</qex>.</q>
<rj><qau>Evelyn.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fungal</ent><br/
<hw>Fun"gal</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining to
fungi.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fungate</ent><br/
<hw>Fun"gate</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>fongate</ets>.]</ety> <fld>(Chem.)</fld> <def>A salt of fungic
acid.</def> <altsp>[Formerly written also
<asp>fungiate</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Funge</ent><br/
<hw>Funge</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>fungus</ets>
mushroom, dolt.]</ety> <def>A blockhead; a dolt; a fool.</def>
<mark>[Obs.]</mark> <rj><au>Burton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fungi</ent><br/
<hw>Fun"gi</hw> <pr>(f<ucr/n"j<imac/)</pr>, <pos>n. pl.</pos>;
<sing><it>sing.</it> <singw>fungus</singw>.</sing> <fld>(Biol.)</fld>
<def>A group of thallophytic plant-like organisms of low organization,
destitute of chlorophyll, in which reproduction is mainly accomplished
by means of asexual spores, which are produced in a great variety of
ways, though sexual reproduction is known to occur in certain
<stype>Phycomycetes</stype>, or so-called algal fungi. They include the
molds, mildews, rusts, smuts, mushrooms, toadstools, puff balls, and the
allies of each. In the two-kingdom classification system they were
classed with the plants, but in the modern five-kingdom classification,
they are not classed as plants, but are classed in their own separate
kingdom <it>fungi</it>, which includes the phyla
<phylum>Zygomycota</phylum> (including simple fungi such as bread
molds), <phylum>Ascomycota</phylum> (including the yeasts),
<phylum>Basidiomycota</phylum> (including the mushrooms, smuts, and
rusts), and <phylum>Deuteromycota</phylum> (the <er>fungi
imperfecti</er>). Some of the forms, such as the yeasts, appear as
single-celled microorganisms, but all of the fungi are are eukaryotic,
thus distinguishing them from the prokaryotic microorganisms of the
kingdom <it>Monera</it>.</def><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><note><hand/ The <ex>Fungi</ex> appear to have originated by
degeneration from various alg<ae/, losing their chlorophyll on assuming
a parasitic or saprophytic life. In an earlier classification they were
divided into the subclasses <stype>Phycomycetes</stype>, the lower or
algal fungi; the <stype>Mesomycetes</stype>, or intermediate fungi; and
the <stype>Mycomycetes</stype>, or the higher fungi; by others into the
<stype>Phycomycetes</stype>; the <stype>Ascomycetes</stype>, or
sac-spore fungi; and the <stype>Basidiomycetes</stype>, or
basidial-spore fungi.</note><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Fungia</ent><br/
\'d8<hw>Fun"gi*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. L.
<ets>fungus</ets> mushroom: cf. F. <ets>fongie</ets>.]</ety>
<fld>(Zool.)</fld> <def>A genus of simple, stony corals; -- so called
because they are usually flat and circular, with radiating plates, like
the gills of a mushroom. Some of them are eighteen inches in
diameter.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fungian</ent><br/
<hw>Fun"gi*an</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Of or pertaining to the <fam>Fungid<ae/</fam>, a family of stony
corals.</def> -- <def2><pos>n.</pos> <def>One of the
<fam>Fungid<ae/</fam>.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fungibles</ent><br/
<hw>Fun"gi*bles</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[LL.
(<ets>res</ets>) <ets>fungibiles</ets>, probably fr. L. <ets>fungi</ets>
to discharge. <ldquo/A barbarous term, supposed to have originated in
the use of the words <ets>functionem recipere</ets> in the
Digeste.<rdquo/ <ets>Bouvier</ets>. <ldquo/Called <ets>fungibiles</ets>,
<ets>quia una alterius</ets> vice fungitur.<rdquo/ <ets>John
Taylor</ets> (1755). Cf. <er>Function</er>.]</ety> <sn>1.</sn>
<fld>(Civ. Law)</fld> <def>Things which may be furnished or restored in
kind, as distinguished from specific things; -- called also
<altname>fungible things</altname>.</def> <rj><au>Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Scots Law)</fld> <def>Movable goods which may be
valued by weight or measure, in contradistinction from those which must
be judged of individually.</def> <rj><au>Jamieson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fungic</ent><br/
<hw>Fun"gic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>fungus</ets>
mushroom: cf. F. <ets>fungique</ets>, <ets>fongique</ets>.]</ety>
<fld>(Chem.)</fld> <def>Pertaining to, or obtained from, mushrooms;
<as>as, fungic acid</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fungicide</ent><br/
<hw>Fun"gi*cide`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Fungi</ets>
+ <ets>-cide</ets>, fr. L. <ets>caedere</ets> to kill.]</ety>
<def>Anything that kills fungi.</def> --
<wordforms><wf>Fun`gi*ci"dal</wf> <pr>(#)</pr>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fungiform</ent><br/
<hw>Fun"gi*form</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Eungus</ets>
+ <ets>-form</ets>: cf. F. <ets>fongiforme</ets>.]</ety> <def>Shaped
like a fungus or mushroom.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fungiform papill<ae/</b></col> <fld>(Anat.)</fld>,
<cd>numerous small, rounded eminences on the upper surface of the
tongue.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fungi Imperfecti</ent><br/
\'d8<hw>Fun"gi Im`per*fec"ti</hw> <pr>(?)</pr>, <pos>pl.</pos> <ety>[L.
<ets>imperfecti</ets> imperfect.]</ety> <fld>(Bot.)</fld> <def>A
heterogenous phylum of fungi which lack a sexual phase, or of which the
sexual phase is not known. Some undoubtedly represent the conidium
stages of various Ascomycetes. It is not considered a natural phylum,
and is also called the <altname>Deuteromycota</altname>. The group is
divided into the orders <ord>Sph<ae/ropsidales</ord>,
<ord>Melanconiales</ord>, and <ord>Moniliales</ord>. It includes the
genera <gen>Penicillium</gen> and <gen>Aspergillus</gen>, which
reproduce asexually by means of conidia.</def><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><ent>Fungilliform</ent><br/
<hw>Fun*gil"li*form</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Shaped like a
small fungus.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fungin</ent><br/
<hw>Fun"gin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>fungus</ets>
mushroom: cf. F, <ets>fongine</ets>, <ets>fungine</ets>.]</ety>
<fld>(Chem.)</fld> <def>A name formerly given to cellulose found in
certain fungi and mushrooms.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fungite</ent><br/
<hw>Fun"gite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>fungus</ets>
mushroom: cf. F. <ets>pongite</ets>.]</ety> <fld>(Paleon.)</fld> <def>A
fossil coral resembling Fungia.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fungivorous</ent><br/
<hw>Fun*giv"o*rous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>fungus</ets> + <ets>vorare</ets> to eat greedily: cf. F.
<ets>fongivore</ets>.]</ety> <fld>(Zool.)</fld> <def>Eating fungi; --
said of certain insects and snails.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fungoid</ent><br/
<hw>Fun"goid</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Fungus</ets> +
<ets>-oil</ets>: cf. F. <ets>fongo<ium/de</ets>.]</ety> <def>Like a
fungus; fungous; spongy.</def><br/
<syn><b>Syn. --</b> funguslike.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fungologist</ent><br/
<hw>Fun*gol"o*gist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A
mycologist.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fungology</ent><br/
<hw>Fun*gol"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Fungus</ets> + <ets>-logy</ets>.]</ety>
<def>Mycology.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fungosity</ent><br/
<hw>Fun*gos"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>fungosit<eacute/</ets>, <ets>fongosit<eacute/</ets>.]</ety>
<def>The quality of that which is fungous; fungous excrescence.</def>
<rj><au>Dunglison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fungous</ent><br/
<hw>Fun"gous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>fungosus</ets>: cf. F. <ets>fungueux</ets>.]</ety> <sn>1.</sn>
<def>Of the nature of fungi; spongy.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 604 --></p>

<p><sn>2.</sn> <def>Growing suddenly, but not substantial or
durable.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fungus</ent><br/
<hw>Fun"gus</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it> L.
<plw>Fungi</plw> <pr>(#)</pr>, E. <plw>Funguses</plw>
<pr>(#)</pr>.</plu> <ety>[L., a mushroom; perh. akin to a doubtful Gr.
<?/ sponge, for <?/; if so, cf. E. <ets>sponge</ets>.]</ety> <sn>1.</sn>
<fld>(Bot.)</fld> <def>Any one of the <er>Fungi</er>, a large and very
complex group of thallophytes of low organization, -- the molds,
mildews, rusts, smuts, mushrooms, toadstools, puff balls, and the allies
of each. See <er>fungi</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The fungi are all destitute of chorophyll, and,
therefore, to be supplied with elaborated nourishment, must live as
saprophytes or parasites. They range in size from single microscopic
cells to systems of entangled threads many feet in extent, which develop
reproductive bodies as large as a man's head. The vegetative system
consists of septate or rarely unseptate filaments called hyph<ae/; the
aggregation of hyph<ae/ into structures of more or less definite form is
known as the mycelium. See <er>Fungi</er>, in the Supplement.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Med.)</fld> <def>A spongy, morbid growth or
granulation in animal bodies, as the proud flesh of wounds.</def>
<rj><au>Hoblyn.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>funguslike</ent><br/
<hw>fun"gus*like`</hw> <pos>adj.</pos> <def>resembling a fungus or
fungi.</def><br/
<syn><b>Syn. --</b> fungoid.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Funic</ent><br/
<hw>Fu"nic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Anat.)</fld>
<def>Funicular.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Funicle</ent><br/
<hw>Fu"ni*cle</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>funiculus</ets>, dim. of <ets>funis</ets> cord, rope: cf. F.
<ets>funicule</ets> funicle (in sense 2). Cf. <er>Funambulo</er>.]</ety>
<fld>(Bot.)</fld> <sn>1.</sn> <def>A small cord, ligature, or
fiber.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>The little stalk that attaches a
seed to the placenta.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Funicular</ent><br/
<hw>Fu*nic"u*lar</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>funiculaire</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Consisting of a small cord or fiber.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Dependent on the tension of a cord.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Anat.)</fld> <def>Pertaining to a funiculus; made
up of, or resembling, a funiculus, or funiculi; <as>as, a funicular
ligament</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Funicular action</b></col> <fld>(Mech.)</fld>, <cd>the
force or action exerted by a rope in drawing together the supports to
which its ends are Fastened, when acted upon by forces applied in a
direction transverse to the rope, as in the archer's bow.</cd> --
<col><b>Funicular curve</b></col>. <cd>Same as <er>Catenary</er>.</cd>
-- <col><b>Funicular machine</b></col> <fld>(Mech.)</fld>, <cd>an
apparatus for illustrating certain principles in statics, consisting of
a cord or chain attached at one end to a fixed point, and having the
other passed over a pulley and sustaining a weight, while one or more
other weights are suspended from the cord at points between the fixed
support and the pulley.</cd> -- <col><b>Funicular polygon</b></col>
<fld>(Mech.)</fld>, <cd>the polygonal figure assumed by a cord fastened
at its extremities, and sustaining weights at different
points.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Funiculate</ent><br/
<hw>Fu*nic"u*late</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Forming a narrow
ridge.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Funiculus</ent><br/
\'d8<hw>Fu*nic"u*lus</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Funiculi</plw> <pr>(#)</pr>.</plu> <ety>[L., a little cord. See
<er>Funicle</er>.]</ety> <sn>1.</sn> <fld>(Anat.)</fld> <def>A cord,
baud, or bundle of fibers; esp., one of the small bundles of fibers, of
which large nerves are made up; applied also to different bands of white
matter in the brain and spinal cord.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <sd>(a)</sd> <def>A short cord which
connects the embryo of some myriapods with the amnion.</def>
<sd>(b)</sd> <def>In Bryozoa, an organ extending back from the stomach.
See <er>Bryozoa</er>, and <er>Phylactolema</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Funiliform</ent><br/
<hw>Fu*nil"i*form</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>funis</ets> rope + <ets>-form</ets>.]</ety> <fld>(Bot.)</fld>
<def>Resembling a cord in toughness and flexibility, as the roots of
some endogenous trees.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Funis</ent><br/
\'d8<hw>Fu"nis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., a rope.
]</ety> <def>A cord; specifically, the umbilical cord or navel
string.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Funk</ent><br/
<hw>Funk</hw> <pr>(f<ucr/<nsm/k)</pr>, <pos>n.</pos> <ety>[OE.
<ets>funke</ets> a little fire; akin to Prov. E. <ets>funk</ets>
touchwood, G. <ets>funke</ets> spark, and perh. to Goth.
<ets>f<omac/n</ets> fire.]</ety> <sn>1.</sn> <def>An offensive smell; a
stench.</def> <mark>[Low]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who funks; a shirk; a coward.</def>
<mark>[Colloq.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>3.</sn> <def>a state of fear.</def><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <def>a mildly depressed state of mind; -- often used in
the phrase <altname>blue funk</altname>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Funk</ent><br/
<hw>Funk</hw> <pr>(f<ucr/<nsm/k)</pr>, <pos>n.</pos> <def>an earthy,
seemingly unsophisticated style of jazz music having elements of black
American blues and gospel.</def><br/
[<source>PJC</source>]</p>

<p><ent>Funk</ent><br/
<hw>Funk</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To envelop with an
offensive smell or smoke.</def> <mark>[Obs.]</mark>
<rj><au>King.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To funk at; to flinch at; to shrink from (a thing or
person); <as>as, to <ex>funk</ex> a task</as>.</def>
<mark>[Colloq.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>3.</sn> <def>To frighten; to cause to flinch.</def>
<mark>[Colloq.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Funk</ent><br/
<hw>Funk</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To emit an offensive
smell; to stink.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To be frightened, and shrink back; to flinch;
<as>as, to funk at the edge of a precipice</as>.</def>
<mark>[Colloq.]</mark> <rj><au>C. Kingsley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To funk out</b></col>, <cd>to back out in a cowardly
fashion.</cd> <mark>[Colloq.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>funk</qex> right out o' political strife.</q>
<rj><qau>Lowell (Biglow Papers).</qau></rj></p>

<p><ent>Funking</ent><br/
<ent>Funk</ent><br/
<mhw>{ <hw>Funk</hw>, <hw>Funk"ing</hw>, }</mhw> <pos>n.</pos> <def>A
shrinking back through fear.</def> <mark>[Colloq.]</mark> <ldquo/The
horrid panic, or <xex>funk</xex> (as the men of Eton call it).<rdquo/
<rj><au>De Quincey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Funka</ent><br/
<hw>Funka</hw> <pos>n.</pos> <def>A genus of robust East Asian
clump-forming perennial herbs having racemose flowers: plantain lilies;
sometimes placed in the family <fam>Hostaceae</fam>.</def><br/
<syn><b>Syn. --</b> Hosta, genus <gen>Hosta</gen>, genus
<gen>Funka</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Funkaceae</ent><br/
<hw>Funkaceae</hw> <pos>n.</pos> <def>one of many families or
subfamilies into which some classification systems subdivide the
Liliaceae, but not widely accepted; it includes the genus
<gen>Hosta</gen>.</def><br/
<syn><b>Syn. --</b> Hostaceae, family <fam>Hostaceae</fam>, family
<fam>Funkaceae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Funky</ent><br/
<hw>Funk"y</hw> <pr>(f<ucr/<nsm/k"<ycr/)</pr>, <pos>a.</pos>
<def>Pertaining to, or characterized by, great fear, or funking; having
great fear.</def> <mark>[Colloq. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Funky</ent><br/
<hw>Funk"y</hw> <pr>(f<ucr/<nsm/k"<ycr/)</pr>, <pos>n.</pos> <def>having
an earthy, unsophisticated style or feeling;</def> <specif>in</specif>
<fld>(Music)</fld>, <def>earthy and seemingly unsophisticated, having
elements of black American blues and gospel. See 2nd <er>funk</er>,
<pos>n.</pos></def><br/
[<source>PJC</source>]</p>

<p><ent>Funnel</ent><br/
<hw>Fun"nel</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>funel</ets>,
<ets>fonel</ets>, prob. through OF. fr, L. <ets>fundibulum</ets>,
<ets>infundibulum</ets>, funnel, fr. <ets>infundere</ets> to pour in; in
in + <ets>fundere</ets> to pour; cf. Armor. <ets>founil</ets> funnel, W.
<ets>ffynel</ets> air hole, chimney. See <er>Fuse</er>, <pos>v.
t.</pos>]</ety> <sn>1.</sn> <def>A vessel of the shape of an inverted
hollow cone, terminating below in a pipe, and used for conveying liquids
or pourable solids into a vessel with a narrow opening; a
tunnel.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A passage or avenue for a fluid or flowing
substance; specifically, a smoke flue or pipe; the iron chimney of a
steamship or the like.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Funnel box</b></col> <fld>(Mining)</fld>, <cd>an
apparatus for collecting finely crushed ore from water.</cd>
<au>Knight.</au> -- <col><b>Funnel stay</b></col> <fld>(Naut.)</fld>,
<cd>one of the ropes or rods steadying a steamer's funnel.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Funnelform</ent><br/
<hw>Fun"nel*form`</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Bot.)</fld>
<def>Having the form of a funnel, or tunnel; that is, expanding
gradually from the bottom upward, as the corolla of some flowers;
infundibuliform.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>funnies</ent><br/
<hw>fun"nies</hw> <pr>(f<ucr/n"<emac/z)</pr>, <pos>n. pl.</pos> <def>The
section of a newspaper containing comic strips; called also
<altname>funny papers</altname> and <altname>comics</altname>. Rarely
encountered in the singular.</def><br/
[<source>PJC</source>]</p>

<p><ent>funniness</ent><br/
<hw>funniness</hw> <pos>n.</pos> <def>a comic incident or series of
incidents.</def><br/
<syn><b>Syn. --</b> drollery, clowning, comedy.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Funny</ent><br/
<hw>Fun"ny</hw> <pr>(?)</pr>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Funnier</adjf> <pr>(?)</pr>; <pos>superl.</pos>
<adjf>Funniest</adjf>.]</amorph> <ety>[From <er>Fun</er>.]</ety>
<def>Droll; comical; amusing; laughable; inciting laughter.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Funny bone</b></col>. <cd>See <cref>crazy bone</cref>,
under <er>Crazy</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Funny</ent><br/
<hw>Fun"ny</hw>, <pos>n.</pos>; <plu><it>pl.</it> <plw>Funnies</plw>
<pr>(<?/)</pr>.</plu> <def>A clinkerbuit, narrow boat for
sculling.</def> <mark>[Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fur</ent><br/
<hw>Fur</hw> <pr>(f<ucir/r)</pr>, <pos>n.</pos> <ety>[OE.
<ets>furre</ets>, OF. <ets>forre</ets>, <ets>fuerre</ets>, sheath, case,
of German origin; cf. OHG. <ets>fuotar</ets> lining, case, G.
<ets>futter</ets>; akin to Icel. <ets>f<omac/<edh/r</ets> lining, Goth.
<ets>f<omac/dr</ets>, scabbard; cf. Skr. <ets>p<amac/tra</ets> vessel,
dish. The German and Icel. words also have the sense, <ets>fodder</ets>,
but this was probably a different word originally. Cf. <er>Fodder</er>
food, <er>Fother</er>, <pos>v. t.</pos>, <er>Forel</er>,
<pos>n.</pos>]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>The short, fine, soft hair of certain animals,
growing thick on the skin, and distinguished from the hair, which is
longer and coarser.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The skins of certain wild animals with the fur;
peltry; <as>as, a cargo of furs</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Strips of dressed skins with fur, used on garments
for warmth or for ornament.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <pluf>pl.</pluf> <def>Articles of clothing made of fur;
<as>as, a set of <ex>furs</ex> for a lady (a collar, tippet, or cape,
muff, etc.)</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Wrapped up in my <qex>furs</qex>.</q> <rj><qau>Lady M. W.
Montagu.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Any coating considered as resembling fur</def>; as:
<sd>(a)</sd> <def>A coat of morbid matter collected on the tongue in
persons affected with fever.</def> <sd>(b)</sd> <def>The soft, downy
covering on the skin of a peach.</def> <sd>(c)</sd> <def>The deposit
formed on the interior of boilers and other vessels by hard
water.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Her.)</fld> <def>One of several patterns or diapers
used as tinctures. There are nine in all, or, according to some writers,
only six.</def> <rj><au>See Tincture.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fur</ent><br/
<hw>Fur</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining to furs;
bearing or made of fur; <as>as, a <ex>fur</ex> cap; the <ex>fur</ex>
trade.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fur seal</b></col> <fld>(Zool.)</fld> <cd>one of several
species of seals of the genera <gen>Callorhinus</gen> and
<gen>Arclocephalus</gen>, inhabiting the North Pacific and the Antarctic
oceans. They have a coat of fine and soft fur which is highly prized.
The northern fur seal (<spn>Callorhinus ursinus</spn>) breeds in vast
numbers on the Prybilov Islands, off the coast of Alaska; -- called also
<altname>sea bear</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fur</ent><br/
<hw>Fur</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Furred</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Furring</conjf>.]</vmorph> <sn>1.</sn> <def>To line, face, or
cover with fur; <as>as, <ex>furred</ex> robes</as>.</def> <ldquo/You
<xex>fur</xex> your gloves with reason.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To cover with morbid matter, as the
tongue.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Arch.)</fld> <def>To nail small strips of board or
larger scantling upon, in order to make a level surface for lathing or
boarding, or to provide for a space or interval back of the plastered or
boarded surface, as inside an outer wall, by way of protection against
damp.</def> <rj><au>Gwill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Furacious</ent><br/
<hw>Fu*ra"cious</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>furax</ets>, <ets>-racis</ets> thievish, from <ets>fur</ets>
thief.]</ety> <def>Given to theft; thievish.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Furacity</ent><br/
<hw>Fu*rac"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
furacitas.]</ety> <def>Addictedness to theft; thievishness.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Furbelow</ent><br/
<hw>Fur"be*low</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Prov. F.
<ets>farbala</ets>, equiv. to F. <ets>falbala</ets>, It.
<ets>falbal<agrave/</ets>.]</ety> <def>A plaited or gathered flounce on
a woman's garment.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Furbelow</ent><br/
<hw>Fur"be*low</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Furbelowed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Furbelowing</conjf>.]</vmorph> <def>To put a furbelow on; to
ornament.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Furbish</ent><br/
<hw>Fur"bish</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Furbished</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Furbishing</conjf>.]</vmorph> <ety>[OE.
<ets>forbischen</ets>, OF. <ets>forbir</ets>, <ets>furbir</ets>,
<ets>fourbir</ets>, F. <ets>fourbir</ets>, fr. OHG. <ets>furban</ets> to
clean. See <er>-ish</er>.]</ety> <def>To rub or scour to brightness; to
clean; to burnish; <as>as, to <ex>furbish</ex> a sword or
spear</as>.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Furbish</qex> new the name of John a Gaunt.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Furbishable</ent><br/
<hw>Fur"bish*a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of
being furbished.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Furbisher</ent><br/
<hw>Fur"bish*er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>fourbisseur</ets>.]</ety> <def>One who furbishes; esp., a sword
cutler, who finishes sword blades and similar weapons.</def></p>

<p><ent>Furcated</ent><br/
<ent>Furcate</ent><br/
<mhw>{ <hw>Fur"cate</hw> <pr>(?)</pr>, <hw>Fur"ca*ted</hw> <pr>(?)</pr>,
}</mhw> <pos>a.</pos> <ety>[L. <ets>furca</ets> fork. See
<er>Fork</er>.]</ety> <def>Forked; branching like a fork; <as>as,
<ex>furcate</ex> twigs</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Furcation</ent><br/
<hw>Fur*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A branching like a
fork.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Furciferous</ent><br/
<hw>Fur*cif"er*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>furcifer</ets> yoke bearer, scoundrel; <ets>furca</ets> fork, yoke,
fork-shaped instrument of punishment + <ets>ferre</ets> to bear.]</ety>
<def>Rascally; scandalous.</def> <mark>[R.]</mark>
<ldquo/<xex>Furciferous</xex> knaves.<rdquo/ <rj><au>De
Quincey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Furcula</ent><br/
\'d8<hw>Fur"cu*la</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., a forked
prop, dim. of <ets>furca</ets> a fork.]</ety> <fld>(Anat.)</fld> <def>A
forked process; the wishbone or furculum.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Furcular</ent><br/
<hw>Fur"cu*lar</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Shaped like a fork;
furcate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Furculum</ent><br/
\'d8<hw>Fur"cu*lum</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., dim. of
L. <ets>furca</ets> a fork.]</ety> <fld>(Anat.)</fld> <def>The wishbone
or merrythought of birds, formed by the united clavicles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Furdle</ent><br/
<hw>Fur"dle</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[See
<er>Fardel</er>, and cf. <er>Furl</er>.]</ety> <def>To draw up into a
bundle; to roll up.</def> <mark>[Ods.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Furfur</ent><br/
\'d8<hw>Fur"fur</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.]</ety>
<def>Scurf; dandruff.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Furfuraceous</ent><br/
<hw>Fur"fu*ra"ceous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>furfuraceus</ets>.]</ety> <def>Made of bran; like bran;
scurfy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Furfuran</ent><br/
<hw>Fur"fu*ran</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>furfur</ets> bran.]</ety> <fld>(Chem.)</fld> <def>A colorless, oily
substance, <chform>C4H4O</chform>, obtained by distilling certain
organic substances, as pine wood, salts of pyromucic acid, etc.; --
called also <altname>tetraphenol</altname>.</def><-- = furan --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Furfuration</ent><br/
<hw>Fur"fu*ra"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>furfur</ets> bran, scurf.]</ety> <def>Falling of scurf from the
head; desquamation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Furfurine</ent><br/
<hw>Fur"fu*rine</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>A white, crystalline base, obtained indirectly from
furfurol.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Furfurol</ent><br/
<hw>Fur"fu*rol</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>furfur</ets> bran + <ets>ole</ets>um oil.]</ety> <fld>(Chem.)</fld>
<def>A colorless oily liquid, <chform>C4H3O.CHO</chform>, of a pleasant
odor, obtained by the distillation of bran, sugar, etc., and regarded as
an aldehyde derivative of furfuran; -- called also
<altname>furfural</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Furfurous</ent><br/
<hw>Fur"fu*rous</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Made of bran;
furfuraceous.</def> <mark>[R.]</mark> <ldquo/<xex>Furfurous</xex>
bread.<rdquo/ <rj><au>Sydney Smith.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Furial</ent><br/
<hw>Fu"ri*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>furialis</ets>: cf. OF. <ets>furial</ets>.]</ety> <def>Furious;
raging; tormenting.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Furibundal</ent><br/
<hw>Fu`ri*bun"dal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>furibundus</ets>, fr. <ets>furere</ets> to rage.]</ety> <def>Full
of rage.</def> <mark>[Obs.]</mark> <rj><au>G. Harvey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Furies</ent><br/
<hw>Fu"ries</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <def>See <er>Fury</er>,
3.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Furile</ent><br/
<hw>Fu"rile</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Fur</ets>furol +
ben<ets>zile</ets>.]</ety> <fld>(Chem.)</fld> <def>A yellow, crystalline
substance, <chform>(C4H3O)2.C2O2</chform>, obtained by the oxidation of
furoin.</def> <altsp>[Written also <asp>furil</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Furilic</ent><br/
<hw>Fu*ril"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Chem.)</fld>
<def>Pertaining to, or derived from, furile; <as>as, <ex>furilic</ex>
acid</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Furioso</ent><br/
\'d8<hw>Fu"ri*o"so</hw> <pr>(?)</pr>, <pos>a. & adv.</pos>
<ety>[It.]</ety> <fld>(Mus.)</fld> <def>With great force or vigor;
vehemently.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Furious</ent><br/
<hw>Fu"ri*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>furiosus</ets>, fr. <ets>furia</ets> rage, fury: cf. F.
<ets>furieux</ets>. See <er>Fury</er>.]</ety> <sn>1.</sn>
<def>Transported with passion or fury; raging; violent; <as>as, a
furious animal</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Rushing with impetuosity; moving with violence;
<as>as, a <ex>furious</ex> stream; a <ex>furious</ex> wind or
storm.</as></def></p>

<p><syn><b>Syn.</b> -- Impetuous; vehement; boisterous; fierce;
turbulent; tumultuous; angry; mad; frantic; frenzied.</syn></p>

<p>-- <wordforms><wf>Fu"ri*ous*ly</wf>, <pos>adv.</pos> --
<wf>Fu"ri*ous*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>furiousness</ent><br/
<hw>fu"ri*ous*ness</hw> <pos>n.</pos> <def>The quality of being
furious.</def><br/
<syn><b>Syn. --</b> ferocity, fierceness, fury, vehemence, violence,
wildness, strength.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Furl</ent><br/
<hw>Furl</hw> <pr>(f<ucir/rl)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Furled</conjf> <pr>(f<ucir/rld)</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>Furling</conjf>.]</vmorph> <ety>[Contr. fr.
<ets>furdle</ets>, fr. <ets>fardel</ets> bundle: cf. F.
<ets>ferler</ets> to furl, OF. <ets>fardeler</ets> to pack. See
<er>Furdle</er>, <er>Fardel</er>, and cf. <er>Farl</er>.]</ety> <def>To
draw up or gather into close compass; to wrap or roll, as a sail, close
to the yard, stay, or mast, or, as a flag, close to or around its staff,
securing it there by a gasket or line.</def> <au>Totten.</au><br/
[<source>1913 Webster</source>]</p>

<p><ent>furled</ent><br/
<hw>furled</hw> <pr>(f<ucir/rld)</pr>, <pos>adj.</pos> <ety>[p. p. of
<er>furl</er>.]</ety> <def>rolled up and secured; <as>as,
<ex>furled</ex> sails bound securely to the spar; a <ex>furled</ex>
flag</as>.</def><br/
<syn><b>Syn. --</b> rolled.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Furlong</ent><br/
<hw>Fur"long</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>furlong</ets>, <ets>furlang</ets>, AS. <ets>furlang</ets>,
<ets>furlung</ets>, prop., the length of a furrow; <ets>furh</ets>
furrow + <ets>lang</ets> long. See <er>Furrow</er>, and <er>Long</er>,
<pos>a.</pos>]</ety> <def>A measure of length; the eighth part of a
mile; forty rods; two hundred and twenty yards.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Furlough</ent><br/
<hw>Fur"lough</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Prob. fr. D.
<ets>verlof</ets>, fr. a prefix akin to E. <ets>for</ets> + the root of
E. <ets>lief</ets>, and akin to Dan. <ets>forlov</ets>, Sw.
<ets>f<oum/rlof</ets>, G. <ets>verlaub</ets> permission. See
<er>Life</er>, <pos>a.</pos>]</ety> <fld>(Mil.)</fld> <def>Leave of
absence; especially, leave given to an officer or soldier to be absent
from service for a certain time; also, the document granting leave of
absence.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Furlough</ent><br/
<hw>Fur"lough</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Furloughed</conjf> <pr>(<?/)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Furloughing</conjf>.]</vmorph> <fld>(Mil.)</fld> <def>To furnish
with a furlough; to grant leave of absence to, as to an officer or
soldier.</def></p>

<p><ent>Furmity</ent><br/
<ent>Furmonty</ent><br/
<mhw>{ <hw>Fur"mon*ty</hw> <pr>(?)</pr>, <hw>Fur"mi*ty</hw> <pr>(?)</pr>
}</mhw> <pos>n.</pos> <def>Same as <er>Frumenty</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Furnace</ent><br/
<hw>Fur"nace</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>fornais</ets>, <ets>forneis</ets>, OF. <ets>fornaise</ets>, F.
<ets>fournaise</ets>, from L. <ets>fornax</ets>; akin to furnus oven,
and prob. to E. <ets>forceps</ets>.]</ety> <sn>1.</sn> <def>An inclosed
place in which heat is produced by the combustion of fuel, as for
reducing ores or melting metals, for warming a house, for baking
pottery, etc.; <as>as, an iron <ex>furnace</ex>; a hot-air
<ex>furnace</ex>; a glass <ex>furnace</ex>; a boiler <ex>furnace</ex>,
etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Furnaces are classified as <xex>wind</xex> or
<xex>air</xex>. <xex>furnaces</xex> when the fire is urged only by the
natural draught; as <xex>blast furnaces</xex>, when the fire is urged by
the injection artificially of a forcible current of air; and as
<xex>reverberatory furnaces</xex>, when the flame, in passing to the
chimney, is thrown down by a low arched roof upon the materials operated
upon.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A place or time of punishment, affliction, or great
trial; severe experience or discipline.</def> <rj><au>Deut. iv.
20.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Bustamente furnace</b></col>, <cd>a shaft furnace for
roasting quicksilver ores.</cd> -- <col><b>Furnace bridge</b></col>,
<cd>Same as <cref>Bridge wall</cref>.</cd> See <er>Bridge</er>,
<pos>n.</pos>, 5. -- <mcol><col><b>Furnace cadmiam</b></col> <it>or</it>
<col><b>Furnace cadmia</b></col></mcol>, <cd>the oxide of zinc which
accumulates in the chimneys of furnaces smelting zinciferous ores.</cd>
<au>Raymond.</au> -- <col><b>Furnace hoist</b></col> <fld>(Iron
Manuf.)</fld>, <cd>a lift for raising ore, coal, etc., to the mouth of a
blast furnace.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Furnace</ent><br/
<hw>Fur"nace</hw>, <pos>n.</pos> <sn>1.</sn> <def>To throw out, or
exhale, as from a furnace; also, to put into a furnace.</def>
<mark>[Obs. or R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He <qex>furnaces</qex><br/
The thick sighs from him.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Furnariidae</ent><br/
<hw>Furnariidae</hw> <pos>n.</pos> <def>A natural family including
ovenbirds.</def><br/
<syn><b>Syn. --</b> family <fam>Furnariidae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Furnarius</ent><br/
<hw>Furnarius</hw> <pos>n.</pos> <def>The type genus of the
<fam>Furnariidae</fam>, comprising the South American
ovenbirds.</def><br/
<syn><b>Syn. --</b> genus <gen>Furnarius</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Furniment</ent><br/
<hw>Fur"ni*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>fourniment</ets>. See <er>Furnish</er>.]</ety>
<def>Furniture.</def> <mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Furnish</ent><br/
<hw>Fur"nish</hw> <pr>(f<ucir/r"n<icr/sh)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Furnished</conjf> <pr>(?)</pr>;
<pos>p. pr. & vb. n.</pos> <conjf>Furnishing</conjf>.]</vmorph>
<ety>[OF. <ets>furnir</ets>, <ets>fornir</ets>, to <ets>furnish</ets>,
<ets>finish</ets>, F. <ets>fournir</ets>; akin to Pr. <ets>formir</ets>,
<ets>furmir</ets>, <ets>fromir</ets>, to accomplish, satisfy, fr. OHG.
<ets>frumjan</ets> to further, execute, do, akin to E. <ets>frame</ets>.
See <er>Frame</er>, <pos>v. t.</pos>, and <er>-ish</er>.]</ety>
<sn>1.</sn> <def>To supply with anything necessary, useful, or
appropriate; to provide; to equip; to fit out, or fit up; to adorn;
<as>as, to <ex>furnish</ex> a family with provisions; to
<ex>furnish</ex> one with arms for defense; to <ex>furnish</ex> a Cable;
to <ex>furnish</ex> the mind with ideas; to <ex>furnish</ex> one with
knowledge or principles; to <ex>furnish</ex> an expedition or
enterprise, a room or a house.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>That the man of God may be perfect, thoroughly
<qex>furnished</qex><br/
unto all good works.</q> <rj><qau>2 Tim. iii. 17,</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To offer for use; to provide (something); to give
(something); to afford; <as>as, to <ex>furnish</ex> food to the hungry:
to <ex>furnish</ex> arms for defense</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Ye are they . . . that <qex>furnish</qex> the drink offering unto
that number.</q> <rj><qau>Is. lxv. 11.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>His writings and his life <qex>furnish</qex> abundant proofs that
he was not a man of strong sense.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Furnish</ent><br/
<hw>Fur"nish</hw>, <pos>n.</pos> <def>That which is furnished as a
specimen; a sample; a supply.</def> <mark>[Obs.]</mark>
<rj><au>Greene.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>furnished</ent><br/
<hw>furnished</hw> <pos>adj.</pos> <def>provided with necessary
furnishings; -- used especially of rented apartments having furniture
included in the rental price; <as>as, a <ex>furnished</ex>
apartment</as>. Opposite of <ant>unfurnished</ant>.</def> [Narrower
terms: <stype>stocked, stocked with </stype>; <stype>appointed</stype>;
<stype>well-appointed, well-found </stype>; <stype>fitted out, outfitted
</stype>]<br/
<syn><b>Syn. --</b> equipped.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Furnisher</ent><br/
<hw>Fur"nish*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who supplies
or fits out.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>furnishings</ent><br/
<hw>fur"nish*ings</hw> <pos>n.</pos> <sn>1.</sn> <def>the furniture and
appliances and other movable accessories (including curtains and rugs)
that make a home (or other building) livable.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>accessory wearing apparel.</def><br/
<syn><b>Syn. --</b> trappings.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Furnishment</ent><br/
<hw>Fur"nish*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
furnishing, or of supplying furniture; also, furniture.</def>
<mark>[Obs.]</mark> <rj><au>Daniel.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Furniture</ent><br/
<hw>Fur"ni*ture</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>fourniture</ets>. See <er>Furnish</er>, <pos>v. t.</pos>]</ety>
<sn>1.</sn> <def>That with which anything is furnished or supplied;
supplies; outfit; equipment.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The form and all the <qex>furniture</qex> of the earth.</q>
<rj><qau>Tillotson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The thoughts which make the <qex>furniture</qex> of their
minds.</q> <rj><qau>M. Arnold.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Articles used for convenience or decoration in a
house or apartment, as tables, chairs, bedsteads, sofas, carpets,
curtains, pictures, vases, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The necessary appendages to anything, as to a
machine, a carriage, a ship, etc.</def> <sd>(a)</sd> <fld>(Naut.)</fld>
<def>The masts and rigging of a ship.</def> <sd>(b)</sd>
<fld>(Mil.)</fld> <def>The mountings of a gun.</def> <sd>(c)</sd>
<def>Builders' hardware such as locks, door and window trimmings.</def>
<sd>(d)</sd> <fld>(Print)</fld> <def>Pieces of wood or metal of a lesser
height than the type, placed around the pages or other matter in a form,
and, with the quoins, serving to secure the form in its place in the
chase.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Mus.)</fld> <def>A mixed or compound stop in an
organ; -- sometimes called <xex>mixture</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Furoin</ent><br/
<hw>Fu"ro*in</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Furfurol</er>.]</ety> <fld>(Chem.)</fld> <def>A colorless,
crystalline substance, <chform>C10H8O4</chform>, from
furfurol.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>furor</ent><br/
<hw>furor</hw> <pos>n.</pos> <def>an interest followed with exaggerated
zeal; a fad.</def><br/
<syn><b>Syn. --</b> fad, craze, furore, cult, rage.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>a sudden outburst (as of protest).</def><br/
<syn><b>Syn. --</b> uproar, furore.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>furore</ent><br/
<hw>fu*ro"re</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[It.]</ety>
<def>Excitement; commotion; enthusiasm.</def> <altsp>[Also spelled
<asp>furor</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>furred</ent><br/
<hw>furred</hw> <pos>adj.</pos> <def>covered with a dense coat of fine
silky hairs.</def><br/
<syn><b>Syn. --</b> furry.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><-- p. 605 --></p>

<p><ent>Furrier</ent><br/
<hw>Fur"ri*er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>fourreur</ets>.]</ety> <def>A dealer in furs; one who makes or
sells fur goods.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Furriery</ent><br/
<hw>Fur"ri*er*y</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>Furs,
in general.</def> <rj><au>Tooke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The business of a furrier; trade in furs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Furring</ent><br/
<hw>Fur"ring</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<fld>(Carp.)</fld> <sd>(a)</sd> <def>The leveling of a surface, or the
preparing of an air space, by means of strips of board or of larger
pieces. See <er>Fur</er>, <pos>v. t.</pos>, 3.</def> <sd>(b)</sd>
<def>The strips thus laid on.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Shipbuilding)</fld> <def>Double planking of a
ship's side.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A deposit from water, as on the inside of a boiler;
also, the operation of cleaning away this deposit.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Furrow</ent><br/
<hw>Fur"row</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>forow</ets>,
<ets>forgh</ets>, <ets>furgh</ets>, AS. <ets>furh</ets>; akin to D.
<ets>voor</ets>, OHG. <ets>furuh</ets>, G. <ets>furche</ets>, Dan.
<ets>fure</ets>, Sw. <ets>f<?/ra</ets>, Icel. for drain, L.
<ets>porca</ets> ridge between two furrows.]</ety> <sn>1.</sn> <def>A
trench in the earth made by, or as by, a plow.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Any trench, channel, or groove, as in wood or metal;
a wrinkle on the face; <as>as, the furrows of age</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Farrow weed</b></col> <cd>a weed which grows on plowed
land.</cd> <au>Shak.</au> -- <col><b>To draw a straight
furrow</b></col>, <cd>to live correctly; not to deviate from the right
line of duty.</cd> <au>Lowell.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Furrow</ent><br/
<hw>Fur"row</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Furrowed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Furrowing</conjf>.]</vmorph> <ety>[From <er>Furrow</er>,
<pos>n.</pos>; cf. AS. <ets>fyrian</ets>.]</ety> <sn>1.</sn> <def>To cut
a furrow in; to make furrows in; to plow; <as>as, to furrow the ground
or sea</as>.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To mark with channels or with wrinkles.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou canst help time to <qex>furrow</qex> me with age.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Fair cheeks were <qex>furrowed</qex> with hot tears.</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Furrowy</ent><br/
<hw>Fur"row*y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Furrowed.</def>
<mark>[R.]</mark> <rj><au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Furry</ent><br/
<hw>Fur"ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From
<er>Fur</er>.]</ety> <sn>1.</sn> <def>Covered with fur; dressed in
fur.</def> <ldquo/<xex>Furry</xex> nations.<rdquo/
<rj><au>Thomson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Consisting of fur; <as>as, furry spoils</as>.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Resembling fur.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Further</ent><br/
<hw>Fur"ther</hw> <pr>(?)</pr>, <pos>adv.</pos> <ety>[A comparative of
forth; OE. <ets>further</ets>, <ets>forther</ets>, AS.
<ets>fur<?/or</ets>, <ets>far<?/ur</ets>; akin to G.
<ets>f<uum/rder</ets>. See <er>Forth</er>, <pos>adv.</pos>]</ety>
<def>To a greater distance; in addition; moreover. See
<er>Farther</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Carries us, I know not how much <qex>further</qex>, into familiar
company.</q> <rj><qau>M. Arnold.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>They sdvanced us far as Eleusis and Thria; but no
<qex>further</qex>.</q> <rj><qau>Jowett (Thucyd. ).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Further off</b></col>, <cd>not so near; apart by a
greater distance.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Further</ent><br/
<hw>Fur"ther</hw>, <pos>a. compar.</pos> <amorph>[<it>Positive
wanting</it>; <pos>superl.</pos> <adjf>Furthest</adjf>.]</amorph>
<sn>1.</sn> <def>More remote; at a greater distance; more in advance;
farther; <as>as, the <ex>further</ex> end of the field</as>. See
<er>Farther</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Beyond; additional; <as>as, a <ex>further</ex>
reason for this opinion; nothing <ex>further</ex> to
suggest.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The forms <xex>further</xex> and <xex>farther</xex> are
in general not differentiated by writers, but <xex>further</xex> is
preferred by many when application to quantity or degree is
implied.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Further</ent><br/
<hw>Fur"ther"</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Furthered</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Furthering</conjf>.]</vmorph> <ety>[OE. <ets>furthren</ets>,
<ets>forthren</ets>, AS. <ets>fyr<edh/ran</ets>,
<ets>fyr<edh/rian</ets>. See <er>Further</er>, <pos>adv.</pos>]</ety>
<def>To help forward; to promote; to advance; to forward; to help or
assist.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This binds thee, then, to <qex>further</qex> my design.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I should nothing <qex>further</qex> the weal public.</q>
<rj><qau>Robynsom (More's Utopia).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Furtherance</ent><br/
<hw>Fur"ther*ance</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
furthering or helping forward; promotion; advancement;
progress.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I know that I shall abide and continue with you all for your<br/
<qex>furthersnce</qex> and joy of faith.</q> <rj><qau>Phil. i.
25.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Built of <qex>furtherance</qex> and pursuing, Not of spent deeds,
but of doing.</q> <rj><qau>Emerson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Furtherer</ent><br/
<hw>Fur"ther*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who furthers.
or helps to advance; a promoter.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Furthermore</ent><br/
<hw>Fur"ther*more"</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>or conj.
Moreover; besides; in addition to what has been said.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Furthermost</ent><br/
<hw>Fur"ther*most"</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Most remote;
furthest.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Furthersome</ent><br/
<hw>Fur"ther*some</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Tending to
further, advance, or promote; helpful; advantageous.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>You will not find it <qex>furthersome</qex>.</q>
<rj><qau>Carlyle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Furthest</ent><br/
<hw>Fur"thest</hw> <pr>(?)</pr>, <pos>a.</pos> <def>superl. Most remote;
most in advance; farthest. See <er>Further</er>, <pos>a.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Furthest</ent><br/
<hw>Fur"thest</hw>, <pos>adv.</pos> <def>At the greatest distance;
farthest.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Furtive</ent><br/
<hw>Fur"tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>furtivus</ets>, fr. <ets>furtum</ets> theft, fr. <ets>fur</ets>
thief, akin to <ets>ferre</ets> to bear: cf. F. <ets>furtif</ets>. See
<er>Fertile</er>.]</ety> <def>Stolen; obtained or characterized by
stealth; sly; secret; stealthy; <as>as, a furtive look</as>.</def>
<rj><au>Prior.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A hasty and furtive ceremony.</q> <rj><qau>Hallam.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Furtively</ent><br/
<hw>Fur"tive*ly</hw>, <pos>adv.</pos> <def>Stealthily by theft.</def>
<rj><au>Lover.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Furuncle</ent><br/
<hw>Fu"run*cle</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>furunculus</ets> a petty thief, a boil, dim. of <ets>fur</ets>
thief: cf. F. <ets>furoncle</ets>.]</ety> <fld>(Med.)</fld> <def>A
superficial, inflammatory tumor, suppurating with a central core; a
boil.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Furuncular</ent><br/
<hw>Fu*run"cu*lar</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining
to a furuncle; marked by the presence of furuncles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fury</ent><br/
<hw>Fu"ry</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>fur</ets>.]</ety> <def>A thief.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Have an eye to your plate, for there be <qex>furies</qex>.</q>
<rj><qau>J. Fleteher.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fury</ent><br/
<hw>Fu"ry</hw>, <pos>n.</pos>; <plu><it>pl.</it> <plw>Furies</plw>
<pr>(#)</pr>.</plu> <ety>[L. <ets>furia</ets>, fr. <ets>furere</ets> to
rage: cf. F. <ets>furie</ets>. Cf. <er>Furor</er>.]</ety> <sn>1.</sn>
<def>Violent or extreme excitement; overmastering agitation or
enthusiasm.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Her wit began to be with a divine <qex>fury</qex> inspired.</q>
<rj><qau>Sir P. Sidney.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Violent anger; extreme wrath; rage; -- sometimes
applied to inanimate things, as the wind or storms; impetuosity;
violence.</def> <ldquo/<xex>Fury</xex> of the wind.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I do oppose my patience to his <qex>fury</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>pl. <fld>(Greek Myth.)</fld> The avenging deities,
Tisiphone, Alecto, and Meg<ae/ra; the Erinyes or Eumenides.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>Furies</qex>, they said, are attendants on justice, and
if the sun in heaven should transgress his path would punish him.</q>
<rj><qau>Emerson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>One of the Parc<ae/, or Fates, esp. Atropos.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Comes the blind <qex>Fury</qex> with the abhorred shears,<br/
And slits the thin-spun life.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A stormy, turbulent violent woman; a hag; a vixen; a
virago; a termagant.</def></p>

<p><syn><b>Syn.</b> -- Anger; indignation; resentment; wrath; ire; rage;
vehemence; violence; fierceness; turbulence; madness; frenzy. See
<er>Anger</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Furze</ent><br/
<hw>Furze</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>firs</ets>,
As. <ets>fyrs</ets>.]</ety> <fld>(Bot.)</fld> <def>A thorny evergreen
shrub (<spn>Ulex Europ<ae/us</spn>), with beautiful yellow flowers, very
common upon the plains and hills of Great Britain; -- called also
<altname>gorse</altname>, and <altname>whin</altname>. The dwarf furze
is <spn>Ulex nanus</spn>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Furzechat</ent><br/
<hw>Furze"chat"</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>The <er>whinchat</er>; -- called also
<altname>furzechuck</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Furzeling</ent><br/
<hw>Furze"ling</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>An English warbler (<spn>Melizophilus provincialis</spn>); --
called also <altname>furze wren</altname>, and <altname>Dartford
warbler</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Furzen</ent><br/
<hw>Furz"en</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Furzy; gorsy.</def>
<mark>[Obs.]</mark> <rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Furzy</ent><br/
<hw>Furz"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Abounding in, or
overgrown with, furze; characterized by furze.</def>
<rj><au>Gay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fusain</ent><br/
\'d8<hw>Fu"sain"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., the spindle
tree; also, charcoal made from it.]</ety> <fld>(Fine Arts)</fld>
<sd>(a)</sd> <def>Fine charcoal of willow wood, used as a drawing
implement.</def> <sd>(b)</sd> <def>A drawing made with it. See
<er>Charcoal</er>, <pos>n.</pos> 2, and <cref>Charcoal drawing</cref>,
under <er>Charcoal</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fusarole</ent><br/
<hw>Fu"sa*role</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>fusarolle</ets>, fr. It. <ets>fusaruolo</ets>, fr. <ets>fuso</ets>
spindle, shaft of a column. See <er>Fusee</er> a conical wheel.]</ety>
<fld>(Arch.)</fld> <def>A molding generally placed under the echinus or
quarter round of capitals in the Doric, Ionic, and Corinthian orders of
architecture.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fuscation</ent><br/
<hw>Fus*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>fuscare</ets>, <ets>fuscatum</ets>, to make dark, fr.
<ets>fuscus</ets> dark.]</ety> <def>A darkening; obscurity;
obfuscation.</def> <mark>[R.]</mark> <rj><au>Blount.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fuscin</ent><br/
<hw>Fus"cin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>fuscus</ets>
dark-colored, tawny.]</ety> <fld>(Physiol. Chem.)</fld> <def>A brown,
nitrogenous pigment contained in the retinal epithelium; a variety of
melanin.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fuscine</ent><br/
<hw>Fus"cine</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld> <def>A
dark-colored substance obtained from empyreumatic animal oil.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fuscous</ent><br/
<hw>Fus"cous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>fuscus</ets>.]</ety> <def>Brown or grayish black;
darkish.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Sad and <qex>fuscous</qex> colors, as black or brown, or deep
purple<br/
and the like.</q> <rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fuse</ent><br/
<hw>Fuse</hw> <pr>(f<umac/z)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Fused</conjf> <pr>(f<umac/zd)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Fusing</conjf>.]</vmorph> <ety>[L. <ets>fusus</ets>, p.
p. of <ets>fundere</ets> to pour, melt, cast. See <er>Foundo</er> to
cast, and cf. <ets>Futile</ets>.]</ety> <sn>1.</sn> <def>To liquefy by
heat; to render fluid; to dissolve; to melt.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To unite or blend, as if melted together.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Whose fancy <qex>fuses</qex> old and new.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fuse</ent><br/
<hw>Fuse</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To be reduced from a
solid to a fluid state by heat; to be melted; to melt.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To be blended, as if melted together.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fusing point</b></col>, <cd>the degree of temperature at
which a substance melts; the point of fusion; the melting
point.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fuse</ent><br/
<hw>Fuse</hw>, <pos>n.</pos> <ety>[For <ets>fusee</ets>,
<ets>fusil</ets>. See 2d <er>Fusil</er>.]</ety> <fld>(Gunnery, Mining,
etc.)</fld> <sn>1.</sn> <def>A tube or casing filled with combustible
matter, by means of which a charge of powder is ignited, as in blasting;
-- called also <altname>fuzee</altname>. See <er>Fuze</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fuse hole</b></col>, <cd>the hole in a shell prepared for
the reception of the fuse.</cd> <au>Farrow.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mil.)</fld> <def>a mechanism in a bomb, torpedo,
rocket, or artillery shell, usually having an easily detonated explosive
charge and activated by the shock of impact, which detonates the main
explosive charge. Some fuses may have timing mechanisms, delaying the
explosion for a short time, or up to several days after impact. Fuses
activated by other mechanisms more sophisticated than impact, such as
proximity or heat, are used in modern weapons such as antiaircraft or
antimissile missiles.</def><br/
[<source>PJC</source>]</p>

<p><ent>Fuze</ent><br/
<ent>Fuse</ent><br/
<mhw>{ <hw>Fuse</hw>, <it>or</it> <hw>Fuze</hw> }</mhw>, <pos>n.</pos>
<fld>(Elec.)</fld> <def>A wire, bar, or strip of fusible metal inserted
for safety in an electric circuit. When the current increases beyond a
certain safe strength, the metal melts, interrupting the circuit and
thereby preventing possibility of damage. It serves the same function as
a <contr>circuit breaker</contr>.</def><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><ent>fused</ent><br/
<hw>fused</hw> <pos>adj.</pos> <def>joined together into a
whole.</def><br/
<syn><b>Syn. --</b> amalgamate, amalgamated, coalesced,
consolidated.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fusee</ent><br/
<hw>Fu*see"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See 2d
<er>Fusil</er>, and cf. <er>Fuse</er>, <pos>n.</pos>]</ety> <sn>1.</sn>
<def>A flintlock gun. See 2d <er>Fusil</er>.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A fuse. See <er>Fuse</er>, <pos>n.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <sd>(a)</sd> <def>A friction match for smokers' use
having a bulbous head which when ignited is not easily blown out even in
a gale of wind.</def> <sd>(b)</sd> <def>A kind of match made of paper
impregnated with niter and having the usual igniting tip.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>4.</sn> <def>A signal device, usually cylindrical, consisting of
a tube filled with a composition which burns with a bright colored light
for a definite time. It is used principally for the protection of trains
or road vehicles, indicating an obstruction or accident ahead. Also
called a <altname>flare</altname> or <altname>railroad
flare</altname>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Fusee</ent><br/
<hw>Fu*see"</hw>, <pos>n.</pos> <ety>[Etymol. uncertain.]</ety> <def>The
track of a buck.</def> <rj><au>Ainsworth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fusee</ent><br/
<hw>Fu*see"</hw>, <pos>n.</pos> <ety>[F. <ets>fus<eacute/e</ets> a
spindleful, fusee, LL. <ets>fusata</ets>, fr. <ets>fusare</ets> to use a
spindle, L. <ets>fusus</ets> spindle.]</ety> <sd>(a)</sd> <def>The cone
or conical wheel of a watch or clock, designed to equalize the power of
the mainspring by having the chain from the barrel which contains the
spring wind in a spiral groove on the surface of the cone in such a
manner that the diameter of the cone at the point where the chain acts
may correspond with the degree of tension of the spring.</def>
<sd>(b)</sd> <def>A similar wheel used in other machinery.</def></p>

<p><ent>Fusel oil</ent><br/
<ent>Fusel</ent><br/
<mhw><hw>Fu"sel</hw> <pr>(?)</pr>, <pos>n.</pos>, <hw>Fu"sel
oil</hw></mhw>. <ety>[G. <ets>fusel</ets> bad liquor.]</ety>
<fld>(Chem.)</fld> <def>A hot, acrid, oily liquid, accompanying many
alcoholic liquors (as potato whisky, corn whisky, etc.), as an
undesirable ingredient, and consisting of several of the higher alcohols
and compound ethers, but mostly of amyl alcohol;</def>
<specif>hence,</specif> <def>amyl alcohol or a mixture of amyl
alcohols.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>fuselage</ent><br/
<hw>fu"se*lage</hw> <pos>n.</pos> <ety>[F. <ets>fusel</ets>
spindle-shaped + <ets>-age</ets>; fr. L. <ets>fusus</ets>
spindle.]</ety> <fld>(A<eum/ronautics)</fld> <def>The central,
approximately cylindrical portion of an airplane which carries the
passengers, crew, and cargo. It usually forms the main structural
portion of an airplane, and to it are typically attached the wings,
tail, and sometimes the engines. In single-propeller airplanes, the
propeller is typically fixed at the front of the <ex>fuselage</ex>,
although variants have been produced with the propeller at the rear.
Some airplanes have no fuselage, properly so called.</def><br/
<syn><b>Syn. --</b> body.</syn><br/
[<source>PJC</source>]</p>

<p><ent>Fuze plug</ent><br/
<ent>Fuse plug</ent><br/
<mhw>{ <hw>Fuse plug</hw>, <it>or</it> <hw>Fuze plug</hw> }</mhw>.
<sn>1.</sn> <fld>(Ordnance)</fld> <def>A plug fitted to the fuse hole of
a shell to hold the fuse.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>A fusible plug that screws into a receptacle, used
as a fuse in electric wiring.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Fusibility</ent><br/
<hw>Fu"si*bil"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>fusibilit<eacute/</ets>.]</ety> <def>The quality of being
fusible.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fusible</ent><br/
<hw>Fu"si*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F.
<ets>fusible</ets>. See <er>Fuse</er>, <pos>v. t.</pos>]</ety>
<def>Capable of being melted or liquefied.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fusible metal</b></col>, <cd>any alloy of different
metals capable of being easily fused, especially an alloy of five parts
of bismuth, three of lead, and two of tin, which melts at a temperature
below that of boiling water.</cd> <au>Ure.</au> -- <col><b>Fusible
plug</b></col> <fld>(Steam Boiler)</fld>, <cd>a piece of easily fusible
alloy, placed in one of the sheets and intended to melt and blow off the
steam in case of low water.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fusiform</ent><br/
<hw>Fu"si*form</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>fusus</ets> spindle + <ets>-form</ets>: cf. F.
<ets>fusiforme</ets>.]</ety> <def>Shaped like a spindle; shaped like a
cylinder that tapers at each end; <as>as, a <ex>fusiform</ex> root; a
<ex>fusiform</ex> cell.</as></def><br/
<syn><b>Syn. --</b> cigar-shaped.</syn>
[<source>1913 Webster</source>]</p>

<p><ent>Fusil</ent><br/
<hw>Fu"sil</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>fusilis</ets>
molten, fluid, fr. <ets>fundere</ets>, <ets>fusum</ets>, to pour, cast.
See <er>Fuse</er>, <pos>v. t.</pos>]</ety> <sn>1.</sn> <def>Capable of
being melted or rendered fluid by heat; fusible.</def> <mark>[R.]</mark>
<ldquo/A kind of <xex>fusil</xex> marble<rdquo/
<rj><au>Woodward.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Running or flowing, as a liquid.</def>
<mark>[R.]</mark> <ldquo/A <xex>fusil</xex> sea.<rdquo/ <rj><au>J.
Philips.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Formed by melting and pouring into a mold; cast;
founded.</def> <mark>[Obs.]</mark> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fusil</ent><br/
<hw>Fu"sil</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>fusil</ets>,
LL. <ets>fosile</ets> a steel for kindling fire, from L.
<ets>focus</ets> hearth, fireplace, in LL. fire. See <er>Focus</er>, and
cf. <er>Fusee</er> a firelock.]</ety> <def>A light kind of flintlock
musket, formerly in use.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fusil</ent><br/
<hw>Fu"sil</hw>, <pos>n.</pos> <ety>[See 3d <er>Fusee</er>.]</ety>
<fld>(Her.)</fld> <def>A bearing of a rhomboidal figure; -- named from
its shape, which resembles that of a spindle.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ It differs from a lozenge in being longer in proportion
to its width.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fusile</ent><br/
<hw>Fu"sile</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Same as
<er>Fusil</er>, <pos>a.</pos></def></p>

<p><ent>Fusilier</ent><br/
<ent>Fusileer</ent><br/
<mhw>{ <hw>Fu"sil*eer"</hw>, <hw>Fu"sil*ier"</hw> }</mhw> <pr>(?)</pr>,
<pos>n.</pos> <ety>[F. <ets>fusilier</ets>, fr. <ets>fusil</ets>.]</ety>
<fld>(Mil.)</fld> <sd>(a)</sd> <def>Formerly, a soldier armed with a
fusil. Hence, in the plural:</def> <sd>(b)</sd> <def>A title now borne
by some regiments and companies; <as>as, <ldquo/The Royal
<ex>Fusiliers</ex>,<rdquo/ etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fusillade</ent><br/
<hw>Fu"sil*lade"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>fusillade</ets>, cf. It. <ets>fucilata</ets>. See <er>Fusil</er> a
firelock.]</ety> <fld>(Mil.)</fld> <def>A simultaneous discharge of
firearms.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fusillade</ent><br/
<hw>Fu"sil*lade"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Fusillader</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Fusillading</conjf>.]</vmorph> <def>To shoot down of shoot at by
a simultaneous discharge of firearms.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fusion</ent><br/
<hw>Fu"sion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>fusio</ets>,
fr. <ets>fundere</ets>, <ets>fusum</ets> to pour, melt: cf. F.
<ets>fusion</ets>. See <er>Fuse</er>, <pos>v. t.</pos>, aud cf,
<er>Foison</er>.]</ety> <sn>1.</sn> <def>The act or operation of melting
or rendering fluid by heat; the act of melting together; <as>as, the
fusion of metals</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The state of being melted or dissolved by heat; a
state of fluidity or flowing in consequence of heat; <as>as, metals in
fusion</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The union or blending together of things, <as>as,
melted together</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The universal <qex>fusion</qex> of races, languages, and customs .
. . <br/
had produced a corresponding <qex>fusion</qex> of creeds.</q>
<rj><qau>C. Kingsley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Watery fusion</b></col> <fld>(Chem.)</fld> <cd>the
melting of certain crystals by heat in their own water of
crystallization.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Biol.)</fld> <def>The union, or binding together,
of adjacent parts or tissues.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fusome</ent><br/
<hw>Fu"some</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[AS.
<ets>f<?/san</ets> to hasten, fr. <ets>f<?/s</ets> ready, prompt, quick;
akin to OS. <ets>f<?/s</ets>, OHG. <ets>funs</ets>, Icel.
<ets>fuss</ets> willing; prob. from the root of E.
<ets>find</ets>.]</ety> <def>Handy; reat; handsome; notable.</def>
<mark>[Prov. Eng.]</mark> <rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fuss</ent><br/
<hw>Fuss</hw> <pr>(f<ucr/s)</pr>, <pos>n.</pos> <ety>[Cf.
<er>Fusome</er>.]</ety> <sn>1.</sn> <def>A tumult; a bustle; unnecessary
or annoying ado about trifles.</def> <rj><au>Byron.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Zealously, assiduously, and with a minimum of <qex>fuss</qex> or
noise</q> <rj><qau>Carlyle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who is unduly anxious about trifles; a
fussbudget.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I am a <qex>fuss</qex> and I don't deny it.</q> <rj><qau>W. D.
Howell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fuss</ent><br/
<hw>Fuss</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Fussed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Fussing</conjf>.]</vmorph> <def>To be overbusy or unduly anxious
about trifles; to make a bustle or ado.</def> <rj><au>Sir W.
Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>fussbudget</ent><br/
<hw>fuss"budg*et</hw> <pos>n.</pos> <def>a person who thinks excessively
about unfortunate things that might happen; one who is excessively
concerned about matters of trifling importance.</def><br/
<syn><b>Syn. --</b> worrier, fusspot, worrywart.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>fussbudgety</ent><br/
<hw>fussbudgety</hw> <pos>adj.</pos> <def>Like a fussbudget; fussy;
grouchy.</def><br/
[<source>PJC</source>]</p>

<p><ent>fusspot</ent><br/
<hw>fusspot</hw> <pos>n.</pos> <def>same as
<er>fussbudget</er>.</def><br/
<syn><b>Syn. --</b> worrier, fussbudget, worrywart.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fussily</ent><br/
<hw>Fuss"i*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a fussy
manner.</def> <rj><au>Byron.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fussiness</ent><br/
<hw>Fuss"i*ness</hw>, <pos>n.</pos> <def>The quality of being
fussy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fussy</ent><br/
<hw>Fuss"y</hw> <pr>(?)</pr>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Fussier</adjf> <pr>(?)</pr>; <pos>superl.</pos>
<adjf>Fussiest</adjf>.]</amorph> <def>Making a fuss; disposed to make an
unnecessary ado about trifles; overnice; fidgety.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Not at all <qex>fussy</qex> about his personal appearance.</q>
<rj><qau>R. G. White.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fust</ent><br/
<hw>Fust</hw> <pr>(f<ucr/st)</pr>, <pos>n.</pos> <ety>[OF.
<ets>fust</ets>, F. <ets>f<ucir/t</ets>, fr. L. <ets>fustis</ets> stick
staff.]</ety> <fld>(Arch.)</fld> <def>The shaft of a column, or trunk of
a pilaster.</def> <rj><au>Gwilt.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fust</ent><br/
<hw>Fust</hw>, <pos>n.</pos> <ety>[OF. <ets>fust</ets> cask, F.
<ets>f<ucir/t</ets> cask, taste or smell of the cask,
<ets>fustiness</ets>, cf. sentir le <ets>f<ucir/t</ets> to taste of the
cask. See 1st <er>Fust</er>.]</ety> <def>A strong, musty smell;
mustiness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fust</ent><br/
<hw>Fust</hw>, <pos>v. i.</pos> <def>To become moldy; to smell
ill.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fusted</ent><br/
<hw>Fust"ed</hw>, <pos>a.</pos> <def>Moldy; ill-smelling.</def>
<mark>[Obs.]</mark> <rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fusteric</ent><br/
<hw>Fus"ter*ic</hw> <pr>(f<ucr/s"t<etil/r*<icr/k)</pr>, <pos>n.</pos>
<def>The coloring matter of fustet.</def> <rj><au>Ure.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fustet</ent><br/
<hw>Fus"tet</hw> <pr>(f<ucr/s"t<ecr/t)</pr>, <pos>n.</pos> <ety>[F.
<ets>fustet</ets> (cf. Sp. & Pg. <ets>fustete</ets>), LL.
<ets>fustetus</ets>, fr. L. <ets>fustis</ets> stick, in LL., tree, See
<er>1st Fust</er>, and cf. <er>Fustic</er>.]</ety> <def>The wood of the
<spn>Rhus Cotinus</spn> or <prodby>Venice sumach</prodby>, a shrub of
Southern Europe, which yields a fine orange color, which, however, is
not durable without a mordant.</def> <rj><au>Ure.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fustian</ent><br/
<hw>Fus"tian</hw> <pr>(f<ucr/s"ch<ait/n; 106)</pr>, <pos>n.</pos>
<ety>[OE. <ets>fustan</ets>, <ets>fustian</ets>, OF.
<ets>fustaine</ets>, F. <ets>futaine</ets>, It. <ets>fustagno</ets>, fr.
LL. <ets>fustaneum</ets>, <ets>fustanum</ets>; cf. Pr.
<ets>fustani</ets>, Sp. <ets>fustan</ets>. So called from
<ets>Fust<amac/t</ets>, i. e., Cairo, where it was made.]</ety>
<sn>1.</sn> <def>A kind of coarse twilled cotton or cotton and linen
stuff, including corduroy, velveteen, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An inflated style of writing; a kind of writing in
which high-sounding words are used, above the dignity of the thoughts or
subject; bombast.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Claudius . . . has run his description into the most wretched
<qex>fustian</qex>.</q> <rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fustian</ent><br/
<hw>Fus"tian</hw>, <pos>a.</pos> <sn>1.</sn> <def>Made of
fustian.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Pompous; ridiculously tumid; inflated; bombastic;
<as>as, <ex>fustian</ex> history</as>.</def>
<rj><au>Walpole.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fustianist</ent><br/
<hw>Fus"tian*ist</hw>, <pos>n.</pos> <def>A writer of fustian.</def>
<mark>[R.]</mark> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fustic</ent><br/
<hw>Fus"tic</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>fustoc</ets>,
Sp. <ets>fustoc</ets>. Cf. <er>Fustet</er>.]</ety> <def>The wood of the
<spn>Maclura tinctoria</spn>, a tree growing in the West Indies, used in
dyeing yellow; -- called also <altname>old fustic</altname>.</def>
<altsp>[Written also <asp>fustoc</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Other kinds of yellow wood are often called
<xex>fustic</xex>; as that of species of <gen>Xanthoxylum</gen>, and
especially the <spn>Rhus Cotinus</spn>, which is sometimes called
<xex>young</xex> fustic to distinguish it from the <gen>Maclura</gen>.
See <er>Fustet</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fustigate</ent><br/
<hw>Fus"ti*gate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>fustigare</ets>, fr. <ets>fustis</ets> stick. See <er>1st
Fust</er>.]</ety> <def>To cudgel.</def> <mark>[R.]</mark>
<rj><au>Bailey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fustigation</ent><br/
<hw>Fus"ti*ga"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>fustigation</ets>.]</ety> <def>A punishment by beating with a stick
or club; cudgeling.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This satire, composed of actual <qex>fustigation</qex>.</q>
<rj><qau>Motley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fustilarian</ent><br/
<hw>Fus"ti*la"ri*an</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<er>Fusty</er>.]</ety> <def>A low fellow; a stinkard; a scoundrel.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj></p>

<p><ent>Fustilugs</ent><br/
<ent>Fustilug</ent><br/
<mhw>{ <hw>Fus"ti*lug`</hw> <pr>(<?/)</pr>, <hw>Fus"ti*lugs`</hw>
<pr>(?)</pr> }</mhw>, <pos>n.</pos> <ety>[<ets>Fusty</ets> +
<ets>lug</ets> something heavy, to be drawn or carried.]</ety> <def>A
gross, fat, unwieldy person.</def> <mark>[Obs.]</mark> <rj><au>F.
Junius.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fustiness</ent><br/
<hw>Fust"i*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A fusty state or
quality; moldiness; mustiness; an ill smell from moldiness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fusty</ent><br/
<hw>Fusty</hw> <pr>(?)</pr>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Fustier</adjf> <pr>(#)</pr>; <pos>superl.</pos>
<adjf>Fustiest</adjf>.]</amorph> <ety>[See <er>2d Fust</er>.]</ety>
<sn>1.</sn> <def>Moldy; musty; ill-smelling; rank.</def> <ldquo/A
<xex>fusty</xex> nut.<rdquo/ <ldquo/<xex>Fusty</xex> plebeians.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Moping.</def> <mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>A melancholy, <qex>fusty</qex> humor.</q>
<rj><qau>Pepys.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fusure</ent><br/
<hw>Fu"sure</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>fusura</ets>,
fr. <ets>fundere</ets>, <ets>fusum</ets>. See <er>Fuse</er>, <pos>v.
t.</pos>]</ety> <def>Act of fusing; fusion.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 606 --></p>

<p><ent>Futchel</ent><br/
<hw>Futch"el</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The jaws between
which the hinder end of a carriage tongue is inserted.</def>
<rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>futharc</ent><br/
<ent>futhorc</ent><br/
<ent>futhork</ent><br/
<mhw><hw>fu"tharc</hw>, <hw>fu"thorc</hw>, <hw>fu"thork</hw></mhw>
<pos>n.</pos> <sn>1.</sn> <ety>[From the sounds of the first five
letters.]</ety> <def>The Runic alphabet; -- so called from the first six
letters <it>f</it>, <it>u</it>, <it><thorn/</it> (<it>th</it>),
<it>o</it> (or <it>a</it>), <it>r</it>, <it>c</it> (<it>=k</it>). See
<er>rune</er>.</def> <altsp>[Also spelled
<asp>futhark</asp>]</altsp><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><note><hand/ The spelling <xex>futharc</xex> represents most
accurately the original values of these six Runic letters.</note><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><note><hand/The name is derived from the sounds of the first five
letters of the runic alphabet, f, u, th, o, r, and c. The vowel sound of
the fourth letter corresponded more closely to <it>a</it> in the earlier
versions used in Scandinavian countries, and the earlier alphabet is
therefore referred to as the <ex>futharc</ex> or <ex>futhark</ex>. The
fifth rune had a sound like that of <it>k</it>, and in the Danish
<ex>futhark</ex> the fifth character is that transliterated as
<it>k</it>. Thus the runic alphabet is also called the <ex>futhork</ex>
or <ex>futhark</ex>. The third rune had a sound and form resembling that
of the Anglo-Saxon <it>thorn</it>, which represented the <it>th</it>
sound at the beginning of the word <it>thorn</it>. The origins of the
runic alphabet are obscure, but the earliest forms may have been
invented around the second century A.D. in eastern Europe. The forms of
some of the letters show a relation to the Latin or Greek alphabets, and
the futhorc was presumably in part an adaptation of those alphabets to
the sound of the Germanic tongues. An inscription of the
<ex>futhark</ex> itself, an ordered list of the runes, was found on an
object dated as early as the fifth century A.D. The Scandinavian
<ex>futharc</ex> had 16 runes, but the <ex>futhorc</ex> used in
Anglo-Saxon England had 31. The <ex>futhark</ex> was mostly used for
writing on wood, for which reason the runes were comprised of only
vertical and diagonal strokes. The degree of widespread use of the
futharc is not known but it was probably used mostly for short messages
or inscriptions on objects. Fewer than 10,000 runic inscriptions, both
on wood and stone, have been found. The number and forms of some of the
runes varied over time and locality.</note> <au>R. I. Page,
<ldquo/Runes<rdquo/.</au><br/
[<source>PJC</source>]</p>

<p><q>The letters are called Runes and the alphabet bears the name
<qex>Futhorc</qex> from the first six letters.</q> <rj><qau>I.
Taylor.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Futile</ent><br/
<hw>Fu"tile</hw> <pr>(?; 277)</pr>, <pos>a.</pos> <ety>[L.
<ets>futilis</ets> that easily pours out, that easily lets loose, vain,
worthless, from the root of <ets>fundere</ets> to pour out: cf. F.
<ets>futile</ets>. See <er>Fuse</er>, <pos>v. t.</pos>]</ety>
<sn>1.</sn> <def>Talkative; loquacious; tattling.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Talkers and <qex>futile</qex> persons.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of no importance; having no useful purpose; useless;
vain; worthless; pointless.</def> <ldquo/<xex>Futile</xex>
theories.<rdquo/ <rj><au>I. Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>His reasoning . . . was singularly <qex>futile</qex>.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Futilely</ent><br/
<hw>Fu"tile*ly</hw>, <pos>adv.</pos> <def>In a futile manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Futility</ent><br/
<hw>Fu"til`i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>futilitas</ets>: cf. F. <ets>futilit<eacute/</ets>.]</ety>
<sn>1.</sn> <def>The quality of being talkative; talkativeness;
loquaciousness; loquacity.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The quality of producing no valuable effect, or of
coming to nothing; uselessness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>futility</qex> of this mode of philosophizing.</q>
<rj><qau>Whewell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Futilous</ent><br/
<hw>Fu"til*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Futile;
trifling.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Futtock</ent><br/
<hw>Fu"ttock</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Prob. corrupted fr.
<ets>foothook</ets>.]</ety> <fld>(Naut.)</fld> <def>One of the crooked
timbers which are scarfed together to form the lower part of the
compound rib of a vessel; one of the crooked transverse timbers passing
across and over the keel.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Futtock plates</b></col> <fld>(Naut.)</fld>, <cd>plates
of iron to which the dead-eyes of the topmast rigging are secured.</cd>
-- <col><b>Futtock shrouds</b></col>, <cd>short iron shrouds leading
from the upper part of the lower mast or of the main shrouds to the edge
of the top, or through it, and connecting the topmast rigging with the
lower mast.</cd> <rj><au>Totten.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Futurable</ent><br/
<hw>Fu"tur*a*ble</hw> <pr>(?; 135)</pr>, <pos>a.</pos> <def>Capable of
being future; possible to occur.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Not only to things future, but <qex>futurable</qex>.</q>
<rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Future</ent><br/
<hw>Fu"ture</hw> <pr>(?; 135)</pr>, <pos>a.</pos> <ety>[F.
<ets>futur</ets>, L. <ets>futurus</ets>, used as fut. p. of
<ets>esse</ets> to be, but from the same root as E. <ets>be</ets>. See
<er>Be</er>, <pos>v. i.</pos>]</ety> <def>That is to be or come
hereafter; that will exist at any time after the present; <as>as, the
next moment is <ex>future</ex>, to the present</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Future tense</b></col> <fld>(Gram.)</fld>, <cd>the tense
or modification of a verb which expresses a future act or
event.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Future</ent><br/
<hw>Fu"ture</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>futur</ets>. See <er>Future</er>, <pos>a.</pos>]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Time to come; time subsequent to the present (as,
the <xex>future</xex> shall be as the present); collectively, events
that are to happen in time to come.</def> <ldquo/Lay the
<xex>future</xex> open.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The possibilities of the future; -- used especially
of prospective success or advancement; <as>as, he had great
<ex>future</ex> before him</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Gram.)</fld> <def>A future tense.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To deal in futures</b></col>, <cd>to speculate on the
future values of merchandise or stocks.</cd> <mark>[Brokers'
cant]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Futureless</ent><br/
<hw>Fu"ture*less</hw>, <pos>a.</pos> <def>Without prospect of betterment
in the future.</def> <rj><au>W. D. Howells.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Futurely</ent><br/
<hw>Fu"ture*ly</hw>, <pos>adv.</pos> <def>In time to come.</def>
<mark>[Obs.]</mark> <rj><au>Raleigh.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Futurism</ent><br/
<hw>Fu"tur*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Painting)</fld>
<sn>1.</sn> <def>A movement or phase of post-impressionism (which see,
below).</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>A point of view that finds meaning or fulfillment in
the future rather than in the past or present. The philosophy of a
<er>futurist</er>.</def> <au>MW10</au><br/
[<source>PJC</source>]</p>

<p><ent>Futurist</ent><br/
<hw>Fu"tur*ist</hw>, <pos>n.</pos> <sn>1.</sn> <def>One whose chief
interests are in what is to come; one who anxiously, eagerly, or
confidently looks forward to the future; an expectant.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Theol.)</fld> <def>One who believes or maintains
that the fulfillment of the prophecies of the Bible is to be in the
future.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Futuritial</ent><br/
<hw>Fu`tu*ri"tial</hw> <pr>(?; 135)</pr>, <pos>a.</pos> <def>Relating to
what is to come; pertaining to futurity; future.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Futurition</ent><br/
<hw>Fu`tu*ri"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>futurition</ets>.]</ety> <def>The state of being future;
futurity.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Nothing . . . can have this imagined <qex>futurition</qex>, but as
it is decreed.</q> <rj><qau>Coleridge.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Futurity</ent><br/
<hw>Fu*tu"ri*ty</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Futurities</plw> <pr>(<?/)</pr>.</plu><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>State of being that is yet to come; future
state.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Future time; time to come; the future.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Event to come; a future event.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>All <qex>futurities</qex> are naked before the All-seeing Eye.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>futurology</ent><br/
<hw>fu`tur*ol"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Studies
projecting or predicting the future based on current trends.</def> --
<wordforms><wf>fu`tur*o*log"i*cal</wf>, <pos>a.</pos> --
<wf>fu`tur*ol"o*gist</wf>, <pos>n.</pos></wordforms><br/
[<source>PJC</source>]</p>

<p><ent>futz</ent><br/
<hw>futz</hw> <pos>v. i.</pos> <def>To fool around; to act without plan
or purpose; -- usually used with <ptcl>around</ptcl>; <as>as, don't
<ex>futz around</ex> with a device without understanding its
operation</as>.</def> <mark>[Slang.]</mark><br/
[<source>PJC</source>]</p>

<p><ent>Fuze</ent><br/
<hw>Fuze</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A tube, filled with
combustible matter, for exploding a shell, etc. See <er>Fuse</er>,
<pos>n.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Chemical fuze</b></col>, <cd>a fuze in which substances
separated until required for action are then brought into contact, and
uniting chemically, produce explosion.</cd> -- <col><b>Concussion
fuze</b></col>, <cd>a fuze ignited by the striking of the
projectile.</cd> -- <col><b>Electric fuze</b></col>, <cd>a fuze which is
ignited by heat or a spark produced by an electric current.</cd> --
<col><b>Friction fuze</b></col>, <cd>a fuze which is ignited by the heat
evolved by friction. See <er>fuzee</er>{1}.</cd> -- <col><b>Percussion
fuze</b></col>, <cd>a fuze in which the ignition is produced by a blow
on some fulminating compound.</cd> -- <col><b>Time fuze</b></col>, <cd>a
fuze adapted, either by its length or by the character of its
composition, to burn a certain time before producing an
explosion.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>fuzee</ent><br/
<hw>fuzee</hw> <pos>n.</pos> <sn>1.</sn> <def>a friction match with a
large head that will stay alight in the wind.</def><br/
<syn><b>Syn. --</b> fusee.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>any device by which an explosive charge is
ignited.</def><br/
<syn><b>Syn. --</b> fuse, fuze, fusee, primer.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Fuzz</ent><br/
<hw>Fuzz</hw> <pr>(f<ucr/z)</pr>, <pos>v. t.</pos> <def>To make
drunk.</def> <mark>[Obs.]</mark> <rj><au>Wood.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fuzz</ent><br/
<hw>Fuzz</hw>, <pos>n.</pos> <ety>[Cf. Prov. E. <ets>fuzzy</ets> that
ravels (of silk or cotton), D. <ets>voos</ets> spongy, fungous, G.
<ets>faser</ets> filament. E. <ets>feaze</ets> to untwist.]</ety>
<def>Fine, light particles or fibers; loose, volatile matter.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Fuzz ball</b></col>, <cd>a kind of fungus or mushroom,
which, when pressed, bursts and scatters a fine dust; a
puffball.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fuzz</ent><br/
<hw>Fuzz</hw>, <pos>v. i.</pos> <def>To fly off in minute
particles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fuzzle</ent><br/
<hw>Fuz"zle</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Cf. LG.
<ets>fuseln</ets> to drink common liquor, fr. <ets>fusel</ets> bad
liquor.]</ety> <def>To make drunk; to intoxicate; to fuddle.</def>
<mark>[Obs.]</mark> <rj><au>Burton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fuzzy</ent><br/
<hw>Fuzz"y</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See <er>Fuzz</er>,
<pos>n.</pos>]</ety> <sn>1.</sn> <def>Not firmly woven; that
ravels.</def> <altsp>[Written also <asp>fozy</asp>.]</altsp>
<mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Furnished with fuzz; having fuzz; like fuzz; <as>as,
the <ex>fuzzy</ex> skin of a peach</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>-fy</ent><br/
<hw>-fy</hw> <pr>(?)</pr>. <ety>[Through French verbs in
<ets>-fier</ets>, L. <ets>-ficare</ets>, akin to <ets>facere</ets> to
do, make. See <er>Fact</er>.]</ety> <def>A suffix signifying <xex>to
make</xex>, <xex>to form into</xex>, etc.; <as>as, aceti<ex>fy</ex>,
ampli<ex>fy</ex>, dandi<ex>fy</ex>, Frenchi<ex>fy</ex>,
etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fy</ent><br/
<hw>Fy</hw> <pr>(?)</pr>, <pos>interj.</pos> <ety>[See <er>Fie</er>,
<ets>interj</ets>.]</ety> <def>A word which expresses blame, dislike,
disapprobation, abhorrence, or contempt. See <er>Fie</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fyke</ent><br/
<hw>Fyke</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[D. <ets>fuik</ets> a bow
net.]</ety> <def>A long bag net distended by hoops, into which fish can
pass easily, without being able to return; -- called also <altname>fyke
net</altname>.</def> <rj><au>Cozzens.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Fyllot</ent><br/
<hw>Fyl"lot</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Prov. fr. AS.
<ets>fy<?/erf<?/te</ets>, <ets>fierf<?/te</ets>,
<ets>fe<oacute/werf<?/te</ets>. See <er>Four</er>, and <er>Foot</er>,
n.]</ety> <def>A rebated cross, formerly used as a secret emblem, and a
common ornament. It is also called <altname>gammadion</altname>, and
<altname>swastika</altname>.</def> <-- Illustr. of two types of fyllot.
--></p>

<p><ent>Fyrdung</ent><br/
<ent>Fyrd</ent><br/
<mhw><hw>Fyrd</hw> <pr>(?)</pr>, <hw>Fyr"dung</hw> <pr>(<?/)</pr></mhw>,
<pos>n.</pos> <ety>[AS.; akin to E. <ets>fare</ets>, <pos>v.
i.</pos>]</ety> <fld>(Old. Eng. Hist.)</fld> <def>The military force of
the whole nation, consisting of all men able to bear arms.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The national <qex>fyrd</qex> or militia.</q> <rj><qau>J. R.
Green.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>fytte</ent><br/
<hw>Fytte</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See <er>Fit</er> a
song.</def> <mark>[Archaic]</mark></p>


<-- Local variables: -->
<-- mode: sgml -->
<-- fill-column: 72 -->
<-- End: -->
