<-- This file is part 4 of the GNU version of
    The Collaborative International Dictionary of English (GCIDE)

    Copyright (C) 1992-2012 Patrick J. Cassidy
    Copyright (C) 2012-2024 Sergey Poznyakoff

    GCIDE is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 3, or (at your option)
    any later version.

    GCIDE is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this copy of GCIDE.  If not, see <http://www.gnu.org/licenses/>.
-->

<p><-- p. 364 --></p>

<p><centered><point26>D.</point26></centered></p>

<p><ent>D</ent><br/
<hw>D</hw> <pr>(d<emac/)</pr> <sn>1.</sn> <def>The fourth letter of the
English alphabet, and a vocal consonant. The English letter is from
Latin, which is from Greek, which took it from Ph<oe/nician, the
probable ultimate origin being Egyptian. It is related most nearly to
<xex>t</xex> and <xex>th</xex>; <as>as, Eng. <xex>d</xex>eep, G.
<xex>t</xex>ief; Eng. <xex>d</xex>aughter, G. <xex>t</xex>ochter, Gr.
<grk>qyga`thr</grk>, Skr. <xex>d</xex>uhitr</as>. See <xex>Guide to
Pronunciation</xex>, <root/178, 179, 229.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mus.)</fld> <def>The nominal of the second tone in
the model major scale (that in C), or of the fourth tone in the relative
minor scale of C (that in A minor), or of the key tone in the relative
minor of F.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>As a numeral D stands for 500. in this use it is not
the initial of any word, or even strictly a letter, but one half of the
sign <?/ (or <?/ ) the original Tuscan numeral for 1000.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dab</ent><br/
<hw>Dab</hw> <pr>(d<acr/b)</pr>, <pos>n.</pos> <ety>[Perh. corrupted fr.
<ets>adept</ets>.]</ety> <def>A skillful hand; a dabster; an
expert.</def> <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>One excels at a plan or the titlepage, another works away at the
body of the book, and the third is a <qex>dab</qex> at an index.</q>
<rj><qau>Goldsmith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dab</ent><br/
<ent>Dab</ent><br/
<hw>Dab</hw>, <pos>n.</pos> <ety>[Perh. so named from its quickness in
diving beneath the sand. Cf. <er>Dabchick</er>.]</ety>
<fld>(Zool.)</fld> <def>A name given to several species of flounders,
esp. to the European species, <spn>Pleuronectes limanda</spn>. The
American rough dab is <spn>Hippoglossoides platessoides</spn>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dab</ent><br/
<hw>Dab</hw> <pr>(d<acr/b)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Dabbed</conjf> <pr>(d<acr/bd)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Dabbing</conjf>.]</vmorph> <ety>[OE. <ets>dabben</ets>
to strice; akin to OD. <ets>dabben</ets> to pinch, knead, fumble,
dabble, and perh. to G. <ets>tappen</ets> to grope.]</ety> <sn>1.</sn>
<def>To strike or touch gently, as with a soft or moist substance; to
tap; hence, to besmear with a dabber.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A sore should . . . be wiped . . . only by <qex>dabbing</qex> it
over with fine lint.</q> <rj><qau>S. Sharp.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To strike by a thrust; to hit with a sudden blow or
thrust.</def> <ldquo/To <xex>dab</xex> him in the neck.<rdquo/
<rj><au>Sir T. More.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dab</ent><br/
<hw>Dab</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A gentle blow
with the hand or some soft substance; a sudden blow or hit; a
peck.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A scratch of her claw, a <qex>dab</qex> of her beak.</q>
<rj><qau>Hawthorne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A small mass of anything soft or moist.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dabb</ent><br/
<hw>Dabb</hw> <pr>(d<adot/b)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>A large, spine-tailed lizard (<spn>Uromastix spinipes</spn>), found
in Egypt, Arabia, and Palestine; -- called also
<altname>dhobb</altname>, and <altname>dhubb</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dabber</ent><br/
<hw>Dab"ber</hw> <pr>(d<acr/b"b<etil/r)</pr>, <pos>n.</pos> <def>That
with which one dabs; hence, a pad or other device used by printers,
engravers, etc., as for dabbing type or engraved plates with
ink.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dabble</ent><br/
<hw>Dab"ble</hw> <pr>(d<acr/b"b'l)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Dabbled</conjf>
<pr>(d<acr/b"b'ld)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Dabbling</conjf> <pr>(d<acr/b"bl<icr/ng)</pr>.]</vmorph>
<ety>[Freq. of <ets>dab</ets>: cf. OD. <ets>dabbelen</ets>.]</ety>
<def>To wet by little dips or strokes; to spatter; to sprinkle; to
moisten; to wet.</def> <ldquo/Bright hair <xex>dabbled</xex> in
blood.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dabble</ent><br/
<hw>Dab"ble</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To play in water, as
with the hands; to paddle or splash in mud or water.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Where the duck <qex>dabbles</qex> 'mid the rustling sedge.</q>
<rj><qau>Wordsworth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To work in slight or superficial manner; to do in a
small way; to tamper; to meddle.</def> <ldquo/<xex>Dabbling</xex> here
and there with the text.<rdquo/ <rj><au>Atterbury.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>During the first year at Dumfries, Burns for the first time began
to <qex>dabble</qex> in politics.</q> <rj><qau>J. C.
Shairp.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dabbler</ent><br/
<hw>Dab"bler</hw> <pr>(d<acr/b"bl<etil/r)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>One who dabbles.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who dips slightly into anything; a superficial
meddler.</def> <ldquo/our <xex>dabblers</xex> in politics.<rdquo/
<rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dabblingly</ent><br/
<hw>Dab"bling*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a dabbling
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dabchick</ent><br/
<hw>Dab"chick`</hw> <pr>(d<acr/b"ch<icr/k`)</pr>, <pos>n.</pos>
<ety>[For <ets>dabchick</ets>. See <er>Dap</er>, <er>Dip</er>, cf.
<er>Dipchick</er>.]</ety> <fld>(Zool.)</fld> <def>A small water bird
(<spn>Podilymbus podiceps</spn>), allied to the grebes, remarkable for
its quickness in diving; -- called also <altname>dapchick</altname>,
<altname>dobchick</altname>, <altname>dipchick</altname>,
<altname>didapper</altname>, <altname>dobber</altname>,
<altname>devil-diver</altname>, <altname>hell-diver</altname>, and
<altname>pied-billed grebe</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daboia</ent><br/
\'d8<hw>Da*boi"a</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>A large and highly venomous Asiatic viper (<spn>Daboia
xanthica</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dabster</ent><br/
<hw>Dab"ster</hw>, <pos>n.</pos> <ety>[Cf. <er>Dab</er> an
expert.]</ety> <def>One who is skilled; a master of his business; a
proficient; an adept.</def> <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Sometimes improperly used for <xex>dabbler</xex>; as,
<ldquo/I am but a <xex>dabster</xex> with gentle art<rdquo/.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dacapo</ent><br/
\'d8<hw>Da`ca"po</hw> <pr>(?)</pr>. <ety>[It., from [the] head or
beginning.]</ety> <fld>(Mus.)</fld> <def>From the beginning; a direction
to return to, and end with, the first strain; -- indicated by the
letters <it>D. C.</it> Also, the strain so repeated.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dace</ent><br/
<hw>Dace</hw> <pr>(d<amac/s)</pr>, <pos>n.</pos> <ety>[Written also
<ets>dare</ets>, <ets>dart</ets>, fr. F. <ets>dard</ets> dase, dart, of
German origin. <ets>Dace</ets> is for an older <ets>darce</ets>, fr. an
OF. nom. <ets>darz</ets>. See <er>Dart</er> a javelin.]</ety>
<fld>(Zool.)</fld> <def>A small European cyprinoid fish (<spn>Leuciscus
leuciscus</spn>, formerly <spn>Squalius leuciscus</spn> or
<spn>Leuciscus vulgaris</spn>); -- called also
<altname>dare</altname>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><note><hand/ In America the name is given to several related fishes
of the genera <gen>Squalius</gen>, <gen>Minnilus</gen>, etc. The
black-nosed dace is <spn>Rhinichthys atronasus</spn> the horned dace is
<spn>Semotilus corporalis</spn>. For red dace, see
<er>Redfin</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dacelo</ent><br/
<hw>Dacelo</hw> <pos>n.</pos> <def>a genus of Australasian
<isa>kingfishers</isa>.</def><br/
<syn><b>Syn. --</b> genus <gen>Dacelo</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>dacha</ent><br/
<hw>dacha</hw> <pos>n.</pos> <ety>[Russian.]</ety> <def>a Russian
country house, especially a cottage used in the summer.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Dachshund</ent><br/
\'d8<hw>Dachs"hund`</hw> <pr>(d<aum/ks"h<udd/nt`)</pr>, <pos>n.</pos>
<ety>[G., from <ets>dachs</ets> badger + <ets>hund</ets> dog.]</ety>
<fld>(Zool.)</fld> <def>One of a breed of small dogs with short crooked
legs, and long body; -- called also <altname>badger dog</altname>. There
are two kinds, the rough-haired and the smooth-haired.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dacian</ent><br/
<hw>Da"cian</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining to
Dacia or the Dacians.</def> -- <def2><pos>n.</pos> <def>A native of
ancient Dacia.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dacninae</ent><br/
<hw>Dacninae</hw> <pos>n.</pos> <def>a natural family comprising the
honeycreepers.</def><br/
<syn><b>Syn. --</b> Coerebidae, family <fam>Coerebidae</fam>, family
<fam>Dacninae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>dacoit</ent><br/
<hw>da*coit"</hw> <pr>(d<adot/*koit")</pr>, <pos>n.</pos> <ety>[Hind.
<ets><dsdot/akait</ets>, <ets><dsdot/<amac/k<amac/yat</ets>.]</ety>
<def>One of a class of robbers, in India and Burma (Myanmar), who act in
gangs and are usually armed.</def> <altsp>[Also spelled
<asp>dakoit</asp>.]</altsp><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>dacoity</ent><br/
<hw>da*coit"y</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The practice of gang
robbery in India; robbery committed by dacoits.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dacotahs</ent><br/
<hw>Da*co"tahs</hw> <pr>(?)</pr>, <pos>n. pl.</pos>; <sing>sing.
<singw>Dacotan</singw> <pr>(<?/)</pr></sing>. <fld>(Ethnol.)</fld>
<def>Same as <er>Dacotas</er>.</def> <rj><au>Longfellow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dacron</ent><br/
<hw>Dacron</hw> <pos>n.</pos> <ety>[Trademark.]</ety> <def>a brand of
polyester textile fiber, or the wrinkle-resistant fabric prepared from
it.</def><br/
<syn><b>Syn. --</b> dacron, Terylene.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dacrycarpus</ent><br/
<hw>Dacrycarpus</hw> <pos>n.</pos> <def>a genus of evergreen coniferous
shrubs or trees of New Zealand to Malaysia and Philippines.</def><br/
<syn><b>Syn. --</b> genus <gen>Dacrycarpus</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dacrydium</ent><br/
<hw>Dacrydium</hw> <pos>n.</pos> <def>a genus of Australasian evergreen
trees or shrubs.</def><br/
<syn><b>Syn. --</b> genus <gen>Dacrydium</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dacrymyces</ent><br/
<hw>Dacrymyces</hw> <pos>n.</pos> <def>the type genus of the
<fam>Dacrymycetaceae</fam>, consisting of fungi with a bifurcate
basidium that lacks septa.</def><br/
<syn><b>Syn. --</b> genus <gen>Dacrymyces</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>dactyl</ent><br/
<hw>dac"tyl</hw> <pr>(d<acr/k"t<icr/l)</pr>, <pos>n.</pos> <ety>[L.
<ets>dactylus</ets>, Gr. <grk>da`ktylos</grk> a finger, a dactyl. Cf.
<er>Digit</er>.]</ety> <sn>1.</sn> <fld>(Pros.)</fld> <def>A poetical
foot of three syllables (<mdash/ <cre/ <cre/), one long followed by two
short, or one accented followed by two unaccented; <as>as, L.
<it>t<eum/gm<icr/n<ecr/</it>, E. <it>mer<bprime/ciful</it>; -- so called
from the similarity of its arrangement to that of the joints of a
finger.</as></def> <altsp>[Written also <asp>dactyle</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <sd>(a)</sd> <def>A finger or toe; a
digit.</def> <sd>(b)</sd> <def>The claw or terminal joint of a leg of an
insect or crustacean.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>dactylar</ent><br/
<hw>dac"tyl*ar</hw> <pr>(d<acr/k"t<icr/l*<etil/r)</pr>, <pos>a.</pos>
<sn>1.</sn> <def>Pertaining to dactyl; dactylic.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>Of or pertaining to a finger or
toe, or to the claw of an insect crustacean.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dactylet</ent><br/
<hw>Dac"tyl*et</hw> <pr>(d<acr/k"t<icr/l*<ecr/t)</pr>, <pos>n.</pos>
<ety>[<ets>Dactyl</ets> + <ets>-et</ets>.]</ety> <def>A dactyl.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dactylic</ent><br/
<hw>Dac*tyl"ic</hw> <pr>(d<acr/k*t<icr/l"<icr/k)</pr>, <pos>a.</pos>
<ety>[L. <ets>dactylicus</ets>, Gr. <grk>daktyliko`s</grk>, fr.
<grk>da`ktylos</grk>.]</ety> <def>Pertaining to, consisting chiefly or
wholly of, dactyls; <as>as, <ex>dactylic</ex> verses</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dactylic</ent><br/
<hw>Dac*tyl"ic</hw>, <pos>n.</pos> <sn>1.</sn> <def>A line consisting
chiefly or wholly of dactyls; <as>as, these lines are
<ex>dactylics</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <pluf>pl.</pluf> <def>Dactylic meters.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>dactylioglyph</ent><br/
<hw>dac*tyl"i*o*glyph</hw>
<pr>(d<acr/k*t<icr/l"<icr/*<osl/*gl<icr/f)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>daktyliogly`fos</grk> an engraver of gems; <grk>dakty`lios</grk>
finger ring (fr. <grk>da`ktylos</grk> finger) + <grk>gly`fein</grk> to
engrave.]</ety> <fld>(Fine Arts)</fld> <sd>(a)</sd> <def>An engraver of
gems for rings and other ornaments.</def> <sd>(b)</sd> <def>The
inscription of the engraver's name on a finger ring or gem.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>dactylioglyphy</ent><br/
<hw>dac*tyl`i*og"ly*phy</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The art or
process of gem engraving.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dactyliography</ent><br/
<hw>Dac*tyl`i*og"ra*phy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>dakty`lios</grk> finger ring + <ets>-graphy</ets>.]</ety>
<fld>(Fine Arts)</fld> <sd>(a)</sd> <def>The art of writing or engraving
upon gems.</def> <sd>(b)</sd> <def>In general, the literature or history
of the art.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dactyliology</ent><br/
<hw>Dac*tyl`i*ol"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>dakty`lios</grk> finger ring + <ets>-logy</ets>.]</ety> <fld>(Fine
Arts)</fld> <sd>(a)</sd> <def>That branch of arch<ae/ology which has to
do with gem engraving.</def> <sd>(b)</sd> <def>That branch of
arch<ae/ology which has to do with finger rings.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dactyliomancy</ent><br/
<hw>Dac*tyl"i*o*man`cy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>dakty`lios</grk> + <ets>-mancy</ets>.]</ety> <def>Divination by
means of finger rings.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dactylist</ent><br/
<hw>Dac"tyl*ist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A writer of
dactylic verse.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dactylitis</ent><br/
\'d8<hw>Dac`tyl*i"tis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <grk>da`ktylos</grk> finger + <ets>-itis</ets>.]</ety>
<fld>(Med.)</fld> <def>An inflammatory affection of the fingers.</def>
<rj><au>Gross.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dactylology</ent><br/
<hw>Dac`tyl*ol"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>da`ktylos</grk> finger + <ets>-logy</ets>.]</ety> <def>The art of
communicating ideas by certain movements and positions of the fingers; a
form of <isa>sign language</isa>, especially the manual alphabets used
by the deaf and dumb.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><note><hand/ There are two different manual alphabets, the
<xex>one-hand</xex> alphabet (which was perfected by Abb<eacute/ de
l'Ep<eacute/e, who died in 1789), and the <xex>two-hand</xex> alphabet.
The latter was probably based on the manual alphabet published by George
Dalgarus of Aberdeen, in 1680. See <xex>Illustration</xex> in
Appendix.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dactylomancy</ent><br/
<hw>Dac*tyl"o*man`cy</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Dactyliomancy.</def> <mark>[R.]</mark> <rj><au>Am.
Cyc.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dactylonomy</ent><br/
<hw>Dac`tyl*on"o*my</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>da`ktylos</grk> finger + <grk>no`mos</grk> law,
distribution.]</ety> <def>The art of numbering or counting by the
fingers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dactylopterous</ent><br/
<hw>Dac`tyl*op"ter*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>da`ktylos</grk> finger + <ets><grk>pte`ryx</grk></ets> wing,
fin.]</ety> <fld>(Zool.)</fld> <def>Having the inferior rays of the
pectoral fins partially or entirely free, as in the gurnards.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dactyloscopidae</ent><br/
<hw>Dactyloscopidae</hw> <pos>n.</pos> <def>a natural family of Atlantic
fishes comprising the <er>sand stargazers</er>.</def><br/
<syn><b>Syn. --</b> family <gen>Dactyloscopidae</gen>.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Dactylotheca</ent><br/
\'d8<hw>Dac`ty*lo*the"ca</hw>
<pr>(d<acr/k`t<icr/*l<osl/*th<emac/"k<adot/)</pr>, <pos>n.</pos>
<ety>[NL., fr. Gr. <grk>da`ktylos</grk> finger, toe + <grk>qh`kh</grk>
case, box.]</ety> <fld>(Zool.)</fld> <def>The scaly covering of the
toes, as in birds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>dactylozooid</ent><br/
<hw>dac`tyl*o*zo"oid</hw> <pr>(d<acr/k`t<icr/*l<osl/*z<omac/"oid)</pr>,
<pos>n.</pos> <ety>[Gr. <grk>da`ktylos</grk> finger + E.
<ets>zooid</ets>.]</ety> <fld>(Zool.)</fld> <def>A kind of zooid of
Siphonophora which has an elongated or even vermiform body, with one
tentacle, but no mouth. See <er>Siphonophora</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dad</ent><br/
<hw>Dad</hw> <pr>(d<acr/d)</pr>, <pos>n.</pos> <ety>[Prob. of Celtic
origin; cf. Ir. <ets>daid</ets>, Gael. <ets>daidein</ets>, W.
<ets>tad</ets>, OL. <ets>tata</ets>, Gr. <grk>ta`ta</grk>,
<grk>te`tta</grk>, Skr. <ets>t<amac/ta</ets>.]</ety> <def>Father; -- a
word sometimes used by children.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I was never so bethumped with words,<br/
Since I first called my brother's father <qex>dad</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daddle</ent><br/
<hw>Dad"dle</hw> <pr>(d<acr/d"d'l)</pr>, <pos>v. i.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Daddled</conjf> <pr>(?)</pr>,
<pos>p. pr. & vb. n.</pos> <conjf>Daddling</conjf>.]</vmorph>
<ety>[Prob. freq. of <ets>dade</ets>.]</ety> <def>To toddle; to walk
unsteadily, like a child or an old man; hence, to do anything slowly or
feebly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daddock</ent><br/
<hw>Dad"dock</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. Prov. E.
<ets>dad</ets> a large piece.]</ety> <def>The rotten body of a
tree.</def> <mark>[Prov. Eng.]</mark> <rj><au>Wright.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daddy</ent><br/
<hw>Dad"dy</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Diminutive of
<er>Dad</er>.</def> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daddy longlegs</ent><br/
<hw>Dad"dy long"legs`</hw> <pr>(?)</pr>. <sn>1.</sn> <fld>(Zool.)</fld>
<def>An arachnidan of the genus <gen>Phalangium</gen>, and allied
genera, having a small body and four pairs of long legs; -- called also
<altname>harvestman</altname>, <altname>carter</altname>, and
<altname>grandfather longlegs</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>A name applied to many species of
dipterous insects of the genus <gen>Tipula</gen>, and allied genera,
with slender bodies, and very long, slender legs; the crane fly; --
called also <altname>father longlegs</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dade</ent><br/
<hw>Dade</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Of. uncertain origin.
Cf. <er>Dandle</er>, <er>Daddle</er>.]</ety> <def>To hold up by leading
strings or by the hand, as a child while he toddles.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Little children when they learn to go<br/
By painful mothers <qex>daded</qex> to and fro.</q>
<rj><qau>Drayton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dade</ent><br/
<hw>Dade</hw>, <pos>v. i.</pos> <def>To walk unsteadily, as a child in
leading strings, or just learning to walk; to move slowly.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>No sooner taught to <qex>dade</qex>, but from their mother
trip.</q> <rj><qau>Drayton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dado</ent><br/
<hw>Da"do</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Dadoes</plw> <pr>(#)</pr>.</plu> <ety>[It. <ets>dado</ets> die,
cube, pedestal; of the same origin as E. <ets>die</ets>, <ets>n.</ets>
See <er>Die</er>, <pos>n.</pos>]</ety> <fld>(Arch.)</fld> <sd>(a)</sd>
<def>That part of a pedestal included between the base and the cornice
(or surbase); the die. See <xex>Illust.</xex> of <er>Column</er>.</def>
Hence: <sd>(b)</sd> <def>In any wall, that part of the basement included
between the base and the base course. See <cref>Base course</cref>,
under <er>Base</er>.</def> <sd>(c)</sd> <def>In interior decoration, the
lower part of the wall of an apartment when adorned with moldings, or
otherwise specially decorated.</def></p>

<p><ent>Daedalian</ent><br/
<ent>Daedal</ent><br/
<mhw>{ <hw>D<ae/"dal</hw> <pr>(?)</pr>, <hw>D<ae/*dal"ian</hw>
<pr>(?)</pr> }</mhw>, <pos>a.</pos> <ety>[L. <ets>daedalus</ets>
cunningly wrought, fr. Gr. <ets><grk>daida`llw</grk></ets>; cf.
<ets><?/</ets> to work cunningly. The word also alludes to the mythical
D<ae/dalus (Gr. <ets><grk>Dai`dalos</grk></ets>, lit., the cunning
worker).]</ety> <sn>1.</sn> <def>Cunningly or ingeniously formed or
working; skillful; artistic; ingenious.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Our bodies decked in our <qex>d<ae/dalian</qex> arms.</q>
<rj><qau>Chapman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>d<ae/dal</qex> hand of Nature.</q> <rj><qau>J.
Philips.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The doth the <qex>d<ae/dal</qex> earth throw forth to thee,<br/
Out of her fruitful, abundant flowers.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Crafty; deceitful.</def> <mark>[R.]</mark>
<rj><au>Keats.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daedalous</ent><br/
<hw>D<ae/d"a*lous</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Bot.)</fld>
<def>Having a variously cut or incised margin; -- said of
leaves.</def></p>

<p><ent>Daemonic</ent><br/
<ent>Daemon</ent><br/
<mhw><hw>D<ae/"mon</hw> <pr>(?)</pr>, <pos>n.</pos>,
<hw>D<ae/*mon"ic</hw> <pr>(<?/)</pr>, <pos>a.</pos></mhw> <def>See
<er>Demon</er>, <er>Demonic</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daff</ent><br/
<hw>Daff</hw> <pr>(d<adot/f)</pr>, <pos>v. t.</pos> <ety>[Cf.
<er>Doff</er>.]</ety> <def>To cast aside; to put off; to doff.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Canst thou so <qex>daff</qex> me? Thou hast killed my child.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daff</ent><br/
<hw>Daff</hw>, <pos>n.</pos> <ety>[See <er>Daft</er>.]</ety> <def>A
stupid, blockish fellow; a numskull.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 365 --></p>

<p><ent>Daff</ent><br/
<hw>Daff</hw> <pr>(d<adot/f)</pr>, <pos>v. i.</pos> <def>To act
foolishly; to be foolish or sportive; to toy.</def> <mark>[Scot.]</mark>
<rj><au>Jamieson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daff</ent><br/
<hw>Daff</hw>, <pos>v. t.</pos> <def>To daunt.</def> <mark>[Prov.
Eng.]</mark> <rj><au>Grose.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daffodil</ent><br/
<hw>Daf"fo*dil</hw> <pr>(d<acr/f"f<osl/*d<icr/l)</pr>, <pos>n.</pos>
<ety>[OE. <ets>affodylle</ets>, prop., the asphodel, fr. LL.
<ets>affodillus</ets> (cf. D. <ets>affodille</ets> or OF.
<ets>asphodile</ets>, <ets>aphodille</ets>, F.
<ets>asphod<egrave/le</ets>), L. <ets>asphodelus</ets>, fr. Gr.
<grk>'asfo`delos</grk>. The initial <it>d</it> in English is not
satisfactorily explained. See <er>Asphodel</er>.]</ety>
<fld>(Bot.)</fld> <sd>(a)</sd> <def>A plant of the genus
<gen>Asphodelus</gen>.</def> <sd>(b)</sd> <def>A plant of the genus
<gen>Narcissus</gen> (<spn>Narcissus Pseudo-narcissus</spn>). It has a
bulbous root and beautiful flowers, usually of a yellow hue. Called also
<altname>daffodilly</altname>, <altname>daffadilly</altname>,
<altname>daffadowndilly</altname>, <altname>daffydowndilly</altname>,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With damask roses and <qex>daffadillies</qex> set.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Strow me the ground with <qex>daffadowndillies</qex>,<br/
And cowslips, and kingcups, and loved lilies.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A college gown<br/
That clad her like an April <qex>daffodilly</qex>.</q>
<rj><qau>Tennyson</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And chance-sown <qex>daffodil</qex>.</q>
<rj><qau>Whittier.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daft</ent><br/
<hw>Daft</hw> <pr>(d<adot/ft)</pr>, <pos>a.</pos> <ety>[OE.
<ets>daft</ets>, <ets>deft</ets>, <ets>deft</ets>, stupid; prob. the
same word as E. <ets>deft</ets>. See <er>Deft</er>.]</ety> <sn>1.</sn>
<def>Stupid; foolish; idiotic; also, delirious; insane; <as>as, he has
gone <ex>daft</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Let us think no more of this <qex>daft</qex> business</q>
<rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Gay; playful; frolicsome.</def> <mark>[Scot.]</mark>
<rj><au>Jamieson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daftness</ent><br/
<hw>Daft"ness</hw>, <pos>n.</pos> <def>The quality of being
daft.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dag</ent><br/
<hw>Dag</hw> <pr>(d<acr/g)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>dague</ets>, LL. <ets>daga</ets>, D. <ets>dagge</ets> (fr. French);
all prob. fr. Celtic; Cf. Gael. <ets>dag</ets> a pistol, Armor.
<ets>dag</ets> dagger, W. <ets>dager</ets>, <ets>dagr</ets>, Ir.
<ets>daigear</ets>. Cf. <er>Dagger</er>.]</ety> <sn>1.</sn> <def>A
dagger; a poniard.</def> <mark>[Obs.]</mark>
<rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A large pistol formerly used.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The Spaniards discharged their <qex>dags</qex>, and hurt some.</q>
<rj><qau>Foxe.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A sort of pistol, called <qex>dag</qex>, was used about the same
time as hand guns and harquebuts.</q> <rj><qau>Grose.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <def>The unbranched antler of a young
deer.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dag</ent><br/
<hw>Dag</hw>, <pos>n.</pos> <ety>[Of Scand. origin; cf. Sw.
<ets>dagg</ets>, Icel. <ets>d<oum/gg</ets>. <root/71. See
<er>Dew</er>.]</ety> <def>A misty shower; dew.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dag</ent><br/
<hw>Dag</hw>, <pos>n.</pos> <ety>[OE. <ets>dagge</ets> (cf.
<er>Dagger</er>); or cf. AS. <ets>d<amac/g</ets> what is
dangling.]</ety> <def>A loose end; a dangling shred.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Daglocks, clotted locks hanging in <qex>dags</qex> or jags at a
sheep's tail.</q> <rj><qau>Wedgwood.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dag</ent><br/
<hw>Dag</hw>, <pos>v. t.</pos> <ety>[1, from <er>Dag</er> dew. 2, from
<er>Dag</er> a loose end.]</ety> <sn>1.</sn> <def>To daggle or
bemire.</def> <mark>[Prov. Eng.]</mark> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To cut into jags or points; to slash; <as>as, to
<ex>dag</ex> a garment</as>.</def> <mark>[Obs.]</mark>
<rj><au>Wright.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dag</ent><br/
<hw>Dag</hw>, <pos>v. i.</pos> <def>To be misty; to drizzle.</def>
<mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>dagame</ent><br/
<hw>dagame</hw> <pos>n.</pos> <def>the <altname>lemonwood tree</altname>
(<spn>Calycophyllum candidissimum</spn>); -- it is a tropical American
tree which is source of a tough elastic wood.</def><br/
<syn><b>Syn. --</b> lemonwood tree, <spn>Calycophyllum
candidissimum</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dagan</ent><br/
<hw>Dagan</hw> <pos>prop. n.</pos> <def>the Mesopotanian god of
agriculture and earth; it is a counterpart of Phoenician and Philistine
Dagon.</def> <note>See references to Dagon in the Bible and in the opera
<title>Samson et Dalila</title>.</note><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Dagda</ent><br/
<hw>Dagda</hw> <pos>n.</pos> <def>in Irish legend, chief god of the
Tuatha De Danann; father of Angus Og and Brigit.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>dagga</ent><br/
<hw>dagga</hw> <pos>n.</pos> <def>a relatively nontoxic South African
herb (<spn>Leonotis leonurus</spn>) smoked like tobacco.</def><br/
<syn><b>Syn. --</b> Cape dagga, red dagga, wilde dagga, <spn>Leonotis
leonurus</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dagger</ent><br/
<hw>Dag"ger</hw> <pr>(-g<etil/r)</pr>, <pos>n.</pos> <ety>[Cf. OE.
<ets>daggen</ets> to pierce, F. <ets>daguer</ets>. See <er>Dag</er> a
dagger.]</ety> <sn>1.</sn> <def>A short weapon used for stabbing. This
is the general term: cf. <er>Poniard</er>, <er>Stiletto</er>, <er>Bowie
knife</er>, <er>Dirk</er>, <er>Misericorde</er>,
<er>Anlace</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Print.)</fld> <def>A mark of reference in the form
of a dagger [<dagger/]. It is the second in order when more than one
reference occurs on a page; -- called also
<altname>obelisk</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dagger moth</b></col> <fld>(Zool.)</fld>, <cd>any moth of
the genus <gen>Apatalea</gen>. The larv<ae/ are often destructive to the
foliage of fruit trees, etc.</cd> -- <col><b>Dagger of lath</b></col>,
<cd>the wooden weapon given to the Vice in the old Moralities.</cd>
<au>Shak.</au> -- <col><b>Double dagger</b></col>, <cd>a mark of
reference [<Dagger/] which comes next in order after the dagger.</cd> --
<mcol><col><b>To look daggers</b></col>, <it>or</it> <col><b>To speak
daggers</b></col></mcol>, <cd>to look or speak fiercely or
reproachfully.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dagger</ent><br/
<hw>Dag"ger</hw>, <pos>v. t.</pos> <def>To pierce with a dagger; to
stab.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dagger</ent><br/
<hw>Dag"ger</hw>, <pos>n.</pos> <ety>[Perh. from
<ets>diagonal</ets>.]</ety> <def>A timber placed diagonally in a ship's
frame.</def> <rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dagges</ent><br/
<hw>Dagges</hw> <pr>(d<acr/gz)</pr>, <pos>n. pl.</pos> <ety>[OE. See
<er>Dag</er> a loose end.]</ety> <def>An ornamental cutting of the edges
of garments, introduced about <sc>a. d.</sc> 1346, according to the
Chronicles of St Albans.</def> <mark>[Obs.]</mark>
<rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daggle</ent><br/
<hw>Dag"gle</hw> <pr>(d<acr/g"g'l)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Daggled</conjf>
<pr>(-g'ld)</pr>; <pos>p. pr. & vb. n.</pos> <conjf>Daggling</conjf>
<pr>(-gl<icr/ng)</pr>.]</vmorph> <ety>[Freq. of <ets>dag</ets>, v. t.,
1.]</ety> <def>To trail, so as to wet or befoul; to make wet and limp;
to moisten.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The warrior's very plume, I say,<br/
Was <qex>daggled</qex> by the dashing spray.</q> <rj><qau>Sir W.
Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daggle</ent><br/
<hw>Dag"gle</hw>, <pos>v. i.</pos> <def>To run, go, or trail one's self
through water, mud, or slush; to draggle.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Nor, like a puppy [have I] <qex>daggled</qex> through the
town.</q> <rj><qau>Pope.</qau></rj></p>

<p><ent>Daggle-tailed</ent><br/
<ent>Daggle-tail</ent><br/
<mhw>{ <hw>Dag"gle-tail`</hw> <pr>(d<acr/g"g'l-t<amac/l`)</pr>,
<hw>Dag"gle-tailed`</hw> <pr>(-t<amac/ld`)</pr>, }</mhw> <pos>a.</pos>
<def>Having the lower ends of garments defiled by trailing in mire or
filth; draggle-tailed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daggle-tail</ent><br/
<hw>Dag"gle-tail`</hw> <pr>(-t<amac/l`)</pr>, <pos>n.</pos> <def>A
slovenly woman; a slattern; a draggle-tail.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daglock</ent><br/
<hw>Dag"lock`</hw> <pr>(-l<ocr/k`)</pr>, <pos>n.</pos>
<ety>[<ets>Dag</ets> a loose end + <ets>lock</ets>.]</ety> <def>A dirty
or clotted lock of wool on a sheep; a taglock.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dago</ent><br/
<hw>Da"go</hw> <pr>(d<amac/"g<osl/)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Dagos</plw> <pr>(-g<omac/z)</pr>.</plu> <ety>[Cf.
Sp. <ets>Diego</ets>, E. <ets>James</ets>.]</ety> <def>A nickname given
to a person of Spanish (or, by extension, Portuguese or Italian)
descent.</def> <mark>[U. S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dagoba</ent><br/
\'d8<hw>Da*go"ba</hw> <pr>(d<adot/*g<omac/"b<adot/)</pr>, <pos>n.</pos>
<ety>[Singhalese <ets>d<amac/goba</ets>.]</ety> <def>A dome-shaped
structure built over relics of Buddha or some Buddhist saint.</def>
<mark>[East Indies]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dagon</ent><br/
<hw>Da"gon</hw> <pr>(d<amac/"g<ocr/n)</pr>, <ety>[Heb.
<ets>D<amac/gon</ets>, fr. <ets>dag</ets> a fish: cf. Gr.
<grk>Dagw`n</grk>.]</ety> <def>The national god of the Philistines,
represented with the face and hands and upper part of a man, and the
tail of a fish.</def> <rj><au>W. Smith.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>This day a solemn feast the people hold<br/
To <qex>Dagon</qex>, their sea idol.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>They brought it into the house of <qex>Dagon</qex>.</q> <rj><qau>1
Sam. v. 2.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dagon</ent><br/
<hw>Dag"on</hw> <pr>(d<acr/g"<ocr/n)</pr>, <pos>n.</pos> <ety>[See
<er>Dag</er> a loose end.]</ety> <def>A slip or piece.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dagswain</ent><br/
<hw>Dag"swain`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From <er>Dag</er>
a loose end?]</ety> <def>A coarse woolen fabric made of daglocks, or the
refuse of wool.</def> <ldquo/Under coverlets made of
<xex>dagswain</xex>.<rdquo/ <rj><au>Holinshed.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dag-tailed</ent><br/
<hw>Dag"-tailed`</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Dag</ets> a
loose end + <ets>tail</ets>.]</ety> <def>Daggle-tailed; having the tail
clogged with daglocks.</def> <ldquo/<xex>Dag-tailed</xex> sheep.<rdquo/
<rj><au>Bp. Hall.</au></rj></p>

<p><ent>Daguerreian</ent><br/
<ent>Daguerrean</ent><br/
<mhw>{ <hw>Da*guer"re*an</hw> <pr>(d<adot/*g<ecr/r"<icr/*<ait/n)</pr>,
<hw>Da*guerre"i*an</hw> <pr>(?)</pr>, }</mhw> <pos>a.</pos>
<def>Pertaining to Daguerre, or to his invention of the
daguerreotype.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daguerreotype</ent><br/
<hw>Da*guerre"o*type</hw> <pr>(d<adot/*g<ecr/r"<osl/*t<imac/p)</pr>,
<pos>n.</pos> <ety>[From <etsep>Daguerre</etsep> the inventor +
<ets>-type</ets>.]</ety> <sn>1.</sn> <def>An early variety of
photograph, produced on a silver plate, or copper plate covered with
silver, and rendered sensitive by the action of iodine, or iodine and
bromine, on which, after exposure in the camera, the latent image is
developed by the vapor of mercury.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The process of taking such pictures.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daguerreotype</ent><br/
<hw>Da*guerre"o*type</hw> <pr>(d<adot/*g<ecr/r"<osl/*t<imac/p)</pr>,
<pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Daguerreotyped</conjf> <pr>(-t<imac/pt)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Daguerreotyping</conjf>
<pr>(-t<imac/`p<icr/ng)</pr>.]</vmorph> <sn>1.</sn> <def>To produce or
represent by the daguerreotype process, as a picture.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To impress with great distinctness; to imprint; to
imitate exactly.</def></p>

<p><ent>Daguerreotypist</ent><br/
<ent>Daguerreotyper</ent><br/
<mhw>{ <hw>Da*guerre"o*ty`per</hw> <pr>(?)</pr>,
<hw>Da*guerre"o*ty`pist</hw> <pr>(?)</pr>, }</mhw> <pos>n.</pos>
<def>One who takes daguerreotypes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daguerreotypy</ent><br/
<hw>Da*guerre"o*ty`py</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The art or
process of producing pictures by method of Daguerre.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dahabeah</ent><br/
\'d8<hw>Da`ha*be"ah</hw> <pr>(d<aum/`h<adot/*b<emac/"<adot/)</pr>,
<pos>n.</pos> <ety>[Ar.]</ety> <def>A Nile boat constructed on the model
of a floating house, having large lateen sails.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dahlia</ent><br/
<hw>Dah"lia</hw> <pr>(d<aum/l"y<adot/ <i>or</i> d<amac/l"y<adot/; 277,
106)</pr>, <pos>n.</pos>; <plu><it>pl.</it> <plw>Dahlias</plw>
<pr>(#)</pr>.</plu> <ety>[Named after Andrew <etsep>Dahl</etsep> a
Swedish botanist.]</ety> <fld>(Bot.)</fld> <def>A genus of plants native
to Mexico and Central America, of the order Composit<ae/; also, any
plant or flower of the genus. The numerous varieties of cultivated
dahlias bear conspicuous flowers which differ in color.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dahlin</ent><br/
<hw>Dah"lin</hw> <pr>(d<aum/"l<icr/n)</pr>, <pos>n.</pos> <ety>[From
<er>Dahlia</er>.]</ety> <fld>(Chem.)</fld> <def>A variety of starch
extracted from the dahlia; -- called also <altname>inulin</altname>. See
<er>Inulin</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dahoon</ent><br/
<hw>Da*hoon"</hw> <pr>(d<adot/*h<oomac/n")</pr>, <ety>[Origin
unknown.]</ety> <def>An evergreen shrub or small tree (<spn>Ilex
cassine</spn>) of the southern United States, bearing red drupes and
having soft, white, close-grained wood; -- called also
<altname><col><b>dahoon holly</b></col></altname>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>daikon</ent><br/
<hw>daikon</hw> <pos>n.</pos> <def>a radish of Japan (<spn>Raphanus
sativus longipinnatus</spn>) with a long hard durable root eaten raw or
cooked.</def><br/
<syn><b>Syn. --</b> Japanese radish, <spn>Raphanus sativus
longipinnatus</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dail</ent><br/
<hw>Dail</hw> <pos>n.</pos> <def>the lower house of the parliament of
the Republic of Ireland; -- also called the <altname>Dail
Eirann</altname>. From its members is selected the <er>Taoiseach</er>,
or prime minister.</def><br/
<syn><b>Syn. --</b> Dail Eireann.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Dailiness</ent><br/
<hw>Dai"li*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Daily
occurrence.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daily</ent><br/
<hw>Dai"ly</hw> <pr>(d<amac/"l<ycr/)</pr>, <pos>a.</pos> <ety>[AS.
<ets>d<ae/gl<imac/c</ets>; <ets>d<ae/g</ets> day + <ets>-l<imac/c</ets>
like. See <er>Day</er>.]</ety> <def>Happening, or belonging to, each
successive day; diurnal; <as>as, <ex>daily</ex> labor; a <ex>daily</ex>
bulletin.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Give us this day our <qex>daily</qex> bread.</q> <rj><qau>Matt.
vi. 11.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Bunyan has told us . . . that in New England his dream was the
<qex>daily</qex> subject of the conversation of thousands.</q>
<rj><qau>Macaulay.</qau></rj></p>

<p><syn><b>Syn.</b> -- <er>Daily</er>, <er>Diurnal</er>.</syn> <usage>
<xex>Daily</xex> is Anglo-Saxon, and <xex>diurnal</xex> is Latin. The
former is used in reference to the ordinary concerns of life; as,
<xex>daily</xex> wants, <xex>daily</xex> cares, <xex>daily</xex>
employments. The latter is appropriated chiefly by astronomers to what
belongs to the astronomical day; as, the <xex>diurnal</xex> revolution
of the earth.</usage><br/
[<source>1913 Webster</source>]</p>

<p><q>Man hath his <qex>daily</qex> work of body or mind<br/
Appointed, which declares his dignity,<br/
And the regard of Heaven on all his ways.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Half yet remains unsung, but narrower bound<br/
Within the visible <qex>diurnal</qex> sphere.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daily</ent><br/
<hw>Dai"ly</hw>, <pos>n.</pos>; <plu><it>pl.</it> <plw>Dailies</plw>
<pr>(<?/)</pr>.</plu> <def>A publication which appears regularly every
day; <as>as, the morning <ex>dailies</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daily</ent><br/
<hw>Dai"ly</hw>, <pos>adv.</pos> <def>Every day; day by day; <as>as, a
thing happens <ex>daily</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daimio</ent><br/
<hw>Dai"mi*o</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Daimios</plw> <pr>(#)</pr>.</plu> <ety>[Jap., fr. Chin. <ets>tai
ming</ets> great name.]</ety> <def>The title of the feudal nobles of
Japan.</def><-- usu. written <asp>daimyo</asp> --><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>daimios</qex>, or territorial nobles, resided in Yedo and
were divided into four classes.</q> <rj><qau>Am. Cyc.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daint</ent><br/
<hw>Daint</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See <er>Dainty</er>,
<pos>n.</pos>]</ety> <def>Something of exquisite taste; a dainty.</def>
<mark>[Obs.]</mark> -- <def2><pos>a.</pos> <def>Dainty.</def></def2>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>To cherish him with diets <qex>daint</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daintify</ent><br/
<hw>Dain"ti*fy</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Daintified</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Daintifying</conjf>.]</vmorph> <ety>[<ets>Dainty</ets> +
<ets>-fy</ets>.]</ety> <def>To render dainty, delicate, or
fastidious.</def> <ldquo/<xex>Daintified</xex> emotion.<rdquo/
<rj><au>Sat. rev.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daintily</ent><br/
<hw>Dain"ti*ly</hw>, <pos>adv.</pos> <def>In a dainty manner; nicely;
scrupulously; fastidiously; deliciously; prettily.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daintiness</ent><br/
<hw>Dain"ti*ness</hw>, <pos>n.</pos> <def>The quality of being dainty;
nicety; niceness; elegance; delicacy; deliciousness; fastidiousness;
squeamishness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>daintiness</qex> and niceness of our captains</q>
<rj><qau>Hakluyt.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>More notorious for the <qex>daintiness</qex> of the provision . .
. than for the massiveness of the dish.</q>
<rj><qau>Hakewill.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The duke exeeded in the <qex>daintiness</qex> of his leg and foot,
and the earl in the fine shape of his hands,</q> <rj><qau>Sir H.
Wotton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daintrel</ent><br/
<hw>Dain"trel</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<ets>daint</ets> or <ets>dainty</ets>; cf. OF.
<ets>daintier</ets>.]</ety> <def>Adelicacy.</def> <mark>[Obs.]</mark>
<rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dainty</ent><br/
<hw>Dain"ty</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Dainties</plw> <pr>(#)</pr>.</plu> <ety>[OE. <ets>deinie</ets>,
<ets>dainte</ets>, <ets>deintie</ets>, <ets>deyntee</ets>, OF.
<ets>deinti<eacute/</ets> delicacy, orig., dignity, honor, fr. L.
<ets>dignitas</ets>, fr. <ets>dignus</ets> worthy. See <er>Deign</er>,
and cf. <er>Dignity</er>.]</ety> <sn>1.</sn> <def>Value; estimation; the
gratification or pleasure taken in anything.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I ne told no <qex>deyntee</qex> of her love.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is delicious or delicate; a
delicacy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That precious nectar may the taste renew<br/
Of Eden's <qex>dainties</qex>, by our parents lost.</q> <rj><qau>Beau. &
Fl.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A term of fondness.</def> <mark>[Poetic]</mark>
<rj><au>B. Jonson.</au></rj></p>

<p><syn><b>Syn.</b> -- <er>Dainty</er>, <er>Delicacy</er>.</syn> <usage>
These words are here compared as denoting articles of food. The term
<xex>delicacy</xex> as applied to a nice article of any kind, and hence
to articles of food which are particularly attractive. <xex>Dainty</xex>
is stronger, and denotes some exquisite article of cookery. A hotel may
be provided with all the <xex>delicacies</xex> of the season, and its
table richly covered with <xex>dainties</xex>.</usage><br/
[<source>1913 Webster</source>]</p>

<p><q>These <qex>delicacies</qex><br/
I mean of taste, sight, smell, herbs, fruits, and flowers,<br/
Walks and the melody of birds.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>[A table] furnished plenteously with bread,<br/
And <qex>dainties</qex>, remnants of the last regale.</q>
<rj><qau>Cowper.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dainty</ent><br/
<hw>Dain"ty</hw>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Daintier</adjf> <pr>(?)</pr>; <pos>superl.</pos>
<adjf>Daintiest</adjf>.]</amorph> <sn>1.</sn> <def>Rare; valuable;
costly.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Full many a <qex>deynt<eacute/</qex> horse had he in stable.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Hence the proverb <ldquo/<xex>dainty maketh
dearth</xex>,<rdquo/ <it>i. e.</it>, rarity makes a thing dear or
precious.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Delicious to the palate; toothsome.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Dainty</qex> bits<br/
Make rich the ribs.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Nice; delicate; elegant, in form, manner, or
breeding; well-formed; neat; tender.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Those <qex>dainty</qex> limbs which nature lent<br/
For gentle usage and soft delicacy.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I would be the girdle.<br/
About her <qex>dainty</qex>, <qex>dainty</qex> waist.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Requiring dainties. Hence: Overnice; hard to please;
fastidious; squeamish; scrupulous; ceremonious.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thew were a fine and <qex>dainty</qex> people.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And let us not be <qex>dainty</qex> of leave-taking,<br/
But shift away.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To make dainty</b></col>, <cd>to assume or affect
delicacy or fastidiousness.</cd> <mark>[Obs.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><q>Ah ha, my mistresses! which of you all<br/
Will now deny to dance? She that <qex>makes dainty</qex>,<br/
She, I'll swear, hath corns.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>daiquiri</ent><br/
<hw>daiquiri</hw> <pos>n.</pos> <def>an alcoholic beverage containing
rum and lime or lemon juice, usually mixed with a fruit juice or fruit
extract and often blended with crushed ice; <as>as, a strawberry
<ex>daiquiri</ex></as>.</def><br/
<syn><b>Syn. --</b> rum cocktail.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Daira</ent><br/
\'d8<hw>Da"<ium/*ra</hw> <pr>(d<aum/"<esl/*r<aum/)</pr>, <pos>n.</pos>
<ety>[Turk. <ets>daire</ets> circuit, department, fr. Ar.
<ets>da<ium/rah</ets> circle.]</ety> <def>Any of several valuable
estates of the Egyptian khedive or his family. The most important are
the <ecol><b>Da"i*ra Sa"ni*eh</b></ecol> <pr>(s<aum/"n<icr/*<ecr/)</pr>,
or <ecol><b>Da"i*ra Sa"ni*yeh</b></ecol>, and the <ecol><b>Da"i*ra
Khas"sa</b></ecol>, administered by the khedive's European bondholders,
and known collectively as <ecol><b>the Daira</b></ecol>, or the
<ecol><b>Daira estates</b></ecol>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Dairy</ent><br/
<hw>Dai"ry</hw> <pr>(d<amac/"r<ycr/)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Dairies</plw> <pr>(-r<icr/z)</pr>.</plu>
<ety>[OE. <ets>deierie</ets>, from <ets>deie</ets>, <ets>daie</ets>,
maid; of Scand. origin; cf. Icel. <ets>deigja</ets> maid, dairymaid, Sw.
<ets>deja</ets>, orig., a baking maid, fr. Icel. <ets>deig</ets>.
<root/66. See <er>Dough</er>.]</ety> <sn>1.</sn> <def>The place, room,
or house where milk is kept, and converted into butter or
cheese.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>What stores my <qex>dairies</qex> and my folds contain.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That department of farming which is concerned in the
production of milk, and its conversion into butter and cheese.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Grounds were turned much in England either to feeding or
<qex>dairy</qex>; and this advanced the trade of English butter.</q>
<rj><qau>Temple.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A dairy farm.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Dairy</xex> is much used adjectively or in
combination; as, <xex>dairy</xex> farm, <xex>dairy</xex> countries,
<xex>dairy</xex> house or <xex>dairy</xex>house, <xex>dairy</xex>room,
<xex>dairy</xex>work, etc.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dairying</ent><br/
<hw>Dai"ry*ing</hw>, <pos>n.</pos> <def>The business of conducting a
dairy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dairymaid</ent><br/
<hw>Dai"ry*maid`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A female servant
whose business is the care of the dairy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dairyman</ent><br/
<hw>Dai"ry*man</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Dairymen</plw> <pr>(<?/)</pr>.</plu> <def>A man who keeps or takes
care of a dairy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dairywoman</ent><br/
<hw>Dai"ry*wom`an</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Dairywomen</plw> <pr>(<?/)</pr>.</plu> <def>A woman who attends to
a dairy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dais</ent><br/
<hw>Da"is</hw> <pr>(d<amac/"<icr/s)</pr>, <pos>n.</pos> <ety>[OE.
<ets>deis</ets>, <ets>des</ets>, table, dais, OF. <ets>deis</ets> table,
F. <ets>dais</ets> a canopy, L. <ets>discus</ets> a quoit, a dish (from
the shape), LL., table, fr. Gr. <ets><grk>di`skos</grk></ets> a quoit, a
dish. See <er>Dish</er>.]</ety> <sn>1.</sn> <def>The high or principal
table, at the end of a hall, at which the chief guests were seated;
also, the chief seat at the high table.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A platform slightly raised above the floor of a hall
or large room, giving distinction to the table and seats placed upon it
for the chief guests.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A canopy over the seat of a person of dignity.</def>
<mark>[Obs.]</mark> <rj><au>Shiply.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daisied</ent><br/
<hw>Dai"sied</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Full of daisies;
adorned with daisies.</def> <ldquo/The <xex>daisied</xex> green.<rdquo/
<rj><au>Langhorne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The grass all deep and <qex>daisied</qex>.</q> <rj><qau>G.
Eliot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daisy</ent><br/
<hw>Dai"sy</hw> <pr>(d<amac/"z<ycr/)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Daisies</plw> <pr>(d<amac/"z<icr/z)</pr>.</plu>
<ety>[OE. <ets>dayesye</ets>, AS. <ets>d<ae/ges-e<aacute/ge</ets> day's
eye, daisy. See <er>Day</er>, and <er>Eye</er>.]</ety> <fld>(Bot.)</fld>
<sd>(a)</sd> <def>A genus of low herbs (<gen>Bellis</gen>), belonging to
the family <fam>Composit<ae/</fam>. The common English and classical
<ex>daisy</ex> is <spn>Bellis perennis</spn>, which has a yellow disk
and white or pinkish rays.</def> <sd>(b)</sd> <def>The whiteweed
(<spn>Chrysanthemum Leucanthemum</spn>), the plant commonly called
<ex>daisy</ex> in North America; -- called also <altname>oxeye
daisy</altname>. See <er>Whiteweed</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The word <xex>daisy</xex> is also used for composite
plants of other genera, as <gen>Erigeron</gen>, or fleabane.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Michaelmas daisy</b></col> <fld>(Bot.)</fld>, <cd>any
plant of the genus <gen>Aster</gen>, of which there are many
species.</cd> -- <col><b>Oxeye daisy</b></col> <fld>(Bot.)</fld>,
<cd>the whiteweed. See <er>Daisy</er> <sd>(b)</sd>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>daisy bush</ent><br/
<ent>daisybush</ent><br/
<mhw><hw>daisybush</hw>, <hw>daisy bush</hw></mhw> <pos>n.</pos>
<def>any of various mostly Australian attractively shaped shrubs of the
genus <gen>Olearia</gen> grown for their handsome and sometimes fragrant
evergreen foliage and profusion of daisy flowers with white or purple or
blue rays.</def><br/
<syn><b>Syn. --</b> .</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dak</ent><br/
<hw>Dak</hw> <pr>(d<add/k <it>or</it> d<aum/k)</pr>, <pos>n.</pos>
<ety>[Hind. <ets><dsdot/<amac/k</ets>.]</ety> <def>Post; mail; also, the
mail or postal arrangements; -- spelt also <asp>dawk</asp>, and
<asp>dauk</asp>.</def> <mark>[India]</mark><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dak boat</b></col>, <cd>a mail boat.</cd> <au>Percy
Smith.</au> -- <col><b>Dak bungalow</b></col>, <cd>a traveler's
rest-house at the end of a dak stage.</cd> -- <col><b>To travel by
dak</b></col>, <cd>to travel by relays of palanquins or other carriage,
as fast as the post along a road.</cd></cs></p>

<p><ent>Dakar</ent><br/
<hw>Dakar</hw> <pos>prop. n.</pos> <fld>(Geography)</fld> <def>The
capital <isa>city</isa> of <country>Senegal</country>. Population (2000)
= 1,729,823.</def><br/
[<source>PJC</source>]</p>

<p><ent>Dakir</ent><br/
<ent>Daker</ent><br/
<mhw>{ <hw>Da"ker</hw> <pr>(?)</pr>, <hw>Da"kir</hw> <pr>(?)</pr>,
}</mhw> <pos>n.</pos> <ety>[See <er>Dicker</er>.]</ety> <fld>(O. Eng. &
Scots Law)</fld> <def>A measure of certain commodities by number,
usually ten or twelve, but sometimes twenty; <as>as, a <ex>daker</ex> of
hides consisted of ten skins; a <ex>daker</ex> of gloves of ten
pairs.</as></def> <rj><au>Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daker hen</ent><br/
<hw>Da"ker hen`</hw> <pr>(?)</pr>. <ety>[<ets>Perh</ets>. <ets>fr</ets>.
W. <ets>crecial</ets> the daker hen; <ets>crec</ets> a sharp noise
(<ets>creg</ets> harsh, hoarse, <ets>crechian</ets> to scream) +
<ets>iar</ets> hen; or cf. D. <ets>duiken</ets> to dive, plunge.]</ety>
<fld>(Zool.)</fld> <def>The corncrake or land rail.</def></p>

<p><ent>Dakoity</ent><br/
<ent>Dakoit</ent><br/
<mhw><hw>Da*koit"</hw>, <pos>n.</pos>, <hw>Da*koit"y</hw>,
<pos>n.</pos></mhw> <def>See <er>Dacoit</er>,
<er>Dacoity</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dakota group</ent><br/
<hw>Da*ko"ta group`</hw> <pr>(?)</pr>. <fld>(Geol.)</fld> <def>A
subdivision at the base of the cretaceous formation in Western North
America; -- so named from the region where the strata were first
studied.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dakotas</ent><br/
<hw>Da*ko"tas</hw> <pr>(?)</pr>, <pos>n. pl</pos>.; <sing>sing.
<singw>Dacota</singw> <pr>(<?/)</pr></sing>. <fld>(Ethnol.)</fld>
<def>An extensive race or stock of Indians, including many tribes,
mostly dwelling west of the Mississippi River; -- also, in part, called
<altname>Sioux</altname>.</def> <altsp>[Written also
<asp>Dacotahs</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dal</ent><br/
\'d8<hw>Dal</hw> <pr>(d<aum/l)</pr>, <pos>n.</pos> <ety>[Hind.]</ety>
<def>Split pulse, esp. of <spn>Cajanus Indicus</spn>.</def> <mark>[East
Indies]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dalbergia</ent><br/
<hw>Dalbergia</hw> <pos>n.</pos> <def>a large genus of tropical trees
having pinnate leaves and paniculate flowers and cultivated commercially
for their dramatically grained and colored timbers.</def><br/
<syn><b>Syn. --</b> genus <gen>Dalbergia</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dale</ent><br/
<hw>Dale</hw> <pr>(d<amac/l)</pr>, <pos>n.</pos> <ety>[AS.
<ets>d<ae/l</ets>; akin to LG., D., Sw., Dan., OS., & Goth.
<ets>dal</ets>, Icel. <ets>dalr</ets>, OHG. <ets>tal</ets>, G.
<ets>thal</ets>, and perh. to Gr. <grk>qo`los</grk> a rotunda, Skr.
<ets>dh<amac/ra</ets> depth. Cf. <er>Dell</er>.]</ety> <sn>1.</sn>
<def>A low place between hills; a vale or valley.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Where mountaines rise, umbrageous <qex>dales</qex> descend.</q>
<rj><qau>Thomson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A trough or spout to carry off water, as from a
pump.</def> <rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dalea</ent><br/
<hw>Dalea</hw> <pos>n.</pos> <def>a genus of plants including the indigo
bush.</def><br/
<syn><b>Syn. --</b> genus <gen>Dalea</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dalesman</ent><br/
<hw>Dales"man</hw> <pr>(d<amac/lz"m<ait/n)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Dalesmen</plw>
<pr>(d<amac/lz"m<eit/n)</pr>.</plu> <def>One living in a dale; -- a term
applied particularly to the inhabitants of the valleys in the north of
England, Norway, etc.</def> <rj><au>Macaulay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>daleth</ent><br/
<hw>daleth</hw> <pr>(?)</pr>, <def>the fourth letter of the Hebrew
alphabet.</def><br/
[<source>PJC</source>]</p>

<p><ent>Dalf</ent><br/
<hw>Dalf</hw> <pr>(?)</pr>, <def><pos>imp.</pos> of
<er>Delve</er>.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dalles</ent><br/
<hw>Dalles</hw> <pr>(d<acr/lz)</pr>, <pos>n. pl.</pos> <ety>[F.
<ets>dalle</ets> a tube, gutter, trough.]</ety> <def>A rapid, esp. one
where the channel is narrowed between rock walls.</def>
<mark>[Northwestern U. S. & Canada]</mark></p>

<p><q>The place below, where the compressed river wound like a silver
thread among the flat black rocks, was the far-famed <qex>Dalles</qex>
of the Columbia.</q> <rj><qau>F. H. Balch.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Dalliance</ent><br/
<hw>Dal"li*ance</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<er>Dally</er>.]</ety> <sn>1.</sn> <def>The act of dallying, trifling,
or fondling; interchange of caresses; wanton play.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Look thou be true, do not give <qex>dalliance</qex><br/
Too much the rein.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>O, the <qex>dalliance</qex> and the wit,<br/
The flattery and the strife!</q> <rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Delay or procrastination.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Entertaining discourse.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 366 --></p>

<p><ent>Dallier</ent><br/
<hw>Dal"li*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who fondles; a
trifler; <as>as, <ex>dalliers</ex> with pleasant words</as>.</def>
<rj><au>Asham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>dallisgrass</ent><br/
<ent>dallis grass</ent><br/
<mhw><hw>dallis grass</hw>, <hw>dallisgrass</hw></mhw> <pos>n.</pos>
<def>a tall tufted perennial tropical American grass (<spn>Paspalum
dilatatum</spn>) naturalized as pasture and forage grass in the southern
U.S.</def><br/
<syn><b>Syn. --</b> paspalum, <spn>Paspalum dilatatum</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dallop</ent><br/
<hw>Dal"lop</hw> <pr>(d<acr/l"l<ocr/p)</pr>, <pos>n.</pos> <ety>[Etymol.
unknown.]</ety> <def>A tuft or clump.</def> <mark>[Obs.]</mark>
<rj><au>Tusser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dally</ent><br/
<hw>Dal"ly</hw> <pr>(d<acr/l"l<ycr/)</pr>, <pos>v. i.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Dallied</conjf>
<pr>(d<acr/l"l<icr/d)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Dallying</conjf>.]</vmorph> <ety>[OE. <ets>dalien</ets>,
<ets>dailien</ets>; cf. Icel. <ets>pylja</ets> to talk, G.
<ets>dallen</ets>, <ets>dalen</ets>, <ets>dahlen</ets>, to trifle, talk
nonsense, OSw. <ets>tule</ets> a droll or funny man; or AS.
<ets>dol</ets> foolish, E. <ets>dull</ets>.]</ety> <sn>1.</sn> <def>To
waste time in effeminate or voluptuous pleasures, or in idleness; to
fool away time; to delay unnecessarily; to tarry; to trifle.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We have trifled too long already; it is madness to
<qex>dally</qex> any longer.</q> <rj><qau>Calamy.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>We have put off God, and <qex>dallied</qex> with his grace.</q>
<rj><qau>Barrow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To interchange caresses, especially with one of the
opposite sex; to use fondling; to wanton; to sport.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Not <qex>dallying</qex> with a brace of courtesans.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Our aerie . . . <qex>dallies</qex> with the wind.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dally</ent><br/
<hw>Dal"ly</hw>, <pos>v. t.</pos> <def>To delay unnecessarily; to while
away.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Dallying</qex> off the time with often skirmishes.</q>
<rj><qau>Knolles.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dalmania</ent><br/
\'d8<hw>Dal*ma"ni*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<etsep>Dalman</etsep>, the geologist.]</ety> <fld>(Paleon.)</fld> <def>A
genus of trilobites, of many species, common in the Upper Silurian and
Devonian rocks.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dalmanites</ent><br/
\'d8<hw>Dal`ma*ni"tes</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Dalmania</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dalmatian</ent><br/
<hw>Dal*ma"tian</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining
to Dalmatia.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dalmatian dog</b></col> <fld>(Zool.)</fld>, <cd>a
carriage dog, shaped like a pointer, and having black or bluish spots on
a white ground; the coach dog.</cd></cs></p>

<p><ent>Dalmatic</ent><br/
<ent>Dalmatica</ent><br/
<mhw><hw>Dal*mat"i*ca</hw> <pr>(?)</pr>, <pos>n.</pos>,
<hw>Dal*mat"ic</hw> <pr>(<?/)</pr>, <pos>n.</pos></mhw> <ety>[LL.
<ets>dalmatica</ets>: cf. F. <ets>dalmatique</ets>.]</ety> <sn>1.</sn>
<fld>(R. C. Ch.)</fld> <def>A vestment with wide sleeves, and with two
stripes, worn at Mass by deacons, and by bishops at pontifical Mass; --
imitated from a dress originally worn in Dalmatia.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A robe worn on state occasions, as by English kings
at their coronation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>dalo</ent><br/
<hw>dalo</hw> <pos>n.</pos> <def>a herb of the Pacific islands
(<spn>Colocasia esculenta</spn>) grown throughout the tropics for its
edible root and in temperate areas as an ornamental for its large glossy
leaves.</def><br/
<syn><b>Syn. --</b> taro, taro plant, dasheen, <spn>Colocasia
esculenta</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dal segno</ent><br/
\'d8<hw>Dal` se"gno</hw> <pr>(?)</pr>. <ety>[It., from the sign.]</ety>
<fld>(Mus.)</fld> <def>A direction to go back to the sign <segno/ and
repeat from thence to the close. See <er>Segno</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dalton</ent><br/
<hw>Dalton</hw> <pos>n.</pos> <def><person>John Dalton</person>,
scientist, born 1766, died 1844.</def><br/
<syn><b>Syn. --</b> John Dalton.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>dalton</ent><br/
<hw>dalton</hw> <pos>n.</pos> <ety>[from the chemist <person>John
Dalton</person>, proponent of the modern atomic theory of matter.]</ety>
<def>a unit of mass, approximately 1.66 x 10<exp>-24</exp> grams; -- it
is approximately equal to the mass of one hydrogen atom, but the exact
value differs slightly as used in physics and chemistry. It is used
mostly to describe the size of proteins and nucleic acids in
biochemistry.</def> <note>Molecular weights are often expressed as
dimensionless units, the unit being understood (in chemistry) to be the
atomic mass unit with carbon equal to 14. Thus having a <ldquo/molecular
weight of 255<rdquo/ means the same as each molecule having a mass of
255 daltons.</note><br/
<syn><b>Syn.</b> atomic mass unit.</syn><br/
[<source>PJC</source>]</p>

<p><ent>Daltonian</ent><br/
<hw>Dal*to"ni*an</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One afflicted
with color blindness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daltonism</ent><br/
<hw>Dal"ton*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Inability to
perceive or distinguish certain colors, esp. red; color blindness. It
has various forms and degrees. So called from the chemist
<person>Dalton</person>, who had this infirmity.</def>
<rj><au>Nichol.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dam</ent><br/
<hw>Dam</hw> <pr>(d<acr/m)</pr>, <pos>n.</pos> <ety>[OE. <ets>dame</ets>
mistress, lady; also, mother, dam. See <er>Dame</er>.]</ety> <sn>1.</sn>
<def>A female parent; -- used of beasts, especially of quadrupeds;
sometimes applied in contempt to a human mother.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Our <qex>sire</qex> and <qex>dam</qex>, now confined to horses,
are a relic of this age (13th century) . . . .<qex>Dame</qex> is used of
a hen; we now make a great difference between <qex>dame</qex> and
<qex>dam</qex>.</q> <rj><qau>T. L. K. Oliphant.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>dam</qex> runs lowing up and down,<br/
Looking the way her harmless young one went.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A king or crowned piece in the game of
draughts.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dam</ent><br/
<hw>Dam</hw>, <pos>n.</pos> <ety>[Akin to OLG., D., & Dan.
<ets>dam</ets>, G. & Sw. <ets>damm</ets>, Icel. <ets>dammr</ets>, and
AS. <ets>fordemman</ets> to stop up, Goth.
<ets>Fa<uacute/rdammjan</ets>.]</ety> <sn>1.</sn> <def>A barrier to
prevent the flow of a liquid; esp., a bank of earth, or wall of any
kind, as of masonry or wood, built across a water course, to confine and
keep back flowing water.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Metal.)</fld> <def>A firebrick wall, or a stone,
which forms the front of the hearth of a blast furnace.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dam plate</b></col> <fld>(Blast Furnace)</fld>, <cd>an
iron plate in front of the dam, to strengthen it.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dam</ent><br/
<hw>Dam</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Dammed</conjf> <pr>(d<acr/md)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Damming</conjf>.]</vmorph> <sn>1.</sn> <def>To obstruct or
restrain the flow of, by a dam; to confine by constructing a dam, as a
stream of water; -- generally used with <ptcl>in</ptcl> or
<ptcl>up</ptcl>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I'll have the current in this place <qex>dammed</qex> up.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A weight of earth that <qex>dams</qex> in the water.</q>
<rj><qau>Mortimer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To shut up; to stop up; to close; to
restrain.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The strait pass was <qex>dammed</qex><br/
With dead men hurt behind, and cowards.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To dam out</b></col>, <cd>to keep out by means of a
dam.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dama</ent><br/
<hw>Dama</hw> <pos>n.</pos> <def>a genus of deer including the Eurasian
fallow deer, <spn>Dama dama</spn>.</def><br/
<syn><b>Syn. --</b> genus <gen>Dama</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Damage</ent><br/
<hw>Dam"age</hw> <pr>(d<acr/m"<asl/j; 48)</pr>, <pos>n.</pos> <ety>[OF.
<ets>damage</ets>, <ets>domage</ets>, F. <ets>dommage</ets>, fr. assumed
LL. <ets>damnaticum</ets>, from L. <ets>damnum</ets> damage. See
<er>Damn</er>.]</ety> <sn>1.</sn> <def>Injury or harm to person,
property, or reputation; an inflicted loss of value; detriment; hurt;
mischief.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He that sendeth a message by the hand of a fool cutteth off the
feet and drinketh <qex>damage</qex>.</q> <rj><qau>Prov. xxvi.
6.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Great errors and absurdities many commit for want of a friend to
tell them of them, to the great <qex>damage</qex> both of their fame and
fortune.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <pluf>pl.</pluf> <fld>(Law)</fld> <def>The estimated
reparation in money for detriment or injury sustained; a compensation,
recompense, or satisfaction to one party, for a wrong or injury actually
done to him by another.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In common-law actions, the jury are the proper judges of
damages.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Consequential damage</b></col>. <cd>See under
<er>Consequential</er>.</cd> -- <col><b>Exemplary damages</b></col>
<fld>(Law)</fld>, <cd>damages imposed by way of example to others.
Similar in purpose to <cref>vindictive damages</cref>, below.</cd> --
<col><b>Nominal damages</b></col> <fld>(Law)</fld>, <cd>those given for
a violation of a right where no actual loss has accrued.</cd> --
<mcol><col><b>vindictive damages</b></col> <it>or</it> <col><b>punitive
damages</b></col></mcol>, <cd>those given specially for the punishment
of the wrongdoer.</cd></cs></p>

<p><syn><b>Syn.</b> -- Mischief; injury; harm; hurt; detriment; evil;
ill. See <er>Mischief</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Damage</ent><br/
<hw>Dam"age</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Damaged</conjf> <pr>(d<acr/m"<asl/jd)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Damaging</conjf>
<pr>(d<acr/m"<asl/*j<icr/ng)</pr>.]</vmorph> <ety>[Cf. OF.
<ets>damagier</ets>, <ets>domagier</ets>. See <er>Damage</er>,
<pos>n.</pos>]</ety> <def>To occasion damage to the soundness, goodness,
or value of; to hurt; to injure; to impair.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He . . . came up to the English admiral and gave him a broadside,
with which he killed many of his men and <qex>damaged</qex> the
ship.</q> <rj><qau>Clarendon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Damage</ent><br/
<hw>Dam"age</hw> <pr>(d<acr/m"<asl/j)</pr>, <pos>v. i.</pos> <def>To
receive damage or harm; to be injured or impaired in soundness or value;
<as>as, some colors in cloth <ex>damage</ex> in sunlight</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Damageable</ent><br/
<hw>Dam"age*a*ble</hw> <pr>(d<acr/m"<asl/j*<adot/*b'l)</pr>,
<pos>a.</pos> <ety>[Cf. OF. <ets>damageable</ets>, F.
<ets>dommageable</ets> for sense 2.]</ety> <sn>1.</sn> <def>Capable of
being injured or impaired; liable to, or susceptible of, damage; <as>as,
a <ex>damageable</ex> cargo</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hurtful; pernicious.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>That it be not <qex>damageable</qex> unto your royal majesty.</q>
<rj><qau>Hakluyt.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>damaged</ent><br/
<hw>damaged</hw> <pr>(d<acr/m"<asl/jd)</pr>, <pos>adj.</pos> <sn>1.</sn>
<def>changed so as to reduce value, function, or other desirable trait;
-- usually not used of persons. Opposite of <ant>undamaged</ant>.</def>
[Narrower terms: <stype>battered, beat-up, beaten-up, bedraggled,
broken-down, dilapidated, ramshackle, tumble-down, unsound</stype>;
<stype>bent, crumpled, dented</stype>; <stype>blasted, rent, ripped,
torn</stype>; <stype>broken-backed</stype>;
<stype>burned-out(prenominal), burned out(predicate),
burnt-out(prenominal), burnt out(predicate)</stype>; <stype>burst,
ruptured</stype>; <stype>corroded</stype>; <stype>cracked, crackled,
crazed</stype>; <stype>defaced, marred</stype>; <stype>hurt,
weakened</stype>; <stype>knocked-out(prenominal), knocked out</stype>;
<stype>mangled, mutilated</stype>; <stype>peeling</stype>;
<stype>scraped, scratched</stype>; <stype>storm-beaten</stype>]
<see>Also See <er>blemished</er>, <er>broken</er>, <er>damaged</er>,
<er>destroyed</er>, <er>impaired</er>, <er>injured</er>,
<er>unsound</er>.</see><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>Rendered imperfect by impairing the integrity of
some part, or by breaking. Opposite of <ant>unbroken</ant>.</def>
[Narrower terms: <stype>busted</stype>; <stype>chipped</stype>;
<stype>cracked</stype>; <stype>crumbled, fragmented</stype>;
<stype>crushed, ground</stype>; <stype>dissolved</stype>;
<stype>fractured</stype>; <stype>shattered, smashed, splintered</stype>;
<stype>split</stype>; <stype>unkept, violated</stype>] <see>Also See:
<er>damaged</er>, <er>imperfect</er>, <er>injured</er>,
<er>unsound</er>.</see><br/
<syn><b>Syn. --</b> broken.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>3.</sn> <def>being unjustly brought into disrepute; <as>as, her
<ex>damaged</ex> reputation</as>.</def><br/
<syn><b>Syn. --</b> discredited.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>4.</sn> <def>made to appear imperfect; -- especially of
reputation; <as>as, the senator's seriously <ex>damaged</ex>
reputation</as>.</def><br/
<syn><b>Syn. --</b> besmirched, flyblown, spotted, stained, sullied,
tainted, tarnished.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Damage feasant</ent><br/
<hw>Dam"age fea`sant</hw> <pr>(?)</pr>. <ety>[OF. <ets>damage</ets> + F.
<ets>faisant</ets> doing, p. pr. See <er>Feasible</er>.]</ety>
<fld>(Law)</fld> <def>Doing injury; trespassing, as cattle.</def>
<rj><au>Blackstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>damages</ent><br/
<hw>damages</hw> <pos>n.</pos> <fld>(Law)</fld> <def>a sum of money paid
in compensation for an injury or wrong.</def><br/
<syn><b>Syn. --</b> amends, indemnity, indemnification, restitution,
redress.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>damaging</ent><br/
<hw>damaging</hw> <pos>adj.</pos> <sn>1.</sn> <def>causing harm or
injury; <as>as, <ex>damaging</ex> to career and
reputation</as>.</def><br/
<syn><b>Syn. --</b> detrimental, detrimental to(predicate), prejudicial,
prejudicious.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>designed or tending to discredit, especially without
positive or helpful suggestions.</def><br/
<syn><b>Syn. --</b> negative.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Damaliscus</ent><br/
<hw>Damaliscus</hw> <pos>n.</pos> <def>a genus of African antelopes
including the sassaby, <spn>Damaliscus lunatus</spn>.</def><br/
<syn><b>Syn. --</b> genus <gen>Damaliscus</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Daman</ent><br/
<hw>Da"man</hw> <pr>(d<aum/"m<adot/n)</pr>, <pos>n.</pos>
<fld>(Zool.)</fld> <def>A small herbivorous mammal of the genus
<gen>Hyrax</gen>. The species found in Palestine and Syria is <spn>Hyrax
Syriacus</spn>; that of Northern Africa is <spn>Hyrax Brucei</spn>; --
called also <altname>ashkoko</altname>, <altname>dassy</altname>, and
<altname>rock rabbit</altname>. See <er>Cony</er>, and
<er>Hyrax</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Damar</ent><br/
<hw>Dam"ar</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Dammar</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Damara</ent><br/
<hw>Da*ma"ra</hw> <pr>(d<aum/*m<aum/"r<aum/)</pr>, <pos>n.</pos>
<ety>[The name is supposed to be from Hottentot <ets>dama</ets>
vanquished.]</ety> <def>A native of Damaraland, German Southwest Africa.
The Damaras include an important and warlike Bantu tribe, and the
<ecol><b>Hill Damaras</b></ecol>, who are Hottentots and mixed breeds
hostile to the Bantus.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Damascene</ent><br/
<hw>Dam"as*cene</hw> <pr>(d<acr/m"<ait/s*s<emac/n)</pr>, <pos>a.</pos>
<ety>[L. <ets>Damascenus</ets> of Damascus, fr. <etsep>Damascus</etsep>
the city, Gr. <grk>Damasko`s</grk>. See <er>Damask</er>, and cf.
<er>Damaskeen</er>, <er>Damaskin</er>, <er>Damson</er>.]</ety> <def>Of
or relating to Damascus.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Damascene</ent><br/
<hw>Dam"as*cene</hw> <pr>(d<acr/m"<ait/s*s<emac/n)</pr>, <pos>n.</pos>
<def>A kind of plum, now called <altname>damson</altname>. See
<er>Damson</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Damascene</ent><br/
<hw>Dam`as*cene"</hw> <pr>(d<acr/m`<ait/s*s<emac/n")</pr>, <pos>v.
t.</pos> <def>Same as <er>Damask</er>, or <er>Damaskeen</er>, <pos>v.
t.</pos></def> <ldquo/<xex>Damascened</xex> armor.<rdquo/
<au>Beaconsfield.</au> <ldquo/Cast and <xex>damascened</xex>
steel.<rdquo/ <au>Ure.</au><br/
[<source>1913 Webster</source>]</p>

<p><ent>damascened</ent><br/
<hw>damascened</hw> <pos>adj.</pos> <def>decorated or inlaid with a wavy
pattern of different (especially precious) metals; -- of metallic
objects; <as>as, a <ex>damascened</ex> sword</as>.</def><br/
<syn><b>Syn. --</b> damascene.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Damascus</ent><br/
<hw>Damascus</hw> <pos>prop. n.</pos> <fld>(Geography)</fld> <def>The
capital <isa>city</isa> of <country>Syria</country>. Population (2000) =
1,549,932.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Damascus blade</b></col>, <cd>a sword or scimiter, made
chiefly at <city>Damascus</city>, having a variegated appearance of
watering, and proverbial for excellence.</cd> -- <mcol><col><b>Damascus
iron</b></col>, <it>or</it> <col><b>Damascus twist</b></col></mcol>,
<cd>metal formed of thin bars or wires of iron and steel elaborately
twisted and welded together; used for making gun barrels, etc., of high
quality, in which the surface, when polished and acted upon by acid, has
a damask appearance.</cd> -- <col><b>Damascus steel</b></col>. <cd>See
<cref>Damask steel</cref>, under <er>Damask</er>,
<pos>a.</pos></cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Damascus steel</ent><br/
<hw>Da*mas"cus steel</hw>. <def>See <cref>Damask steel</cref>, under
<er>Damask</er>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Damask</ent><br/
<hw>Dam"ask</hw> <pr>(d<acr/m"<ait/sk)</pr>, <pos>n.</pos> <ety>[From
the city <etsep>Damascus</etsep>, L. <ets>Damascus</ets>, Gr.
<grk>Damasko`s</grk>, Heb. <ets>Dammesq</ets>, Ar. <ets>Daemeshq</ets>;
cf. Heb. <ets>d'meseq</ets> damask; cf. It. <ets>damasco</ets>, Sp.
<ets>damasco</ets>, F. <ets>damas</ets>. Cf. <er>Damascene</er>,
<er>Damass<eacute/</er>.]</ety> <sn>1.</sn> <def>Damask silk; silk woven
with an elaborate pattern of flowers and the like.</def> <ldquo/A bed of
ancient <xex>damask</xex>.<rdquo/ <rj><au>W. Irving.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Linen so woven that a pattern in produced by the
different directions of the thread, without contrast of color.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A heavy woolen or worsted stuff with a pattern woven
in the same way as the linen damask; -- made for furniture covering and
hangings.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Damask or Damascus steel; also, the peculiar
markings or <ldquo/water<rdquo/ of such steel.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A deep pink or rose color.</def>
<rj><au>Fairfax.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Damask</ent><br/
<hw>Dam"ask</hw>, <pos>a.</pos> <sn>1.</sn> <def>Pertaining to, or
originating at, the city of <city>Damascus</city>; resembling the
products or manufactures of <city>Damascus</city>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Having the color of the damask rose.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>But let concealment, like a worm i' the bud,<br/
Feed on her <qex>damask</qex> cheek.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Damask color</b></col>, <cd>a deep rose-color like that
of the damask rose.</cd> -- <col><b>Damask plum</b></col>, <cd>a small
dark-colored plum, generally called <altname>damson</altname>.</cd> --
<col><b>Damask rose</b></col> <fld>(Bot.)</fld>, <cd>a large, pink,
hardy, and very fragrant variety of rose (<spn>Rosa damascena</spn>)
from Damascus.</cd> <ldquo/<xex>Damask roses</xex> have not been known
in England above one hundred years.<rdquo/ <au>Bacon.</au> --
<mcol><col><b>Damask steel</b></col>, <it>or</it> <col><b>Damascus
steel</b></col></mcol>, <cd>steel of the kind originally made at
Damascus, famous for its hardness, and its beautiful texture, ornamented
with waving lines; especially, that which is inlaid with damaskeening;
-- formerly much valued for sword blades, from its great flexibility and
tenacity.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Damask</ent><br/
<hw>Dam"ask</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Damasked</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Damasking</conjf>.]</vmorph> <def>To decorate in a way peculiar
to Damascus or attributed to Damascus; particularly: <sd>(a)</sd> with
flowers and rich designs, as silk; <sd>(b)</sd> with inlaid lines of
gold, etc., or with a peculiar marking or <ldquo/water,<rdquo/ as metal.
See <er>Damaskeen</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Mingled metal <qex>damasked</qex> o'er with gold.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>On the soft, downy bank, <qex>damasked</qex> with flowers.</q>
<rj><qau>Milton.</qau></rj></p>

<p><ent>Damasken</ent><br/
<ent>Damaskeen</ent><br/
<mhw>{ <hw>Dam"as*keen`</hw> <pr>(?)</pr>, <hw>Dam"as*ken</hw>
<pr>(?)</pr>, }</mhw> <pos>v. t.</pos> <ety>[F. <ets>damaschinare</ets>.
See <er>Damascene</er>, <pos>v.</pos>]</ety> <def>To decorate, as iron,
steel, etc., with a peculiar marking or <ldquo/water<rdquo/ produced in
the process of manufacture, or with designs produced by inlaying or
incrusting with another metal, as silver or gold, or by etching, etc.,
to damask.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Damaskeening</qex> is is partly mosaic work, partly
engraving, and partly carving.</q> <rj><qau>Ure.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Damaskin</ent><br/
<hw>Dam"as*kin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>damasquin</ets>, adj., It. <ets>damaschino</ets>, Sp.
<ets>damasquino</ets>. See <er>Damaskeen</er>.]</ety> <def>A sword of
Damask steel.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>No old Toledo blades or <qex>damaskins</qex>.</q> <rj><qau>Howell
(1641).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Damasse</ent><br/
<hw>Da*mas*s<eacute/"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F.
<ets>damass<eacute/</ets>, fr. <ets>damas</ets>. See
<er>Damask</er>.]</ety> <def>Woven like damask.</def> --
<def2><pos>n.</pos> <def>A damass<eacute/ fabric, esp. one of
linen.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Damassin</ent><br/
<hw>Dam"as*sin</hw> <pr>(d<acr/m"<ait/s*s<icr/n)</pr>, <pos>n.</pos>
<ety>[F., fr. <ets>damas</ets>. See <er>Damask</er>.]</ety> <def>A kind
of modified damask or brocade.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dambonite</ent><br/
<hw>Dam"bo*nite</hw> <pr>(-b<osl/*n<imac/t)</pr>, <pos>n.</pos>
<ety>[Cf. F. <ets>dambonite</ets>.]</ety> <fld>(Chem.)</fld> <def>A
white, crystalline, sugary substance obtained from an African
caoutchouc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dambose</ent><br/
<hw>Dam"bose</hw> <pr>(d<acr/m"b<omac/s)</pr>, <pos>n.</pos>
<fld>(Chem.)</fld> <def>A crystalline variety of fruit sugar obtained
from dambonite.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dame</ent><br/
<hw>Dame</hw> <pr>(d<amac/m)</pr>, <pos>n.</pos> <ety>[F.
<ets>dame</ets>, LL. <ets>domna</ets>, fr. L. <ets>domina</ets>
mistress, lady, fem. of <ets>dominus</ets> master, ruler, lord; akin to
<ets>domare</ets> to tame, subdue. See <er>Tame</er>, and cf.
<er>Dam</er> a mother, <er>Dan</er>, <er>Danger</er>, <er>Dungeon</er>,
<er>Dominie</er>, <er>Don</er>, <pos>n.</pos>, <er>Duenna</er>.]</ety>
<sn>1.</sn> <def>A mistress of a family, who is a lady; a woman in
authority; especially, a lady.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Then shall these lords do vex me half so much,<br/
As that proud <qex>dame</qex>, the lord protector's wife.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The mistress of a family in common life, or the
mistress of a common school; <as>as, a <ex>dame's</ex>
school</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In the <qex>dame's</qex> classes at the village school.</q>
<rj><au>Emerson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A woman in general, esp. an elderly woman.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A mother; -- applied to human beings and
quadrupeds.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Damewort</ent><br/
<hw>Dame"wort`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>A
cruciferous plant (<spn>Hesperis matronalis</spn>), remarkable for its
fragrance, especially toward the close of the day; -- called also
<altname>rocket</altname> and <altname>dame's violet</altname>.</def>
<rj><au>Loudon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Damiana</ent><br/
<hw>Da`mi*a"na</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL.; of uncertain
origin.]</ety> <fld>(Med.)</fld> <def>A Mexican drug, used as an
aphrodisiac.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ There are several varieties derived from different
plants, esp. from a species of <gen>Turnera</gen> and from
<spn>Bigelovia veneta</spn>. <rj><au>Wood & Bache.</au></rj> </note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Damianist</ent><br/
<hw>Da"mi*an*ist</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Eccl.
Hist.)</fld> <def>A follower of Damian, patriarch of Alexandria in the
6th century, who held heretical opinions on the doctrine of the Holy
Trinity.</def></p>

<p><ent>Dammara</ent><br/
<ent>Dammar</ent><br/
<mhw>{ <hw>Dam"mar</hw> <pr>(?)</pr>, <hw>Dam"ma*ra</hw> <pr>(?)</pr>,
}</mhw> <pos>n.</pos> <ety>[Jav. & Malay. <ets>damar</ets>.]</ety>
<def>An oleoresin used in making varnishes; dammar gum; dammara resin.
It is obtained from certain resin trees indigenous to the East Indies,
esp. <spn>Shorea robusta</spn> and the dammar pine.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dammar pine</b></col>, <fld>(Bot.)</fld>, <cd>a tree of
the Moluccas (<spn>Agathis orientalis</spn> syn. <spn>Dammara
orientalis</spn>), yielding dammar.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dammara</ent><br/
<hw>Dam"ma*ra</hw>, <pos>n.</pos> <fld>(Bot.)</fld> <def>A large tree of
the order <ord>Conifer<ae/</ord>, indigenous to the East Indies and
Australasia; -- called also <altname>Agathis</altname>. There are
several species.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Damn</ent><br/
<hw>Damn</hw> <pr>(d<acr/m)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Damned</conjf> <pr>(d<acr/md <it>or</it>
d<acr/m"n<ecr/d)</pr>; <pos>p. pr. & vb. n.</pos> <conjf>Damning</conjf>
<pr>(d<acr/m"<icr/ng <it>or</it> d<acr/m"n<icr/ng)</pr>.]</vmorph>
<ety>[OE. <ets>damnen</ets> dampnen (with excrescent <it>p</it>), OF.
<ets>damner</ets>, <ets>dampner</ets>, F. <ets>damner</ets>, fr. L.
<ets>damnare</ets>, <ets>damnatum</ets>, to condemn, fr.
<ets>damnum</ets> damage, a fine, penalty. Cf. <er>Condemn</er>,
<er>Damage</er>.]</ety> <sn>1.</sn> <def>To condemn; to declare guilty;
to doom; to adjudge to punishment; to sentence; to censure.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He shall not live; look, with a spot I <qex>damn</qex> him.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Theol.)</fld> <def>To doom to punishment in the
future world; to consign to perdition; to curse.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To condemn as bad or displeasing, by open
expression, as by denunciation, hissing, hooting, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>You are not so arrant a critic as to <qex>damn</qex> them [the
works of modern poets] . . . without hearing.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Damn</qex> with faint praise, assent with civil leer,<br/
And without sneering teach the rest to sneer.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Damn</xex> is sometimes used interjectionally,
imperatively, and intensively.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Damn</ent><br/
<hw>Damn</hw>, <pos>v. i.</pos> <def>To invoke damnation; to
curse.</def> <ldquo/While I inwardly <xex>damn</xex>.<rdquo/
<rj><au>Goldsmith.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Damnability</ent><br/
<hw>Dam`na*bil"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The quality of
being damnable; damnableness.</def> <rj><au>Sir T. More.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Damnable</ent><br/
<hw>Dam"na*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>damnabilis</ets>, fr. <ets>damnare</ets>: cf. F.
<ets>damnable</ets>. See <er>Damn</er>.]</ety> <sn>1.</sn> <def>Liable
to damnation; deserving, or for which one deserves, to be damned; of a
damning nature.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A creature unprepared unmeet for death,<br/
And to transport him in the mind he is,<br/
Were <qex>damnable</qex>.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Odious; pernicious; detestable.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Begin, murderer; . . . leave thy <qex>damnable</qex> faces.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Damnableness</ent><br/
<hw>Dam"na*ble*ness</hw>, <pos>n.</pos> <def>The state or quality of
deserving damnation; execrableness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>damnableness</qex> of this most execrable impiety.</q>
<rj><qau>Prynne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Damnably</ent><br/
<hw>Dam"na*bly</hw>, <pos>adv.</pos> <sn>1.</sn> <def>In a manner to
incur severe censure, condemnation, or punishment.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Odiously; detestably; excessively.</def>
<mark>[Low]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Damnation</ent><br/
<hw>Dam*na"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>damnation</ets>, L. <ets>damnatio</ets>, fr. <ets>damnare</ets>.
See <er>Damn</er>.]</ety> <sn>1.</sn> <def>The state of being damned;
condemnation; openly expressed disapprobation.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Theol.)</fld> <def>Condemnation to everlasting
punishment in the future state, or the punishment itself.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>How can ye escape the <qex>damnation</qex> of hell?</q>
<rj><qau>Matt. xxiii. 33.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Wickedness is sin, and sin is <qex>damnation</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A sin deserving of everlasting punishment.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The deep <qex>damnation</qex> of his taking-off.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Damnatory</ent><br/
<hw>Dam"na*to*ry</hw> <pr>(d<acr/m"n<adot/*t<osl/*r<ycr/)</pr>,
<pos>a.</pos> <ety>[L. <ets>damnatorius</ets>, fr. <ets>damnator</ets> a
condemner.]</ety> <def>Dooming to damnation; condemnatory.</def>
<ldquo/<xex>Damnatory</xex> invectives.<rdquo/
<rj><au>Hallam.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Damned</ent><br/
<hw>Damned</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Sentenced
to punishment in a future state; condemned; consigned to
perdition.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hateful; detestable; abominable.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>But, O, what <qex>damned</qex> minutes tells he o'er<br/
Who doats, yet doubts, suspects, yet strongly loves.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Damnific</ent><br/
<hw>Dam*nif"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>damnificus</ets>; <ets>damnum</ets> damage, loss +
<ets>facere</ets> to make. See <er>Damn</er>.]</ety> <def>Procuring or
causing loss; mischievous; injurious.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Damnification</ent><br/
<hw>Dam`ni*fi*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL.
<ets>damnificatio</ets>.]</ety> <def>That which causes damage or
loss.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Damnify</ent><br/
<hw>Dam"ni*fy</hw> <pr>(d<acr/m"n<icr/*f<imac/)</pr>, <pos>v. t.</pos>
<ety>[LL. <ets>damnificare</ets>, fr. L. <ets>damnificus</ets>: cf. OF.
<ets>damnefier</ets>. See <er>Damnific</er>.]</ety> <def>To cause loss
or damage to; to injure; to impair.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>This work will ask as many more officials to make expurgations and
expunctions, that the commonwealth of learning be not
<qex>damnified</qex>.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Damning</ent><br/
<hw>Damn"ing</hw> <pr>(?)</pr>, <pos>a.</pos> <def>That damns; damnable;
<as>as, damning evidence of guilt</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Damningness</ent><br/
<hw>Damn"ing*ness</hw>, <pos>n.</pos> <def>Tendency to bring
damnation.</def> <ldquo/The damningness of them [sins].<rdquo/
<rj><au>Hammond.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>damnum</ent><br/
\'d8<hw>dam"num</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.]</ety>
<fld>(law)</fld> <def>Harm; detriment, either to character or
property.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 367 --></p>

<p><ent>Damoiselle</ent><br/
<ent>Damosella</ent><br/
<ent>Damosel</ent><br/
<mhw>{ <hw>Dam"o*sel</hw> <pr>(d<acr/m"<osl/*z<ecr/l)</pr>,
<hw>Dam`o*sel"la</hw> <pr>(-z<ecr/l"l<adot/)</pr>,
\'d8<hw>Da`moi`selle"</hw> <pr>(d<adot/`mw<aum/`z<ecr/l")</pr> }</mhw>,
<pos>n.</pos> <def>See <er>Damsel</er>.</def> <mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Damourite</ent><br/
<hw>Dam"our*ite</hw> <pr>(d<acr/m"<oocr/*<imac/t)</pr>, <pos>n.</pos>
<ety>[Ater the French chemist <etsep>Damour</etsep>.]</ety>
<fld>(Min.)</fld> <def>A kind of Muscovite, or potash mica, containing
water.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Damp</ent><br/
<hw>Damp</hw> <pr>(d<acr/mp)</pr>, <pos>n.</pos> <ety>[Akin to LG., D.,
& Dan. <ets>damp</ets> vapor, steam, fog, G. <ets>dampf</ets>, Icel.
<ets>dampi</ets>, Sw. <ets>damb</ets> dust, and to MNG.
<ets>dimpfen</ets> to smoke, imp. <ets>dampf</ets>.]</ety> <sn>1.</sn>
<def>Moisture; humidity; fog; fogginess; vapor.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Night . . . with black air<br/
Accompanied, with <qex>damps</qex> and dreadful gloom.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Dejection; depression; cloud of the mind.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Even now, while thus I stand blest in thy presence,<br/
A secret <qex>damp</qex> of grief comes o'er my soul.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>It must have thrown a <qex>damp</qex> over your autumn
excursion.</q> <rj><qau>J. D. Forbes.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Mining)</fld> <def>A gaseous product, formed in
coal mines, old wells, pints, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Choke damp</b></col>, <cd>a damp consisting principally
of carbonic acid gas; -- so called from its extinguishing flame and
animal life. See <cref>Carbonic acid</cref>, under
<er>Carbonic</er>.</cd> -- <col><b>Damp sheet</b></col>, <cd>a curtain
in a mine gallery to direct air currents and prevent accumulation of
gas.</cd> -- <col><b>Fire damp</b></col>, <cd>a damp consisting chiefly
of light carbureted hydrogen; -- so called from its tendence to explode
when mixed with atmospheric air and brought into contact with
flame.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Damp</ent><br/
<hw>Damp</hw> <pr>(d<acr/mp)</pr>, <pos>a.</pos>
<amorph>[<pos>Compar.</pos> <adjf>Damper</adjf> <pr>(?)</pr>;
<pos>superl.</pos> <adjf>Dampest</adjf>.]</amorph> <sn>1.</sn>
<def>Being in a state between dry and wet; moderately wet; moist;
humid.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>O'erspread with a <qex>damp</qex> sweat and holy fear.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Dejected; depressed; sunk.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>All these and more came flocking, but with looks<br/
Downcast and <qex>damp</qex>.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Damp</ent><br/
<hw>Damp</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Damped</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Damping</conjf>.]</vmorph> <ety>[OE. <ets>dampen</ets> to choke,
suffocate. See <er>Damp</er>, <pos>n.</pos>]</ety> <sn>1.</sn> <def>To
render damp; to moisten; to make humid, or moderately wet; to dampen;
<as>as, to <ex>damp</ex> cloth</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To put out, as fire; to depress or deject; to
deaden; to cloud; to check or restrain, as action or vigor; to make
dull; to weaken; to discourage.</def> <ldquo/To <xex>damp</xex> your
tender hopes.<rdquo/ <rj><au>Akenside.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Usury dulls and <qex>damps</qex> all industries, improvements, and
new inventions, wherein money would be stirring if it were not for this
slug.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>How many a day has been <qex>damped</qex> and darkened by an angry
word!</q> <rj><qau>Sir J. Lubbock.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The failure of his enterprise <qex>damped</qex> the spirit of the
soldiers.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dampen</ent><br/
<hw>Damp"en</hw> <pr>(d<acr/mp"'n)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>dampened</conjf>
<pr>(d<acr/mp"'nd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>dampening</conjf>.]</vmorph> <sn>1.</sn> <def>To make damp or
moist; to make slightly wet.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To depress; to check; to make dull; to
lessen.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In a way that considerably <qex>dampened</qex> our enthusiasm.</q>
<rj><qau>The Century.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dampen</ent><br/
<hw>Damp"en</hw>, <pos>v. i.</pos> <def>To become damp; to deaden.</def>
<rj><au>Byron.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>dampening</ent><br/
<hw>dampening</hw> <pos>n.</pos> <def>the act or process of making
something slightly wet.</def><br/
<syn><b>Syn. --</b> moistening.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>damper</ent><br/
<hw>damp"er</hw> <pr>(d<acr/m"p<etil/r)</pr>, <pos>n.</pos> <def>That
which damps or checks;</def> <specif>as:</specif> <sd>(a)</sd> <def>A
valve or movable plate in the flue or other part of a stove, furnace,
etc., used to check or regulate the draught of air.</def> <sd>(b)</sd>
<def>A contrivance, as in a pianoforte, to deaden vibrations; or, as in
other pieces of mechanism, to check some action at a particular
time.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Nor did Sabrina's presence seem to act as any <qex>damper</qex> at
the modest little festivities.</q> <rj><qau>W. Black.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dampish</ent><br/
<hw>Damp"ish</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Moderately damp or
moist.</def></p>

<p>-- <wordforms><wf>Damp"ish*ly</wf>, <pos>adv.</pos> --
<wf>Damp"ish*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dampne</ent><br/
<hw>Damp"ne</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To damn.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dampness</ent><br/
<hw>Damp"ness</hw>, <pos>n.</pos> <def>Moderate humidity; moisture;
fogginess; moistness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Damp off</ent><br/
<hw>Damp" off`</hw> <pr>(?)</pr>. <def>To decay and perish through
excessive moisture.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dampy</ent><br/
<hw>Damp"y</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Somewhat
damp.</def> <mark>[Obs.]</mark> <rj><au>Drayton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Dejected; gloomy; sorrowful.</def>
<mark>[Obs.]</mark> <ldquo/Dispel <xex>dampy</xex> throughts.<rdquo/
<rj><au>Haywards.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Damsel</ent><br/
<hw>Dam"sel</hw> <pr>(d<acr/m"z<ecr/l)</pr>, <pos>n.</pos> <ety>[OE.
<ets>damosel</ets>, <ets>damesel</ets>, <ets>damisel</ets>, damsel, fr.
OF. <ets>damoisele</ets>, <ets>damisele</ets>, gentlewoman, F.
<ets>demoiselle</ets> young lady; cf. OF. <ets>damoisel</ets> young
nobleman, F. <ets>damoiseau</ets>; fr. LL. <ets>domicella</ets>,
<ets>dominicella</ets>, fem., <ets>domicellus</ets>,
<ets>dominicellus</ets>, masc., dim. fr. L. <ets>domina</ets>,
<ets>dominus</ets>. See <er>Dame</er>, and cf. <er>Demoiselle</er>,
<er>Doncella</er>.]</ety> <sn>1.</sn> <def>A young person, either male
or female, of noble or gentle extraction; <as>as, <ex>Damsel</ex> Pepin;
<ex>Damsel</ex> Richard, Prince of Wales.</as></def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A young unmarried woman; a girl; a maiden.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With her train of <qex>damsels</qex> she was gone,<br/
In shady walks the scorching heat to shun.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Sometimes a troop of <qex>damsels</qex> glad, . . . <br/
Goes by to towered Camelot.</q> <rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Milling)</fld> <def>An attachment to a millstone
spindle for shaking the hopper.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>damselfish</ent><br/
<hw>damselfish</hw> <pos>n.</pos> <def>small brilliantly colored
tropical marine fishes of coral reefs.</def><br/
<syn><b>Syn. --</b> demoiselle.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>damselfly</ent><br/
<hw>damselfly</hw> <pos>n.</pos> <def>a slender nonstinging insect
similar to but smaller than the dragonfly but having wings folded when
at rest.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Damson</ent><br/
<hw>Dam"son</hw> <pr>(d<acr/m"z'n)</pr>, <pos>n.</pos> <ety>[OE.
<ets>damasin</ets> the Damascus plum, fr. L. Damascenus. See
<er>Damascene</er>.]</ety> <def>A small oval plum of a blue color, the
fruit of a variety of the <spn>Prunus domestica</spn>; -- called also
<altname>damask plum</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dan</ent><br/
<hw>Dan</hw> <pr>(d<acr/n)</pr>, <pos>n.</pos> <ety>[OE. <ets>dan</ets>,
<ets>danz</ets>, OF. <ets>danz</ets> (prop. only nom.), <ets>dan</ets>,
master, fr. L. <ets>dominus</ets>. See <er>Dame</er>.]</ety> <def>A
title of honor equivalent to <xex>master</xex>, or <xex>sir</xex>.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Old <qex>Dan</qex> Geoffry, in gently spright<br/
The pure wellhead of poetry did dwell.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>What time <qex>Dan</qex> Abraham left the Chaldee land.</q>
<rj><qau>Thomson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dan</ent><br/
<hw>Dan</hw>, <pos>n.</pos> <ety>[Etymol. uncertain.]</ety>
<fld>(Mining)</fld> <def>A small truck or sledge used in coal
mines.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Danaidae</ent><br/
<hw>Danaidae</hw> <pos>n.</pos> <def>a small natural family of usually
tropical butterflies, including the monarch butterflies.</def><br/
<syn><b>Syn. --</b> family <fam>Danaidae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Danaide</ent><br/
<hw>Da"na*ide</hw> <pr>(d<amac/"n<adot/*<imac/d)</pr>, <pos>n.</pos>
<ety>[From the mythical <ets>Danaides</ets>, who were condemned to fill
with water a vessel full of holes.]</ety> <fld>(Mach.)</fld> <def>A
water wheel having a vertical axis, and an inner and outer tapering
shell, between which are vanes or floats attached usually to both
shells, but sometimes only to one.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Danaite</ent><br/
<hw>Da"na*ite</hw> <pr>(d<amac/"n<adot/*<imac/t)</pr>, <pos>n.</pos>
<ety>[Named after <person>J. Freeman
<etsep>Dana</etsep></person>.]</ety> <fld>(Min.)</fld> <def>A
cobaltiferous variety of arsenopyrite.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Danalite</ent><br/
<hw>Da"na*lite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Named after James
Dwight <ets>Dana</ets>.]</ety> <fld>(Min.)</fld> <def>A mineral
occurring in octahedral crystals, also massive, of a reddish color. It
is a silicate of iron, zinc manganese, and glucinum, containing
sulphur.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Danaus</ent><br/
<hw>Danaus</hw> <pos>n.</pos> <def>the type genus of the Danaidae,
including the monarch butterfly, <spn>Danaus plexippus</spn>.</def><br/
<syn><b>Syn. --</b> genus <gen>Danaus</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Danburite</ent><br/
<hw>Dan"bu*rite</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Min.)</fld>
<def>A borosilicate of lime, first found at <etsep>Danbury</etsep>,
Conn. It is near the topaz in form.</def> <rj><au>Dana.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dance</ent><br/
<hw>Dance</hw> <pr>(d<adot/ns)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Danced</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Dancing</conjf>.]</vmorph> <ety>[F. <ets>danser</ets>,
fr. OHG. <ets>dans<omac/n</ets> to draw; akin to <ets>dinsan</ets> to
draw, Goth. <ets>apinsan</ets>, and prob. from the same root (meaning
<ets>to stretch</ets>) as E. <ets>thin</ets>. See <er>Thin</er>.]</ety>
<sn>1.</sn> <def>To move with measured steps, or to a musical
accompaniment; to go through, either alone or in company with others,
with a regulated succession of movements, (commonly) to the sound of
music; to trip or leap rhythmically.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Jack shall pipe and Gill shall <qex>dance</qex>.</q>
<rj><qau>Wither.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Good shepherd, what fair swain is this<br/
Which <qex>dances</qex> with your daughter?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To move nimbly or merrily; to express pleasure by
motion; to caper; to frisk; to skip about.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Then, 'tis time to <qex>dance</qex> off.</q>
<rj><qau>Thackeray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>More <qex>dances</qex> my rapt heart<br/
Than when I first my wedded mistress saw.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Shadows in the glassy waters <qex>dance</qex>.</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Where rivulets <qex>dance</qex> their wayward round.</q>
<rj><qau>Wordsworth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>To dance on a rope</b></col>, <it>or</it>
<col><b>To dance on nothing</b></col></mcol>, <cd>to be
hanged.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dance</ent><br/
<hw>Dance</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To cause to dance, or
move nimbly or merrily about, or up and down; to dandle.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>dance</qex> our ringlets to the whistling wind.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Thy grandsire loved thee well;<br/
Many a time he <qex>danced</qex> thee on his knee.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To dance attendance</b></col>, <cd>to come and go
obsequiously; to be or remain in waiting, at the beck and call of
another, with a view to please or gain favor.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><q>A man of his place, and so near our favor,<br/
To <qex>dance attendance</qex> on their lordships' pleasure.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dance</ent><br/
<hw>Dance</hw>, <pos>n.</pos> <ety>[F. <ets>danse</ets>, of German
origin. See <er>Dance</er>, <pos>v. i.</pos>]</ety> <sn>1.</sn> <def>The
leaping, tripping, or measured stepping of one who dances; an amusement,
in which the movements of the persons are regulated by art, in figures
and in accord with music.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mus.)</fld> <def>A tune by which dancing is
regulated, as the minuet, the waltz, the cotillion, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The word <xex>dance</xex> was used ironically, by the
older writers, of many proceedings besides dancing.</note><br/
[<source>1913 Webster</source>]</p>

<p><q>Of remedies of love she knew parchance<br/
For of that art she couth the olde <qex>dance</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dance of Death</b></col> <fld>(Art)</fld>, <cd>an
allegorical representation of the power of death over all, -- the old,
the young, the high, and the low, being led by a dancing skeleton.</cd>
-- <col><b>Morris dance</b></col>. <cd>See <er>Morris</er>.</cd> --
<col><b>To lead one a dance</b></col>, <cd>to cause one to go through a
series of movements or experiences as if guided by a partner in a dance
not understood.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dancer</ent><br/
<hw>Dan"cer</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who dances or who
practices dancing.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>The merry dancers</b></col>, <cd>beams of the northern
lights when they rise and fall alternately without any considerable
change of length. See <cref>Aurora borealis</cref>, under
<er>Aurora</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Danceress</ent><br/
<hw>Dan"cer*ess</hw>, <pos>n.</pos> <def>A female dancer.</def>
<mark>[Obs.]</mark> <rj><au>Wyclif.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dancette</ent><br/
<hw>Dan`cet`t<eacute/"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>danch<eacute/</ets> dancett<eacute/, <ets>dent</ets> tooth.]</ety>
<fld>(Her.)</fld> <def>Deeply indented; having large teeth; thus, a fess
<xex>dancett<eacute/</xex> has only three teeth in the whole width of
the escutcheon.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dancing</ent><br/
<hw>Dan"cing</hw> <pr>(?)</pr>, <pos>p. a. & vb. n.</pos> <def>from
<er>Dance</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dancing girl</b></col>, <cd>one of the women in the East
Indies whose profession is to dance in the temples, or for the amusement
of spectators. There are various classes of dancing girls.</cd> --
<col><b>Dancing master</b></col>, <cd>a teacher of dancing.</cd> --
<col><b>Dancing school</b></col>, <cd>a school or place where dancing is
taught.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dancy</ent><br/
<hw>Dan"cy</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Her.)</fld> <def>Same
as <er>Dancett<eacute/</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dandelion</ent><br/
<hw>Dan"de*li`on</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>dent de
lion</ets> lion's tooth, fr. L. <ets>dens</ets> tooth + <ets>leo</ets>
lion. See <er>Tooth</er>, <pos>n.</pos>, and <er>Lion</er>.]</ety>
<fld>(Bot.)</fld> <def>A well-known plant of the genus
<gen>Taraxacum</gen> (<spn>Taraxacum officinale</spn>, formerly called
<spn>Taraxacum Dens-leonis</spn> and <spn>Leontodos Taraxacum</spn>)
bearing large, yellow, compound flowers, and deeply notched
leaves.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dander</ent><br/
<hw>Dan"der</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Corrupted from
<ets>dandruff</ets>.]</ety> <sn>1.</sn> <def>Dandruff or scurf on the
head.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Anger or vexation; rage.</def> <mark>[Low]</mark>
<rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dander</ent><br/
<hw>Dan"der</hw>, <pos>v. i.</pos> <ety>[See <er>Dandle</er>.]</ety>
<def>To wander about; to saunter; to talk incoherently.</def>
<mark>[Prov. Eng.]</mark> <rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dandi</ent><br/
\'d8<hw>Dan"di</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Hind.
<ets><dsdot/<amac/n<dsdot/i</ets>, fr. <ets><dsdot/<amac/n<dsdot/</ets>
an oar.]</ety> <def>A boatman; an oarsman.</def>
<mark>[India]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dandie</ent><br/
<hw>Dan"die</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>One
of a breed of small terriers; -- called also <altname>Dandie
Dinmont</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- Illustr. of dandie dinmont --></p>

<p><ent>Dandie  Dinmont</ent><br/
<ent>Dandie Dinmont</ent><br/
<mhw>{ <hw>Dan"die Din"mont</hw> <pr>(d<acr/n"d<icr/
d<icr/n"m<ocr/nt)</pr>, <it>or</it> <hw>Dan"die Din"mont</hw> }</mhw>,
<pos>n.</pos> <sn>1.</sn> <def>In Scott's <ldquo/Guy Mannering<rdquo/, a
Border farmer of eccentric but fine character, who owns two terriers
claimed to be the progenitors of the Dandie Dinmont terriers.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>One of a breed of terriers with short legs, long
body, and rough coat, originating in the country about the English and
Scotch border.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Dandified</ent><br/
<hw>Dan"di*fied</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Made up like a
dandy; having the dress or manners of a dandy; buckish.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dandify</ent><br/
<hw>Dan"di*fy</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Dandified</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Dandifying</conjf>.]</vmorph> <ety>[<ets>Dandy</ets> +
<ets>-fy</ets>.]</ety> <def>To cause to resemble a dandy; to make
dandyish.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dandiprat</ent><br/
<hw>Dan"di*prat</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Dandy</ets>
+ <ets>brat</ets> child.]</ety> <sn>1.</sn> <def>A little fellow; -- in
sport or contempt.</def> <ldquo/A <xex>dandiprat</xex> hop-thumb.<rdquo/
<rj><au>Stanyhurst.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A small coin.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Henry VII. stamped a small coin called <qex>dandiprats</qex>.</q>
<rj><qau>Camden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dandle</ent><br/
<hw>Dan"dle</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Dandled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Dandling</conjf> <pr>(?)</pr>.]</vmorph> <ety>[Cf. G.
<ets>d<aum/ndeln</ets> to trifly, dandle, OD. & Prov. G.
<ets>danten</ets>, G. <ets>tand</ets> trifly, prattle; Scot.
<ets>dandill</ets>, <ets>dander</ets>, to go about idly, to
trifly.]</ety> <sn>1.</sn> <def>To move up and down on one's knee or in
one's arms, in affectionate play, as an infant.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Ye shall be <qex>dandled</qex> . . . upon her knees.</q>
<rj><qau>Isaiah 66:12</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To treat with fondness, as if a child; to fondle; to
toy with; to pet.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They have put me in a silk gown and gaudy fool's cap; I as ashamed
to be <qex>dandled</qex> thus.</q> <rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The book, thus <qex>dandled</qex> into popularity by bishops and
good ladies, contained many pieces of nursery eloquence.</q>
<rj><qau>Jeffrey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To play with; to put off or delay by trifles; to
wheedle.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Captains do so <qex>dandle</qex> their doings, and dally in the
service, as it they would not have the enemy subdued.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dandler</ent><br/
<hw>Dan"dler</hw> <pr>(d<acr/n"dl<etil/r)</pr>, <pos>n.</pos> <def>One
who dandles or fondles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dandriff</ent><br/
<hw>Dan"driff</hw> <pr>(d<acr/n"dr<icr/f)</pr>, <pos>n.</pos> <def>See
<er>Dandruff</er>.</def> <rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dandruff</ent><br/
<hw>Dandruff</hw> <pr>(d<acr/n"dr<ucr/f)</pr>, <pos>n.</pos> <ety>[Prob.
from W. <ets>ton</ets>crust, peel, skin + AS. <ets>dr<omac/f</ets>
dirty, draffy, or W. <ets>drwg</ets> bad: cf. AS. <ets>tan</ets> a
letter, an eruption. <root/240.]</ety> <def>A scurf which forms on the
head, and comes off in small scales or particles.</def> <altsp>[Written
also <asp>dandriff</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dandy</ent><br/
<hw>Dan"dy</hw> <pr>(d<acr/n"d<ycr/)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Dandies</plw> <pr>(d<acr/n"d<icr/z)</pr>.</plu>
<ety>[Cf. F. <ets>dandin</ets>, ninny, silly fellow, <ets>dandiner</ets>
to waddle, to play the fool; prob. allied to E. <ets>dandle</ets>.
Senses 2 & 3 are of uncertain etymology.]</ety> <sn>1.</sn> <def>One who
affects special finery or gives undue attention to dress; a fop; a
coxcomb.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Naut.)</fld> <sd>(a)</sd> <def>A sloop or cutter
with a jigger on which a lugsail is set.</def> <sd>(b)</sd> <def>A small
sail carried at or near the stern of small boats; -- called also
<altname>jigger</altname>, and <altname>mizzen</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A dandy roller. See below.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dandy brush</b></col>, <cd>a yard whalebone brush.</cd>
-- <col><b>Dandy fever</b></col>. <cd>See <er>Dengue</er>.</cd> --
<col><b>Dandy line</b></col>, <cd>a kind of fishing line to which are
attached several crosspieces of whalebone which carry a hook at each
end.</cd> -- <col><b>Dandy roller</b></col>, <cd>a roller sieve used in
machines for making paper, to press out water from the pulp, and set the
paper.</cd></cs></p>

<p><ent>Dandy-hen</ent><br/
<ent>Dandy-cock</ent><br/
<mhw><hw>Dan"dy-cock`</hw> <pr>(<?/)</pr>, <pos>n. masc.</pos>,
<hw>Dan"dy-hen`</hw> <pr>(<?/)</pr>, <pos>n. fem.</pos></mhw> <ety>[See
<er>Dandy</er>.]</ety> <def>A bantam fowl.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dandyish</ent><br/
<hw>Dan"dy*ish</hw>, <pos>a.</pos> <def>Like a dandy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dandyism</ent><br/
<hw>Dan"dy*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The manners and
dress of a dandy; foppishness.</def> <rj><au>Byron.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dandyize</ent><br/
<hw>Dan"dy*ize</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <def>To make, or
to act, like a dandy; to dandify.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dandyling</ent><br/
<hw>Dan"dy*ling</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Dandy</ets>
+ <ets>-ling</ets>.]</ety> <def>A little or insignificant dandy; a
contemptible fop.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dane</ent><br/
<hw>Dane</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL. <ets>Dani</ets>: cf.
AS. <ets>Dene</ets>.]</ety> <def>A native, or a naturalized inhabitant,
of Denmark.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Great Dane</b></col>. <fld>(Zool.)</fld> <cd>See
<cref>Danish dog</cref>, under <er>Danish</er>.</cd></cs></p>

<p><ent>Danegelt</ent><br/
<ent>Danegeld</ent><br/
<mhw>{ <hw>Dane"geld`</hw> <pr>(?)</pr>, <hw>Dane"gelt`</hw>
<pr>(?)</pr> }</mhw>, <pos>n.</pos> <ety>[AS. <ets>danegeld</ets>. See
<er>Dane</er>, and <er>Geld</er>, <pos>n.</pos>]</ety> <fld>(Eng.
Hist.)</fld> <def>An annual tax formerly laid on the English nation to
buy off the ravages of Danish invaders, or to maintain forces to oppose
them. It afterward became a permanent tax, raised by an assessment, at
first of one shilling, afterward of two shillings, upon every hide of
land throughout the realm.</def> <rj><au>Wharton's Law Dict.
Tomlins.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Danewort</ent><br/
<hw>Dane"wort`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>A
fetid European species of elder (<spn>Sambucus Ebulus</spn>); dwarf
elder; wallwort; elderwort; -- called also <altname>Daneweed</altname>,
<altname>Dane's weed</altname>, and <altname>Dane's-blood</altname>.
<note>[Said to grow on spots where battles were fought against the
Danes.]</note></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dang</ent><br/
<hw>Dang</hw> <pr>(?)</pr>, <def><pos>imp.</pos> of <er>Ding</er>.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dang</ent><br/
<hw>Dang</hw>, <pos>v. t.</pos> <ety>[Cf. <er>Ding</er>.]</ety> <def>To
dash.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Till she, o'ercome with anguish, shame, and rage,<br/
<qex>Danged</qex> down to hell her loathsome carriage.</q>
<rj><qau>Marlowe.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Danger</ent><br/
<hw>Dan"ger</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>danger</ets>, <ets>daunger</ets>, power, arrogance, refusal,
difficulty, fr. OF. <ets>dagier</ets>, <ets>dongier</ets> (with same
meaning), F. <ets>danger</ets> danger, fr. an assumed LL.
<ets>dominiarium</ets> power, authority, from L. <ets>dominium</ets>
power, property. See <er>Dungeon</er>, <er>Domain</er>,
<er>Dame</er>.]</ety> <sn>1.</sn> <def>Authority; jurisdiction;
control.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>In <qex>danger</qex>had he . . . the young girls.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Power to harm; subjection or liability to
penalty.</def> <mark>[Obs.]</mark> See <cref>In one's danger</cref>,
below.<br/
[<source>1913 Webster</source>]</p>

<p><q>You stand within his <qex>danger</qex>, do you not?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Covetousness of gains hath brought [them] in <qex>danger</qex>of
this statute.</q> <rj><qau>Robynson (More's Utopia).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Exposure to injury, loss, pain, or other evil;
peril; risk; insecurity.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Difficulty; sparingness.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Coyness; disdainful behavior.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<cs><p><col><b>In one's danger</b></col>, <cd>in one's power; liable to
a penalty to be inflicted by him. <mark>[Obs.]</mark> This sense is
retained in the proverb, <ldquo/Out of debt out of
<xex>danger</xex>.<rdquo/</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>Those rich man in whose debt and <qex>danger</qex> they be
not.</q> <rj><qau>Robynson (More's Utopia).</qau></rj></p>

<p>-- <col><b>To do danger</b></col>, <cd>to cause danger.</cd>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj></p></cs>

<p><syn><b>Syn.</b> -- Peril; hazard; risk; jeopardy.</syn> <usage> --
<er>Danger</er>, <er>Peril</er>, <er>Hazard</er>, <er>Risk</er>,
<er>Jeopardy</er>. <xex>Danger</xex> is the generic term, and implies
some contingent evil in prospect. <xex>Peril</xex> is instant or
impending danger; as, in <xex>peril</xex> of one's life.
<xex>Hazard</xex> arises from something fortuitous or beyond our
control; as, the <xex>hazard</xex> of the seas. <xex>Risk</xex> is
doubtful or uncertain danger, often incurred voluntarily; as, to
<xex>risk</xex> an engagement. <xex>Jeopardy</xex> is extreme danger.
<xex>Danger</xex> of a contagious disease; the <xex>perils</xex> of
shipwreck; the <xex>hazards</xex> of speculation; the <xex>risk</xex> of
daring enterprises; a life brought into <xex>jeopardy</xex>.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Danger</ent><br/
<hw>Dan"ger</hw>, <pos>v. t.</pos> <def>To endanger.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dangerful</ent><br/
<hw>Dan"ger*ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Full of danger;
dangerous.</def> <mark>[Obs.]</mark> --
<wordforms><wf>Dan"ger*ful*ly</wf>, <pos>adv.</pos>
<mark>[Obs.]</mark></wordforms> <rj><au>Udall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dangerless</ent><br/
<hw>Dan"ger*less</hw>, <pos>a.</pos> <def>Free from danger.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dangerous</ent><br/
<hw>Dan"ger*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OE., haughty,
difficult, dangerous, fr. OF. <ets>dangereus</ets>, F.
<ets>dangereux</ets>. See <er>Danger</er>.]</ety> <sn>1.</sn>
<def>Attended or beset with danger; full of risk; perilous; hazardous;
unsafe.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Our troops set forth to-morrow; stay with us;<br/
The ways are <qex>dangerous</qex>.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>It is <qex>dangerous</qex> to assert a negative.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Causing danger; ready to do harm or
injury.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If they incline to think you <qex>dangerous</qex><br/
To less than gods.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>In a condition of danger, as from illness;
threatened with death.</def> <mark>[Colloq.]</mark> <rj><au>Forby.
Bartlett.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Hard to suit; difficult to please.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>My wages ben full strait, and eke full small;<br/
My lord to me is hard and <qex>dangerous</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Reserved; not affable.</def> <mark>[Obs.]</mark>
<ldquo/Of his speech <xex>dangerous</xex>.<rdquo/
<rj><au>Chaucer.</au></rj></p>

<p>-- <wordforms><wf>Dan"ger*ous*ly</wf>, <pos>adv.</pos> --
<wf>Dan"ger*ous*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 368 --></p>

<p><ent>Dangle</ent><br/
<hw>Dan"gle</hw> <pr>(d<acr/<nsm/"g'l)</pr>, <pos>v. i.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Dangled</conjf> <pr>(?)</pr>;
<pos>p. pr. & vb. n.</pos> <conjf>Dangling</conjf>
<pr>(?)</pr>.]</vmorph> <ety>[Akin to Dan. <ets>dangle</ets>, dial. Sw.
<ets>dangla</ets>, Dan. <ets>dingle</ets>, Sw. <ets>dingla</ets>, Icel.
<ets>dingla</ets>; perh. from E. <ets>ding</ets>.]</ety> <def>To hang
loosely, or with a swinging or jerking motion.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He'd rather on a gibbet <qex>dangle</qex><br/
Than miss his dear delight, to wrangle.</q>
<rj><qau>Hudibras.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>From her lifted hand<br/
<qex>Dangled</qex> a length of ribbon.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>To dangle about</b></col> <it>or</it> <col><b>To
dangle after</b></col></mcol>, <cd>to hang upon importunately; to court
the favor of; to beset.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><q>The Presbyterians, and other fanatics that <qex>dangle after</qex>
them,<br/
are well inclined to pull down the present establishment.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dangle</ent><br/
<hw>Dan"gle</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To cause to dangle;
to swing, as something suspended loosely; <as>as, to <ex>dangle</ex> the
feet</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And the bridegroom stood <qex>dangling</qex> his bonnet and
plume.</q> <rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dangleberry</ent><br/
<hw>Dan"gle*ber`ry</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>A dark blue, edible berry with a white bloom, and its shrub
(<spn>Gaylussacia frondosa</spn>) closely allied to the common
huckleberry. The bush is also called <prodby>blue tangle</prodby>, and
is found from New England to Kentucky, and southward.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dangler</ent><br/
<hw>Dan"gler</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who dangles about
or after others, especially after women; a trifler.</def> <ldquo/
<xex>Danglers</xex> at toilets.<rdquo/ <rj><au>Burke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daniel</ent><br/
<hw>Dan"i*el</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A Hebrew prophet
distinguished for sagacity and ripeness of judgment in youth; hence, a
sagacious and upright judge.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>Daniel</qex> come to judgment.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Danish</ent><br/
<hw>Dan"ish</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Dane</er>.]</ety> <def>Belonging to the Danes, or to their language
or country.</def> -- <def2><pos>n.</pos> <def>The language of the
Danes.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Danish dog</b></col> <fld>(Zool.)</fld>, <cd>one of a
large and powerful breed of dogs reared in Denmark; -- called also
<altname>great Dane</altname>. See <xex>Illustration</xex> in
Appendix.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Danite</ent><br/
<hw>Dan"ite</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A
descendant of Dan; an Israelite of the tribe of Dan.</def>
<rj><au>Judges xiii. 2.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <ety>[So called in remembrance of the prophecy in Gen.
xlix. 17, <ldquo/<ets>Dan</ets> shall be a serpent by the way,<rdquo/
etc.]</ety> <def>One of a secret association of Mormons, bound by an
oath to obey the heads of the church in all things.</def> <mark>[U.
S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dank</ent><br/
<hw>Dank</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. dial, Sw.
<ets>dank</ets> a moist place in a field, Icel. <ets>d<oum/kk</ets> pit,
pool; possibly akin to E. <ets>damp</ets> or to <ets>daggle</ets>
dew.]</ety> <def>Damp; moist; humid; wet.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Now that the fields are <qex>dank</qex> and ways are mire.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Cheerless watches on the cold, <qex>dank</qex> ground.</q>
<rj><qau>Trench.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dank</ent><br/
<hw>Dank</hw>, <pos>n.</pos> <def>Moisture; humidity; water.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dank</ent><br/
<hw>Dank</hw>, <pos>n.</pos> <def>A small silver coin current in
Persia.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dankish</ent><br/
<hw>Dank"ish</hw>, <pos>a.</pos> <def>Somewhat dank.</def> --
<wordforms><wf>Dank"ish*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><q>In a dark and <qex>dankish</qex> vault at home.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dannebrog</ent><br/
<hw>Dan"ne*brog</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The ancient battle
standard of Denmark, bearing figures of cross and crown.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Order of Dannebrog</b></col>, <cd>an ancient Danish order
of knighthood.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Danseuse</ent><br/
\'d8<hw>Dan`seuse"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr.
<ets>danser</ets> to dance.]</ety> <def>A professional female dancer; a
woman who dances at a public exhibition as in a ballet.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dansk</ent><br/
<hw>Dansk</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Dan.]</ety>
<def>Danish.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dansker</ent><br/
<hw>Dansk"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A Dane.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Inquire me first what <qex>Danskers</qex> are in Paris.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dantean</ent><br/
<hw>Dan*te"an</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Relating to,
emanating from or resembling, the poet Dante or his writings.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dantesque</ent><br/
<hw>Dan*tesque"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. It.
<ets>Dantesco</ets>.]</ety> <def>Dantelike; Dantean.</def>
<rj><au>Earle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Danubian</ent><br/
<hw>Da*nu"bi*an</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to, or
bordering on, the river Danube.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dap</ent><br/
<hw>Dap</hw> <pr>(d<acr/p)</pr>, <pos>v. i.</pos> <ety>[Cf.
<er>Dip</er>.]</ety> <fld>(Angling)</fld> <def>To drop the bait gently
on the surface of the water.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To catch a club by <qex>dapping</qex> with a grasshoper.</q>
<rj><qau>Walton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dapatical</ent><br/
<hw>Da*pat"ic*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>dapaticus</ets>, fr. <ets>daps</ets> feast.]</ety> <def>Sumptuous
in cheer.</def> <mark>[Obs.]</mark> <rj><au>Bailey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daphne</ent><br/
<hw>Daph"ne</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., a laurel tree,
from Gr. <grk>da`fnh</grk>.]</ety> <sn>1.</sn> <fld>(Bot.)</fld> <def>A
genus of diminutive Shrubs, mostly evergreen, and with fragrant
blossoms.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Myth.)</fld> <def>A nymph of Diana, fabled to have
been changed into a laurel tree.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daphnetin</ent><br/
<hw>Daph"ne*tin</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>A colorless crystalline substance, <chform>C9H6O4</chform>,
extracted from daphnin.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daphnia</ent><br/
\'d8<hw>Daph"ni*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL.]</ety>
<fld>(Zool.)</fld> <def>A genus of the genus
<gen>Daphnia</gen>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daphnin</ent><br/
<hw>Daph"nin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>daphnine</ets>.]</ety> <fld>(Chem.)</fld> <sd>(a)</sd> <def>A dark
green bitter resin extracted from the mezereon (<spn>Daphne
mezereum</spn>) and regarded as the essential principle of the
plant.</def> <mark>[R.]</mark> <sd>(b)</sd> <def>A white, crystalline,
bitter substance, regarded as a glucoside, and extracted from
<spn>Daphne mezereum</spn> and <spn>Daphne alpina</spn>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daphnomancy</ent><br/
<hw>Daph"no*man`cy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<ets><grk>da`fnh</grk></ets> the laurel + <ets>-mancy</ets>.]</ety>
<def>Divination by means of the laurel.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dapifer</ent><br/
\'d8<hw>Dap"i*fer</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.,
<ets>daps</ets> a feast + <ets>ferre</ets> to bear.]</ety> <def>One who
brings meat to the table; hence, in some countries, the official title
of the grand master or steward of the king's or a nobleman's
household.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dapper</ent><br/
<hw>Dap"per</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OE. <ets>daper</ets>;
prob. fr. D. <ets>dapper</ets> brave, valiant; akin to G.
<ets>tapfer</ets> brave, OHG. <ets>taphar</ets> heavy, weighty, OSlav.
<ets>dobr<ucr/</ets> good, Russ. <ets>dobrui</ets>. Cf.
<er>Deft</er>.]</ety> <def>Little and active; spruce; trim; smart; neat
in dress or appearance; lively.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He wondered how so many provinces could be held in subjection by
such a <qex>dapper</qex> little man.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>dapper</qex> ditties that I wont devise.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Sharp-nosed, <qex>dapper</qex> steam yachts.</q> <rj><qau>Julian
Hawthorne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dapperling</ent><br/
<hw>Dap"per*ling</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A dwarf; a
dandiprat.</def> <mark>[r.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dapple</ent><br/
<hw>Dap"ple</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. Icel.
<ets>depill</ets> a spot, a dot, a dog with spots over the eyes,
<ets>dapi</ets> a pool, and E. <ets>dimple</ets>.]</ety> <def>One of the
spots on a dappled animal.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He has . . . as many eyes on his body as my gray mare hath
<qex>dapples</qex>.</q> <rj><qau>Sir P. Sidney.</qau></rj></p>

<p><ent>Dappled</ent><br/
<ent>Dapple</ent><br/
<mhw>{ <hw>Dap"ple</hw> <pr>(?)</pr>, <hw>Dap"pled</hw> <pr>(?)</pr>
}</mhw>, <pos>a.</pos> <def>Marked with spots of different shades of
color; spotted; variegated; <as>as, a <ex>dapple</ex>
horse</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Some <qex>dapple</qex> mists still floated along the peaks.</q>
<rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The word is used in composition to denote that some
color is variegated or marked with spots; as, <xex>dapple</xex>-bay;
<xex>dapple</xex>-gray.</note><br/
[<source>1913 Webster</source>]</p>

<p><q>His steed was all <qex>dapple</qex>-gray.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>O, swiftly can speed my <qex>dapple</qex>-gray steed.</q>
<rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dapple</ent><br/
<hw>Dap"ple</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Dappled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Dappling</conjf>.]</vmorph> <def>To variegate with spots; to
spot.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The gentle day, . . . <br/
<qex>Dapples</qex> the drowsy east with spots of gray.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>dappled</qex> pink and blushing rose.</q>
<rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Darbies</ent><br/
<hw>Dar"bies</hw> <pr>(d<aum/r"b<icr/z)</pr>, <pos>n. pl.</pos>
<def>Manacles; handcuffs.</def> <mark>[Cant]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Jem Clink will fetch you the <qex>darbies</qex>.</q> <rj><qau>Sir
W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In <ldquo/The Steel Glass<rdquo/ by Gascoigne, printed
in 1576, occurs the line <ldquo/To binde such babes in father
<xex>Derbies bands</xex>.<rdquo/</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Darby</ent><br/
<hw>Dar"by</hw> <pr>(d<aum/r"b<ycr/)</pr>, <pos>n.</pos> <def>A
plasterer's float, having two handles; -- used in smoothing ceilings,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Darbyite</ent><br/
<hw>Dar"by*ite</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One of the Plymouth
Brethren, or of a sect among them; -- so called from John N.
<xex>Darby</xex>, one of the leaders of the Brethren.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dardanelles</ent><br/
<hw>Dardanelles</hw> <pos>n.</pos> <sn>1.</sn> <def>the strait between
the Aegean and the Sea of Marmara that separates European from Asian
Turkey.</def><br/
<syn><b>Syn. --</b> Hellespont.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>the unsuccessful campaign in World War I (1915) by
the English and French to open a passage for aid to Russia; defeated by
the Turks.</def><br/
<syn><b>Syn. --</b> Dardanelles campaign.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dardanian</ent><br/
<hw>Dar*da"ni*an</hw> <pr>(?)</pr>, <pos>a. & n.</pos><ety>[From L.
<etsep>Dardania</etsep>, poetic name of Troy.]</ety>
<def>Trojan.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dare</ent><br/
<hw>Dare</hw> <pr>(d<acir/r)</pr>, <pos>v. i.</pos>
<vmorph>[<pos>imp.</pos> <conjf>Durst</conjf> <pr>(d<ucir/rst)</pr> or
<conjf>Dared</conjf> <pr>(d<acir/rd)</pr>; <pos>p. p.</pos>
<conjf>Dared</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Daring</conjf>.]</vmorph> <ety>[OE. <ets>I dar</ets>,
<ets>dear</ets>, I dare, imp. <ets>dorste</ets>, <ets>durste</ets>, AS.
<ets>ic dear</ets> I dare, imp. <ets>dorste</ets>. inf.
<ets>durran</ets>; akin to OS. <ets>gidar</ets>, <ets>gidorsta</ets>,
<ets>gidurran</ets>, OHG. <ets>tar</ets>, <ets>torsta</ets>,
<ets>turran</ets>, Goth. <ets>gadar</ets>, <ets>gada<uacute/rsta</ets>,
Gr. <ets><grk>tharsei^n</grk></ets>, <ets><grk>tharrei^n</grk></ets>, to
be bold, <ets><grk>tharsy`s</grk></ets> bold, Skr. <ets>Dhrsh</ets> to
be bold. <root/70.]</ety> <def>To have adequate or sufficient courage
for any purpose; to be bold or venturesome; not to be afraid; to
venture.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I <qex>dare</qex> do all that may become a man; Who
<qex>dares</qex> do more is none.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Why then did not the ministers use their new law? Bacause they
<qex>durst</qex> not, because they could not.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Who <qex>dared</qex> to sully her sweet love with suspicion.</q>
<rj><qau>Thackeray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The tie of party was stronger than the tie of blood, because a
partisan was more ready to <qex>dare</qex> without asking why.</q>
<rj><qau>Jowett (Thucyd.).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The present tense, <xex>I dare</xex>, is really an old
past tense, so that the third person is <xex>he dare</xex>, but the form
<xex>he dares</xex> is now often used, and will probably displace the
obsolescent <xex>he dare</xex>, through grammatically as incorrect as
<xex>he shalls</xex> or <xex>he cans</xex>.</note>
<rj><au>Skeat.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The pore <qex>dar</qex> plede (the poor man <qex>dare</qex>
plead).</q> <rj><qau>P. Plowman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>You know one <qex>dare</qex> not discover you.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The fellow <qex>dares</qex> not deceive me.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Here boldly spread thy hands, no venom'd weed<br/
<qex>Dares</qex> blister them, no slimy snail <qex>dare</qex> creep.</q>
<rj><qau>Beau. & Fl.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Formerly <xex>durst</xex> was also used as the present.
Sometimes the old form <xex>dare</xex> is found for <xex>durst</xex> or
<xex>dared</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dare</ent><br/
<hw>Dare</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Dared</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Daring</conjf>.]</vmorph> <sn>1.</sn> <def>To have courage for;
to attempt courageously; to venture to do or to undertake.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>What high concentration of steady feeling makes men
<qex>dare</qex> every thing and do anything?</q>
<rj><qau>Bagehot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To wrest it from barbarism, to <qex>dare</qex> its solitudes.</q>
<rj><qau>The Century.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To challenge; to provoke; to defy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Time, I <qex>dare</qex> thee to discover<br/
Such a youth and such a lover.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dare</ent><br/
<hw>Dare</hw>, <pos>n.</pos> <sn>1.</sn> <def>The quality of daring;
venturesomeness; boldness; dash.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>It lends a luster . . . <br/
A large <qex>dare</qex> to our great enterprise.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Defiance; challenge.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Childish, unworthy <qex>dares</qex><br/
Are not enought to part our powers.</q> <rj><qau>Chapman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Sextus Pompeius<br/
Hath given the <qex>dare</qex> to C<ae/sar.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dare</ent><br/
<hw>Dare</hw>, <pos>v. i.</pos> <ety>[OE. <ets>darien</ets>, to lie
hidden, be timid.]</ety> <def>To lurk; to lie hid.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dare</ent><br/
<hw>Dare</hw>, <pos>v. t.</pos> <def>To terrify; to daunt.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>For I have done those follies, those mad mischiefs,<br/
Would <qex>dare</qex> a woman.</q> <rj><qau>Beau. & Fl.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To dare larks</b></col>, <cd>to catch them by producing
terror through to use of mirrors, scarlet cloth, a hawk, etc., so that
they lie still till a net is thrown over them.</cd>
<rj><au>Nares.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dare</ent><br/
<hw>Dare</hw>, <pos>n.</pos> <ety>[See <er>Dace</er>.]</ety>
<fld>(Zool.)</fld> <def>A small fish; the dace.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dare-devil</ent><br/
<hw>Dare"-dev`il</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A reckless
fellow. Also used adjectively; <as>as, <ex>dare-devil</ex>
excitement</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A humorous <qex>dare-devil</qex> -- the very man<br/
To suit my prpose.</q> <rj><qau>Ld. Lytton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dare-deviltry</ent><br/
<hw>Dare"-dev`il*try</hw> <pr>(?)</pr>, <pos>n</pos>; <plu><it>pl.</it>
<plw>Dare-deviltries</plw> <pr>(<?/)</pr>.</plu> <def>Reckless mischief;
the action of a dare-devil.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dareful</ent><br/
<hw>Dare"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Full of daring or of
defiance; adventurous.</def> <mark>[R.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Darer</ent><br/
<hw>Dar"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who dares or
defies.</def></p>

<p><ent>Dar es Salaam</ent><br/
<hw>Dar es Salaam</hw> <pos>prop. n.</pos> <fld>(Geography)</fld>
<def>The administrative capital <isa>city</isa> of
<country>Tanzania</country>. Population (2000) = 1,360,850.</def><br/
[<source>PJC</source>]</p>

<p><ent>Dargue</ent><br/
<ent>Darg</ent><br/
<mhw>{ <hw>Darg</hw>, <hw>Dargue</hw> <pr>(?)</pr> }</mhw>,
<pos>n.</pos> <ety>[Scot., contr. fr. <ets>day work</ets>.]</ety> <def>A
day's work; also, a fixed amount of work, whether more or less than that
of a day.</def> <mark>[Local, Eng. & Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daric</ent><br/
<hw>Dar"ic</hw> <pr>(d<acr/r"<icr/k)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>dareiko`s</grk>, of Persian origin.]</ety> <sn>1.</sn>
<fld>(Antiq.)</fld> <sd>(a)</sd> <def>A gold coin of ancient Persia,
weighing usually a little more than 128 grains, and bearing on one side
the figure of an archer.</def> <sd>(b)</sd> <def>A silver coin of about
86 grains, having the figure of an archer, and hence, in modern times,
called a <ex>daric</ex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Any very pure gold coin.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daring</ent><br/
<hw>Dar"ing</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Boldness;
fearlessness; adventurousness; also, a daring act.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daring</ent><br/
<hw>Dar"ing</hw>, <pos>a.</pos> <def>Bold; fearless; adventurous;
<as>as, <ex>daring</ex> spirits</as>.</def> --
<wordforms><wf>Dar"ing*ly</wf>, <pos>adv.</pos> --
<wf>Dar"ing*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dariole</ent><br/
<hw>Da`ri*ole"</hw> <pr>(d<adot/`r<icr/*<omac/l")</pr>, <pos>n.</pos>
<ety>[F.]</ety> <sn>1.</sn> <def>A crustade.</def>
<mark>[Obs.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>A shell or cup of pastry filled with custard,
whipped cream, crushed macaroons, etc.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Dark</ent><br/
<hw>Dark</hw> <pr>(d<aum/rk)</pr>, <pos>a.</pos> <ety>[OE.
<ets>dark</ets>, <ets>derk</ets>, <ets>deork</ets>, AS.
<ets>dearc</ets>, <ets>deorc</ets>; cf. Gael. & Ir. <ets>dorch</ets>,
<ets>dorcha</ets>, dark, black, dusky.]</ety> <sn>1.</sn>
<def>Destitute, or partially destitute, of light; not receiving,
reflecting, or radiating light; wholly or partially black, or of some
deep shade of color; not light-colored; <as>as, a <ex>dark</ex> room; a
<ex>dark</ex> day; <ex>dark</ex> cloth; <ex>dark</ex> paint; a
<ex>dark</ex> complexion.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>O <qex>dark</qex>, <qex>dark</qex>, <qex>dark</qex>, amid the
blaze of noon,<br/
Irrecoverably <qex>dark</qex>, total eclipse<br/
Without all hope of day!</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>In the <qex>dark</qex> and silent grave.</q> <rj><qau>Sir W.
Raleigh.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Not clear to the understanding; not easily seen
through; obscure; mysterious; hidden.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>dark</qex> problems of existence.</q>
<rj><qau>Shairp.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>What may seem <qex>dark</qex> at the first, will afterward be
found more plain.</q> <rj><qau>Hooker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>What's your <qex>dark</qex> meaning, mouse, of this light
word?</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Destitute of knowledge and culture; in moral or
intellectual darkness; unrefined; ignorant.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The age wherein he lived was <qex>dark</qex>, but he<br/
Could not want light who taught the world to see.</q>
<rj><qau>Denhan.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The tenth century used to be reckoned by medi<ae/val historians as
the <qex>darkest</qex> part of this intellectual night.</q>
<rj><qau>Hallam.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Evincing black or foul traits of character; vile;
wicked; atrocious; <as>as, a <ex>dark</ex> villain; a <ex>dark</ex>
deed.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Left him at large to his own <qex>dark</qex> designs.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Foreboding evil; gloomy; jealous;
suspicious.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>More <qex>dark</qex> and <qex>dark</qex> our woes.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A deep melancholy took possesion of him, and gave a
<qex>dark</qex> tinge to all his views of human nature.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>There is, in every true woman-s heart, a spark of heavenly fire,
which beams and blazes in the <qex>dark</qex> hour of adversity.</q>
<rj><qau>W. Irving.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Deprived of sight; blind.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He was, I think, at this time quite <qex>dark</qex>, and so had
been for some years.</q> <rj><qau>Evelyn.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Dark</xex> is sometimes used to qualify another
adjective; <as>as, <ex>dark</ex> blue, <ex>dark</ex> green, and
sometimes it forms the first part of a compound; as,
<ex>dark</ex>-haired, <ex>dark</ex>-eyed, <ex>dark</ex>-colored,
<ex>dark</ex>-seated, <ex>dark</ex>-working.</as></note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>A dark horse</b></col>, <cd>in racing or politics, a
horse or a candidate whose chances of success are not known, and whose
capabilities have not been made the subject of general comment or of
wagers</cd>. <mark>[Colloq.]</mark> -- <mcol><col><b>Dark
house</b></col>, <col><b>Dark room</b></col></mcol>, <cd>a house or room
in which madmen were confined.</cd> <mark>[Obs.]</mark> <au>Shak.</au>
-- <col><b>Dark lantern</b></col>. <cd>See <er>Lantern</er>.</cd> -- The
<col><b>Dark Ages</b></col>, <cd>a period of stagnation and obscurity in
literature and art, lasting, according to Hallam, nearly 1000 years,
from about 500 to about 1500 <sc>A. D.</sc>. See <cref>Middle
Ages</cref>, under <er>Middle</er>.</cd> -- <col><b>The Dark and Bloody
Ground</b></col>, <cd>a phrase applied to the State of Kentucky, and
said to be the significance of its name, in allusion to the frequent
wars that were waged there between Indians.</cd> -- <col><b>The dark
day</b></col>, <cd>a day (May 19, 1780) when a remarkable and
unexplained darkness extended over all New England.</cd> -- <col><b>To
keep dark</b></col>, <cd>to reveal nothing.</cd>
<mark>[Low]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dark</ent><br/
<hw>Dark</hw> <pr>(d<aum/rk)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>Absence of light; darkness; obscurity; a place where there is
little or no light.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Here stood he in the <qex>dark</qex>, his sharp sword out.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The condition of ignorance; gloom;
secrecy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Look, what you do, you do it still i' th' <qex>dark</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Till we perceive by our own understandings, we are as much in the
<qex>dark</qex>, and as void of knowledge, as before.</q>
<rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Fine Arts)</fld> <def>A dark shade or dark passage
in a painting, engraving, or the like; <as>as, the light and
<ex>darks</ex> are well contrasted</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The lights may serve for a repose to the <qex>darks</qex>, and the
<qex>darks</qex> to the lights.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dark</ent><br/
<hw>Dark</hw>, <pos>v. t.</pos> <def>To darken; to obscure.</def>
<mark>[Obs.]</mark> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>dark-blue</ent><br/
<hw>dark-blue</hw> <pos>adj.</pos> <def>of a color similar to that of a
clear unclouded sky.</def><br/
<syn><b>Syn. --</b> blue, bluish, light-blue, cerulean.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>dark-brown</ent><br/
<hw>dark-brown</hw> <pos>adj.</pos> <def>of a color similar to that of
wood or earth.</def><br/
<syn><b>Syn. --</b> brown, brownish.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Darken</ent><br/
<hw>Dark"en</hw> <pr>(d<aum/rk"'n)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Darkened</conjf>
<pr>(-'nd)</pr>; <pos>p. pr. & vb. n.</pos> <conjf>Darkening</conjf>
<pr>(-n*<icr/ng)</pr>.]</vmorph> <ety>[AS. <ets>deorcian</ets>. See
<er>Dark</er>, <pos>a.</pos>]</ety> <sn>1.</sn> <def>To make dark or
black; to deprive of light; to obscure; <as>as, a <ex>darkened</ex>
room</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They [locusts] covered the face of the whole earth, so that the
land was <qex>darkened</qex>.</q> <rj><qau>Ex. x. 15.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>So spake the Sovran Voice; and clouds began<br/
To <qex>darken</qex> all the hill.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To render dim; to deprive of vision.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Let their eyes be <qex>darkened</qex>, that they may not see.</q>
<rj><qau>Rom. xi. 10.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To cloud, obscure, or perplex; to render less clear
or intelligible.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Such was his wisdom that his confidence did seldom
<qex>darken</qex>his foresight.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Who is this that <qex>darkeneth</qex> counsel by words without
knowledge?</q> <rj><qau>Job. xxxviii. 2.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To cast a gloom upon.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With these forced thoughts, I prithee, <qex>darken</qex> not<br/
The mirth of the feast.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To make foul; to sully; to tarnish.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I must not think there are<br/
Evils enough to <qex>darken</qex> all his goodness.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Darken</ent><br/
<hw>Dark"en</hw>, <pos>v. i.</pos> <def>To grow or darker.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>darkened</ent><br/
<hw>darkened</hw> <pos>adj.</pos> <def>overtaken by night or
darkness.</def><br/
<syn><b>Syn. --</b> nighted.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Darkener</ent><br/
<hw>Dark"en*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, darkens.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Darkening</ent><br/
<hw>Dark"en*ing</hw>, <pos>n.</pos> <def>Twilight; gloaming.</def>
<mark>[Prov. Eng. & Scot.]</mark> <rj><au>Wright.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Darkful</ent><br/
<hw>Dark"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Full of
darkness.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>dark-green</ent><br/
<hw>dark-green</hw> <pos>adj.</pos> <def>similar to the color of fresh
grass.</def><br/
<syn><b>Syn. --</b> green, greenish, light-green.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>dark-haired</ent><br/
<hw>dark-haired</hw> <pos>adj.</pos> <def>same as <er>brunet</er>;
<as>as, a <ex>dark-haired</ex> beauty</as>.</def><br/
<syn><b>Syn. --</b> black-haired.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>darkie</ent><br/
<hw>dark"ie</hw> <pr>(d<aum/r"k<emac/)</pr>, <pos>n.</pos> <def>a black
person; an African-American; -- an older term now considered
offensive.</def><br/
<syn><b>Syn. --</b> darky, darkey.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Darkish</ent><br/
<hw>Dark"ish</hw> <pr>(d<aum/r"k<icr/sh)</pr>, <pos>a.</pos>
<def>Somewhat dark; dusky.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Darkle</ent><br/
<hw>Dar"kle</hw> <pr>(d<aum/r"k'l)</pr>, <pos>v. i.</pos> <ety>[Freq. of
<ets>dark</ets>.]</ety> <def>To grow dark; to show indistinctly.</def>
<rj><au>Thackeray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Darkling</ent><br/
<hw>Dark"ling</hw> <pr>(d<aum/rk"l<icr/ng)</pr>, <pos>adv.</pos>
<ety>[<ets>Dark</ets> + the adverbial suffix <ets>-ling</ets>.]</ety>
<def>In the dark.</def> <mark>[Poetic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>So, out went the candle, and we were left <qex>darkling</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>As the wakeful bird</qex><br/
<qex>Sings darkling</qex>.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Darkling</ent><br/
<hw>Dark"ling</hw>, <pos>p. pr. & a.</pos> <sn>1.</sn> <def>Becoming
dark or gloomy; frowing.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His honest brows <qex>darkling</qex> as he looked towards me.</q>
<rj><qau>Thackeray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Dark; gloomy.</def> <ldquo/The <xex>darkling</xex>
precipice.<rdquo/ <rj><au>Moore.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Darkly</ent><br/
<hw>Dark"ly</hw>, <pos>adv.</pos> <sn>1.</sn> <def>With imperfect light,
clearness, or knowledge; obscurely; dimly; blindly;
uncertainly.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>What fame to future times conveys but <qex>darkly</qex> down.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>so softly dark and <qex>darkly</qex> pure.</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>With a dark, gloomy, cruel, or menacing
look.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Looking <qex>darkly</qex> at the clerguman.</q>
<rj><qau>Hawthorne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Darkness</ent><br/
<hw>Dark"ness</hw>, <pos>n.</pos> <sn>1.</sn> <def>The absence of light;
blackness; obscurity; gloom.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And <qex>darkness</qex> was upon the face of the deep.</q>
<rj><qau>Gen. i. 2.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A state of privacy; secrecy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>What I tell you in <qex>darkness</qex>, that speak ye in
light.</q> <rj><qau>Matt. x. 27.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A state of ignorance or error, especially on moral
or religious subjects; hence, wickedness; impurity.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Men loved <qex>darkness</qex> rather than light, because their
deeds were evil.</q> <rj><qau>John. iii. 19.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Pursue these sons of <qex>darkness</qex>: drive them out<br/
From all heaven's bounds.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Want of clearness or perspicuity; obscurity; <as>as,
the <ex>darkness</ex> of a subject, or of a discussion</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A state of distress or trouble.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A day of clouds and of thick <qex>darkness</qex>.</q>
<rj><qau>Joel. ii. 2.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 369 --></p>

<p><cs><col><b>Prince of darkness</b></col>, <cd>the Devil; Satan.</cd>
<ldquo/In the power of the <xex>Prince of darkness</xex>.<rdquo/
<rj><au>Locke.</au></rj></cs></p>

<p><syn><b>Syn.</b> -- <er>Darkness</er>, <er>Dimness</er>,
<er>Obscurity</er>, <er>Gloom</er>.</syn> <usage> <xex>Darkness</xex>
arises from a total, and <xex>dimness</xex> from a partial, want of
light. A thing is <xex>obscure</xex> when so overclouded or covered as
not to be easily perceived. As tha shade or <xex>obscurity</xex>
increases, it deepens into <xex>gloom</xex>. What is <xex>dark</xex> is
hidden from view; what is <xex>obscure</xex> is difficult to perceive or
penetrate; the eye becomes <xex>dim</xex> with age; an impending storm
fills the atmosphere with <xex>gloom</xex>. When taken figuratively,
these words have a like use; as, the <xex>darkness</xex> of ignorance;
<xex>dimness</xex> of discernment; <xex>obscurity</xex> of reasoning;
<xex>gloom</xex> of superstition.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>dark-skinned</ent><br/
<hw>dark-skinned</hw> <pos>adj.</pos> <sn>1.</sn> <def>same as
<er>colored</er>.</def> [Narrower terms: <stype>black (vs.
white)</stype>]<br/
<syn><b>Syn. --</b> colored, coloured.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>having a dark color; -- of skin color.</def><br/
<syn><b>Syn. --</b> dusky, swart, swarthy.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Darksome</ent><br/
<hw>Dark"some</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Dark; gloomy;
obscure; shaded; cheerless.</def> <mark>[Poetic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He brought him through a <qex>darksome</qex> narrow pass<br/
To a broad gate, all built of beaten gold.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>darky</ent><br/
<hw>dark"y</hw> <pr>(?)</pr>, <pos>n.</pos> <def>a negro; an
African-American; -- an older term now considered offensive.</def>
<mark>[Slang]</mark><br/
<syn><b>Syn. --</b> darkie, darkey.</syn><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>darling</ent><br/
<hw>dar"ling</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>derling</ets>, <ets>deorling</ets>, AS. <ets>de<oacute/rling</ets>;
<ets>de<oacute/re</ets> dear + <ets>-ling</ets>. See <er>Dear</er>, and
<er>-ling</er>.]</ety> <def>One dearly beloved; a favorite.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And can do naught but wail her <qex>darling's</qex> loss.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>darling</ent><br/
<hw>dar"ling</hw>, <pos>a.</pos> <def>Dearly beloved; regarded with
especial kindness and tenderness; favorite.</def> <ldquo/Some
<xex>darling</xex> science.<rdquo/ <au>I. Watts.</au>
<ldquo/<xex>Darling</xex> sin.<rdquo/ <au>Macaulay.</au><br/
[<source>1913 Webster</source>]</p>

<p><ent>Darlingtonia</ent><br/
\'d8<hw>Dar`ling*to"ni*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL.
Named after Dr. William <etsep>Darlington</etsep>, a botanist of West
Chester, Penn.]</ety> <fld>(Bot.)</fld> <def>A genus of California
pitcher plants consisting of a single species. The long tubular leaves
are hooded at the top, and frequently contain many insects drowned in
the secretion of the leaves.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Darmera</ent><br/
<hw>Darmera</hw> <pos>n.</pos> <def>a genus consisting of one
species.</def><br/
<syn><b>Syn. --</b> genus <gen>Darmera</gen>, Peltiphyllum, genus
<gen>Peltiphyllum</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Darn</ent><br/
<hw>Darn</hw> <pr>(d<aum/rn)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Darned</conjf> <pr>(d<aum/rnd)</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>Darning</conjf>.]</vmorph> <ety>[OE.
<ets>derne</ets>, prob. of Celtic origin; cf. W. <ets>darnio</ets> to
piece, break in pieces, W. & Arm. to E. <ets>tear</ets>. Cf.
<er>Tear</er>, <pos>v. t.</pos>]</ety> <def>To mend as a rent or hole,
with interlacing stitches of yarn or thread by means of a needle; to sew
together with yarn or thread.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He spent every day ten hours in his closet, in <qex>darning</qex>
his stockings.</q> <rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Darning last</b></col>. <cd>See under <er>Last</er>.</cd>
-- <col><b>Darning needle</b></col>. <sd>(a)</sd> <cd>A long, strong
needle for mending holes or rents, especially in stockings.</cd>
<sd>(b)</sd> <fld>(Zool.)</fld> <cd>Any species of dragon fly, having a
long, cylindrical body, resembling a needle. These flies are harmless
and without stings. <note>[In this sense, usually written with a
hyphen.]</note> Called also <altname>devil's
darning-needle</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Darn</ent><br/
<hw>Darn</hw>, <pos>n.</pos> <def>A place mended by darning.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Darn</ent><br/
<hw>Darn</hw>, <pos>v. t.</pos> <def>A colloquial euphemism for
<er>Damn</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>darned</ent><br/
<hw>darned</hw> <pos>adj.</pos> <def>an intensifying expletive; a
euphemism for <altname>damned</altname>; <as>as, for no <ex>darned</ex>
reason at all</as>.</def><br/
<syn><b>Syn. --</b> blasted, blessed, damn, damned, deuced, goddam,
goddamn, goddamned, gosh-darned.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>darnel</ent><br/
<hw>dar"nel</hw> <pr>(d<acr/r"n<ecr/l)</pr>, <pos>n.</pos> <ety>[OE.
<ets>darnel</ets>, <ets>dernel</ets>, of uncertain origin; cf. dial. F.
<ets>darnelle</ets>, Sw. <ets>d<aring/r-repe</ets>; perh. named from a
supposed intoxicating quality of the plant, and akin to Sw.
<ets>d<aring/ra</ets> to infatuate, OD. <ets>door</ets> foolish, G.
<ets>thor</ets> fool, and Ee. <ets>dizzy</ets>.]</ety> <fld>(Bot.)</fld>
<def>Any grass of the genus <gen>Lolium</gen>, esp. the <spn>Lolium
temulentum</spn> (bearded darnel), the grains of which have been reputed
poisonous. Other species, as <spn>Lolium perenne</spn> (rye grass or ray
grass), and its variety <spn>Lolium Italicum</spn> (Italian rye grass),
are highly esteemed for pasture and for making hay.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Under <xex>darnel</xex> our early herbalists
comprehended all kinds of cornfield weeds.</note> <rj><au>Dr.
Prior.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Darner</ent><br/
<hw>Darn"er</hw> <pr>(d<acr/rn"<etil/r)</pr>, <pos>n.</pos> <def>One who
mends by darning.</def></p>

<p><ent>Darnic</ent><br/
<ent>Darnex</ent><br/
<mhw>{ <hw>Dar"nex</hw> <pr>(d<acr/r"n<ecr/ks)</pr>, <hw>Dar"nic</hw>
<pr>(d<acr/r"n<icr/k)</pr>, }</mhw> <pos>n.</pos> <def>Same as
<er>Dornick</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daroo</ent><br/
\'d8<hw>Da*roo"</hw> <pr>(d<adot/*r<oomac/")</pr>, <pos>n.</pos>
<fld>(Bot.)</fld> <def>The Egyptian sycamore (<spn>Ficus
Sycamorus</spn>). See <er>Sycamore</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Darr</ent><br/
<hw>Darr</hw> <pr>(d<acr/r)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>The European black tern.</def></p>

<p><ent>Darrain</ent><br/
<ent>Darraign</ent><br/
<mhw>{ <hw>Dar"raign</hw>, <hw>Dar"rain</hw>, }</mhw> <pr>(?)</pr>,
<pos>v. t.</pos> <ety>[OF. <ets>deraisnier</ets> to explain, defend, to
maintain in legal action by proof and reasonings, LL.
<ets>derationare</ets>; <ets>de-</ets> + <ets>rationare</ets> to
discourse, contend in law, fr. L. <ets>ratio</ets> reason, in LL., legal
cause. Cf. <er>Arraign</er>, and see <er>Reason</er>.]</ety> <sn>1.</sn>
<def>To make ready to fight; to array.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Darrain</qex> your battle, for they are at hand.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To fight out; to contest; to decide by combat.</def>
<mark>[Obs.]</mark> <ldquo/To <xex>darrain</xex> the battle.<rdquo/
<rj><au>Chaucer .</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Darrein</ent><br/
<hw>Dar"rein</hw>, <pos>a.</pos> <ety>[OF. <ets>darrein</ets>,
<ets>darrain</ets>, fr. an assumed LL. <ets>deretranus</ets>; L.
<ets>de</ets> + <ets>retro</ets> back, backward.]</ety> <fld>(Law)</fld>
<def>Last; <as>as, <ex>darrein</ex> continuance, the last
continuance</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dart</ent><br/
<hw>Dart</hw> <pr>(d<aum/rt)</pr>, <pos>n.</pos> <ety>[OF.
<ets>dart</ets>, of German origin; cf. OHG. <ets>tart</ets> javelin,
dart, AS. <ets>dara<edh/</ets>, <ets>daro<edh/</ets>, Sw.
<ets>dart</ets> dagger, Icel. <ets>darra<edh/r</ets> dart.]</ety>
<sn>1.</sn> <def>A pointed missile weapon, intended to be thrown by the
hand; a short lance; a javelin; hence, any sharp-pointed missile weapon,
as an arrow.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And he [Joab] took three <qex>darts</qex> in his hand, and thrust
them through the heart of Absalom.</q> <rj><qau>2 Sa. xviii.
14.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Anything resembling a dart; anything that pierces or
wounds like a dart.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The artful inquiry, whose venomed <qex>dart</qex><br/
Scarce wounds the hearing while it stabs the heart.</q> <rj><qau>Hannan
More.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A spear set as a prize in running.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Zool.)</fld> <def>A fish; the dace. See
<er>Dace</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dart sac</b></col> <fld>(Zool.)</fld>, <cd>a sac
connected with the reproductive organs of land snails, which contains a
dart, or arrowlike structure.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dart</ent><br/
<hw>Dart</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Darted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Darting</conjf>.]</vmorph> <sn>1.</sn> <def>To throw with a
sudden effort or thrust, as a dart or other missile weapon; to hurl or
launch.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To throw suddenly or rapidly; to send forth; to
emit; to shoot; <as>as, the sun <ex>darts</ex> forth his
beams</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Or what ill eyes malignant glances <qex>dart</qex>?</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dart</ent><br/
<hw>Dart</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To fly or pass swiftly,
as a dart.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To start and run with velocity; to shoot rapidly
along; <as>as, the deer <ex>darted</ex> from the thicket</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dartars</ent><br/
<hw>Dar"tars</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>dartre</ets>
eruption, dandruff. <root/240.]</ety> <def>A kind of scab or ulceration
on the skin of lambs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>dart board</ent><br/
<ent>dartboard</ent><br/
<mhw><hw>dartboard</hw>, <hw>dart board</hw></mhw> <pos>n.</pos> <def>a
circular board of wood or cork used as the target in the game of darts.
It may have any of several patterns on it, such as concentric circles,
or a central circle with rays.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Darter</ent><br/
<hw>Dart"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who
darts, or who throw darts; that which darts.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>The snakebird, a water bird of
the genus <gen>Plotus</gen>; -- so called because it darts out its long,
snakelike neck at its prey. See <er>Snakebird</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <def>A small fresh-water etheostomoid
fish. The group includes numerous genera and species, all of them
American. See <er>Etheostomoid</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dartingly</ent><br/
<hw>Dart"ing*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>Like a dart;
rapidly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dartle</ent><br/
<hw>Dar"tle</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <def>To pierce or
shoot through; to dart repeatedly: -- frequentative of
<xex>dart</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>My star that <qex>dartles</qex> the red and the blue.</q>
<rj><qau>R. Browning.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dartoic</ent><br/
<hw>Dar*to"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Anat.)</fld>
<def>Of or pertaining to the dartos.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dartoid</ent><br/
<hw>Dar"toid</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Dartos</ets> +
<ets>-oid</ets>.]</ety> <fld>(Anat.)</fld> <def>Like the dartos;
dartoic; <as>as, <ex>dartoid</ex> tissue</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dartos</ent><br/
\'d8<hw>Dar"tos</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<ets>dart'os</ets> flayed.]</ety> <fld>(Anat.)</fld> <def>A thin layer
of peculiar contractile tissue directly beneath the skin of the
scrotum.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dartrous</ent><br/
<hw>Dar"trous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F.
<ets>dartreux</ets>. See <er>Dartars</er>.]</ety> <fld>(Med.)</fld>
<def>Relating to, or partaking of the nature of, the disease called
tetter; herpetic.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dartrous diathesis</b></col>, <cd>A morbid condition of
the system predisposing to the development of certain skin diseases,
such as eczema, psoriasis, and pityriasis. Also called <altname>rheumic
diathesis</altname>, and <altname>herpetism</altname>.</cd>
<rj><au>Piffard.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Darussalam Bandar Seri Begawan</ent><br/
<hw>Darussalam Bandar Seri Begawan</hw> <pos>prop. n.</pos>
<fld>(Geography)</fld> <def>The capital <isa>city</isa> of
<country>Brunei</country>. Population (2000) = 52,300.</def><br/
[<source>PJC</source>]</p>

<p><ent>Darwinian</ent><br/
<hw>Dar*win"i*an</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From the name of
Charles <ets>Darwin</ets>, an English scientist.]</ety> <def>Pertaining
to Darwin; <as>as, the <ex>Darwinian</ex> theory, a theory of the manner
and cause of the supposed development of living things from certain
original forms or elements</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ This theory was put forth by Darwin in 1859 in a work
entitled <ldquo/The Origin of species by Means of Natural
Selection.<rdquo/ The author argues that, in the struggle for existence,
those plants and creatures best fitted to the requirements of the
situation in which they are placed are the ones that will live; in other
words, that Nature selects those which are to survive. This is the
theory of <xex>natural selection</xex> or the <xex>survival of the
fittest</xex>. He also argues that natural selection is capable of
modifying and producing organisms fit for their circumstances. See
<cref>Development theory</cref>, under <er>Development</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Darwinian</ent><br/
<hw>Dar*win"i*an</hw>, <pos>n.</pos> <def>An advocate of
Darwinism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Darwinianism</ent><br/
<hw>Dar*win"i*an*ism</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Darwinism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Darwinism</ent><br/
<hw>Dar"win*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Biol.)</fld>
<def>The theory or doctrines put forth by Darwin. See above.</def>
<rj><au>Huxley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dase</ent><br/
<hw>Dase</hw> <pr>(d<amac/z)</pr>, <pos>v. t.</pos> <def>See
<er>Daze</er>.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dasewe</ent><br/
<hw>Dase"we</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[OE.
<ets>dasewen</ets>, <ets>daswen</ets>; cf. AS. <ets>dysegian</ets> to be
foolish.]</ety> <def>To become dim-sighted; to become dazed or
dazzled.</def> <mark>[Obs.]</mark> <rj><au>Chauscer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dash</ent><br/
<hw>Dash</hw> <pr>(d<acr/sh)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Dashed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Dashing</conjf>.]</vmorph> <ety>[Of. Scand. origin; cf.
Dan <ets>daske</ets> to beat, strike, Sw. & Icel. <ets>daska</ets>, Dan.
& Sw. <ets>dask</ets> blow.]</ety> <sn>1.</sn> <def>To throw with
violence or haste; to cause to strike violently or hastily; -- often
used with <xex>against</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If you <qex>dash</qex> a stone against a stone in the botton of
the water, it maketh a sound.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To break, as by throwing or by collision; to
shatter; to crust; to frustrate; to ruin.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou shalt <qex>dash</qex> them in pieces like a potter's
vessel.</q> <rj><qau>Ps. ii. 9.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A brave vessel, . . . <br/
<qex>Dashed</qex> all to pieces.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To perplex and <qex>dash</qex><br/
Maturest counsels.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To put to shame; to confound; to confuse; to abash;
to depress.</def> <rj><au>South.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Dash</qex> the proud gamester in his gilded car.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To throw in or on in a rapid, careless manner; to
mix, reduce, or adulterate, by throwing in something of an inferior
quality; to overspread partially; to bespatter; to touch here and there;
<as>as, to <ex>dash</ex> wine with water; to <ex>dash</ex> paint upon a
picture.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>I take care to <qex>dash</qex> the character with such particular
circumstance as may prevent ill-natured applications.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The very source and fount of day<br/
Is <qex>dashed</qex> with wandering isles of night.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To form or sketch rapidly or carelessly; to execute
rapidly, or with careless haste; -- with <ptcl>off</ptcl>; <as>as, to
<ex>dash</ex> off a review or sermon</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To erase by a stroke; to strike out; knock out; --
with <ptcl>out</ptcl>; <as>as, to <ex>dash</ex> out a
word</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dash</ent><br/
<hw>Dash</hw>, <pos>v. i.</pos> <def>To rush with violence; to move
impetuously; to strike violently; <as>as, the waves <ex>dash</ex> upon
rocks</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>[He] <qex>dashed</qex> through thick and thin.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>On each hand the gushing waters play,<br/
And down the rough cascade all <qex>dashing</qex> fall.</q>
<rj><qau>Thomson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dash</ent><br/
<hw>Dash</hw>, <pos>n.</pos> <sn>1.</sn> <def>Violent striking together
of two bodies; collision; crash.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A sudden check; abashment; frustration; ruin;
<as>as, his hopes received a <ex>dash</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A slight admixture, infusion, or adulteration; a
partial overspreading; <as>as, wine with a <ex>dash</ex> of water; red
with a <ex>dash</ex> of purple.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Innocence when it has in it a <qex>dash</qex> of folly.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A rapid movement, esp. one of short duration; a
quick stroke or blow; a sudden onset or rush; <as>as, a bold
<ex>dash</ex> at the enemy; a <ex>dash</ex> of rain.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>She takes upon her bravely at first <qex>dash</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Energy in style or action; animation;
spirit.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>A vain show; a blustering parade; a flourish;
<as>as, to make or cut a great <ex>dash</ex></as>.</def>
<mark>[Low]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Punctuation)</fld> <def>A mark or line [--], in
writing or printing, denoting a sudden break, stop, or transition in a
sentence, or an abrupt change in its construction, a long or significant
pause, or an unexpected or epigrammatic turn of sentiment. Dashes are
also sometimes used instead of marks or parenthesis.</def> <rj><au>John
Wilson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <fld>(Mus.)</fld> <sd>(a)</sd> <def>The sign of staccato,
a small mark [\'fa] denoting that the note over which it is placed is to
be performed in a short, distinct manner.</def> <sd>(b)</sd> <def>The
line drawn through a figure in the thorough bass, as a direction to
raise the interval a semitone.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <fld>(Racing)</fld> <def>A short, spirited effort or
trial of speed upon a race course; -- used in horse racing, when a
single trial constitutes the race.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dashboard</ent><br/
<hw>Dash"board`</hw> <pr>(d<acr/sh"b<omac/rd`)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>A board placed on the fore part of a carriage, sleigh,
or other vehicle, to intercept water, mud, or snow, thrown up by the
heels of the horses; -- in England commonly called
<altname>splashboard</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Naut.)</fld> <sd>(a)</sd> <def>The float of a
paddle wheel.</def> <sd>(b)</sd> <def>A screen at the bow of a steam
launch to keep off the spray; -- called also
<altname>sprayboard</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>an instrument panel beneath the front window of a
motor vehicle (such as an automobile or truck), containing indicating
gauges and dials, such as the speedometer and fuel gauges, and sometimes
certain control knobs or other devices.</def><br/
[<source>PJC</source>]</p>

<p><ent>Dasheen</ent><br/
<hw>Dash`een"</hw> <pr>(d<acr/sh`<emac/n")</pr>, <pos>n.</pos>
<sn>1.</sn> <def>A tropical aroid (of the genus <gen>Caladium</gen>,
syn. <gen>Colocasia</gen>) having an edible farinaceous root. It is
related to the taro and to the tanier, but is much superior to it in
quality and is as easily cooked as the potato. It is a staple food plant
of the tropics, being prepared like potatoes, and has been introduced
into the Southern United States.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>a herb of the Pacific islands grown throughout the
tropics for its edible root and in temperate areas as an ornamental for
its large glossy leaves.</def><br/
<syn><b>Syn. --</b> taro, taro plant, dalo, Colocasia
esculenta.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>3.</sn> <def>the edible starchy tuberous root of taro
plants.</def><br/
<syn><b>Syn. --</b> taro, cocoyam, eddo.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>4.</sn> <def>a tropical starchy tuberous root.</def><br/
<syn><b>Syn. --</b> taro, taro root, cocoyam, edda.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>dasher</ent><br/
<hw>dash"er</hw> <pr>(d<acr/sh"<etil/r)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>That which dashes or agitates; <as>as, the <ex>dasher</ex> of a
churn</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A dashboard or splashboard.</def> <mark>[U.
S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>One who makes an ostentatious parade.</def>
<mark>[Low]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dashing</ent><br/
<hw>Dash"ing</hw>, <pos>a.</pos> <def>Bold; spirited; showy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>dashing</qex> and daring spirit is preferable to the
listless.</q> <rj><qau>T. Campbell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dashingly</ent><br/
<hw>Dash"ing*ly</hw>, <pos>adv.</pos> <def>Conspicuously; showily.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q> A <qex>dashingly</qex> dressed gentleman.</q>
<rj><qau>Hawthorne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dashism</ent><br/
<hw>Dash"ism</hw> <pr>(-<icr/z'm)</pr>, <pos>n.</pos> <def>The character
of making ostentatious or blustering parade or show.</def> <mark>[R. &
Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He must fight a duel before his claim to . . . <qex>dashism</qex>
can be universally allowed.</q> <rj><qau>V. Knox.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>dash-pot</ent><br/
<ent>dashpot</ent><br/
<mhw><hw>dash"pot`</hw>, <hw>dash-pot</hw></mhw>
<pr>(d<acr/sh"p<ocr/t`)</pr>, <pos>n.</pos> <fld>(Mach.)</fld> <def>a
mechanical damping device containing a piston that moves in a
fluid-filled chamber to serve as a pneumatic or hydraulic cushion for a
falling weight, as in the valve gear of a steam engine, to prevent
shock.</def><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><-- letters refer to illustration --> <note><hand/ It consists of a
chamber, containing air or a liquid, in which a piston (<it>a</it>),
attached to the weight, falls freely until it enters a space (as below
the openings, <it>b</it>) from which the air or liquid can escape but
slowly (as through cock <it>c</it>), when its fall is gradually
checked.</note><br/
[<source>1913 Webster</source>]</p>

<p><note>A cataract of an engine is sometimes called a
<xex>dashpot</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dashy</ent><br/
<hw>Dash"y</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From
<er>Dash</er>.]</ety> <def>Calculated to arrest attention;
ostentatiously fashionable; showy.</def> <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dastard</ent><br/
<hw>Das"tard</hw> <pr>(d<acr/s"t<etil/rd)</pr>, <pos>n.</pos>
<ety>[Prob. from Icel. <ets>d<ae/str</ets> exhausted. breathless, p. p.
of <ets>d<ae/sa</ets> to groan, lose one's breath; cf. <ets>dasask</ets>
to become exhausted, and E. <ets>daze</ets>.]</ety> <def>One who meanly
shrinks from danger; an arrant coward; a poltroon.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>You are all recreants and <qex>dashtards</qex>, and delight to
live in slavery to the nobility.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dastard</ent><br/
<hw>Das"tard</hw>, <pos>a.</pos> <def>Meanly shrinking from danger;
cowardly; dastardly.</def> <ldquo/Their <xex>dastard</xex> souls.<rdquo/
<rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dastard</ent><br/
<hw>Das"tard</hw>, <pos>v. t.</pos> <def>To dastardize.</def>
<mark>[R.]</mark> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dastardize</ent><br/
<hw>Das"tard*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Dastardized</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Dastardizing</conjf>.]</vmorph> <def>To make cowardly;
to intimidate; to dispirit; <as>as, to <ex>dastardize</ex> my
courage</as>.</def> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dastardliness</ent><br/
<hw>Das"tard*li*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The quality
of being dastardly; cowardice; base fear.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dastardly</ent><br/
<hw>Das"tard*ly</hw>, <pos>a.</pos> <def>Meanly timid; cowardly; base;
<as>as, a <ex>dastardly</ex> outrage</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dastardness</ent><br/
<hw>Das"tard*ness</hw>, <pos>n.</pos> <def>Dastardliness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dastardy</ent><br/
<hw>Das"tard*y</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Base timidity;
cowardliness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daswe</ent><br/
<hw>Das"we</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>See
<er>Dasewe</er></def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dasymeter</ent><br/
<hw>Da*sym"e*ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>dasy`s</grk> rough, thick + <ets>-meter</ets>.]</ety>
<fld>(Physics)</fld> <def>An instrument for testing the density of
gases, consisting of a thin glass globe, which is weighed in the gas or
gases, and then in an atmosphere of known density.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dasypaedal</ent><br/
<hw>Das`y*p<ae/"dal</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Dasyp<ae/dic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dasypaedes</ent><br/
\'d8<hw>Das`y*p<ae/"des</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
from Gr. <grk>dasy`s</grk> hairy, shaggy + <ets><grk>pai^s</grk></ets>,
<ets><grk>paido`s</grk></ets>, a child.]</ety> <fld>(Zool.)</fld>
<def>Those birds whose young are covered with down when
hatched.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dasypaedic</ent><br/
<hw>Das`y*p<ae/"dic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Pertaining to the Dasyp<ae/des; ptilop<ae/dic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dasyproctidae</ent><br/
<hw>Dasyproctidae</hw> <pos>n.</pos> <def>a natural family including the
agoutis and pacas.</def><br/
<syn><b>Syn. --</b> family <fam>Dasyproctidae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dasypus</ent><br/
<hw>Dasypus</hw> <pos>n.</pos> <def>the type genus of the
<fam>Dasypodidae</fam>.</def><br/
<syn><b>Syn. --</b> genus <gen>Dasypus</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dasyuridae</ent><br/
<hw>Dasyuridae</hw> <pos>n.</pos> <def>a natural family including the
dasyures, native cats, pouched mice, banded anteaters, and Tasmanian
devils.</def><br/
<syn><b>Syn. --</b> family <fam>Dasyuridae</fam>, family
<fam>Dasyurinae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>dasyure</ent><br/
<hw>das"y*ure</hw> <pr>(d<acr/s"<icr/*<umac/r)</pr>, <pos>n.</pos>
<ety>[Gr. <grk>dasy`s</grk> thick, shaggy + <grk>o'yra`</grk> tail: cf.
F. <ets>dasyure</ets>.]</ety> <sn>1.</sn> <fld>(Zool.)</fld> <def>A
carnivorous catlike marsupial quadruped of Australia, belonging to the
genus <gen>Dasyurus</gen>, called also <altname>native cat</altname>.
There are several species.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>any of several related animals,
such as the Tasmanian devil; -- called also <altname>ursine
dasyure</altname>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Dasyurine</ent><br/
<hw>Das`y*u"rine</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Pertaining to, or like, the dasyures.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dasyurus</ent><br/
<hw>Dasyurus</hw> <pos>n.</pos> <def>the type genus of the family
Dasyuridae: native cats.</def><br/
<syn><b>Syn. --</b> genus <gen>Dasyurus</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>DAT</ent><br/
<hw>DAT</hw> <pos>n.</pos> <ety>[acronym, from <ets>D</ets>igital
<ets>A</ets>udio<ets>T</ets>ape.]</ety> <def>digital audiotape, a
digitally encoded tape recording of sound; -- in contrast to the usual
analog audio tape.</def> <mark>[acronym]</mark> <br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Data</ent><br/
\'d8<hw>Da"ta</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[L.
<ets>pl</ets>. of <ets>datum</ets>.]</ety> <sn>1.</sn> <def>See
<er>Datum</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>a collection of facts, observations, or other
information related to a particular question or problem; <as>as, the
historical <ex>data</ex> show that the budget deficit is only a small
factor in determining interest rates</as>.</def> <note>The term in this
sense is used especially in reference to experimental observations
collected in the course of a controlled scientific
investigation.</note><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <fld>(Computers)</fld> <def>information, most commonly in
the form of a series of binary digits, stored on a physical storage
medium for manipulation by a computer program. It is contrasted with the
<contr>program</contr> which is a series of instructions used by the
central processing unit of a computer to manipulate the <ex>data</ex>.
In some computers <ex>data</ex> and executable programs are stored in
separate locations.</def><br/
[<source>PJC</source>]</p>

<p><ent>database</ent><br/
<hw>database</hw> <pos>n.</pos> <def>an organized body of related
information.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>data-based</ent><br/
<hw>data-based</hw> <pos>adj.</pos> <def>relying on observation or
experiment.</def><br/
<syn><b>Syn. --</b> experimental, observational.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>datable</ent><br/
<hw>dat"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>That may be dated;
having a known or ascertainable date.</def> <ldquo/<xex>Datable</xex>
almost to a year.<rdquo/ <rj><au>The Century.</au></rj><br/
<syn><b>Syn. --</b> dateable.</syn>
[<source>1913 Webster</source>]</p>

<p><ent>Dataria</ent><br/
\'d8<hw>Da*ta"ri*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL., fr. L.
<ets>datum</ets> given.]</ety> <fld>(R. C. Ch.)</fld> <def>Formerly, a
part of the Roman chancery; now, a separate office from which are sent
graces or favors, cognizable <xex>in foro externo</xex>, such as
appointments to benefices. The name is derived from the word
<xex>datum</xex>, given or dated (with the indications of the time and
place of granting the gift or favor).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Datary</ent><br/
<hw>Da"ta*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL.
<ets>datarius</ets>. See <er>Dataria</er>.]</ety> <sn>1.</sn> <fld>(R.
C. Ch.)</fld> <def>An officer in the pope's court, having charge of the
Dataria.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The office or employment of a datary.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Date</ent><br/
<hw>Date</hw>, <pos>n.</pos><ety>[F. <ets>datte</ets>, L.
<ets>dactylus</ets>, fr. Gr. <ets><?/</ets>, prob. not the same word as
<grk>da`ktylos</grk> finger, but of Semitic origin.]</ety>
<fld>(Bot.)</fld> <def>The fruit of the date palm; also, the date palm
itself.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ This fruit is somewhat in the shape of an olive,
containing a soft pulp, sweet, esculent, and wholesome, and inclosing a
hard kernel.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Date palm</b></col>, <it>or</it> <col><b>Date
tree</b></col></mcol> <fld>(Bot.)</fld>, <cd>the genus of palms which
bear dates, of which common species is <spn>Ph<oe/nix dactylifera</spn>.
See <xex>Illust.</xex></cd> -- <col><b>Date plum</b></col>
<fld>(Bot.)</fld>, <cd>the fruit of several species of
<gen>Diospyros</gen>, including the American and Japanese persimmons,
and the European lotus (<spn>Diospyros Lotus</spn>).</cd> --
<mcol><col><b>Date shell</b></col>, <it>or</it> <col><b>Date
fish</b></col></mcol> <fld>(Zool.)</fld>, <cd>a bivalve shell, or its
inhabitant, of the genus <gen>Pholas</gen>, and allied genera. See
<er>Pholas</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 370 --></p>

<p><ent>Date</ent><br/
<hw>Date</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>date</ets>, LL.
<ets>data</ets>, fr. L. <ets>datus</ets> given, p. p. of <ets>dare</ets>
to give; akin to Gr. <ets><?/</ets>, OSlaw. <ets>dati</ets>, Skr.
<ets>d<amac/</ets>. Cf. <er>Datum</er>, <ets>Dose</ets>, <er>Dato</er>,
<er>Die</er>.]</ety> <sn>1.</sn> <def>That addition to a writing,
inscription, coin, etc., which specifies the time (as day, month, and
year) when the writing or inscription was given, or executed, or made;
<as>as, the <ex>date</ex> of a letter, of a will, of a deed, of a
coin</as>. etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And bonds without a <qex>date</qex>, they say, are void.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The point of time at which a transaction or event
takes place, or is appointed to take place; a given point of time;
epoch; <as>as, the <ex>date</ex> of a battle</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He at once,<br/
Down the long series of eventful time,<br/
So fixed the <qex>dates</qex> of being, so disposed<br/
To every living soul of every kind<br/
The field of motion, and the hour of rest.</q>
<rj><qau>Akenside.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Assigned end; conclusion.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>What Time would spare, from Steel receives its
<qex>date</qex>.</q> <rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Given or assigned length of life; duration.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Good luck prolonged hath thy <qex>date</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Through his life's whole <qex>date</qex>.</q>
<rj><qau>Chapman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To bear date</b></col>, <cd>to have the date named on the
face of it; -- said of a writing.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Date</ent><br/
<hw>Date</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Dated</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Dating</conjf>.]</vmorph> <ety>[Cf. F. <ets>dater</ets>. See 2d
<er>Date</er>.]</ety> <sn>1.</sn> <def>To note the time of writing or
executing; to express in an instrument the time of its execution;
<as>as, to <ex>date</ex> a letter, a bond, a deed, or a
charter</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To note or fix the time of, as of an event; to give
the date of; <as>as, to <ex>date</ex> the building of the
pyramids</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ We may say <xex>dated at</xex> or <xex>from</xex> a
place.</note><br/
[<source>1913 Webster</source>]</p>

<p><q>The letter is <qex>dated</qex> at Philadephia.</q> <rj><qau>G. T.
Curtis.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>You will be suprised, I don't question, to find among your
correspondencies in foreign parts, a letter <qex>dated from</qex>
Blois.</q> <rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>In the countries of his jornal seems to have been written; parts
of it are <qex>dated from</qex> them.</q> <rj><qau>M.
Arnold.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Date</ent><br/
<hw>Date</hw>, <pos>v. i.</pos> <def>To have beginning; to begin; to be
dated or reckoned; -- with <xex>from</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The Batavian republic <qex>dates</qex> from the successes of the
French arms.</q> <rj><qau>E. Everett.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>dateable</ent><br/
<hw>dateable</hw> <pos>adj.</pos> <def>that can be given a date.
Opposite of <ant>undatable</ant>.</def> [Narrower terms:
<stype>dated</stype>]<br/
<syn><b>Syn. --</b> datable.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><q>a concrete and <qex>dateable</qex> happening</q> <qau>C. W.
Shumaker</qau></p>

<p><ent>dated</ent><br/
<hw>dated</hw> <pos>adj.</pos> <sn>1.</sn> <def>marked by features of
the immediate and usually discounted past.</def><br/
<syn><b>Syn. --</b> outmoded; pass<eacute/.</syn>
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>bearing a date; <as>as, <ex>dated</ex> and stamped
documents</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>dateless</ent><br/
<hw>date"less</hw>, <pos>a.</pos> <sn>1.</sn> <def>Without date; having
no fixed time.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>not having a social companion for an occasion;
<as>as, to be <ex>dateless</ex> for the prom</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Date line</ent><br/
<hw>Date line</hw>. <def>The hypothetical line on the surface of the
earth fixed by international or general agreement as a boundary on one
side of which the same day shall have a different name and date in the
calendar from its name and date on the other side. Also called
<altname>International Date Line</altname>.</def><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><note><hand/ Speaking generally, the date line coincides with the
meridian 180<deg/ from Greenwich. It deflects between north latitudes
80<deg/ and 45<deg/, so that all Asia lies to the west, all North
America, including the Aleutian Islands, to the east of the line; and
between south latitudes 12<deg/ and 56<deg/, so that Chatham Island and
the Tonga group lie to the west of it. A vessel crossing this line to
the westward sets the date forward by one day, as from Sunday to Monday.
A vessel crossing the line to the eastward sets the date back by one
day, as from Monday to Sunday. Hawaii has the same day name as San
Francisco; Manila, the same day name as Australia, and this is one day
later than the day of Hawaii. Thus when it is Monday May 1st at San
Francisco it is Tuesday may 2d at Manila.</note><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Dater</ent><br/
<hw>Dat"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
dates.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Datiscin</ent><br/
<hw>Da*tis"cin</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>A white crystalline glucoside extracted from the bastard hemp
(<spn>Datisca cannabina</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dative</ent><br/
<hw>Da"tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>dativus</ets>
appropriate to giving, fr. <ets>dare</ets> to give. See 2d
<er>Date</er>.]</ety> <sn>1.</sn> <fld>(Gram.)</fld> <def>Noting the
case of a noun which expresses the remoter object, and is generally
indicated in English by <xex>to</xex> or <xex>for</xex> with the
objective.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <sd>(a)</sd> <def>In one's gift; capable
of being disposed of at will and pleasure, as an office.</def>
<sd>(b)</sd> <def>Removable, as distinguished from perpetual; -- said of
an officer.</def> <sd>(c)</sd> <def>Given by a magistrate, as
distinguished from being cast upon a party by the law.</def>
<rj><au>Burril. Bouvier.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dative executor</b></col>, <cd>one appointed by the judge
of probate, his office answering to that of an
administrator.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dative</ent><br/
<hw>Da"tive</hw>, <pos>n.</pos> <ety>[L. <ets>dativus</ets>.]</ety>
<def>The dative case. See <er>Dative</er>, <pos>a.</pos>, 1.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Datively</ent><br/
<hw>Da"tive*ly</hw>, <pos>adv.</pos> <def>As a gift.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Datolite</ent><br/
<hw>Dat"o*lite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From. Gr.
<ets><grk>date`omai</grk></ets> to divide + <ets>-lite</ets>; in
allusion to the granular structure of a massive variety.]</ety>
<fld>(Min.)</fld> <def>A borosilicate of lime commonly occurring in
glassy,, greenish crystals.</def> <altsp>[Written also
<asp>datholite</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Datril</ent><br/
<hw>Datril</hw> <pos>n.</pos> <def>an analgesic derived from
acetanolide; also used as an antipyretic; Datril and Tylenol are
trademarks of brands of acetaminophen tablets. See
<er>acetaminophen</er>.</def><br/
<syn><b>Syn. --</b> acetaminophen, Tylenol.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Datum</ent><br/
\'d8<hw>Da"tum</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Data</plw> <pr>(#)</pr>.</plu> <ety>[L. See 2d
<er>Date</er>.]</ety> <sn>1.</sn> <def>Something given or admitted; a
fact or principle granted; that upon which an inference or an argument
is based; -- used chiefly in the plural.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Any writer, therefore, who . . . furnishes us with <qex>data</qex>
sufficient to determine the time in which he wrote.</q>
<rj><qau>Priestley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>a single piece of information; a fact; especially a
piece of information obtained by observation or experiment; -- used
mostly in the plural.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <pluf>pl.</pluf> <fld>(Math.)</fld> <def>The quantities
or relations which are assumed to be given in any problem.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Surveying)</fld> <def>a point, line, or level
surface used as a reference in measuring elevations.</def>
<au>RHUD</au><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Datum line</b></col> <fld>(Surv.)</fld>, <cd>the
horizontal or base line, from which the heights of points are reckoned
or measured, as in the plan of a railway, etc.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Datura</ent><br/
\'d8<hw>Da*tu"ra</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL.; cf. Skr.
<ets>dhatt<umac/ra</ets>, Per. & Ar. <ets>tat<umac/ra</ets>,
<ets>Tat<umac/la</ets>.]</ety> <fld>(Bot.)</fld> <def>A genus of
solanaceous plants, with large funnel-shaped flowers and a four-celled,
capsular fruit.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The commonest species are the thorn apple (<spn>D.
stramonium</spn>), with a prickly capsule (see <xex>Illust.</xex> of
<er>capsule</er>), white flowers and green stem, and <spn>Datura
tatula</spn>, with a purplish tinge of the stem and flowers. Both are
narcotic and dangerously poisonous.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daturine</ent><br/
<hw>Da*tu"rine</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<er>Datura</er>.]</ety> <fld>(Chem.)</fld> <def>Atropine; -- called also
<altname>daturia</altname> and <altname>daturina</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daub</ent><br/
<hw>Daub</hw> <pr>(d<add/b)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Daubed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Daubing</conjf>.]</vmorph> <ety>[OE. <ets>dauben</ets>
to smear, OF. <ets>dauber</ets> to plaster, fr. L. <ets>dealbare</ets>
to whitewash, plaster; <ets>de-</ets> + <ets>albare</ets> to whiten, fr.
<ets>albus</ets> white, perh. also confused with W. <ets>dwb</ets>
plaster, <ets>dwbio</ets> to plaster, Ir. & OGael. <ets>dob</ets>
plaster. See <er>Alb</er>, and cf. <er>Dealbate</er>.]</ety> <sn>1.</sn>
<def>To smear with soft, adhesive matter, as pitch, slime, mud, etc.; to
plaster; to bedaub; to besmear.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>She took for him an ark of bulrushes, and <qex>daubed</qex> it
with slime and with pitch.</q> <rj><qau>Ex. ii. 3.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To paint in a coarse or unskillful manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If a picture is <qex>daubed</qex> with many bright and glaring
colors, the vulgar admire it is an excellent piece.</q> <rj><qau>I.
Watts.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A lame, imperfect piece, rudely <qex>daubed</qex> over.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To cover with a specious or deceitful exterior; to
disguise; to conceal.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>So smooth he <qex>daubed</qex> his vice with show of virtue.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To flatter excessively or glossy.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I can safely say, however, that, without any <qex>daubing</qex> at
all,<br/
I am very sincerely your very affectionate, humble servant.</q>
<rj><qau>Smollett.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To put on without taste; to deck gaudily.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Let him be <qex>daubed</qex> with lace.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daub</ent><br/
<hw>Daub</hw> <pr>(d<add/b)</pr>, <pos>v. i.</pos> <def>To smear; to
play the flatterer.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His conscience . . . will not <qex>daub</qex> nor flatter.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daub</ent><br/
<hw>Daub</hw>, <pos>n.</pos> <sn>1.</sn> <def>A viscous, sticky
application; a spot smeared or daubed; a smear.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Paint.)</fld> <def>A picture coarsely
executed.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Did you . . . take a look at the grand picture? . . . 'T is a
melancholy <qex>daub</qex>, my lord.</q> <rj><qau>Sterne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>daubed</ent><br/
<hw>daubed</hw> <pos>adj.</pos> <def>smeared thickly; <as>as,
mud-<ex>daubed</ex> walls</as>.</def><br/
<syn><b>Syn. --</b> beplastered, besmeared.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Daubentonia</ent><br/
<hw>Daubentonia</hw> <pos>n.</pos> <sn>1.</sn> <def>the type genus,
coextensive with the family <fam>Daubentoniidae</fam>.</def><br/
<syn><b>Syn. --</b> genus <gen>Daubentonia</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Daubentoniidae</ent><br/
<hw>Daubentoniidae</hw> <pos>n.</pos> <def>a natural family comprising
solely the <er>aye-aye</er>.</def><br/
<syn><b>Syn. --</b> family <fam>Daubentoniidae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dauber</ent><br/
<hw>Daub"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who,
or that which, daubs; especially, a coarse, unskillful
painter.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Copperplate Print.)</fld> <def>A pad or ball of
rags, covered over with canvas, for inking plates; a dabber.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A low and gross flatterer.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Zool.)</fld> <def>The mud wasp; the mud
dauber.</def></p>

<p><ent>Daubry</ent><br/
<ent>Daubery</ent><br/
<mhw>{ <hw>Daub"er*y</hw> <pr>(?)</pr>, <it>or</it> <hw>Daub"ry</hw>
<pr>(?)</pr> }</mhw>, <pos>n.</pos> <def>A daubing; specious coloring;
false pretenses.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>She works by charms, by spells, by the figure, and such
<qex>daubery</qex> as this is.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daubing</ent><br/
<hw>Daub"ing</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act of one who
daubs; that which is daubed.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A rough coat of mortar put upon a wall to give it
the appearance of stone; rough-cast.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>In currying, a mixture of fish oil and tallow worked
into leather; -- called also <altname>dubbing</altname>.</def>
<rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daubreelite</ent><br/
<hw>Dau"bree*lite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<ets>Daubr<eacute/e</ets>, a French mineralogist.]</ety>
<fld>(Min.)</fld> <def>A sulphide of chromium observed in some meteoric
irons.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dauby</ent><br/
<hw>Daub"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Smeary; viscous;
glutinous; adhesive.</def> <ldquo/<xex>Dauby</xex> wax.<rdquo/<br/
[<source>1913 Webster</source>]</p>

<p><ent>Daughter</ent><br/
<hw>Daugh"ter</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Daughters</plw> <pr>(#)</pr>; <mark>obs. pl</mark>.
<plw>Daughtren</plw> <pr>(#)</pr>.</plu> <ety>[OE. <ets>doughter</ets>,
<ets>doghter</ets>, <ets>dohter</ets>, AS. <ets>dohtor</ets>,
<ets>dohter</ets>; akin to OS. <ets>dohtar</ets>, D. <ets>dochter</ets>,
G. <ets>tochter</ets>, Icel. <ets>d<omac/ttir</ets>, Sw.
<ets>dotter</ets>, Dan. <ets>dotter</ets>, <ets>datter</ets>, Goth.
<ets>da<uacute/htar</ets>,, OSlav. <ets>d<ucr/shti</ets>, Russ.
<ets>doche</ets>, Lith. <ets>dukt<emac/</ets>, Gr. <grk>qyga`thr</grk>,
Zend. <ets>dughdhar</ets>, Skr. <ets>duhit<rsdot/</ets>; possibly
originally, the milker, cf. Skr. <ets>duh</ets> to milk. <root/68,
245.]</ety> <sn>1.</sn> <def>The female offspring of the human species;
a female child of any age; -- applied also to the lower
animals.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A female descendant; a woman.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This woman, being a <qex>daughter</qex> of Abraham.</q>
<rj><qau>Luke xiii. 16.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Dinah, the <qex>daughter</qex> of Leah, which she bare unto Jacob,
went out to see the <qex>daughter</qex> of the land.</q> <rj><qau>Gen.
xxxiv. 1.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A son's wife; a daughter-in-law.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And Naomi said, Turn again, my <qex>daughters</qex>.</q>
<rj><qau>Ruth. i. 11.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A term of address indicating parental
interest.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Daughter</qex>, be of good comfort.</q> <rj><qau>Matt. ix.
22.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Daughter cell</b></col> <fld>(Biol.)</fld>, <cd>one of
the cells formed by cell division. See <cref>Cell division</cref>, under
<er>Division</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daughter-in-law</ent><br/
<hw>Daugh"ter-in-law`</hw> <pr>(?)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Daughters-in-law</plw>.</plu> <def>The wife of
one's son.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daughterliness</ent><br/
<hw>Daugh"ter*li*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state of
a daughter, or the conduct becoming a daughter.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daughterly</ent><br/
<hw>Daugh"ter*ly</hw>, <pos>a.</pos> <def>Becoming a daughter;
filial.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Sir Thomas liked her natural and dear <qex>daughterly</qex>
affection towards him.</q> <rj><qau>Cavendish.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dauk</ent><br/
<hw>Dauk</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>See <er>Dawk</er>,
<pos>v. t.</pos>, to cut or gush.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daun</ent><br/
<hw>Daun</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A variant of
<xex>Dan</xex>, a title of honor.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daunt</ent><br/
<hw>Daunt</hw> <pr>(d<add/nt; 277)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Daunted</conjf>; <pos>p. pr. &
vb. n.</pos> <conjf>Daunting</conjf>.]</vmorph> <ety>[OF.
<ets>danter</ets>, F. <ets>dompter</ets> to tame, subdue, fr. L.
<ets>domitare</ets>, v. intens. of <ets>domare</ets> to tame. See
<er>Tame</er>.]</ety> <sn>1.</sn> <def>To overcome; to conquer.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To repress or subdue the courage of; to check by
fear of danger; to cow; to intimidate; to dishearten.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Some presences <qex>daunt</qex> and discourage us.</q>
<rj><qau>Glanvill.</qau></rj></p>

<p><syn><b>Syn.</b> -- To dismay; appall. See <er>Dismay</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daunter</ent><br/
<hw>Daunt"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
daunts.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>daunting</ent><br/
<hw>daunting</hw> <pos>adj.</pos> <def>serving to discourage,
dishearten, or intimidate; discouraging; disheartening. Opposite of
<ant>encouraging</ant>.</def><br/
<syn><b>Syn. --</b> intimidating.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>dauntless</ent><br/
<hw>daunt"less</hw>, <pos>a.</pos> <def>Incapable of being daunted;
undaunted; bold; fearless; intrepid.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Dauntless</qex> he rose, and to the fight returned.</q>
<rj><qau>Dryden.</qau></rj></p>

<p>-- <wordforms><wf>Daunt"less*ly</wf>, <pos>adv.</pos> --
<wf>Daunt"less*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>dauntlessness</ent><br/
<hw>dauntlessness</hw> <pos>n.</pos> <def>resolute
courageousness.</def><br/
<syn><b>Syn. --</b> intrepidity.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dauphin</ent><br/
<hw>Dau"phin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>dauphin</ets>, prop., a dolphin, from L. <ets>delphinus</ets>. See
<er>Dolphin</er>. The name was given, for some reason unexplained, to
Guigo, count of Vienne, in the 12th century, and was borne by succeeding
counts of Vienne. In 1349, Dauphiny was bequeathed to Philippe de
Valois, king of France, on condition that the heir of the crown should
always hold the title of <ets>Dauphin</ets> de Viennois.]</ety> <def>The
title of the eldest son of the king of France, and heir to the crown.
Since the revolution of 1830, the title has been discontinued.</def></p>

<p><ent>Dauphine</ent><br/
<ent>Dauphiness</ent><br/
<mhw>{ <hw>Dau"phin*ess</hw> <pr>(?)</pr>, <it>or</it>
<hw>Dau"phine</hw> <pr>(?)</pr> }</mhw>, <pos>n.</pos> <def>The title of
the wife of the dauphin.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dauw</ent><br/
\'d8<hw>Dauw</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[D.]</ety>
<fld>(Zool.)</fld> <def>The striped quagga, or Burchell's zebra, of
South Africa (<spn>Asinus Burchellii</spn>); -- called also
<altname>peechi</altname>, or <altname>peetsi</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>davallia</ent><br/
<hw>davallia</hw> <pos>n.</pos> <def>any fern of the genus
<gen>Davallia</gen>; they have scaly creeping rhizomes.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Davalliaceae</ent><br/
<hw>Davalliaceae</hw> <pos>n.</pos> <def>one of a number of families
into which Polypodiaceae has been subdivided in some classification
systems; includes genera <gen>Araiostegia</gen>; <gen>Davallia</gen>;
<gen>Davallodes</gen>; <gen>Gymnogrammitis</gen>; <gen>Humata</gen>;
<gen>Leucostegia</gen>; <gen>Scyphularia</gen>;
<gen>Trogostolon</gen>.</def><br/
<syn><b>Syn. --</b> family <fam>Davalliaceae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Davenport</ent><br/
<hw>Dav"en*port</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From the name of
the original maker. <au>Encyc. Dict.</au>]</ety> <def>A kind of small
writing table, generally somewhat ornamental, and forming a piece of
furniture for the parlor or boudoir.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A much battered <qex>davenport</qex> in one of the windows, at
which sat a lady writing.</q> <rj><qau>A. B. Edwards.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Davidic</ent><br/
<hw>Da*vid"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining to
<etsep>David</etsep>, the king and psalmist of Israel, or to his
family.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daviesia</ent><br/
<hw>Daviesia</hw> <pos>n.</pos> <def>a genus of Australasian shrubs and
subshrubs having small yellow or purple flowers followed by short
triangular pods.</def><br/
<syn><b>Syn. --</b> genus <gen>Daviesia</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Davit</ent><br/
<hw>Dav"it</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>davier</ets> forceps, davit, cooper's instrument, G.
<ets>david</ets> davit; all probably from the proper name
<ets>David</ets>.]</ety> <fld>(Naut.)</fld> <sd>(a)</sd> <def>A spar
formerly used on board of ships, as a crane to hoist the flukes of the
anchor to the top of the bow, without injuring the sides of the ship; --
called also the <altname>fish davit</altname>.</def> <sd>(b)</sd>
<pluf>pl.</pluf> <def>Curved arms of timber or iron, projecting over a
ship's side of stern, having tackle to raise or lower a boat, swing it
in on deck, rig it out for lowering, etc.; -- called also <altname>boat
davits</altname>.</def> <rj><au>Totten.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Davy Jones</ent><br/
<hw>Da"vy Jones"</hw> <pr>(?)</pr>. <def>The spirit of the sea; sea
devil; -- a term used by sailors.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This same <qex>Davy Jones</qex>, according to the mythology of
sailors, is the fiend that presides over all the evil spirits of the
deep, and is seen in various shapes warning the devoted wretch of death
and woe.</q> <rj><qau>Smollett.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Davy Jones's Locker</b></col>, <cd>the ocean, or bottom
of the ocean.</cd> -- <col><b>Gone to Davy Jones's Locker</b></col>,
<cd>dead, and buried in the sea; thrown overboard.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Davy lamp</ent><br/
<hw>Da"vy lamp`</hw> <pr>(?)</pr>. <def>See <cref>Safety lamp</cref>,
under <er>Lamp</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Davyne</ent><br/
<hw>Da"vyne</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Davyum</er>.]</ety> <fld>(Min.)</fld> <def>A variety of nephelite
from Vesuvius.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Davyum</ent><br/
<hw>Da"vy*um</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Named after
<person>Sir Humphry <etsep>Davy</etsep></person>, the English
chemist.]</ety> <fld>(Chem.)</fld> <def>A rare metallic element found in
platinum ore. It is a white malleable substance. Symbol Da. Atomic
weight 154.</def><-- ? Europium is 152(the closest)? --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daw</ent><br/
<hw>Daw</hw> <pr>(d<add/)</pr>, <pos>n.</pos> <ety>[OE. <ets>dawe</ets>;
akin to OHG. <ets>t<amac/ha</ets>, MHG. <ets>t<amac/he</ets>,
<ets>t<amac/hele</ets>, G. <ets>dohle</ets>. Cf. <er>Caddow</er>.]</ety>
<fld>(Zool.)</fld> <def>A European bird of the Crow family (<spn>Corvus
monedula</spn>), often nesting in church towers and ruins; a
jackdaw.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The loud <qex>daw</qex>, his throat<br/
displaying, draws<br/
The whole assembly of his fellow <qex>daws</qex>.</q>
<rj><qau>Waller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The <xex>daw</xex> was reckoned as a silly bird, and a
<xex>daw</xex> meant a simpleton. See in Shakespeare: -- <ldquo/Then
thou dwellest with <xex>daws</xex> too.<rdquo/ (<au>Coriolanus iv. 5, 1.
47.</au>) <au>Skeat.</au></note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daw</ent><br/
<hw>Daw</hw>, <pos>v. i.</pos> <ety>[OE. <ets>dawen</ets>. See
<er>Dawn</er>.]</ety> <def>To dawn.</def> <mark>[Obs.]</mark> <see>See
Dawn.</see> <rj><au>Drayton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daw</ent><br/
<hw>Daw</hw>, <pos>v. t.</pos> <ety>[Contr. fr. <er>Adaw</er>.]</ety>
<sn>1.</sn> <def>To rouse.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To daunt; to terrify.</def> <mark>[Obs.]</mark>
<rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dawdle</ent><br/
<hw>Daw"dle</hw> <pr>(d<add/"d'l)</pr>, <pos>v. i.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Dawdled</conjf> <pr>(?)</pr>;
<pos>p. pr. & vb. n.</pos> <conjf>Dawdling</conjf>
<pr>(?)</pr>.]</vmorph> <ety>[Cf. <er>Daddle</er>.]</ety> <def>To waste
time in trifling employment; to trifle; to saunter.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Come some evening and <qex>dawdle</qex> over a dish of tea with
me.</q> <rj><qau>Johnson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>We . . . <qex>dawdle</qex> up and down Pall Mall.</q>
<rj><qau>Thackeray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dawdle</ent><br/
<hw>Daw"dle</hw>, <pos>v. t.</pos> <def>To waste by trifling; <as>as, to
<ex>dawdle</ex> away a whole morning</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dawdle</ent><br/
<hw>Daw"dle</hw>, <pos>n.</pos> <def>A dawdler.</def> <rj><au>Colman &
Carrick.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dawdler</ent><br/
<hw>Daw"dler</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who wastes time
in trifling employments; an idler; a trifler.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dawe</ent><br/
<hw>Dawe</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See <er>Day</er>.]</ety>
<def>Day.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dawish</ent><br/
<hw>Daw"ish</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Like a daw.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dawk</ent><br/
\'d8<hw>Dawk</hw> <pr>(d<add/k)</pr>, <pos>n.</pos> <def>See
<er>Dak</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dawk</ent><br/
<hw>Dawk</hw>, <pos>v. t.</pos> <ety>[Prov. E. <ets>dauk</ets> to cut or
pierce with a jerk; cf. OE. <ets>dalk</ets> a dimple. Cf. Ir.
<ets>tolch</ets>, <ets>tollachd</ets>, <ets>tolladh</ets>, a hole,
crevice, <ets>toll</ets> to bore, pierce, W. <ets>tyllu</ets>.]</ety>
<def>To cut or mark with an incision; to gash.</def>
<rj><au>Moxon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dawk</ent><br/
<hw>Dawk</hw>, <pos>n.</pos> <def>A hollow, crack, or cut, in
timber.</def> <rj><au>Moxon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dawn</ent><br/
<hw>Dawn</hw> <pr>(d<add/n)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Dawned</conjf> <pr>(d<add/nd)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Dawning</conjf>.]</vmorph> <ety>[OE. <ets>dawnen</ets>,
<ets>dawen</ets>, <ets>dagen</ets>, <ets>daien</ets>, AS.
<ets>dagian</ets> to become day, to dawn, fr. <ets>d<ae/g</ets> day;
akin to D. <ets>dagen</ets>, G. <ets>tagen</ets>, Icel. <ets>daga</ets>,
Dan. <ets>dages</ets>, Sw. <ets>dagas</ets>. See <er>Day</er>.
<root/71.]</ety> <sn>1.</sn> <def>To begin to grow light in the morning;
to grow light; to break, or begin to appear; <as>as, the day
<ex>dawns</ex>; the morning <ex>dawns</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>In the end of the Sabbath, as it began to <qex>dawn</qex> toward
the first day of the week, came <person>Mary Magdalene</person> . . . to
see the sepulcher.</q> <rj><qau>Matt. xxviii. 1.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To began to give promise; to begin to appear or to
expand.</def> <ldquo/In <xex>dawning</xex> youth.<rdquo/
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>When life awakes, and <qex>dawns</qex> at every line.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Dawn</qex> on our darkness and lend us thine aid.</q>
<rj><qau>Heber,</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dawn</ent><br/
<hw>Dawn</hw>, <pos>n.</pos> <sn>1.</sn> <def>The break of day; the
first appearance of light in the morning; show of approaching
sunrise.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And oft at <qex>dawn</qex>, deep noon, or falling eve.</q>
<rj><qau>Thomson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>No sun, no moon, no morn, no noon,<br/
No <qex>dawn</qex>, no dusk, no proper time of day.</q>
<rj><qau>Hood.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>First opening or expansion; first appearance;
beginning; rise.</def> <ldquo/The <xex>dawn</xex> of time.<rdquo/
<rj><au>Thomson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>These tender circumstances diffuse a <qex>dawn</qex> of serenity
over the soul.</q> <rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>dawning</ent><br/
<hw>dawn"ing</hw> <pos>n.</pos> <def>the first light of day;
dawn.</def><br/
<syn><b>Syn. --</b> dawn, morning, aurora, first light, daybreak, break
of day, break of the day, dayspring, sunrise, sunup, cockcrow.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dawsonite</ent><br/
<hw>Daw"son*ite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Named after J. W.
<ets>Dawson</ets> of Montreal.]</ety> <fld>(Min.)</fld> <def>A hydrous
carbonate of alumina and soda, occurring in white, bladed
crystals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Day</ent><br/
<hw>Day</hw> <pr>(d<amac/)</pr>, <pos>n.</pos> <ety>[OE. <ets>day</ets>,
<ets>dai</ets>, <ets>dei</ets>, AS. <ets>d<ae/g</ets>; akin to OS., D.,
Dan., & Sw. <ets>dag</ets>, G. <ets>tag</ets>, Icel. <ets>dagr</ets>,
Goth. <ets>dags</ets>; cf. Skr. <ets>dah</ets> (for <ets>dhagh</ets> ?)
to burn. <root/69. Cf. <er>Dawn</er>.]</ety> <sn>1.</sn> <def>The time
of light, or interval between one night and the next; the time between
sunrise and sunset, or from dawn to darkness; hence, the light;
sunshine; -- also called <altname>daytime</altname>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>The period of the earth's revolution on its axis. --
ordinarily divided into twenty-four hours. It is measured by the
interval between two successive transits of a celestial body over the
same meridian, and takes a specific name from that of the body. Thus, if
this is the sun, the day (the interval between two successive transits
of the sun's center over the same meridian) is called a <stype>solar
day</stype>; if it is a star, a <stype>sidereal day</stype>; if it is
the moon, a <stype>lunar day</stype>. See <cref>Civil day</cref>,
<cref>Sidereal day</cref>, below.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Those hours, or the daily recurring period, allotted
by usage or law for work.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A specified time or period; time, considered with
reference to the existence or prominence of a person or thing; age;
time.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A man who was great among the Hellenes of his <qex>day</qex>.</q>
<rj><qau>Jowett (Thucyd. )</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>If my debtors do not keep their <qex>day</qex>, . . . <br/
I must with patience all the terms attend.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>(Preceded by <xex>the</xex>) Some day in particular,
as some day of contest, some anniversary, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The field of Agincourt,<br/
Fought on the <qex>day</qex> of Crispin Crispianus.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>His name struck fear, his conduct won the <qex>day</qex>.</q>
<rj><qau>Roscommon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Day</xex> is much used in self-explaining
compounds; as, <xex>day</xex>break, <xex>day</xex>light,
work<xex>day</xex>, etc.</note><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 371 --></p>

<p><cs><col><b>Anniversary day</b></col>. <cd>See <er>Anniversary</er>,
<pos>n.</pos></cd> -- <col><b>Astronomical day</b></col>, <cd>a period
equal to the mean solar day, but beginning at noon instead of at
midnight, its twenty-four hours being numbered from 1 to 24; also, the
sidereal day, as that most used by astronomers.</cd> -- <col><b>Born
days</b></col>. <cd>See under <er>Born</er>.</cd> -- <col><b>Canicular
days</b></col>. <cd>See <er>Dog day</er>.</cd> -- <col><b>Civil
day</b></col>, <cd>the mean solar day, used in the ordinary reckoning of
time, and among most modern nations beginning at mean midnight; its
hours are usually numbered in two series, each from 1 to 12. This is the
period recognized by courts as constituting a day. The Babylonians and
Hindoos began their day at sunrise, the Athenians and Jews at sunset,
the ancient Egyptians and Romans at midnight.</cd> -- <col><b>Day
blindness</b></col>. <fld>(Med.)</fld> <cd>See <er>Nyctalopia</er>.</cd>
-- <mcol><col><b>Day by day</b></col>, <it>or</it> <col><b>Day after
day</b></col></mcol>, <cd>daily; every day; continually; without
intermission of a day. See under <er>By</er>.</cd> <ldquo/<xex>Day by
day</xex> we magnify thee.<rdquo/ <au>Book of Common Prayer.</au> --
<col><b>Days in bank</b></col> <fld>(Eng. Law)</fld>, <cd>certain stated
days for the return of writs and the appearance of parties; -- so called
because originally peculiar to the Court of Common Bench, or Bench
(<xex>bank</xex>) as it was formerly termed.</cd> <au>Burrill.</au> --
<col><b>Day in court</b></col>, <cd>a day for the appearance of parties
in a suit.</cd> -- <col><b>Days of devotion</b></col> <fld>(R. C.
Ch.)</fld>, <cd>certain festivals on which devotion leads the faithful
to attend mass.</cd> <au>Shipley.</au> -- <col><b>Days of
grace</b></col>. <cd>See <er>Grace</er>.</cd> -- <col><b>Days of
obligation</b></col> <fld>(R. C. Ch.)</fld>, <cd>festival days when it
is obligatory on the faithful to attend Mass.</cd> <au>Shipley.</au> --
<col><b>Day owl</b></col>, <fld>(Zool.)</fld>, <cd>an owl that flies by
day. See <er>Hawk owl</er>.</cd> -- <col><b>Day rule</b></col>
<fld>(Eng. Law)</fld>, <cd>an order of court (now abolished) allowing a
prisoner, under certain circumstances, to go beyond the prison limits
for a single day.</cd> -- <col><b>Day school</b></col>, <cd>one which
the pupils attend only in daytime, in distinction from a boarding
school.</cd> -- <col><b>Day sight</b></col>. <fld>(Med.)</fld> <cd>See
<er>Hemeralopia</er>.</cd> -- <col><b>Day's work</b></col>
<fld>(Naut.)</fld>, <cd>the account or reckoning of a ship's course for
twenty-four hours, from noon to noon.</cd> -- <col><b>From day to
day</b></col>, <cd>as time passes; in the course of time; <as>as, he
improves <ex>from day to day</ex></as>.</cd> -- <col><b>Jewish
day</b></col>, <cd>the time between sunset and sunset.</cd> --
<col><b>Mean solar day</b></col> <fld>(Astron.)</fld>, <cd>the mean or
average of all the apparent solar days of the year.</cd> --
<mcol><col><b>One day</b></col>, <col><b>One of these
days</b></col></mcol>, <cd>at an uncertain time, usually of the future,
rarely of the past; sooner or later.</cd> <ldquo/Well, niece, I hope to
see you <xex>one day</xex> fitted with a husband.<rdquo/ <au>Shak.</au>
-- <col><b>Only from day to day</b></col>, <cd>without certainty of
continuance; temporarily.</cd> <au>Bacon.</au> -- <col><b>Sidereal
day</b></col>, <cd>the interval between two successive transits of the
first point of Aries over the same meridian. The <ex>Sidereal day</ex>
is 23 h. 56 m. 4.09 s. of mean solar time.</cd> -- <col><b>To win the
day</b></col>, <cd>to gain the victory, to be successful.</cd> <au>S.
Butler.</au> -- <col><b>Week day</b></col>, <cd>any day of the week
except Sunday; a working day.</cd> -- <col><b>Working day</b></col>.
<sd>(a)</sd> <cd>A day when work may be legally done, in distinction
from Sundays and legal holidays.</cd> <sd>(b)</sd> <cd>The number of
hours, determined by law or custom, during which a workman, hired at a
stated price per day, must work to be entitled to a day's
pay.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dayaks</ent><br/
<hw>Day"aks</hw> <pr>(d<imac/"<acr/ks)</pr>, <pos>n. pl.</pos>
<fld>(Ethnol.)</fld> <def>See <er>Dyaks</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>day-and-night</ent><br/
<hw>day-and-night</hw> <pos>adj.</pos> <def>same as
<er>around-the-clock</er>.</def><br/
<syn><b>Syn. --</b> around-the-clock, nonstop,
round-the-clock.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>daybed</ent><br/
<hw>daybed</hw> <pos>n.</pos> <sn>1.</sn> <def>an armless couch; a seat
by day and a bed by night.</def><br/
<syn><b>Syn. --</b> divan bed.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>a long chair; for reclining.</def><br/
<syn><b>Syn. --</b> chaise longue, chaise.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>day boarder</ent><br/
<hw>day boarder</hw> <pos>n.</pos> <def>a schoolchild at a boarding
school who has meals at school but sleeps at home.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Daybook</ent><br/
<hw>Day"book`</hw> <pr>(d<amac/"b<oocr/k`)</pr>, <pos>n.</pos> <def>A
journal of accounts; a primary record book in which are recorded the
debts and credits, or accounts of the day, in their order, and from
which they are transferred to the journal.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>dayboy</ent><br/
<hw>dayboy</hw> <pos>n.</pos> <def>a <isa>day boarder</isa> who is a
boy.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Daybreak</ent><br/
<hw>Day"break`</hw> <pr>(d<amac/"br<amac/k`)</pr>, <pos>n.</pos>
<def>The time of the first appearance of light in the morning.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Day-coal</ent><br/
<hw>Day"-coal`</hw> <pr>(d<amac/"k<omac/l`)</pr>, <pos>n.</pos>
<fld>(Mining)</fld> <def>The upper stratum of coal, as nearest the light
or surface.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daydream</ent><br/
<hw>Day"dream`</hw> <pr>(-dr<emac/m`)</pr>, <pos>n.</pos> <def>A vain
fancy speculation; a reverie; a castle in the air; unfounded
hope.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Mrs. Lambert's little <qex>daydream</qex> was over.</q>
<rj><qau>Thackeray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daydreamer</ent><br/
<hw>Day"dream`er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One given to
daydreams.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dayflower</ent><br/
<hw>Day"flow`er</hw> <pr>(-flou`<etil/r)</pr>, <pos>n.</pos>
<fld>(Bot.)</fld> <def>A genus consisting mostly of tropical perennial
herbs (<gen>Commelina</gen>), having ephemeral flowers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dayfly</ent><br/
<hw>Day"fly`</hw> <pr>(d<amac/"fl<imac/`)</pr>, <pos>n.</pos>
<fld>(Zool.)</fld> <def>A neuropterous insect of the genus
<gen>Ephemera</gen> and related genera, of many species, and inhabiting
fresh water in the larval state; the ephemeral fly; -- so called because
it commonly lives but one day in the winged or adult state. See
<cref>Ephemeral fly</cref>, under <er>Ephemeral</er>.</def><-- = the
Mayfly? mayfly is ephemerid of order <ord>ephemeroptera</ord> [MW10].
"Mayfly" not in 1913 W. --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Day-labor</ent><br/
<hw>Day"-la`bor</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Labor hired or
performed by the day.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Day-laborer</ent><br/
<hw>Day"-la`bor*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who works
by the day; -- usually applied to a farm laborer, or to a workman who
does not work at any particular trade.</def>
<rj><au>Goldsmith.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daylight</ent><br/
<hw>Day"light`</hw> <pr>(-l<imac/t)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>The light of day as opposed to the darkness of night; the light of
the sun, as opposed to that of the moon or to artificial
light.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <pluf>pl.</pluf> <def>The eyes.</def> <mark>[Prov.
Eng.]</mark> <rj><au>Wright.</au></rj></p>

<p><-- 3. any opening in a surrounding enclosure, esp. one affording
escape; -- used in the phrase <ldquo/head for daylight<rdquo/. --><br/
[<source>1913 Webster</source>]</p>

<p><ent>daylily</ent><br/
<ent>day lily</ent><br/
<mhw><hw>day" lil`y</hw>, <hw>day"lil`y</hw></mhw>
<pr>(l<icr/l`<ycr/)</pr>. <fld>(Bot.)</fld> <sd>(a)</sd> <def>any plant
of a genus of plants (<gen>Hemerocallis</gen>) closely resembling true
lilies, but having tuberous rootstocks instead of bulbs. The common
species have long narrow leaves and either yellow or tawny-orange
flowers, which often bloom for only one day.</def> <sd>(b)</sd> <def>A
genus of plants (<gen>Funkia</gen>) differing from the last in having
ovate veiny leaves, and large white or blue flowers.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Daymaid</ent><br/
<hw>Day"maid`</hw> <pr>(-m<amac/d`)</pr>, <pos>n.</pos> <def>A
dairymaid.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daymare</ent><br/
<hw>Day"mare`</hw> <pr>(d<amac/"m<acir/r`)</pr>, <pos>n.</pos>
<ety>[<ets>Day</ets> + <ets>mare</ets> incubus.]</ety> <fld>(Med.)</fld>
<def>A kind of incubus which occurs during wakefulness, attended by the
peculiar pressure on the chest which characterizes nightmare.</def>
<rj><au>Dunglison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Day-net</ent><br/
<hw>Day"-net`</hw> <pr>(-n<ecr/t`)</pr>, <pos>n.</pos> <def>A net for
catching small birds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Day-peep</ent><br/
<hw>Day"-peep`</hw> <pr>(-p<emac/p`)</pr>, <pos>n.</pos> <def>The
dawn.</def> <mark>[Poetic]</mark> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daysman</ent><br/
<hw>Days"man</hw> <pr>(d<amac/z"m<acr/n)</pr>, <pos>n.</pos> <ety>[From
<ets>day</ets> in the sense of <it>day fixed for trial</it>.]</ety>
<def>An umpire or arbiter; a mediator.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Neither is there any <qex>daysman</qex> betwixt us.</q>
<rj><qau>Job ix. 33.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>dayspring</ent><br/
<hw>day"spring`</hw> <pr>(d<amac/"spr<icr/ng`)</pr>, <pos>n.</pos>
<def>The beginning of the day, or first appearance of light; the dawn;
hence, the beginning.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The tender mercy of our God; whereby the <qex>dayspring</qex> from
on high hath visited us.</q> <rj><qau>Luke i. 78.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>day-star</ent><br/
<hw>day"-star`</hw> <pr>(d<amac/"st<aum/r`)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>The morning star; the star which ushers in the day; --
usually the planet Venus, when seen before and just after
sunrise.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><q>A dark place, until the day dawn, and the <qex>day-star</qex>
arise in your hearts.</q> <rj><qau>2 Peter i. 19.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The sun, as the orb of day.</def>
<mark>[Poetic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>So sinks the <qex>day-star</qex> in the ocean bed,<br/
And yet anon repairs his drooping head,<br/
And tricks his beams, and with new-spangled ore<br/
Flames in the forehead of the morning sky.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>daytime</ent><br/
<hw>day"time`</hw> <pr>(d<amac/"t<imac/m`)</pr>, <pos>n.</pos> <def>The
time during which there is daylight, as distinguished from the night;
same as <er>day</er>, 1; <as>as, during the
<ex>daytime</ex></as>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>day-to-day</ent><br/
<hw>day-to-day</hw> <pos>adj.</pos> <def>occurring every day.</def> <br/
<syn><b>Syn. --</b> daily, day-after-day.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>daywoman</ent><br/
<hw>day"wom`an</hw> <pr>(d<amac/"w<oocr/m`<ait/n)</pr>, <pos>n.</pos>
<def>A dairymaid.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daze</ent><br/
<hw>Daze</hw> <pr>(d<amac/z)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Dazed</conjf> <pr>(d<amac/zd)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Dazing</conjf>.]</vmorph> <ety>[OE. <ets>dasen</ets>,
prob. from Icel. <ets>dasask</ets> to become weary, a reflexive verb;
cf. Sw. <ets>dasa</ets> to lie idle, and OD. <ets>daesen</ets> to be
foolish, insane, <ets>daes</ets>, <ets>dwaes</ets>, D. <ets>dwaas</ets>,
foolish, insane, AS. <ets>dw<aemac/s</ets>, <ets>dysig</ets>, stupid.
<root/71. Cf. <er>Dizzy</er>, <er>Doze</er>.]</ety> <def>To stupefy with
excess of light; with a blow, with cold, or with fear; to confuse; to
benumb.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>While flashing beams do <qex>daze</qex> his feeble eyen.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Such souls,<br/
Whose sudden visitations <qex>daze</qex> the world.</q> <rj><qau>Sir H.
Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He comes out of the room in a <qex>dazed</qex> state, that is an
odd though a sufficient substitute for interest.</q>
<rj><qau>Dickens.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Daze</ent><br/
<hw>Daze</hw>, <pos>n.</pos> <sn>1.</sn> <def>The state of being dazed;
<as>as, he was in a <ex>daze</ex></as>.</def> <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mining)</fld> <def>A glittering stone.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>dazed</ent><br/
<hw>dazed</hw> <pos>adj.</pos> <sn>1.</sn> <def>stupefied; conscious but
unable to think clearly; -- usually caused by a blow or other
shock.</def><br/
<syn><b>Syn. --</b> foggy, groggy, logy, stuporous.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>stunned from or as if from repeated blows.</def><br/
<syn><b>Syn. --</b> punch-drunk, silly, slaphappy.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dazzle</ent><br/
<hw>Daz"zle</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Dazzled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Dazzling</conjf> <pr>(?)</pr>.]</vmorph> <ety>[Freq. of
<ets>daze</ets>.]</ety> <sn>1.</sn> <def>To overpower with light; to
confuse the sight of by brilliance of light.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Those heavenly shapes<br/
Will <qex>dazzle</qex> now the earthly, with their blaze<br/
Insufferably bright.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>An unreflected light did never yet<br/
<qex>Dazzle</qex> the vision feminine.</q> <rj><qau>Sir H.
Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To bewilder or surprise with brilliancy or display
of any kind.</def> <ldquo/<xex>Dazzled</xex> and drove back his
enemies.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dazzle</ent><br/
<hw>Daz"zle</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To be overpoweringly
or intensely bright; to excite admiration by brilliancy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Ah, friend! to <qex>dazzle</qex>, let the vain design.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To be overpowered by light; to be confused by excess
of brightness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>An overlight maketh the eyes <qex>dazzle</qex>.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I dare not trust these eyes;<br/
They dance in mists, and <qex>dazzle</qex> with surprise.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dazzle</ent><br/
<hw>Daz"zle</hw>, <pos>n.</pos> <def>A light of dazzling
brilliancy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dazzlement</ent><br/
<hw>Daz"zle*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Dazzling flash,
glare, or burst of light.</def> <rj><au>Donne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dazzlingly</ent><br/
<hw>Daz"zling*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a dazzling
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>DBMS</ent><br/
<hw>DBMS</hw> <pos>n.</pos> <ety>[acronym from
<ets>D</ets>ata<ets>B</ets>ase <ets>M</ets>anagement
<ets>S</ets>ystem.]</ety> <def>a database management system, a software
system that facilitates the creation and maintenance and use of an
electronic database.</def><br/
<syn><b>Syn. --</b> database management system.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>D-day</ent><br/
<hw>D-day</hw> <pos>n.</pos> <sn>1.</sn> <fld>(Mil.)</fld> <def>the day
designated for the beginning of a planned attack by a military force; in
communications the day is often otherwise unspecified for security
reasons; <as>as, the day before <ex>D-day</ex> the troops will move into
position</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>6 June 1944, the day of the landing in France, by
troops allied against the Germans in World War II.</def><br/
<syn><b>Syn. --</b> 6 June 1944.</syn> <br/
[<source>WordNet 1.5</source>]</p>

<p><sn>3.</sn> <def>the day for commencement or execution of any
elaborate planned activity; -- often used jocosely.</def>
<mark>[informal]</mark><br/
[<source>PJC</source>]</p>

<p><ent>De-</ent><br/
<hw>De-</hw> <pr>(?)</pr>. <def>A prefix from Latin <xex>de</xex> down,
from, away; as in <xex>de</xex>bark, <xex>de</xex>cline,
<xex>de</xex>cease, <xex>de</xex>duct, <xex>de</xex>camp. In words from
the French it is equivalent to Latin <xex>dis-</xex> apart, away; or
sometimes to <xex>de</xex>. Cf. <er>Dis-</er>. It is negative and
opposite in <xex>de</xex>range, <xex>de</xex>form, <xex>de</xex>stroy,
etc. It is intensive in <xex>de</xex>prave, <xex>de</xex>spoil,
<xex>de</xex>clare, <xex>de</xex>solate, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>de-access</ent><br/
<hw>de-access</hw> <pos>v. t.</pos> <def>to sell or otherwise give up
ownership; -- used mostly of artworks in museums.</def><br/
<syn><b>Syn. --</b> sell off.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>de-accession</ent><br/
<ent>deaccession</ent><br/
<mhw><hw>deaccession</hw>, <hw>de-accession</hw></mhw> <pos>v. t.</pos>
<ety>[<ets>de-</ets> + <ets>accession</ets>. Ca. 1970.]</ety> <def>to
sell (artwork); -- used of sales of art by museums.</def> <note>The word
appears to have been coined as a euphemism to avoid the negative
connotations of the word <ldquo/sell<rdquo/, particularly for works
donated by benefactors. The practise is justified as a means of
acquiring funds for purchase of more valuable artworks.</note><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Deacon</ent><br/
<hw>Dea"con</hw> <pr>(d<emac/"k'n)</pr>, <pos>n.</pos> <ety>[OE.
<ets>diakne</ets>, <ets>deakne</ets>, <ets>deken</ets>, AS.
<ets>diacon</ets>, <ets>deacon</ets>, L. <ets>diaconus</ets>, fr. Gr.
<grk>dia`konos</grk> a servant or minister, a minister of the church; of
uncertain origin. In sense 2 prob. confused with <ets>dean</ets>.]</ety>
<sn>1.</sn> <fld>(Eccl.)</fld> <def>An officer in Christian churches
appointed to perform certain subordinate duties varying in different
communions. In the Roman Catholic and Episcopal churches, a person
admitted to the lowest order in the ministry, subordinate to the bishops
and priests. In Presbyterian churches, he is subordinate to the minister
and elders, and has charge of certain duties connected with the
communion service and the care of the poor. In Congregational churches,
he is subordinate to the pastor, and has duties as in the Presbyterian
church.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The chairman of an incorporated company.</def>
<mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deacon</ent><br/
<hw>Dea"con</hw> <pr>(d<emac/"k'n)</pr>, <pos>v. t.</pos> <sn>1.</sn>
<def>To read aloud each line of (a psalm or hymn) before singing it, --
usually with <ptcl>off</ptcl>.</def> <mark>[Colloq. New. Eng.]</mark>
See <er>Line</er>, <pos>v. t.</pos><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The expression is derived from a former custom in the
Congregational churches of New England. It was part of the office of a
deacon to read aloud the psalm given out, one line at a time, the
congregation singing each line as soon as read; -- called, also,
<ecol><b>lining out the psalm</b></ecol>.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>With humorous reference to hypocritical posing: To
pack (fruit or vegetables) with the finest specimens on top; to alter
slyly the boundaries of (land); to adulterate or doctor (an article to
be sold), etc.</def> <mark>[Colloq., U. S.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Deaconess</ent><br/
<hw>Dea"con*ess</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Eccl.)</fld>
<def>A female deacon</def>; as: <sd>(a)</sd> <fld>(Primitive Ch.)</fld>
<def>One of an order of women whose duties resembled those of
deacons.</def> <sd>(b)</sd> <fld>(Ch. of Eng. and Prot. Epis. Ch.)</fld>
<def>A woman set apart for church work by a bishop.</def> <sd>(c)</sd>
<def>A woman chosen as a helper in church work, as among the
Congregationalists.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deaconhood</ent><br/
<hw>Dea"con*hood</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state of
being a deacon; office of a deacon; deacon ship.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deaconry</ent><br/
<hw>Dea"con*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See <er>Deacon
ship</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deaconship</ent><br/
<hw>Dea"con*ship</hw>, <pos>n.</pos> <def>The office or ministry of a
deacon or deaconess.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>deactivate</ent><br/
<hw>de*ac"ti*vate</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To make
inactive; to render ineffective; <as>as, to <ex>deactivate</ex> a bomb;
to <ex>deactivate</ex> a machine; to <ex>deactivate</ex> the
alarm</as>.</def> <note>The <ex>deactivation</ex> of a machine or device
is usually a reversible process; switching off an electrical device may
be referred to as <ex>deactivation</ex>. To render an enzyme or catalyst
ineffective is more commonly referred to as to
<er>inactivate</er>.</note><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>To disband (a military unit, or other group); to
discontinue (a group activity); <as>as, to <ex>deactivate</ex> the
regiment; to <ex>deactivate</ex> the investigation</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>deactivation</ent><br/
<hw>de*ac`ti*va"tion</hw>, <pos>n.</pos> <def>The act or process of
deactivating.</def><br/
[<source>PJC</source>]</p>

<p><ent>Dead</ent><br/
<hw>Dead</hw> <pr>(d<ecr/d)</pr>, <pos>a.</pos> <ety>[OE.
<ets>ded</ets>, <ets>dead</ets>, <ets>deed</ets>, AS.
<ets>de<aacute/d</ets>; akin to OS. <ets>d<omac/d</ets>, D.
<ets>dood</ets>, G. <ets>todt</ets>, <ets>tot</ets>, Icel.
<ets>dau<edh/r</ets>, Sw. & Dan. <ets>d<oum/d</ets>, Goth.
<ets>daubs</ets>; prop. p. p. of an old verb meaning <ets>to die</ets>.
See <er>Die</er>, and cf. <er>Death</er>.]</ety> <sn>1.</sn>
<def>Deprived of life; -- opposed to <ant>alive</ant> and
<ant>living</ant>; reduced to that state of a being in which the organs
of motion and life have irrevocably ceased to perform their functions;
<as>as, a <ex>dead</ex> tree; a <ex>dead</ex> man.</as></def> <ldquo/The
queen, my lord, is <xex>dead</xex>.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The crew, all except himself, were <qex>dead</qex> of hunger.</q>
<rj><qau>Arbuthnot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Seek him with candle, bring him <qex>dead</qex> or living.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Destitute of life; inanimate; <as>as, <ex>dead</ex>
matter</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Resembling death in appearance or quality; without
show of life; deathlike; <as>as, a <ex>dead</ex> sleep</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Still as death; motionless; inactive; useless;
<as>as, <ex>dead</ex> calm; a <ex>dead</ex> load or
weight.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>So constructed as not to transmit sound; soundless;
<as>as, a <ex>dead</ex> floor</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Unproductive; bringing no gain; unprofitable;
<as>as, <ex>dead</ex> capital; <ex>dead</ex> stock in
trade.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>Lacking spirit; dull; lusterless; cheerless; <as>as,
<ex>dead</ex> eye; <ex>dead</ex> fire; <ex>dead</ex> color,
etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>Monotonous or unvaried; <as>as, a <ex>dead</ex>
level or pain; a <ex>dead</ex> wall.</as></def> <ldquo/The ground is a
<xex>dead</xex> flat.<rdquo/ <rj><au>C. Reade.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>Sure as death; unerring; fixed; complete; <as>as, a
<ex>dead</ex> shot; a <ex>dead</ex> certainty.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>I had them a <qex>dead</qex> bargain.</q>
<rj><qau>Goldsmith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <def>Bringing death; deadly.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>11.</sn> <def>Wanting in religious spirit and vitality; <as>as,
<ex>dead</ex> faith; <ex>dead</ex> works.</as></def>
<ldquo/<xex>Dead</xex> in trespasses.<rdquo/ <rj><au>Eph. ii.
1.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>12.</sn> <fld>(Paint.)</fld> <sd>(a)</sd> <def>Flat; without
gloss; -- said of painting which has been applied purposely to have this
effect.</def> <sd>(b)</sd> <def>Not brilliant; not rich; <as>thus, brown
is a <ex>dead</ex> color, as compared with crimson</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>13.</sn> <fld>(Law)</fld> <def>Cut off from the rights of a
citizen; deprived of the power of enjoying the rights of property;
<as>as, one banished or becoming a monk is civilly
<ex>dead</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>14.</sn> <fld>(Mach.)</fld> <def>Not imparting motion or power;
<as>as, the <ex>dead</ex> spindle of a lathe, etc.</as> See
<er>Spindle</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>15.</sn> <fld>(Elec.)</fld> <def>Carrying no current, or
producing no useful effect; -- said of a conductor in a dynamo or motor,
also of a telegraph wire which has no instrument attached and,
therefore, is not in use.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>16.</sn> <def>Out of play; regarded as out of the game; -- said
of a ball, a piece, or a player under certain conditions in cricket,
baseball, checkers, and some other games.</def></p>

<p><q>[In golf], a ball is said to lie <qex>dead</qex> when it lies so
near the hole that the player is certain to hole it in the next
stroke.</q> <rj><qau>Encyc. of Sport.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<cs><p><col><b>Dead ahead</b></col> <fld>(Naut.)</fld>, <cd>directly
ahead; -- said of a ship or any object, esp. of the wind when blowing
from that point toward which a vessel would go.</cd> -- <col><b>Dead
angle</b></col> <fld>(Mil.)</fld>, <cd>an angle or space which can not
be seen or defended from behind the parapet.</cd> -- <col><b>Dead
block</b></col>, <cd>either of two wooden or iron blocks intended to
serve instead of buffers at the end of a freight car.</cd> --
<col><b>Dead calm</b></col> <fld>(Naut.)</fld>, <cd>no wind at all.</cd>
-- <mcol><col><b>Dead center</b></col>, <it>or</it> <col><b>Dead
point</b></col></mcol> <fld>(Mach.)</fld>, <cd>either of two points in
the orbit of a crank, at which the crank and connecting rod lie a
straight line. It corresponds to the end of a stroke; as, <it>A</it> and
<it>B</it> are <xex>dead centers</xex> of the crank mechanism in which
the crank <it>C</it> drives, or is driven by, the lever <it>L</it>.</cd>
-- <col><b>Dead color</b></col> <fld>(Paint.)</fld>, <cd>a color which
has no gloss upon it.</cd> -- <col><b>Dead coloring</b></col> <fld>(Oil
paint.)</fld>, <cd>the layer of colors, the preparation for what is to
follow. In modern painting this is usually in monochrome.</cd> --
<col><b>Dead door</b></col> <fld>(Shipbuilding)</fld>, <cd>a storm
shutter fitted to the outside of the quarter-gallery door.</cd> --
<col><b>Dead flat</b></col> <fld>(Naut.)</fld>, <cd>the widest or
midship frame.</cd> -- <col><b>Dead freight</b></col> <fld>(Mar.
Law)</fld>, <cd>a sum of money paid by a person who charters a whole
vessel but fails to make out a full cargo. The payment is made for the
unoccupied capacity.</cd> <au>Abbott.</au> -- <col><b>Dead
ground</b></col> <fld>(Mining)</fld>, <cd>the portion of a vein in which
there is no ore.</cd> -- <col><b>Dead hand</b></col>, <cd>a hand that
can not alienate, as of a person civilly dead.</cd> <ldquo/Serfs held in
<xex>dead hand</xex>.<rdquo/ <au>Morley.</au> <see>See
<er>Mortmain</er>.</see> -- <col><b>Dead head</b></col>
<fld>(Naut.)</fld>, <cd>a rough block of wood used as an anchor
buoy.</cd> -- <col><b>Dead heat</b></col>, <cd>a heat or course between
two or more race horses, boats, etc., in which they come out exactly
equal, so that neither wins.</cd> -- <col><b>Dead horse</b></col>,
<cd>an expression applied to a debt for wages paid in advance.</cd>
<mark>[Law]</mark> -- <col><b>Dead language</b></col>, <cd>a language
which is no longer spoken or in common use by a people, and is known
only in writings, as the Hebrew, Greek, and Latin.</cd><-- Hebrew was
revived in modern Israel --> -- <col><b>Dead letter</b></col>.
<sd>(a)</sd> <cd>A letter which, after lying for a certain fixed time
uncalled for at the post office to which it was directed, is then sent
to the general post office to be opened.</cd> <sd>(b)</sd> <cd>That
which has lost its force or authority; as, the law has become a
<xex>dead letter</xex>.</cd> -- <col><b>Dead-letter office</b></col>,
<cd>a department of the general post office where dead letters are
examined and disposed of.</cd> -- <col><b>Dead level</b></col>, <cd>a
term applied to a flat country.</cd> -- <col><b>Dead lift</b></col>,
<sd>(a)</sd> <cd>a direct lift, without assistance from mechanical
advantage, as from levers, pulleys, etc.; hence, an extreme
emergency.</cd> <ldquo/(As we say) at a <xex>dead lift</xex>.<rdquo/
<au>Robynson (More's Utopia).</au> <sd>(b)</sd>
<fld>(Weighlifting)</fld> <cd>The lifting of a weight from the ground,
without raising it to the shoulders.</cd> -- <col><b>Dead line</b></col>
<fld>(Mil.)</fld>, <cd>a line drawn within or around a military prison,
to cross which involves for a prisoner the penalty of being instantly
shot.</cd> -- <col><b>Dead load</b></col> <fld>(Civil Engin.)</fld>,
<cd>a constant, motionless load, as the weight of a structure, in
distinction from a moving load, as a train of cars, or a variable
pressure, as of wind.</cd> -- <col><b>Dead march</b></col>
<fld>(Mus.)</fld>, <cd>a piece of solemn music intended to be played as
an accompaniment to a funeral procession.</cd> -- <col><b>Dead
nettle</b></col> <fld>(Bot.)</fld>, <cd>a harmless plant with leaves
like a nettle (<spn>Lamium album</spn>).</cd> -- <col><b>Dead
oil</b></col> <fld>(Chem.)</fld>, <cd>the heavy oil obtained in the
distillation of coal tar, and containing phenol, naphthalus,
etc.</cd><-- sic. naphthalins? --> -- <col><b>Dead plate</b></col>
<fld>(Mach.)</fld>, <cd>a solid covering over a part of a fire grate, to
prevent the entrance of air through that part.</cd> -- <col><b>Dead
pledge</b></col>, <cd>a mortgage. See <er>Mortgage</er>.</cd> --
<col><b>Dead point</b></col>. <fld>(Mach.)</fld> <cd>See <cref>Dead
center</cref>.</cd> -- <col><b>Dead reckoning</b></col>
<fld>(Naut.)</fld>, <cd>the method of determining the place of a ship
from a record kept of the courses sailed as given by compass, and the
distance made on each course as found by log, with allowance for leeway,
etc., without the aid of celestial observations.</cd> -- <col><b>Dead
rise</b></col>, <cd>the transverse upward curvature of a vessel's
floor.</cd> -- <col><b>Dead rising</b></col>, <cd>an elliptical line
drawn on the sheer plan to determine the sweep of the floorheads
throughout the ship's length.</cd> -- <col><b>Dead-Sea apple</b></col>.
<cd>See under <er>Apple</er>.</cd> -- <col><b>Dead set</b></col>.
<cd>See under <er>Set</er>.</cd> -- <col><b>Dead shot</b></col>.
<sd>(a)</sd> <cd>An unerring marksman.</cd> <sd>(b)</sd> <cd>A shot
certain to be made.</cd> -- <col><b>Dead smooth</b></col>, <cd>the
finest cut made; -- said of files.</cd> -- <col><b>Dead wall</b></col>
<fld>(Arch.)</fld>, <cd>a blank wall unbroken by windows or other
openings.</cd> -- <col><b>Dead water</b></col> <fld>(Naut.)</fld>,
<cd>the eddy water closing in under a ship's stern when sailing.</cd> --
<col><b>Dead weight</b></col>. <sd>(a)</sd> <cd>A heavy or oppressive
burden.</cd> <au>Dryden.</au> <sd>(b)</sd> <fld>(Shipping)</fld> <cd>A
ship's lading, when it consists of heavy goods; or, the heaviest part of
a ship's cargo.</cd> <sd>(c)</sd> <fld>(Railroad)</fld> <cd>The weight
of rolling stock, the live weight being the load.</cd> <au>Knight.</au>
-- <col><b>Dead wind</b></col> <fld>(Naut.)</fld>, <cd>a wind directly
ahead, or opposed to the ship's course.</cd> -- <col><b>To be
dead</b></col>, <cd>to die.</cd> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I deme thee, thou must algate be <qex>dead</qex>.</q>
<rj><qau>Chaucer.</qau></rj></p></cs>

<p><syn><b>Syn.</b> -- Inanimate; deceased; extinct. See
<er>Lifeless</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dead</ent><br/
<hw>Dead</hw> <pr>(d<ecr/d)</pr>, <pos>adv.</pos> <def>To a degree
resembling death; to the last degree; completely; wholly.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I was tired of reading, and <qex>dead</qex> sleepy.</q>
<rj><qau>Dickens.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dead drunk</b></col>, <cd>so drunk as to be
unconscious.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dead</ent><br/
<hw>Dead</hw> <pr>(d<ecr/d)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
most quiet or deathlike time; the period of profoundest repose,
inertness, or gloom; <as>as, the <ex>dead</ex> of winter</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>When the drum beat at <qex>dead</qex> of night.</q>
<rj><qau>Campbell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who is dead; -- commonly used
collectively.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And Abraham stood up from before his <qex>dead</qex>.</q>
<rj><qau>Gen. xxiii. 3.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dead</ent><br/
<hw>Dead</hw>, <pos>v. t.</pos> <def>To make dead; to deaden; to deprive
of life, force, or vigor.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Heaven's stern decree,<br/
With many an ill, hath numbed and <qex>deaded</qex> me.</q>
<rj><qau>Chapman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dead</ent><br/
<hw>Dead</hw>, <pos>v. i.</pos> <def>To die; to lose life or
force.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>So iron, as soon as it is out of the fire, <qex>deadeth</qex>
straightway.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>deadbeat</ent><br/
<ent>dead beat</ent><br/
<mhw><hw>dead` beat"</hw> <pr>(d<ecr/d`b<emac/t")</pr>,
<hw>dead"beat`</hw></mhw> <pr>(d<ecr/d"b<emac/t`)</pr>. <def>a loafer,
sponger, or swindler; especially, one who does not pay his debts. Same
as <er>Beat</er>, <pos>n.</pos>, 7.</def> <mark>[Low, U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deadbeat</ent><br/
<hw>Dead"beat`</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Physics)</fld>
<def>Making a beat without recoil; giving indications by a single beat
or excursion; -- said of galvanometers and other instruments in which
the needle or index moves to the extent of its deflection and stops with
little or no further oscillation.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Deadbeat escapement</b></col>. <cd>See under
<er>Escapement</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deadborn</ent><br/
<hw>Dead"born`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Stillborn.</def>
<rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deaden</ent><br/
<hw>Dead"en</hw> <pr>(d<ecr/d"'n)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Deadened</conjf>
<pr>(d<ecr/d"'nd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Deadening</conjf>.]</vmorph> <ety>[From <er>Dead</er>; cf. AS.
<ets>d<?/dan</ets> to kill, put to death. See <er>Dead</er>,
<pos>a.</pos>]</ety> <sn>1.</sn> <def>To make as dead; to impair in
vigor, force, activity, or sensation; to lessen the force or acuteness
of; to blunt; <as>as, to <ex>deaden</ex> the natural powers or feelings;
to <ex>deaden</ex> a sound.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 372 --></p>

<p><q>As harper lays his open palm<br/
Upon his harp, to <qex>deaden</qex> its vibrations.</q>
<rj><qau>Longfellow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To lessen the velocity or momentum of; to retard;
<as>as, to <ex>deaden</ex> a ship's headway</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To make vapid or spiritless; <as>as, to
<ex>deaden</ex> wine</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To deprive of gloss or brilliancy; to obscure;
<as>as, to <ex>deaden</ex> gilding by a coat of size</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To render impervious to sound, as a wall or floor;
to deafen.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Deadener</ent><br/
<hw>Dead"en*er</hw> <pr>(d<ecr/d"'n*<etil/r)</pr>, <pos>n.</pos>
<def>One who, or that which, deadens or checks.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>deadening</ent><br/
<hw>dead"en*ing</hw> <pos>adj.</pos> <ety>[<pos>p. pr.</pos> of verb
<er>deaden</er>{3}.]</ety> <def>Rendering less lively, intense, or
vigorous; <as>as, the <ex>deadening</ex> effect of some routine
tasks</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>So lacking in interest as to cause mental weariness;
<as>as, the <ex>deadening</ex> effect of some routine
tasks</as>.</def><br/
<syn><b>Syn. --</b> boring, dreary, ho-hum, irksome, tedious, tiresome,
wearisome.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>deadening</ent><br/
<hw>dead"en*ing</hw> <pos>n.</pos> <def>The act of making something
futile and useless (as by routine).</def><br/
<syn><b>Syn. --</b> stultification, impairment.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dead-eye</ent><br/
<hw>Dead"-eye`</hw> <pr>(d<ecr/d"<imac/`)</pr>, <pos>n.</pos>
<fld>(Naut.)</fld> <def>A round, flattish, wooden block, encircled by a
rope, or an iron band, and pierced with three holes to receive the
lanyard; -- used to extend the shrouds and stays, and for other
purposes. Called also <altname>deadman's eye</altname>.</def>
<rj><au>Totten.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deadhead</ent><br/
<hw>Dead"head`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who
receives free tickets for theaters, public conveyances, etc.</def>
<mark>[Colloq. U. S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Naut.)</fld> <def>A buoy. See under <er>Dead</er>,
<pos>a.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dead-hearted</ent><br/
<hw>Dead"-heart`ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having a dull,
faint heart; spiritless; listless.</def> --
<wordforms><wf>Dead"-heart`ed*ness</wf>, <pos>n.</pos></wordforms>
<rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deadhouse</ent><br/
<hw>Dead"house`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A morgue; a place
for the temporary reception and exposure of dead bodies.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deadish</ent><br/
<hw>Dead"ish</hw>, <pos>a.</pos> <def>Somewhat dead, dull, or lifeless;
deathlike.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The lips put on a <qex>deadish</qex> paleness.</q> <rj><qau>A.
Stafford.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deadlatch</ent><br/
<hw>Dead"latch`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A kind of latch
whose bolt may be so locked by a detent that it can not be opened from
the inside by the handle, or from the outside by the latch key.</def>
<rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deadlight</ent><br/
<hw>Dead"light`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Naut.)</fld>
<def>A strong shutter, made to fit open ports and keep out water in a
storm.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deadlihood</ent><br/
<hw>Dead"li*hood</hw> <pr>(?)</pr>, <pos>n.</pos> <def>State of the
dead.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deadliness</ent><br/
<hw>Dead"li*ness</hw>, <pos>n.</pos> <def>The quality of being
deadly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>deadlock</ent><br/
<hw>dead"lock`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A lock
which is not self-latching, but requires a key to throw the bolt
forward.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A counteraction of things, which produces an entire
stoppage; a complete obstruction of action.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Things are at a <qex>deadlock</qex>.</q> <rj><qau>London
Times.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The Board is much more likely to be at a <qex>deadlock</qex> of
two to two.</q> <rj><qau>The Century.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>deadlocked</ent><br/
<hw>deadlocked</hw> <pos>adj.</pos> <def>at a complete standstill
because of opposition of two unrelenting forces or factions.</def><br/
<syn><b>Syn. --</b> stalemated, blocked.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>deadly</ent><br/
<hw>dead"ly</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Capable of
causing death; mortal; fatal; destructive; certain or likely to cause
death; <as>as, a <ex>deadly</ex> blow or wound</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Aiming or willing to destroy; implacable;
desperately hostile; flagitious; <as>as, <ex>deadly</ex>
enemies</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thy assailant is quick, skillful, and <qex>deadly</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Subject to death; mortal.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The image of a <qex>deadly</qex> man.</q> <rj><qau>Wyclif (Rom. i.
23).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Deadly nightshade</b></col> <fld>(Bot.)</fld>, <cd>a
poisonous plant; belladonna. See under
<er>Nightshade</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>deadly</ent><br/
<hw>dead"ly</hw>, <pos>adv.</pos> <sn>1.</sn> <def>In a manner
resembling, or as if produced by, death; deathly.</def>
<ldquo/<xex>Deadly</xex> pale.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>In a manner to occasion death; mortally.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The groanings of a <qex>deadly</qex> wounded man.</q>
<rj><qau>Ezek. xxx. 24.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>In an implacable manner; destructively.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Extremely.</def> <mark>[Obs.]</mark>
<ldquo/<xex>Deadly</xex> weary.<rdquo/ <au>Orrery.</au> <ldquo/So
<xex>deadly</xex> cunning a man.<rdquo/ <rj><au>Arbuthnot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deadness</ent><br/
<hw>Dead"ness</hw>, <pos>n.</pos> <def>The state of being destitute of
life, vigor, spirit, activity, etc.; dullness; inertness; languor;
coldness; vapidness; indifference; <as>as, the <ex>deadness</ex> of a
limb, a body, or a tree; the <ex>deadness</ex> of an eye;
<ex>deadness</ex> of the affections; the <ex>deadness</ex> of beer or
cider; <ex>deadness</ex> to the world, and the like.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>dead-on</ent><br/
<hw>dead-on</hw> <pos>adj.</pos> <def>precisely accurate and to the
point; <as>as, a <ex>dead-on</ex> feel for characterization</as>.</def>
<mark>[prenominal and informal]</mark><br/
<syn><b>Syn. --</b> precise.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><q>She avoids big scenes . . . preferring to rely on small gestures
and <qex>dead-on</qex> dialogue.</q> <qau>Peter S. Prescott</qau><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dead-pay</ent><br/
<hw>Dead"-pay`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Pay drawn for
soldiers, or others, really dead, whose names are kept on the
rolls.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>O you commanders,<br/
That, like me, have no <qex>dead-pays</qex>.</q>
<rj><qau>Massinger.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dead-reckoning</ent><br/
<hw>Dead"-reck`on*ing</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Naut.)</fld> <def>See under <er>Dead</er>, <pos>a.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deads</ent><br/
<hw>Deads</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <fld>(Mining)</fld>
<def>The substances which inclose the ore on every side.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dead-stroke</ent><br/
<hw>Dead"-stroke`</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Mech.)</fld>
<def>Making a stroke without recoil; deadbeat.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dead-stroke hammer</b></col> <fld>(Mach.)</fld>, <cd>a
power hammer having a spring interposed between the driving mechanism
and the hammer head, or helve, to lessen the recoil of the hammer and
reduce the shock upon the mechanism.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deadwood</ent><br/
<hw>Dead"wood`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<fld>(Naut.)</fld> <def>A mass of timbers built into the bow and stern
of a vessel to give solidity.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Dead trees or branches; useless material.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <mark>[fig.]</mark> <def>People who are unproductive; --
used especially in reference to employees.</def><br/
[<source>PJC</source>]</p>

<p><ent>Deadworks</ent><br/
<hw>Dead"works`</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <fld>(Naut.)</fld>
<def>The parts of a ship above the water when she is laden.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deaf</ent><br/
<hw>Deaf</hw> <pr>(d<ecr/f <it>or</it> d<emac/f; 277)</pr>,
<pos>a.</pos> <ety>[OE. <ets>def</ets>, <ets>deaf</ets>,
<ets>deef</ets>, AS. <ets>de<aacute/f</ets>; akin to D. <ets>doof</ets>,
G. <ets>taub</ets>, Icel. <ets>daufr</ets>, Dan. <ets>d<oum/v</ets>, Sw.
<ets>d<oum/f</ets>, Goth. <ets>daubs</ets>, and prob. to E.
<ets>dumb</ets> (the original sense being, dull as applied to one of the
senses), and perh. to Gr. <grk>tyflo`s</grk> (for <grk>qyflo`s</grk>)
blind, <grk>ty^fos</grk> smoke, vapor, folly, and to G. <ets>toben</ets>
to rage. Cf. <er>Dum</er>b.]</ety> <sn>1.</sn> <def>Wanting the sense of
hearing, either wholly or in part; unable to perceive sounds; hard of
hearing; <as>as, a <ex>deaf</ex> man</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Come on my right hand, for this ear is <qex>deaf</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Unwilling to hear or listen; determinedly
inattentive; regardless; not to be persuaded as to facts, argument, or
exhortation; -- with <xex>to</xex>; <as>as, <ex>deaf</ex> to
reason</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>O, that men's ears should be<br/
To counsel <qex>deaf</qex>, but not to flattery!</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Deprived of the power of hearing;
deafened.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Deaf</qex> with the noise, I took my hasty flight.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Obscurely heard; stifled; deadened.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>deaf</qex> murmur through the squadron went.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Decayed; tasteless; dead; <as>as, a <ex>deaf</ex>
nut; <ex>deaf</ex> corn.</as></def> <mark>[Obs. or Prov. Eng.]</mark>
<rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>If the season be unkindly and intemperate, they [peppers] will
catch a blast; and then the seeds will be <qex>deaf</qex>, void, light,
and naught.</q> <rj><qau>Holland.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deaf</ent><br/
<hw>Deaf</hw> <pr>(?; 277)</pr>, <pos>v. t.</pos> <def>To deafen.</def>
<mark>[Obs.]</mark> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>deaf-aid</ent><br/
<hw>deaf-aid</hw> <pos>n.</pos> <def>an electronic device which
amplifies sound and is worn to compensate for poor hearing.</def><br/
<syn><b>Syn. --</b> hearing aid.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>deaf-and-dumb</ent><br/
<ent>deaf and dumb</ent><br/
<mhw><hw>deaf and dumb</hw>, <hw>deaf-and-dumb</hw></mhw>
<pos>adj.</pos> <def>both deaf and unable to speak; without the sense of
hearing or the faculty of speech. Same as <er>Deaf-mute</er>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Deafen</ent><br/
<hw>Deaf"en</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Deafened</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Deafening</conjf>.]</vmorph> <ety>[From
<er>Deaf</er>.]</ety> <sn>1.</sn> <def>To make deaf; to deprive of the
power of hearing; to render incapable of perceiving sounds
distinctly.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Deafened</qex> and stunned with their promiscuous cries.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Arch.)</fld> <def>To render impervious to sound, as
a partition or floor, by filling the space within with mortar, by lining
with paper, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>deafened</ent><br/
<hw>deafened</hw> <pos>adj.</pos> <def>rendered deaf.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>deafening</ent><br/
<hw>deaf"en*ing</hw>, <pos>n.</pos> <def>The act or process of rendering
impervious to sound, as a floor or wall; also, the material with which
the spaces are filled in this process; pugging; sound
insulation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>deafening</ent><br/
<hw>deaf"en*ing</hw>, <pos>a.</pos> <def>extremely loud; so loud as to
cause deafness; <as>as, a disco with rock music played at a
<ex>deafening</ex> volume</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Deafly</ent><br/
<hw>Deaf"ly</hw>, <pos>adv.</pos> <def>Without sense of sounds;
obscurely.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deafly</ent><br/
<hw>Deaf"ly</hw>, <pos>a.</pos> <def>Lonely; solitary.</def>
<mark>[Prov. Eng.]</mark> <rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deaf-mute</ent><br/
<hw>Deaf"-mute`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A person who is
deaf and dumb; one who, through deprivation or defect of hearing, has
either failed the acquire the power of speech, or has lost it.</def>
<mark>[See Illust. of <er>Dactylology</er>.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Deaf-mutes</qex> are still so called, even when, by
artificial methods, they have been taught to speak imperfectly.</q><br/
[<source>1913 Webster</source>]</p>

<p><ent>deaf-mutism</ent><br/
<ent>deaf-muteness</ent><br/
<mhw><hw>deaf-muteness</hw>, <hw>deaf-mutism</hw></mhw> <pos>n.</pos>
<def>the condition of being a deaf-mute; a congenital deafness that
results in inability to speak.</def><br/
[<source>1913 Webster</source> <source>WordNet 1.5</source>]</p>

<p><ent>Deafness</ent><br/
<hw>Deaf"ness</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>Incapacity of perceiving sounds; the state of the organs which
prevents the impression which constitute hearing; want of the sense of
hearing.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Unwillingness to hear; voluntary rejection of what
is addressed to the understanding.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Nervous deafness</b></col>, <cd>a variety of deafness
dependent upon morbid change in some portion of the nervous system,
especially the auditory nerve.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deal</ent><br/
<hw>Deal</hw> <pr>(d<emac/l)</pr>, <pos>n.</pos> <ety>[OE.
<ets>del</ets>, <ets>deel</ets>, part, AS. <ets>d<aemac/l</ets>; akin to
OS. <ets>d<emac/l</ets>, D. & Dan. <ets>deel</ets>, G. <ets>theil</ets>,
<ets>teil</ets>, Icel. <ets>deild</ets>, Sw. <ets>del</ets>, Goth.
<ets>dails</ets>. <root/65. Cf. 3d <er>Dole</er>.]</ety> <sn>1.</sn>
<def>A part or portion; a share; hence, an indefinite quantity, degree,
or extent, degree, or extent; <as>as, a <ex>deal</ex> of time and
trouble; a <ex>deal</ex> of cold.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Three tenth <qex>deals</qex> [parts of an ephah] of flour.</q>
<rj><qau>Num. xv. 9.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>As an object of science it [the Celtic genius] may count for a
good <qex>deal</qex> . . . as a spiritual power.</q> <rj><qau>M.
Arnold.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>She was resolved to be a good <qex>deal</qex> more
circumspect.</q> <rj><qau>W. Black.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ It was formerly limited by <xex>some</xex>,
<xex>every</xex>, <xex>never a</xex>, <xex>a thousand</xex>, etc.; as,
<xex>some deal</xex>; but these are now obsolete or vulgar. In general,
we now qualify the word with <xex>great</xex> or <xex>good</xex>, and
often use it adverbially, <xex>by</xex> being understood; as, a
<xex>great deal</xex> of time and pains; a <xex>great</xex> (or
<xex>good</xex>) <xex>deal</xex> better or worse; that is, better
<xex>by</xex> a great deal, or by a great part or difference.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The process of dealing cards to the players; also,
the portion disturbed.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>deal</qex>, the shuffle, and the cut.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Distribution; apportionment.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>An arrangement to attain a desired result by a
combination of interested parties; -- applied to stock speculations and
political bargains.</def> <mark>[Slang]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <ety>[Prob. from D. <ets>deel</ets> a plank, threshing
floor. See <er>Thill</er>.]</ety> <def>The division of a piece of timber
made by sawing; a board or plank; particularly, a board or plank of fir
or pine above seven inches in width, and exceeding six feet in length.
If narrower than this, it is called a <xex>batten</xex>; if shorter, a
<xex>deal end</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Whole deal</xex> is a general term for planking one
and one half inches thick.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Wood of the pine or fir; <as>as, a floor of
<ex>deal</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Deal tree</b></col>, <cd>a fir tree.</cd> <rj><au>Dr.
Prior.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deal</ent><br/
<hw>Deal</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Dealt</conjf> <pr>(d<ecr/lt)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Dealing</conjf>.]</vmorph> <ety>[OE. <ets>delen</ets>, AS.
<ets>d<aemac/lan</ets>, fr. <ets>d<aemac/l</ets> share; akin to OS.
<ets>d<emac/lian</ets>, D. <ets>deelen</ets>, G. <ets>theilen</ets>,
<ets>teilen</ets>, Icel. <ets>deila</ets>, Sw. <ets>dela</ets>, Dan.
<ets>dele</ets>, Goth. <ets>dailjan</ets>. See <er>Deal</er>,
<pos>n.</pos>]</ety> <sn>1.</sn> <def>To divide; to separate in
portions; hence, to give in portions; to distribute; to bestow
successively; -- sometimes with <xex>out</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Is it not to <qex>deal</qex> thy bread to the hungry?</q>
<rj><qau>Is. lviii. 7.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And Rome <qex>deals</qex> out her blessings and her gold.</q>
<rj><qau>Tickell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The nightly mallet <qex>deals</qex> resounding blows.</q>
<rj><qau>Gay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Hissing through the skies, the feathery deaths were
<qex>dealt</qex>.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Specifically: To distribute, as cards, to the
players at the commencement of a game; <as>as, to <ex>deal</ex> the
cards; to <ex>deal</ex> one a jack.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deal</ent><br/
<hw>Deal</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To make distribution;
to share out in portions, as cards to the players.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To do a distributing or retailing business, as
distinguished from that of a manufacturer or producer; to traffic; to
trade; to do business; <as>as, he <ex>deals</ex> in
flour</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They buy and sell, they <qex>deal</qex> and traffic.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>This is to drive to wholesale trade, when all other petty
merchants <qex>deal</qex> but for parcels.</q> <rj><qau>Dr. H.
More.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To act as an intermediary in business or any
affairs; to manage; to make arrangements; -- followed by
<xex>between</xex> or <xex>with</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Sometimes he that <qex>deals</qex> between man and man, raiseth
his own credit with both, by pretending greater interest than he hath in
either.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To conduct one's self; to behave or act in any
affair or towards any one; to treat.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If he will <qex>deal</qex> clearly and impartially, . . . he will
acknowledge all this to be true.</q> <rj><qau>Tillotson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To contend (with); to treat (with), by way of
opposition, check, or correction; <as>as, he has turbulent passions to
<ex>deal</ex> with</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To deal by</b></col>, <cd>to treat, either well or ill;
<as>as, to <ex>deal</ex> well <ex>by</ex> servants</as>.</cd>
<ldquo/Such an one <xex>deals</xex> not fairly <xex>by</xex> his own
mind.<rdquo/ <au>Locke.</au> -- <col><b>To deal in</b></col>.
<sd>(a)</sd> <cd>To have to do with; to be engaged in; to practice;
<as>as, they <ex>deal in</ex> political matters</as>.</cd> <sd>(b)</sd>
<cd>To buy and sell; to furnish, as a retailer or wholesaler; <as>as,
they <ex>deal in</ex> fish</as>.</cd> -- <col><b>To deal with</b></col>.
<sd>(a)</sd> <cd>To treat in any manner; to use, whether well or ill; to
have to do with; specifically, to trade with.</cd> <ldquo/<xex>Dealing
with</xex> witches.<rdquo/ <au>Shak.</au> <sd>(b)</sd> <cd>To reprove
solemnly; to expostulate with.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><q>The deacons of his church, who, to use their own phrase,
<ldquo/<qex>dealt with</qex> him<rdquo/ on the sin of rejecting the aid
which Providence so manifestly held out.</q>
<rj><qau>Hawthorne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Return . . . and I will <qex>deal</qex> well <qex>with</qex>
thee.</q> <rj><qau>Gen. xxxii. 9.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dealbate</ent><br/
<hw>De*al"bate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>dealbatus</ets>, p. p. of <ets>dealbare</ets>. See
<er>Daub</er>.]</ety> <def>To whiten.</def> <mark>[Obs.]</mark>
<rj><au>Cockeram.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dealbation</ent><br/
<hw>De`al*ba"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>dealbatio</ets>: cf. F. <ets>d<eacute/albation</ets>.]</ety>
<def>Act of bleaching; a whitening.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dealer</ent><br/
<hw>Deal"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who
deals; one who has to do, or has concern, with others; esp., a trader, a
trafficker, a shopkeeper, a broker, or a merchant; <as>as, a
<ex>dealer</ex> in dry goods; a <ex>dealer</ex> in stocks; a retail
<ex>dealer</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who distributes cards to the players.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dealfish</ent><br/
<hw>Deal"fish`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<ets>deal</ets> a long, narrow plank.]</ety> <fld>(Zool.)</fld> <def>A
long, thin fish of the arctic seas (<spn>Trachypterus
arcticus</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dealing</ent><br/
<hw>Deal"ing</hw>, <pos>n.</pos> <def>The act of one who deals;
distribution of anything, as of cards to the players; method of
business; traffic; intercourse; transaction; <as>as, to have
<ex>dealings</ex> with a person</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Double dealing</b></col>, <cd>insincere, treacherous
dealing; duplicity.</cd> -- <col><b>Plain dealing</b></col>, <cd>fair,
sincere, honorable dealing; honest, outspoken expression of
opinion.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dealth</ent><br/
<hw>Dealth</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Share dealt.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deambulate</ent><br/
<hw>De*am"bu*late</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[L.
<ets>deambulare</ets>, <ets>deambulatum</ets>; <ets>de-</ets> +
<ets>ambulare</ets> to walk.]</ety> <def>To walk abroad.</def>
<mark>[Obs.]</mark> <rj><au>Cockeram.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deambulation</ent><br/
<hw>De*am`bu*la"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>deambulatio</ets>.]</ety> <def>A walking abroad; a
promenading.</def> <mark>[Obs.]</mark> <rj><au>Sir T.
Elyot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deambulatory</ent><br/
<hw>De*am"bu*la*to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. LL.
<ets>deambulator</ets> a traveler.]</ety> <def>Going about from place to
place; wandering; of or pertaining to a deambulatory.</def>
<mark>[Obs.]</mark> <ldquo/<xex>Deambulatory</xex> actors.<rdquo/
<rj><au>Bp. Morton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deambulatory</ent><br/
<hw>De*am"bu*la*to*ry</hw>, <pos>n.</pos> <ety>[L.
<ets>deambulatorium</ets>.]</ety> <def>A covered place in which to walk;
an ambulatory.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dean</ent><br/
<hw>Dean</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>dene</ets>,
<ets>deene</ets>, OF. <ets>deien</ets>, <ets>dien</ets>, F.
<ets>doyen</ets>, eldest of a corporation, a dean, L. <ets>decanus</ets>
the chief of ten, one set over ten persons, <it>e. g.</it>, over
soldiers or over monks, from <ets>decem</ets> ten. See <er>Ten</er>, and
cf. <er>Decemvir</er>.]</ety> <sn>1.</sn> <def>A dignitary or presiding
officer in certain ecclesiastical and lay bodies; esp., an
ecclesiastical dignitary, subordinate to a bishop.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dean of cathedral church</b></col>, <cd>the chief officer
of a chapter; he is an ecclesiastical magistrate next in degree to
bishop, and has immediate charge of the cathedral and its estates.</cd>
-- <col><b>Dean of peculiars</b></col>, <cd>a dean holding a preferment
which has some peculiarity relative to spiritual superiors and the
jurisdiction exercised in it.</cd> <mark>[Eng.]</mark> -- <col><b>Rural
dean</b></col>, <cd>one having, under the bishop, the especial care and
inspection of the clergy within certain parishes or districts of the
diocese.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The collegiate officer in the universities of Oxford
and Cambridge, England, who, besides other duties, has regard to the
moral condition of the college.</def> <rj><au>Shipley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The head or presiding officer in the faculty of some
colleges or universities.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A registrar or secretary of the faculty in a
department of a college, as in a medical, or theological, or scientific
department.</def> <mark>[U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>The chief or senior of a company on occasion of
ceremony; <as>as, the <ex>dean</ex> of the diplomatic corps</as>; -- so
called by courtesy.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Cardinal dean</b></col>, <cd>the senior cardinal bishop
of the college of cardinals at Rome.</cd> <au>Shipley.</au> --
<col><b>Dean and chapter</b></col>, <cd>the legal corporation and
governing body of a cathedral. It consists of the dean, who is chief,
and his canons or prebendaries.</cd> -- <col><b>Dean of
arches</b></col>, <cd>the lay judge of the court of arches.</cd> --
<col><b>Dean of faculty</b></col>, <cd>the president of an incorporation
or barristers; specifically, the president of the incorporation of
advocates in Edinburgh.</cd> -- <col><b>Dean of guild</b></col>, <cd>a
magistrate of Scotch burghs, formerly, and still, in some burghs, chosen
by the Guildry, whose duty is to superintend the erection of new
buildings and see that they conform to the law.</cd> --
<mcol><col><b>Dean of a monastery</b></col>, <col><b>Monastic
dean</b></col></mcol>, <cd>a monastic superior over ten monks.</cd> --
<col><b>Dean's stall</b></col>. <cd>See <cref>Decanal stall</cref>,
under <er>Decanal</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deanery</ent><br/
<hw>Dean"er*y</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Deaneries</plw> <pr>(<?/)</pr>.</plu> <sn>1.</sn> <def>The office
or the revenue of a dean. See the Note under <er>Benefice</er>,
<pos>n.</pos>, 3.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The residence of a dean.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The territorial jurisdiction of a dean.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Each archdeaconry is divided into rural <qex>deaneries</qex>, and
each <qex>deanery</qex> is divided into parishes.</q>
<rj><qau>Blackstone.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deanship</ent><br/
<hw>Dean"ship</hw>, <pos>n.</pos> <def>The office of a dean.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I dont't value your <qex>deanship</qex> a straw.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dear</ent><br/
<hw>Dear</hw> <pr>(d<emac/r)</pr>, <pos>a.</pos>
<amorph>[<pos>Compar.</pos> <adjf>Dearer</adjf>
<pr>(d<emac/r"<etil/r)</pr>; <pos>superl.</pos> <adjf>Dearest</adjf>
<pr>(d<emac/r"<ecr/st)</pr>.]</amorph> <ety>[OE. <ets>dere</ets>,
<ets>deore</ets>, AS. <ets>de<oacute/re</ets>; akin to OS.
<ets>diuri</ets>, D. <ets>duur</ets>, OHG. <ets>tiuri</ets>, G.
<ets>theuer</ets>, <ets>teuer</ets>, Icel. <ets>d<ymac/rr</ets>, Dan. &
Sw. <ets>dyr</ets>. Cf. <er>Darling</er>, <er>Dearth</er>.]</ety>
<sn>1.</sn> <def>Bearing a high price; high-priced; costly;
expensive.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The cheapest of us is ten groats too <qex>dear</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Marked by scarcity or dearth, and exorbitance of
price; <as>as, a <ex>dear</ex> year</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Highly valued; greatly beloved; cherished;
precious.</def> <ldquo/Hear me, <xex>dear</xex> lady.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Neither count I my life <qex>dear</qex> unto myself.</q>
<rj><qau>Acts xx. 24.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And the last joy was <qex>dearer</qex> than the rest.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Dear</qex> as remember'd kisses after death.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Hence, close to the heart; heartfelt; present in
mind; engaging the attention.</def> <sd>(a)</sd> <def>Of agreeable
things and interests.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>[I'll] leave you to attend him: some <qex>dear</qex> cause<br/
Will in concealment wrap me up awhile.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>His <qex>dearest</qex> wish was to escape from the bustle and
glitter of Whitehall.</q> <rj><qau>Macaulay.</qau></rj></p>

<p><sd>(b)</sd> <def>Of disagreeable things and antipathies.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In our <qex>dear</qex> peril.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Would I had met my <qex>dearest</qex> foe in heaven<br/
Or ever I had seen that day.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dear</ent><br/
<hw>Dear</hw>, <pos>n.</pos> <def>A dear one; lover;
sweetheart.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That kiss I carried from thee, <qex>dear</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dear</ent><br/
<hw>Dear</hw>, <pos>adv.</pos> <def>Dearly; at a high price.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If thou attempt it, it will cost thee <qex>dear</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dear</ent><br/
<hw>Dear</hw>, <pos>v. t.</pos> <def>To endear.</def>
<mark>[Obs.]</mark> <rj><au>Shelton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dearborn</ent><br/
<hw>Dear"born</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A four-wheeled
carriage, with curtained sides.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dear-bought</ent><br/
<hw>Dear"-bought`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Bought at a high
price; <as>as, <ex>dear-bought</ex> experience</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 373 --></p>

<p><ent>Deare</ent><br/
<hw>Deare</hw> <pr>(?)</pr>, <def>variant of <er>Dere</er>, <pos>v. t. &
n.</pos></def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dearie</ent><br/
<hw>Dear"ie</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Deary</er>.</def> <rj><au>Dickens.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dearling</ent><br/
<hw>Dear"ling</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A darling.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dear-loved</ent><br/
<hw>Dear"-loved`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Greatly
beloved.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dearly</ent><br/
<hw>Dear"ly</hw>, <pos>adv.</pos> <sn>1.</sn> <def>In a dear manner;
with affection; heartily; earnestly; <as>as, to love one
<ex>dearly</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>At a high rate or price; grievously.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He buys his mistress <qex>dearly</qex> with his throne.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Exquisitely.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dearn</ent><br/
<hw>Dearn</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[AS. <ets>derne</ets>,
<ets>dyrne</ets>, <ets>dierne</ets>, hidden, secret. Cf.
<er>Derne</er>.]</ety> <def>Secret; lonely; solitary; dreadful.</def>
<mark>[Obs.]</mark> <au>Shak.</au> -- <wordforms><wf>Dearn"ly</wf>,
<pos>adv.</pos> <mark>[Obs.]</mark></wordforms>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dearn</ent><br/
<hw>Dearn</hw>, <pos>v. t.</pos> <def>Same as <er>Darn</er>.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dearness</ent><br/
<hw>Dear"ness</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
quality or state of being dear; costliness; excess of price.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>dearness</qex> of corn.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Fondness; preciousness; love; tenderness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>dearness</qex> of friendship.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dearth</ent><br/
<hw>Dearth</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>derthe</ets>,
fr. <ets>dere</ets>. See <er>Dear</er>.]</ety> <def>Scarcity which
renders dear; want; lack; specifically, lack of food on account of
failure of crops; famine.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There came a <qex>dearth</qex> over all the land of Egypt.</q>
<rj><qau>Acts vii. 11.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He with her press'd, she faint with <qex>dearth</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Dearth</qex> of plot, and narrowness of imagination.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dearticulate</ent><br/
<hw>De`ar*tic"u*late</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To
disjoint.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dearworth</ent><br/
<hw>Dear"worth`</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Derworth</er>.]</ety> <def>Precious.</def> <mark>[Obs.]</mark>
<rj><au>Piers Plowman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deary</ent><br/
<hw>Dear"y</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A dear; a
darling.</def> <mark>[Familiar]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deas</ent><br/
<hw>De"as</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See <er>Dais</er>.</def>
<mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Death</ent><br/
<hw>Death</hw> <pr>(d<ecr/th)</pr>, <pos>n.</pos> <ety>[OE.
<ets>deth</ets>, <ets>dea<edh/</ets>, AS. <ets>de<aacute/<edh/</ets>;
akin to OS. <ets>d<omac/<edh/</ets>, D. <ets>dood</ets>, G.
<ets>tod</ets>, Icel. <ets>dau<edh/i</ets>, Sw. & Dan.
<ets>d<oum/d</ets>, Goth. <ets>dau<thorn/us</ets>; from a verb meaning
<ets>to die</ets>. See <er>Die</er>, <pos>v. i.</pos>, and cf.
<er>Dead</er>.]</ety> <sn>1.</sn> <def>The cessation of all vital
phenomena without capability of resuscitation, either in animals or
plants.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Local death</xex> is going on at all times and in
all parts of the living body, in which individual cells and elements are
being cast off and replaced by new; a process essential to life.
<xex>General death</xex> is of two kinds; death of the body as a whole
(<xex>somatic</xex> or <xex>systemic</xex> death), and death of the
tissues. By the former is implied the absolute cessation of the
functions of the brain, the circulatory and the respiratory organs; by
the latter the entire disappearance of the vital actions of the ultimate
structural constituents of the body. When death takes place, the body as
a whole dies first, the death of the tissues sometimes not occurring
until after a considerable interval.
<rj><au>Huxley.</au></rj></note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Total privation or loss; extinction; cessation;
<as>as, the <ex>death</ex> of memory</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>death</qex> of a language can not be exactly compared
with the death of a plant.</q> <rj><qau>J. Peile.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Manner of dying; act or state of passing from
life.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>death</qex> that I abhor.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Let me die the <qex>death</qex> of the righteous.</q>
<rj><qau>Num. xxiii. 10.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Cause of loss of life.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Swiftly flies the feathered <qex>death</qex>.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He caught his <qex>death</qex> the last county sessions.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Personified: The destroyer of life, --
conventionally represented as a skeleton with a scythe.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Death</qex>! great proprietor of all.</q>
<rj><qau>Young.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And I looked, and behold a pale horse; and his name that sat on
him was <qex>Death</qex>.</q> <rj><qau>Rev. vi. 8.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Danger of death.</def> <ldquo/In <xex>deaths</xex>
oft.<rdquo/ <rj><au>2 Cor. xi. 23.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>Murder; murderous character.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Not to suffer a man of <qex>death</qex> to live.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <fld>(Theol.)</fld> <def>Loss of spiritual
life.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To be carnally minded is <qex>death</qex>.</q> <rj><qau>Rom. viii.
6.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>Anything so dreadful as to be like death.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It was <qex>death</qex> to them to think of entertaining such
doctrines.</q> <rj><qau>Atterbury.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And urged him, so that his soul was vexed unto
<qex>death</qex>.</q> <rj><qau>Judg. xvi. 16.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Death</xex> is much used adjectively and as the
first part of a compound, meaning, in general, <xex>of</xex> or
<xex>pertaining to death</xex>, <xex>causing</xex> or <xex>presaging
death</xex>; as, <xex>death</xex>bed or <xex>death</xex> bed;
<xex>death</xex>blow or <xex>death</xex> blow, etc.</note><br/
[<source>1913 Webster</source>]</p>

<cs><p><col><b>Black death</b></col>. <cd>See <er>Black death</er>, in
the Vocabulary.</cd> -- <col><b>Civil death</b></col>, <cd>the
separation of a man from civil society, or the debarring him from the
enjoyment of civil rights, as by banishment, attainder, abjuration of
the realm, entering a monastery, etc.</cd> <au>Blackstone.</au> --
<col><b>Death adder</b></col>. <fld>(Zool.)</fld> <sd>(a)</sd> <cd>A
kind of viper found in South Africa (<spn>Acanthophis tortor</spn>); --
so called from the virulence of its venom.</cd> <sd>(b)</sd> <cd>A
venomous Australian snake of the family <fam>Elapid<ae/</fam>, of
several species, as the <spn>Hoplocephalus superbus</spn> and
<spn>Acanthopis antarctica</spn>.</cd> -- <col><b>Death bell</b></col>,
<cd>a bell that announces a death.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>death bell</qex> thrice was heard to ring.</q>
<rj><qau>Mickle.</qau></rj></p>

<p>-- <col><b>Death candle</b></col>, <cd>a light like that of a candle,
viewed by the superstitious as presaging death.</cd> -- <col><b>Death
damp</b></col>, <cd>a cold sweat at the coming on of death.</cd> --
<col><b>Death fire</b></col>, <cd>a kind of ignis fatuus supposed to
forebode death.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>And round about in reel and rout,<br/
The <qex>death fires</qex> danced at night.</q>
<rj><qau>Coleridge.</qau></rj></p>

<p>-- <col><b>Death grapple</b></col>, <cd>a grapple or struggle for
life.</cd> -- <col><b>Death in life</b></col>, <cd>a condition but
little removed from death; a living death.</cd> <mark>[Poetic]</mark>
<ldquo/Lay lingering out a five years' <xex>death in life</xex>.<rdquo/
<au>Tennyson.</au> -- <col><b>Death rate</b></col>, <cd>the relation or
ratio of the number of deaths to the population.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>At all ages the <qex>death rate</qex> is higher in towns than in
rural districts.</q> <rj><qau>Darwin.</qau></rj></p>

<p>-- <col><b>Death rattle</b></col>, <cd>a rattling or gurgling in the
throat of a dying person.</cd> -- <col><b>Death's door</b></col>,
<cd>the boundary of life; the partition dividing life from death.</cd>
-- <col><b>Death stroke</b></col>, <cd>a stroke causing death.</cd> --
<col><b>Death throe</b></col>, <cd>the spasm of death.</cd> --
<col><b>Death token</b></col>, <cd>the signal of approaching death.</cd>
-- <col><b>Death warrant</b></col>. <sd>(a)</sd> <fld>(Law)</fld> <cd>An
order from the proper authority for the execution of a criminal.</cd>
<sd>(b)</sd> <cd>That which puts an end to expectation, hope, or
joy.</cd> -- <col><b>Death wound</b></col>. <sd>(a)</sd> <cd>A fatal
wound or injury.</cd> <sd>(b)</sd> <fld>(Naut.)</fld> <cd>The springing
of a fatal leak.</cd> -- <col><b>Spiritual death</b></col>
<fld>(Scripture)</fld>, <cd>the corruption and perversion of the soul by
sin, with the loss of the favor of God.</cd> -- <col><b>The gates of
death</b></col>, <cd>the grave.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>Have <qex>the gates of death</qex> been opened unto thee?</q>
<rj><qau>Job xxxviii. 17.</qau></rj></p>

<p>-- <col><b>The second death</b></col>, <cd>condemnation to eternal
separation from God.</cd> <au>Rev. ii. 11.</au> -- <col><b>To be the
death of</b></col>, <cd>to be the cause of death to; to make die.</cd>
<ldquo/It was one who should <xex>be the death of</xex> both his
parents.<rdquo/ <au>Milton.</au></p></cs>

<p><syn><b>Syn.</b> -- <er>Death</er>, <er>Decease</er>,
<er>Demise</er>, <er>Departure</er>, <er>Release</er>.</syn> <usage>
<xex>Death</xex> applies to the termination of every form of existence,
both animal and vegetable; the other words only to the human race.
<xex>Decease</xex> is the term used in law for the removal of a human
being out of life in the ordinary course of nature. <xex>Demise</xex>
was formerly confined to decease of princes, but is now sometimes used
of distinguished men in general; <as>as, the <ex>demise</ex> of Mr.
Pitt</as>. <xex>Departure</xex> and <xex>release</xex> are peculiarly
terms of Christian affection and hope. A violent <xex>death</xex> is not
usually called a <xex>decease</xex>. <xex>Departure</xex> implies a
friendly taking leave of life. <xex>Release</xex> implies a deliverance
from a life of suffering or sorrow.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deathbed</ent><br/
<hw>Death"bed</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The bed in which a
person dies; hence, the closing hours of life of one who dies by
sickness or the like; the last sickness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That often-quoted passage from Lord Hervey in which the Queen's
<qex>deathbed</qex> is described.</q> <rj><qau>Thackeray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deathbird</ent><br/
<hw>Death"bird`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>Tengmalm's or Richardson's owl (<spn>Nyctale Tengmalmi</spn>); --
so called from a superstition of the North American Indians that its
note presages death.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deathblow</ent><br/
<hw>Death"blow`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A mortal or
crushing blow; a stroke or event which kills or destroys.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>deathblow</qex> of my hope.</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deathful</ent><br/
<hw>Death"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Full of
death or slaughter; murderous; destructive; bloody.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>These eyes behold<br/
The <qex>deathful</qex> scene.</q> <rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Liable to undergo death; mortal.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The deathless gods and <qex>deathful</qex> earth.</q>
<rj><qau>Chapman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deathfulness</ent><br/
<hw>Death"ful*ness</hw>, <pos>n.</pos> <def>Appearance of death.</def>
<rj><au>Jer. Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>death knell</ent><br/
<hw>death" knell`</hw>, <pos>n.</pos> <sn>1.</sn> <def>A stroke or
tolling of a bell, announcing a death; a knell{1}.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <specif>Hence:</specif> <mark>(figuratively)</mark>
<def>A sign or harbinger of the end, death, or passing away of
anything.</def><br/
[<source>PJC</source>]</p>

<p><ent>Deathless</ent><br/
<hw>Death"less</hw>, <pos>a.</pos> <def>Not subject to death,
destruction, or extinction; immortal; undying; imperishable; <as>as,
<ex>deathless</ex> beings; <ex>deathless</ex> fame.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deathlike</ent><br/
<hw>Death"like`</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Resembling death.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>deathlike</qex> slumber, and a dead repose.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Deadly.</def> <mark>[Obs.]</mark>
<ldquo/<xex>Deathlike</xex> dragons.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deathliness</ent><br/
<hw>Death"li*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The quality of
being deathly; deadliness.</def> <rj><au>Southey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deathly</ent><br/
<hw>Death"ly</hw>, <pos>a.</pos> <def>Deadly; fatal; mortal;
destructive.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deathly</ent><br/
<hw>Death"ly</hw>, <pos>adv.</pos> <def>Deadly; <as>as, <ex>deathly</ex>
pale or sick</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>death-roll</ent><br/
<hw>death-roll</hw> <pos>n.</pos> <def>a list of persons killed in a war
or other disaster.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Death's-head</ent><br/
<hw>Death's"-head`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A naked human
skull as the emblem of death; the head of the conventional
personification of death.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I had rather be married to a <qex>death's-head</qex> with a bone
in his mouth.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Death's-head moth</b></col> <fld>(Zool.)</fld>, <cd>a
very large European moth (<spn>Acherontia atropos</spn>), so called from
a figure resembling a human skull on the back of the thorax; -- called
also <altname>death's-head sphinx</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Death's-herb</ent><br/
<hw>Death's"-herb`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The deadly
nightshade (<spn>Atropa belladonna</spn>).</def> <rj><au>Dr.
Prior.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deathsman</ent><br/
<hw>Deaths"man</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An executioner; a
headsman or hangman.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deathward</ent><br/
<hw>Death"ward</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>Toward
death.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deathwatch</ent><br/
<hw>Death"watch`</hw> <pr>(?; 224)</pr>, <pos>n.</pos> <sn>1.</sn>
<fld>(Zool.)</fld> <sd>(a)</sd> <def>A small beetle (<spn>Anobium
tessellatum</spn> and other allied species). By forcibly striking its
head against woodwork it makes a ticking sound, which is a call of the
sexes to each other, but has been imagined by superstitious people to
presage death.</def> <sd>(b)</sd> <def>A small wingless insect, of the
family <fam>Psocid<ae/</fam>, which makes a similar but fainter sound;
-- called also <altname>deathtick</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>She is always seeing apparitions and hearing
<qex>deathwatches</qex>.</q> <rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I did not hear the dog howl, mother, or the <qex>deathwatch</qex>
beat.</q> <rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The guard set over a criminal before his
execution.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deaurate</ent><br/
<hw>De*au"rate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>deauratus</ets>, p. p. of <ets>deaurare</ets> to gild;
<ets>de-</ets> + <ets>aurum</ets> gold.]</ety> <def>Gilded.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deaurate</ent><br/
<hw>De*au"rate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To gild.</def>
<mark>[Obs.]</mark> <rj><au>Bailey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deauration</ent><br/
<hw>De`au*ra"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Act of
gilding.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deave</ent><br/
<hw>Deave</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[See
<er>Deafen</er>.]</ety> <def>To stun or stupefy with noise; to
deafen.</def> <mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debacchate</ent><br/
<hw>De*bac"chate</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[L.
<ets>debacchatus</ets>, p. p. of <ets>debacchari</ets> to rage;
<ets>de-</ets> + <ets>bacchari</ets> to rage like a bacchant.]</ety>
<def>To rave as a bacchanal.</def> <mark>[R.]</mark>
<rj><au>Cockeram.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debacchation</ent><br/
<hw>De`bac*cha"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>debacchatio</ets>.]</ety> <def>Wild raving or debauchery.</def>
<mark>[R.]</mark> <rj><au>Prynne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debacle</ent><br/
<hw>De*ba"cle</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>d<eacute/b<acir/cle</ets>, fr. <ets>d<eacute/b<acir/cler</ets> to
unbar, break loose; pref. <ets>d<eacute/-</ets> (prob. = L.
<ets>dis</ets>) + <ets>b<acir/cler</ets> to bolt, fr. L.
<ets>baculum</ets> a stick.]</ety> <sn>1.</sn> <fld>(Geol.)</fld> <def>A
breaking or bursting forth; a violent rush or flood of waters which
breaks down opposing barriers, and hurls forward and disperses blocks of
stone and other d<eacute/bris.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A sudden breaking up or breaking loose; a violent
dispersion or disruption; impetuous rush; outburst.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>3.</sn> <def>a complete and ludicrous failure; a rout, as of an
army; a great disaster; a <er>fiasco</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Debar</ent><br/
<hw>De*bar"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Debarred</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Debarring</conjf>.]</vmorph> <ety>[Pref. <ets>de-</ets>
+ <ets>bar</ets>.]</ety> <def>To cut off from entrance, as if by a bar
or barrier; to preclude; to hinder from approach, entry, or enjoyment;
to shut out or exclude; to deny or refuse; -- with <xex>from</xex>, and
sometimes with <xex>of</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Yet not so strictly hath our Lord imposed<br/
Labor, as to <qex>debar</qex> us when we need<br/
Refreshment.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Their wages were so low as to <qex>debar</qex> them, not only from
the comforts but from the common decencies of civilized life.</q>
<rj><qau>Buckle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debarb</ent><br/
<hw>De*barb"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>de-</ets> + L. <ets>barba</ets> beard.]</ety> <def>To deprive of
the beard.</def> <mark>[Obs.]</mark> <rj><au>Bailey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debark</ent><br/
<hw>De"bark"</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Debarked</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Debarking</conjf>.]</vmorph> <ety>[F.
<ets>d<eacute/barquer</ets>; pref. <ets>d<eacute/-</ets> (L.
<ets>dis-</ets>) + <ets>barque</ets>. See <er>Bark</er> the vessel, and
cf. <er>Disbark</er>.]</ety> <def>To go ashore from a ship or boat; to
disembark; to put ashore.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debarkation</ent><br/
<hw>De`bar*ka"tion</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Disembarkation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>debarkation</qex>, therefore, had to take place by small
steamers.</q> <rj><qau>U. S. Grant.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debarment</ent><br/
<hw>De*bar"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Hindrance from
approach; exclusion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debarrass</ent><br/
<hw>De*bar"rass</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Cf. F.
<ets>d<eacute/barrasser</ets>. See <er>Embarrass</er>.]</ety> <def>To
disembarrass; to relieve.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debase</ent><br/
<hw>De*base"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Debased</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Debasing</conjf>.]</vmorph> <ety>[Pref. <ets>de-</ets> +
<ets>base</ets>. See <er>Base</er>, <pos>a.</pos>, and cf.
<er>Abase</er>.]</ety> <def>To reduce from a higher to a lower state or
grade of worth, dignity, purity, station, etc.; to degrade; to lower; to
deteriorate; to abase; <as>as, to <ex>debase</ex> the character by
crime; to <ex>debase</ex> the mind by frivolity; to <ex>debase</ex>
style by vulgar words.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>The coin which was adulterated and <qex>debased</qex>.</q>
<rj><qau>Hale.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>It is a kind of taking God's name in vain to <qex>debase</qex>
religion with such frivolous disputes.</q>
<rj><qau>Hooker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And to <qex>debase</qex> the sons, exalts the sires.</q>
<rj><qau>Pope.</qau></rj></p>

<p><syn><b>Syn.</b> -- To abase; degrade. See <er>Abase</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debased</ent><br/
<hw>De*based"</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Her.)</fld>
<def>Turned upside down from its proper position; inverted;
reversed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debasement</ent><br/
<hw>De*base"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
debasing or the state of being debased.</def>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debaser</ent><br/
<hw>De*bas"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, debases.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debasingly</ent><br/
<hw>De*bas"ing*ly</hw>, <pos>adv.</pos> <def>In a manner to
debase.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debatable</ent><br/
<hw>De*bat"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. OF.
<ets>debatable</ets>. See <er>Debate</er>.]</ety> <def>Liable to be
debated; disputable; subject to controversy or contention; open to
question or dispute; <as>as, a <ex>debatable</ex>
question</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>The Debatable Land</b></col> <it>or</it>
<col><b><or/ Ground</b></col></mcol>, <cd>a tract of land between the
Esk and the Sark, claimed by both England and Scotland; the Batable
Ground.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debate</ent><br/
<hw>De*bate"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Debated</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Debating</conjf>.]</vmorph> <ety>[OF. <ets>debatre</ets>, F.
<ets>d<eacute/battre</ets>; L. <ets>de</ets> + <ets>batuere</ets> to
beat. See <er>Batter</er>, <pos>v. t.</pos>, and cf.
<er>Abate</er>.]</ety> <sn>1.</sn> <def>To engage in combat for; to
strive for.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Volunteers . . . thronged to serve under his banner, and the cause
of religion was <qex>debated</qex> with the same ardor in Spain as on
the plains of Palestine.</q> <rj><qau>Prescott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To contend for in words or arguments; to strive to
maintain by reasoning; to dispute; to contest; to discuss; to argue for
and against.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A wise council . . . that did <qex>debate</qex> this business.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Debate</qex> thy cause with thy neighbor himself.</q>
<rj><qau>Prov. xxv. 9.</qau></rj></p>

<p><syn><b>Syn.</b> -- To argue; discuss; dispute; controvert. See
<er>Argue</er>, and <er>Discuss</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debate</ent><br/
<hw>De*bate"</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To engage in strife
or combat; to fight.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Well could he tourney and in lists <qex>debate</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To contend in words; to dispute; hence, to
deliberate; to consider; to discuss or examine different arguments in
the mind; -- often followed by <xex>on</xex> or
<xex>upon</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He presents that great soul <qex>debating</qex> upon the subject
of life and death with his intimate friends.</q>
<rj><qau>Tatler.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debate</ent><br/
<hw>De*bate"</hw>, <pos>n.</pos> <ety>[F. <ets>d<eacute/bat</ets>, fr.
<ets>d<eacute/battre</ets>. See <er>Debate</er>, <pos>v. t.</pos>]</ety>
<sn>1.</sn> <def>A fight or fighting; contest; strife.</def>
<mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>On the day of the Trinity next ensuing was a great
<qex>debate</qex> . . . and in that murder there were slain . . .
fourscore.</q> <rj><qau>R. of Gloucester.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>But question fierce and proud reply<br/
Gave signal soon of dire <qex>debate</qex>.</q> <rj><qau>Sir W.
Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Contention in words or arguments; discussion for the
purpose of elucidating truth or influencing action; strife in argument;
controversy; <as>as, the <ex>debates</ex> in Parliament or in
Congress</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Heard, noted, answer'd, as in full <qex>debate</qex>.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Subject of discussion.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Statutes and edicts concerning this <qex>debate</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debateful</ent><br/
<hw>De*bate"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Full of
contention; contentious; quarrelsome.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debatefully</ent><br/
<hw>De*bate"ful*ly</hw>, <pos>adv.</pos> <def>With contention.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debatement</ent><br/
<hw>De*bate"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. OF.
<ets>debatement</ets> a beating.]</ety> <def>Controversy; deliberation;
debate.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>A serious question and <qex>debatement</qex> with myself.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debater</ent><br/
<hw>De*bat"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who debates; one
given to argument; a disputant; a controvertist.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Debate where leisure serves with dull <qex>debaters</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debating</ent><br/
<hw>De*bat"ing</hw>, <pos>n.</pos> <def>The act of discussing or
arguing; discussion.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Debating society</b></col> <it>or</it>
<col><b>Debating club</b></col></mcol>, <cd>a society or club for the
purpose of debate and improvement in extemporaneous
speaking.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debatingly</ent><br/
<hw>De*bat"ing*ly</hw>, <pos>adv.</pos> <def>In the manner of a
debate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debauch</ent><br/
<hw>De*bauch"</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Debauched</conjf> <pr>(?)</pr>;
<pos>p. pr. & vb. n.</pos> <conjf>Debauching</conjf>.]</vmorph> <ety>[F.
<ets>d<eacute/baucher</ets>, prob. originally, to entice away from the
workshop; pref. <ets>d<eacute/-</ets> (L. <ets>dis-</ets> or
<ets>de</ets>) + OF. <ets>bauche</ets>, <ets>bauge</ets>, hut, cf. F.
<ets>bauge</ets> lair of a wild boar; prob. from G. or Icel., cf. Icel.
<ets>b<amac/lkr</ets>. See <er>Balk</er>, <pos>n.</pos>]</ety> <def>To
lead away from purity or excellence; to corrupt in character or
principles; to mar; to vitiate; to pollute; to seduce; <as>as, to
<ex>debauch</ex> one's self by intemperance; to <ex>debauch</ex> a
woman; to <ex>debauch</ex> an army.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Learning not <qex>debauched</qex> by ambition.</q>
<rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A man must have got his conscience thoroughly <qex>debauched</qex>
and hardened before he can arrive to the height of sin.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Her pride <qex>debauched</qex> her judgment and her eyes.</q>
<rj><qau>Cowley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debauch</ent><br/
<hw>De*bauch"</hw>, <pos>n.</pos> <ety>[Cf. F.
<ets>d<eacute/bauche</ets>.]</ety> <sn>1.</sn> <def>Excess in eating or
drinking; intemperance; drunkenness; lewdness; debauchery.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The first physicians by <qex>debauch</qex> were made.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An act or occasion of debauchery.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Silenus, from his night's <qex>debauch</qex>,<br/
Fatigued and sick.</q> <rj><qau>Cowley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debauched</ent><br/
<hw>De*bauched"</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Dissolute;
dissipated.</def> <ldquo/A coarse and <xex>debauched</xex> look.<rdquo/
<rj><au>Ld. Lytton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debauchedly</ent><br/
<hw>De*bauch"ed*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a
profligate manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debauchedness</ent><br/
<hw>De*bauch"ed*ness</hw>, <pos>n.</pos> <def>The state of being
debauched; intemperance.</def> <rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debauchee</ent><br/
<hw>Deb`au*chee"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>d<eacute/bauch<eacute/</ets>, <ets>n.</ets>, properly p. p. of
<ets>d<eacute/baucher</ets>. See <er>Debauch</er>, <pos>v.
t.</pos>]</ety> <def>One who is given to intemperance or bacchanalian
excesses; a man habitually lewd; a libertine.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debaucher</ent><br/
<hw>De*bauch"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who debauches
or corrupts others; especially, a seducer to lewdness.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 374 --></p>

<p><ent>Debauchery</ent><br/
<hw>De*bauch"er*y</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Debaucheries</plw> <pr>(<?/)</pr>.</plu> <sn>1.</sn>
<def>Corruption of fidelity; seduction from virtue, duty, or
allegiance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The republic of Paris will endeavor to complete the
<qex>debauchery</qex> of the army.</q> <rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Excessive indulgence of the appetites; especially,
excessive indulgence of lust; intemperance; sensuality; habitual
lewdness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Oppose . . . <qex>debauchery</qex> by temperance.</q>
<rj><qau>Sprat.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debauchment</ent><br/
<hw>De*bauch"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
corrupting; the act of seducing from virtue or duty.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debauchness</ent><br/
<hw>De*bauch"ness</hw>, <pos>n.</pos> <def>Debauchedness.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debeige</ent><br/
<hw>De*beige"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>de</ets> of
+ <ets>beige</ets> the natural color of wool.]</ety> <def>A kind of
woolen or mixed dress goods.</def> <altsp>[Written also
<asp>debage</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debel</ent><br/
<hw>De*bel"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Cf. F.
<ets>d<eacute/beller</ets>. See <er>Debellate</er>.]</ety> <def>To
conquer.</def> <mark>[Obs.]</mark> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debellate</ent><br/
<hw>De*bel"late</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>debellatus</ets>, p. p. of <ets>debellare</ets> to subdue;
<ets>de-</ets> + <ets>bellum</ets> war.]</ety> <def>To subdue; to
conquer in war.</def> <mark>[Obs.]</mark> <rj><au>Speed.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debellation</ent><br/
<hw>Deb`el*la"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL.
<ets>debellatio</ets>.]</ety> <def>The act of conquering or
subduing.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>De bene esse</ent><br/
\'d8<hw>De be"ne es"se</hw> <pr>(?)</pr>. <ety>[L.]</ety>
<fld>(Law)</fld> <def>Of well being; of formal sufficiency for the time;
conditionally; provisionally.</def> <rj><au>Abbott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debenture</ent><br/
<hw>De*ben"ture</hw> <pr>(?; 135)</pr>, <pos>n.</pos> <ety>[L.
<ets>debentur</ets> they are due, fr. <ets>debere</ets> to owe; cf. F.
<ets>debentur</ets>. So called because these receipts began with the
words <ets>Debentur mihi</ets>.]</ety> <sn>1.</sn> <def>A writing
acknowledging a debt; a writing or certificate signed by a public
officer, as evidence of a debt due to some person; the sum thus
due.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A customhouse certificate entitling an exporter of
imported goods to a drawback of duties paid on their importation.</def>
<rj><au>Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><note>It is applied in England to deeds of mortgage given by railway
companies for borrowed money; also to municipal and other bonds and
securities for money loaned.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Any of various instruments issued, esp. by
corporations, as evidences of debt. Such instruments (often called
<col><b>debenture bonds</b></col>) are generally, through not
necessarily, under seal, and are usually secured by a mortgage or other
charge upon property; they may be registered or unregistered. A
debenture secured by a mortgage on specific property is called a
<col><b>mortgage debenture</b></col>; one secured by a floating charge
(which see), a <col><b>floating debenture</b></col>; one not secured by
any charge <col><b>a naked debenture</b></col>. In general the term
<xex>debenture</xex> in British usage designates any security issued by
companies other than their shares, including, therefore, what are in the
United States commonly called <stype>bonds</stype>. When used in the
United States <xex>debenture</xex> generally designates an instrument
secured by a floating charge junior to other charges secured by fixed
mortgages, or, specif., one of a series of securities secured by a group
of securities held in trust for the benefit of the debenture
holders.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Debentured</ent><br/
<hw>De*ben"tured</hw> <pr>(?; 135)</pr>, <pos>a.</pos> <def>Entitled to
drawback or debenture; <as>as, <ex>debentured</ex> goods</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debenture stock</ent><br/
<hw>Debenture stock</hw>. <fld>(Finance)</fld> <def>The debt or series
of debts, collectively, represented by a series of debentures; a debt
secured by a trust deed of property for the benefit of the holders of
shares in the debt or of a series of debentures. By the terms of much
debenture stock the holders are not entitled to demand payment until the
winding up of the company or default in payment; in the case of railway
debentures, they cannot demand payment of the principal, and the debtor
company cannot redeem the stock, except by authority of an act of
Parliament.</def> <mark>[Eng.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Debile</ent><br/
<hw>Deb"ile</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>debilis</ets>: cf. F. <ets>d<eacute/bile</ets>. See
<er>Debility</er>.]</ety> <def>Weak.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debilitant</ent><br/
<hw>De*bil"i*tant</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>debilitants</ets>, p. pr.]</ety> <fld>(Med.)</fld> <def>Diminishing
the energy of organs; reducing excitement; <as>as, a <ex>debilitant</ex>
drug</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debilitate</ent><br/
<hw>De*bil"i*tate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Debilitated</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Debilitating</conjf>.]</vmorph> <ety>[L. <ets>debilitatus</ets>,
p. p. of <ets>debilitare</ets> to debilitate, fr. <ets>debilis</ets>.
See <er>Debility</er>.]</ety> <def>To impair the strength of; to weaken;
to enfeeble; <as>as, to <ex>debilitate</ex> the body by
intemperance</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Various ails <qex>debilitate</qex> the mind.</q>
<rj><qau>Jenyns.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>debilitated</qex> frame of Mr. Bertram was exhausted by
this last effort.</q> <rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>debilitated</ent><br/
<hw>debilitated</hw> <pos>adj.</pos> <sn>1.</sn> <def>lacking strength
or vigor; weakened.</def><br/
<syn><b>Syn. --</b> adynamic, asthenic, enervated.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>weakened due to illness.</def><br/
<syn><b>Syn. --</b> enfeebled, infirm, seedy.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>debilitating</ent><br/
<hw>debilitating</hw> <pos>adj.</pos> <def>causing weakness. Opposite of
<ant>invigorating</ant>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>debilitative</ent><br/
<hw>debilitative</hw> <pos>adj.</pos> <def>causing weakness.</def>
[Narrower terms: <stype>debilitating (vs. invigorating)</stype>]<br/
<syn><b>Syn. --</b> enervating, enfeebling, weakening.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Debilitation</ent><br/
<hw>De*bil`i*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>debilitatio</ets>: cf. F. <ets>d<eacute/bilitation</ets>.]</ety>
<def>The act or process of debilitating, or the condition of one who is
debilitated; weakness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debility</ent><br/
<hw>De*bil"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>debilitas</ets>, fr. <ets>debilis</ets> weak, prob. fr.
<ets>de-</ets> + <ets>habilis</ets> able: cf. F.
<ets>d<eacute/bilit<eacute/</ets>. See <er>Able</er>,
<pos>a.</pos>]</ety> <def>The state of being weak; weakness; feebleness;
languor.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The inconveniences of too strong a perspiration, which are
<qex>debility</qex>, faintness, and sometimes sudden death.</q>
<rj><qau>Arbuthnot.</qau></rj></p>

<p><syn><b>Syn.</b> -- <er>Debility</er>, <er>Infirmity</er>,
<er>Imbecility</er>.</syn> <usage> An <xex>infirmity</xex> belongs, for
the most part, to particular members, and is often temporary, as of the
eyes, etc. <xex>Debility</xex> is more general, and while it lasts
impairs the ordinary functions of nature. <xex>Imbecility</xex> attaches
to the whole frame, and renders it more or less powerless.
<xex>Debility</xex> may be constitutional or may be the result or
superinduced causes; <xex>Imbecility</xex> is always constitutional;
<xex>infirmity</xex> is accidental, and results from sickness or a decay
of the frame. These words, in their figurative uses, have the same
distinctions; we speak of <xex>infirmity</xex> of will,
<xex>debility</xex> of body, and an <xex>Imbecility</xex> which affects
the whole man; but <xex>Imbecility</xex> is often used with specific
reference to feebleness of mind.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debit</ent><br/
<hw>Deb"it</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>debitum</ets>
what is due, debt, from <ets>debere</ets> to owe: cf. F.
<ets>d<eacute/bit</ets>. See <er>Debt</er>.]</ety> <def>A debt; an entry
on the debtor (Dr.) side of an account; -- mostly used adjectively;
<as>as, the <ex>debit</ex> side of an account</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debit</ent><br/
<hw>Deb"it</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Debited</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Debiting</conjf>.]</vmorph> <sn>1.</sn> <def>To charge with debt;
-- the opposite of, and correlative to, <xex>credit</xex>; <as>as, to
<ex>debit</ex> a purchaser for the goods sold</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bookkeeping)</fld> <def>To enter on the debtor
(Dr.) side of an account; <as>as, to <ex>debit</ex> the amount of goods
sold</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debit card</ent><br/
<hw>Deb"it card`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>debit</er>.]</ety> <def>a small usually plastic card with a magnetic
coded number, similar to a credit card, which is used to pay for
purchases by the electronic deduction of a sum of money (a debit)
directly from the card-holder's bank account. Such cards do not require
the establishment of a credit line, and such transactions do not incur
any interest payments.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debitor</ent><br/
<hw>Deb"it*or</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. See
<er>Debtor</er>.]</ety> <def>A debtor.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debituminization</ent><br/
<hw>De`bi*tu`mi*ni*za"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act
of depriving of bitumen.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debituminize</ent><br/
<hw>De`bi*tu"mi*nize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To deprive
of bitumen.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deblai</ent><br/
\'d8<hw>D<eacute/`blai"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<fld>(Fort.)</fld> <def>The cavity from which the earth for parapets,
etc. (remblai), is taken.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debonair</ent><br/
<hw>Deb`o*nair"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OE.
<ets>debonere</ets>, OF. <ets>de bon aire</ets>, <ets>debonaire</ets>,
of good descent or lineage, excellent, debonair, F.
<ets>d<eacute/bonnaire</ets> debonair; <ets>de</ets> of (L.
<ets>de</ets>) + <ets>bon</ets> good (L. <ets>bonus</ets>) +
<ets>aire</ets>. See <er>Air</er>, and <er>Bounty</er>, and cf.
<er>Bonair</er>.]</ety> <def>Characterized by courteousness, affability,
or gentleness; of good appearance and manners; graceful;
complaisant.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Was never prince so meek and <qex>debonair</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debonairity</ent><br/
<hw>Deb`o*nair"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>debonairet<eacute/</ets>, F.
<ets>d<eacute/bonnairet<eacute/</ets>.]</ety> <def>Debonairness.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debonairly</ent><br/
<hw>Deb`o*nair"ly</hw>, <pos>adv.</pos> <def>Courteously;
elegantly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debonairness</ent><br/
<hw>Deb`o*nair"ness</hw>, <pos>n.</pos> <def>The quality of being
debonair; good humor; gentleness; courtesy.</def>
<rj><au>Sterne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debosh</ent><br/
<hw>De*bosh"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Old form of
<ets>debauch</ets>.]</ety> <def>To debauch.</def> <mark>[Obs.]</mark>
<ldquo/A <xex>deboshed</xex> lady.<rdquo/ <rj><au>Beau. &
Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deboshment</ent><br/
<hw>De*bosh"ment</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Debauchment.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debouch</ent><br/
<hw>De*bouch"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Debouched</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Debouching</conjf>.]</vmorph> <ety>[F.
<ets>d<eacute/boucher</ets>; pref. <ets>d<eacute/-</ets> (L.
<ets>dis-</ets> or <ets>de</ets>) + <ets>boucher</ets> to stop up, fr.
<ets>bouche</ets> mouth, fr. L. <ets>bucca</ets> the cheek. Cf.
<er>Disembogue</er>.]</ety> <def>To march out from a wood, defile, or
other confined spot, into open ground; to issue.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Battalions <qex>debouching</qex> on the plain.</q>
<rj><qau>Prescott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Geog.)</fld> <def>To issue; -- said of a stream
passing from a gorge out into an open valley or a plain.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Debouche</ent><br/
\'d8<hw>D<eacute/`bou`ch<eacute/"</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[F.]</ety> <def>A place for exit; an outlet; hence, a market for
goods.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>d<eacute/bouch<eacute/s</qex> were ordered widened to
afford easy egress.</q> <rj><qau>The Century.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>D<eacute/bouchure</ent><br/
\'d8<hw>D<eacute/`bou`chure"</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[F.]</ety> <def>The outward opening of a river, of a valley, or of
a strait.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debrief</ent><br/
<hw>De*brief"</hw> <pr>(?)</pr>, <pos>v.</pos> <def>to interrogate (a
person who has recently experienced an event), to obtain information
about that experience; -- used especially of military pilots or
diplomatic agents who have just returned from a mission.</def><br/
[<source>PJC</source>]</p>

<p><ent>Debride</ent><br/
<hw>De*bride"</hw> <pr>(?)</pr>, <pos>v.</pos> <def>to remove (e. g.,
dead tissue) surgically from a wound.</def><br/
[<source>PJC</source>]</p>

<p><ent>Debridement</ent><br/
<hw>De*bride"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>the surgical
excision of dead, contaminated, or damaged tissue, and foreign matter,
especially from a wound.</def><br/
[<source>PJC</source>]</p>

<p><ent>Debris</ent><br/
\'d8<hw>D<eacute/`bris"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr.
pref. <ets>d<eacute/-</ets> (L. <ets>dis</ets>) + <ets>briser</ets> to
break, shatter; perh. of Celtic origin.]</ety> <sn>1.</sn>
<fld>(Geol.)</fld> <def>Broken and detached fragments, taken
collectively; especially, fragments detached from a rock or mountain,
and piled up at the base.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Rubbish, especially such as results from the
destruction of anything; remains; ruins.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debruised</ent><br/
<hw>De*bruised"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. OF.
<ets>debruisier</ets> to shatter, break. Cf. <er>Bruise</er>.]</ety>
<fld>(Her.)</fld> <def>Surmounted by an ordinary; <as>as, a lion is
<ex>debruised</ex> when a bend or other ordinary is placed over it, as
in the cut</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The lion of England and the lilies of France without the baton
sinister, under which, according to the laws of heraldry, they where
<qex>debruised</qex> in token of his illegitimate birth.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debt</ent><br/
<hw>Debt</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>dette</ets>, F.
<ets>dette</ets>, LL. <ets>debita</ets>, fr. L. <ets>debitus</ets> owed,
p. p. of <ets>debere</ets> to owe, prop., to have on loan;
<ets>de-</ets> + <ets>habere</ets> to have. See <er>Habit</er>, and cf.
<er>Debit</er>, <er>Due</er>.]</ety> <sn>1.</sn> <def>That which is due
from one person to another, whether money, goods, or services; that
which one person is bound to pay to another, or to perform for his
benefit; thing owed; obligation; liability.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Your son, my lord, has paid a soldier's <qex>debt</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>When you run in <qex>debt</qex>, you give to another power over
your liberty.</q> <rj><qau>Franklin.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A duty neglected or violated; a fault; a sin; a
trespass.</def> <ldquo/Forgive us our <xex>debts</xex>.<rdquo/
<rj><au>Matt. vi. 12.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Law)</fld> <def>An action at law to recover a
certain specified sum of money alleged to be due.</def>
<rj><au>Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Bond debt</b></col>, <col><b>Book
debt</b></col></mcol>, <cd>etc. See under <er>Bond</er>, <er>Book</er>,
etc.</cd> -- <col><b>Debt of nature</b></col>, <cd>death.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debted</ent><br/
<hw>Debt"ed</hw>, <pos>p. a.</pos> <def>Indebted; obliged to.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I stand <qex>debted</qex> to this gentleman.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debtee</ent><br/
<hw>Debt*ee"</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Law)</fld> <def>One
to whom a debt is due; creditor; -- correlative to
<xex>debtor</xex>.</def> <rj><au>Blackstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debtless</ent><br/
<hw>Debt"less</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Free from
debt.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debtor</ent><br/
<hw>Debt"or</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>dettur</ets>, <ets>dettour</ets>, OF. <ets>detor</ets>,
<ets>detur</ets>, <ets>detour</ets>, F. <ets>d<eacute/biteur</ets>, fr.
L. <ets>debitor</ets>, fr. <ets>debere</ets> to owe. See
<er>Debt</er>.]</ety> <def>One who owes a debt; one who is indebted; --
correlative to <xex>creditor</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>[I 'll] bring your latter hazard back again,<br/
And thankfully rest <qex>debtor</qex> for the first.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>In Athens an insolvent <qex>debtor</qex> became slave to his
creditor.</q> <rj><qau>Mitford.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Debtors</qex> for our lives to you.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debulliate</ent><br/
<hw>De*bul"li*ate</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[Pref.
<ets>d<eacute/-</ets> + L. <ets>bullire</ets> to boil.]</ety> <def>To
boil over.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debullition</ent><br/
<hw>Deb`ul*li"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Debulliate</er>.]</ety> <def>A bubbling or boiling over.</def>
<mark>[Obs.]</mark> <rj><au>Bailey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deburse</ent><br/
<hw>De*burse"</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <ety>[Pref.
<ets>de</ets> + L. <ets>bursa</ets> purse.]</ety> <def>To
disburse.</def> <mark>[Obs.]</mark> <rj><au>Ludlow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debuscope</ent><br/
<hw>De"bu*scope</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From the
inventor, <ets>Debus</ets>, a French optician +
<ets>-scope</ets>.]</ety> <fld>(Opt.)</fld> <def>A modification of the
kaleidoscope; -- used to reflect images so as to form beautiful
designs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debut</ent><br/
\'d8<hw>D<eacute/`but"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>d<eacute/but</ets>, prop., the first cast or throw at play, fr.
<ets>but</ets> aim, mark. See <er>Butt</er> an end.]</ety> <def>A
beginning or first attempt; hence, a first appearance before the public,
as of an actor or public speaker.</def></p>

<p><ent>Debutante</ent><br/
<ent>Debutant</ent><br/
<mhw>\'d8<hw>D<eacute/`bu`tant"</hw> <pr>(?)</pr>, <pos>n.</pos>; fem.
<hw>D<eacute/`bu`tante"</hw> <pr>(<?/)</pr></mhw>. <ety>[F., p. pr. of
<ets>d<eacute/buter</ets> to have the first throw, to make one's
<ets>d<eacute/but</ets>. See <er>D<eacute/but</er>.]</ety> <def>A person
who makes his (or her) first appearance before the public.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Debutante</ent><br/
<hw>D<eacute/`bu`tante"</hw> <pr>(?)</pr>, <pos>fem. n.</pos> <def>A
young woman making her first appearance in society, especially one who
is one of the honorees at a debutante cotillion. See
<er>cotillion</er>{4}.</def><br/
[<source>PJC</source>]</p>

<p><ent>Deca-</ent><br/
<hw>Dec"a-</hw> <pr>(?)</pr>. <pos>pref.</pos> <ety>[Cf.
<er>Ten</er>.]</ety> <def>A prefix, from Gr. <grk>de`ka</grk>,
signifying <it>ten</it>;</def> <specif>specifically:</specif>
<fld>(Metric System)</fld>, <def>a prefix signifying the weight or
measure that is <sig>ten times</sig> the principal unit.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decacerata</ent><br/
\'d8<hw>De*cac`e*ra"ta</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
fr. Gr. <grk>de`ka</grk> ten + <grk>ke`ras</grk> a horn.]</ety>
<fld>(Zool.)</fld> <def>The division of Cephalopoda which includes the
squids, cuttlefishes, and others having ten arms or tentacles; -- called
also <altname>Decapoda</altname>. <altsp>[Written also
<asp>Decacera</asp>.]</altsp> See <er>Dibranchiata</er>.</def></p>

<p><ent>Decachordon</ent><br/
<ent>Decachord</ent><br/
<mhw>{ <hw>Dec"a*chord</hw> <pr>(?)</pr>, <hw>Dec`a*chor"don</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[Gr. <grk>deka`chordos</grk>
tenstringed; <grk>de`ka</grk> ten + <grk>chordh`</grk> a string.]</ety>
<sn>1.</sn> <def>An ancient Greek musical instrument of ten strings,
resembling the harp.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Something consisting of ten parts.</def> <rj><au>W.
Watson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decacuminated</ent><br/
<hw>Dec`a*cu"mi*na`ted</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>decacuminare</ets> to cut off the top. See
<er>Cacuminate</er>.]</ety> <def>Having the point or top cut off.</def>
<mark>[Obs.]</mark> <rj><au>Bailey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decad</ent><br/
<hw>Dec"ad</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A decade.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Averill was a <qex>decad</qex> and a half his elder.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decadal</ent><br/
<hw>Dec"a*dal</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to ten;
consisting of tens.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decade</ent><br/
<hw>Dec"ade</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>d<eacute/cade</ets>, L. <ets>decas</ets>, <ets>-adis</ets>, fr. Gr.
<?/, fr. <grk>de`ka</grk> ten. See <er>Ten</er>.]</ety> <def>A group or
division of ten; esp., a period of ten years; a decennium; <as>as, a
<ex>decade</ex> of years or days; a <ex>decade</ex> of soldiers; the
second <ex>decade</ex> of Livy.</as></def> <altsp>[Written also
<asp>decad</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><q>During this notable <qex>decade</qex> of years.</q>
<rj><qau>Gladstone.</qau></rj></p>

<p><ent>Decadency</ent><br/
<ent>Decadence</ent><br/
<mhw>{ <hw>De*ca"dence</hw> <pr>(?)</pr>, <hw>De*ca"den*cy</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[LL. <ets>decadentia</ets>; L.
<ets>de-</ets> + <ets>cadere</ets> to fall: cf. F.
<ets>d<eacute/cadence</ets>. See <er>Decay</er>.]</ety> <def>A falling
away; decay; deterioration; declension. <ldquo/The old castle, where the
family lived in their <xex>decadence</xex>.<rdquo/</def> <rj><au>Sir W.
Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decadent</ent><br/
<hw>De*ca"dent</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Decaying;
deteriorating.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decadent</ent><br/
<hw>De*ca"dent</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One that is
decadent, or deteriorating; esp., one characterized by, or exhibiting,
the qualities of those who are degenerating to a lower type; -- specif.
applied to a certain school of modern French writers.</def></p>

<p><q>The <qex>decadents</qex> and <ae/sthetes, and certain types of
realists.</q> <rj><qau>C. L. Dana.</qau></rj></p>

<p><q>The business men of a great State allow their State to be
represented in Congress by <ldquo/<qex>decadents</qex><rdquo/.</q>
<rj><qau>The Century.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Decadist</ent><br/
<hw>Dec"a*dist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A writer of a book
divided into decades; <as>as, Livy was a <ex>decadist</ex></as>.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decagon</ent><br/
<hw>Dec"a*gon</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>deca-</ets> + Gr. <grk>gwni`a</grk> a corner or angle: cf. F.
<ets>d<eacute/cagone</ets>.]</ety> <fld>(Geom.)</fld> <def>A plane
figure having ten sides and ten angles; any figure having ten angles. A
<xex>regular decagon</xex> is one that has all its sides and angles
equal.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decagonal</ent><br/
<hw>De*cag"o*nal</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to a
decagon; having ten sides.</def></p>

<p><ent>Decagramme</ent><br/
<ent>Decagram</ent><br/
<mhw>{ <hw>Dec"a*gram</hw>, <hw>Dec"a*gramme</hw> }</mhw> <pr>(?)</pr>,
<pos>n.</pos> <ety>[F. <ets>d<eacute/cagramme</ets>; Gr.
<grk>de`ka</grk> ten + F. <ets>gramme</ets>. See <er>Gram</er>.]</ety>
<def>A mass in the metric system equal to ten grams, and equal to about
154.32 grains avoirdupois. See 3rd <er>Gram</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decagynia</ent><br/
\'d8<hw>Dec`a*gyn"i*a</hw>
<pr>(d<ecr/k`<adot/*j<icr/n"<icr/*<adot/)</pr>, <pos>n. pl.</pos>
<ety>[NL., fr. Gr. <grk>de`ka</grk> ten + <grk>gynh`</grk> a woman, a
female.]</ety> <fld>(Bot.)</fld> <def>A Linn<ae/an order of plants
characterized by having ten styles.</def></p>

<p><ent>Deccagynous</ent><br/
<ent>Decagynian</ent><br/
<mhw>{ <hw>Dec`a*gyn"i*an</hw>
<pr>(d<ecr/k`<adot/*j<icr/n"<icr/*<ait/n)</pr>, <hw>Dec*cag"y*nous</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[Cf. F.
<ets>d<eacute/cagyne</ets>.]</ety> <fld>(Bot.)</fld> <def>Belonging to
the Decagynia; having ten styles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decahedral</ent><br/
<hw>Dec`a*he"dral</hw> <pr>(d<ecr/k`<adot/*h<emac/"dr<ait/l)</pr>,
<pos>a.</pos> <def>Having ten sides.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decahedron</ent><br/
<hw>Dec`a*he"dron</hw> <pr>(d<ecr/k`<adot/*h<emac/"dr<ocr/n)</pr>,
<pos>n.</pos>; <plu><it>pl.</it> E. <plw>Decahedrons</plw>
<pr>(d<ecr/k`<adot/*h<emac/"dr<ocr/nz)</pr>, L. <plw>Decahedra</plw>
<pr>(#)</pr>.</plu> <ety>[Pref. <ets>deca-</ets> + Gr. <grk>'e`dra</grk>
a seat, a base, fr. <grk>'e`zesqai</grk> to sit: cf. F.
<ets>d<eacute/ca<egrave/dre</ets>.]</ety> <fld>(Geom.)</fld> <def>A
solid figure or body inclosed by ten plane surfaces.</def>
<altsp>[Written also, less correctly, <asp>decaedron</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decalcification</ent><br/
<hw>De*cal`ci*fi*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The
removal of calcareous matter.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decalcify</ent><br/
<hw>De*cal"ci*fy</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Decalcified</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Decalcifying</conjf>.]</vmorph> <def>To deprive of
calcareous matter; thus, to <xex>decalcify</xex> bones is to remove the
stony part, and leave only the gelatin.</def></p>

<p><ent>Decalcomanie</ent><br/
<ent>Decalcomania</ent><br/
<mhw>{ <hw>De*cal`co*ma"ni*a</hw> <pr>(?)</pr>,
<hw>De*cal`co*ma"nie</hw> <pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[F.
<ets>d<eacute/calcomanie</ets>.]</ety> <def>The art or process of
transferring pictures and designs to china, glass, marble, etc., and
permanently fixing them thereto.</def></p>

<p><ent>Decalitre</ent><br/
<ent>Decaliter</ent><br/
<mhw>{ <hw>Dec"a*li`ter</hw>, <hw>Dec"a*li`tre</hw> }</mhw>
<pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>d<eacute/calitre</ets>; Gr.
<grk>de`ka</grk> ten + F. <ets>litre</ets>. See <er>Liter</er>.]</ety>
<def>A measure of capacity in the metric system; a cubic volume of ten
liters, equal to about 610.24 cubic inches, that is, 2.642 wine
gallons.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decalog</ent><br/
<hw>Dec"a*log</hw> <pr>(?; 115)</pr>, <pos>n.</pos>
<def>Decalogue.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decalogist</ent><br/
<hw>De*cal"o*gist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who explains
the Decalogue.</def> <rj><au>J. Gregory.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decalogue</ent><br/
<hw>Dec"a*logue</hw> <pr>(?; 115)</pr>, <pos>n.</pos> <ety>[F.
<ets>d<eacute/calogue</ets>, L. <ets>decalogus</ets>, fr. Gr.
<grk>de`ka</grk> ten + <grk>lo`gos</grk> speech, <grk>le`gw</grk> to
speak, to say. See <er>Ten</er>.]</ety> <def>The Ten Commandments or
precepts given by God to Moses on Mount Sinai, and originally written on
two tables of stone.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decameron</ent><br/
<hw>De*cam"e*ron</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[It.
<ets>decamerone</ets>, fr. Gr. <grk>de`ka</grk> ten + <grk>me`ros</grk>
part; though quite generally supposed to be derived from
<grk>"hme`ra</grk> day: cf. F.
<ets>d<eacute/cam<eacute/ron</ets>.]</ety> <def>A celebrated collection
of tales, supposed to be related in ten days; -- written in the 14th
century, by <person>Boccaccio</person>, an Italian.</def></p>

<p><ent>Decametre</ent><br/
<ent>Decameter</ent><br/
<mhw>{ <hw>Dec"a*me`ter</hw>, <hw>Dec"a*me`tre</hw> }</mhw>
<pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>d<eacute/cam<egrave/tre</ets>;
Gr. <grk>de`ka</grk> ten + <ets>m<egrave/tre</ets>. See
<er>Meter</er>.]</ety> <def>A measure of length in the metric system;
ten meters, equal to about 393.7 inches.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decamp</ent><br/
<hw>De*camp"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Decamped</conjf> <pr>(?; 215)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Decamping</conjf>.]</vmorph> <ety>[F.
<ets>d<eacute/camper</ets>; pref. <ets>d<eacute/-</ets> (L.
<ets>dis</ets>) + <ets>camp</ets> camp. See <er>Camp</er>.]</ety>
<sn>1.</sn> <def>To break up a camp; to move away from a camping ground,
usually by night or secretly.</def> <rj><au>Macaulay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence, to depart suddenly; to run away; -- generally
used disparagingly.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The fathers were ordered to <qex>decamp</qex>, and the house was
once again converted into a tavern.</q>
<rj><qau>Goldsmith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decampment</ent><br/
<hw>De*camp"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>d<eacute/campement</ets>.]</ety> <def>Departure from a camp; a
marching off.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decanal</ent><br/
<hw>Dec"a*nal</hw> <pr>(?; 277)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>d<eacute/canal</ets>. See <er>Dean</er>.]</ety> <def>Pertaining to
a dean or deanery.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His rectorial as well as <qex>decanal</qex> residence.</q>
<rj><qau>Churton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Decanal side</b></col>, <cd>the side of the choir on
which the dean's tall is placed.</cd> -- <col><b>Decanal
stall</b></col>, <cd>the stall allotted to the dean in the choir, on the
right or south side of the chancel.</cd>
<rj><au>Shipley.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decandria</ent><br/
\'d8<hw>De*can"dri*a</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL., fr.
Gr. <grk>de`ka</grk> ten + <grk>'anh`r</grk>, <grk>'andro`s</grk>, a
man.]</ety> <fld>(Bot.)</fld> <def>A Linn<ae/an class of plants
characterized by having ten stamens.</def></p>

<p><ent>Decandrous</ent><br/
<ent>Decandrian</ent><br/
<mhw>{ <hw>De*can"dri*an</hw> <pr>(?)</pr>, <hw>De*can"drous</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[Cf. F.
<ets>d<eacute/candre</ets>.]</ety> <fld>(Bot.)</fld> <def>Belonging to
the Decandria; having ten stamens.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decane</ent><br/
<hw>Dec"ane</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Deca-</er>.]</ety> <fld>(Chem.)</fld> <def>A liquid hydrocarbon,
<chform>C10H22</chform>, of the paraffin series, including several
isomeric modifications.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decangular</ent><br/
<hw>Dec*an"gu*lar</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>deca-</ets> + <ets>angular</ets>.]</ety> <def>Having ten
angles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decani</ent><br/
\'d8<hw>De*ca"ni</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L., lit., of the
dean.]</ety> <def>Used of the side of the choir on which the dean's
stall is placed; decanal; -- correlative to <contr>cantoris</contr>;
<as>as, the decanal, or <ex>decani</ex>, side</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decant</ent><br/
<hw>De*cant"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Decanted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Decanting</conjf>.]</vmorph> <ety>[F. <ets>d<eacute/canter</ets>
(cf. It. <ets>decantare</ets>), prop., to pour off from the edge of a
vessel; pref. <ets>d<eacute/-</ets> (L. <ets>de</ets>) + OF.
<ets>cant</ets> (It. <ets>canto</ets>) edge, border, end. See
<er>Cant</er> an edge.]</ety> <def>To pour off gently, as liquor, so as
not to disturb the sediment; or to pour from one vessel into another;
<as>as, to <ex>decant</ex> wine</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decantate</ent><br/
<hw>De*can"tate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To
decant.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decantation</ent><br/
<hw>De`can*ta"tion</hw> <pr>(?; 277)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>d<eacute/cantation</ets>.]</ety> <def>The act of pouring off a
clear liquor gently from its lees or sediment, or from one vessel into
another.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decanter</ent><br/
<hw>De*cant"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A
vessel used to decant liquors, or for receiving decanted liquors; a kind
of glass bottle used for holding wine or other liquors, from which
drinking glasses are filled.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who decants liquors.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decaphyllous</ent><br/
<hw>De*caph"yl*lous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>deca-</ets> + Gr. <grk>fy`llon</grk> leaf: cf. F.
<ets>d<eacute/caphylle</ets>.]</ety> <fld>(Bot.)</fld> <def>Having ten
leaves.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decapitate</ent><br/
<hw>De*cap"i*tate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Decapitated</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Decapitating</conjf>.]</vmorph> <ety>[LL. <ets>decapitatus</ets>,
p. p. of <ets>decapitare</ets>; L. <ets>de-</ets> + <ets>caput</ets>
head. See <er>Chief</er>.]</ety> <sn>1.</sn> <def>To cut off the head
of; to behead.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To remove summarily from office.</def>
<mark>[Colloq. U. S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>decapitated</ent><br/
<hw>decapitated</hw> <pos>adj.</pos> <def>having had the head cut
off.</def><br/
<syn><b>Syn. --</b> beheaded.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Decapitation</ent><br/
<hw>De*cap`i*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL.
<ets>decapitatio</ets>: cf. F. <ets>d<eacute/capitation</ets>.]</ety>
<def>The act of beheading; beheading.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decapod</ent><br/
<hw>Dec"a*pod</hw> <pr>(d<ecr/k"<adot/*p<ocr/d)</pr>, <pos>n.</pos>
<ety>[Cf. F. <ets>d<eacute/capode</ets>.]</ety> <fld>(Zool.)</fld>
<def>A crustacean with ten feet or legs, as a crab; one of the
<ord>Decapoda</ord>. Also used adjectively, <as>as a <ex>decapod</ex>
crustacean</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 375 --></p>

<p><ent>Decapoda</ent><br/
\'d8<hw>De*cap"o*da</hw> <pr>(d<esl/*k<acr/p"<osl/*d<adot/)</pr>,
<pos>prop. n. pl.</pos> <ety>[NL., fr. Gr. <grk>de`ka</grk> ten +
<grk>poy`s</grk>, <grk>podo`s</grk>, foot.]</ety> <sn>1.</sn>
<fld>(Zool.)</fld> <def>The order of <class>Crustacea</class> which
includes the shrimps, lobsters, crabs, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ They have a carapace, covering and uniting the somites
of the head and thorax and inclosing a gill chamber on each side, and
usually have five (rarely six) pairs of legs. They are divided into two
principal groups: Brachyura and Macrura. Some writers recognize a third
(Anomura) intermediate between the others.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>A division of the dibranchiate
cephalopods including the cuttlefishes and squids. See
<er>Decacera</er>.</def></p>

<p><ent>Decapodous</ent><br/
<ent>Decapodal</ent><br/
<mhw>{ <hw>De*cap"o*dal</hw> <pr>(?)</pr>, <hw>De*cap"o*dous</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <fld>(Zool.)</fld> <def>Belonging to
the decapods; having ten feet; ten-footed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decarbonate</ent><br/
<hw>De*car"bon*ate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To deprive
of carbonic acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decarbonization</ent><br/
<hw>De*car`bon*i*za"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The
action or process of depriving a substance of carbon.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decarbonize</ent><br/
<hw>De*car"bon*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Decarbonized</conjf>
<pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Decarbonizing</conjf>.]</vmorph> <def>To deprive of carbon;
<as>as, to <ex>decarbonize</ex> steel; to <ex>decarbonize</ex> the
blood.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Decarbonized iron</b></col>. <cd>See <er>Malleable
iron</er>.</cd> -- <col><b>Decarbonized steel</b></col>, <cd>homogenous
wrought iron made by a steel process, as that of Bessemer; ingot
iron.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decarbonizer</ent><br/
<hw>De*car"bon*i`zer</hw> <pr>(?)</pr>, <pos>n.</pos> <def>He who, or
that which, decarbonizes a substance.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decarburization</ent><br/
<hw>De*car`bu*ri*za"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act,
process, or result of decarburizing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decarburize</ent><br/
<hw>De*car"bu*rize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To deprive
of carbon; to remove the carbon from.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decard</ent><br/
<hw>De*card"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To discard.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>You have cast those by, <qex>decarded</qex> them.</q> <rj><qau>J.
Fletcher.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decardinalize</ent><br/
<hw>De*car"di*nal*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To depose
from the rank of cardinal.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decastere</ent><br/
<hw>Dec"a*stere</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>d<eacute/cast<egrave/re</ets>; Gr. <grk>de`ka</grk> ten + F.
<ets>st<egrave/re</ets> a stere.]</ety> <fld>(Metric System)</fld>
<def>A measure of capacity, equal to ten steres, or ten cubic
meters.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decastich</ent><br/
<hw>Dec"a*stich</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>deca-</ets> + Gr. <grk>sti`chos</grk> a row, a line of writing, a
verse.]</ety> <def>A poem consisting of ten lines.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decastyle</ent><br/
<hw>Dec"a*style</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>de`ka</grk> ten + <grk>sty`los</grk> a column.]</ety>
<fld>(Arch.)</fld> <def>Having ten columns in front; -- said of a
portico, temple, etc.</def> -- <def2><pos>n.</pos> <def>A portico having
ten pillars or columns in front.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decasyllabic</ent><br/
<hw>Dec`a*syl*lab"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>deca-</ets> + <ets>syllabic</ets>: cf. F.
<ets>d<eacute/casyllabique</ets>, <ets>d<eacute/casyllable</ets>.]</ety>
<def>Having, or consisting of, ten syllables.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>decathlon</ent><br/
<hw>de*cath"lon</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Deca-</er>; <er>Pentathlon</er>.]</ety> <def>In the modern Olympic
Games, a composite contest consisting of a 100-meter run, a broad jump,
putting the shot, a running high-jump, a 400-meter run, throwing the
discus, a 100-meter hurdle race, pole vaulting, throwing the javelin,
and a 1500-meter run.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Decatoic</ent><br/
<hw>Dec`a*to"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Chem.)</fld>
<def>Pertaining to, or derived from, decane.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decay</ent><br/
<hw>De*cay"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Decayed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Decaying</conjf>.]</vmorph> <ety>[OF. <ets>decaeir</ets>,
<ets>dechaer</ets>, <ets>decheoir</ets>, F. <ets>d<eacute/choir</ets>,
to decline, fall, become less; L. <ets>de-</ets> + <ets>cadere</ets> to
fall. See <er>Chance</er>.]</ety> <def>To pass gradually from a sound,
prosperous, or perfect state, to one of imperfection, adversity, or
dissolution; to waste away; to decline; to fail; to become weak,
corrupt, or disintegrated; to rot; to perish; <as>as, a tree
<ex>decays</ex>; fortunes <ex>decay</ex>; hopes
<ex>decay</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Ill fares the land, to hastening ills a prey,<br/
Where wealth accumulates and men <qex>decay</qex>.</q>
<rj><qau>Goldsmith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decay</ent><br/
<hw>De*cay"</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To cause to decay;
to impair.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Infirmity, that <qex>decays</qex> the wise.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To destroy.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decay</ent><br/
<hw>De*cay"</hw>, <pos>n.</pos> <sn>1.</sn> <def>Gradual failure of
health, strength, soundness, prosperity, or of any species of excellence
or perfection; tendency toward dissolution or extinction; corruption;
rottenness; decline; deterioration; <as>as, the <ex>decay</ex> of the
body; the <ex>decay</ex> of virtue; the <ex>decay</ex> of the Roman
empire; a castle in <ex>decay</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Perhaps my God, though he be far before,<br/
May turn, and take me by the hand, and more --<br/
May strengthen my <qex>decays</qex>.</q>
<rj><qau>Herbert.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>His [Johnson's] failure was not to be ascribed to intellectual
<qex>decay</qex>.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Which has caused the <qex>decay</qex> of the consonants to follow
somewhat different laws.</q> <rj><qau>James Byrne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Destruction; death.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Cause of decay.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He that plots to be the only figure among ciphers, is the
<qex>decay</qex> of the whole age.</q> <rj><qau>Bacon.</qau></rj></p>

<p><syn><b>Syn.</b> -- Decline; consumption. See
<er>Decline</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>decayable</ent><br/
<hw>decayable</hw> <pos>adj.</pos> <def>susceptible to decay.</def><br/
<syn><b>Syn. --</b> putrescible, putrefiable, spoilable.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Decayed</ent><br/
<hw>De*cayed"</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Fallen, as to
physical or social condition; affected with decay; rotten; <as>as,
<ex>decayed</ex> vegetation or vegetables; a <ex>decayed</ex> fortune or
gentleman.</as></def> -- <wordforms><wf>De*cay"ed*ness</wf>
<pr>(#)</pr>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decayer</ent><br/
<hw>De*cay"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A causer of
decay.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decease</ent><br/
<hw>De*cease"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>deses</ets>, <ets>deces</ets>, F. <ets>d<eacute/c<egrave/s</ets>,
fr. L. <ets>decessus</ets> departure, death, fr. <ets>decedere</ets> to
depart, die; <ets>de-</ets> + <ets>cedere</ets> to withdraw. See
<er>Cease</er>, <er>Cede</er>.]</ety> <def>Departure, especially
departure from this life; death.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His <qex>decease</qex>, which he should accomplish at
Jerusalem.</q> <rj><qau>Luke ix. 31.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And I, the whilst you mourn for his <qex>decease</qex>,<br/
Will with my mourning plaints your plaint increase.</q>
<rj><qau>Spenser.</qau></rj></p>

<p><syn><b>Syn.</b> -- Death; departure; dissolution; demise; release.
See <er>Death</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decease</ent><br/
<hw>De*cease"</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Deceased</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Deceasing</conjf>.]</vmorph> <def>To depart from this life; to
die; to pass away.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>She's dead, <qex>deceased</qex>, she's dead.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>When our summers have <qex>deceased</qex>.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Inasmuch as he carries the malignity and the lie with him, he so
far <qex>deceases</qex> from nature.</q>
<rj><qau>Emerson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deceased</ent><br/
<hw>De*ceased"</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Passed away; dead;
gone.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>The deceased</b></col>, <cd>the dead
person.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decede</ent><br/
<hw>De*cede"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[L.
<ets>decedere</ets>. See <er>Decease</er>, <pos>n.</pos>]</ety> <def>To
withdraw.</def> <mark>[Obs.]</mark> <rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decedent</ent><br/
<hw>De*ce"dent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>decedens</ets>, p. pr. of <ets>decedere</ets>.]</ety>
<def>Removing; departing.</def> <rj><au>Ash.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decedent</ent><br/
<hw>De*ce"dent</hw>, <pos>n.</pos> <def>A deceased person.</def>
<rj><au>Bouvier.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deceit</ent><br/
<hw>De*ceit"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>deceit</ets>, <ets>des<cced/ait</ets>, <ets>decept</ets> (cf.
<ets>deceite</ets>, <ets>de<cced/oite</ets>), fr. L. <ets>deceptus</ets>
deception, fr. <ets>decipere</ets>. See <er>Deceive</er>.]</ety>
<sn>1.</sn> <def>An attempt or disposition to deceive or lead into
error; any declaration, artifice, or practice, which misleads another,
or causes him to believe what is false; a contrivance to entrap;
deception; a wily device; fraud.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Making the ephah small and the shekel great, and falsifying the
balances by <qex>deceit</qex>.</q> <rj><qau>Amos viii. 5.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Friendly to man, far from <qex>deceit</qex> or guile.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Yet still we hug the dear <qex>deceit</qex>.</q> <rj><qau>N.
Cotton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>Any trick, collusion, contrivance,
false representation, or underhand practice, used to defraud another.
When injury is thereby effected, an <xex>action of deceit</xex>, as it
called, lies for compensation.</def></p>

<p><syn><b>Syn.</b> -- Deception; fraud; imposition; duplicity;
trickery; guile; falsifying; double-dealing; stratagem. See
<er>Deception</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deceitful</ent><br/
<hw>De*ceit"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Full of, or
characterized by, deceit; serving to mislead or insnare; trickish;
fraudulent; cheating; insincere.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Harboring foul <qex>deceitful</qex> thoughts.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deceitfully</ent><br/
<hw>De*ceit"ful*ly</hw>, <pos>adv.</pos> <def>With intent to
deceive.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deceitfulness</ent><br/
<hw>De*ceit"ful*ness</hw>, <pos>n.</pos> <sn>1.</sn> <def>The
disposition to deceive; <as>as, a man's <ex>deceitfulness</ex> may be
habitual</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The quality of being deceitful; <as>as, the
<ex>deceitfulness</ex> of a man's practices</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Tendency to mislead or deceive.</def> <ldquo/The
<xex>deceitfulness</xex> of riches.<rdquo/ <rj><au>Matt. xiii.
22.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deceitless</ent><br/
<hw>De*ceit"less</hw>, <pos>a.</pos> <def>Free from deceit.</def>
<rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deceivable</ent><br/
<hw>De*ceiv"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F.
<ets>d<eacute/cevable</ets>.]</ety> <sn>1.</sn> <def>Fitted to deceive;
deceitful.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The fraud of <qex>deceivable</qex> traditions.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Subject to deceit; capable of being
misled.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Blind, and thereby <qex>deceivable</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deceivableness</ent><br/
<hw>De*ceiv"a*ble*ness</hw>, <pos>n.</pos> <sn>1.</sn> <def>Capability
of deceiving.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With all <qex>deceivableness</qex> of unrighteousness.</q>
<rj><qau>2 Thess. ii. 10.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Liability to be deceived or misled; <as>as, the
<ex>deceivableness</ex> of a child</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deceivably</ent><br/
<hw>De*ceiv"a*bly</hw>, <pos>adv.</pos> <def>In a deceivable
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deceive</ent><br/
<hw>De*ceive"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Deceived</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Deceiving</conjf>.]</vmorph> <ety>[OE.
<ets>deceveir</ets>, F. <ets>d<eacute/cevoir</ets>, fr. L.
<ets>decipere</ets> to catch, insnare, deceive; <ets>de-</ets> +
<ets>capere</ets> to take, catch. See <er>Capable</er>, and cf.
<er>Deceit</er>, <er>Deception</er>.]</ety> <sn>1.</sn> <def>To lead
into error; to cause to believe what is false, or disbelieve what is
true; to impose upon; to mislead; to cheat; to disappoint; to delude; to
insnare.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Evil men and seducers shall wax worse and worse,
<qex>deceiving</qex>, and being <qex>deceived</qex>.</q> <rj><qau>2 Tim.
iii. 13.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Nimble jugglers that <qex>deceive</qex> the eye.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>What can 'scape the eye<br/
Of God all-seeing, or <qex>deceive</qex> his heart?</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To beguile; to amuse, so as to divert the attention;
to while away; to take away as if by deception.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>These occupations oftentimes <qex>deceived</qex><br/
The listless hour.</q> <rj><qau>Wordsworth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To deprive by fraud or stealth; to defraud.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Plant fruit trees in large borders, and set therein fine flowers,
but thin and sparingly, lest they <qex>deceive</qex> the trees.</q>
<rj><qau>Bacon.</qau></rj></p>

<p><syn><b>Syn.</b> -- <er>Deceive</er>, <er>Delude</er>,
<er>Mislead</er>.</syn> <usage> <xex>Deceive</xex> is a general word
applicable to any kind of misrepresentation affecting faith or life.
<xex>To delude</xex>, primarily, is to make sport of, by deceiving, and
is accomplished by playing upon one's imagination or credulity, as by
exciting false hopes, causing him to undertake or expect what is
impracticable, and making his failure ridiculous. It implies some
infirmity of judgment in the victim, and intention to deceive in the
deluder. But it is often used reflexively, indicating that a person's
own weakness has made him the sport of others or of fortune; <as>as, he
<ex>deluded</ex> himself with a belief that luck would always favor
him</as>. <xex>To mislead</xex> is to lead, guide, or direct in a wrong
way, either willfully or ignorantly.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deceiver</ent><br/
<hw>De*ceiv"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who deceives;
one who leads into error; a cheat; an impostor.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The deceived and the <qex>deceiver</qex> are his.</q> <rj><qau>Job
xii. 16.</qau></rj></p>

<p><syn><b>Syn.</b> -- <er>Deceiver</er>, <er>Impostor</er>.</syn>
<usage> A <xex>deceiver</xex> operates by stealth and in private upon
individuals; an <xex>impostor</xex> practices his arts on the community
at large. The one succeeds by artful falsehoods, the other by bold
assumption. The faithless friend and the fickle lover are
<xex>deceivers</xex>; the false prophet and the pretended prince are
<xex>impostors</xex>.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>decelerate</ent><br/
<hw>decelerate</hw> <pos>v. i.</pos> <sn>1.</sn> <fr>1</fr> <def>to
reduce speed; <as>as, The car <ex>decelerated</ex></as>. Opposite of
<ant>accelerate</ant>.</def><br/
<syn><b>Syn. --</b> slow, slow down, slow up, retard.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>decelerate</ent><br/
<hw>decelerate</hw> <pos>v. t.</pos> <def>to cause to reduce speed.
Opposite of <ant>accelerate</ant>.</def><br/
<syn><b>Syn. --</b> slow down.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>deceleration</ent><br/
<hw>deceleration</hw> <pos>n.</pos> <def>a decrease in velocity.
Opposite of <ant>acceleration</ant></def><br/
<syn><b>Syn. --</b> slowing, retardation.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>December</ent><br/
<hw>De*cem"ber</hw> <pr>(d<esl/*s<ecr/m"b<etil/r)</pr>, <pos>prop.
n.</pos> <ety>[F. <ets>d<eacute/cembre</ets>, from L.
<ets>December</ets>, fr. <ets>decem</ets> ten; this being the tenth
month among the early Romans, who began the year in March. See
<er>Ten</er>.]</ety> <sn>1.</sn> <def>The twelfth and last month of the
year, containing thirty-one days. During this month occurs the winter
solstice.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Fig.: With reference to the end of the year and to
the winter season; <as>as, the <ex>December</ex> of his
life</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decembrist</ent><br/
<hw>De*cem"brist</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Russian
Hist.)</fld> <def>One of those who conspired for constitutional
government against the <person>Emperor Nicholas</person> on his
accession to the throne at the death of <person>Alexander I.</person>,
in December, 1825; -- called also
<altname>Dekabrist</altname>.</def></p>

<p><q>He recalls the history of the <qex>decembrists</qex> . . . that
gallant band of revolutionists.</q> <rj><qau>G. Kennan.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Decemdentate</ent><br/
<hw>De`cem*den"tate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>decem</ets> ten + E. <ets>dentate</ets>.]</ety> <def>Having ten
points or teeth.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decemfid</ent><br/
<hw>De*cem"fid</hw> <pr>(d<esl/*s<ecr/m"f<icr/d)</pr>, <pos>a.</pos>
<ety>[L. <ets>decem</ets> ten + root of <ets>findere</ets> to
cleave.]</ety> <fld>(Bot.)</fld> <def>Cleft into ten parts.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decemlocular</ent><br/
<hw>De`cem*loc"u*lar</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>decem</ets> ten + E. <ets>locular</ets>.]</ety> <fld>(Bot.)</fld>
<def>Having ten cells for seeds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decempedal</ent><br/
<hw>De*cem"pe*dal</hw> <pr>(d<esl/*s<ecr/m"p<esl/*d<ait/l)</pr>,
<pos>a.</pos> <ety>[L. <ets>decem</ets> ten + E.
<ets>pedal</ets>.]</ety> <sn>1.</sn> <def>Ten feet in length.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>Having ten feet; decapodal.</def>
<mark>[R.]</mark> <rj><au>Bailey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decemvir</ent><br/
<hw>De*cem"vir</hw> <pr>(d<esl/*s<ecr/m"v<etil/r)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> E. <plw>Decemvirs</plw> <pr>(#)</pr>, L.
<plw>Decemviri</plw> <pr>(#)</pr>.</plu> <ety>[L., fr. <ets>decem</ets>
ten + <ets>vir</ets> a man.]</ety> <sn>1.</sn> <def>One of a body of ten
magistrates in ancient Rome.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The title of <xex>decemvirs</xex> was given to various
bodies of Roman magistrates. The most celebrated decemvirs framed
<ldquo/the laws of the Twelve Tables,<rdquo/ about 450 <sc>B. C.</sc>,
and had absolute authority for three years.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A member of any body of ten men in
authority.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decemviral</ent><br/
<hw>De*cem"vi*ral</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>decemviralis</ets>.]</ety> <def>Pertaining to the decemvirs in
Rome.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decemvirate</ent><br/
<hw>De*cem"vi*rate</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>decemviratus</ets>.]</ety> <sn>1.</sn> <def>The office or term of
office of the decemvirs in Rome.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A body of ten men in authority.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decemvirship</ent><br/
<hw>De*cem"vir*ship</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The office of
a decemvir.</def> <rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decence</ent><br/
<hw>De"cence</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Decency.</def>
<mark>[Obs.]</mark> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decency</ent><br/
<hw>De"cen*cy</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Decencies</plw> <pr>(#)</pr>.</plu> <ety>[L. <ets>decentia</ets>,
fr. <ets>decens</ets>: cf. F. <ets>d<eacute/cence</ets>. See
<er>Decent</er>.]</ety> <sn>1.</sn> <def>The quality or state of being
decent, suitable, or becoming, in words or behavior; propriety of form
in social intercourse, in actions, or in discourse; proper formality;
becoming ceremony; seemliness; hence, freedom from obscenity or
indecorum; modesty.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Observances of time, place, and of <qex>decency</qex> in
general.</q> <rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Immodest words admit of no defense,<br/
For want of <qex>decency</qex> is want of sense.</q>
<rj><qau>Roscommon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is proper or becoming.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The external <qex>decencies</qex> of worship.</q>
<rj><qau>Atterbury.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Those thousand <qex>decencies</qex>, that daily flow<br/
From all her words and actions.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decene</ent><br/
<hw>De"cene</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>decem</ets>
ten.]</ety> <fld>(Chem.)</fld> <def>One of the higher hydrocarbons,
<chform>C10H20</chform>, of the ethylene series.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decennary</ent><br/
<hw>De*cen"na*ry</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Decennaries</plw> <pr>(#)</pr>.</plu> <ety>[L. <ets>decennium</ets>
a period of ten years; <ets>decem</ets> ten + <ets>annus</ets> a
year.]</ety> <sn>1.</sn> <def>A period of ten years.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(O. Eng. Law)</fld> <def>A tithing consisting of ten
neighboring families.</def> <rj><au>Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decennial</ent><br/
<hw>De*cen"ni*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Decennary</er>.]</ety> <def>Consisting of ten years; happening every
ten years; <as>as, a <ex>decennial</ex> period; <ex>decennial</ex>
games.</as></def> <rj><au>Hallam.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decennial</ent><br/
<hw>De*cen"ni*al</hw>, <pos>n.</pos> <def>A tenth year or tenth
anniversary.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decennium</ent><br/
\'d8<hw>De*cen"ni*um</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Decenniums</plw> <pr>(#)</pr>, L. <plw>Decennia</plw>
<pr>(#)</pr>.</plu> <ety>[L.]</ety> <def>A period of ten years.</def>
<ldquo/The present <xex>decennium</xex>.<rdquo/ <au>Hallam.</au>
<ldquo/The last <xex>decennium</xex> of Chaucer's life.<rdquo/
<rj><au>A. W. Ward.</au></rj></p>

<p><ent>Decennovary</ent><br/
<ent>Decennoval</ent><br/
<mhw>{ <hw>De*cen"no*val</hw> <pr>(?)</pr>, <hw>De*cen"no*va*ry</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[L. <ets>decem</ets> ten +
<ets>novem</ets> nine.]</ety> <def>Pertaining to the number nineteen; of
nineteen years.</def> <mark>[R.]</mark> <rj><au>Holder.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>decent</ent><br/
<hw>de"cent</hw> <pr>(d<emac/"s<eit/nt)</pr>, <pos>a.</pos> <ety>[L.
<ets>decens</ets>, <ets>decentis</ets>, p. pr. of <ets>decere</ets> to
be fitting or becoming; akin to <ets>decus</ets> glory, honor, ornament,
Gr. <grk>dokei^n</grk> to seem good, to seem, think; cf. Skr.
<ets>d<amac/<cced/</ets> to grant, to give; and perh. akin to E.
<ets>attire</ets>, <ets>tire</ets>: cf. F. <ets>d<eacute/cent</ets>. Cf.
<er>Decorate</er>, <er>Decorum</er>, <er>Deign</er>.]</ety> <sn>1.</sn>
<def>Suitable in words, behavior, dress, or ceremony; becoming; fit;
decorous; proper; seemly; <as>as, <ex>decent</ex> conduct;
<ex>decent</ex> language</as>.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Before his <qex>decent</qex> steps.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Free from immodesty or obscenity; modest.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Comely; shapely; well-formed.</def>
<mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>A sable stole of cyprus lawn<br/
Over thy <qex>decent</qex> shoulders drawn.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>By foreign hands thy <qex>decent</qex> limbs composed.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Moderate, but competent; sufficient; hence,
respectable; fairly good; reasonably comfortable or satisfying; <as>as,
a <ex>decent</ex> fortune; a <ex>decent</ex> person.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>decent</qex> retreat in the mutability of human
affairs.</q> <rj><qau>Burke.</qau></rj></p>

<p>-- <wordforms><wf>De"cent*ly</wf>, <pos>adv.</pos> --
<wf>De"cent*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>decentralisation</ent><br/
<hw>decentralisation</hw> <pos>n.</pos> <def>same as
<er>decentralization</er>.</def><br/
<syn><b>Syn. --</b> decentralization.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>decentralise</ent><br/
<hw>decentralise</hw> <pos>v.</pos> <def>same as <er>decentralize</er>.
Opposite of <ant>centralize</ant> and <ant>concentrate</ant></def><br/
<syn><b>Syn. --</b> decentralize, deconcentrate.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>decentralizing</ent><br/
<hw>decentralizing</hw> <pos>adj. prenom.</pos> <def>causing a
dispersion or movement away from the center; -- used especially of power
or administrative functions. Opposite of
<ant>centralizing</ant>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>decentralization</ent><br/
<hw>de*cen`tral*i*za"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>The action of decentralizing, or the state of being
decentralized.</def> <ldquo/The <xex>decentralization</xex> of
France.<rdquo/ <rj><au>J. P. Peters.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>the spread of power away from the center to local
branches or governments.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Decentralize</ent><br/
<hw>De*cen"tral*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>to make
less central; to prevent from centralizing; to cause to withdraw from
the center or place of concentration; to divide and distribute (what has
been united or concentrated); -- esp. said of authority, or the
administration of public affairs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deceptible</ent><br/
<hw>De*cep"ti*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of being
deceived; deceivable.</def> <au>Sir T. Browne.</au> --
<wordforms><wf>De*cep`ti*bil"i*ty</wf> <pr>(<?/)</pr>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deception</ent><br/
<hw>De*cep"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>d<eacute/ception</ets>, L. <ets>deceptio</ets>, fr.
<ets>decipere</ets>, <ets>deceptum</ets>. See <er>Deceive</er>.]</ety>
<sn>1.</sn> <def>The act of deceiving or misleading.</def>
<rj><au>South.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The state of being deceived or misled.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There is one thing relating either to the action or enjoyments of
man in which he is not liable to <qex>deception</qex>.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which deceives or is intended to deceive; false
representation; artifice; cheat; fraud.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There was of course room for vast <qex>deception</qex>.</q>
<rj><qau>Motley.</qau></rj></p>

<p><syn><b>Syn.</b> -- <er>Deception</er>, <er>Deceit</er>,
<er>Fraud</er>, <er>Imposition</er>.</syn> <usage> <xex>Deception</xex>
usually refers to the act, and <xex>deceit</xex> to the habit of the
mind; hence we speak of a person as skilled in <xex>deception</xex> and
addicted to <xex>deceit</xex>. The practice of <xex>deceit</xex> springs
altogether from design, and that of the worst kind; but a
<xex>deception</xex> does not always imply aim and intention. It may be
undesigned or accidental. An <xex>imposition</xex> is an act of
deception practiced upon some one to his annoyance or injury; a
<xex>fraud</xex> implies the use of stratagem, with a view to some
unlawful gain or advantage.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deceptious</ent><br/
<hw>De*cep"tious</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[LL.
<ets>deceptiosus</ets>.]</ety> <def>Tending deceive; delusive.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>As if those organs had <qex>deceptious</qex> functions.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deceptive</ent><br/
<hw>De*cep"tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>d<eacute/ceptif</ets>. See <er>Deceive</er>.]</ety> <def>Tending to
deceive; having power to mislead, or impress with false opinions;
<as>as, a <ex>deceptive</ex> countenance or appearance</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Language altogether <qex>deceptive</qex>, and hiding the deeper
reality from our eyes.</q> <rj><qau>Trench.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Deceptive cadence</b></col> <fld>(Mus.)</fld>, <cd>a
cadence on the subdominant, or in some foreign key, postponing the final
close.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deceptively</ent><br/
<hw>De*cep"tive*ly</hw>, <pos>adv.</pos> <def>In a manner to
deceive.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deceptiveness</ent><br/
<hw>De*cep"tive*ness</hw>, <pos>n.</pos> <def>The power or habit of
deceiving; tendency or aptness to deceive.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deceptivity</ent><br/
<hw>De`cep*tiv"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Deceptiveness;
a deception; a sham.</def> <mark>[R.]</mark>
<rj><au>Carlyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deceptory</ent><br/
<hw>De*cep"to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>deceptorius</ets>, from <ets>decipere</ets>.]</ety>
<def>Deceptive.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decern</ent><br/
<hw>De*cern"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>decernere</ets>. See <er>Decree</er>.]</ety> <sn>1.</sn> <def>To
perceive, discern, or decide.</def> <mark>[Obs.]</mark>
<rj><au>Granmer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Scots Law)</fld> <def>To decree; to
adjudge.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 376 --></p>

<p><ent>Decerniture</ent><br/
<hw>De*cern"i*ture</hw> <pr>(?; 135)</pr>, <pos>n.</pos> <fld>(Scots
Law)</fld> <def>A decree or sentence of a court.</def>
<rj><au>Stormonth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decerp</ent><br/
<hw>De*cerp"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>decerpere</ets>; <ets>de-</ets> + <ets>carpere</ets> to
pluck.]</ety> <def>To pluck off; to crop; to gather.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decerpt</ent><br/
<hw>De*cerpt"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>decerptus</ets>, p. p. of <ets>decerpere</ets>.]</ety> <def>Plucked
off or away.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decerptible</ent><br/
<hw>De*cerp"ti*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>That may be
plucked off, cropped, or torn away.</def> <mark>[Obs.]</mark>
<rj><au>Bailey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decerption</ent><br/
<hw>De*cerp"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
act of plucking off; a cropping.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is plucked off or rent away; a fragment;
a piece.</def> <rj><au>Glanvill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decertation</ent><br/
<hw>De`cer*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>decertatio</ets>, fr. <ets>decertare</ets>, <ets>decertatum</ets>;
<ets>de-</ets> + <ets>certare</ets> to contend.]</ety> <def>Contest for
mastery; contention; strife.</def> <mark>[R.]</mark>
<rj><au>Arnway.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decession</ent><br/
<hw>De*ces"sion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>decessio</ets>, fr. <ets>decedere</ets> to depart. See
<er>Decease</er>, <pos>n.</pos>]</ety> <def>Departure; decrease; --
opposed to <xex>accession</xex>.</def> <mark>[Obs.]</mark> <rj><au>Jer.
Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decharm</ent><br/
<hw>De*charm"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Cf. F.
<ets>d<eacute/charmer</ets>. See <er>Charm</er>.]</ety> <def>To free
from a charm; to disenchant.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dechristianize</ent><br/
<hw>De*chris"tian*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Dechristianized</conjf>
<pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Dechristianizing</conjf>.]</vmorph> <def>To turn from, or divest
of, Christianity.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decidable</ent><br/
<hw>De*cid"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of being
decided; determinable.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deciare</ent><br/
<hw>Dec"i*are`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>d<eacute/ciare</ets>; pref. <ets>d<eacute/ci-</ets> tenth (fr. L.
<ets>decimus</ets>) + <ets>are</ets>. See 2d <er>Are</er>.]</ety>
<fld>(Metric System)</fld> <def>A measure of area, the tenth part of an
are; ten square meters.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Decide</ent><br/
<hw>De*cide"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Decided</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Deciding</conjf>.]</vmorph> <ety>[L. <ets>dec<imac/dere</ets>;
<ets>de-</ets> + <ets>caedere</ets> to cut, cut off; prob. akin to E.
<ets>shed</ets>, v.: cf. F. <ets>d<eacute/cider</ets>. Cf.
<er>Decision</er>.]</ety> <sn>1.</sn> <def>To cut off; to
separate.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Our seat denies us traffic here;<br/
The sea, too near, <qex>decides</qex> us from the rest.</q>
<rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To bring to a termination, as a question,
controversy, struggle, by giving the victory to one side or party; to
render judgment concerning; to determine; to settle.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>So shall thy judgment be; thyself hast <qex>decided</qex> it.</q>
<rj><qau>1 Kings xx. 40.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The quarrel toucheth none but us alone;<br/
Betwixt ourselves let us <qex>decide</qex> it then.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decide</ent><br/
<hw>De*cide"</hw>, <pos>v. i.</pos> <def>To determine; to form a
definite opinion; to come to a conclusion; to give decision; <as>as, the
court <ex>decided</ex> in favor of the defendant</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Who shall <qex>decide</qex>, when doctors disagree?</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decided</ent><br/
<hw>De*cid"ed</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Free
from ambiguity; unequivocal; unmistakable; unquestionable; clear;
evident; <as>as, a <ex>decided</ex> advantage</as>.</def> <ldquo/A more
<xex>decided</xex> taste for science.<rdquo/
<rj><au>Prescott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Free from doubt or wavering; determined; of fixed
purpose; fully settled; positive; resolute; <as>as, a <ex>decided</ex>
opinion or purpose</as>.</def></p>

<p><syn><b>Syn.</b> -- <er>Decided</er>, <er>Decisive</er>.</syn>
<usage> We call a thing <xex>decisive</xex> when it has the power or
quality of deciding; as, a <ex>decisive</ex> battle; we speak of it as
<xex>decided</xex> when it is so fully settled as to leave no room for
doubt; as, a <ex>decided</ex> preference, a <ex>decided</ex> aversion.
Hence, a <xex>decided</xex> victory is one about which there is no
question; a <xex>decisive</xex> victory is one which ends the contest.
<xex>Decisive</xex> is applied only to things; as, a <ex>decisive</ex>
sentence, a <ex>decisive</ex> decree, a <ex>decisive</ex> judgment.
<xex>Decided</xex> is applied equally to persons and things. Thus we
speak of a man as <xex>decided</xex> in his whole of conduct; and as
having a <xex>decided</xex> disgust, or a <xex>decided</xex> reluctance,
to certain measures. <ldquo/A politic caution, a guarded circumspection,
were among the ruling principles of our forefathers in their most
<xex>decided</xex> conduct.<rdquo/ <au>Burke.</au> <ldquo/The sentences
of superior judges are final, <xex>decisive</xex>, and
irrevocable.<rdquo/ <rj><au>Blackstone.</au></rj> </usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decidedly</ent><br/
<hw>De*cid"ed*ly</hw>, <pos>adv.</pos> <def>In a decided manner;
indisputably; clearly; thoroughly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decidement</ent><br/
<hw>De*cide"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Means of forming
a decision.</def> <mark>[Obs.]</mark> <rj><au>Beau. & Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decidence</ent><br/
<hw>Dec"i*dence</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>decidens</ets> falling off.]</ety> <def>A falling off.</def>
<mark>[R.]</mark> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decider</ent><br/
<hw>De*cid"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
decides.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decidua</ent><br/
\'d8<hw>De*cid"u*a</hw> <pr>(?; 135)</pr>, <pos>n.</pos> <ety>[NL., fr.
L. <ets>deciduus</ets>. See <er>Deciduous</er>.]</ety>
<fld>(Anat.)</fld> <def>The inner layer of the wall of the uterus, which
envelops the embryo, forms a part of the placenta, and is discharged
with it.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deciduata</ent><br/
\'d8<hw>De*cid`u*a"ta</hw> <pr>(?)</pr>, <pos>n. pl.</pos>
<ety>[NL.]</ety> <fld>(Zool.)</fld> <def>A group of Mammalia in which a
decidua is thrown off with, or after, the fetus, as in the human
species.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deciduate</ent><br/
<hw>De*cid"u*ate</hw> <pr>(?; 135)</pr>, <pos>a.</pos>
<fld>(Anat.)</fld> <def>Possessed of, or characterized by, a
decidua.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deciduity</ent><br/
<hw>Dec`i*du"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Deciduousness.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deciduous</ent><br/
<hw>De*cid"u*ous</hw> <pr>(?; 135)</pr>, <pos>a.</pos> <ety>[L.
<ets>deciduus</ets>, fr. <ets>decidere</ets> to fall off; <ets>de-</ets>
+ <ets>cadere</ets> to fall. See <er>Chance</er>.]</ety>
<fld>(Biol.)</fld> <def>Falling off, or subject to fall or be shed, at a
certain season, or a certain stage or interval of growth, as leaves
(except of evergreens) in autumn, or as parts of animals, such as hair,
teeth, antlers, etc.; also, shedding leaves or parts at certain seasons,
stages, or intervals; <as>as, <ex>deciduous</ex> trees; the
<ex>deciduous</ex> membrane.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deciduousness</ent><br/
<hw>De*cid"u*ous*ness</hw>, <pos>n.</pos> <def>The quality or state of
being deciduous.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decigramme</ent><br/
<ent>Decigram</ent><br/
<mhw>{ <hw>Dec"i*gram</hw>, <hw>Dec"i*gramme</hw> }</mhw> <pr>(?)</pr>,
<pos>n.</pos> <ety>[F. <ets>d<eacute/cigramme</ets>; pref.
<ets>d<eacute/ci-</ets> tenth (fr. L. <ets>decimus</ets>) +
<ets>gramme</ets>.]</ety> <def>A quantity of mass in the metric system
equal to one tenth of a gram, and equal to 1.5432 grains avoirdupois.
See 3rd <er>gram</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decile</ent><br/
<ent>Decil</ent><br/
<mhw>{ <hw>Dec"il</hw>, <hw>Dec"ile</hw> }</mhw> <pr>(?)</pr>,
<pos>n.</pos> <ety>[F. <ets>d<eacute/cil</ets>, fr. L. <ets>decem</ets>
ten, cf. It. <ets>decile</ets>.]</ety> <fld>(Astrol.)</fld> <def>An
aspect or position of two planets, when they are distant from each other
a tenth part of the zodiac, or 36<deg/.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decilitre</ent><br/
<ent>Deciliter</ent><br/
<mhw>{ <hw>Dec"i*li`ter</hw>, <hw>Dec"i*li`tre</hw> }</mhw>
<pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>d<eacute/cilitre</ets>; pref.
<ets>d<eacute/ci-</ets> tenth (L. <ets>decimus</ets>) +
<ets>litre</ets>. See <er>Liter</er>.]</ety> <def>A measure of capacity
or volume in the metric system; one tenth of a liter, equal to 6.1022
cubic inches, or 3.38 fluid ounces.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decillion</ent><br/
<hw>De*cil"lion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>decem</ets> ten + the ending of <ets>million</ets>.]</ety>
<def>According to the English notation, a million involved to the tenth
power, or a unit with sixty ciphers annexed; according to the French and
American notation, a thousand involved to the eleventh power, or a unit
with thirty-three ciphers annexed. [See the Note under
<er>Numeration</er>.]</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decillionth</ent><br/
<hw>De*cil"lionth</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to a
decillion, or to the quotient of unity divided by a decillion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decillionth</ent><br/
<hw>De*cil"lionth</hw> <pr>(?)</pr>, <pos>n.</pos> <sd>(a)</sd> <def>The
quotient of unity divided by a decillion.</def> <sd>(b)</sd> <def>One of
a decillion equal parts.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decimal</ent><br/
<hw>Dec"i*mal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F.
<ets>d<eacute/cimal</ets> (cf. LL. <ets>decimalis</ets>), fr. L.
<ets>decimus</ets> tenth, fr. <ets>decem</ets> ten. See <er>Ten</er>,
and cf. <er>Dime</er>.]</ety> <def>Of or pertaining to decimals;
numbered or proceeding by tens; having a tenfold increase or decrease,
each unit being ten times the unit next smaller; <as>as,
<ex>decimal</ex> notation; a <ex>decimal</ex> coinage.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Decimal arithmetic</b></col>, <cd>the common arithmetic,
in which numeration proceeds by tens.</cd> -- <col><b>Decimal
fraction</b></col>, <cd>a fraction in which the denominator is some
power of 10, as <frac2x10/, <frac25x100/, and is usually not expressed,
but is signified by a point placed at the left hand of the numerator, as
.2, .25.</cd> -- <col><b>Decimal point</b></col>, <cd>a dot or full stop
at the left of a decimal fraction. The figures at the left of the point
represent units or whole numbers, as 1.05.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decimal</ent><br/
<hw>Dec"i*mal</hw>, <pos>n.</pos> <def>A number expressed in the scale
of tens; specifically, and almost exclusively, used as synonymous with a
decimal fraction.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Circulating decimal</b></col>, <it>or</it>
<col><b>Circulatory decimal</b></col></mcol>, <cd>a decimal fraction in
which the same figure, or set of figures, is constantly repeated; as,
0.354354354; -- called also <altname>recurring decimal</altname>,
<altname>repeating decimal</altname>, and
<altname>repetend</altname>.</cd></cs><-- see also repetend --><br/
[<source>1913 Webster</source>]</p>

<p><ent>decimalisation</ent><br/
<hw>decimalisation</hw> <pos>n.</pos> <def>same as
<er>decimalization</er>.</def><br/
<syn><b>Syn. --</b> decimalization.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>decimalise</ent><br/
<hw>decimalise</hw> <pos>v.</pos> <sn>1.</sn> <def>same as
<er>decimalize</er>.</def><br/
<syn><b>Syn. --</b> decimalize.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>decimalization</ent><br/
<hw>decimalization</hw> <pos>n.</pos> <def>the act of changing to a
decimal system; <as>as, the <ex>decimalization</ex> of the British
currency</as>.</def><br/
<syn><b>Syn. --</b> decimalisation.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>decimalism</ent><br/
<hw>dec"i*mal*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The system of a
decimal currency, decimal weights, measures, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decimalize</ent><br/
<hw>Dec"i*mal*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>to convert
the dominant units of measure (e.g. of currency) to a decimal-based
system; to reduce to a decimal system; <as>as, to <ex>decimalize</ex>
the currency</as>.</def> -- <wordforms><wf>Dec`i*mal*i*za"tion</wf>
<pr>(#)</pr>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decimally</ent><br/
<hw>Dec"i*mal*ly</hw>, <pos>adv.</pos> <def>By tens; by means of
decimals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decimate</ent><br/
<hw>Dec"i*mate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Decimated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Decimating</conjf> <pr>(?)</pr>.]</vmorph> <ety>[L.
<ets>decimatus</ets>, p. p. of <ets>decimare</ets> to decimate (in
senses 1 & 2), fr. <ets>decimus</ets> tenth. See
<er>Decimal</er>.]</ety> <sn>1.</sn> <def>To take the tenth part of; to
tithe.</def> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To select by lot and punish with death every tenth
man of; <as>as, to <ex>decimate</ex> a regiment as a punishment for
mutiny</as>.</def> <rj><au>Macaulay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To destroy a considerable part of; <as>as, to
<ex>decimate</ex> an army in battle; to <ex>decimate</ex> a people by
disease.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decimation</ent><br/
<hw>Dec`i*ma"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>decimatio</ets>: cf. F. <ets>d<eacute/cimation</ets>.]</ety>
<sn>1.</sn> <def>A tithing.</def> <mark>[Obs.]</mark> <rj><au>State
Trials (1630).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A selection of every tenth person by lot, as for
punishment.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The destruction of any large proportion, as of
people by pestilence or war.</def> <rj><au>Milman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decimator</ent><br/
<hw>Dec"i*ma`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. LL.
<ets>decimator</ets>.]</ety> <def>One who decimates.</def>
<rj><au>South.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decime</ent><br/
\'d8<hw>D<eacute/`cime"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<def>A French coin, the tenth part of a franc, equal to about two cents
(around 1900). In 2001 all previous French coins were superseded by the
euro.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Decimetre</ent><br/
<ent>Decimeter</ent><br/
<mhw>{ <hw>Dec"i*me`ter</hw>, <hw>Dec"i*me`tre</hw> }</mhw>
<pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>d<eacute/cim<egrave/tre</ets>;
pref. <ets>d<eacute/ci-</ets> tenth (fr. L. <ets>decimus</ets>) +
<ets>m<egrave/tre</ets>. See <er>Meter</er>.]</ety> <def>A measure of
length in the metric system; one tenth of a meter, equal to 3.937
inches.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decimosexto</ent><br/
<hw>Dec`i*mo*sex"to</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Prop., in
sixteenth; fr. L. <ets>decimus</ets> tenth + <ets>sextus</ets>
sixth.]</ety> <def>A book consisting of sheets, each of which is folded
into sixteen leaves; hence, indicating, more or less definitely, a size
of book; -- usually written 16mo or 16<deg/.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decimosexto</ent><br/
<hw>Dec`i*mo*sex"to</hw>, <pos>a.</pos> <def>Having sixteen leaves to a
sheet; <as>as, a <ex>decimosexto</ex> form, book, leaf,
size</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decine</ent><br/
<hw>De"cine</hw> <pr>(?; 104)</pr>, <pos>n.</pos> <ety>[From L.
<ets>decem</ets> ten.]</ety> <fld>(Chem.)</fld> <def>One of the higher
hydrocarbons, <wordforms>C10H15</wordforms>, of the acetylene series; --
called also <altname>decenylene</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decipher</ent><br/
<hw>De*ci"pher</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Deciphered</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Deciphering</conjf>.]</vmorph> <ety>[Pref.
<ets>de-</ets> + <ets>cipher</ets>. Formed in imitation of F.
<ets>d<eacute/chiffrer</ets>. See <er>Cipher</er>.]</ety> <sn>1.</sn>
<def>To translate from secret characters or ciphers into intelligible
terms; <as>as, to <ex>decipher</ex> a letter written in secret
characters</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To find out, so as to be able to make known the
meaning of; to make out or read, as words badly written or partly
obliterated; to detect; to reveal; to unfold.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To stamp; to detect; to discover.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>You are both <qex>deciphered</qex>, . . . <br/
For villains.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decipherable</ent><br/
<hw>De*ci"pher*a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of
being deciphered; <as>as, old writings not
<ex>decipherable</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decipherer</ent><br/
<hw>De*ci"pher*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
deciphers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decipheress</ent><br/
<hw>De*ci"pher*ess</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A woman who
deciphers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decipherment</ent><br/
<hw>De*ci"pher*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
deciphering.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decipiency</ent><br/
<hw>De*cip"i*en*cy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>decipiens</ets>, p. pr. of <ets>decipere</ets>. See
<er>Deceive</er>.]</ety> <def>State of being deceived;
hallucination.</def> <mark>[Obs.]</mark> <rj><au>Sir T.
Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decipium</ent><br/
<hw>De*cip"i*um</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. L.
<ets>decipere</ets> to deceive.]</ety> <fld>(Chem.)</fld> <def>A
supposed rare element, said to be associated with cerium, yttrium, etc.,
in the mineral samarskite, and more recently called <xex>samarium</xex>.
Symbol Dp. See <er>Samarium</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decision</ent><br/
<hw>De*ci"sion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>decisio</ets>, fr. <ets>dec<imac/dere</ets>, <ets>decisum</ets>:
cf. F. <ets>d<eacute/cision</ets>. See <er>Decide</er>.]</ety>
<sn>1.</sn> <def>Cutting off; division; detachment of a part.</def>
<mark>[Obs.]</mark> <rj><au>Bp. Pearson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The act of deciding; act of settling or terminating,
as a controversy, by giving judgment on the matter at issue;
determination, as of a question or doubt; settlement;
conclusion.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>decision</qex> of some dispute.</q>
<rj><qau>Atterbury.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>An account or report of a conclusion, especially of
a legal adjudication or judicial determination of a question or cause;
<as>as, a <ex>decision</ex> of arbitrators; a <ex>decision</ex> of the
Supreme Court.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The quality of being decided; prompt and fixed
determination; unwavering firmness; <as>as, to manifest great
<ex>decision</ex></as>.</def></p>

<p><syn><b>Syn.</b> -- <er>Decision</er>, <er>Determination</er>,
<er>Resolution</er>.</syn> <usage> Each of these words has two meanings,
one implying the act of deciding, determining, or resolving; and the
other a <xex>habit of mind</xex> as to doing. It is in the last sense
that the words are here compared. <xex>Decision</xex> is a <xex>cutting
short</xex>. It implies that several courses of action have been
presented to the mind, and that the choice is now finally made. It
supposes, therefore, a union of promptitude and energy.
<xex>Determination</xex> is the natural consequence of decision. It is
the settling of a thing with a fixed purpose to adhere.
<xex>Resolution</xex> is the necessary result in a mind which is
characterized by firmness. It is a spirit which <xex>scatters</xex>
(resolves) all doubt, and is ready to face danger or suffering in
carrying out one's determinations. Martin Luther was equally
distinguished for his prompt <xex>decision</xex>, his steadfast
<xex>determination</xex>, and his inflexible
<xex>resolution</xex>.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decisive</ent><br/
<hw>De*ci*sive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>d<eacute/cisif</ets>. See <er>Decision</er>.]</ety> <sn>1.</sn>
<def>Having the power or quality of deciding a question or controversy;
putting an end to contest or controversy; final; conclusive.</def>
<ldquo/A <xex>decisive</xex>, irrevocable doom.<rdquo/ <au>Bates.</au>
<ldquo/<xex>Decisive</xex> campaign.<rdquo/ <au>Macaulay.</au>
<ldquo/<xex>Decisive</xex> proof.<rdquo/ <au>Hallam.</au><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Marked by promptness and decision.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A noble instance of this attribute of the <qex>decisive</qex>
character.</q> <rj><qau>J. Foster.</qau></rj></p>

<p><syn><b>Syn.</b> -- Decided; positive; conclusive. See
<er>Decided</er>.</syn></p>

<p>-- <wordforms><wf>De*ci"sive*ly</wf>, <pos>adv.</pos> --
<wf>De*ci"sive*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decisory</ent><br/
<hw>De*ci"so*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>d<eacute/cisoire</ets>. See <er>Decision</er>.]</ety> <def>Able to
decide or determine; having a tendency to decide.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decistere</ent><br/
<hw>Dec"i*stere</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>d<eacute/cist<egrave/re</ets>; pref. <ets>d<eacute/ci-</ets> tenth
(fr. L. <ets>decimus</ets>) + <ets>st<egrave/re</ets> a stere.]</ety>
<fld>(Metric System)</fld> <def>The tenth part of the stere or cubic
meter, equal to 3.531 cubic feet. See <er>Stere</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decitizenize</ent><br/
<hw>De*cit"i*zen*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To deprive
of the rights of citizenship.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>We have no law -- as the French have -- to <qex>decitizenize</qex>
a citizen.</q> <rj><qau>Edw. Bates.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decivilize</ent><br/
<hw>De*civ"i*lize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To reduce
from civilization to a savage state.</def> <mark>[R.]</mark>
<rj><au>Blackwood's Mag.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deck</ent><br/
<hw>Deck</hw> <pr>(d<ecr/k)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Decked</conjf> <pr>(d<ecr/kt)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Decking</conjf>.]</vmorph> <ety>[D. <ets>dekken</ets> to
cover; akin to E. <ets>thatch</ets>. See <er>Thatch</er>.]</ety>
<sn>1.</sn> <def>To cover; to overspread.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>deck</qex> with clouds the uncolored sky.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To dress, as the person; to clothe; especially, to
clothe with more than ordinary elegance; to array; to adorn; to
embellish.</def><br/
<syn><b>Syn. --</b> adorn, decorate, grace, embellish, ornament,
beautify.</syn><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Deck</qex> thyself now with majesty and excellency.</q>
<rj><qau>Job xl. 10.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And <qex>deck</qex> my body in gay ornaments.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The dew with spangles <qex>decked</qex> the ground.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To furnish with a deck, as a vessel.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>to knock down (a person) with a forceful blow;
<as>as, He <ex>decked</ex> his opponent with a single
punch</as>.</def><br/
<syn><b>Syn. --</b> coldcock, dump, knock down, floor.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Deck</ent><br/
<hw>Deck</hw>, <pos>n.</pos> <ety>[D. <ets>dek</ets>. See <er>Deck</er>,
<pos>v.</pos>]</ety> <sn>1.</sn> <def>The floorlike covering of the
horizontal sections, or compartments, of a ship. Small vessels have only
one deck; larger ships have two or three decks.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The following are the more common names of the decks of
vessels having more than one.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Berth deck</b></col> <fld>(Navy)</fld>, <cd>a deck next
below the gun deck, where the hammocks of the crew are swung.</cd> --
<col><b>Boiler deck</b></col> <fld>(River Steamers)</fld>, <cd>the deck
on which the boilers are placed.</cd> -- <col><b>Flush deck</b></col>,
<cd>any continuous, unbroken deck from stem to stern.</cd> --
<col><b>Gun deck</b></col> <fld>(Navy)</fld>, <cd>a deck below the spar
deck, on which the ship's guns are carried. If there are two gun decks,
the upper one is called the <xex>main deck</xex>, the lower, the
<xex>lower gun deck</xex>; if there are three, one is called the
<xex>middle gun deck</xex>.</cd> -- <col><b>Half-deck</b></col>,
<cd>that portion of the deck next below the spar deck which is between
the mainmast and the cabin.</cd> -- <col><b>Hurricane deck</b></col>
<fld>(River Steamers, etc.)</fld>, <cd>the upper deck, usually a light
deck, erected above the frame of the hull.</cd> -- <col><b>Orlop
deck</b></col>, <cd>the deck or part of a deck where the cables are
stowed, usually below the water line.</cd> -- <col><b>Poop
deck</b></col>, <cd>the deck forming the roof of a poop or poop cabin,
built on the upper deck and extending from the mizzenmast aft.</cd> --
<col><b>Quarter-deck</b></col>, <cd>the part of the upper deck abaft the
mainmast, including the poop deck when there is one.</cd> --
<col><b>Spar deck</b></col>. <sd>(a)</sd> <cd>Same as the upper
deck.</cd> <sd>(b)</sd> <cd>Sometimes a light deck fitted over the upper
deck.</cd> -- <col><b>Upper deck</b></col>, <cd>the highest deck of the
hull, extending from stem to stern.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(arch.)</fld> <def>The upper part or top of a
mansard roof or curb roof when made nearly flat.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Railroad)</fld> <def>The roof of a passenger
car.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A pack or set of playing cards.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The king was slyly fingered from the <qex>deck</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A heap or store.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Who . . . hath such trinkets<br/
Ready in the <qex>deck</qex>.</q> <rj><qau>Massinger.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(A<eum/ronautics)</fld> <def>A main a<eum/roplane
surface, esp. of a biplane or multiplane.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>7.</sn> <def>the portion of a bridge which serves as the
roadway.</def><br/
[<source>PJC</source>]</p>

<p><sn>8.</sn> <def>a flat platform adjacent to a house, usually without
a roof; -- it is typically used for relaxing out of doors, outdoor
cooking, or entertaining guests.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Between decks</b></col>. <cd>See under
<er>Between</er>.</cd> -- <col><b>Deck bridge</b></col> <fld>(Railroad
Engineering)</fld>, <cd>a bridge which carries the track upon the upper
chords; -- distinguished from a <xex>through bridge</xex>, which carries
the track upon the lower chords, between the girders.</cd> --
<col><b>Deck curb</b></col> <fld>(Arch.)</fld>, <cd>a curb supporting a
deck in roof construction.</cd> -- <col><b>Deck floor</b></col>
<fld>(Arch.)</fld>, <cd>a floor which serves also as a roof, as of a
belfry or balcony.</cd> -- <col><b>Deck hand</b></col>, <cd>a sailor
hired to help on the vessel's deck, but not expected to go aloft.</cd>
-- <col><b>Deck molding</b></col> <fld>(Arch.)</fld>, <cd>the molded
finish of the edge of a deck, making the junction with the lower slope
of the roof.</cd> -- <col><b>Deck roof</b></col> <fld>(Arch.)</fld>,
<cd>a nearly flat roof which is not surmounted by parapet walls.</cd> --
<col><b>Deck transom</b></col> <fld>(Shipbuilding)</fld>, <cd>the
transom into which the deck is framed.</cd> -- <col><b>To clear the
decks</b></col> <fld>(Naut.)</fld>, <cd>to remove every unnecessary
incumbrance in preparation for battle; to prepare for action.</cd> --
<col><b>To sweep the deck</b></col> <fld>(Card Playing)</fld>, <cd>to
clear off all the stakes on the table by winning them.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deckel</ent><br/
<hw>Deck"el</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Paper Making)</fld>
<def>Same as <er>Deckle</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deck chair</ent><br/
<hw>Deck" chair`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>a folding chair,
usually having arms and a full-length leg rest; -- used for relaxing on
the deck of a ship, at poolside, etc. Also called <altname>steamer
chair</altname></def><br/
[<source>PJC</source>]</p>

<p><ent>decked</ent><br/
<hw>decked</hw> <pos>adj.</pos> <def>clothed or adorned with
finery.</def><br/
<syn><b>Syn. --</b> adorned(predicate), bedecked(predicate)(predicate),
decked out(predicate).</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Decker</ent><br/
<hw>Deck"er</hw> <pr>(d<ecr/k"<etil/r)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>One who, or that which, decks or adorns; a coverer; <as>as, a table
<ex>decker</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A vessel or vehicle which has a deck or decks; --
used esp. in composition; <as>as, a single-<ex>decker</ex>; a
three-<ex>decker</ex>; a double-<ex>decker</ex> bus.</as></def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>deckle</ent><br/
<hw>dec"kle</hw> <pr>(d<ecr/k"k'l)</pr>, <pos>n.</pos> <ety>[Cf. G.
<ets>deckel</ets> cover, lid.]</ety> <fld>(Paper Making)</fld> <def>A
separate thin wooden frame used to form the border of a hand mold, or a
curb of India rubber or other material which rests on, and forms the
edge of, the mold in a paper machine and determines the width of the
paper.</def> <altsp>[Spelt also <asp>deckel</asp>, and
<asp>dekle</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deckle edge</ent><br/
<hw>Dec"kle edge`</hw>. <def>The rough, untrimmed edge of paper left by
the deckle; also, a rough edge in imitation of this.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>deckled</ent><br/
<ent>deckle-edged</ent><br/
<mhw><hw>dec"kle-edged`</hw> <hw>dec"kled</hw></mhw> <pr>(?)</pr>,
<pos>a.</pos> <def>having a rough edge; having a deckle edge; -- used of
handmade paper or paper resembling handmade; <as>as,
<ex>deckle-edged</ex> paper; a <ex>deckle-edged</ex>
book</as>.</def><br/
<syn><b>Syn. --</b> featheredged.</syn><br/
[<source>Webster 1913 Suppl.</source> + <source>WordNet 1.5</source>]</p>

<p><ent>Declaim</ent><br/
<hw>De*claim"</hw> <pr>(d<esl/*kl<amac/m")</pr>, <pos>v. i.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Declaimed</conjf>
<pr>(d<esl/*kl<amac/md")</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Declaiming</conjf>.]</vmorph> <ety>[L. <ets>declamare</ets>;
<ets>de-</ets> + <ets>clamare</ets> to cry out: cf. F.
<ets>d<eacute/clamer</ets>. See <er>Claim</er>.]</ety> <sn>1.</sn>
<def>To speak rhetorically; to make a formal speech or oration; to
harangue; specifically, to recite a speech, poem, etc., in public as a
rhetorical exercise; to practice public speaking; <as>as, the students
<ex>declaim</ex> twice a week</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To speak for rhetorical display; to speak pompously,
noisily, or theatrically; to make an empty speech; to rehearse trite
arguments in debate; to rant.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Grenville seized the opportunity to <qex>declaim</qex> on the
repeal of the stamp act.</q> <rj><qau>Bancroft.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 377 --></p>

<p><ent>Declaim</ent><br/
<hw>De*claim"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <sn>1.</sn> <def>To
utter in public; to deliver in a rhetorical or set manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To defend by declamation; to advocate loudly.</def>
<mark>[Obs.]</mark> <ldquo/<xex>Declaims</xex> his cause.<rdquo/
<rj><au>South.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Declaimant</ent><br/
<hw>De*claim"ant</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A
declaimer.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Declaimer</ent><br/
<hw>De*claim"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who declaims;
an haranguer.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Declamation</ent><br/
<hw>Dec`la*ma"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>declamatio</ets>, from <ets>declamare</ets>: cf. F.
<ets>d<eacute/clamation</ets>. See <er>Declaim</er>.]</ety> <sn>1.</sn>
<def>The act or art of declaiming; rhetorical delivery; haranguing; loud
speaking in public; especially, the public recitation of speeches as an
exercise in schools and colleges; <as>as, the practice
<ex>declamation</ex> by students</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The public listened with little emotion, but with much civility,
to five acts of monotonous <qex>declamation</qex>.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A set or harangue; declamatory discourse.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Pretentious rhetorical display, with more sound than
sense; <as>as, mere <ex>declamation</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Declamator</ent><br/
<hw>Dec"la*ma`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.]</ety>
<def>A declaimer.</def> <mark>[R.]</mark> <rj><au>Sir T.
Elyot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Declamatory</ent><br/
<hw>De*clam"a*to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>declamatorius</ets>: cf. F. <ets>d<eacute/clamatoire</ets>.]</ety>
<sn>1.</sn> <def>Pertaining to declamation; treated in the manner of a
rhetorician; <as>as, a <ex>declamatory</ex> theme</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Characterized by rhetorical display; pretentiously
rhetorical; without solid sense or argument; bombastic; noisy; <as>as, a
<ex>declamatory</ex> way or style</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Declarable</ent><br/
<hw>De*clar"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of being
declared.</def> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Declarant</ent><br/
<hw>De*clar"ant</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>d<eacute/clarant</ets>, p. pr. of
<ets>d<eacute/clarer</ets>.]</ety> <fld>(Law)</fld> <def>One who
declares.</def> <rj><au>Abbott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Declaration</ent><br/
<hw>Dec`la*ra"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>d<eacute/claration</ets>, fr. L. <ets>declaratio</ets>, fr.
<ets>declarare</ets>. See <er>Declare</er>.]</ety> <sn>1.</sn> <def>The
act of declaring, or publicly announcing; explicit asserting;
undisguised token of a ground or side taken on any subject;
proclamation; exposition; <as>as, the <ex>declaration</ex> of an
opinion; a <ex>declaration</ex> of war, etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is declared or proclaimed; announcement;
distinct statement; formal expression; avowal.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Declarations</qex> of mercy and love . . . in the Gospel.</q>
<rj><qau>Tillotson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The document or instrument containing such statement
or proclamation; <as>as, the <ex>Declaration</ex> of Independence (now
preserved in Washington)</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In 1776 the Americans laid before Europe that noble
<qex>Declaration</qex>, which ought to be hung up in the nursery of
every king, and blazoned on the porch of every royal palace.</q>
<rj><qau>Buckle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Law)</fld> <def>That part of the process or
pleadings in which the plaintiff sets forth in order and at large his
cause of complaint; the narration of the plaintiff's case containing the
count, or counts. See <er>Count</er>, <pos>n.</pos>, 3.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Declaration of Independence</b></col>. <fld>(Amer.
Hist.)</fld> <cd>See Declaration of Independence in the vocabulary. See
also under <er>Independence</er>.</cd> -- <col><b>Declaration of
rights</b></col>. <fld>(Eng. Hist)</fld> <cd>See <cref>Bill of
rights</cref>, under <er>Bill</er>.</cd> -- <col><b>Declaration of
trust</b></col> <fld>(Law)</fld>, <cd>a paper subscribed by a grantee of
property, acknowledging that he holds it in trust for the purposes and
upon the terms set forth.</cd> <rj><au>Abbott.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Declaration of Independence</ent><br/
<hw>Declaration of Independence</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Amer. Hist.)</fld> <def>The document promulgated, <datey>July 4,
1776</datey>, by the leaders of the thirteen British Colonies in America
that they have formed an independent country. See note below.</def><br/
[<source>PJC</source>]</p>

<p><note><b>The Declaration of Independence of The United States of
America</b><br/
<br/
When in the Course of human events, it becomes necessary for one people
to dissolve the political bands which have connected them with another,
and to assume, among the Powers of the earth, the separate and equal
station to which the Laws of Nature and of Nature's God entitle them, a
decent respect to the opinions of mankind requires that they should
declare the causes which impel them to the separation.<br/
<br/
We hold these truths to be self-evident, that all men are created equal,
that they are endowed by their Creator with certain unalienable Rights,
that among these are Life, Liberty, and the pursuit of Happiness. That
to secure these rights, Governments are instituted among Men, deriving
their just powers from the consent of the governed, That whenever any
Form of Government becomes destructive of these ends, it is the Right of
the People to alter or to abolish it, and to institute new Government,
laying its foundation on such principles and organizing its powers in
such form, as to them shall seem most likely to effect their Safety and
Happiness. Prudence, indeed, will dictate that Governments long
established should not be changed for light and transient causes; and
accordingly all experience hath shown, that mankind are more disposed to
suffer, while evils are sufferable, than to right themselves by
abolishing the forms to which they are accustomed. But when a long train
of abuses and usurpations, pursuing invariably the same Object evinces a
design to reduce them under absolute Despotism, it is their right, it is
their duty, to throw off such Government, and to provide new Guards for
their future security. -- Such has been the patient sufferance of these
Colonies; and such is now the necessity which constrains them to alter
their former Systems of Government.<br/
<br/
The history of the present King of Great Britain is a history of
repeated injuries and usurpations, all having in direct object the
establishment of an absolute Tyranny over these States. To prove this,
let Facts be submitted to a candid world.<br/
<br/
He has refused his Assent to Laws, the most wholesome and necessary for
the public good.<br/
<br/
He has forbidden his Governors to pass Laws of immediate and pressing
importance, unless suspended in their operation till his Assent should
be obtained; and when so suspended, he has utterly neglected to attend
to them.<br/
<br/
He has refused to pass other Laws for the accommodation of large
districts of people, unless those people would relinquish the right of
Representation in the Legislature, a right inestimable to them and
formidable to tyrants only.<br/
<br/
He has called together legislative bodies at places unusual,
uncomfortable, and distant from the depository of their Public Records,
for the sole purpose of fatiguing them into compliance with his
measures.<br/
<br/
He has dissolved Representative Houses repeatedly, for opposing with
manly firmness his invasions on the rights of the people.<br/
<br/
He has refused for a long time, after such dissolutions, to cause others
to be elected; whereby the Legislative Powers, incapable of
Annihilation, have returned to the People at large for their exercise;
the State remaining in the mean time exposed to all the dangers of
invasion from without, and convulsions within.<br/
<br/
He has endeavoured to prevent the population of these States; for that
purpose obstructing the Laws of Naturalization of Foreigners; refusing
to pass others to encourage their migration hither, and raising the
conditions of new Appropriations of Lands.<br/
<br/
He has obstructed the Administration of Justice, by refusing his Assent
to Laws for establishing Judiciary Powers.<br/
<br/
He has made judges dependent on his Will alone, for the tenure of their
offices, and the amount and payment of their salaries.<br/
<br/
He has erected a multitude of New Offices, and sent hither swarms of
Officers to harass our People, and eat out their substance.<br/
<br/
He has kept among us, in times of peace, Standing Armies without the
Consent of our legislatures.<br/
<br/
He has affected to render the Military independent of and superior to
the Civil Power.<br/
<br/
He has combined with others to subject us to a jurisdiction foreign to
our constitution, and unacknowledged by our laws; giving his Assent to
their Acts of pretended legislation:<br/
<br/
For quartering large bodies of armed troops among us:<br/
<br/
For protecting them, by a mock Trial, from Punishment for any Murders
which they should commit on the Inhabitants of these States:<br/
<br/
For cutting off our Trade with all parts of the world:<br/
<br/
For imposing taxes on us without our Consent:<br/
<br/
For depriving us, in many cases, of the benefits of Trial by Jury:<br/
<br/
For transporting us beyond Seas to be tried for pretended offences:<br/
<br/
For abolishing the free System of English Laws in a neighbouring
Province, establishing therein an Arbitrary government, and enlarging
its Boundaries so as to render it at once an example and fit instrument
for introducing the same absolute rule into these Colonies:<br/
<br/
For taking away our Charters, abolishing our most valuable Laws, and
altering fundamentally the Forms of our Governments:<br/
<br/
For suspending our own Legislatures, and declaring themselves invested
with Power to legislate for us in all cases whatsoever.<br/
<br/
He has abdicated Government here, by declaring us out of his Protection
and waging War against us.<br/
<br/
He has plundered our seas, ravaged our Coasts, burnt our towns, and
destroyed the lives of our people.<br/
<br/
He is at this time transporting large armies of foreign mercenaries to
compleat the works of death, desolation and tyranny, already begun with
circumstances of Cruelty & perfidy scarcely paralleled in the most
barbarous ages, and totally unworthy of the Head of a civilized
nation.<br/
<br/
He has constrained our fellow Citizens taken Captive on the high Seas to
bear Arms against their Country, to become the executioners of their
friends and Brethren, or to fall themselves by their Hands.<br/
<br/
He has excited domestic insurrections amongst us, and has endeavoured to
bring on the inhabitants of our frontiers, the merciless Indian Savages,
whose known rule of warfare, is an undistinguished destruction of all
ages, sexes and conditions.<br/
<br/
In every stage of these Oppressions We have Petitioned for Redress in
the most humble terms: Our repeated Petitions have been answered only by
repeated injury. A Prince, whose character is thus marked by every act
which may define a Tyrant, is unfit to be the ruler of a free
People.<br/
<br/
Nor have We been wanting in attention to our British brethren. We have
warned them from time to time of attempts by their legislature to extend
an unwarrantable jurisdiction over us. We have reminded them of the
circumstances of our emigration and settlement here. We have appealed to
their native justice and magnanimity, and we have conjured them by the
ties of our common kindred to disavow these usurpations, which would
inevitably interrupt our connections and correspondence. They too have
been deaf to the voice of justice and of consanguinity. We must,
therefore, acquiesce in the necessity, which denounces our Separation,
and hold them, as we hold the rest of mankind, Enemies in War, in Peace
Friends.<br/
<br/
We, therefore, the Representatives of the United States of America, in
General Congress, Assembled, appealing to the Supreme Judge of the world
for the rectitude of our intentions, do, in the Name, and by the
Authority of the good People of these Colonies, solemnly publish and
declare, That these United Colonies are, and of Right ought to be Free
and Independent States; that they are Absolved from all Allegiance to
the British Crown, and that all political connection between them and
the State of Great Britain, is and ought to be totally dissolved; and
that as Free and Independent States, they have full Power to levy War,
conclude Peace, contract Alliances, establish Commerce, and to do all
other Acts and Things which Independent States may of right do. And for
the support of this Declaration, with a firm reliance on the Protection
of Divine Providence, we mutually pledge to each other our Lives, our
Fortunes and our sacred Honor.</note></p>

<p><ent>Declarative</ent><br/
<hw>De*clar"a*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>declarativus</ets>, fr. <ets>declarare</ets>: cf. F.
<ets>d<eacute/claratif</ets>.]</ety> <def>Making declaration,
proclamation, or publication; explanatory; assertive; declaratory.</def>
<ldquo/<xex>Declarative</xex> laws.<rdquo/ <rj><au>Baker.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <ldquo/vox populi,<rdquo/ so <qex>declarative</qex> on the
same side.</q> <rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Declaratively</ent><br/
<hw>De*clar"a*tive*ly</hw>, <pos>adv.</pos> <def>By distinct assertion;
not impliedly; in the form of a declaration.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The priest shall expiate it, that is,
<qex>declaratively</qex>.</q> <rj><qau>Bates.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Declarator</ent><br/
<hw>Dec"la*ra`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., an
announcer.]</ety> <fld>(Scots Law)</fld> <def>A form of action by which
some right or interest is sought to be judicially declared.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Declaratorily</ent><br/
<hw>De*clar"a*to*ri*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a
declaratory manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Declaratory</ent><br/
<hw>De*clar"a*to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>d<eacute/claratoire</ets>.]</ety> <def>Making declaration,
explanation, or exhibition; making clear or manifest; affirmative;
expressive; <as>as, a clause <ex>declaratory</ex> of the will of the
legislature</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Declaratory act</b></col> <fld>(Law)</fld>, <cd>an act or
statute which sets forth more clearly, and declares what is, the
existing law.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Declare</ent><br/
<hw>De*clare"</hw> <pr>(d<esl/*kl<acir/r")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Declared</conjf>
<pr>(d<esl/*kl<acir/rd")</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Declaring</conjf>.]</vmorph> <ety>[F. <ets>d<eacute/clarer</ets>,
from L. <ets>declarare</ets>; <ets>de</ets> + <ets>clarare</ets> to make
clear, <ets>clarus</ets>, clear, bright. See <er>Clear</er>.]</ety>
<sn>1.</sn> <def>To make clear; to free from obscurity.</def>
<mark>[Obs.]</mark> <ldquo/To <xex>declare</xex> this a little.<rdquo/
<rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To make known by language; to communicate or
manifest explicitly and plainly in any way; to exhibit; to publish; to
proclaim; to announce.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This day I have begot whom I <qex>declare</qex><br/
My only Son.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The heavens <qex>declare</qex> the glory of God.</q> <rj><qau>Ps.
xix. 1.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To make declaration of; to assert; to affirm; to set
forth; to avow; <as>as, he <ex>declares</ex> the story to be
false</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I the Lord . . . <qex>declare</qex> things that are right.</q>
<rj><qau>Isa. xlv. 19.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Com.)</fld> <def>To make full statement of, as
goods, etc., for the purpose of paying taxes, duties, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To declare off</b></col>, <cd>to recede from an
agreement, undertaking, contract, etc.; to renounce.</cd> -- <col><b>To
declare one's self</b></col>, <cd>to avow one's opinion; to show openly
what one thinks, or which side he espouses.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Declare</ent><br/
<hw>De*clare"</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To make a
declaration, or an open and explicit avowal; to proclaim one's self; --
often with <xex>for</xex> or <xex>against</xex>; <as>as, victory
<ex>declares</ex> against the allies</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Like fawning courtiers, for success they wait,<br/
And then come smiling, and <qex>declare</qex> for fate.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>To state the plaintiff's cause of
action at law in a legal form; <as>as, the plaintiff <ex>declares</ex>
in trespass</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>declared</ent><br/
<hw>declared</hw> <pos>adj.</pos> <sn>1.</sn> <def>made known or openly
avowed; <as>as, their <ex>declared</ex> and their covert objectives; a
<ex>declared</ex> liberal</as>. Opposite of <ant>undeclared</ant>.</def>
[Narrower terms: <stype>avowed(prenominal),
professed(prenominal)</stype>]<br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>stated as fact; explicitly stated.</def><br/
<syn><b>Syn. --</b> stated.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Declaredly</ent><br/
<hw>De*clar"ed*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>Avowedly;
explicitly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Declaredness</ent><br/
<hw>De*clar"ed*ness</hw>, <pos>n.</pos> <def>The state of being
declared.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Declarement</ent><br/
<hw>De*clare"ment</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Declaration.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Declarer</ent><br/
<hw>De*clar"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who makes known
or proclaims; that which exhibits.</def> <rj><au>Udall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Declass</ent><br/
<hw>De*class"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Declassed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Declassing</conjf>.]</vmorph> <ety>[Cf. F.
<ets>d<eacute/classer</ets>.]</ety> <def>To remove from a class; to
separate or degrade from one's class.</def> <rj><au>North Am.
Rev.</au></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>declasse</ent><br/
\'d8<hw>d<eacute/class<eacute/</hw> <pr>(d<asl/`kl<acr/`s<amac/",
d<asl/`kl<aum/`s<amac/")</pr> <pos>adj.</pos> <ety>[F. Cf. F.
<ets>d<eacute/classer</ets>.]</ety> <sn>1.</sn> <def>Reduced or fallen
in status, social position, class or rank; fallen from a high status or
rank to a lower one.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>Of inferior grade, rank, status, or
prestige.</def><br/
[<source>PJC</source>]</p>

<p><ent>declassification</ent><br/
<hw>declassification</hw> <pos>n.</pos> <def>Reduction by the government
of restrictions on a classified document or weapon.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>declassified</ent><br/
<hw>declassified</hw> <pos>adj.</pos> <def>having a security
classification removed so as to be open to public inspection; -- of
documents or information.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>declassify</ent><br/
<hw>declassify</hw> <pos>v.</pos> <def>to lift the restriction on
publication [of documents] by reducing or eliminating the secrecy
classification of; -- usually applied to government documents classified
as secret.</def><br/
<syn><b>Syn. --</b> make available again.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>declaw</ent><br/
<hw>declaw</hw> <pos>v. t.</pos> <def>to remove the claws from, -- used
especially with a cat as an object.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Declension</ent><br/
<hw>De*clen"sion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Apparently
corrupted fr. F. <ets>d<eacute/clinaison</ets>, fr. L.
<ets>declinatio</ets>, fr. <ets>declinare</ets>. See <er>Decline</er>,
and cf. <er>Declination</er>.]</ety> <sn>1.</sn> <def>The act or the
state of declining; declination; descent; slope.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>declension</qex> of the land from that place to the
sea.</q> <rj><qau>T. Burnet.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A falling off towards a worse state; a downward
tendency; deterioration; decay; <as>as, the <ex>declension</ex> of
virtue, of science, of a state, etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Seduced the pitch and height of all his thoughts<br/
To base <qex>declension</qex>.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Act of courteously refusing; act of declining; a
declinature; refusal; <as>as, the <ex>declension</ex> of a
nomination</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Gram.)</fld> <sd>(a)</sd> <def>Inflection of nouns,
adjectives, etc., according to the grammatical cases.</def> <sd>(b)</sd>
<def>The form of the inflection of a word declined by cases; <as>as, the
first or the second <ex>declension</ex> of nouns, adjectives,
etc.</as></def> <sd>(c)</sd> <def>Rehearsing a word as
declined.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The nominative was held to be the primary and original
form, and was likened to a perpendicular line; the variations, or
<xex>oblique</xex> cases, were regarded as fallings (hence called
<xex>casus</xex>, cases, or fallings) from the nominative or
perpendicular; and an enumerating of the various forms, being a sort of
progressive descent from the noun's upright form, was called a
<xex>declension</xex>.</note> <rj><au>Harris.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Declension of the needle</b></col>, <cd>declination of
the needle.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Declensional</ent><br/
<hw>De*clen"sion*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Belonging to
declension.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Declensional</qex> and syntactical forms.</q> <rj><qau>M.
Arnold.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Declinable</ent><br/
<hw>De*clin"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>d<eacute/clinable</ets>. See <er>Decline</er>.]</ety> <def>Capable
of being declined; admitting of declension or inflection; <as>as,
<ex>declinable</ex> parts of speech</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Declinal</ent><br/
<hw>De*clin"al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Declining;
sloping.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Declinate</ent><br/
<hw>Dec"li*nate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>declinatus</ets>, p. p. of <ets>declinare</ets>. See
<er>Decline</er>.]</ety> <def>Bent downward or aside; <fld>(Bot.)</fld>
bending downward in a curve; declined.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Declination</ent><br/
<hw>Dec`li*na"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>declinatio</ets> a bending aside, an avoiding: cf. F.
<ets>d<eacute/clination</ets> a decadence. See
<er>Declension</er>.]</ety> <sn>1.</sn> <def>The act or state of bending
downward; inclination; <as>as, <ex>declination</ex> of the
head</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The act or state of falling off or declining from
excellence or perfection; deterioration; decay; decline.</def>
<ldquo/The <xex>declination</xex> of monarchy.<rdquo/
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Summer . . . is not looked on as a time<br/
Of <qex>declination</qex> or decay.</q> <rj><qau>Waller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The act of deviating or turning aside; oblique
motion; obliquity; withdrawal.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>declination</qex> of atoms in their descent.</q>
<rj><qau>Bentley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Every <qex>declination</qex> and violation of the rules.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The act or state of declining or refusing;
withdrawal; refusal; averseness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The queen's <qex>declination</qex> from marriage.</q>
<rj><qau>Stow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Astron.)</fld> <def>The angular distance of any
object from the celestial equator, either northward or
southward.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Dialing)</fld> <def>The arc of the horizon,
contained between the vertical plane and the prime vertical circle, if
reckoned from the east or west, or between the meridian and the plane,
reckoned from the north or south.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Gram.)</fld> <def>The act of inflecting a word;
declension. See <er>Decline</er>, <pos>v. t.</pos>, 4.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Angle of declination</b></col>, <cd>the angle made by a
descending line, or plane, with a horizontal plane.</cd> --
<col><b>Circle of declination</b></col>, <cd>a circle parallel to the
celestial equator.</cd> -- <col><b>Declination compass</b></col>
<fld>(Physics)</fld>, <cd>a compass arranged for finding the declination
of the magnetic needle.</cd> -- <mcol><col><b>Declination of the
compass</b></col> <it>or</it> <col><b>Declination of the
needle</b></col></mcol>, <cd>the horizontal angle which the magnetic
needle makes with the true north-and-south line.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Declinator</ent><br/
<hw>Dec"li*na`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>d<eacute/clinateur</ets>. See <er>Decline</er>.]</ety> <sn>1.</sn>
<def>An instrument for taking the declination or angle which a plane
makes with the horizontal plane.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A dissentient.</def> <mark>[R.]</mark> <rj><au>Bp.
Hacket.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Declinatory</ent><br/
<hw>De*clin"a*to*ry</hw> <pr>(?; 277)</pr>, <pos>a.</pos> <ety>[LL.
<ets>declinatorius</ets>, fr. L. <ets>declinare</ets>: cf. F.
<ets>d<eacute/clinatoire</ets>.]</ety> <def>Containing or involving a
declination or refusal, as of submission to a charge or sentence.</def>
<rj><au>Blackstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Declinatory plea</b></col> <fld>(O. Eng. Law)</fld>,
<cd>the plea of sanctuary or of benefit of clergy, before trial or
conviction; -- now abolished.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Declinature</ent><br/
<hw>De*clin"a*ture</hw> <pr>(?; 135)</pr>, <pos>n.</pos> <def>The act of
declining or refusing; <as>as, the <ex>declinature</ex> of an
office</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decline</ent><br/
<hw>De*cline"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Declined</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Declining</conjf>.]</vmorph> <ety>[OE.
<ets>declinen</ets> to bend down, lower, sink, decline (a noun), F.
<ets>d<eacute/cliner</ets> to decline, refuse, fr. L.
<ets>declinare</ets> to turn aside, inflect (a part of speech), avoid;
<ets>de-</ets> + <ets>clinare</ets> to incline; akin to E.
<ets>lean</ets>. See <er>Lean</er>, <pos>v. i.</pos>]</ety> <sn>1.</sn>
<def>To bend, or lean downward; to take a downward direction; to bend
over or hang down, as from weakness, weariness, despondency, etc.; to
condescend.</def> <ldquo/With <xex>declining</xex> head.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He . . . would <qex>decline</qex> even to the lowest of his
family.</q> <rj><qau>Lady Hutchinson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Disdaining to <qex>decline</qex>,<br/
Slowly he falls, amidst triumphant cries.</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The ground at length became broken and <qex>declined</qex>
rapidly.</q> <rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To tend or draw towards a close, decay, or
extinction; to tend to a less perfect state; to become diminished or
impaired; to fail; to sink; to diminish; to lessen; <as>as, the day
<ex>declines</ex>; virtue <ex>declines</ex>; religion <ex>declines</ex>;
business <ex>declines</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>That empire must <qex>decline</qex><br/
Whose chief support and sinews are of coin.</q>
<rj><qau>Waller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And presume to know . . . <br/
Who thrives, and who <qex>declines</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To turn or bend aside; to deviate; to stray; to
withdraw; <as>as, a line that <ex>declines</ex> from straightness;
conduct that <ex>declines</ex> from sound morals.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Yet do I not <qex>decline</qex> from thy testimonies.</q>
<rj><qau>Ps. cxix. 157.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To turn away; to shun; to refuse; -- the opposite of
<xex>accept</xex> or <xex>consent</xex>; <as>as, he <ex>declined</ex>,
upon principle</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decline</ent><br/
<hw>De*cline"</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To bend downward;
to bring down; to depress; to cause to bend, or fall.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In melancholy deep, with head <qex>declined</qex>.</q>
<rj><qau>Thomson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And now fair Phoebus gan <qex>decline</qex> in haste<br/
His weary wagon to the western vale.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To cause to decrease or diminish.</def>
<mark>[Obs.]</mark> <ldquo/You have <xex>declined</xex> his
means.<rdquo/ <rj><au>Beau. & Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He knoweth his error, but will not seek to <qex>decline</qex>
it.</q> <rj><qau>Burton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To put or turn aside; to turn off or away from; to
refuse to undertake or comply with; reject; to shun; to avoid; <as>as,
to <ex>decline</ex> an offer; to <ex>decline</ex> a contest; he
<ex>declined</ex> any participation with them.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Could I<br/
<qex>Decline</qex> this dreadful hour?</q>
<rj><qau>Massinger.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Gram.)</fld> <def>To inflect, or rehearse in order
the changes of grammatical form of; <as>as, to <ex>decline</ex> a noun
or an adjective</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Now restricted to such words as have case inflections;
but formerly it was applied both to declension and
conjugation.</note><br/
[<source>1913 Webster</source>]</p>

<p><q>After the first <qex>declining</qex> of a noun and a verb.</q>
<rj><qau>Ascham.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To run through from first to last; to repeat like a
schoolboy declining a noun.</def> <mark>[R.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decline</ent><br/
<hw>De*cline"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>d<eacute/clin</ets>. See <er>Decline</er>, <pos>v. i.</pos>]</ety>
<sn>1.</sn> <def>A falling off; a tendency to a worse state; diminution
or decay; deterioration; also, the period when a thing is tending toward
extinction or a less perfect state; <as>as, the <ex>decline</ex> of
life; the <ex>decline</ex> of strength; the <ex>decline</ex> of virtue
and religion.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Their fathers lived in the <qex>decline</qex> of literature.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Med.)</fld> <def>That period of a disorder or
paroxysm when the symptoms begin to abate in violence; <as>as, the
<ex>decline</ex> of a fever</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A gradual sinking and wasting away of the physical
faculties; any wasting disease, esp. pulmonary consumption; <as>as, to
die of a <ex>decline</ex></as>.</def> <rj><au>Dunglison.</au></rj></p>

<p><syn><b>Syn.</b> -- <er>Decline</er>, <er>Decay</er>,
<er>Consumption</er>.</syn> <usage> <xex>Decline</xex> marks the first
stage in a downward progress; <xex>decay</xex> indicates the second
stage, and denotes a tendency to ultimate destruction;
<xex>consumption</xex> marks a steady decay from an internal exhaustion
of strength. The health may experience a <xex>decline</xex> from various
causes at any period of life; it is naturally subject to
<xex>decay</xex> with the advance of old age; <xex>consumption</xex> may
take place at almost any period of life, from disease which wears out
the constitution. In popular language <xex>decline</xex> is often used
as synonymous with <xex>consumption</xex>. By a gradual
<xex>decline</xex>, states and communities lose their strength and
vigor; by progressive <xex>decay</xex>, they are stripped of their
honor, stability, and greatness; by a <xex>consumption</xex> of their
resources and vital energy, they are led rapidly on to a completion of
their existence.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Declined</ent><br/
<hw>De*clined"</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Declinate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decliner</ent><br/
<hw>De*clin"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>He who declines or
rejects.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A studious <qex>decliner</qex> of honors.</q>
<rj><qau>Evelyn.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>declining</ent><br/
<hw>declining</hw> <pos>adj.</pos> <sn>1.</sn> <def>decreasing; <as>as,
steadily <ex>declining</ex> incomes</as>.</def><br/
<syn><b>Syn. --</b> down(prenominal).</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>going from better to worse.</def><br/
<syn><b>Syn. --</b> deteriorating, failing, regressing, retrograde,
retrogressive.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>3.</sn> <def>becoming less or smaller; <as>as, <ex>declining</ex>
powers of body and mind</as>. Opposite of
<ant>increasing</ant>.</def><br/
<syn><b>Syn. --</b> eroding.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>4.</sn> <def>drawing to an end; waning; <as>as, his
<ex>declining</ex> years</as>.</def> <mark>[prenominal]</mark><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Declinometer</ent><br/
<hw>Dec`li*nom"e*ter</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Decline</ets> + <ets>-meter</ets>.]</ety>
<fld>(Physics)</fld> <def>An instrument for measuring the declination of
the magnetic needle.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Declinous</ent><br/
<hw>De*clin"ous</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Declinate.</def></p>

<p><ent>Declivous</ent><br/
<ent>Declivitous</ent><br/
<mhw>{ <hw>De*cliv"i*tous</hw> <pr>(?)</pr>, <hw>De*cli"vous</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <def>Descending gradually;
moderately steep; sloping; downhill.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Declivity</ent><br/
<hw>De*cliv"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Declivities</plw> <pr>(#)</pr>.</plu> <ety>[L.
<ets>declivitas</ets>, fr. <ets>declivis</ets> sloping, downhill;
<ets>de</ets> + <ets>clivus</ets> a slope, a hill; akin to
<ets>clinare</ets> to incline: cf. F.
<ets>d<eacute/clivit<eacute/</ets>. See <er>Decline</er>.]</ety>
<sn>1.</sn> <def>Deviation from a horizontal line; gradual descent of
surface; inclination downward; slope; -- opposed to
<xex>acclivity</xex>, or ascent; the same slope, considered as
<xex>descending</xex>, being a <xex>declivity</xex>, which, considered
as <xex>ascending</xex>, is an <xex>acclivity</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A descending surface; a sloping place.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Commodious <qex>declivities</qex> and channels for the passage of
the waters.</q> <rj><qau>Derham.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>declutch</ent><br/
<hw>declutch</hw> <pos>v. i. & t.</pos> <def>to disengage the clutch of
a car.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Decoct</ent><br/
<hw>De*coct"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Decocted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Decocting</conjf>.]</vmorph> <ety>[L. <ets>decoctus</ets>, p. p.
of <ets>decoquere</ets> to boil down; <ets>de-</ets> +
<ets>coquere</ets> to cook, boil. See <er>Cook</er> to decoct.]</ety>
<sn>1.</sn> <def>To prepare by boiling; to digest in hot or boiling
water; to extract the strength or flavor of by boiling; to make an
infusion of.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To prepare by the heat of the stomach for
assimilation; to digest; to concoct.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To warm, strengthen, or invigorate, as if by
boiling.</def> <mark>[R.]</mark> <ldquo/<xex>Decoct</xex> their cold
blood.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decoctible</ent><br/
<hw>De*coct"i*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of being
boiled or digested.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decoction</ent><br/
<hw>De*coc"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>d<eacute/coction</ets>, L. <ets>decoctio</ets>.]</ety> <sn>1.</sn>
<def>The act or process of boiling anything in a watery fluid to extract
its virtues.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In <qex>decoction</qex> . . . it either purgeth at the top or
settleth at the bottom.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An extract got from a body by boiling it in
water.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If the plant be boiled in water, the strained liquor is called the
<qex>decoction</qex> of the plant.</q>
<rj><qau>Arbuthnot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>In pharmacy <qex>decoction</qex> is opposed to infusion, where
there is merely steeping.</q> <rj><qau>Latham.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decocture</ent><br/
<hw>De*coc"ture</hw> <pr>(?; 135)</pr>, <pos>n.</pos> <def>A
decoction.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>decode</ent><br/
<hw>decode</hw> <pos>v. t.</pos> <def>to convert from a coded form into
the original form; -- of communications. Inverse of
<inv>encode</inv>.</def><br/
<syn><b>Syn. --</b> decrypt, decipher[WE1].</syn><br/
[<source>PJC</source>]</p>

<p><ent>Decoherer</ent><br/
<hw>De`co*her"er</hw> <pr>(d<emac/`k<osl/*h<emac/r"<etil/r)</pr>,
<pos>n.</pos> <ety>[Pref. <ets>de-</ets> + <ets>coherer</ets>.]</ety>
<fld>(Elec.)</fld> <def>A device for restoring a coherer to its normal
condition after it has been affected by an electric wave, a process
usually accomplished by some method of tapping or shaking, or by
rotation of the coherer.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>decollate</ent><br/
<hw>de*col"late</hw> <pr>(d<esl/*k<ocr/l"l<amac/t)</pr>, <pos>v.
t.</pos> <vmorph>[<pos>imp. & p. p.</pos> <conjf>Decollated</conjf>;
<pos>p. pr. & vb. n.</pos> <conjf>Decollating</conjf>.]</vmorph>
<ety>[L. <ets>decollatus</ets>, p. p. of <ets>decollare</ets> to behead;
<ets>de-</ets> + <ets>collum</ets> neck.]</ety> <def>To sever from the
neck; to behead; to decapitate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>decollated</qex> head of St. John the Baptist.</q>
<rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decollated</ent><br/
<hw>De*col"la*ted</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Decapitated; worn or cast off in the process of growth, as the apex
of certain univalve shells.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decollation</ent><br/
<hw>De`col*la"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>decollatio</ets>: cf. F. <ets>d<eacute/collation</ets>.]</ety>
<sn>1.</sn> <def>The act of beheading or state of one beheaded; --
especially used of the execution of St. John the Baptist.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A painting representing the beheading of a saint or
martyr, esp. of St. John the Baptist.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decolletage</ent><br/
\'d8<hw>D<eacute/`col`le*tage"</hw>
<pr>(d<amac/`k<osl/`l'*t<adot/zh)</pr>, <pos>n.</pos> <ety>[F. See
<er>D<eacute/collet<eacute/</er>.]</ety> <fld>(Costume)</fld>
<sn>1.</sn> <def>The upper border or part of a low-cut (i.e.,
d<eacute/collet<eacute/) dress.</def><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>The exposed upper parts of the breasts of a woman
wearing a low-cut dress; <as>as, transfixed by her stunning
<ex>decolletage</ex></as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Decollete</ent><br/
\'d8<hw>D<eacute/`col`le*t<eacute/"</hw>
<pr>(d<asl/`k<ocr/l`l<eit/*t<asl/")</pr>, <pos>a.</pos> <ety>[F., p. p.
of <ets>d<eacute/colleter</ets> to bare the neck and shoulders;
<ets>d<eacute/-</ets> + <ets>collet</ets> collar, fr. L.
<ets>collum</ets> neck.]</ety> <sn>1.</sn> <def>Leaving the neck and
shoulders uncovered; cut low in the neck, or low-necked, as a
dress.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Wearing a d<eacute/collet<eacute/ gown.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Decolling</ent><br/
<hw>De*col"ling</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Beheading.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>By a speedy dethroning and <qex>decolling</qex> of the king.</q>
<rj><qau>Parliamentary History (1648).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>decolonisation</ent><br/
<hw>decolonisation</hw> <pos>n.</pos> <def>same as
<er>decolonization</er>.</def> <mark>[mostly British]</mark><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>decolonization</ent><br/
<hw>decolonization</hw> <pos>n.</pos> <sn>1.</sn> <def>the action of
changing from colonial to independent status.</def><br/
<syn><b>Syn. --</b> decolonisation.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>decolonize</ent><br/
<hw>decolonize</hw> <pos>v. t.</pos> <def>to grant independence to (a
former colony).</def> <altsp>[Also spelled
<asp>decolonise</asp>.]</altsp><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>decolonize</ent><br/
<hw>decolonize</hw> <pos>v. i.</pos> <def>to release one's colonies and
free them to become independent nations; -- of nations.</def>
<altsp>[Also spelled <asp>decolonise</asp>.]</altsp><br/
[<source>PJC</source>]</p>

<p><ent>Decolor</ent><br/
<hw>De*col"or</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Cf. F.
<ets>d<eacute/colorer</ets>, L. <ets>decolorare</ets>. Cf.
<er>Discolor</er>.]</ety> <def>To deprive of color; to bleach.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decolorant</ent><br/
<hw>De*col"or*ant</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>d<eacute/colorant</ets>, p. pr.]</ety> <def>A substance which
removes color, or bleaches.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decolorate</ent><br/
<hw>De*col"or*ate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>decoloratus</ets>, p. p. of <ets>decolorare</ets>.]</ety>
<def>Deprived of color.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decolorate</ent><br/
<hw>De*col"or*ate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To
decolor.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 378 --></p>

<p><ent>Decoloration</ent><br/
<hw>De*col`or*a"tion</hw>
<pr>(d<esl/*k<ucr/l`<etil/r*<amac/"sh<ucr/n)</pr>, <pos>n.</pos>
<ety>[L. <ets>decoloratio</ets>: cf. F.
<ets>d<eacute/coloration</ets>.]</ety> <def>The removal or absence of
color.</def> <rj><au>Ferrand.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decolorize</ent><br/
<hw>De*col"or*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To deprive of
color; to whiten.</def> <au>Turner.</au> --
<wordforms><wf>De*col`or*i*za"tion</wf> <pr>(#)</pr>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decomplex</ent><br/
<hw>De"com*plex`</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>de-</ets> (intens.) + <ets>complex</ets>.]</ety> <def>Repeatedly
compound; made up of complex constituents.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decomposable</ent><br/
<hw>De`com*pos"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of
being resolved into constituent elements.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decompose</ent><br/
<hw>De`com*pose"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Decomposed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Decomposing</conjf>.]</vmorph> <ety>[Cf. F.
<ets>d<eacute/composer</ets>. Cf. <er>Discompose</er>.]</ety> <def>To
separate the constituent parts of; to resolve into original elements; to
set free from previously existing forms of chemical combination; to
bring to dissolution; to rot or decay.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decompose</ent><br/
<hw>De`com*pose"</hw>, <pos>v. i.</pos> <def>To become resolved or
returned from existing combinations; to undergo dissolution; to decay;
to rot.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decomposed</ent><br/
<hw>De`com*posed"</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Separated or broken up; -- said of the crest of birds when the
feathers are divergent.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decomposite</ent><br/
<hw>De`com*pos"ite</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>de-</ets> (intens.) + <ets>composite</ets>.]</ety> <sn>1.</sn>
<def>Compounded more than once; compounded with things already
composite.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>See <er>Decompound</er>,
<pos>a.</pos>, 2.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decomposite</ent><br/
<hw>De`com*pos"ite</hw>, <pos>n.</pos> <def>Anything
decompounded.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Decomposites</qex> of three metals or more.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decomposition</ent><br/
<hw>De*com`po*si"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>de-</ets> (in sense 3 intensive) + <ets>composition</ets>: cf. F.
<ets>d<eacute/composition</ets>. Cf. <er>Decomposition</er>.]</ety>
<sn>1.</sn> <def>The act or process of resolving the constituent parts
of a compound body or substance into its elementary parts; separation
into constituent part; analysis; the decay or dissolution consequent on
the removal or alteration of some of the ingredients of a compound;
disintegration; <as>as, the <ex>decomposition</ex> of wood, rocks,
etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The state of being reduced into original
elements.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Repeated composition; a combination of
compounds.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Decomposition of forces</b></col>. <cd>Same as
<cref>Resolution of forces</cref>, under <er>Resolution</er>.</cd> --
<col><b>Decomposition of light</b></col>, <cd>the division of light into
the prismatic colors.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>decompositional</ent><br/
<hw>decompositional</hw> <pos>adj.</pos> <def>causing organic
decay.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Decompound</ent><br/
<hw>De`com*pound"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Decompounded</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Decompounding</conjf>.]</vmorph> <ety>[Pref. <ets>de-</ets>
(intens. in sense 1) + <ets>compound</ets>, v. t.]</ety> <sn>1.</sn>
<def>To compound or mix with that is already compound; to compound a
second time.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To reduce to constituent parts; to
decompose.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It divides and <qex>decompounds</qex> objects into . . .
parts.</q> <rj><qau>Hazlitt.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decompound</ent><br/
<hw>De`com*pound"</hw>, <pos>a.</pos> <ety>[Pref. <ets>de-</ets>
(intens.) + <ets>compound</ets>, <ets>a.</ets>]</ety> <sn>1.</sn>
<def>Compound of what is already compounded; compounded a second
time.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>Several times compounded or
divided, as a leaf or stem; decomposite.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decompound</ent><br/
<hw>De`com*pound"</hw>, <pos>n.</pos> <def>A decomposite.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decompoundable</ent><br/
<hw>De`com*pound"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of
being decompounded.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>decompress</ent><br/
<hw>decompress</hw> <pos>v. i.</pos> <def>to undergo the process of
<er>decompression</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>decompress</ent><br/
<hw>decompress</hw> <pos>v. t.</pos> <def>to subject to the process of
<er>decompression</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>decompressing</ent><br/
<hw>decompressing</hw> <pos>n.</pos> <sn>1.</sn> <def>the process of
experiencing <er>decompression</er>; the act or process of relieving or
reducing pressure.</def><br/
<syn><b>Syn. --</b> decompression.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>decompression</ent><br/
<hw>decompression</hw> <pos>n.</pos> <sn>1.</sn> <def>the process of
experiencing <er>decompression</er>; the act or process of relieving or
reducing pressure.</def><br/
<syn><b>Syn. --</b> decompressing.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>the reduction of atmospheric pressure experienced by
divers rising from deep water to the surface, thus reducing the
concentration of dissolved atmospheric gases in the blood; -- especially
applied to a gradual reduction of such pressure.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>the process, analogous to sense 2, undergone by
divers in a decompression chamber, in which an artificially high
atmospheric pressure is gradually lowered to normal pressure.</def><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <def>a return to a normal, more relaxed state after a
period of intense stress, psychological pressure, or urgent activity; --
of people.</def><br/
[<source>PJC</source>]</p>

<p><sn>5.</sn> <fld>(Computers)</fld> <def>the process of converting
digitally encoded data from a more compact (compressed) form to its
original, larger size.</def> <note>The process of compression and
decompression may completely recover all of the original data (called
<ecol><b>lossless compression</b></ecol>), or may lose some of the
original data in order to achieve higher degress of compression
(<ecol><b>lossy compression</b></ecol>). The latter is used especially
with images or video data, which may be of very large size relative to
text, and for which small changes may be imperceptible to the human eye.
The <er>JPEG</er> data compression format is a lossy format.</note><br/
[<source>PJC</source>]</p>

<p><ent>Deconcentrate</ent><br/
<hw>De`con*cen"trate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To
withdraw from concentration; to decentralize.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deconcentration</ent><br/
<hw>De*con`cen*tra"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Act of
deconcentrating.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deconcoct</ent><br/
<hw>De`con*coct"</hw> <pr>(d<emac/`k<ocr/n*k<ocr/kt")</pr>, <pos>v.
t.</pos> <def>To decompose.</def> <mark>[R.]</mark>
<rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deconsecrate</ent><br/
<hw>De*con"se*crate</hw> <pr>(d<esl/*k<ocr/n"s<esl/*kr<amac/t)</pr>,
<pos>v. t.</pos> <def>To deprive of sacredness; to secularize.</def> --
<wordforms><wf>De*con`se*cra"tion</wf> <pr>(#)</pr>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>deconstruct</ent><br/
<hw>de`con*struct"</hw> <pr>(d<esl/`k<ucr/n*str<ucr/kt")</pr>, <pos>v.
t.</pos> <def>To interpret (a text or an artwork) by the method of
deconstruction.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>deconstruction</ent><br/
<hw>de`con*struc"tion</hw> <pr>(d<esl/`k<ucr/n*str<ucr/k"sh<ucr/n)</pr>,
<pos>n.</pos> <def>A philosophical theory of criticism (usually of
literature or film) that seeks to expose deep-seated contradictions in a
work by delving below its surface meaning. This method questions the
ability of language to represent a fixed reality, and proposes that a
text has no stable meaning because words only refer to other words, that
metaphysical or ethnocentric assumptions about the meaning of words must
be questioned, and words may be redefined in new contexts and new,
equally valid and even contradictory meanings may be found. Such new
interpretations may be based on the philosophical, political, or social
implications of the words of a text, rather than solely on attempts to
determine the author's intentions.</def> <au>RHUD</au> <au>MW10</au><br/
<syn><b>Syn. --</b> deconstructionism.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>the process of criticising or interpreting a text by
the method of <er>deconstruction{1}</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>deconstructionism</ent><br/
<hw>de`con*struc"tion*ism</hw>
<pr>(d<esl/`k<ucr/n*str<ucr/k"sh<ucr/n*<icr/z'm)</pr>, <pos>n.</pos>
<def>Same as <er>decontruction{1}</er>.</def><br/
<syn><b>Syn. --</b> deconstruction.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>deconstructionist</ent><br/
<hw>de`con*struc"tion*ist</hw>
<pr>(d<esl/`k<ucr/n*str<ucr/k"sh<ucr/n*<icr/st)</pr>, <pos>adj.</pos>
<def>Of or pertaining to deconstruction or deconstructionism; <as>as,
<ex>deconstructionist</ex> criticism</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>decontaminate</ent><br/
<hw>de`con*tam"i*nate</hw>
<pr>(d<esl/`k<ucr/n*t<acr/m"<icr/*n<amac/t)</pr>, <pos>v. t.</pos>
<def>To remove contamination or contaminants from, by a cleansing
process; -- usually used of radioactive, infectious, or toxic materials;
<as>as, to <ex>decontaminate</ex> clothing worn by persons with
infective disease; <ex>decontaminate</ex> an area of PCB's after
explosion of a transformer</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>decontamination</ent><br/
<hw>decontamination</hw> <pos>n.</pos> <def>The removal of contaminants;
<as>as, the <ex>decontamination</ex> of a room after a spill of
radioactive materials</as>.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>decor</ent><br/
<ent>decor</ent><br/
<mhw><hw>decor</hw>, <hw>d<eacute/cor</hw></mhw> <pos>n.</pos> <ety>[Fr.
<ets>d<eacute/cor</ets>, fr. <ets>d<eacute/corer</ets> to decorate, fr.
L <ets>decorare</ets>. See <er>decorate</er>.]</ety> <sn>1.</sn>
<def>the layout, style, and furnishings of a livable interior.</def><br/
<syn><b>Syn. --</b> interior decoration.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>Decoration{2}.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <fld>(Theater)</fld> <def>A stage setting.</def>
<au>MW10</au><br/
[<source>PJC</source>]</p>

<p><ent>Decorament</ent><br/
<hw>Dec"o*ra*ment</hw> <pr>(d<ecr/k"<osl/*r<adot/*m<eit/nt)</pr>,
<pos>n.</pos> <ety>[L. <ets>decoramentum</ets>. See <er>Decorate</er>,
<pos>v. t.</pos>]</ety> <def>Ornament.</def> <mark>[Obs.]</mark>
<rj><au>Bailey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decorate</ent><br/
<hw>Dec"o*rate</hw> <pr>(d<ecr/k"<osl/*r<amac/t)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Decorated</conjf>
<pr>(d<ecr/k"<osl/*r<amac/`t<ecr/d)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Decorating</conjf>
<pr>(d<ecr/k"<osl/*r<amac/`t<icr/ng)</pr>.]</vmorph> <ety>[L.
<ets>decoratus</ets>, p. p. of <ets>decorare</ets>, fr. <ets>decus</ets>
ornament; akin to <ets>decere</ets> to be becoming. See
<er>Decent</er>.]</ety> <def>To deck with that which is becoming,
ornamental, or honorary; to adorn; to beautify; to embellish; <as>as, to
<ex>decorate</ex> the person; to <ex>decorate</ex> an edifice; to
<ex>decorate</ex> a lawn with flowers; to <ex>decorate</ex> the mind
with moral beauties; to <ex>decorate</ex> a hero with
honors.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Her fat neck was ornamented with jewels, rich bracelets
<qex>decorated</qex> her arms.</q> <rj><qau>Thackeray.</qau></rj></p>

<p><syn><b>Syn.</b> -- To adorn; embellish; ornament; beautify; grace.
See <er>Adorn</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Decorated style</b></col> <fld>(Arch.)</fld>, <cd>a name
given by some writers to the perfected English Gothic architecture; it
may be considered as having flourished from about <sc>a. d</sc>. 1300 to
<sc>a. d</sc>. 1375.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>decorated</ent><br/
<hw>decorated</hw> <pos>adj.</pos> <def>having decorations.</def>
[Narrower terms: <stype>beaded, beady, bejeweled, bejewelled,
bespangled, gemmed, jeweled, jewelled, sequined, spangled,
spangly</stype>; <stype>bedaubed</stype>; <stype>bespectacled, monocled,
spectacled</stype>; <stype>braided</stype>; <stype>brocaded, embossed,
raised</stype>; <stype>buttony</stype>; <stype>carbuncled</stype>;
<stype>champleve, cloisonne, enameled</stype>; <stype>crested, plumed
having a decorative plume)</stype>; <stype>crested, top-knotted,
topknotted, tufted</stype>; <stype>crested</stype>; <stype>embellished,
ornamented, ornate</stype>; <stype>embroidered</stype>;
<stype>encircled, ringed, wreathed</stype>; <stype>fancied up, gussied,
gussied up, tricked out</stype>; <stype>feathery, feathered,
plumy</stype>; <stype>frilled, frilly, ruffled</stype>;
<stype>fringed</stype>; <stype>gilt-edged</stype>;
<stype>inflamed</stype>; <stype>inlaid</stype>;
<stype>inwrought</stype>; <stype>laced</stype>; <stype>mosaic,
tessellated</stype>; <stype>paneled, wainscoted</stype>;
<stype>studded</stype>; <stype>tapestried</stype>; <stype>tasseled,
tasselled</stype>; <stype>tufted</stype>; <stype>clinquant, tinseled,
tinselly</stype>; <stype>tricked-out</stype>] <see>Also See:
<er>clothed</er>, <er>fancy</er>.</see> Antonym:
<ant>unadorned</ant>.<br/
<syn><b>Syn. --</b> adorned.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>decoration</ent><br/
<hw>dec`o*ra"tion</hw> <pr>(d<ecr/k`<osl/*r<amac/"sh<ucr/n)</pr>,
<pos>n.</pos> <ety>[LL. <ets>decoratio</ets>: cf. F.
<ets>d<eacute/coration</ets>.]</ety> <sn>1.</sn> <def>The act of
adorning, embellishing, or honoring; ornamentation.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which adorns, enriches, or beautifies;
something added by way of embellishment; ornament.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The hall was celebrated for . . . the richness of its
<qex>decoration</qex>.</q> <rj><qau>Motley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Specifically, any mark of honor to be worn upon the
person, as a medal, cross, or ribbon of an order of knighthood, bestowed
for services in war, great achievements in literature, art,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decoration Day</ent><br/
<hw>Decoration Day</hw>. <def>a day, May 30, originally appointed for
decorating with flowers the graves of the Union soldiers and sailors,
who fell in the Civil War in the United States; -- now called
<altname>Memorial Day</altname>, and established as the last Monday in
May, and designated as a day for commemorating those who died in all
wars of the United States.</def> <mark>[U. S.]</mark><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><ent>Decorative</ent><br/
<hw>Dec"o*ra*tive</hw> <pr>(d<ecr/k"<osl/*r<adot/*t<icr/v <it>or</it>
d<ecr/k"<osl/*r<asl/*t<icr/v)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>d<eacute/coratif</ets>.]</ety> <def>Suited to decorate or
embellish; adorning.</def> -- <wordforms><wf>Dec"o*ra*tive*ness</wf>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Decorative art</b></col>, <cd>fine art which has for its
end ornamentation, rather than the representation of objects or
events.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decorator</ent><br/
<hw>Dec"o*ra`tor</hw> <pr>(d<ecr/k"<osl/*r<amac/"t<etil/r)</pr>,
<pos>n.</pos> <ety>[Cf. F. <ets>d<eacute/corateur</ets>.]</ety> <def>One
who decorates, adorns, or embellishes; specifically, an artisan whose
business is the decoration of houses, esp. their interior
decoration.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>decore</ent><br/
<hw>de*core"</hw> <pr>(d<esl/*k<omac/r")</pr>, <pos>v. t.</pos>
<ety>[Cf. F. <ets>d<eacute/corer</ets>. See <er>Decorate</er>.]</ety>
<def>To decorate; to beautify.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>decore</qex> and beautify the house of God.</q>
<rj><qau>E. Hall.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decorement</ent><br/
<hw>De*core"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Ornament.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decorous</ent><br/
<hw>Dec"or*ous</hw> <pr>(d<ecr/k"<osl/r*<ucr/s <it>or</it>
d<esl/*k<omac/"r<ucr/s; 277)</pr>, <pos>a.</pos> <ety>[L.
<ets>dec<omac/rus</ets>, fr. <ets>decor</ets> comeliness, beauty; akin
to <ets>decere</ets>. See <er>Decent</er>, and cf.
<er>Decorum</er>.]</ety> <def>Suitable to a character, or to the time,
place, and occasion; marked with decorum; becoming; proper; seemly;
befitting; <as>as, a <ex>decorous</ex> speech; <ex>decorous</ex>
behavior; a <ex>decorous</ex> dress for a judge.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>decorous</qex> pretext the war.</q>
<rj><qau>Motley.</qau></rj></p>

<p>-- <wordforms><wf>De*co"rous*ly</wf>, <pos>adv.</pos> --
<wf>De*co"rous*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decorticate</ent><br/
<hw>De*cor"ti*cate</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Decorticated</conjf>; <pos>p.
pr. & vb. n.</pos> <conjf>Decorticating</conjf>.]</vmorph> <ety>[L.
<ets>decorticatus</ets>, p. p. of <ets>decorticare</ets> to bark;
<ets>de-</ets> + <ets>cortex</ets> bark.]</ety> <def>To divest of the
bark, husk, or exterior coating; to husk; to peel; to hull.</def>
<ldquo/Great barley dried and <xex>decorticated</xex>.<rdquo/
<rj><au>Arbuthnot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decortication</ent><br/
<hw>De*cor`ti*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>decorticatio</ets>: cf. F. <ets>d<eacute/cortication</ets>.]</ety>
<def>The act of stripping off the bark, rind, hull, or outer
coat.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decorticator</ent><br/
<hw>De*cor"ti*ca`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A machine for
decorticating wood, hulling grain, etc.; also, an instrument for
removing surplus bark or moss from fruit trees.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decorum</ent><br/
<hw>De*cor"um</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>dec<omac/rum</ets>, fr. <ets>dec<omac/rus</ets>. See
<er>Decorous</er>.]</ety> <def>Propriety of manner or conduct; grace
arising from suitableness of speech and behavior to one's own character,
or to the place and occasion; decency of conduct; seemliness; that which
is seemly or suitable.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Negligent of the duties and <qex>decorums</qex> of his
station.</q> <rj><qau>Hallam.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>If your master<br/
Would have a queen his beggar, you must tell him,<br/
That majesty, to keep <qex>decorum</qex>, must<br/
No less beg than a kingdom.</q> <rj><qau>Shak.</qau></rj></p>

<p><syn><b>Syn.</b> -- <er>Decorum</er>, <er>Dignity</er>.</syn> <usage>
<xex>Decorum</xex>, in accordance with its etymology, is that which is
<xex>becoming</xex> in outward act or appearance; <as>as, the
<ex>decorum</ex> of a public assembly</as>. <xex>Dignity</xex> springs
from an inward elevation of soul producing a corresponding effect on the
manners; <as>as, <ex>dignity</ex> of personal
appearance</as>.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decoy</ent><br/
<hw>De*coy"</hw> <pr>(d<esl/*koi")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Decoyed</conjf>
<pr>(-koid")</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Decoying</conjf>.]</vmorph> <ety>[Pref. <ets>de-</ets> +
<ets>coy</ets>; orig., to quiet, soothe, caress, entice. See
<er>Coy</er>.]</ety> <def>To lead into danger by artifice; to lure into
a net or snare; to entrap; to insnare; to allure; to entice; <as>as, to
<ex>decoy</ex> troops into an ambush; to <ex>decoy</ex> ducks into a
net.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Did to a lonely cot his steps <qex>decoy</qex>.</q>
<rj><qau>Thomson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>E'en while fashion's brightest arts <qex>decoy</qex>,<br/
The heart, distrusting, asks if this be joy.</q>
<rj><qau>Goldsmith.</qau></rj></p>

<p><syn><b>Syn.</b> -- To entice; tempt; allure; lure. See
<er>Allure</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decoy</ent><br/
<hw>De*coy"</hw>, <pos>n.</pos> <sn>1.</sn> <def>Anything intended to
lead into a snare; a lure that deceives and misleads into danger, or
into the power of an enemy; a bait.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A fowl, or the likeness of one, used by sportsmen to
entice other fowl into a net or within shot.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A place into which wild fowl, esp. ducks, are
enticed in order to take or shoot them.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A person employed by officers of justice, or parties
exposed to injury, to induce a suspected person to commit an offense
under circumstances that will lead to his detection.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decoy-duck</ent><br/
<hw>De*coy"-duck`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A duck used to
lure wild ducks into a decoy; hence, a person employed to lure others
into danger.</def> <rj><au>Beau. & Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decoyer</ent><br/
<hw>De*coy"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who decoys
another.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decoy-man</ent><br/
<hw>De*coy"-man`</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Decoy-men</plw> <pr>(<?/)</pr>.</plu> <def>A man employed in
decoying wild fowl.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decrease</ent><br/
<hw>De*crease"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Decreased</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Decreasing</conjf>.]</vmorph> <ety>[OE.
<ets>decrecen</ets>, fr. OF. <ets>decreistre</ets>, F.
<ets>d<eacute/cro<icir/tre</ets>, or from the OF. noun (see
<er>Decrease</er>, <pos>n.</pos>), fr. L. <ets>decrescere</ets> to grow
less; <ets>de</ets> + <ets>crescere</ets> to grow. See
<er>Crescent</er>, and cf. <er>Increase</er>.]</ety> <def>To grow less,
-- opposed to <xex>increase</xex>; to be diminished gradually, in size,
degree, number, duration, etc., or in strength, quality, or excellence;
<as>as, they days <ex>decrease</ex> in length from June to
December</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He must increase, but I must <qex>decrease</qex>.</q>
<rj><qau>John iii. 30.</qau></rj></p>

<p><syn><b>Syn.</b> -- To <er>Decrease</er>, <er>Diminish</er>.</syn>
<usage> Things usually <xex>decrease</xex> or fall off by degrees, and
from within, or through some cause which is imperceptible; as, the flood
<ex>decreases</ex>; the cold <xex>decreases</xex>; their affection has
<xex>decreased</xex>. Things commonly <xex>diminish</xex> by an
influence from without, or one which is apparent; as, the army was
<ex>diminished</ex> by disease; his property is <xex>diminishing</xex>
through extravagance; their affection has <xex>diminished</xex> since
their separation their separation. The turn of thought, however, is
often such that these words may be interchanged.</usage><br/
[<source>1913 Webster</source>]</p>

<p><q>The olive leaf, which certainly them told<br/
The flood <qex>decreased</qex>.</q> <rj><qau>Drayton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Crete's ample fields <qex>diminish</qex> to our eye;<br/
Before the Boreal blasts the vessels fly.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decrease</ent><br/
<hw>De*crease"</hw>, <pos>v. t.</pos> <def>To cause to grow less; to
diminish gradually; <as>as, extravagance <ex>decreases</ex> one's
means</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That might <qex>decrease</qex> their present store.</q>
<rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decrease</ent><br/
<hw>De*crease"</hw>, <pos>n.</pos> <ety>[OE. <ets>decrees</ets>, OF.
<ets>decreis</ets>, fr. <ets>decreistre</ets>. See <er>Decrease</er>,
<pos>v.</pos>]</ety> <sn>1.</sn> <def>A becoming less; gradual
diminution; decay; <as>as, a <ex>decrease</ex> of revenue or of
strength</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The wane of the moon.</def>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>decreased</ent><br/
<hw>decreased</hw> <pos>adj.</pos> <def>made less in size or amount or
degree. Opposite of <ant>increased</ant>.</def> [Narrower terms:
<stype>attenuate, attenuated, faded, weakened</stype>; <stype>belittled,
diminished, small</stype>; <stype>cut, cut-rate</stype>;
<stype>diminished, lessened</stype>; <stype>minimized</stype>;
<stype>remittent</stype>; <stype>attenuated</stype>]<br/
<syn><b>Syn. --</b> reduced.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Decreaseless</ent><br/
<hw>De*crease"less</hw>, <pos>a.</pos> <def>Suffering no decrease.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>It [the river] flows and flows, and yet will flow,<br/
Volume <qex>decreaseless</qex> to the final hour.</q> <rj><qau>A.
Seward.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decreasing</ent><br/
<hw>De*creas"ing</hw>, <pos>a.</pos> <def>Becoming less and less;
diminishing.</def> -- <wordforms><wf>De*creas"ing*ly</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Decreasing series</b></col> <fld>(Math.)</fld>, <cd>a
series in which each term is numerically smaller than the preceding
term.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decreation</ent><br/
<hw>De`cre*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Destruction; --
opposed to <xex>creation</xex>.</def> <mark>[R.]</mark>
<rj><au>Cudworth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decree</ent><br/
<hw>De*cree"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>decre</ets>, F. <ets>d<eacute/cret</ets>, fr. L.
<ets>decretum</ets>, neut. <ets>decretus</ets>, p. p. of
<ets>decernere</ets> to decide; <ets>de-</ets> + <ets>cernere</ets> to
decide. See <er>Certain</er>, and cf. <er>Decreet</er>,
<er>Decretal</er>.]</ety> <sn>1.</sn> <def>An order from one having
authority, deciding what is to be done by a subordinate; also, a
determination by one having power, deciding what is to be done or to
take place; edict, law; authoritative rule, decision.</def> <ldquo/The
<xex>decrees</xex> of Venice.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>There went out a <qex>decree</qex> from C<ae/sar Augustus that all
the world should be taxed.</q> <rj><qau>Luke ii. 1.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Poor hand, why quiverest thou at this <qex>decree</qex>?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <sd>(a)</sd> <def>A decision, order, or
sentence, given in a cause by a court of equity or admiralty.</def>
<sd>(b)</sd> <def>A determination or judgment of an umpire on a case
submitted to him.</def> <rj><au>Brande.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Eccl.)</fld> <def>An edict or law made by a council
for regulating any business within their jurisdiction; <as>as, the
<ex>decrees</ex> of ecclesiastical councils</as>.</def></p>

<p><syn><b>Syn.</b> -- Law; regulation; edict; ordinance. See
<er>Law</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decree</ent><br/
<hw>De*cree"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Decreed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Decreeing</conjf>.]</vmorph> <sn>1.</sn> <def>To determine
judicially by authority, or by decree; to constitute by edict; to
appoint by decree or law; to determine; to order; to ordain; <as>as, a
court <ex>decrees</ex> a restoration of property</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou shalt also <qex>decree</qex> a thing, and it shall be
established unto thee.</q> <rj><qau>Job xxii. 28.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To ordain by fate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decree</ent><br/
<hw>De*cree"</hw>, <pos>v. i.</pos> <def>To make decrees; -- used
absolutely.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Father eternal! thine is to <qex>decree</qex>;<br/
Mine, both in heaven and earth to do thy will.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decreeable</ent><br/
<hw>De*cree"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of being
decreed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decreer</ent><br/
<hw>De*cre"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
decrees.</def> <rj><au>J. Goodwin.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decreet</ent><br/
<hw>De*creet"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf.
<er>Decree</er>.]</ety> <fld>(Scots Law)</fld> <def>The final judgment
of the Court of Session, or of an inferior court, by which the question
at issue is decided.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decrement</ent><br/
<hw>Dec"re*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>decrementum</ets>, fr. <ets>decrescere</ets>. See
<er>Decrease</er>.]</ety> <sn>1.</sn> <def>The state of becoming
gradually less; decrease; diminution; waste; loss.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Twit me with the <qex>decrements</qex> of my pendants.</q>
<rj><qau>Ford.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Rocks, mountains, and the other elevations of the earth suffer a
continual <qex>decrement</qex>.</q> <rj><qau>Woodward.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The quantity lost by gradual diminution or waste; --
opposed to <ant>increment</ant>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Crystallog.)</fld> <def>A name given by Ha<uum/y to
the successive diminution of the layers of molecules, applied to the
faces of the primitive form, by which he supposed the secondary forms to
be produced.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Math.)</fld> <def>The quantity by which a variable
is diminished.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Equal decrement of life</b></col>. <sd>(a)</sd> <cd>The
decrease of life in a group of persons in which the assumed law of
mortality is such that of a given large number of persons, all being now
of the same age, an equal number shall die each consecutive year.</cd>
<sd>(b)</sd> <cd>The decrease of life in a group of persons in which the
assumed law of mortality is such that the ratio of those dying in a year
to those living through the year is constant, being independent of the
age of the persons.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decrepit</ent><br/
<hw>De*crep"it</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>decrepitus</ets>, perhaps orig., noised out, noiseless, applied to
old people, who creep about quietly; <ets>de-</ets> + <ets>crepare</ets>
to make a noise, rattle: cf. F. <ets>d<eacute/cr<eacute/pit</ets>. See
<er>Crepitate</er>.]</ety> <def>Broken down with age; wasted and
enfeebled by the infirmities of old age; feeble; worn out.</def>
<ldquo/Beggary or <xex>decrepit</xex> age.<rdquo/
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Already <qex>decrepit</qex> with premature old age.</q>
<rj><qau>Motley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Sometimes incorrectly written
<xex>decrepid</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decrepitate</ent><br/
<hw>De*crep"i*tate</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Decrepitated</conjf>; <pos>p.
pr. & vb. n.</pos> <conjf>Decrepitating</conjf>.]</vmorph> <ety>[Cf. F.
<ets>d<eacute/cr<eacute/piter</ets>.]</ety> <def>To roast or calcine so
as to cause a crackling noise; <as>as, to <ex>decrepitate</ex>
salt</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decrepitate</ent><br/
<hw>De*crep"i*tate</hw>, <pos>v. i.</pos> <def>To crackle, as salt in
roasting.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decrepitation</ent><br/
<hw>De*crep`i*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>d<eacute/cr<eacute/pitation</ets>.]</ety> <def>The act of
decrepitating; a crackling noise, such as salt makes when
roasting.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decrepitness</ent><br/
<hw>De*crep"it*ness</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Decrepitude.</def> <mark>[R.]</mark> <rj><au>Barrow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decrepitude</ent><br/
<hw>De*crep"i*tude</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>d<eacute/cr<eacute/pitude</ets>.]</ety> <def>The broken state
produced by decay and the infirmities of age; infirm old age.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decrescendo</ent><br/
\'d8<hw>De`cres*cen"do</hw> <pr>(?)</pr>, <pos>a. & adv.</pos>
<ety>[It.]</ety> <fld>(Mus.)</fld> <def>With decreasing volume of sound;
-- a direction to performers, either written upon the staff (abbreviated
<xex>Dec</xex>., or <xex>Decresc</xex>.), or indicated by the
sign.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decrescent</ent><br/
<hw>De*cres"cent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>decrescens</ets>, p. pr. of <ets>decrescere</ets>. See
<er>Decrease</er>.]</ety> <def>Becoming less by gradual diminution;
decreasing; <as>as, a <ex>decrescent</ex> moon</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decrescent</ent><br/
<hw>De*cres"cent</hw>, <pos>n.</pos> <fld>(Her.)</fld> <def>A crescent
with the horns directed towards the sinister.</def>
<rj><au>Cussans.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decretal</ent><br/
<hw>De*cre"tal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>decretalis</ets>, fr. <ets>decretum</ets>. See
<er>Decree</er>.]</ety> <def>Appertaining to a decree; containing a
decree; <as>as, a <ex>decretal</ex> epistle</as>.</def>
<rj><au>Ayliffe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decretal</ent><br/
<hw>De*cre"tal</hw>, <pos>n.</pos> <ety>[LL. <ets>decretale</ets>, neut.
of L. <ets>decretalis</ets>. See <er>Decretal</er>, <pos>a.</pos>]</ety>
<sn>1.</sn> <fld>(R. C. Ch.)</fld> <def>An authoritative order or
decree; especially, a letter of the pope, determining some point or
question in ecclesiastical law. The decretals form the second part of
the canon law.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Canon Law)</fld> <def>The collection of
ecclesiastical decrees and decisions made, by order of Gregory IX., in
1234, by St. Raymond of Pennafort.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decrete</ent><br/
<hw>De*crete"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>decretum</ets>. See <er>Decree</er>.]</ety> <def>A decree.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decretion</ent><br/
<hw>De*cre"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From L.
<ets>decrescere</ets>, <ets>decretum</ets>. See
<er>Decrease</er>.]</ety> <def>A decrease.</def> <mark>[Obs.]</mark>
<rj><au>Pearson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decretist</ent><br/
<hw>De*cre"tist</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL.
<ets>decretista</ets>, fr. <ets>decretum</ets>: cf. F.
<ets>d<eacute/cr<eacute/tiste</ets>. See <er>Decree</er>,
<pos>n.</pos>]</ety> <def>One who studies, or professes the knowledge
of, the decretals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decretive</ent><br/
<hw>De*cre"tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From L.
<ets>decretum</ets>. See <er>Decree</er>, <pos>n.</pos>]</ety>
<def>Having the force of a decree; determining.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The will of God is either <qex>decretive</qex> or perceptive.</q>
<rj><qau>Bates.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decretorial</ent><br/
<hw>Dec`re*to"ri*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Decretory;
authoritative.</def> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decretorily</ent><br/
<hw>Dec"re*to*ri*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a
decretory or definitive manner; by decree.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decretory</ent><br/
<hw>Dec"re*to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>decretorius</ets>, from <ets>decretum</ets>. See
<er>Decree</er>.]</ety> <sn>1.</sn> <def>Established by a decree;
definitive; settled.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>decretory</qex> rigors of a condemning sentence.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Serving to determine; critical.</def> <ldquo/The
critical or <xex>decretory</xex> days.<rdquo/ <rj><au>Sir T.
Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 379 --></p>

<p><ent>Decrew</ent><br/
<hw>De*crew"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[F.
<ets>d<eacute/crue</ets>, <ets>n.</ets>, decrease, and
<ets>d<eacute/cru</ets>, p. p. of <ets>d<eacute/cro<icir/tre</ets>. See
<er>Decrease</er>, and cf. <er>Accrue</er>.]</ety> <def>To
decrease.</def> <mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decrial</ent><br/
<hw>De*cri"al</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Decry</er>.]</ety> <def>A crying down; a clamorous censure;
condemnation by censure.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decrier</ent><br/
<hw>De*cri"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
decries.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decrown</ent><br/
<hw>De*crown"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To deprive of a
crown; to discrown.</def> <mark>[R.]</mark>
<rj><au>Hakewill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decrustation</ent><br/
<hw>De`crus*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. OF.
<ets>d<eacute/crustation</ets>.]</ety> <def>The removal of a
crust.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decry</ent><br/
<hw>De*cry"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Decried</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Decrying</conjf>.]</vmorph> <ety>[F. <ets>d<eacute/crier</ets>,
OF. <ets>descrier</ets>; pref. <ets>des-</ets> (L. <ets>dis-</ets>) +
<ets>crier</ets> to cry. See <er>Cry</er>, and cf.
<er>Descry</er>.]</ety> <def>To cry down; to censure as faulty, mean, or
worthless; to clamor against; to blame clamorously; to discredit; to
disparage.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>For small errors they whole plays <qex>decry</qex>.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Measures which are extolled by one half of the kingdom are
naturally <qex>decried</qex> by the other.</q>
<rj><qau>Addison.</qau></rj></p>

<p><syn><b>Syn.</b> -- To <er>Decry</er>, <er>Depreciate</er>,
<er>Detract</er>, <er>Disparage</er>.</syn> <usage> <xex>Decry</xex> and
<xex>depreciate</xex> refer to the estimation of a thing, the former
seeking to lower its value by clamorous censure, the latter by
representing it as of little worth. <xex>Detract</xex> and
<xex>disparage</xex> also refer to merit or value, which the former
assails with caviling, insinuation, etc., while the latter willfully
underrates and seeks to degrade it. Men <xex>decry</xex> their rivals
and <xex>depreciate</xex> their measures. The envious <xex>detract</xex>
from the merit of a good action, and <xex>disparage</xex> the motives of
him who performs it.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>decrypt</ent><br/
<hw>decrypt</hw> <pos>v.</pos> <def>to convert from a coded form into
the original; -- of communications. Inverse of
<inv>encrypt</inv>.</def><br/
<syn><b>Syn. --</b> decode, decipher[WE1].</syn><br/
[<source>PJC</source>]</p>

<p><ent>Decubation</ent><br/
<hw>Dec`u*ba"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From L.
<ets>decubare</ets>; <ets>de-</ets> + <ets>cubare</ets>. See
<er>Decumbent</er>.]</ety> <def>Act of lying down; decumbence.</def>
<mark>[Obs.]</mark> <rj><au>Evelyn.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decubitus</ent><br/
\'d8<hw>De*cu"bi*tus</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. L.
<ets>de-</ets> + <ets>cubare</ets>, to lie down: cf. F.
<ets>d<eacute/cubitus</ets>.]</ety> <fld>(Med.)</fld> <def>An attitude
assumed in lying down; <as>as, the dorsal
<ex>decubitus</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deculassment</ent><br/
<ent>Deculassement</ent><br/
<mhw>\'d8<hw>D<eacute/`cu`lasse`ment"</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[F.]</ety> Also, sometimes, Anglicized <hw>Dec`u*lass"ment</hw>
<pr>(<?/)</pr>.</mhw> <fld>(Ordnance)</fld> <def>An accidental blowing
off of, or other serious damage to, the breechblock of a gun; also, a
removal of the breechblock for the purpose of disabling the
gun.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Decuman</ent><br/
<hw>Dec"u*man</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>decumanus</ets> of the tenth, and by metonymy, large, fr.
<ets>decem</ets> ten.]</ety> <def>Large; chief; -- applied to an
extraordinary billow, supposed by some to be every tenth in order.
<mark>[R.]</mark> Also used substantively.</def> <ldquo/Such
<xex>decuman</xex> billows.<rdquo/ <au>Gauden.</au> <ldquo/The baffled
<xex>decuman</xex>.<rdquo/ <rj><au>Lowell.</au></rj></p>

<p><ent>decumary</ent><br/
<hw>decumary</hw> <pos>n.</pos> <def>a woody climber of southeastern US
(<spn>Decumaria barbara</spn>) having white flowers in compound terminal
clusters.</def><br/
<syn><b>Syn. --</b> <spn>Decumaria barbata</spn>, <spn>Decumaria
barbara</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Decumbency</ent><br/
<ent>Decumbence</ent><br/
<mhw>{ <hw>De*cum"bence</hw> <pr>(?)</pr>, <hw>De*cum"ben*cy</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <def>The act or posture of lying
down.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The ancient manner of <qex>decumbency</qex>.</q> <rj><qau>Sir T.
Browne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decumbent</ent><br/
<hw>De*cum"bent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>decumbens</ets>, <ets>-entis</ets>, p. pr. of <ets>decumbere</ets>;
<ets>de-</ets> + <ets>cumbere</ets> (only in comp.), <ets>cubare</ets>
to lie down.]</ety> <sn>1.</sn> <def>Lying down; prostrate;
recumbent.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>decumbent</qex> portraiture of a woman.</q>
<rj><qau>Ashmole.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>Reclining on the ground, as if too
weak to stand, and tending to rise at the summit or apex; <as>as, a
<ex>decumbent</ex> stem</as>.</def> <rj><au>Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decumbently</ent><br/
<hw>De*cum"bent*ly</hw>, <pos>adv.</pos> <def>In a decumbent
posture.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decumbiture</ent><br/
<hw>De*cum"bi*ture</hw> <pr>(?; 135)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>Confinement to a sick bed, or time of taking to one's bed from
sickness.</def> <rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Astrol.)</fld> <def>Aspect of the heavens at the
time of taking to one's sick bed, by which the prognostics of recovery
or death were made.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decuple</ent><br/
<hw>Dec"u*ple</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F.
<ets>d<eacute/cuple</ets>, L. <ets>decuplus</ets>, fr. <ets>decem</ets>
ten.]</ety> <def>Tenfold.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decuple</ent><br/
<hw>Dec"u*ple</hw>, <pos>n.</pos> <def>A number ten times
repeated.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decuple</ent><br/
<hw>Dec"u*ple</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Decupled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Decupling</conjf> <pr>(?)</pr>.]</vmorph> <def>To make tenfold;
to multiply by ten.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decurion</ent><br/
<hw>De*cu"ri*on</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>decurio</ets>, <ets>decurionis</ets>, fr. <ets>decuria</ets> a
squad of ten, fr. <ets>decem</ets> ten.]</ety> <fld>(Rom. Antiq.)</fld>
<def>A head or chief over ten; especially, an officer who commanded a
division of ten soldiers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decurionate</ent><br/
<hw>De*cu"ri*on*ate</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>decurionatus</ets>, fr. <ets>decurio</ets>.]</ety> <def>The office
of a decurion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decurrence</ent><br/
<hw>De*cur"rence</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
running down; a lapse.</def> <mark>[R.]</mark>
<rj><au>Gauden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decurrent</ent><br/
<hw>De*cur"rent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>decurrens</ets>, <ets>-entis</ets>, p. pr. of <ets>decurrere</ets>
to run down; <ets>de-</ets> + <ets>currere</ets> to run: cf. F.
<ets>d<eacute/current</ets>.]</ety> <fld>(Bot.)</fld> <def>Extending
downward; -- said of a leaf whose base extends downward and forms a wing
along the stem.</def> -- <wordforms><wf>De*cur"rent*ly</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decursion</ent><br/
<hw>De*cur"sion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>decursio</ets>, fr. <ets>decurrere</ets>. See
<er>Decurrent</er>.]</ety> <def>A flowing; also, a hostile
incursion.</def> <mark>[Obs.]</mark> <rj><au>Sir M. Hale.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decursive</ent><br/
<hw>De*cur"sive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>d<eacute/cursif</ets>. See <er>Decurrent</er>.]</ety> <def>Running
down; decurrent.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decursively</ent><br/
<hw>De*cur"sive*ly</hw>, <pos>adv.</pos> <def>In a decursive
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Decursively pinnate</b></col> <fld>(Bot.)</fld>,
<cd>having the leaflets decurrent, or running along the petiole; -- said
of a leaf.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decurt</ent><br/
<hw>De*curt"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>decurtare</ets>; <ets>de-</ets> + <ets>curtare</ets>.]</ety>
<def>To cut short; to curtail.</def> <mark>[Obs.]</mark>
<rj><au>Bale.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decurtation</ent><br/
<hw>De`cur*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>decurtatio</ets>.]</ety> <def>Act of cutting short.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decury</ent><br/
<hw>Dec"u*ry</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Decuries</plw> <pr>(#)</pr>.</plu> <ety>[L. <ets>decuria</ets>, fr.
<ets>decem</ets> ten.]</ety> <def>A set or squad of ten men under a
decurion.</def> <rj><au>Sir W. Raleigh.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decussate</ent><br/
<hw>De*cus"sate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Decussated</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Decussating</conjf>.]</vmorph> <ety>[L. <ets>decussatus</ets>, p.
p. of <ets>decussare</ets> to cross like an X, fr. <ets>decussis</ets>
(orig. equiv. to <ets>decem asses</ets>) the number ten, which the
Romans represented by X.]</ety> <def>To cross at an acute angle; to cut
or divide in the form of X; to intersect; -- said of lines in
geometrical figures, rays of light, nerves, etc.</def></p>

<p><ent>Decussated</ent><br/
<ent>Decussate</ent><br/
<mhw>{ <hw>De*cus"sate</hw> <pr>(?)</pr>, <hw>De*cus"sa*ted</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <sn>1.</sn> <def>Crossed;
intersected.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>Growing in pairs, each of which is
at right angles to the next pair above or below; <as>as,
<ex>decussated</ex> leaves or branches</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Rhet.)</fld> <def>Consisting of two rising and two
falling clauses, placed in alternate opposition to each other; <as>as, a
<ex>decussated</ex> period</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decussately</ent><br/
<hw>De*cus"sate*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a
decussate manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decussation</ent><br/
<hw>De`cus*sa"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>decussatio</ets>.]</ety> <def>Act of crossing at an acute angle, or
state of being thus crossed; an intersection in the form of an X;
<as>as, the <ex>decussation</ex> of lines, nerves, etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decussative</ent><br/
<hw>De*cus"sa*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Intersecting at
acute angles.</def> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decussatively</ent><br/
<hw>De*cus"sa*tive*ly</hw>, <pos>adv.</pos> <def>Crosswise; in the form
of an X.</def> <ldquo/Anointed <xex>decussatively</xex>.<rdquo/
<rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decyl</ent><br/
<hw>De"cyl</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>decem</ets>
ten + <ets>-yl</ets>.]</ety> <fld>(Chem.)</fld> <def>A hydrocarbon
radical, <chform>C10H21.</chform>, never existing alone, but regarded as
the characteristic constituent of a number of compounds of the paraffin
series.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Decylic</ent><br/
<hw>De*cyl"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Chem.)</fld>
<def>Allied to, or containing, the radical decyl.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dedalian</ent><br/
<hw>De*dal"ian</hw> <pr>(?)</pr>, <pos>a.</pos> <def>See
<er>D<ae/dalian</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dedalous</ent><br/
<hw>Ded"a*lous</hw> <pr>(?)</pr>, <pos>a.</pos> <def>See
<er>D<ae/dalous</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dedans</ent><br/
\'d8<hw>De*dans"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<fld>(Court Tennis)</fld> <def>A division, at one end of a tennis court,
for spectators.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dede</ent><br/
<hw>Dede</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Dead.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dedecorate</ent><br/
<hw>De*dec"o*rate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>dedecoratus</ets>, p. p. of <ets>dedecorare</ets> to disgrace. See
<er>Decorate</er>.]</ety> <def>To bring to shame; to disgrace.</def>
<mark>[Obs.]</mark> <rj><au>Bailey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dedecoration</ent><br/
<hw>De*dec`o*ra"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>dedecoratio</ets>.]</ety> <def>Disgrace; dishonor.</def>
<mark>[Obs.]</mark> <rj><au>Bailey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dedecorous</ent><br/
<hw>De*dec"o*rous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>dedecorus</ets>. See <er>Decorous</er>.]</ety> <def>Disgraceful;
unbecoming.</def> <mark>[R.]</mark> <rj><au>Bailey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dedentition</ent><br/
<hw>De`den*ti"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The shedding of
teeth.</def> <mark>[R.]</mark> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dedicate</ent><br/
<hw>Ded"i*cate</hw> <pr>(?)</pr>, <pos>p. a.</pos> <ety>[L.
<ets>dedicatus</ets>, p. p. of <ets>dedicare</ets> to affirm, to
dedicate; <ets>de-</ets> + <ets>dicare</ets> to declare, dedicate; akin
to <ets>dicere</ets> to say. See <er>Diction</er>.]</ety>
<def>Dedicated; set apart; devoted; consecrated.</def>
<ldquo/<xex>Dedicate</xex> to nothing temporal.<rdquo/
<rj><au>Shak.</au></rj></p>

<p><syn><b>Syn.</b> -- Devoted; consecrated; addicted.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dedicate</ent><br/
<hw>Ded"i*cate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Dedicated</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Dedicating</conjf>.]</vmorph> <sn>1.</sn> <def>To set apart and
consecrate, as to a divinity, or for sacred uses; to devote formally and
solemnly; <as>as, to <ex>dedicate</ex> vessels, treasures, a temple, or
a church, to a religious use</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Vessels of silver, and vessels of gold, . . . which also king
David did <qex>dedicate</qex> unto the Lord.</q> <rj><qau>2 Sam. viii.
10, 11.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>We have come to <qex>dedicate</qex> a portion of that field as a
final resting place for those who here gave their lives that that nation
might live. . . . But in a larger sense we can not <qex>dedicate</qex>,
we can not consecrate, we can not hallow this ground.</q> <rj><qau>A.
Lincoln.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To devote, set apart, or give up, as one's self, to
a duty or service.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The profession of a soldier, to which he had <qex>dedicated</qex>
himself.</q> <rj><qau>Clarendon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To inscribe or address, as to a patron.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He complied ten elegant books, and <qex>dedicated</qex> them to
the Lord Burghley.</q> <rj><qau>Peacham.</qau></rj></p>

<p><syn><b>Syn.</b> -- See <er>Addict</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>dedicated</ent><br/
<hw>dedicated</hw> <pos>adj.</pos> <sn>1.</sn> <def>wholly committed to
a purpose or cause; <as>as, a <ex>dedicated</ex>
musician</as>.</def><br/
<syn><b>Syn. --</b> devoted.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>zealous in loyalty or affection; <as>as,
<ex>dedicated</ex> nurses</as>.</def><br/
<syn><b>Syn. --</b> devoted.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>3.</sn> <def>set apart especially for a higher purpose; <as>as, a
life <ex>dedicated</ex> to science</as>.</def> [Narrower terms:
<stype>consecrated (vs. desecrated), consecrate</stype>]<br/
<syn><b>Syn. --</b> dedicated to(predicate), devoted
to(predicate).</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dedicatee</ent><br/
<hw>Ded`i*ca*tee"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One to whom a
thing is dedicated; -- correlative to <inv>dedicator</inv>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dedication</ent><br/
<hw>Ded`i*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>dedicatio</ets>.]</ety> <sn>1.</sn> <def>The act of setting apart
or consecrating to a divine Being, or to a sacred use, often with
religious solemnities; solemn appropriation; <as>as, the
<ex>dedication</ex> of Solomon's temple</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A devoting or setting aside for any particular
purpose; <as>as, a <ex>dedication</ex> of lands to public
use</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>An address to a patron or friend, prefixed to a
book, testifying respect, and often recommending the work to his special
protection and favor.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dedicator</ent><br/
<hw>Ded"i*ca`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.: cf. F.
<ets>d<eacute/dicateur</ets>.]</ety> <def>One who dedicates; more
especially, one who inscribes a book to the favor of a patron, or to one
whom he desires to compliment.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dedicatorial</ent><br/
<hw>Ded`i*ca*to"ri*al</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Dedicatory.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dedicatory</ent><br/
<hw>Ded"i*ca*to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>d<eacute/dicatoire</ets>.]</ety> <def>Constituting or serving as a
dedication; complimental.</def> <ldquo/An epistle
<xex>dedicatory</xex>.<rdquo/ <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dedicatory</ent><br/
<hw>Ded"i*ca*to*ry</hw>, <pos>n.</pos> <def>Dedication.</def>
<mark>[R.]</mark> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dedimus</ent><br/
\'d8<hw>Ded"i*mus</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>dedimus</ets> we have given, fr. <ets>dare</ets> to give. So called
because the writ began, <ets>Dedimus potestatem</ets>, etc.]</ety>
<fld>(Law)</fld> <def>A writ to commission private persons to do some
act in place of a judge, as to examine a witness, etc.</def>
<rj><au>Bouvier.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dedition</ent><br/
<hw>De*di"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>deditio</ets>, fr. <ets>dedere</ets> to give away, surrender;
<ets>de-</ets> + <ets>dare</ets> to give.]</ety> <def>The act of
yielding; surrender.</def> <mark>[R.]</mark> <rj><au>Sir M.
Hale.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dedolent</ent><br/
<hw>Ded"o*lent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>dedolens</ets>, p. pr. of <ets>dedolere</ets> to give over
grieving; <ets>de-</ets> + <ets>dolere</ets> to grieve.]</ety>
<def>Feeling no compunction; apathetic.</def> <mark>[R.]</mark>
<rj><au>Hallywell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deduce</ent><br/
<hw>De*duce"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Deduced</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Deducing</conjf>.]</vmorph> <ety>[L. <ets>deducere</ets>;
<ets>de-</ets> + <ets>ducere</ets> to lead, draw. See <er>Duke</er>, and
cf. <er>Deduct</er>.]</ety> <sn>1.</sn> <def>To lead forth.</def>
<mark>[A Latinism]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He should hither <qex>deduce</qex> a colony.</q>
<rj><qau>Selden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To take away; to deduct; to subtract; <as>as, to
<ex>deduce</ex> a part from the whole</as>.</def> <mark>[Obs.]</mark>
<rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To derive or draw; to derive by logical process; to
obtain or arrive at as the result of reasoning; to gather, as a truth or
opinion, from what precedes or from premises; to infer; -- with
<it>from</it> or <it>out of</it>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>O goddess, say, shall I <qex>deduce</qex> my rhymes<br/
From the dire nation in its early times?</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Reasoning is nothing but the faculty of <qex>deducing</qex>
unknown truths from principles already known.</q>
<rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>See what regard will be paid to the pedigree which
<qex>deduces</qex> your descent from kings and conquerors.</q>
<rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deducement</ent><br/
<hw>De*duce"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Inference;
deduction; thing deduced.</def> <mark>[R.]</mark>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deducibility</ent><br/
<hw>De*du`ci*bil"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Deducibleness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deducible</ent><br/
<hw>De*du"ci*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Capable of being deduced or inferred; derivable by reasoning, as a
result or consequence.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>All properties of a triangle depend on, and are
<qex>deducible</qex> from, the complex idea of three lines including a
space.</q> <rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Capable of being brought down.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>As if God [were] <qex>deducible</qex> to human imbecility.</q>
<rj><qau>State Trials (1649).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deducibleness</ent><br/
<hw>De*du"ci*ble*ness</hw>, <pos>n.</pos> <def>The quality of being
deducible; deducibility.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deducibly</ent><br/
<hw>De*du"ci*bly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>By
deduction.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deducive</ent><br/
<hw>De*du"cive</hw> <pr>(?)</pr>, <pos>a.</pos> <def>That deduces;
inferential.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deduct</ent><br/
<hw>De*duct"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Deducted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Deducting</conjf>.]</vmorph> <ety>[L. <ets>deductus</ets>, p. p.
of <ets>deducere</ets> to deduct. See <er>Deduce</er>.]</ety>
<sn>1.</sn> <def>To lead forth or out.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>A people <qex>deducted</qex> out of the city of Philippos.</q>
<rj><qau>Udall.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To take away, separate, or remove, in numbering,
estimating, or calculating; to subtract; -- often with <xex>from</xex>
or <xex>out of</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Deduct</qex> what is but vanity, or dress.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Two and a half per cent should be <qex>deducted</qex> out of the
pay of the foreign troops.</q> <rj><qau>Bp. Burnet.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>We <qex>deduct</qex> from the computation of our years that part
of our time which is spent in . . . infancy.</q>
<rj><au>Norris.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To reduce; to diminish.</def> <mark>[Obs.]</mark>
<ldquo/Do not <xex>deduct</xex> it to days.<rdquo/
<rj><au>Massinger.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>deducted</ent><br/
<hw>deducted</hw> <pos>adj.</pos> <def>taken away. Opposite of
<ant>added</ant>.</def><br/
<syn><b>Syn. --</b> subtracted.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Deductible</ent><br/
<hw>De*duct"i*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Capable of being deducted, taken away, or withdrawn.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Not one found honestly <qex>deductible</qex><br/
From any use that pleased him.</q> <rj><qau>Mrs.
Browning.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Deducible; consequential.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deduction</ent><br/
<hw>De*duc"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>deductio</ets>: cf. F. <ets>d<eacute/duction</ets>.]</ety>
<sn>1.</sn> <def>Act or process of deducing or inferring.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>deduction</qex> of one language from another.</q>
<rj><qau>Johnson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>This process, by which from two statements we deduce a third, is
called <qex>deduction</qex>.</q> <rj><qau>J. R. Seely.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Act of deducting or taking away; subtraction;
<as>as, the <ex>deduction</ex> of the subtrahend from the
minuend</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which is deduced or drawn from premises by a
process of reasoning; an inference; a conclusion.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Make fair <qex>deductions</qex>; see to what they mount.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>That which is or may be deducted; the part taken
away; abatement; <as>as, a <ex>deduction</ex> from the yearly rent in
compensation for services; <ex>deductions</ex> from income in
calculating income taxes</as>.</def></p>

<p><syn><b>Syn.</b> -- See <er>Induction</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deductive</ent><br/
<hw>De*duct"ive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. L.
<ets>deductivus</ets> derivative.]</ety> <def>Of or pertaining to
deduction; capable of being deduced from premises; deducible.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>All knowledge of causes is <qex>deductive</qex>.</q>
<rj><qau>Glanvill.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Notions and ideas . . . used in a <qex>deductive</qex>
process.</q> <rj><qau>Whewell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deductively</ent><br/
<hw>De*duct"ive*ly</hw>, <pos>adv.</pos> <def>By deduction; by way of
inference; by consequence.</def> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deductor</ent><br/
\'d8<hw>De*duc"tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., a guide.
See <er>Deduce</er>.]</ety> <fld>(Zool.)</fld> <def>The pilot whale or
blackfish.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deduit</ent><br/
<hw>De*duit"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>d<eacute/duit</ets>. Cf. <er>Deduct</er>.]</ety> <def>Delight;
pleasure.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deduplication</ent><br/
<hw>De*du`pli*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>de-</ets> + <ets>duplication</ets>.]</ety> <fld>(Biol.)</fld>
<def>The division of that which is morphologically one organ into two or
more, as the division of an organ of a plant into a pair or
cluster.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deed</ent><br/
<hw>Deed</hw> <pr>(d<emac/d)</pr>, <pos>a.</pos> <def>Dead.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deed</ent><br/
<hw>Deed</hw>, <pos>n.</pos> <ety>[AS. <ets>d<aemac/d</ets>; akin to OS.
<ets>d<amac/d</ets>, D. & Dan. <ets>daad</ets>, G. <ets>that</ets>, Sw.
<ets>d<aring/d</ets>, Goth. <ets>d<emac/ds</ets>; fr. the root of
<ets>do</ets>. See <er>Do</er>, <pos>v. t.</pos>]</ety> <sn>1.</sn>
<def>That which is done or effected by a responsible agent; an act; an
action; a thing done; -- a word of extensive application, including,
whatever is done, good or bad, great or small.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And Joseph said to them, What <qex>deed</qex> is this which ye
have done?</q> <rj><qau>Gen. xliv. 15.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>We receive the due reward of our <qex>deeds</qex>.</q>
<rj><qau>Luke xxiii. 41.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Would serve his kind in <qex>deed</qex> and word.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Illustrious act; achievement; exploit.</def>
<ldquo/Knightly <xex>deeds</xex>.<rdquo/ <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Whose <qex>deeds</qex> some nobler poem shall adorn.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Power of action; agency; efficiency.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>To be, both will and <qex>deed</qex>, created free.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Fact; reality; -- whence we have
<xex>indeed</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Law)</fld> <def>A sealed instrument in writing, on
paper or parchment, duly executed and delivered, containing some
transfer, bargain, or contract.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The term is generally applied to conveyances of real
estate, and it is the prevailing doctrine that a deed must be signed as
well as sealed, though at common law signing was formerly not
necessary.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Blank deed</b></col>, <cd>a printed form containing the
customary legal phraseology, with blank spaces for writing in names,
dates, boundaries, etc.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Performance; -- followed by <xex>of</xex>.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>In deed</b></col>, <cd>in fact; in truth; verily. See
<er>Indeed</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deed</ent><br/
<hw>Deed</hw>, <pos>v. t.</pos> <def>To convey or transfer by deed;
<as>as, he <ex>deeded</ex> all his estate to his eldest son</as>.</def>
<mark>[Colloq. U. S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deedful</ent><br/
<hw>Deed"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Full of deeds or
exploits; active; stirring.</def> <mark>[R.]</mark> <ldquo/A
<xex>deedful</xex> life.<rdquo/ <rj><au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deedless</ent><br/
<hw>Deed"less</hw>, <pos>a.</pos> <def>Not performing, or not having
performed, deeds or exploits; inactive.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Deedless</qex> in his tongue.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deed poll</ent><br/
<hw>Deed" poll`</hw> <pr>(?)</pr>. <fld>(Law)</fld> <def>A deed of one
part, or executed by only one party, and distinguished from an indenture
by having the edge of the parchment or paper cut even, or
<xex>polled</xex> as it was anciently termed, instead of being
indented.</def> <rj><au>Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>deeds</ent><br/
<hw>deeds</hw> <pos>n.</pos> <fld>(Religion)</fld> <def>performance of
moral or religious acts; <as>salvation is not by <ex>deeds</ex>, but by
faith; to do good <ex>deeds</ex></as>.</def><br/
<syn><b>Syn. --</b> works.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Deedy</ent><br/
<hw>Deed"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Industrious;
active.</def> <mark>[R.]</mark> <rj><au>Cowper.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deem</ent><br/
<hw>Deem</hw> <pr>(d<emac/m)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Deemed</conjf> <pr>(d<emac/md)</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>Deeming</conjf>.]</vmorph> <ety>[OE.
<ets>demen</ets> to judge, condemn, AS. <ets>d<emac/man</ets>, fr.
<ets>d<omac/m</ets> doom; akin to OFries. <ets>d<emac/ma</ets>, OS.
<ets>ad<omac/mian</ets>, D. <ets>doemen</ets>, OHG. <ets>tuommen</ets>,
Icel. <ets>d<ae/ma</ets>, Sw. <ets>d<oum/mma</ets>, Dan.
<ets>d<oum/mme</ets>, Goth. <ets>d<omac/mjan</ets>. See <er>Doom</er>,
<pos>n.</pos>, and cf. <er>Doom</er>, <pos>v.</pos>]</ety> <sn>1.</sn>
<def>To decide; to judge; to sentence; to condemn.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Claudius . . . Was <qex>demed</qex> for to hang upon a tree.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To account; to esteem; to think; to judge; to hold
in opinion; to regard.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>For never can I <qex>deem</qex> him less him less than god.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deem</ent><br/
<hw>Deem</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To be of opinion; to
think; to estimate; to opine; to suppose.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And <qex>deemest</qex> thou as those who pore,<br/
With aged eyes, short way before?</q> <rj><qau>Emerson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To pass judgment.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deem</ent><br/
<hw>Deem</hw>, <pos>n.</pos> <def>Opinion; judgment.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 380 --></p>

<p><ent>Deemster</ent><br/
<hw>Deem"ster</hw> <pr>(d<emac/m"st<etil/r)</pr>, <pos>n.</pos>
<ety>[<ets>Deem</ets> + <ets>-ster</ets>; i. e., doomster. Cf.
<er>Dempster</er>.]</ety> <def>A judge in the Isle of Man who decides
controversies without process.</def> <rj><au>Cowell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>de-energize</ent><br/
<hw>de-energize</hw> <pos>v. t.</pos> <def>to deprive of energy,
especially electrical energy; <as>the door locks were
<ex>de-energized</ex> and opened manually</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Deep</ent><br/
<hw>Deep</hw> <pr>(d<emac/p)</pr>, <pos>a.</pos>
<amorph>[<pos>Compar.</pos> <adjf>Deeper</adjf>
<pr>(d<emac/p"<etil/r)</pr>; <pos>superl.</pos> <adjf>Deepest</adjf>
<pr>(d<emac/p"<ecr/st)</pr>.]</amorph> <ety>[OE. <ets>dep</ets>,
<ets>deop</ets>, AS. <ets>de<oacute/p</ets>; akin to D. <ets>diep</ets>,
G. <ets>tief</ets>, Icel. <ets>dj<umac/pr</ets>, Sw. <ets>diup</ets>,
Dan. <ets>dyb</ets>, Goth. <ets>diups</ets>; fr. the root of E.
<ets>dip</ets>, <ets>dive</ets>. See <er>Dip</er>, <er>Dive</er>.]</ety>
<sn>1.</sn> <def>Extending far below the surface; of great perpendicular
dimension (measured from the surface downward, and distinguished from
<xex>high</xex>, which is measured upward); far to the bottom; having a
certain depth; <as>as, a <ex>deep</ex> sea</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The water where the brook is <qex>deep</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Extending far back from the front or outer part; of
great horizontal dimension (measured backward from the front or nearer
part, mouth, etc.); <as>as, a <ex>deep</ex> cave or recess or wound; a
gallery ten seats <ex>deep</ex>; a company of soldiers six files
<ex>deep</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Shadowing squadrons <qex>deep</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Safely in harbor<br/
Is the king's ship in the <qex>deep</qex> nook.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Low in situation; lying far below the general
surface; <as>as, a <ex>deep</ex> valley</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Hard to penetrate or comprehend; profound; --
opposed to <ant>shallow</ant> or <ant>superficial</ant>; intricate;
mysterious; not obvious; obscure; <as>as, a <ex>deep</ex> subject or
plot</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Speculations high or <qex>deep</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A question <qex>deep</qex> almost as the mystery of life.</q>
<rj><qau>De Quincey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>O Lord, . . . thy thoughts are very <qex>deep</qex>.</q>
<rj><qau>Ps. xcii. 5.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Of penetrating or far-reaching intellect; not
superficial; thoroughly skilled; sagacious; cunning.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Deep</qex> clerks she dumbs.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Profound; thorough; complete; unmixed; intense;
heavy; heartfelt; <as>as, <ex>deep</ex> distress; <ex>deep</ex>
melancholy; <ex>deep</ex> horror.</as></def> <ldquo/<ex>Deep</ex>
despair.<rdquo/ <au>Milton.</au> <ldquo/<ex>Deep</ex> silence.<rdquo/
<au>Milton.</au> <ldquo/<ex>Deep</ex> sleep.<rdquo/ <au>Gen. ii.
21.</au> <ldquo/<ex>Deeper</ex> darkness.<rdquo/ <au>Hoole.</au>
<ldquo/Their <ex>deep</ex> poverty.<rdquo/ <au>2 Cor. viii. 2.</au><br/
[<source>1913 Webster</source>]</p>

<p><q>An attitude of <qex>deep</qex> respect.</q>
<rj><qau>Motley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>Strongly colored; dark; intense; not light or thin;
<as>as, <ex>deep</ex> blue or crimson</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>Of low tone; full-toned; not high or sharp; grave;
heavy.</def> <ldquo/The <xex>deep</xex> thunder.<rdquo/
<rj><au>Byron.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The bass of heaven's <qex>deep</qex> organ.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>Muddy; boggy; sandy; -- said of roads.</def>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The ways in that vale were very <qex>deep</qex>.</q>
<rj><qau>Clarendon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>A deep line of operations</b></col>
<fld>(Military)</fld>, <cd>a long line.</cd> -- <col><b>Deep
mourning</b></col> <fld>(Costume)</fld>, <cd>mourning complete and
strongly marked, the garments being not only all black, but also
composed of lusterless materials and of such fashion as is identified
with mourning garments.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deep</ent><br/
<hw>Deep</hw>, <pos>adv.</pos> <def>To a great depth; with depth; far
down; profoundly; deeply.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Deep</qex>-versed in books, and shallow in himself.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Drink <qex>deep</qex>, or taste not the Pierian spring.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Deep</xex>, in its usual adverbial senses, is often
prefixed to an adjective; as, <ex>deep</ex>-chested, <ex>deep</ex>-cut,
<ex>deep</ex>-seated, <ex>deep</ex>-toned, <ex>deep</ex>-voiced,
<ldquo/<ex>deep</ex>-uddered kine.<rdquo/</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deep</ent><br/
<hw>Deep</hw>, <pos>n.</pos> <sn>1.</sn> <def>That which is deep,
especially deep water, as the sea or ocean; an abyss; a great
depth.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Courage from the <qex>deeps</qex> of knowledge springs.</q>
<rj><qau>Cowley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The hollow <qex>deep</qex> of hell resounded.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Blue Neptune storms, the bellowing <qex>deeps</qex> resound.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is profound, not easily fathomed, or
incomprehensible; a moral or spiritual depth or abyss.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thy judgments are a great <qex>deep</qex>.</q> <rj><qau>Ps. xxxvi.
6.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Deep of night</b></col>, <cd>the most quiet or profound
part of night; dead of night.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>deep of night</qex> is crept upon our talk.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deepen</ent><br/
<hw>Deep"en</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Deepened</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Deepening</conjf>.]</vmorph> <sn>1.</sn> <def>To make
deep or deeper; to increase the depth of; to sink lower; <as>as, to
<ex>deepen</ex> a well or a channel</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It would . . . <qex>deepen</qex> the bed of the Tiber.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To make darker or more intense; to darken; <as>as,
the event <ex>deepened</ex> the prevailing gloom</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>You must <qex>deepen</qex> your colors.</q>
<rj><qau>Peacham.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To make more poignant or affecting; to increase in
degree; <as>as, to <ex>deepen</ex> grief or sorrow</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To make more grave or low in tone; <as>as, to
<ex>deepen</ex> the tones of an organ</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Deepens</qex> the murmur of the falling floods.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deepen</ent><br/
<hw>Deep"en</hw>, <pos>v. i.</pos> <def>To become deeper; <as>as, the
water <ex>deepens</ex> at every cast of the lead; the plot
<ex>deepens</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>His blood-red tresses <qex>deepening</qex> in the sun.</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>deep-eyed</ent><br/
<hw>deep-eyed</hw> <pos>adj.</pos> <def>having eyes set well behind the
brow; characteristic of the bony face of a cadaver.</def><br/
<syn><b>Syn. --</b> hollow-eyed, sunken-eyed.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>deep fat</ent><br/
<hw>deep fat</hw> <pos>n.</pos> <def>Hot liquified fat used to deep-fry
food. See <er>deep-fry</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>deep-fat-fry</ent><br/
<hw>deep-fat-fry</hw> <pos>v. t.</pos> <def>To fry in deep
fat.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Deep-fet</ent><br/
<hw>Deep"-fet`</hw> <pr>(d<emac/p"f<ecr/t`)</pr>, <pos>a.</pos>
<def>Deeply fetched or drawn.</def> <mark>[Obs.]</mark>
<ldquo/<xex>Deep-fet</xex> groans.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>deep-fried</ent><br/
<hw>deep-fried</hw> <pos>adj.</pos> <def>Fried in fat or oil deep enough
to cover the object.</def><br/
<syn><b>Syn. --</b> fried.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>deep-fry</ent><br/
<hw>deep-fry</hw> <pos>v.</pos> <def>to cook by immersing in hot fat or
oil.</def><br/
<syn><b>Syn. --</b> french-fry.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Deep-laid</ent><br/
<hw>Deep"-laid`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Laid deeply;
formed with cunning and sagacity; secretly and carefully planned;
<as>as, <ex>deep-laid</ex> plans</as>.</def><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><ent>Deeply</ent><br/
<hw>Deep"ly</hw>, <pos>adv.</pos> <sn>1.</sn> <def>At or to a great
depth; far below the surface; <as>as, to sink
<ex>deeply</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Profoundly; thoroughly; not superficially; in a high
degree; intensely; <as>as, <ex>deeply</ex> skilled in
ethics</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He had <qex>deeply</qex> offended both his nobles and people.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He sighed <qex>deeply</qex> in his spirit.</q> <rj><qau>Mark viii.
12.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Very; with a tendency to darkness of
color.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>deeply</qex> red juice of buckthorn berries.</q>
<rj><qau>Boyle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Gravely; with low or deep tone; <as>as, a
<ex>deeply</ex> toned instrument</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>With profound skill; with art or intricacy; <as>as,
a <ex>deeply</ex> laid plot or intrigue</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>deep-mined</ent><br/
<hw>deep-mined</hw> <pos>adj.</pos> <def>taken from an underground mine;
-- as contrasted with coal obtained from a strip mine; <as>as,
<ex>deep-mined</ex> coal</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Deep-mouthed</ent><br/
<hw>Deep"-mouthed`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having a loud
and sonorous voice.</def> <ldquo/<xex>Deep-mouthed</xex> dogs.<rdquo/
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deepness</ent><br/
<hw>Deep"ness</hw>, <pos>n.</pos> <sn>1.</sn> <def>The state or quality
of being deep, profound, mysterious, secretive, etc.; depth; profundity;
-- opposed to <xex>shallowness</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Because they had no <qex>deepness</qex> of earth.</q>
<rj><qau>Matt. xiii. 5.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Craft; insidiousness.</def> <mark>[R.]</mark>
<rj><au>J. Gregory.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deep-read</ent><br/
<hw>Deep"-read`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Profoundly book-
learned.</def> <ldquo/Great writers and <xex>deep-read</xex> men.<rdquo/
<rj><au>L'Estrange.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>deep-rooted</ent><br/
<hw>deep-rooted</hw> <pos>adj.</pos> <def>well-established; <as>as,
<ex>deep-rooted</ex> prejudice</as>.</def><br/
<syn><b>Syn. --</b> deep-seated, fundamental, ingrained.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Deep-sea</ent><br/
<hw>Deep"-sea`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining to
the deeper parts of the sea; <as>as, a <ex>deep-sea</ex> line (<it>i.
e.</it>, a line to take soundings at a great depth); <ex>deep-sea</ex>
lead; <ex>deep-sea</ex> soundings, explorations, etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>at some distance from the shore; <as>as,
<ex>deep-sea</ex> fishing</as>.</def><br/
<syn><b>Syn. --</b> offshore.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><sn>3.</sn> <def>taking place in the deeper parts of the sea; <as>as,
<ex>deep-sea</ex> exploration</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>deep-seated</ent><br/
<hw>deep-seated</hw> <pos>adj.</pos> <def>same as
<er>deep-rooted</er>.</def><br/
<syn><b>Syn. --</b> deep-rooted, fundamental, ingrained.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>deep-set</ent><br/
<hw>deep-set</hw> <pos>adj.</pos> <def>having a sunken area.</def><br/
<syn><b>Syn. --</b> sunken, recessed.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>deep-six</ent><br/
<hw>deep-six</hw> <pos>v. t.</pos> <sn>1.</sn> <def>to discard in a deep
body of water; -- also used figuratively, to discard
contemptuously.</def><br/
<syn><b>Syn. --</b> deep six, give it the deep six.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>to throw from a boat into the water.</def><br/
<syn><b>Syn. --</b> deep six, throw overboard.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Deep-waisted</ent><br/
<hw>Deep"-waist`ed</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Naut.)</fld>
<def>Having a deep waist, as when, in a ship, the poop and forecastle
are much elevated above the deck.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>deep-water</ent><br/
<hw>deep-water</hw> <pos>adj.</pos> <sn>1.</sn> <def>having waters of
great depth; <as>as, a <ex>deep-water</ex> port</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>carried on in waters of great depth.</def><br/
<syn><b>Syn. --</b> deep-sea.</syn><br/
[<source>PJC</source>]</p>

<p><ent>Deer</ent><br/
<hw>Deer</hw> <pr>(d<emac/r)</pr>, <pos>n. sing. & pl.</pos> <ety>[OE.
<ets>der</ets>, <ets>deor</ets>, animal, wild animal, AS.
<ets>de<oacute/r</ets>; akin to D. <ets>dier</ets>, OFries.
<ets>diar</ets>, G. <ets>thier</ets>, <ets>tier</ets>, Icel.
<ets>d<ymac/r</ets>, Dan. <ets>dyr</ets>, Sw. <ets>djur</ets>, Goth.
<ets>dius</ets>; of unknown origin. <root/71.]</ety> <sn>1.</sn>
<def>Any animal; especially, a wild animal.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Mice and rats, and such small <qex>deer</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The camel, that great <qex>deer</qex>.</q> <rj><qau>Lindisfarne
MS.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>A ruminant of the genus
<gen>Cervus</gen>, of many species, and of related genera of the family
<fam>Cervid<ae/</fam>. The males, and in some species the females, have
solid antlers, often much branched, which are shed annually. Their
flesh, for which they are hunted, is called
<prod>venison</prod>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The deer hunted in England is <spn>Cervus elaphus</spn>,
called also <xex>stag</xex> or <stype>red deer</stype>; the fallow deer
is <spn>Cervus dama</spn>; the common American deer is <spn>Cervus
Virginianus</spn>; the blacktailed deer of Western North America is
<spn>Cervus Columbianus</spn>; and the mule deer of the same region is
<spn>Cervus macrotis</spn>. See <er>Axis</er>, <er>Fallow deer</er>,
<er>Mule deer</er>, <er>Reindeer</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <ex>Deer</ex> is much used adjectively, or as the first
part of a compound; <as>as, <ex>deer</ex>killer, <ex>deer</ex>slayer,
<ex>deer</ex>slaying, <ex>deer</ex> hunting, <ex>deer</ex> stealing,
<ex>deer</ex>like, etc.</as></note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Deer mouse</b></col> <fld>(Zool.)</fld>, <cd>the
white-footed mouse (<spn>Peromyscus leucopus</spn>, formerly
<spn>Hesperomys leucopus</spn>) of America.</cd> -- <col><b>Small
deer</b></col>, <cd>petty game, not worth pursuing; -- used
metaphorically. (See citation from Shakespeare under the first
definition, above.)</cd> <ldquo/Minor critics . . . can find leisure for
the chase of such <xex>small deer</xex>.<rdquo/ <rj><au>G. P.
Marsh.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deerberry</ent><br/
<hw>Deer"ber`ry</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>A shrub of the blueberry group (<spn>Vaccinium stamineum</spn>);
also, its bitter, greenish white berry; -- called also <altname>squaw
huckleberry</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deergrass</ent><br/
<hw>Deer"grass`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>An American genus (<gen>Rhexia</gen>) of perennial herbs, with
opposite leaves, and showy flowers (usually bright purple), with four
petals and eight stamens, -- the only genus of the order
<ord>Melastomace<ae/</ord> inhabiting a temperate clime.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deerhound</ent><br/
<hw>Deer"hound`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>One of a large and fleet breed of hounds used in hunting deer; a
staghound.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deerlet</ent><br/
<hw>Deer"let</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Deer</ets> +
<ets>- let</ets>.]</ety> <fld>(Zool.)</fld> <def>A chevrotain. See
<er>Kanchil</er>, and <er>Napu</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deer-neck</ent><br/
<hw>Deer"-neck`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A deerlike, or
thin, ill-formed neck, as of a horse.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>deer's-ear</ent><br/
<hw>deer's-ear</hw> <pos>n.</pos> <def>any of various tall perennial
herbs constituting the genus <gen>Frasera</gen>; it is widely
distributed in warm dry upland areas of the US Pacific states.</def><br/
<syn><b>Syn. --</b> columbo, American columbo, deer's-ears, pyramid
plant, American gentian.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Deerskin</ent><br/
<hw>Deer"skin`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The skin of a deer,
or the leather which is made from it.</def> <rj><au>Hakluyt.
Longfellow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deerstalker</ent><br/
<hw>Deer"stalk`er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One
who practices deerstalking.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A close-fitting cap, usually woolen, such as is worn
in deerstalking, having a low crown and visors both in front and back,
and having earflaps which are usually worn tied together over the top;
also called <altname>fore-and-after</altname>, <altname>deerstalker
hat</altname> and <altname>deerstalker cap</altname>; a hunter's cap;
formerly also used for any stiff, round hat.</def>
<mark>[Eng.]</mark><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><ent>Deerstalking</ent><br/
<hw>Deer"stalk`ing</hw>, <pos>n.</pos> <def>The hunting of deer on foot,
by stealing upon them unawares.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deer's-tongue</ent><br/
<hw>Deer's"-tongue`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>A plant (<spn>Liatris odoratissima</spn>) whose fleshy leaves give
out a fragrance compared to vanilla.</def> <rj><au>Wood.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>dee</ent><br/
<hw>dee</hw> <pr>(d<emac/)</pr>, <pos>n.</pos> <fld>(Physics)</fld>
<def>an electrode with a large interior cavity, shaped like the letter
"D", used in opposed pairs to accelerate particles in a
cyclotron.</def><br/
[<source>PJC</source>]</p>

<p><ent>Dees</ent><br/
<hw>Dees</hw> <pr>(d<emac/s)</pr>, <pos>n. pl.</pos> <def>Dice.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dees</ent><br/
<hw>Dees</hw>, <pos>n.</pos> <def>A dais.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>de-escalate</ent><br/
<hw>de-escalate</hw> <pos>v. t.</pos> <def>to reduce in intensity (a
crisis or a war).</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>de-escalation</ent><br/
<hw>de-escalation</hw> <pos>n.</pos> <def>a reduction in intensity (of a
crisis or a war).</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Deesis</ent><br/
\'d8<hw>De*e"sis</hw> <pr>(d<esl/*<emac/"s<icr/s)</pr>, <pos>n.</pos>
<ety>[NL., fr. Gr. <grk>de`hsis</grk> supplication.]</ety>
<fld>(Rhet.)</fld> <def>An invocation of, or address to, the Supreme
Being.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deess</ent><br/
<hw>De"ess</hw> <pr>(d<esl/"<ecr/s)</pr>, <pos>n.</pos> <ety>[F.
<ets>d<eacute/esse</ets>, fem. of <ets>dieu</ets> god.]</ety> <def>A
goddess.</def> <mark>[Obs.]</mark> <rj><au>Croft.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deev</ent><br/
\'d8<hw>Deev</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Hind. & Pers.
Myth.)</fld> <def>See <er>Dev</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deface</ent><br/
<hw>De*face"</hw> <pr>(d<esl/*f<amac/s")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Defaced</conjf>
<pr>(d<esl/*f<amac/st")</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Defacing</conjf>.]</vmorph> <ety>[OE. <ets>defacen</ets> to
disfigure, efface, OF. <ets>desfacier</ets>; L. <ets>dis-</ets> +
<ets>facies</ets> face. See <er>Face</er>, and cf.
<er>Efface</er>.]</ety> <sn>1.</sn> <def>To destroy or mar the face or
external appearance of; to disfigure; to injure, spoil, or mar, by
effacing or obliterating important features or portions of; <as>as, to
<ex>deface</ex> a monument; to <ex>deface</ex> an edifice; to
<ex>deface</ex> writing; to <ex>deface</ex> a note, deed, or bond; to
<ex>deface</ex> a record.</as></def> <ldquo/This high face
<xex>defaced</xex>.<rdquo/ <rj><au>Emerson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>So by false learning is good sense <qex>defaced</qex>.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <ety>[Cf. F. <ets>d<eacute/faire</ets>.]</ety> <def>To
destroy; to make null.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>[Profane scoffing] doth . . . <qex>deface</qex> the reverence of
religion.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>For all his power was utterly <qex>defaste</qex>
[<qex>defaced</qex>].</q> <rj><qau>Spenser.</qau></rj></p>

<p><syn><b>Syn.</b> -- See <er>Efface</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>defaced</ent><br/
<hw>defaced</hw> <pos>adj.</pos> <def>having the external appearance
impaired, usually deliberately.</def><br/
<syn><b>Syn. --</b> marred.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Defacement</ent><br/
<hw>De*face"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
act of defacing, or the condition of being defaced; injury to the
surface or exterior; obliteration.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which mars or disfigures.</def>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defacer</ent><br/
<hw>De*fa"cer</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, defaces or disfigures.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>De facto</ent><br/
\'d8<hw>De` fac"to</hw> <pr>(?)</pr>. <ety>[L.]</ety> <def>Actually; in
fact; in reality; <as>as, a king <ex>de facto</ex>, -- distinguished
from a king <ex>de jure</ex>, or by right</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defail</ent><br/
<hw>De*fail"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[F.
<ets>d<eacute/faillir</ets> to fail; pref. <ets>d<eacute/-</ets> (L.
<ets>de</ets>) + <ets>faillir</ets>. See <er>Fail</er>, and cf.
<er>Default</er>.]</ety> <def>To cause to fail.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defailance</ent><br/
<hw>De*fail"ance</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>d<eacute/faillance</ets>.]</ety> <def>Failure; miscarriage.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Possibility of <qex>defailance</qex> in degree or continuance.</q>
<rj><qau>Comber.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defailure</ent><br/
<hw>De*fail"ure</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Failure.</def>
<mark>[Obs.]</mark> <rj><au>Barrow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defalcate</ent><br/
<hw>De*fal"cate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Defalcated</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Defalcating</conjf>.]</vmorph> <ety>[LL. <ets>defalcatus</ets>,
p. p. of <ets>defalcare</ets> to deduct, orig., to cut off with a
sickle; L. <ets>de-</ets> + <ets>falx</ets>, <ets>falcis</ets>, a
sickle. See <er>Falchion</er>.]</ety> <def>To cut off; to take away or
deduct a part of; -- used chiefly of money, accounts, rents, income,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To show what may be practicably and safely <qex>defalcated</qex>
from them [the estimates].</q> <rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defalcate</ent><br/
<hw>De*fal"cate</hw>, <pos>v. i.</pos> <def>To commit defalcation; to
embezzle money held in trust.</def> <ldquo/Some partner
<xex>defalcating</xex>, or the like.<rdquo/
<rj><au>Carlyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defalcation</ent><br/
<hw>De`fal*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL.
<ets>defalcatio</ets>: cf. F. <ets>d<eacute/falcation</ets>.]</ety>
<sn>1.</sn> <def>A lopping off; a diminution; abatement; deficit.
Specifically: Reduction of a claim by deducting a counterclaim; set-
off.</def> <rj><au>Abbott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is lopped off, diminished, or
abated.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>An abstraction of money, etc., by an officer or
agent having it in trust; an embezzlement.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defalcator</ent><br/
<hw>Def"al*ca`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A defaulter or
embezzler.</def> <mark>[Modern]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defalk</ent><br/
<hw>De*falk"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[F.
<ets>d<eacute/falquer</ets>. See <er>Defalcate</er>.]</ety> <def>To lop
off; to abate.</def> <mark>[Obs.]</mark> <rj><au>B.
Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defamation</ent><br/
<hw>Def`a*ma"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>diffamacioun</ets>, F. <ets>diffamation</ets>. See
<er>Defame</er>.]</ety> <def>Act of injuring another's reputation by any
slanderous communication, written or oral; the wrong of maliciously
injuring the good name of another; slander; detraction; calumny;
aspersion.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In modern usage, written defamation bears the title of
<xex>libel</xex>, and oral defamation that of <xex>slander</xex>.</note>
<rj><au>Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defamatory</ent><br/
<hw>De*fam"a*to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Containing
defamation; injurious to reputation; calumnious; slanderous; <as>as,
<ex>defamatory</ex> words; <ex>defamatory</ex> writings.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defame</ent><br/
<hw>De*fame"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Defamed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Defaming</conjf>.]</vmorph> <ety>[OE. <ets>defamen</ets>,
<ets>diffamen</ets>, from F. <ets>diffamer</ets>, or OF. perh.
<ets>defamer</ets>, fr. L. <ets>diffamare</ets> (cf.
<ets>defamatus</ets> infamous); <ets>dis-</ets> (in this word confused
with <ets>de</ets>) + <ets>fama</ets> a report. See
<er>Fame</er>.]</ety> <sn>1.</sn> <def>To harm or destroy the good fame
or reputation of; to disgrace; especially, to speak evil of maliciously;
to dishonor by slanderous reports; to calumniate; to asperse.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To render infamous; to bring into
disrepute.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>My guilt thy growing virtues did <qex>defame</qex>;<br/
My blackness blotted thy unblemish'd name.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To charge; to accuse.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Rebecca is . . . <qex>defamed</qex> of sorcery practiced on the
person of a noble knight.</q> <rj><qau>Sir W. Scott.</qau></rj></p>

<p><syn><b>Syn.</b> -- To asperse; slander; calumniate; vilify. See
<er>Asperse</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defame</ent><br/
<hw>De*fame"</hw>, <pos>n.</pos> <def>Dishonor.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defamer</ent><br/
<hw>De*fam"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who defames; a
slanderer; a detractor; a calumniator.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defamingly</ent><br/
<hw>De*fam"ing*ly</hw>, <pos>adv.</pos> <def>In a defamatory
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defamous</ent><br/
<hw>Def"a*mous</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Defamatory.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defatigable</ent><br/
<hw>De*fat"i*ga*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Defatigate</er>.]</ety> <def>Capable of being wearied or tired
out.</def> <mark>[R.]</mark> <rj><au>Glanvill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defatigate</ent><br/
<hw>De*fat"i*gate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>defatigatus</ets>, p. p. of <ets>defatigare</ets>; <ets>de-</ets> +
<ets>fatigare</ets> to weary. See <er>Fatigue</er>.]</ety> <def>To weary
or tire out; to fatigue.</def> <mark>[R.]</mark> <rj><au>Sir T.
Herbert.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defatigation</ent><br/
<hw>De*fat`i*ga"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>defatigatio</ets>.]</ety> <def>Weariness; fatigue.</def>
<mark>[R.]</mark> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Default</ent><br/
<hw>De*fault"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>defaute</ets>, OF. <ets>defaute</ets>, <ets>defalte</ets>, fem., F.
<ets>d<eacute/faut</ets>, masc., LL. <ets>defalta</ets>, fr. a verb
meaning, to be deficient, to want, fail, fr. L. <ets>de-</ets> +
<ets>fallere</ets> to deceive. See <er>Fault</er>.]</ety> <sn>1.</sn>
<def>A failing or failure; omission of that which ought to be done;
neglect to do what duty or law requires; <as>as, this evil has happened
through the governor's <ex>default</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Fault; offense; ill deed; wrong act; failure in
virtue or wisdom.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And pardon craved for his so rash <qex>default</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Regardless of our merit or <qex>default</qex>.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Law)</fld> <def>A neglect of, or failure to take,
some step necessary to secure the benefit of law, as a failure to appear
in court at a day assigned, especially of the defendant in a suit when
called to make answer; also of jurors, witnesses, etc.</def><br/
[<source>1913 Webster</source>]</p>

<cs><p><col><b>In default of</b></col>, <cd>in case of failure or lack
of.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>Cooks could make artificial birds and fishes <qex>in default
of</qex> the real ones.</q> <rj><qau>Arbuthnot.</qau></rj></p>

<p>-- <col><b>To suffer a default</b></col> <fld>(Law)</fld>, <cd>to
permit an action to be called without appearing to answer.</cd><br/
[<source>1913 Webster</source>]</p></cs>

<p><ent>Default</ent><br/
<hw>De*fault"</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Defaulted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Defaulting</conjf>.]</vmorph> <sn>1.</sn> <def>To fail in duty;
to offend.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That he gainst courtesy so foully did <qex>default</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To fail in fulfilling a contract, agreement, or
duty.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To fail to appear in court; to let a case go by
default.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Default</ent><br/
<hw>De*fault"</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To fail to perform
or pay; to be guilty of neglect of; to omit; <as>as, to <ex>default</ex>
a dividend</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>What they have <qex>defaulted</qex> towards him as no king.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>To call a defendant or other party
whose duty it is to be present in court, and make entry of his default,
if he fails to appear; to enter a default against.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To leave out of account; to omit.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Defaulting</qex> unnecessary and partial discourses.</q>
<rj><qau>Hales.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defaulter</ent><br/
<hw>De*fault"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One
who makes default; one who fails to appear in court when court when
called.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who fails to perform a duty; a delinquent;
particularly, one who fails to account for public money intrusted to his
care; a peculator; a defalcator.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defeasance</ent><br/
<hw>De*fea"sance</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>defesance</ets>, fr. <ets>defesant</ets>, F.
<ets>d<eacute/faisant</ets>, p. pr. of <ets>defaire</ets>, F.
<ets>d<eacute/faire</ets>, to undo. See <er>Defeat</er>.]</ety>
<sn>1.</sn> <def>A defeat; an overthrow.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>After his foes' <qex>defeasance</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A rendering null or void.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Law)</fld> <def>A condition, relating to a deed,
which being performed, the deed is defeated or rendered void; or a
collateral deed, made at the same time with a feoffment, or other
conveyance, containing conditions, on the performance of which the
estate then created may be defeated.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 381 --></p>

<p><note><hand/ Mortgages were usually made in this manner in former
times, but the modern practice is to include the conveyance and the
defeasance in the same deed.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defeasanced</ent><br/
<hw>De*fea"sanced</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Law)</fld>
<def>Liable to defeasance; capable of being made void or
forfeited.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defeasible</ent><br/
<hw>De*fea"si*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Defeasance</er>.]</ety> <def>Capable of being annulled or made void;
<as>as, a <ex>defeasible</ex> title</as>.</def> --
<wordforms><wf>De*fea"si*ble*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defeat</ent><br/
<hw>De*feat"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Defeated</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Defeating</conjf>.]</vmorph> <ety>[From F.
<ets>d<eacute/fait</ets>, OF. <ets>desfait</ets>, p. p. ofe
<ets>d<eacute/faire</ets>, OF. <ets>desfaire</ets>, to undo; L.
<ets>dis-</ets> + <ets>facere</ets> to do. See <er>Feat</er>,
<er>Fact</er>, and cf. <er>Disfashion</er>.]</ety> <sn>1.</sn> <def>To
undo; to disfigure; to destroy.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>His unkindness may <qex>defeat</qex> my life.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To render null and void, as a title; to frustrate,
as hope; to deprive, as of an estate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He finds himself naturally to dread a superior Being that can
<qex>defeat</qex> all his designs, and disappoint all his hopes.</q>
<rj><qau>Tillotson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The escheators . . . <qex>defeated</qex> the right heir of his
succession.</q> <rj><qau>Hallam.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>In one instance he <qex>defeated</qex> his own purpose.</q>
<rj><qau>A. W. Ward.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To overcome or vanquish, as an army; to check,
disperse, or ruin by victory; to overthrow.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To resist with success; <as>as, to <ex>defeat</ex>
an assault</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Sharp reasons to <qex>defeat</qex> the law.</q>
<rj><qau>Shak.</qau></rj></p>

<p><syn><b>Syn.</b> -- To baffle; disappoint; frustrate.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defeat</ent><br/
<hw>De*feat"</hw>, <pos>n.</pos> <ety>[Cf. F. <ets>d<eacute/faite</ets>,
fr. <ets>d<eacute/faire</ets>. See <er>Defeat</er>, <pos>v.</pos>]</ety>
<sn>1.</sn> <def>An undoing or annulling; destruction.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Upon whose property and most dear life<br/
A damned <qex>defeat</qex> was made.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Frustration by rendering null and void, or by
prevention of success; <as>as, the <ex>defeat</ex> of a plan or
design</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>An overthrow, as of an army in battle; loss of a
battle; repulse suffered; discomfiture; -- opposed to
<ant>victory</ant>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>defeatism</ent><br/
<hw>defeatism</hw> <pos>n.</pos> <def>acceptance of the inevitability of
defeat.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Defeature</ent><br/
<hw>De*fea"ture</hw> <pr>(?; 135)</pr>, <pos>n.</pos> <ety>[OF.
<ets>desfaiture</ets> a killing, disguising, prop., an undoing. See
<er>Defeat</er>, and cf. <er>Disfeature</er>.]</ety> <sn>1.</sn>
<def>Overthrow; defeat.</def> <mark>[Obs.]</mark> <ldquo/Nothing but
loss in their <xex>defeature</xex>.<rdquo/ <rj><au>Beau. &
Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Disfigurement; deformity.</def> <mark>[Obs.]</mark>
<ldquo/Strange <xex>defeatures</xex> in my face.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defeatured</ent><br/
<hw>De*fea"tured</hw> <pr>(?; 135)</pr>, <pos>p. p.</pos> <def>Changed
in features; deformed.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Features when <qex>defeatured</qex> in the . . . way I have
described.</q> <rj><qau>De Quincey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defecate</ent><br/
<hw>Def"e*cate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>defaecatus</ets>, p. p. of <ets>defaecare</ets> to defecate;
<ets>de-</ets> + <ets>faex</ets>, <ets>faecis</ets>, dregs, lees.]</ety>
<def>Freed from anything that can pollute, as dregs, lees, etc.;
refined; purified.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Till the soul be <qex>defecate</qex> from the dregs of sense.</q>
<rj><qau>Bates.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defecate</ent><br/
<hw>Def"e*cate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Defecated</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Defecating</conjf>.]</vmorph> <sn>1.</sn> <def>To clear from
impurities, as lees, dregs, etc.; to clarify; to purify; to
refine.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>defecate</qex> the dark and muddy oil of amber.</q>
<rj><qau>Boyle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To free from extraneous or polluting matter; to
clear; to purify, as from that which materializes.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We <qex>defecate</qex> the notion from materiality.</q>
<rj><qau>Glanvill.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Defecated</qex> from all the impurities of sense.</q>
<rj><qau>Bp. Warburton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defecate</ent><br/
<hw>Def"e*cate</hw> <pr>(?)</pr>, <pos>v. i.</pos> <sn>1.</sn> <def>To
become clear, pure, or free.</def> <rj><au>Goldsmith.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To void excrement.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defecation</ent><br/
<hw>Def`e*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>defaecatio</ets>: cf. F.
<ets>d<eacute/f<eacute/cation</ets>.]</ety> <sn>1.</sn> <def>The act of
separating from impurities, as lees or dregs; purification.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Physiol.)</fld> <def>The act or process of voiding
excrement.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defecator</ent><br/
<hw>Def"e*ca`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <def>That which
cleanses or purifies; esp., an apparatus for removing the feculencies of
juices and sirups.</def> <rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defect</ent><br/
<hw>De*fect"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>defectus</ets>, fr. <ets>deficere</ets>, <ets>defectum</ets>, to
desert, fail, be wanting; <ets>de-</ets> + <ets>facere</ets> to make,
do. See <er>Fact</er>, <er>Feat</er>, and cf. <er>Deficit</er>.]</ety>
<sn>1.</sn> <def>Want or absence of something necessary for completeness
or perfection; deficiency; -- opposed to
<xex>superfluity</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Errors have been corrected, and <qex>defects</qex> supplied.</q>
<rj><qau>Davies.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Failing; fault; imperfection, whether physical or
moral; blemish; <as>as, a <ex>defect</ex> in the ear or eye; a
<ex>defect</ex> in timber or iron; a <ex>defect</ex> of memory or
judgment.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Trust not yourself; but, your <qex>defects</qex> to know,<br/
Make use of every friend -- and every foe.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Among boys little tenderness is shown to personal
<qex>defects</qex>.</q> <rj><qau>Macaulay.</qau></rj></p>

<p><syn><b>Syn.</b> -- Deficiency; imperfection; blemish. See
<er>Fault</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defect</ent><br/
<hw>De*fect"</hw>, <pos>v. i.</pos> <def>To fail; to become
deficient.</def> <mark>[Obs.]</mark> <ldquo/<xex>Defected</xex>
honor.<rdquo/ <rj><au>Warner.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>to abandon one country or faction, and join
another.</def><br/
[<source>PJC</source>]</p>

<p><ent>Defect</ent><br/
<hw>De*fect"</hw>, <pos>v. t.</pos> <def>To injure; to damage.</def>
<ldquo/None can my life <xex>defect</xex>.<rdquo/ <mark>[R.]</mark>
<rj><au>Troubles of Q. Elizabeth (1639).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defectibility</ent><br/
<hw>De*fect`i*bil"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Deficiency;
imperfection.</def> <mark>[R.]</mark> <rj><au>Ld. Digby. Jer.
Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defectible</ent><br/
<hw>De*fect"i*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Liable to
defect; imperfect.</def> <mark>[R.]</mark> <ldquo/A
<xex>defectible</xex> understanding.<rdquo/ <rj><au>Jer.
Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defection</ent><br/
<hw>De*fec"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>defectio</ets>: cf. F. <ets>d<eacute/fection</ets>. See
<er>Defect</er>.]</ety> <def>Act of abandoning a person or cause to
which one is bound by allegiance or duty, or to which one has attached
himself; desertion; failure in duty; a falling away; apostasy;
backsliding.</def> <ldquo/<xex>Defection</xex> and falling away from
God.<rdquo/ <rj><au>Sir W. Raleigh.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The general <qex>defection</qex> of the whole realm.</q>
<rj><qau>Sir J. Davies.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defectionist</ent><br/
<hw>De*fec"tion*ist</hw>, <pos>n.</pos> <def>One who advocates or
encourages defection.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defectious</ent><br/
<hw>De*fec"tious</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having defects;
imperfect.</def> <mark>[Obs.]</mark> <ldquo/Some one
<xex>defectious</xex> piece.<rdquo/ <rj><au>Sir P. Sidney.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defective</ent><br/
<hw>De*fect"ive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>defectivus</ets>: cf. F. <ets>d<eacute/fectif</ets>. See
<er>Defect</er>.]</ety> <sn>1.</sn> <def>Wanting in something;
incomplete; lacking a part; deficient; imperfect; faulty; -- applied
either to natural or moral qualities; <as>as, a <ex>defective</ex> limb;
<ex>defective</ex> timber; a <ex>defective</ex> copy or account; a
<ex>defective</ex> character; <ex>defective</ex> rules.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Gram.)</fld> <def>Lacking some of the usual forms
of declension or conjugation; <as>as, a <ex>defective</ex> noun or
verb</as>.</def> -- <wordforms><wf>De*fect"ive*ly</wf>, <pos>adv.</pos>
-- <wf>De*fect"ive*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defective</ent><br/
<hw>De*fect"ive</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>Anything that is defective or lacking in some respect.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <fld>(Med.)</fld> <def>One who is lacking physically or
mentally.</def></p>

<p><note><hand/ Under the term <xex>defectives</xex> are included
deaf-mutes, the blind, the feeble-minded, the insane, and sometimes,
esp. in criminology, criminals and paupers.</note><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Defectuosity</ent><br/
<hw>De*fec`tu*os"i*ty</hw> <pr>(?; 135)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>d<eacute/fectuosit<eacute/</ets>.]</ety> <def>Great
imperfection.</def> <mark>[Obs.]</mark> <rj><au>W.
Montagu.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defectuous</ent><br/
<hw>De*fec"tu*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>d<eacute/fectueux</ets>.]</ety> <def>Full of defects;
imperfect.</def> <mark>[Obs.]</mark> <rj><au>Barrow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defedation</ent><br/
<hw>Def`e*da"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>defoedare</ets>, <ets>defoedatum</ets>, to defile; <ets>de-</ets> +
<ets>foedare</ets> to foul, <ets>foedus</ets> foul.]</ety> <def>The act
of making foul; pollution.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defence</ent><br/
<hw>De*fence"</hw> <pr>(d<esl/*f<ecr/ns")</pr>, <pos>n. & v. t.</pos>
<def>See <er>Defense</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>defenceless</ent><br/
<hw>defenceless</hw> <pos>adj.</pos> <def>same as <er>defenseless</er>;
<as>as, a <ex>defenceless</ex> child</as>.</def><br/
<syn><b>Syn. --</b> defenseless, helpless.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Defend</ent><br/
<hw>De*fend"</hw> <pr>(d<esl/*f<ecr/nd")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Defended</conjf>; <pos>p. pr. &
vb. n.</pos> <conjf>Defending</conjf>.]</vmorph> <ety>[F.
<ets>d<eacute/fendre</ets>, L. <ets>defendere</ets>; <ets>de-</ets> +
<ets>fendere</ets> (only in comp.) to strike; perh. akin to Gr.
<grk>qei`nein</grk> to strike, and E. <ets>dint</ets>. Cf.
<er>Dint</er>, <er>Defense</er>, <er>Fend</er>.]</ety> <sn>1.</sn>
<def>To ward or fend off; to drive back or away; to repel.</def>
<mark>[A Latinism & Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Th' other strove for to <qex>defend</qex><br/
The force of Vulcan with his might and main.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To prohibit; to forbid.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Which God <qex>defend</qex> that I should wring from him.</q>
<rj><qau>Shak.</qau></rj></p>

<p><sn>3.</sn> <def>To repel danger or harm from; to protect; to secure
against attack; to maintain against force or argument; to uphold; to
guard; <as>as, to <ex>defend</ex> a town; to <ex>defend</ex> a cause; to
<ex>defend</ex> character; to <ex>defend</ex> the absent</as>; --
sometimes followed by <xex>from</xex> or <xex>against</xex>; <as>as, to
<ex>defend</ex> one's self <xex>from</xex>, or <xex>against</xex>, one's
enemies</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The lord mayor craves aid . . . to <qex>defend</qex> the city.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>God <qex>defend</qex> the right!</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A village near it was <qex>defended</qex> by the river.</q>
<rj><qau>Clarendon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Law.)</fld> <def>To deny the right of the plaintiff
in regard to (the suit, or the wrong charged); to oppose or resist, as a
claim at law; to contest, as a suit.</def>
<rj><au>Burrill.</au></rj></p>

<p><syn><b>Syn.</b> -- To <er>Defend</er>, <er>Protect</er>.</syn>
<usage> To <xex>defend</xex> is literally to ward off; to
<xex>protect</xex> is to cover so as to secure against approaching
danger. We <xex>defend</xex> those who are attacked; we
<xex>protect</xex> those who are liable to injury or invasion. A
fortress is <xex>defended</xex> by its guns, and <xex>protected</xex> by
its wall.</usage><br/
[<source>1913 Webster</source>]</p>

<p><q>As birds flying, so will the Lord of hosts <qex>defend</qex>
Jerusalem; <qex>defending</qex> also he will deliver it.</q>
<rj><qau>Is. xxxi. 5.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Leave not the faithful side<br/
That gave thee being, still shades thee and <qex>protects</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defendable</ent><br/
<hw>De*fend"a*ble</hw> <pr>(d<esl/*f<ecr/nd"<adot/*b'l)</pr>,
<pos>a.</pos> <ety>[Cf. F. <ets>d<eacute/fendable</ets>.]</ety>
<def>Capable of being defended; defensible.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defendant</ent><br/
<hw>De*fend"ant</hw> <pr>(d<esl/*f<ecr/nd"<ait/nt)</pr>, <pos>a.</pos>
<ety>[F. <ets>d<eacute/fendant</ets>, p. pr. of
<ets>d<eacute/fendre</ets>. See <er>Defend</er>.]</ety> <sn>1.</sn>
<def>Serving, or suitable, for defense; defensive.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>With men of courage and with means <qex>defendant</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Making defense.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defendant</ent><br/
<hw>De*fend"ant</hw>, <pos>n.</pos> <sn>1.</sn> <def>One who defends; a
defender.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The rampiers and ditches which the <qex>defendants</qex> had cast
up.</q> <rj><qau>Spotswood.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>A person required to make answer in
an action or suit; -- opposed to <xex>plaintiff</xex>.</def>
<rj><au>Abbott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The term is applied to any party of whom a demand is
made in court, whether the party denies and defends the claim, or admits
it, and suffers a default; also to a party charged with a criminal
offense.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defendee</ent><br/
<hw>De`fen*dee"</hw> <pr>(d<esl/`f<ecr/n*d<emac/" <it>or</it>
d<esl/*f<ecr/nd"<emac/`)</pr>, <pos>n.</pos> <def>One who is
defended.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defender</ent><br/
<hw>De*fend"er</hw> <pr>(d<esl/*f<ecr/nd"<etil/r)</pr>, <pos>n.</pos>
<ety>[Cf. <er>Fender</er>.]</ety> <def>One who defends; one who
maintains, supports, protects, or vindicates; a champion; an advocate; a
vindicator.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Provinces . . . left without their ancient and puissant
<qex>defenders</qex>.</q> <rj><qau>Motley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defendress</ent><br/
<hw>De*fend"ress</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A female
defender.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Defendress</qex> of the faith.</q>
<rj><qau>Stow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>defenestrate</ent><br/
<hw>de*fen"es*trate</hw> <pr>(d<esl/*f<ecr/n"<ecr/s*tr<amac/t)</pr>,
<pos>v. t.</pos> <def>to throw (something or someone) out of a
window.</def><br/
[<source>PJC</source>]</p>

<p><ent>defenestration</ent><br/
<hw>de*fen`es*tra"tion</hw>
<pr>(d<esl/*f<ecr/n`<ecr/s*tr<amac/"sh<ucr/n)</pr>, <pos>n.</pos>
<def>the act of throwing (something or someone) out of a
window.</def><br/
[<source>PJC</source>]</p>

<p><ent>defensative</ent><br/
<hw>de*fen"sa*tive</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>defensare</ets>, <ets>defensatum</ets>, to defend diligently,
intens. of <ets>defendere</ets>. See <er>Defend</er>.]</ety> <def>That
which serves to protect or defend.</def></p>

<p><ent>Defence</ent><br/
<ent>Defense</ent><br/
<mhw>{ <hw>De*fense"</hw>, <hw>De*fence"</hw> }</mhw> <pr>(?)</pr>,
<pos>n.</pos> <ety>[F. <ets>d<eacute/fense</ets>, OF.
<ets>defense</ets>, fem., <ets>defens</ets>, masc., fr. L.
<ets>defensa</ets> (cf. LL. <ets>defensum</ets>), from
<ets>defendere</ets>. See <er>Defend</er>, and cf.
<er>Fence</er>.]</ety> <sn>1.</sn> <def>The act of defending, or the
state of being defended; protection, as from violence or
danger.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In cases of <qex>defense</qex> 't is best to weigh<br/
The enemy more mighty than he seems.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which defends or protects; anything employed to
oppose attack, ward off violence or danger, or maintain security; a
guard; a protection.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>War would arise in <qex>defense</qex> of the right.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>God, the widow's champion and <qex>defense</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Protecting plea; vindication;
justification.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Men, brethren, and fathers, hear ye my <qex>defense</qex>.</q>
<rj><qau>Acts xxii. 1.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Law)</fld> <def>The defendant's answer or plea; an
opposing or denial of the truth or validity of the plaintiff's or
prosecutor's case; the method of proceeding adopted by the defendant to
protect himself against the plaintiff's action.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Act or skill in making defense; defensive plan or
policy; practice in self defense, as in fencing, boxing, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A man of great <qex>defense</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>By how much <qex>defense</qex> is better than no skill.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Prohibition; a prohibitory ordinance.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Severe <qex>defenses</qex> . . . against wearing any linen under a
certain breadth.</q> <rj><qau>Sir W. Temple.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defense</ent><br/
<hw>De*fense"</hw>, <pos>v. t.</pos> <def>To furnish with defenses; to
fortify.</def> <mark>[Obs.]</mark> <altsp>[Written also
<asp>defence</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><q>Better manned and more strongly <qex>defensed</qex>.</q>
<rj><qau>Hales.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defenseless</ent><br/
<hw>De*fense"less</hw>, <pos>a.</pos> <def>Destitute of defense;
unprepared to resist attack; unable to oppose; unprotected.</def>
<altsp>[Also spelled <asp>defenceless</asp>.]</altsp>--
<wordforms><wf>De*fense"less*ly</wf>, <pos>adv.</pos> --
<wf>De*fense"less*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>unarmed; used of persons or the military.</def>
<ant>armed</ant><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Defenser</ent><br/
<hw>De*fens"er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>d<eacute/fenseur</ets>, L. <ets>defensor</ets>. Cf.
<er>Defensor</er>.]</ety> <def>Defender.</def> <mark>[Obs.]</mark>
<rj><au>Foxe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defensibility</ent><br/
<hw>De*fen`si*bil"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Capability
of being defended.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defensible</ent><br/
<hw>De*fen"si*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>d<eacute/fensable</ets>, LL. <ets>defensabilis</ets>,
<ets>defensibilis</ets>. See <er>Defense</er>, and cf.
<er>Defendable</er>.]</ety> <sn>1.</sn> <def>Capable of being defended;
<as>as, a <ex>defensible</ex> city, or a <ex>defensible</ex>
cause</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Capable of offering defense.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defensibleness</ent><br/
<hw>De*fen"si*ble*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Capability
of being defended; defensibility.</def> <rj><au>Priestley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defensive</ent><br/
<hw>De*fen"sive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>d<eacute/fensif</ets>.]</ety> <sn>1.</sn> <def>Serving to defend or
protect; proper for defense; opposed to <xex>offensive</xex>; <as>as,
<ex>defensive</ex> armor</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A moat <qex>defensive</qex> to a house.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Carried on by resisting attack or aggression; --
opposed to <xex>offensive</xex>; <as>as, <ex>defensive</ex>
war</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>In a state or posture of defense.</def>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defensive</ent><br/
<hw>De*fen"sive</hw>, <pos>n.</pos> <def>That which defends; a
safeguard.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Wars preventive, upon just fears, are true
<qex>defensives</qex>.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>To be on the defensive</b></col>, <col><b>To stand
on the defensive</b></col></mcol>, <cd>to be or stand in a state or
posture of defense or resistance, in opposition to aggression or
attack.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defensively</ent><br/
<hw>De*fen"sive*ly</hw>, <pos>adv.</pos> <def>On the
defensive.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defensor</ent><br/
<hw>De*fen"sor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. See
<er>Defenser</er>.]</ety> <sn>1.</sn> <def>A defender.</def>
<rj><au>Fabyan.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>A defender or an advocate in court;
a guardian or protector.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Eccl.)</fld> <def>The patron of a church; an
officer having charge of the temporal affairs of a church.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defensory</ent><br/
<hw>De*fen"so*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>defensorius</ets>.]</ety> <def>Tending to defend; defensive;
<as>as, <ex>defensory</ex> preparations</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defer</ent><br/
<hw>De*fer"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Deferred</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Deferring</conjf>.]</vmorph> <ety>[OE.
<ets>differren</ets>, F. <ets>diff<eacute/rer</ets>, fr. L.
<ets>differre</ets> to delay, bear different ways; <ets>dis-</ets> +
<ets>ferre</ets> to bear. See <er>Bear</er> to support, and cf.
<er>Differ</er>, <er>Defer</er> to offer.]</ety> <def>To put off; to
postpone to a future time; to delay the execution of; to delay; to
withhold.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Defer</qex> the spoil of the city until night.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>God . . . will not long <qex>defer</qex><br/
To vindicate the glory of his name.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defer</ent><br/
<hw>De*fer"</hw>, <pos>v. i.</pos> <def>To put off; to delay to act; to
wait.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Pius was able to <qex>defer</qex> and temporize at leisure.</q>
<rj><qau>J. A. Symonds.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defer</ent><br/
<hw>De*fer"</hw>, <pos>v. t.</pos> <ety>[F.
<ets>d<eacute/f<eacute/rer</ets> to pay deference, to yield, to bring
before a judge, fr. L. <ets>deferre</ets> to bring down; <ets>de-</ets>
+ <ets>ferre</ets> to bear. See <er>Bear</er> to support, and cf.
<er>Defer</er> to delay, <er>Delate</er>.]</ety> <sn>1.</sn> <def>To
render or offer.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Worship <qex>deferred</qex> to the Virgin.</q>
<rj><qau>Brevint.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To lay before; to submit in a respectful manner; to
refer; -- with <xex>to</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Hereupon the commissioners . . . <qex>deferred</qex> the matter to
the Earl of Northumberland.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defer</ent><br/
<hw>De*fer"</hw>, <pos>v. i.</pos> <def>To yield deference to the wishes
of another; to submit to the opinion of another, or to authority; --
with <xex>to</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The house, <qex>deferring</qex> to legal right, acquiesced.</q>
<rj><qau>Bancroft.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deference</ent><br/
<hw>Def"er*ence</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>d<eacute/f<eacute/rence</ets>. See 3d <er>Defer</er>.]</ety> <def>A
yielding of judgment or preference from respect to the wishes or opinion
of another; submission in opinion; regard; respect;
complaisance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Deference</qex> to the authority of thoughtful and sagacious
men.</q> <rj><qau>Whewell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Deference</qex> is the most complicate, the most indirect,
and the most elegant of all compliments.</q>
<rj><qau>Shenstone.</qau></rj></p>

<p><syn><b>Syn.</b> -- <er>Deference</er>, <er>Reverence</er>,
<er>Respect</er>.</syn> <usage> <xex>Deference</xex> marks an
inclination to yield one's opinion, and to acquiesce in the sentiments
of another in preference to one's own. <xex>Respect</xex> marks the
estimation that we have for another, which makes us look to him as
worthy of high confidence for the qualities of his mind and heart.
<xex>Reverence</xex> denotes a mingling of fear with a high degree of
respect and esteem. Age, rank, dignity, and personal merit call for
<xex>deference</xex>; <xex>respect</xex> should be paid to the wise and
good; <xex>reverence</xex> is due to God, to the authors of our being,
and to the sanctity of the laws.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deferent</ent><br/
<hw>Def"er*ent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>deferens</ets>, p. pr. of <ets>deferre</ets>. See 3d
<er>Defer</er>.]</ety> <def>Serving to carry; bearing.</def>
<mark>[R.]</mark> <ldquo/Bodies <xex>deferent</xex>.<rdquo/
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deferent</ent><br/
<hw>Def"er*ent</hw>, <pos>n.</pos> <sn>1.</sn> <def>That which carries
or conveys.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Though air be the most favorable <qex>deferent</qex> of
sounds.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Ptolemaic Astron.)</fld> <def>An imaginary circle
surrounding the earth, in whose periphery either the heavenly body or
the center of the heavenly body's epicycle was supposed to be carried
round.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deferential</ent><br/
<hw>Def`er*en"tial</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Deference</er>.]</ety> <def>Expressing deference; accustomed to
defer.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deferentially</ent><br/
<hw>Def`er*en"tial*ly</hw>, <pos>adv.</pos> <def>With
deference.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deferment</ent><br/
<hw>De*fer"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See 1st
<er>Defer</er>.]</ety> <def>The act of delaying; postponement.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>My grief, joined with the instant business,<br/
Begs a <qex>deferment</qex>.</q> <rj><qau>Suckling.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deferrer</ent><br/
<hw>De*fer"rer</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who defers or
puts off.</def></p>

<p><ent>Defervescency</ent><br/
<ent>Defervescence</ent><br/
<mhw>{ <hw>De`fer*ves"cence</hw> <pr>(?)</pr>, <hw>De`fer*ves"cency</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[L. <ets>defervescere</ets> to
grow cool.]</ety> <sn>1.</sn> <def>A subsiding from a state of
ebullition; loss of heat; lukewarmness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>defervescency</qex> in holy actions.</q> <rj><qau>Jer.
Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Med.)</fld> <def>The subsidence of a febrile
process; <as>as, the stage of <ex>defervescence</ex> in
pneumonia</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defeudalize</ent><br/
<hw>De*feu"dal*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To deprive
of the feudal character or form.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defiance</ent><br/
<hw>De*fi"ance</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>defiance</ets>, <ets>desfiance</ets>, challenge, fr.
<ets>desfier</ets> to challenge, F. <ets>d<eacute/fier</ets>. See
<er>Defy</er>.]</ety> <sn>1.</sn> <def>The act of defying, putting in
opposition, or provoking to combat; a challenge; a provocation; a
summons to combat.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A war without a just <qex>defiance</qex> made.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Stood for her cause, and flung <qex>defiance</qex> down.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A state of opposition; willingness to flight;
disposition to resist; contempt of opposition.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He breathed <qex>defiance</qex> to my ears.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A casting aside; renunciation; rejection.</def>
<mark>[Obs.]</mark> <ldquo/<xex>Defiance</xex> to thy kindness.<rdquo/
<rj><au>Ford.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>To bid defiance</b></col>, <col><b>To set at
defiance</b></col></mcol>, <cd>to defy; to disregard recklessly or
contemptuously.</cd> <rj><au>Locke.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defiant</ent><br/
<hw>De*fi"ant</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>d<eacute/fiant</ets>, p. pr. of <ets>d<eacute/fier</ets>. See
<er>Defy</er>.]</ety> <def>Full of defiance; bold; insolent; <as>as, a
<ex>defiant</ex> spirit or act</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In attitude stern and <qex>defiant</qex>.</q>
<rj><qau>Longfellow.</qau></rj></p>

<p>-- <wordforms><wf>De*fi"ant*ly</wf>, <pos>adv.</pos> --
<wf>De*fi"ant*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 382 --></p>

<p><ent>Defiatory</ent><br/
<hw>De*fi"a*to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Defy</er>.]</ety> <def>Bidding or manifesting defiance.</def>
<mark>[Obs.]</mark> <rj><au>Shelford.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defibrinate</ent><br/
<hw>De*fi"bri*nate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To deprive
of fibrin, as fresh blood or lymph by stirring with twigs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defibrination</ent><br/
<hw>De*fi`bri*na"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act or
process of depriving of fibrin.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defibrinize</ent><br/
<hw>De*fi"bri*nize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To
defibrinate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deficience</ent><br/
<hw>De*fi"cience</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Deficiency</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou in thyself art perfect, and in thee<br/
Is no <qex>deficience</qex> found.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deficiency</ent><br/
<hw>De*fi"cien*cy</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Deficiencies</plw> <pr>(#)</pr>.</plu> <ety>[See
<er>Deficient</er>.]</ety> <def>The state of being deficient;
inadequacy; want; failure; imperfection; shortcoming; defect.</def>
<ldquo/A <xex>deficiency</xex> of blood.<rdquo/
<rj><au>Arbuthnot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>[Marlborough] was so miserably ignorant, that his
<qex>deficiencies</qex> made him the ridicule of his contemporaries.</q>
<rj><qau>Buckle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Deficiency of a curve</b></col> <fld>(Geom.)</fld>,
<cd>the amount by which the number of double points on a curve is short
of the maximum for curves of the same degree.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deficient</ent><br/
<hw>De*fi"cient</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>deficiens</ets>, <ets>-entis</ets>, p. pr. of <ets>deficere</ets>
to be wanting. See <er>Defect</er>.]</ety> <def>Wanting, to make up
completeness; wanting, as regards a requirement; not sufficient;
inadequate; defective; imperfect; incomplete; lacking; <as>as,
<ex>deficient</ex> parts; <ex>deficient</ex> estate; <ex>deficient</ex>
strength; <ex>deficient</ex> in judgment.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>The style was indeed <qex>deficient</qex> in ease and variety.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Deficient number</b></col>. <fld>(Arith.)</fld> <cd>See
under <er>Abundant</er>.</cd></cs></p>

<p>-- <wordforms><wf>De*fi"cient-ly</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deficit</ent><br/
<hw>Def"i*cit</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Lit., <ets>it is
wanting</ets>, 3d person pres. indic. of L. <ets>deficere</ets>, cf. F.
<ets>d<eacute/ficit</ets>. See <er>Defect</er>.]</ety> <def>Deficiency
in amount or quality; a falling short; lack; <as>as, a <ex>deficit</ex>
in taxes, revenue, etc.</as></def> <rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defier</ent><br/
<hw>De*fi"er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Defy</er>.]</ety> <def>One who dares and defies; a contemner;
<as>as, a <ex>defier</ex> of the laws</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defiguration</ent><br/
<hw>De*fig`u*ra"tion</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Disfiguration; mutilation.</def> <mark>[Obs.]</mark> <rj><au>Bp.
Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defigure</ent><br/
<hw>De*fig"ure</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>de-</ets> (intens.) + <ets>figure</ets>.]</ety> <def>To
delineate.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>These two stones as they are here <qex>defigured</qex>.</q>
<rj><qau>Weever.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defilade</ent><br/
<hw>De`fi*lade"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Defiladed</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Defilading</conjf>.]</vmorph> <ety>[Cf. F.
<ets>d<eacute/filer</ets> to defile, and <ets>d<eacute/filade</ets> act
of defiling. See 1st <er>Defile</er>.]</ety> <fld>(Mil.)</fld> <def>To
raise, as a rampart, so as to shelter interior works commanded from some
higher point.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defilading</ent><br/
<hw>De`fi*lad"ing</hw>, <pos>n.</pos> <fld>(Mil.)</fld> <def>The art or
act of determining the directions and heights of the lines of rampart
with reference to the protection of the interior from exposure to an
enemy's fire from any point within range, or from any works which may be
erected.</def> <rj><au>Farrow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defile</ent><br/
<hw>De*file"</hw> <pr>(d<esl/*f<imac/l")</pr>, <pos>v. i.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Defiled</conjf>
<pr>(d<esl/*f<imac/ld")</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Defiling</conjf>.]</vmorph> <ety>[F. <ets>d<eacute/filer</ets>;
pref. <ets>d<eacute/-</ets>, for <ets>des-</ets> (L. <ets>dis-</ets>) +
<ets>file</ets> a row or line. See <er>File</er> a row.]</ety> <def>To
march off in a line, file by file; to file off.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defile</ent><br/
<hw>De*file"</hw>, <pos>v. t.</pos> <fld>(Mil.)</fld> <def>Same as
<er>Defilade</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defile</ent><br/
<hw>De*file"</hw> <pr>(d<esl/*f<imac/l" <it>or</it> d<emac/"f<imac/l;
277)</pr>, <pos>n.</pos> <ety>[Cf. F. <ets>d<eacute/fil<eacute/</ets>,
fr. <ets>d<eacute/filer</ets> to defile.]</ety> <sn>1.</sn> <def>Any
narrow passage or gorge in which troops can march only in a file, or
with a narrow front; a long, narrow pass between hills, rocks,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mil.)</fld> <def>The act of defilading a fortress,
or of raising the exterior works in order to protect the interior. See
<er>Defilade</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defile</ent><br/
<hw>De*file"</hw> <pr>(d<esl/*f<imac/l")</pr>, <pos>v. t.</pos>
<ety>[OE. <ets>defoulen</ets>, <ets>-foilen</ets>, to tread down, OF.
<ets>defouler</ets>; <ets>de-</ets> + <ets>fouler</ets> to trample (see
<er>Full</er>, <pos>v. t.</pos>), and OE. <ets>defoulen</ets> to foul
(influenced in form by the older verb <ets>defoilen</ets>). See
<er>File</er> to defile, <er>Foul</er>, <er>Defoul</er>.]</ety>
<sn>1.</sn> <def>To make foul or impure; to make filthy; to dirty; to
befoul; to pollute.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They that touch pitch will be <qex>defiled</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To soil or sully; to tarnish, as reputation; to
taint.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He is . . . among the greatest prelates of this age, however his
character may be <qex>defiled</qex> by . . . dirty hands.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To injure in purity of character; to
corrupt.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Defile</qex> not yourselves with the idols of Egypt.</q>
<rj><qau>Ezek. xx. 7.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To corrupt the chastity of; to debauch; to violate;
to rape.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The husband murder'd and the wife <qex>defiled</qex>.</q>
<rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To make ceremonially unclean; to pollute.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That which dieth of itself, or is torn with beasts, he shall not
eat to <qex>defile</qex> therewith.</q> <rj><qau>Lev. xxii.
8.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>defiled</ent><br/
<hw>defiled</hw> <pos>adj.</pos> <sn>1.</sn> <def>morally
blemished.</def> <mark>[archaic]</mark><br/
<syn><b>Syn. --</b> maculate.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <fld>(Religion)</fld> <def>ritually unclean. Opposite of
<ant>clean</ant>.</def><br/
<syn><b>Syn. --</b> unclean, impure.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Defilement</ent><br/
<hw>De*file"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>d<eacute/filement</ets>. See <er>Defile</er>]</ety>
<fld>(Mil.)</fld> <def>The protection of the interior walls of a
fortification from an enfilading fire, as by covering them, or by a high
parapet on the exposed side.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defilement</ent><br/
<hw>De*file"ment</hw>, <pos>n.</pos> <ety>[From 3d
<er>Defile</er>.]</ety> <def>The act of defiling, or state of being
defiled, whether physically or morally; pollution; foulness; dirtiness;
uncleanness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Defilements</qex> of the flesh.</q>
<rj><qau>Hopkins.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The chaste can not rake into such filth without danger of
<qex>defilement</qex>.</q> <rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defiler</ent><br/
<hw>De*fil"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who defiles; one
who corrupts or violates; that which pollutes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defiliation</ent><br/
<hw>De*fil`i*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>de-</ets> + <ets>filius</ets> son.]</ety> <def>Abstraction of a
child from its parents.</def> <rj><au>Lamb.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Definable</ent><br/
<hw>De*fin"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From
<er>Define</er>.]</ety> <def>Capable of being defined, limited, or
explained; determinable; describable by definition; ascertainable;
<as>as, <ex>definable</ex> limits; <ex>definable</ex> distinctions or
regulations; <ex>definable</ex> words</as>.</def> --
<wordforms><wf>De*fin"a*bly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Define</ent><br/
<hw>De*fine"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Defined</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Defining</conjf>.]</vmorph> <ety>[OE. <ets>definer</ets>,
usually, to end, to finish, F. <ets>d<eacute/finir</ets> to define, L.
<ets>definire</ets> to limit, define; <ets>de-</ets> + <ets>finire</ets>
to limit, end, <ets>finis</ets> boundary, limit, end. See
<er>Final</er>, <er>Finish</er>.]</ety> <sn>1.</sn> <def>To fix the
bounds of; to bring to a termination; to end.</def> <ldquo/To
<xex>define</xex> controversies.<rdquo/ <rj><au>Barrow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To determine or clearly exhibit the boundaries of;
to mark the limits of; <as>as, to <ex>define</ex> the extent of a
kingdom or country</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To determine with precision; to mark out with
distinctness; to ascertain or exhibit clearly; <as>as, the
<ex>defining</ex> power of an optical instrument</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Rings . . . very distinct and well <qex>defined</qex>.</q>
<rj><qau>Sir I. Newton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To determine the precise signification of; to fix
the meaning of; to describe accurately; to explain; to expound or
interpret; <as>as, to <ex>define</ex> a word, a phrase, or a scientific
term</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They <qex>define</qex> virtue to be life ordered according to
nature.</q> <rj><qau>Robynson (More's Utopia).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Define</ent><br/
<hw>De*fine"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To determine; to
decide.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Definement</ent><br/
<hw>De*fine"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
defining; definition; description.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Definer</ent><br/
<hw>De*fin"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who defines or
explains.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Definite</ent><br/
<hw>Def"i*nite</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>definitis</ets>, p. p. of <ets>definire</ets>: cf. F.
<ets>d<eacute/fini</ets>. See <er>Define</er>.]</ety> <sn>1.</sn>
<def>Having certain or distinct; determinate in extent or greatness;
limited; fixed; <as>as, <ex>definite</ex> dimensions; a
<ex>definite</ex> measure; a <ex>definite</ex> period or
interval.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Elements combine in <qex>definite</qex> proportions.</q>
<rj><qau>Whewell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Having certain limits in signification; determinate;
certain; precise; fixed; exact; clear; <as>as, a <ex>definite</ex> word,
term, or expression</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Determined; resolved.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Serving to define or restrict; limiting;
determining; <as>as, the <ex>definite</ex> article</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Definite article</b></col> <fld>(Gram.)</fld>, <cd>the
article <xex>the</xex>, which is used to designate a particular person
or thing, or a particular class of persons or things; -- also called a
<xex>definitive</xex>. See <er>Definitive</er>, <pos>n.</pos></cd> - -
<col><b>Definite inflorescence</b></col>. <fld>(Bot.)</fld> <cd>See
<cref>Determinate inflorescence</cref>, under <er>Determinate</er>.</cd>
-- <col><b>Law of definite proportions</b></col> <fld>(Chem.)</fld>,
<cd>the essential law of chemical combination that every definite
compound always contains the same elements in the same proportions by
weight; and, if two or more elements form more than one compound with
each other, the relative proportions of each are fixed. Compare <xex>Law
of multiple proportions</xex>, under <er>Multiple</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Definite</ent><br/
<hw>Def"i*nite</hw>, <pos>n.</pos> <def>A thing defined or
determined.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Definitely</ent><br/
<hw>Def"i*nite*ly</hw>, <pos>adv.</pos> <def>In a definite manner; with
precision; precisely; determinately.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Definiteness</ent><br/
<hw>Def"i*nite*ness</hw>, <pos>n.</pos> <def>The state of being
definite; determinateness; precision; certainty.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Definition</ent><br/
<hw>Def`i*ni"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>definitio</ets>: cf. F. <ets>d<eacute/finition</ets>.]</ety>
<sn>1.</sn> <def>The act of defining; determination of the limits;
<as>as, a telescope accurate in <ex>definition</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Act of ascertaining and explaining the
signification; a description of a thing by its properties; an
explanation of the meaning of a word or term; <as>as, the
<ex>definition</ex> of <ldquo/circle;<rdquo/ the <ex>definition</ex> of
<ldquo/wit;<rdquo/ an exact <ex>definition</ex>; a loose
<ex>definition</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Definition</qex> being nothing but making another understand
by words what the term defined stands for.</q>
<rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Description; sort.</def> <mark>[R.]</mark> <ldquo/A
new creature of another <xex>definition</xex>.<rdquo/ <rj><au>Jer.
Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Logic)</fld> <def>An exact enunciation of the
constituents which make up the logical essence.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Opt.)</fld> <def>Distinctness or clearness, as of
an image formed by an optical instrument; precision in detail.</def></p>

<p><syn><b>Syn.</b> -- <er>Definition</er>, <er>Explanation</er>,
<er>Description</er>.</syn> <usage> A <xex>definition</xex> is designed
to settle a thing in its compass and extent; an <xex>explanation</xex>
is intended to remove some obscurity or misunderstanding, and is
therefore more extended and minute; a <xex>description</xex> enters into
striking particulars with a view to interest or impress by graphic
effect. It is not therefore true, though often said, that
<xex>description</xex> is only an extended <xex>definition</xex>.
<ldquo/Logicians distinguish <xex>definitions</xex> into
<xex>essential</xex> and <xex>accidental</xex>. An <xex>essential
definition</xex> states what are regarded as the constituent parts of
the essence of that which is to be defined; and an <xex>accidental
definition</xex> lays down what are regarded as circumstances belonging
to it, viz., properties or accidents, such as causes, effects,
etc.<rdquo/</usage> <rj><au>Whately.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Definitional</ent><br/
<hw>Def`i*ni"tion*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Relating to
definition; of the nature of a definition; employed in
defining.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Definitive</ent><br/
<hw>De*fin"i*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>definitivus</ets>: cf. F. <ets>d<eacute/finitif</ets>.]</ety>
<sn>1.</sn> <def>Determinate; positive; final; conclusive;
unconditional; express.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A strict and <qex>definitive</qex> truth.</q> <rj><qau>Sir T.
Browne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Some <qex>definitive</qex> . . . scheme of reconciliation.</q>
<rj><qau>Prescott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Limiting; determining; <as>as, a <ex>definitive</ex>
word</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Determined; resolved.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Definitive</ent><br/
<hw>De*fin"i*tive</hw>, <pos>n.</pos> <fld>(Gram.)</fld> <def>A word
used to define or limit the extent of the signification of a common
noun, such as the definite article, and some pronouns.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Definitives</xex> . . . are commonly called by
grammarians <xex>articles</xex>. . . . They are of two kinds, either
those properly and strictly so called, or else pronominal articles, such
as <xex>this</xex>, <xex>that</xex>, <xex>any</xex>, <xex>other</xex>,
<xex>some</xex>, <xex>all</xex>, <xex>no</xex>, <xex>none</xex>,
etc.</note> <rj><au>Harris (Hermes).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Definitively</ent><br/
<hw>De*fin"i*tive*ly</hw>, <pos>adv.</pos> <def>In a definitive
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Definitiveness</ent><br/
<hw>De*fin"i*tive*ness</hw>, <pos>n.</pos> <def>The quality of being
definitive.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Definitude</ent><br/
<hw>De*fin"i*tude</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Definiteness.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Definitude</qex> . . . is a knowledge of minute
differences.</q> <rj><qau>Sir W. Hamilton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defix</ent><br/
<hw>De*fix"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>defixus</ets>, p. p. of <ets>defigere</ets> to fix; <ets>de-</ets>
+ <ets>figere</ets> to fix.]</ety> <def>To fix; to fasten; to
establish.</def> <mark>[Obs.]</mark> <ldquo/To <xex>defix</xex> their
princely seat . . . in that extreme province.<rdquo/
<rj><au>Hakluyt.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deflagrability</ent><br/
<hw>Def`la*gra*bil"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Chem.)</fld> <def>The state or quality of being
deflagrable.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The ready <qex>deflagrability</qex> . . . of saltpeter.</q>
<rj><qau>Boyle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deflagrable</ent><br/
<hw>De*fla"gra*ble</hw> <pr>(?; 277)</pr>, <pos>a.</pos> <ety>[See
<er>Deflagrate</er>.]</ety> <fld>(Chem.)</fld> <def>Burning with a
sudden and sparkling combustion, as niter; hence, slightly explosive;
liable to snap and crackle when heated, as salt.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deflagrate</ent><br/
<hw>Def"la*grate</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Deflagrated</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Deflagrating</conjf>.]</vmorph> <ety>[L. <ets>deflagratus</ets>,
p. p. of <ets>deflagrare</ets> to burn up; <ets>de-</ets> +
<ets>flagrare</ets> to flame, burn.]</ety> <fld>(Chem.)</fld> <def>To
burn with a sudden and sparkling combustion, as niter; also, to snap and
crackle with slight explosions when heated, as salt.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deflagrate</ent><br/
<hw>Def"la*grate</hw>, <pos>v. t.</pos> <fld>(Chem.)</fld> <def>To cause
to burn with sudden and sparkling combustion, as by the action of
intense heat; to burn or vaporize suddenly; <as>as, to
<ex>deflagrate</ex> refractory metals in the oxyhydrogen
flame</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deflagration</ent><br/
<hw>Def`la*gra"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>deflagratio</ets>: cf. F. <ets>d<eacute/flagration</ets>.]</ety>
<sn>1.</sn> <def>A burning up; conflagration.</def> <ldquo/Innumerable
deluges and <xex>deflagrations</xex>.<rdquo/ <rj><au>Bp.
Pearson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Chem.)</fld> <def>The act or process of
deflagrating.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deflagrator</ent><br/
<hw>Def"la*gra`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>A form of the voltaic battery having large plates, used for
producing rapid and powerful combustion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>deflate</ent><br/
<hw>de*flate"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>de-</ets> down + L. <ets>flare</ets>, <ets>flatus</ets> to
blow.]</ety> <def>To reduce from an inflated condition; used literally
and metaphorically; <as>as, to <ex>deflate</ex> a tire; to
<ex>deflate</ex> expectations</as>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>deflated</ent><br/
<hw>deflated</hw> <pos>adj.</pos> <sn>1.</sn> <def>brought low in
spirit.</def> <illu>left us fatigued and <ex>deflated</ex>
spiritually</illu><br/
<syn><b>Syn. --</b> chapfallen, chopfallen, crestfallen.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>deflation</ent><br/
<hw>deflation</hw> <pos>n.</pos> <sn>1.</sn> <def>the act or process of
deflating.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>a fall in the average prices of goods and services;
-- usually associated with contraction of economic activity. Opposite of
<ant>inflation</ant>. Compare <contr>disinflation</contr>.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>the reduction of available credit or a contraction
of economic activity resulting from or associated with a decline of
prices.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>4.</sn> <def>the act of letting the air out of
something.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>5.</sn> <fld>(Geol.)</fld> <def>the erosion of land structures
such as sand or soil due to the action of wind.</def> <au>RHUD</au><br/
[<source>PJC</source>]</p>

<p><ent>deflationary</ent><br/
<hw>deflationary</hw> <pos>adj.</pos> <sn>1.</sn> <def>of or pertaining
to deflation; <as>as, <ex>deflationary</ex> signs</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <fld>(Economics)</fld> <def>associated with or tending to
cause decreases in consumer prices or increases in the purchasing power
of money; <as>as, <ex>deflationary</ex> measures</as>. Opposite of
<ant>inflationary</ant>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>deflator</ent><br/
<hw>deflator</hw> <pos>n.</pos> <def>a statistical factor designed to
remove the effect of inflation; inflation adjusted variables are in
constant dollars; <as>as, the GNP <ex>deflator</ex>.</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>deflect</ent><br/
<hw>de*flect"</hw> <pr>(d<esl/*fl<ecr/kt")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Deflected</conjf>; <pos>p. pr. &
vb. n.</pos> <conjf>Deflecting</conjf>.]</vmorph> <ety>[L.
<ets>deflectere</ets>; <ets>de-</ets> + <ets>flectere</ets> to bend or
turn. See <er>Flexible</er>.]</ety> <def>To cause to turn aside; to
bend; <as>as, rays of light are often <ex>deflected</ex>; to
<ex>deflect</ex> a punch; to <ex>deflect</ex> criticism by acknowledging
a mistake</as>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><q>Sitting with their knees <qex>deflected</qex> under them.</q>
<rj><qau>Lord (1630).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deflect</ent><br/
<hw>De*flect"</hw>, <pos>v. i.</pos> <def>To turn aside; to deviate from
a right or a horizontal line, or from a proper position, course or
direction; to swerve.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>At some part of the Azores, the needle <qex>deflecteth</qex> not,
but lieth in the true meridian.</q> <rj><qau>Sir T.
Browne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>deflect</qex> from the line of truth and reason.</q>
<rj><qau>Warburton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deflectable</ent><br/
<hw>De*flect"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of
being deflected.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deflected</ent><br/
<hw>De*flect"ed</hw>, <pos>a.</pos> <sn>1.</sn> <def>Turned aside;
deviating from a direct line or course.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Bent downward; deflexed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deflection</ent><br/
<hw>De*flec"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>deflexio</ets>, fr. <ets>deflectere</ets>: cf. F.
<ets>d<eacute/flexion</ets>.]</ety> <sn>1.</sn> <def>The act of turning
aside, or state of being turned aside; a turning from a right line or
proper course; a bending, esp. downward; deviation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The other leads to the same point, through certain
<qex>deflections</qex>.</q> <rj><qau>Lowth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Gunnery)</fld> <def>The deviation of a shot or ball
from its true course.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Opt.)</fld> <def>A deviation of the rays of light
toward the surface of an opaque body; inflection; diffraction.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Engin.)</fld> <def>The bending which a beam or
girder undergoes from its own weight or by reason of a load.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deflectionization</ent><br/
<hw>De*flec`tion*i*za"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act
of freeing from inflections.</def> <rj><au>Earle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deflectionize</ent><br/
<hw>De*flec"tion*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To free
from inflections.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Deflectionized</qex> languages are said to be analytic.</q>
<rj><qau>Earle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deflective</ent><br/
<hw>De*flect"ive</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Causing
deflection.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Deflective forces</b></col>, <cd>forces that cause a body
to deviate from its course.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deflector</ent><br/
<hw>De*flect"or</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Mech.)</fld>
<def>That which deflects, as a diaphragm in a furnace, or a cone in a
lamp (to deflect and mingle air and gases and help
combustion).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deflexed</ent><br/
<hw>De*flexed"</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Bent abruptly
downward.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deflexion</ent><br/
<hw>De*flex"ion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Deflection</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deflexure</ent><br/
<hw>De*flex"ure</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From L.
<ets>deflectere</ets>, <ets>deflexum</ets>. See <er>Deflect</er>.]</ety>
<def>A bending or turning aside; deflection.</def>
<rj><au>Bailey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deflorate</ent><br/
<hw>De*flo"rate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[LL.
<ets>defloratus</ets>, p. p. of <ets>deflorare</ets>. See
<er>Deflour</er>.]</ety> <fld>(Bot.)</fld> <def>Past the flowering
state; having shed its pollen.</def> <rj><au>Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defloration</ent><br/
<hw>Def`lo*ra"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL.
<ets>defloratio</ets>: cf. F. <ets>d<eacute/floration</ets>.]</ety>
<sn>1.</sn> <def>The act of deflouring; <as>as, the <ex>defloration</ex>
of a virgin</as>.</def> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is chosen as the flower or choicest part;
careful culling or selection.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The laws of Normandy are, in a great measure, the
<qex>defloration</qex> of the English laws.</q> <rj><qau>Sir M.
Hale.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>deflour</ent><br/
<hw>de*flour"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>de-</ets> + <ets>flower</ets>.]</ety> <def>Same as
<er>Deflower</er>.</def> <mark>[archaic]</mark> <br/
[<source>1913 Webster</source>]</p>

<p><q>He died innocent and before the sweetness of his soul was
<qex>defloured</qex> and ravished from him.</q> <rj><qau>Jer.
Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deflourer</ent><br/
<hw>De*flour"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Deflowerer</er>.</def> <mark>[archaic]</mark> <br/
[<source>1913 Webster</source>]</p>

<p><ent>Deflow</ent><br/
<hw>De*flow"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[Pref.
<ets>de-</ets> + <ets>flow</ets>: cf. L. <ets>defluere</ets>.]</ety>
<def>To flow down.</def> <mark>[Obs.]</mark> <rj><au>Sir T.
Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>deflower</ent><br/
<hw>de*flow"er</hw> <pr>(?)</pr>, <pos>v. t.</pos> <altsp>[Previously
also spelled <asp>deflour</asp>.]</altsp> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Deflowered</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Deflowering</conjf>.]</vmorph> <ety>[F.
<ets>d<eacute/florer</ets>, LL. <ets>deflorare</ets>; L. <ets>de-</ets>
+ <ets>flos</ets>, <ets>floris</ets>, flower. See <er>Flower</er>, and
cf. <er>Deflorate</er>.]</ety> <sn>1.</sn> <def>To deprive of
flowers.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>An earthquake . . . <qex>deflowering</qex> the gardens.</q>
<rj><qau>W. Montagu.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To take away the prime beauty and grace of; to rob
of the choicest ornament.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To deprive of virginity, as a woman; to violate; to
ravish; also, to seduce.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If a man had <qex>deflowered</qex> a virgin.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deflowerer</ent><br/
<hw>De*flow"er*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
deflowers; a ravisher.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defluous</ent><br/
<hw>Def"lu*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>defluus</ets>, fr. <ets>defluere</ets> to flow down; <ets>de-</ets>
+ <ets>fluere</ets> to flow.]</ety> <def>Flowing down; falling
off.</def> <mark>[Obs.]</mark> <rj><au>Bailey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deflux</ent><br/
<hw>De*flux"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>defluxus</ets>, fr. <ets>defluere</ets>,
<ets>defluxum</ets>.]</ety> <def>Downward flow.</def>
<mark>[Obs.]</mark> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defluxion</ent><br/
<hw>De*flux"ion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>defluxio</ets>.]</ety> <fld>(Med.)</fld> <def>A discharge or
flowing of humors or fluid matter, as from the nose in catarrh; --
sometimes used synonymously with <xex>inflammation</xex>.</def>
<rj><au>Dunglison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defly</ent><br/
<hw>Def"ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>Deftly.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defoedation</ent><br/
<hw>Def`<oe/*da"tion</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Defedation.</def> <mark>[Obs.]</mark></p>

<p><ent>Defoliated</ent><br/
<ent>Defoliate</ent><br/
<mhw>{ <hw>De*fo"li*ate</hw> <pr>(?)</pr>, <hw>De*fo"li*a`ted</hw>
<pr>(?)</pr>. }</mhw> <pos>a.</pos> <def>Deprived of leaves, as by their
natural fall.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>deformational</ent><br/
<hw>deformational</hw> <pos>adj.</pos> <sn>1.</sn> <def>of or pertaining
to deformation (in all senses).</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>defoliate</ent><br/
<hw>de*fol"i*ate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[LL.
<ets>defoliare</ets>, to shed leaves; L. <ets>de-</ets> +
<ets>folium</ets> leaf: cf. F. <ets>d<eacute/foliation</ets>.]</ety>
<def>to cause (a plant) to shed its leaves.</def><br/
[<source>PJC</source>]</p>

<p><ent>defoliation</ent><br/
<hw>de*fo`li*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL.
<ets>defoliare</ets>, <ets>defoliatum</ets>, to shed leaves; L.
<ets>de-</ets> + <ets>folium</ets> leaf: cf. F.
<ets>d<eacute/foliation</ets>.]</ety> <def>The separation of ripened
leaves from a branch or stem; the falling or shedding of the
leaves.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>the act or process of causing plants to lose their
leaves, especially by application of a chemical agent.</def> <note>The
deliberate defoliation of plants has been used in war (as in Vietnam) to
deprive an enemy of cover and allow attack from the air; also, to
destroy narcotic-producing plants as a tactic against illegal drug
production. The chemical defoliating agents are often sprayed over large
areas from airplanes.</note><br/
[<source>PJC</source>]</p>

<p><ent>Deforce</ent><br/
<hw>De*force"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Deforced</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Deforcing</conjf>.]</vmorph> <ety>[OF.
<ets>deforcier</ets>; <ets>de-</ets> or <ets>des-</ets> (L.
<ets>de</ets> or <ets>dis-</ets>) + <ets>forcier</ets>, F.
<ets>forcer</ets>. See <er>Force</er>, <pos>v.</pos>]</ety>
<fld>(Law)</fld> <sd>(a)</sd> <def>To keep from the rightful owner; to
withhold wrongfully the possession of, as of lands or a freehold.</def>
<sd>(b)</sd> <fld>(Scots Law)</fld> <def>To resist the execution of the
law; to oppose by force, as an officer in the execution of his
duty.</def> <rj><au>Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deforcement</ent><br/
<hw>De*force"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.]</ety>
<fld>(Law)</fld> <sd>(a)</sd> <def>A keeping out by force or wrong; a
wrongful withholding, as of lands or tenements, to which another has a
right.</def> <sd>(b)</sd> <fld>(Scots Law)</fld> <def>Resistance to an
officer in the execution of law.</def> <rj><au>Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deforceor</ent><br/
<hw>De*force"or</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Deforciant</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deforciant</ent><br/
<hw>De*for"ciant</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>deforciant</ets>, p. pr. of <ets>deforcier</ets>. See
<er>Deforce</er>.]</ety> <fld>(Eng. Law)</fld> <sd>(a)</sd> <def>One who
keeps out of possession the rightful owner of an estate.</def>
<sd>(b)</sd> <def>One against whom a fictitious action of fine was
brought.</def> <mark>[Obs.]</mark> <rj><au>Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deforciation</ent><br/
<hw>De*for`ci*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Law)</fld>
<def>Same as <er>Deforcement</er>, <pos>n.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 383 --></p>

<p><ent>Deforest</ent><br/
<hw>De*for"est</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To clear of
forests; to disforest.</def> <rj><au>U. S. Agric. Reports.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deform</ent><br/
<hw>De*form"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Deformed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Deforming</conjf>.]</vmorph> <ety>[L.
<ets>deformare</ets>; <ets>de-</ets> + <ets>formare</ets> to form,
shape, fr. <ets>forma</ets>: cf. F. <ets>d<eacute/former</ets>. See
<er>Form</er>.]</ety> <sn>1.</sn> <def>To spoil the form of; to mar in
form; to misshape; to disfigure.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Deformed</qex>, unfinished, sent before my time<br/
Into this breathing world.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To render displeasing; to deprive of comeliness,
grace, or perfection; to dishonor.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Above those passions that this world <qex>deform</qex>.</q>
<rj><qau>Thomson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deform</ent><br/
<hw>De*form"</hw>, <pos>a.</pos> <ety>[L. <ets>deformis</ets>;
<ets>de-</ets> + <ets>forma</ets> form: cf. OF. <ets>deforme</ets>, F.
<ets>difforme</ets>. Cf. <er>Difform</er>.]</ety> <def>Deformed;
misshapen; shapeless; horrid.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Sight so <qex>deform</qex> what heart of rock could long<br/
Dry-eyed behold?</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deformation</ent><br/
<hw>Def`or*ma"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>deformatio</ets>: cf. F. <ets>d<eacute/formation</ets>.]</ety>
<sn>1.</sn> <def>The act of deforming, or state of anything
deformed.</def> <rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Transformation; change of shape.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deformed</ent><br/
<hw>De*formed"</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Unnatural or
distorted in form; having a deformity; misshapen; disfigured; <as>as, a
<ex>deformed</ex> person; a <ex>deformed</ex> head.</as></def> --
<wordforms><wf>De*form"ed*ly</wf> <pr>(#)</pr>, <pos>adv.</pos> --
<wf>De*form"ed*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deformer</ent><br/
<hw>De*form"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
deforms.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deformity</ent><br/
<hw>De*form"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Deformities</plw> <pr>(#)</pr>.</plu> <ety>[L.
<ets>deformitas</ets>, fr. <ets>deformis</ets>: cf. OF.
<ets>deformet<eacute/</ets>, <ets>deformit<eacute/</ets>, F.
<ets>difformit<eacute/</ets>. See <er>Deform</er>, <pos>v.</pos> &
<pos>a.</pos>, and cf. <er>Disformity</er>.]</ety> <sn>1.</sn> <def>The
state of being deformed; want of proper form or symmetry; any unnatural
form or shape; distortion; irregularity of shape or features;
ugliness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To make an envious mountain on my back,<br/
Where sits <qex>deformity</qex> to mock my body.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Anything that destroys beauty, grace, or propriety;
irregularity; absurdity; gross deviation from order or the established
laws of propriety; <as>as, <ex>deformity</ex> in an edifice;
<ex>deformity</ex> of character.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Confounded, that her Maker's eyes<br/
Should look so near upon her foul <qex>deformities</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deforser</ent><br/
<hw>De*fors"er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<er>Deforce</er>.]</ety> <ety>[Written also <ets>deforsor</ets>.]</ety>
<def>A deforciant.</def> <mark>[Obs.]</mark>
<rj><au>Blount.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defoul</ent><br/
<hw>De*foul"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[See
<er>Defile</er>, <pos>v. t.</pos>]</ety> <sn>1.</sn> <def>To tread
down.</def> <mark>[Obs.]</mark> <rj><au>Wyclif.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To make foul; to defile.</def> <mark>[Obs.]</mark>
<rj><au>Wyclif.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defraud</ent><br/
<hw>De*fraud"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Defrauded</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Defrauding</conjf>.]</vmorph> <ety>[L. <ets>defraudare</ets>;
<ets>de-</ets> + <ets>fraudare</ets> to cheat, fr. <ets>fraus</ets>,
<ets>fraudis</ets>, fraud: cf. OF. <ets>defrauder</ets>. See
<er>Fraud</er>.]</ety> <def>To deprive of some right, interest, or
property, by a deceitful device; to withhold from wrongfully; to injure
by embezzlement; to cheat; to overreach; <as>as, to <ex>defraud</ex> a
servant, or a creditor, or the state</as>; -- with <xex>of</xex> before
the thing taken or withheld.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We have <qex>defrauded</qex> no man.</q> <rj><qau>2 Cor. vii.
2.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Churches seem injured and <qex>defrauded</qex> of their
rights.</q> <rj><qau>Hooker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defraudation</ent><br/
<hw>De`frau*da"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>defraudatio</ets>: cf. F. <ets>d<eacute/fraudation</ets>.]</ety>
<def>The act of defrauding; a taking by fraud.</def> <mark>[R.]</mark>
<rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defrauder</ent><br/
<hw>De*fraud"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who defrauds;
a cheat; an embezzler; a peculator.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defraudment</ent><br/
<hw>De*fraud"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. OF.
<ets>defraudement</ets>.]</ety> <def>Privation by fraud;
defrauding.</def> <mark>[Obs.]</mark> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defray</ent><br/
<hw>De*fray"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Defrayed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Defraying</conjf>.]</vmorph> <ety>[F.
<ets>d<eacute/frayer</ets>; pref. <ets>d<eacute/-</ets> (L.
<ets>de</ets> or <ets>dis-</ets>) + <ets>frais</ets> expense, fr. LL.
<ets>fredum</ets>, <ets>fridum</ets>, expense, fine by which an offender
obtained peace from his sovereign, or more likely, atoned for an offense
against the public peace, fr. OHG. <ets>fridu</ets> peace, G.
<ets>friede</ets>. See <er>Affray</er>.]</ety> <sn>1.</sn> <def>To pay
or discharge; to serve in payment of; to provide for, as a charge, debt,
expenses, costs, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>For the discharge of his expenses, and <qex>defraying</qex> his
cost, he allowed him . . . four times as much.</q>
<rj><qau>Usher.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To avert or appease, as by paying off; to satisfy;
<as>as, to <ex>defray</ex> wrath</as>.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defrayal</ent><br/
<hw>De*fray"al</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
defraying; payment; <as>as, the <ex>defrayal</ex> of necessary
costs</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defrayer</ent><br/
<hw>De*fray"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who pays off
expenses.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defrayment</ent><br/
<hw>De*fray"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Payment of
charges.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>defrock</ent><br/
<hw>defrock</hw> <pos>v. t.</pos> <def>To divest of the frock, <it>i.
e.</it> to deprive (a priest, minister, etc.) of official ecclesiastical
authority; -- of church officials.</def><br/
<syn><b>Syn. --</b> unfrock.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>defrost</ent><br/
<hw>defrost</hw> <pos>v. t.</pos> <def>To remove the frost or ice from;
<as>as, to <ex>defrost</ex> the car window; to <ex>defrost</ex> a
refrigerator</as>.</def><br/
<syn><b>Syn. --</b> deice.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>defrost</ent><br/
<hw>defrost</hw> <pos>v. i.</pos> <sn>1.</sn> <def>To become free of
frost or ice; <as>as, it took four hours for the refrigerator to
<ex>defrost</ex></as>.</def><br/
<syn><b>Syn. --</b> deice.</syn><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>To thaw; -- used especially of items removed from a
freezer, such as frozen foods.</def><br/
[<source>PJC</source>]</p>

<p><ent>defroster</ent><br/
<hw>defroster</hw> <pos>n.</pos> <def>A device that removes ice or frost
(as from a windshield or a refrigerator or the wings of an
airplane).</def><br/
<syn><b>Syn. --</b> deicer.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>deft</ent><br/
<hw>deft</hw> <pr>(d<ecr/ft)</pr>, <pos>a.</pos> <ety>[OE.
<ets>daft</ets>, <ets>deft</ets>, becoming, mild, gentle, stupid (cf.
OE. <ets>daffe</ets>, <ets>deffe</ets>, fool, coward), AS.
<ets>d<ae/ft</ets> (in derivatives only) mild, gentle, fitting,
seasonable; akin to <ets>dafen</ets>, <ets>gedafen</ets>, becoming, fit,
Goth. <ets>gadaban</ets> to be fit. Cf. <er>Daft</er>, <er>Daff</er>,
<er>Dapper</er>.]</ety> <sn>1.</sn> <def>Apt; fit; spruce; neat.</def>
<mark>[Archaic or Poetic]</mark> <ldquo/The <xex>deftest</xex>
way.<rdquo/ <au>Shak.</au> <ldquo/<xex>Deftest</xex> feats.<rdquo/
<rj><au>Gay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Let me be <qex>deft</qex> and debonair.</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>dexterous; clever; handy; <as>as, a <ex>deft</ex>
feat of legerdemain</as>.</def><br/
[<source>PJC</source>]</p>

<p><q>The limping god, so <qex>deft</qex> at his new ministry.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deftly</ent><br/
<hw>Deft"ly</hw>, <pos>adv.</pos> <ety>[Cf. <er>Defly</er>.]</ety>
<def>Aptly; fitly; dexterously; neatly.</def> <ldquo/<xex>Deftly</xex>
dancing.<rdquo/ <rj><au>Drayton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Thyself and office <qex>deftly</qex> show.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deftness</ent><br/
<hw>Deft"ness</hw>, <pos>n.</pos> <def>The quality of being deft.</def>
<rj><qau>Drayton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defunct</ent><br/
<hw>De*funct"</hw> <pr>(d<esl/*f<ucr/<nsm/kt")</pr>. <pos>a.</pos>
<ety>[L. <ets>defunctus</ets>, p. p. of <ets>defungi</ets> to acquit
one's self of, to perform, finish, depart, die; <ets>de</ets> +
<ets>fungi</ets> to perform, discharge: cf. F. <ets>d<eacute/funt</ets>.
See <er>Function</er>.]</ety> <sn>1.</sn> <def>Having finished the
course of life; dead; deceased.</def> <ldquo/<xex>Defunct</xex>
organs.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The boar, <qex>defunct</qex>, lay tripped up, near.</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>No longer in effect or use; no longer operating;
<as>as, a <ex>defunct</ex> business; a <ex>defunct</ex>
law</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Defunct</ent><br/
<hw>De*funct"</hw>, <pos>n.</pos> <def>A dead person; one
deceased.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Defunction</ent><br/
<hw>De*func"tion</hw> <pr>(d<esl/*f<ucr/<nsm/k"sh<ucr/n)</pr>,
<pos>n.</pos> <ety>[L. <ets>defunctio</ets> performance, death.]</ety>
<def>Death.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>After <qex>defunction</qex> of King Pharamond.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>defunctive</ent><br/
<hw>de*func"tive</hw> <pr>(d<esl/*f<ucr/<nsm/k"t<icr/v)</pr>,
<pos>a.</pos> <def>Funereal.</def> <mark>[Obs.]</mark>
<ldquo/<xex>Defunctive</xex> music.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>defuse</ent><br/
<hw>de*fuse"</hw> <pr>(d<esl/*f<umac/z")</pr>, <pos>v. t.</pos>
<ety>[Cf. <er>Diffuse</er>.]</ety> <sn>1.</sn> <def>To disorder; to make
shapeless.</def> <mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To remove the fuse from; to deactivate (a bomb or
other explosive device) or make it ineffective.</def><br/
<syn><b>Syn. --</b> deactivate.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><sn>3.</sn> <def>To make less dangerous; <as>as, to <ex>defuse</ex> a
tense confrontation between demonstrators and police</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>defusing</ent><br/
<hw>defusing</hw> <pr>(d<esl/*f<umac/z"<icr/ng)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>The act of deactivating or making ineffective (as a
bomb).</def><br/
<syn><b>Syn. --</b> deactivation.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>defy</ent><br/
<hw>de*fy"</hw> <pr>(d<esl/*f<imac/")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Defied</conjf>
<pr>(d<esl/*f<imac/d")</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Defying</conjf>.]</vmorph> <ety>[F. <ets>d<eacute/fier</ets>, OF.
<ets>deffier</ets>, <ets>desfier</ets>, LL. <ets>disfidare</ets> to
disown faith or fidelity, to dissolve the bond of allegiance, as between
the vassal and his lord; hence, to challenge, defy; fr. L.
<ets>dis-</ets> + <ets>fides</ets> faith. See <er>Faith</er>, and cf.
<er>Diffident</er>, <er>Affiance</er>.]</ety> <sn>1.</sn> <def>To
renounce or dissolve all bonds of affiance, faith, or obligation with;
to reject, refuse, or renounce.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I defy the surety and the bond.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>For thee I have <qex>defied</qex> my constant mistress.</q>
<rj><qau>Beau. & Fl.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To provoke to combat or strife; to call out to
combat; to challenge; to dare; to brave; to set at defiance; to treat
with contempt; <as>as, to <ex>defy</ex> an enemy; to <ex>defy</ex> the
power of a magistrate; to <ex>defy</ex> the arguments of an opponent; to
<ex>defy</ex> public opinion.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>I once again<br/
<qex>Defy</qex> thee to the trial of mortal fight.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I <qex>defy</qex> the enemies of our constitution to show the
contrary.</q> <rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>defy</ent><br/
<hw>de*fy"</hw> <pr>(d<esl/*f<imac/")</pr>, <pos>n.</pos> <def>A
challenge.</def> <mark>[Obs.]</mark> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>degage</ent><br/
\'d8<hw>d<eacute/`ga`g<eacute/"</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[F., p. p. of <ets>d<eacute/gager</ets> to disengage. See
<er>De-</er>, 1st Gage, and cf. <er>Disgage</er>.]</ety>
<def>Unconstrained; easy; free.</def> <rj><au>Vanbrugh.</au></rj></p>

<p><q>A graceful and <qex>d<eacute/gag<eacute/</qex> manner.</q>
<rj><qau>Poe.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>degarnish</ent><br/
<hw>de*gar"nish</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>degarnished</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>degarnishing</conjf>.]</vmorph> <ety>[F.
<ets>d<eacute/garnir</ets>; pref. <ets>d<eacute/-</ets>, <ets>des-</ets>
(L. <ets>dis-</ets>) + <ets>garnir</ets> to furnish. See
<er>Garnish</er>, and cf. <er>Disgarnish</er>.]</ety> <sn>1.</sn>
<def>To strip or deprive of entirely, as of furniture, ornaments, etc.;
to disgarnish; <as>as, to <ex>degarnish</ex> a house, etc.</as></def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To deprive of a garrison, or of troops necessary for
defense; <as>as, to <ex>degarnish</ex> a city or fort</as>.</def>
<mark>[R.]</mark> <rj><au>Washington.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Degarnishment</ent><br/
<hw>De*gar"nish*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
depriving, as of furniture, apparatus, or a garrison.</def>
<mark>[R.]</mark></p>

<p><ent>degauss</ent><br/
<hw>de*gauss"</hw> <pr>(d<esl/*gous")</pr>, <pos>n.</pos> <sn>1.</sn>
<def>To make a (steel) ship's hull nonmagnetic by applying an opposing
magnetic field.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>To remove irregular magnetization in (the electron
gun of a cathode-ray tube); -- used to improve picture quality,
especially in computer monitors.</def><br/
[<source>PJC</source>]</p>

<p><ent>degaussing</ent><br/
<hw>degaussing</hw> <pos>n.</pos> <def>the process of making a (steel)
ship's hull nonmagnetic by producing an opposing magnetic
field.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Degener</ent><br/
<ent>Degender</ent><br/
<mhw>{ <hw>De*gen"der</hw> <pr>(?)</pr>, <hw>De*gen"er</hw>
<pr>(?)</pr>, }</mhw> <pos>v. i.</pos> <ety>[See
<er>Degenerate</er>.]</ety> <def>To degenerate.</def>
<mark>[Obs.]</mark> <ldquo/<xex>Degendering</xex> to hate.<rdquo/
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He <qex>degenereth</qex> into beastliness.</q>
<rj><qau>Joye.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Degeneracy</ent><br/
<hw>De*gen"er*a*cy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<er>Degenerate</er>, <pos>a.</pos>]</ety> <sn>1.</sn> <def>The act of
becoming degenerate; a growing worse.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Willful <qex>degeneracy</qex> from goodness.</q>
<rj><qau>Tillotson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The state of having become degenerate; decline in
good qualities; deterioration; meanness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Degeneracy</qex> of spirit in a state of slavery.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To recover mankind out of their universal corruption and
<qex>degeneracy</qex>.</q> <rj><qau>S. Clarke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Degenerate</ent><br/
<hw>De*gen"er*ate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>degeneratus</ets>, p. p. of <ets>degenerare</ets> to degenerate,
cause to degenerate, fr. <ets>degener</ets> base, degenerate, that
departs from its race or kind; <ets>de-</ets> + <ets>genus</ets> race,
kind. See <er>Kin</er> relationship.]</ety> <def>Having become worse
than one's kind, or one's former state; having declined in worth; having
lost in goodness; deteriorated; degraded; unworthy; base; low.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Faint-hearted and <qex>degenerate</qex> king.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>degenerate</qex> and degraded state.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Degenerate</qex> from their ancient blood.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>These <qex>degenerate</qex> days.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I had planted thee a noble vine . . . : how then art thou turned
into the <qex>degenerate</qex> plant of a strange vine unto me?</q>
<rj><qau>Jer. ii. 21.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Degenerate</ent><br/
<hw>De*gen"er*ate</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Degenerated</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Degenerating</conjf>.]</vmorph> <sn>1.</sn> <def>To be or grow
worse than one's kind, or than one was originally; hence, to be
inferior; to grow poorer, meaner, or more vicious; to decline in good
qualities; to deteriorate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>When wit transgresseth decency, it <qex>degenerates</qex> into
insolence and impiety.</q> <rj><qau>Tillotson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Biol.)</fld> <def>To fall off from the normal
quality or the healthy structure of its kind; to become of a lower
type.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>degenerate</ent><br/
<hw>de*gen"er*ate</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>a
person who has declined from a high standard, especially a sexual
deviate; -- usually used disparagingly or opprobriously of persons whose
sexual behavior does not conform to the norms of accepted
morals.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>a person or thing that has fallen from a higher to a
lower state, or reverted to an earlier type or stage of development or
culture.</def> <au>RHUD</au><br/
[<source>PJC</source>]</p>

<p><ent>Degenerately</ent><br/
<hw>De*gen"er*ate*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a
degenerate manner; unworthily.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Degenerateness</ent><br/
<hw>De*gen"er*ate*ness</hw>, <pos>n.</pos> <def>Degeneracy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Degeneration</ent><br/
<hw>De*gen`er*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>d<eacute/g<eacute/n<eacute/ration</ets>.]</ety> <sn>1.</sn>
<def>The act or state of growing worse, or the state of having become
worse; decline; degradation; debasement; degeneracy;
deterioration.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Our <qex>degeneration</qex> and apostasy.</q>
<rj><qau>Bates.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Physiol.)</fld> <def>That condition of a tissue or
an organ in which its vitality has become either diminished or
perverted; a substitution of a lower for a higher form of structure;
<as>as, fatty <ex>degeneration</ex> of the liver</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Biol.)</fld> <def>A gradual deterioration, from
natural causes, of any class of animals or plants or any particular
organ or organs; hereditary degradation of type.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The thing degenerated.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Cockle, aracus, . . . and other <qex>degenerations</qex>.</q>
<rj><qau>Sir T. Browne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Amyloid degeneration</b></col>, <col><b>Caseous
degeneration</b></col>, etc.</mcol> <cd>See under <er>Amyloid</er>,
<er>Caseous</er>, etc.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Degenerationist</ent><br/
<hw>De*gen`er*a"tion*ist</hw>, <pos>n.</pos> <fld>(Biol.)</fld> <def>A
believer in the theory of degeneration, or hereditary degradation of
type; <as>as, the <ex>degenerationists</ex> hold that savagery is the
result of degeneration from a superior state</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Degenerative</ent><br/
<hw>De*gen"er*a*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Undergoing or
producing degeneration; tending to degenerate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Degenerous</ent><br/
<hw>De*gen"er*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>degener</ets>. See <er>Degenerate</er>.]</ety> <def>Degenerate;
base.</def> <mark>[Obs.]</mark> <ldquo/<xex>Degenerous</xex>
passions.<rdquo/ <au>Dryden.</au> <ldquo/<xex>Degenerous</xex>
practices.<rdquo/ <rj><au>South.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Degenerously</ent><br/
<hw>De*gen"er*ous*ly</hw>, <pos>adv.</pos> <def>Basely.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Degerm</ent><br/
<hw>De*germ"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <fld>(Milling)</fld>
<def>To extract the germs from, as from wheat grains.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Degerminator</ent><br/
<hw>De*ger"mi*na`tor</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Milling)</fld> <def>A machine for breaking open the kernels of
wheat or other grain and removing the germs.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Deglaze</ent><br/
<hw>De*glaze"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To remove the
glaze from, as pottery or porcelain, so as to give a dull
finish.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Deglazing</ent><br/
<hw>De*glaz"ing</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The process of
giving a dull or ground surface to glass by acid or by mechanical
means.</def> <rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Degloried</ent><br/
<hw>De*glo"ried</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Deprived of glory;
dishonored.</def> <mark>[Obs.]</mark> <ldquo/With thorns
<xex>degloried</xex>.<rdquo/ <rj><au>G. Fletcher.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deglutinate</ent><br/
<hw>De*glu"ti*nate</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Deglutinated</conjf>; <pos>p.
pr. & vb. n.</pos> <conjf>Deglutinating</conjf>.]</vmorph> <ety>[L.
<ets>deglutinatus</ets>, p. p. of <ets>deglutinare</ets> to deglutinate;
<ets>de-</ets> + <ets>glutinare</ets> to glue, <ets>gluten</ets>
glue.]</ety> <def>To loosen or separate by dissolving the glue which
unties; to unglue.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deglutination</ent><br/
<hw>De*glu`ti*na"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
ungluing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deglutition</ent><br/
<hw>Deg`lu*ti"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>deglutire</ets> to swallow down; <ets>de-</ets> +
<ets>glutire</ets> to swallow: cf. F. <ets>d<eacute/glutition</ets>. See
<er>Glut</er>.]</ety> <def>The act or process of swallowing food; the
power of swallowing.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The muscles employed in the act of <qex>deglutition</qex>.</q>
<rj><qau>Paley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deglutitious</ent><br/
<hw>Deg`lu*ti"tious</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to
deglutition.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deglutitory</ent><br/
<hw>De*glu"ti*to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Serving for,
or aiding in, deglutition.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Degradation</ent><br/
<hw>Deg`ra*da"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL.
<ets>degradatio</ets>, from <ets>degradare</ets>: cf. F.
<ets>d<eacute/gradation</ets>. See <er>Degrade</er>.]</ety> <sn>1.</sn>
<def>The act of reducing in rank, character, or reputation, or of
abasing; a lowering from one's standing or rank in office or society;
diminution; <as>as, the <ex>degradation</ex> of a peer, a knight, a
general, or a bishop</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He saw many removes and <qex>degradations</qex> in all the other
offices of which he had been possessed.</q>
<rj><qau>Clarendon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The state of being reduced in rank, character, or
reputation; baseness; moral, physical, or intellectual degeneracy;
disgrace; abasement; debasement.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The . . . <qex>degradation</qex> of a needy man of letters.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Deplorable is the <qex>degradation</qex> of our nature.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Moments there frequently must be, when a sinner is sensible of the
<qex>degradation</qex> of his state.</q> <rj><qau>Blair.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Diminution or reduction of strength, efficacy, or
value; degeneration; deterioration.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The development and <qex>degradation</qex> of the alphabetic forms
can be traced.</q> <rj><qau>I. Taylor (The Alphabet).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Geol.)</fld> <def>A gradual wearing down or
wasting, as of rocks and banks, by the action of water, frost
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Biol.)</fld> <def>The state or condition of a
species or group which exhibits degraded forms; degeneration.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>degradation</qex> of the species man is observed in some
of its varieties.</q> <rj><qau>Dana.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Physiol.)</fld> <def>Arrest of development, or
degeneration of any organ, or of the body as a whole.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Degradation of energy</b></col>, <it>or</it>
<col><b>Dissipation of energy</b></col></mcol> <fld>(Physics)</fld>,
<cd>the transformation of energy into some form in which it is less
available for doing work.</cd></cs></p>

<p><syn><b>Syn.</b> -- Abasement; debasement; reduction;
decline.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Degrade</ent><br/
<hw>De*grade"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Degraded</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Degrading</conjf>.]</vmorph> <ety>[F. <ets>d<eacute/grader</ets>,
LL. <ets>degradare</ets>, fr. L. <ets>de-</ets> + <ets>gradus</ets>
step, degree. See <er>Grade</er>, and cf. <er>Degree</er>.]</ety>
<sn>1.</sn> <def>To reduce from a higher to a lower rank or degree; to
lower in rank; to deprive of office or dignity; to strip of honors;
<as>as, to <ex>degrade</ex> a nobleman, or a general
officer</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Prynne was sentenced by the Star Chamber Court to be
<qex>degraded</qex> from the bar.</q> <rj><qau>Palfrey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To reduce in estimation, character, or reputation;
to lessen the value of; to lower the physical, moral, or intellectual
character of; to debase; to bring shame or contempt upon; to disgrace;
<as>as, vice <ex>degrades</ex> a man</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>O miserable mankind, to what fall<br/
<qex>Degraded</qex>, to what wretched state reserved!</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Yet time ennobles or <qex>degrades</qex> each line.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Her pride . . . struggled hard against this <qex>degrading</qex>
passion.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Geol.)</fld> <def>To reduce in altitude or
magnitude, as hills and mountains; to wear down.</def></p>

<p><syn><b>Syn.</b> -- To abase; demean; lower; reduce. See
<er>Abase</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Degrade</ent><br/
<hw>De*grade"</hw>, <pos>v. i.</pos> <fld>(Biol.)</fld> <def>To
degenerate; to pass from a higher to a lower type of structure; <as>as,
a family of plants or animals <ex>degrades</ex> through this or that
genus or group of genera</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Degraded</ent><br/
<hw>De*grad"ed</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Reduced
in rank, character, or reputation; debased; sunken; low; base.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The Netherlands . . . were reduced practically to a very
<qex>degraded</qex> condition.</q> <rj><qau>Motley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Biol.)</fld> <def>Having the typical characters or
organs in a partially developed condition, or lacking certain
parts.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Some families of plants are <qex>degraded</qex> dicotyledons.</q>
<rj><qau>Dana.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <ety>[Cf. F. <ets>degr<eacute/</ets> step.]</ety>
<fld>(Her.)</fld> <def>Having steps; -- said of a cross each of whose
extremities finishes in steps growing larger as they leave the center;
-- termed also <xex>on degrees</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Degradement</ent><br/
<hw>De*grade"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Deprivation of
rank or office; degradation.</def> <mark>[R.]</mark>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>degrading</ent><br/
<hw>de*grad"ing</hw>, <pos>a.</pos> <def>causing humiliation or
degradation; <as>as, a <ex>degrading</ex> surrender</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>degradingly</ent><br/
<hw>de*grad"ing*ly</hw>, <pos>adv.</pos> <def>In a degrading
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Degras</ent><br/
<mhw>\'d8<hw>D<eacute/`gras"</hw> <pr>(?)</pr>, <hw>Deg"ras</hw>
<pr>(<?/)</pr></mhw>, <pos>n.</pos> <ety>[F.; cf. F. <ets>gras</ets>, a.
& n., fat.]</ety> <def>A semisolid emulsion produced by the treatment of
certain skins with oxidized fish oil, which extracts their soluble
albuminoids. It was formerly solely a by-product of chamois leather
manufacture, but is now made for its own sake, being valuable as a
dressing for hides.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Degravation</ent><br/
<hw>Deg`ra*va"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>degravare</ets>, <ets>degravatum</ets>, to make heavy. See
<er>Grave</er>, <pos>a.</pos>]</ety> <def>The act of making heavy.</def>
<mark>[Obs.]</mark> <rj><au>Bailey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Degrease</ent><br/
<hw>De*grease"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To remove grease
or fatty matter from, as wool or silk.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Degree</ent><br/
<hw>De*gree"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>degr<eacute/</ets>, OF. <ets>degret</ets>, fr. LL.
<ets>degradare</ets>. See <er>Degrade</er>.]</ety> <sn>1.</sn> <def>A
step, stair, or staircase.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>By ladders, or else by <qex>degree</qex>.</q> <rj><qau>Rom. of
R.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One of a series of progressive steps upward or
downward, in quality, rank, acquirement, and the like; a stage in
progression; grade; gradation; <as>as, <ex>degrees</ex> of vice and
virtue; to advance by slow <ex>degrees</ex>; <ex>degree</ex> of
comparison.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The point or step of progression to which a person
has arrived; rank or station in life; position.</def> <ldquo/A dame of
high <xex>degree</xex>.<rdquo/ <au>Dryden.</au> <ldquo/A knight is your
<xex>degree</xex>.<rdquo/ <au>Shak.</au> <ldquo/Lord or lady of high
<xex>degree</xex>.<rdquo/ <rj><au>Lowell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Measure of advancement; quality; extent; <as>as,
tastes differ in kind as well as in <ex>degree</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>degree</qex> of excellence which proclaims genius, is
different in different times and different places.</q> <rj><qau>Sir. J.
Reynolds.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Grade or rank to which scholars are admitted by a
college or university, in recognition of their attainments; also,
<mark>(informal)</mark> the diploma provided by an educational
institution attesting to the achievement of that rank; <as>as, the
<ex>degree</ex> of bachelor of arts, master, doctor, etc.; to hang one's
<ex>degrees</ex> on the office wall</as>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><note><hand/ In the United States diplomas are usually given as the
evidence of a degree conferred. In the humanities the first degree is
that of <stype>bachelor of arts</stype> (B. A. or A. B.); the second
that of <stype>master of arts</stype> (M. A. or A. M.). The degree of
<xex>bachelor</xex> (<xex>of arts</xex>, <xex>science</xex>,
<xex>divinity</xex>, <xex>law</xex>, etc.) is conferred upon those who
complete a prescribed course of undergraduate study. The first degree in
medicine is that of <stype>doctor of medicine</stype> (M. D.). The
degrees of <xex>master</xex> and <xex>doctor</xex> are also conferred,
in course, upon those who have completed certain prescribed postgraduate
studies, as <stype>doctor of philosophy</stype> (Ph. D.); the degree of
<xex>doctor</xex> is also conferred as a complimentary recognition of
eminent services in science or letters, or for public services or
distinction (as <stype>doctor of laws</stype> (LL. D.) or <stype>doctor
of divinity</stype> (D. D.), when they are called <stype>honorary
degrees</stype>.</note> <-- by 1960 the Ph. D. was more common than the
honorary degree. --><br/
[<source>1913 Webster</source>]</p>

<p><q>The youth attained his bachelor's <qex>degree</qex>, and left the
university.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Genealogy)</fld> <def>A certain distance or remove
in the line of descent, determining the proximity of blood; one remove
in the chain of relationship; <as>as, a relation in the third or fourth
<ex>degree</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In the 11th century an opinion began to gain ground in Italy, that
third cousins might marry, being in the seventh <qex>degree</qex>
according to the civil law.</q> <rj><qau>Hallam.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 384 --></p>

<p><sn>7.</sn> <fld>(Arith.)</fld> <def>Three figures taken together in
numeration; thus, 140 is one <xex>degree</xex>, 222,140 two
<xex>degrees</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <fld>(Algebra)</fld> <def>State as indicated by sum of
exponents; more particularly, the degree of a term is indicated by the
sum of the exponents of its literal factors; thus,
<mathex>a<exp>2</exp>b<exp>3</exp>c</mathex> is a term of the sixth
<xex>degree</xex>. The <xex>degree</xex> of a power, or radical, is
denoted by its index, that of an equation by the greatest sum of the
exponents of the unknown quantities in any term; thus,
<mathex>ax<exp>4</exp> + bx<exp>2</exp> = c</mathex>, and
<mathex>mx<exp>2</exp>y<exp>2</exp> + nyx = p</mathex>, are both
equations of the fourth <xex>degree</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <fld>(Trig.)</fld> <def>A 360th part of the circumference
of a circle, which part is taken as the principal unit of measure for
arcs and angles. The degree is divided into 60 minutes and the minute
into 60 seconds.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <def>A division, space, or interval, marked on a
mathematical or other instrument, as on a thermometer.</def>
<sn>11.</sn> <fld>(Mus.)</fld> <def>A line or space of the
staff.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The short lines and their spaces are <xex>added
degrees</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Accumulation of degrees</b></col>. <fld>(Eng.
Univ.)</fld> <cd>See under <er>Accumulation</er>.</cd> -- <col><b>By
degrees</b></col>, <cd>step by step; by little and little; by moderate
advances.</cd> <ldquo/I'll leave it <xex>by degrees</xex>.<rdquo/
<au>Shak.</au> -- <mcol><col><b>Degree of a curve</b></col> <it>or</it>
<col><b>Degree of a surface</b></col></mcol> <fld>(Geom.)</fld>, <cd>the
number which expresses the degree of the equation of the curve or
surface in rectilinear coordinates. A straight line will, in general,
meet the curve or surface in a number of points equal to the degree of
the curve or surface and no more.</cd> -- <col><b>Degree of
latitude</b></col> <fld>(Geog.)</fld>, <cd>on the earth, the distance on
a meridian between two parallels of latitude whose latitudes differ from
each other by one degree. This distance is not the same on different
parts of a meridian, on account of the flattened figure of the earth,
being 68.702 statute miles at the equator, and 69.396 at the poles.</cd>
-- <col><b>Degree of longitude</b></col>, <cd>the distance on a parallel
of latitude between two meridians that make an angle of one degree with
each other at the poles -- a distance which varies as the cosine of the
latitude, being at the equator 69.16 statute miles.</cd> -- <col><b>To a
degree</b></col>, <cd>to an extreme; exceedingly; <as>as, mendacious
<ex>to a degree</ex></as>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><q>It has been said that Scotsmen . . . are . . . grave <qex>to a
degree</qex> on occasions when races more favored by nature are gladsome
to excess.</q> <rj><qau>Prof. Wilson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>degreed</ent><br/
<hw>de*greed"</hw> <pr>(d<esl/*gr<emac/d")</pr>,<pos>a.</pos>
<def>possessing a college degree or degrees.</def><br/
[<source>PJC</source>]</p>

<p><ent>degressive</ent><br/
<hw>degressive</hw> <pos>adj.</pos> <sn>1.</sn> <def>going down by
steps.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>gradually decreasing in rate on sums below a certain
amount.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Degu</ent><br/
\'d8<hw>De"gu</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Native name.]</ety>
<fld>(Zool.)</fld> <def>A small South American rodent (<spn>Octodon
Cumingii</spn>), of the family <fam>Octodontid<ae/</fam>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Degum</ent><br/
<hw>De*gum"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Degummed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Degumming</conjf>.]</vmorph> <def>To deprive of, or free
from, gum; <as>as, to <ex>degum</ex> ramie</as>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Degust</ent><br/
<hw>De*gust"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>degustare</ets>: cf. F. <ets>d<eacute/guster</ets>. See
<er>Gust</er> to taste.]</ety> <def>To taste.</def> <mark>[Obs.]</mark>
<rj><au>Cockeram.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Degustation</ent><br/
<hw>Deg`us*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>degustatio</ets>: cf. F. <ets>d<eacute/gustation</ets>.]</ety>
<fld>(Physiol.)</fld> <def>Tasting; the appreciation of sapid qualities
by the taste organs.</def> <rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dehisce</ent><br/
<hw>De*hisce"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[L.
<ets>dehiscere</ets>; <ets>de-</ets> + <ets>hiscere</ets> to
gape.]</ety> <def>To gape; to open by dehiscence.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dehiscence</ent><br/
<hw>De*his"cence</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>d<eacute/hiscence</ets>.]</ety> <sn>1.</sn> <def>The act of
gaping.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Biol.)</fld> <def>A gaping or bursting open along a
definite line of attachment or suture, without tearing, as in the
opening of pods, or the bursting of capsules at maturity so as to emit
seeds, etc.; also, the bursting open of follicles, as in the ovaries of
animals, for the expulsion of their contents.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dehiscent</ent><br/
<hw>De*his"cent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>dehiscens</ets>, <ets>-entis</ets>, p. pr. Cf. F.
<ets>d<eacute/hiscent</ets>.]</ety> <def>Characterized by dehiscence;
opening in some definite way, as the capsule of a plant.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dehonestate</ent><br/
<hw>De`ho*nes"tate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>dehonestatus</ets>, p. p. of <ets>dehonestare</ets> to dishonor;
<ets>de-</ets> + <ets>honestare</ets> to make honorable. Cf.
<er>Dishonest</er>, and see <er>Honest</er>.]</ety> <def>To
disparage.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dehonestation</ent><br/
<hw>De*hon`es*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>dehonestatio</ets>.]</ety> <def>A dishonoring; disgracing.</def>
<mark>[Obs.]</mark> <rj><au>Gauden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dehorn</ent><br/
<hw>De*horn"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Dehorned</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Dehorning</conjf>.]</vmorph> <def>To deprive of horns;
to prevent the growth of the horns of (cattle) by burning their ends
soon after they start. See <er>Dishorn</er>.</def>
<ldquo/<xex>Dehorning</xex> cattle.<rdquo/ <rj><au>Farm Journal
(1886).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dehors</ent><br/
\'d8<hw>De*hors"</hw> <pr>(?)</pr>, <pos>prep.</pos> <ety>[F.,
outside.]</ety> <fld>(Law)</fld> <def>Out of; without; foreign to; out
of the agreement, record, will, or other instrument.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dehors</ent><br/
\'d8<hw>De*hors"</hw>, <pos>n.</pos> <fld>(Mil.)</fld> <def>All sorts of
outworks in general, at a distance from the main works; any advanced
works for protection or cover.</def> <rj><au>Farrow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dehort</ent><br/
<hw>De*hort"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Dehorted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Dehorting</conjf>.]</vmorph> <ety>[L. <ets>dehortari</ets>;
<ets>de-</ets> + <ets>hortari</ets> to urge, exhort.]</ety> <def>To urge
to abstain or refrain; to dissuade.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The apostles vehemently <qex>dehort</qex> us from unbelief.</q>
<rj><qau>Bp. Ward.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><ldquo/Exhort<rdquo/ remains, but <qex>dehort</qex>, a word whose
place neither <ldquo/dissuade<rdquo/ nor any other exactly supplies, has
escaped us.</q> <rj><qau>Trench.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dehortation</ent><br/
<hw>De`hor*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>dehortatio</ets>.]</ety> <def>Dissuasion; advice against
something.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dehortative</ent><br/
<hw>De*hort"a*tive</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Dissuasive.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dehortatory</ent><br/
<hw>De*hort"a*to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>dehortatorius</ets>.]</ety> <def>Fitted or designed to dehort or
dissuade.</def> <rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dehorter</ent><br/
<hw>De*hort"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A dissuader; an
adviser to the contrary.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dehumanize</ent><br/
<hw>De*hu"man*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To divest of
human qualities, such as pity, tenderness, etc.; <as>as,
<ex>dehumanizing</ex> influences</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>dehumidify</ent><br/
<hw>de*hu*mid"i*fy</hw> <pos>v. t.</pos> <def>to remove the moisture
from (air or another gas); to reduce the humidity of; <as>as, The air
conditioner <ex>dehumidifies</ex> the air in the summer</as>.</def><br/
<syn><b>Syn. --</b> make less humid.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Dehusk</ent><br/
<hw>De*husk"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To remove the husk
from.</def> <mark>[Obs.]</mark> <ldquo/Wheat <xex>dehusked</xex> upon
the floor.<rdquo/ <rj><au>Drant.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>dehydrate</ent><br/
<hw>de*hy"drate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To deprive of
water; to render free from water; <as>as, to <ex>dehydrate</ex> alcohol;
to <ex>dehydrate</ex> food for preservation</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>dehydrate</ent><br/
<hw>de*hy"drate</hw> <pr>(?)</pr>, <pos>v. i.</pos> <sn>1.</sn> <def>to
lose water or moisture.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>to lose sufficient water to cause physiological
distress; -- of living organisms; <as>as, victims trapped in the
earthquake rubble may <ex>dehydrate</ex> if not found
quickly.</as></def><br/
[<source>PJC</source>]</p>

<p><ent>dehydrated</ent><br/
<hw>dehydrated</hw> <pos>adj.</pos> <sn>1.</sn> <def>thoroughly dried
out.</def><br/
<syn><b>Syn. --</b> desiccated, dried-out.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>suffering from fluid deprivation; <as>as, to become
<ex>dehydrated</ex> from overexertion on a hot day</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dehydration</ent><br/
<hw>De`hy*dra"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>The act or process of freeing from water; also, the condition of a
body from which the water has been removed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dehydrogenate</ent><br/
<hw>De*hy"dro*gen*ate</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<fld>(Chem.)</fld> <def>To deprive of, or free from, hydrogen.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dehydrogenation</ent><br/
<hw>De*hy`dro*gen*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Chem.)</fld> <def>The act or process of freeing from hydrogen;
also, the condition resulting from the removal of hydrogen.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>deice</ent><br/
<hw>de*ice</hw> <pos>v. t.</pos> <def>to remove ice or frost
from.</def><br/
<syn><b>Syn. --</b> defrost.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>deicer</ent><br/
<hw>deicer</hw> <pos>n.</pos> <def>a device that removes ice or frost
(as from a windshield or a refrigerator or the wings of an
airplane).</def><br/
<syn><b>Syn. --</b> defroster.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Deicide</ent><br/
<hw>De"i*cide</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>deicida</ets> a deicide (in sense 2); <ets>deus</ets> god +
<ets>c<ae/dere</ets> to cut, kill: cf. F.
<ets>d<eacute/icide</ets>.]</ety> <sn>1.</sn> <def>The act of killing a
being of a divine nature; particularly, the putting to death of Jesus
Christ.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Earth profaned, yet blessed, with <qex>deicide</qex>.</q>
<rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One concerned in putting Christ to death.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deictic</ent><br/
<hw>Deic"tic</hw> <pr>(d<imac/k"t<icr/k)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>deiktiko`s</grk> serving to show or point out, fr.
<grk>deikny`nai</grk> to show.]</ety> <sn>1.</sn> <fld>(Logic)</fld>
<def>Direct; proving directly; -- applied to reasoning, and opposed to
<contr>elenchtic</contr> or refutative.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Grammar)</fld> <def>showing or pointing to
directly; pertaining to deixis; -- used to designate words that specify
identity, location, or time from the perspective of one of the
participants in a discourse, using the surrounding context as reference;
<as>as, the words <examp>this</examp>, <examp>that</examp>,
<examp>these</examp>, <examp>those</examp>, <examp>here</examp>,
<examp>there</examp>, <examp>now</examp>, <examp>then</examp>,
<examp>we</examp>, <examp>you</examp>, <examp>they</examp>, <examp>the
former</examp>, and <examp>the latter</examp> serve a <ex>deictic</ex>
function</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Deictically</ent><br/
<hw>Deic"tic*al*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a manner
to show or point out; directly; absolutely; definitely.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>When Christ spake it <qex>deictically</qex>.</q>
<rj><qau>Hammond.</qau></rj></p>

<p><ent>Deifical</ent><br/
<ent>Deific</ent><br/
<mhw>{ <hw>De*if"ic</hw> <pr>(?)</pr>, <hw>De*if"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[L. <ets>deificus</ets>;
<ets>deus</ets> god + <ets>facere</ets> to make: cf. F.
<ets>d<eacute/ifique</ets>.]</ety> <def>Making divine; producing a
likeness to God; god-making.</def> <ldquo/A <xex>deifical</xex>
communion.<rdquo/ <rj><au>Homilies.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deification</ent><br/
<hw>De`i*fi*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL.
<ets>deificare</ets> to deify: cf. F. <ets>d<eacute/ification</ets>. See
<er>Deify</er>.]</ety> <def>The act of deifying; exaltation to divine
honors; apotheosis; excessive praise.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deified</ent><br/
<hw>De"i*fied</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Honored or worshiped
as a deity; treated with supreme regard; godlike.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deifier</ent><br/
<hw>De"i*fi`er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
deifies.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deiform</ent><br/
<hw>De"i*form</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>deus</ets>
a god + <ets>-form</ets>.]</ety> <sn>1.</sn> <def>Godlike, or of a
godlike form.</def> <rj><au>Dr. H. More.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Conformable to the will of God.</def>
<mark>[R.]</mark> <rj><au>Bp. Burnet.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deiformity</ent><br/
<hw>De`i*for"mi*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Likeness to
deity.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deify</ent><br/
<hw>De"i*fy</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Deified</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Deifying</conjf>.]</vmorph> <ety>[F. <ets>d<eacute/ifier</ets>,
LL. <ets>deificare</ets>, fr. L. <ets>deificus</ets>. See
<er>Deific</er>, <er>Deity</er>, <er>-fy</er>.]</ety> <sn>1.</sn>
<def>To make a god of; to exalt to the rank of a deity; to enroll among
the deities; to apotheosize; <as>as, Julius C<ae/sar was
<ex>deified</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To praise or revere as a deity; to treat as an
object of supreme regard; <as>as, to <ex>deify</ex>
money</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He did again so extol and <qex>deify</qex> the pope.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To render godlike.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>By our own spirits are we <qex>deified</qex>.</q>
<rj><qau>Wordsworth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deign</ent><br/
<hw>Deign</hw> <pr>(d<amac/n)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Deigned</conjf> <pr>(d<amac/nd)</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>Deigning</conjf>.]</vmorph> <ety>[OE.
<ets>deinen</ets>, <ets>deignen</ets>, OF. <ets>degner</ets>,
<ets>deigner</ets>, <ets>daigner</ets>, F. <ets>daigner</ets>, fr. L.
<ets>dignari</ets> to deem worthy, deign, fr. <ets>dignus</ets> worthy;
akin to <ets>decere</ets> to be fitting. See <er>Decent</er>, and cf.
<er>Dainty</er>, <er>Dignity</er>, <er>Condign</er>,
<er>Disdain</er>.]</ety> <sn>1.</sn> <def>To esteem worthy; to consider
worth notice; -- opposed to <xex>disdain</xex>.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I fear my Julia would not <qex>deign</qex> my lines.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To condescend to give or bestow; to stoop to
furnish; to vouchsafe; to allow; to grant.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Nor would we <qex>deign</qex> him burial of his men.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deign</ent><br/
<hw>Deign</hw>, <pos>v. i.</pos> <def>To think worthy; to vouchsafe; to
condescend; - - followed by an infinitive.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>O <qex>deign</qex> to visit our forsaken seats.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Yet not Lord Cranstone <qex>deigned</qex> she greet.</q>
<rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Round turned he, as not <qex>deigning</qex><br/
Those craven ranks to see.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note>In early English <xex>deign</xex> was often used
impersonally.</note><br/
[<source>1913 Webster</source>]</p>

<p><q>Him <qex>deyneth</qex> not to set his foot to ground.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deignous</ent><br/
<hw>Deign"ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[For
<ets>disdeignous</ets>, OF. <ets>desdeignos</ets>,
<ets>desdaigneus</ets>, F. <ets>d<eacute/daigneux</ets>. See
<er>Disdain</er>.]</ety> <def>Haughty; disdainful.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deil</ent><br/
<hw>Deil</hw> <pr>(d<emac/l)</pr>, <pos>n.</pos> <def>Devil; -- spelt
also <asp>deel</asp>.</def> <mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Deil's buckie</b></col>. <cd>See under
<er>Buckie</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deinoceras</ent><br/
\'d8<hw>Dei*noc"e*ras</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL.]</ety>
<fld>(Paleon.)</fld> <def>See <er>Dinoceras</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deinornis</ent><br/
\'d8<hw>Dei*nor"nis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL.]</ety>
<fld>(Paleon.)</fld> <def>See <er>Dinornis</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deinosaur</ent><br/
\'d8<hw>Dei"no*saur</hw> <pr>(d<imac/"n<osl/*s<add/r)</pr>,
<pos>n.</pos> <ety>[NL.]</ety> <fld>(Paleon.)</fld> <def>See
<er>Dinosaur</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deinotherium</ent><br/
\'d8<hw>Dei`no*the"ri*um</hw>
<pr>(d<imac/`n<osl/*th<emac/"r<icr/*<ucr/m)</pr>, <pos>n.</pos>
<ety>[NL.]</ety> <fld>(Paleon.)</fld> <def>See
<er>Dinotherium</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deintegrate</ent><br/
<hw>De*in"te*grate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>deintegrare</ets> to impair; <ets>de-</ets> + <ets>integrare</ets>
to make whole.]</ety> <def>To disintegrate.</def>
<mark>[Obs.]</mark></p>

<p><ent>Deintevous</ent><br/
<ent>Deinteous</ent><br/
<mhw>{ <hw>Dein"te*ous</hw> <pr>(?)</pr>, <hw>Dein"te*vous</hw>
<pr>(?)</pr> }</mhw>, <pos>a.</pos> <def>Rare; excellent; costly.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>de-iodinase</ent><br/
<hw>de-iodinase</hw> <pos>n.</pos> <def>an enzyme that removes the
iodine radical.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>de-iodinate</ent><br/
<hw>de-iodinate</hw> <pos>v. t.</pos> <fld>(chemistry)</fld> <def>to
remove iodine from.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>de-iodinating</ent><br/
<hw>de-iodinating</hw> <pos>adj.</pos> <def>removing iodine from.</def>
<ant>iodinating</ant><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>de-iodination</ent><br/
<hw>de-iodination</hw> <pos>n.</pos> <def>the removal of iodine atoms
from organic compounds.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>de-ionate</ent><br/
<hw>de-ionate</hw> <pos>v.</pos> <fld>(Chem.)</fld> <def>to remove ions
from.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>deionization</ent><br/
<hw>de*i`on*i*za"tion</hw> <pos>n.</pos> <fld>(Chem.)</fld> <def>the act
or process of removing ions.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>deionize</ent><br/
<hw>de*i"on*ize`</hw> <pos>v. t.</pos> <sn>1.</sn> <fld>(Chem.)</fld>
<def>to remove ions from (a solution).</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>to reassociate the ions of (an ionized gas).</def>
<au>RHUD</au><br/
[<source>PJC</source>]</p>

<p><ent>deionized</ent><br/
<hw>de*i"on*ized`</hw> <pos>a.</pos> <fld>(Chem.)</fld> <def>freed from
ions by a process of deionization; <as>as, <ex>deionized</ex>
water</as>.</def> <note>In chemistry and biochemistry, experiments often
require water free from contaminating ions, and the ordinary distilled
water may be subjected to a process of deionization in order to render
the ion content sufficiently low so as not to interfere with the
investigation.</note><br/
[<source>PJC</source>]</p>

<p><ent>deionizer</ent><br/
<hw>de*i"on*iz`er</hw> <pos>n.</pos> <fld>(Chem.)</fld> <def>an
apparatus used to remove ions from a solution; a common variant contains
a mixture of cation exchange resin in the acid form and anion exchange
resin in the hydroxyl form inside a replaceable cartridge; ions in
aqueous solution are exchanged for the elements of water by passing the
solution through the mixed resin.</def> <note>In chemistry and
biochemistry, experiments often require water free from contaminating
ions, and ordinary distilled water may be further purified by passing
through a <ex>deionizer</ex> in order to render the ion content
sufficiently low so as not to interfere with the
investigation.</note><br/
[<source>PJC</source>]</p>

<p><ent>deiparous</ent><br/
<hw>de*ip"a*rous</hw> <pr>(d<esl/*<icr/p"<adot/*r<ucr/s)</pr>,
<pos>a.</pos> <ety>[L. <ets>deus</ets> a god + <ets>parere</ets> to
bring forth.]</ety> <def>Bearing or bringing forth a god; -- said of the
Virgin Mary.</def> <mark>[Obs.]</mark> <rj><au>Bailey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deipnosophist</ent><br/
<hw>Deip*nos"o*phist</hw> <pr>(d<imac/p*n<ocr/s"<osl/*f<icr/st)</pr>,
<pos>n.</pos> <ety>[Gr. <grk>deipnosofisth`s</grk>; <grk>dei^pnon</grk>
a meal + <grk>sofisth`s</grk> a wise man, sophist.]</ety> <def>One of an
ancient sect of philosophers, who cultivated learned conversation at
meals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deis</ent><br/
<hw>De"is</hw> <pr>(d<emac/"<icr/s)</pr>, <pos>n.</pos> <def>See
<er>Dais</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deism</ent><br/
<hw>De"ism</hw> <pr>(d<emac/"<icr/z'm)</pr>, <pos>n.</pos> <ety>[L.
<ets>deus</ets> god: cf. F. <ets>d<eacute/isme</ets>. See
<er>Deity</er>.]</ety> <def>The doctrine or creed of a deist; the belief
or system of those who acknowledge the existence of one God, but deny
revelation.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <ex>Deism</ex> is the belief in natural religion only,
or those truths, in doctrine and practice, which man is to discover by
the light of reason, independent of any revelation from God. Hence,
<ex>deism</ex> implies <consof>infidelity</consof>, or a disbelief in
the divine origin of the Scriptures.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deist</ent><br/
<hw>De"ist</hw> <pr>(d<emac/"<icr/st)</pr>, <pos>n.</pos> <ety>[L.
<ets>deus</ets> god: cf. F. <ets>d<eacute/iste</ets>. See
<er>Deity</er>.]</ety> <def>One who believes in the existence of a God,
but denies revealed religion; a freethinker.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ A <xex>deist</xex>, as denying a revelation, is opposed
to a Christian; as, opposed to the denier of a God, whether
<contr>atheist</contr> or <contr>pantheist</contr>, a <ex>deist</ex> is
generally denominated <altname>theist</altname>.</note>
<rj><au>Latham.</au></rj></p>

<p><syn><b>Syn.</b> -- See <er>Infidel</er>.</syn></p>

<p><ent>Deistical</ent><br/
<ent>Deistic</ent><br/
<mhw>{ <hw>De*is"tic</hw> <pr>(d<esl/*<icr/s"t<icr/k)</pr>,
<hw>De*is"tic*al</hw> <pr>(?)</pr>, }</mhw> <pos>a.</pos>
<def>Pertaining to, savoring of, or consisting in, deism; <as>as, a
<ex>deistic</ex> writer; a <ex>deistical</ex> book.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>deistical</qex> or antichristian scheme.</q> <rj><qau>I.
Watts.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deistically</ent><br/
<hw>De*is"tic*al*ly</hw>, <pos>adv.</pos> <def>After the manner of
deists.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deisticalness</ent><br/
<hw>De*is"tic*al*ness</hw>, <pos>n.</pos> <def>State of being
deistical.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deitate</ent><br/
<hw>De"i*tate</hw> <pr>(d<emac/"<icr/*t<asl/t)</pr>, <pos>a.</pos>
<def>Deified.</def> <mark>[Obs.]</mark> <rj><au>Cranmer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deity</ent><br/
<hw>De"i*ty</hw> <pr>(d<emac/"<icr/*t<ycr/)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Deities</plw>
<pr>(d<emac/"<icr/*t<icr/z)</pr>.</plu> <ety>[OE. <ets>deite</ets>, F.
<ets>d<eacute/it<eacute/</ets>, fr. L. <ets>deitas</ets>, fr.
<ets>deus</ets> a god; akin to <ets>divus</ets> divine,
<ets>Jupiter</ets>, gen. <ets>Jovis</ets>, Jupiter, <ets>dies</ets> day,
Gr. <grk>di^os</grk> divine, <grk>Zey`s</grk>, gen. <grk>Dio`s</grk>,
Zeus, Skr. <ets>d<emac/va</ets> divine, as a noun, god, <ets>daiva</ets>
divine, <ets>dy<omac/</ets> sky, day, hence, the sky personified as a
god, and to the first syllable of E. <ets>Tues</ets>day, Gael. & Ir.
<ets>dia</ets> God, W. <ets>duw</ets>. Cf. <er>Divine</er>,
<er>Journey</er>, <er>Journal</er>, <er>Tuesday</er>.]</ety> <sn>1.</sn>
<def>The collection of attributes which make up the nature of a god;
divinity; godhead; <as>as, the <ex>deity</ex> of the Supreme Being is
seen in his works</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They declared with emphasis the perfect <qex>deity</qex> and the
perfect manhood of Christ.</q> <rj><qau>Milman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A god or goddess; a heathen god.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To worship calves, the <qex>deities</qex><br/
Of Egypt.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>The Deity</b></col>, <cd>God, the Supreme
Being.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><q>This great poet and philosopher [Simonides], the more he
contemplated the nature of <qex>the Deity</qex>, found that he waded but
the more out of his depth.</q> <rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>deixis</ent><br/
<hw>deixis</hw> <pr>(d<imac/k"s<icr/s)</pr>, <pos>n.</pos>
<fld>(Grammar)</fld> <def>the function or operation of a deictic word;
the function of pointing or specifying from the perspective of a
participant in an act of speech or writing; aspects of a communication
whose interpretation depends on knowledge of the context in which the
communication occurs.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Deject</ent><br/
<hw>De*ject"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Dejected</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Dejecting</conjf>.]</vmorph> <ety>[L. <ets>dejectus</ets>, p. p.
of <ets>dejicere</ets> to throw down; <ets>de-</ets> + <ets>jacere</ets>
to throw. See <er>Jet</er> a shooting forth.]</ety> <sn>1.</sn> <def>To
cast down.</def> <mark>[Obs. or Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Christ <qex>dejected</qex> himself even unto the hells.</q>
<rj><qau>Udall.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Sometimes she <qex>dejects</qex> her eyes in a seeming civility;
and many mistake in her a cunning for a modest look.</q>
<rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To cast down the spirits of; to dispirit; to
discourage; to dishearten.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Nor think, to die <qex>dejects</qex> my lofty mind.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deject</ent><br/
<hw>De*ject"</hw>, <pos>a.</pos> <ety>[L. <ets>dejectus</ets>, p.
p.]</ety> <def>Dejected.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dejecta</ent><br/
\'d8<hw>De*jec"ta</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL., neut.
pl. from L. <ets>dejectus</ets>, p. p.]</ety> <def>Excrements; <as>as,
the <ex>dejecta</ex> of the sick</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dejected</ent><br/
<hw>De*ject"ed</hw>, <pos>a.</pos> <def>Cast down; afflicted;
low-spirited; sad; <as>as, a <ex>dejected</ex> look or
countenance</as>.</def> -- <wordforms><wf>De*ject"ed*ly</wf>,
<pos>adv.</pos> -- <wf>De*ject"ed*ness</wf>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dejecter</ent><br/
<hw>De*ject"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who casts down,
or dejects.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dejection</ent><br/
<hw>De*jec"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>dejectio</ets> a casting down: cf. F.
<ets>d<eacute/jection</ets>.]</ety> <sn>1.</sn> <def>A casting down;
depression.</def> <mark>[Obs. or Archaic]</mark>
<rj><au>Hallywell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The act of humbling or abasing one's self.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Adoration implies submission and <qex>dejection</qex>.</q>
<rj><qau>Bp. Pearson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Lowness of spirits occasioned by grief or
misfortune; mental depression; melancholy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>What besides,<br/
Of sorrow, and <qex>dejection</qex>, and despair,<br/
Our frailty can sustain, thy tidings bring.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A low condition; weakness; inability.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>dejection</qex> of appetite.</q>
<rj><qau>Arbuthnot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Physiol.)</fld> <sd>(a)</sd> <def>The discharge of
excrement.</def> <sd>(b)</sd> <def>F<ae/ces; excrement.</def>
<rj><au>Ray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dejectly</ent><br/
<hw>De*ject"ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>Dejectedly.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dejectory</ent><br/
<hw>De*jec"to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>dejector</ets> a dejecter.]</ety> <sn>1.</sn> <def>Having power, or
tending, to cast down.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Promoting evacuations by stool.</def>
<rj><au>Ferrand.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dejecture</ent><br/
<hw>De*jec"ture</hw> <pr>(?; 135)</pr>, <pos>n.</pos> <def>That which is
voided; excrements.</def> <rj><au>Arbuthnot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dejerate</ent><br/
<hw>Dej"er*ate</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[L.
<ets>dejeratus</ets>, p. p. of <ets>dejerare</ets> to swear;
<ets>de-</ets> + <ets>jurare</ets> to swear.]</ety> <def>To swear
solemnly; to take an oath.</def> <mark>[Obs.]</mark>
<rj><au>Cockeram.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dejeration</ent><br/
<hw>Dej`er*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>dejeratio</ets>.]</ety> <def>The act of swearing solemnly.</def>
<mark>[Obs.]</mark> <rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dejeune</ent><br/
\'d8<hw>D<eacute/`jeu`n<eacute/"</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[F.]</ety> <def>A d<eacute/jeuner.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Take a <qex>d<eacute/jeun<eacute/</qex> of muskadel and eggs.</q>
<rj><qau>B. Jonson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dejeuner</ent><br/
\'d8<hw>D<eacute/`jeu`ner"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>d<eacute/jeuner</ets> breakfast, as a verb, to breakfast. Cf.
<er>Dinner</er>.]</ety> <def>A breakfast; sometimes, also, a lunch or
collation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>De jure</ent><br/
\'d8<hw>De` ju"re</hw> <pr>(?)</pr>. <ety>[L.]</ety> <def>By right; of
right; by law; -- often opposed to <contr>de facto</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deka-</ent><br/
<hw>Dek"a-</hw> <pr>(?)</pr>. <fld>(Metric System)</fld> <def>A prefix
signifying <sig>ten</sig>. See <er>Deca-</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dekabrist</ent><br/
<hw>Dek"a*brist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A
<er>Decembrist</er>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Dekagram</ent><br/
<hw>Dek"a*gram</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Decagram</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dekaliter</ent><br/
<hw>Dek"a*li`ter</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Decaliter</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dekameter</ent><br/
<hw>Dek"a*me`ter</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Decameter</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dekastere</ent><br/
<hw>Dek"a*stere`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Decastere</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dekle</ent><br/
<hw>De"kle</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Paper Making)</fld>
<def>See <er>Deckle</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Del</ent><br/
<hw>Del</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See <er>Deal</er>,
<pos>n.</pos>]</ety> <def>Share; portion; part.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>del</ent><br/
<hw>del</hw> <pos>n.</pos> <fld>(Math.)</fld> <def>a differential
operator which, operating on a function of several variables, gives the
sum of the partial derivatives of the function with respect to the three
orthogonal spatial coordinates; -- also called the
<altname>gradient</altname> or <altname>grad</altname>. It is
represented by an inverted Greek capital delta (<nabla/), and is thus
because of its shape also called <altname>nabla</altname>, meaning
<it>harp</it> in Hebrew.</def><br/
[<source>PJC</source>]</p>

<p><ent>Delaceration</ent><br/
<hw>De*lac`er*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>delacerare</ets>, <ets>delaceratum</ets>, to tear in pieces. See
<er>Lacerate</er>.]</ety> <def>A tearing in pieces.</def>
<mark>[Obs.]</mark> <rj><au>Bailey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delacrymation</ent><br/
<hw>De*lac`ry*ma"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>delacrimatio</ets>, fr. <ets>delacrimare</ets> to weep. See
<er>Lachrymation</er>.]</ety> <def>An involuntary discharge of watery
humors from the eyes; wateriness of the eyes.</def> <mark>[Obs.]</mark>
<rj><au>Bailey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delactation</ent><br/
<hw>De`lac*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>de-</ets> + L. <ets>lactare</ets> to suck milk, from <ets>lac</ets>
milk.]</ety> <def>The act of weaning.</def> <mark>[Obs.]</mark>
<rj><au>Bailey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delaine</ent><br/
<hw>De*laine"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See <ets>Muslin
delaine</ets>, under <er>Muslin</er>.]</ety> <def>A kind of fabric for
women's dresses.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delamination</ent><br/
<hw>De*lam`i*na"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Biol.)</fld>
<def>Formation and separation of lamin<ae/ or layers; one of the methods
by which the various blastodermic layers of the ovum are
differentiated.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ This process consists of a concentric splitting of the
cells of the blastosphere into an outer layer (epiblast) and an inner
layer (hypoblast). By the perforation of the resultant two-walled
vesicle, a gastrula results similar to that formed by the process of
invagination.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delapsation</ent><br/
<hw>De`lap*sa"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Delapsion</er>.</def> <rj><au>Ray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delapse</ent><br/
<hw>De*lapse"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Delapsed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Delapsing</conjf>.]</vmorph> <ety>[L.
<ets>delapsus</ets>, p. p. of <ets>delabi</ets> to fall down;
<ets>de-</ets> + <ets>labi</ets> to fall or side.]</ety> <def>To pass
down by inheritance; to lapse.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Which Anne derived alone the right, before all other,<br/
Of the <qex>delapsed</qex> crown from Philip.</q>
<rj><qau>Drayton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 385 --></p>

<p><ent>Delapsion</ent><br/
<hw>De*lap"sion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A falling down, or
out of place; prolapsion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delassation</ent><br/
<hw>De`las*sa"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>delassare</ets>, <ets>delassatum</ets>, to tire out; <ets>de-</ets>
+ <ets>lassare</ets> to tire.]</ety> <def>Fatigue.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Able to continue without <qex>delassation</qex>.</q>
<rj><qau>Ray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delate</ent><br/
<hw>De*late"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Delated</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Delating</conjf>.]</vmorph> <ety>[L. <ets>delatus</ets>, used as
p. p. of <ets>deferre</ets>. See <er>Tolerate</er>, and cf. 3d
<er>Defer</er>, <er>Delay</er>, <pos>v.</pos>]</ety> <mark>[Obs. or
Archaic]</mark> <sn>1.</sn> <def>To carry; to convey.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Try exactly the time wherein sound is <qex>delated</qex>.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To carry abroad; to spread; to make
public.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>When the crime is <qex>delated</qex> or notorious.</q>
<rj><qau>Jer. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To carry or bring against, as a charge; to inform
against; to accuse; to denounce.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>As men were <qex>delated</qex>, they were marked down for such a
fine.</q> <rj><qau>Bp. Burnet.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To carry on; to conduct.</def>
<rj><au>Warner.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delate</ent><br/
<hw>De*late"</hw>, <pos>v. i.</pos> <def>To dilate.</def>
<mark>[Obs.]</mark> <rj><au>Goodwin.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delation</ent><br/
<hw>De*la"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>delatio</ets> accusation: cf. F. <ets>d<eacute/lation</ets>.]</ety>
<sn>1.</sn> <def>Conveyance.</def> <mark>[Obs. or Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>In <qex>delation</qex> of sounds, the inclosure of them preserveth
them.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>Accusation by an informer.</def>
<rj><au>Milman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delator</ent><br/
<hw>De*la"tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.]</ety> <def>An
accuser; an informer.</def> <mark>[R.]</mark>
<rj><au>Howell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delaware</ent><br/
<hw>Del"a*ware</hw> <pr>(d<ecr/l"<adot/*w<acir/r)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>one of the thirteen original states of the United
States of America.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>An American grape, with compact
bunches of small, amber-colored berries, sweet and of a good
flavor.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delawarean</ent><br/
<hw>Delawarean</hw> <pos>n.</pos> <def>a resident of Delaware.</def><br/
<syn><b>Syn. --</b> Delawarian.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Delawarian</ent><br/
<hw>Delawarian</hw> <pos>n.</pos> <def>a resident of Delaware.</def><br/
<syn><b>Syn. --</b> Delawarean.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Delawares</ent><br/
<hw>Del"a*wares</hw> <pr>(d<ecr/l"<adot/*w<acir/rz)</pr>, <pos>n.
pl.</pos>; <sing>sing. <singw>Delaware</singw>.</sing>
<fld>(Ethnol.)</fld> <def>A tribe of Indians formerly inhabiting the
valley of the Delaware River, but now mostly located in the Indian
Territory.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delay</ent><br/
<hw>De*lay"</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Delays</plw> <pr>(#)</pr>.</plu> <ety>[F. <ets>d<eacute/lai</ets>,
fr. OF. <ets>deleer</ets> to delay, or fr. L. <ets>dilatum</ets>, which,
though really from a different root, is used in Latin only as a p. p.
neut. of <ets>differre</ets> to carry apart, defer, delay. See
<er>Tolerate</er>, and cf. <er>Differ</er>, <er>Delay</er>,
<pos>v.</pos>]</ety> <def>A putting off or deferring; procrastination;
lingering inactivity; stop; detention; hindrance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Without any <qex>delay</qex>, on the morrow I sat on the judgment
seat.</q> <rj><qau>Acts xxv. 17.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The government ought to be settled without the <qex>delay</qex> of
a day.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delay</ent><br/
<hw>De*lay"</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Delayed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Delaying</conjf>.]</vmorph> <ety>[OF. <ets>deleer</ets>,
<ets>delaier</ets>, fr. the noun <ets>d<eacute/lai</ets>, or directly
fr. L. <ets>dilatare</ets> to enlarge, dilate, in LL., to put off. See
<er>Delay</er>, <pos>n.</pos>, and cf. <er>Delate</er>, 1st
<er>Defer</er>, <er>Dilate</er>.]</ety> <sn>1.</sn> <def>To put off; to
defer; to procrastinate; to prolong the time of or before.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>My lord <qex>delayeth</qex> his coming.</q> <rj><qau>Matt. xxiv.
48.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To retard; to stop, detain, or hinder, for a time;
to retard the motion, or time of arrival, of; <as>as, the mail is
<ex>delayed</ex> by a heavy fall of snow</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thyrsis! whose artful strains have oft <qex>delayed</qex><br/
The huddling brook to hear his madrigal.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To allay; to temper.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The watery showers <qex>delay</qex> the raging wind.</q>
<rj><qau>Surrey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delay</ent><br/
<hw>De*lay"</hw>, <pos>v. i.</pos> <def>To move slowly; to stop for a
time; to linger; to tarry.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There seem to be certain bounds to the quickness and slowness of
the succession of those ideas, . . . beyond which they can neither
<qex>delay</qex> nor hasten.</q> <rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delayer</ent><br/
<hw>De*lay"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who delays; one
who lingers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delayingly</ent><br/
<hw>De*lay"ing*ly</hw>, <pos>adv.</pos> <def>By delays.</def>
<mark>[R.]</mark> <rj><au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delayment</ent><br/
<hw>De*lay"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Hindrance.</def>
<mark>[Obs.]</mark> <rj><au>Gower.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Del credere</ent><br/
\'d8<hw>Del` cred"er*e</hw> <pr>(?)</pr>. <ety>[It., of belief or
trust.]</ety> <fld>(Mercantile Law)</fld> <def>An agreement by which an
agent or factor, in consideration of an additional premium or commission
(called a <xex>del credere</xex> commission), engages, when he sells
goods on credit, to insure, warrant, or guarantee to his principal the
solvency of the purchaser, the engagement of the factor being to pay the
debt himself if it is not punctually discharged by the buyer when it
becomes due.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dele</ent><br/
<hw>De"le</hw> <pr>(?)</pr>, <pos>imperative sing.</pos> <mord>of L.
<xex>delere</xex> to destroy</mord>. <ety>[Cf. <er>Delete</er>.]</ety>
<fld>(Print.)</fld> <def>Erase; remove; -- a direction to cancel
something which has been put in type; usually expressed by a peculiar
form of <xex>d</xex>, thus: <dele/.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dele</ent><br/
<hw>De"le</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Deled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Deleing</conjf>.]</vmorph> <ety>[From the preceding word.]</ety>
<fld>(Print.)</fld> <def>To erase; to cancel; to delete; to mark for
omission.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dele</ent><br/
<hw>Dele</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[See
<er>Deal</er>.]</ety> <def>To deal; to divide; to distribute.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deleble</ent><br/
<hw>Del"e*ble</hw> <pr>(?; 277)</pr>, <pos>a.</pos> <ety>[L.
<ets>delebilis</ets>. See 1st <er>Dele</er>.]</ety> <def>Capable of
being blotted out or erased.</def> <ldquo/An impression easily
<xex>deleble</xex>.<rdquo/ <rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delectable</ent><br/
<hw>De*lec"ta*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OF.
<ets>delitable</ets>, OF. <ets>delitable</ets>, F.
<ets>d<eacute/lectable</ets>, fr. L. <ets>delectabilis</ets>, fr.
<ets>delectare</ets> to delight. See <er>Delight</er>.]</ety>
<sn>1.</sn> <def>Highly pleasing; delightful.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Delectable</qex> both to behold and taste.</q>
<rj><qau>Milton.</qau></rj></p>

<p><sn>2.</sn> <def>extremely pleasing to the sense of taste; same as
<er>luscious</er>, 1.</def><br/
<syn><b>Syn. --</b> delicious, luscious, pleasant-tasting, scrumptious,
toothsome, yummy.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p>-- <wordforms><wf>De*lec"ta*ble*ness</wf>, <pos>n.</pos> --
<wf>De*lec"ta*bly</wf>, <pos>adv.</pos> -- <wf>De*lec`ta*bil"i*ty</wf>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delectate</ent><br/
<hw>De*lec"tate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>delectatus</ets>, p. p. of <ets>delectare</ets>. See
<er>Delight</er>.]</ety> <def>To delight; to charm.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delectation</ent><br/
<hw>De`lec*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>delectatio</ets>: cf. F. <ets>d<eacute/lectation</ets>.]</ety>
<def>Great pleasure; delight.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delectus</ent><br/
\'d8<hw>De*lec"tus</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., selection,
from <ets>deligere</ets>, <ets>delectum</ets>, to select.]</ety> <def>A
name given to an elementary book for learners of Latin or Greek.</def>
<rj><au>G. Eliot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delegacy</ent><br/
<hw>Del`e*ga*cy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<er>Delegate</er>, <pos>a.</pos>]</ety> <sn>1.</sn> <def>The act of
delegating, or state of being delegated; deputed power.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>By way of <qex>delegacy</qex> or grand commission.</q>
<rj><qau>Sir W. Raleigh.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A body of delegates or commissioners; a
delegation.</def> <mark>[Obs.]</mark> <rj><au>Burton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delegate</ent><br/
<hw>Del"e*gate</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>delegatus</ets>, p. p. of <ets>delegare</ets> to send, delegate;
<ets>de-</ets> + <ets>legare</ets> to send with a commission, to depute.
See <er>Legate</er>.]</ety> <sn>1.</sn> <def>Any one sent and empowered
to act for another; one deputed to represent; a chosen deputy; a
representative; a commissioner; a vicar.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <sd>(a)</sd> <def>One elected by the people of a
territory to represent them in Congress, where he has the right of
debating, but not of voting.</def> <sd>(b)</sd> <def>One sent by any
constituency to act as its representative in a convention; <as>as, a
<ex>delegate</ex> to a convention for nominating officers, or for
forming or altering a constitution</as>.</def> <mark>[U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Court of delegates</b></col>, <cd>formerly, the great
court of appeal from the archbishops' courts and also from the court of
admiralty. It is now abolished, and the privy council is the immediate
court of appeal in such cases.</cd> <mark>[Eng.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delegate</ent><br/
<hw>Del"e*gate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>delegatus</ets>, p. p.]</ety> <def>Sent to act for or represent
another; deputed; <as>as, a <ex>delegate</ex> judge</as>.</def>
<ldquo/<xex>Delegate</xex> power.<rdquo/ <rj><au>Strype.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delegate</ent><br/
<hw>Del"e*gate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Delegated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Delegating</conjf> <pr>(?)</pr>.]</vmorph> <sn>1.</sn>
<def>To send as one's representative; to empower as an ambassador; to
send with power to transact business; to commission; to depute; to
authorize.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To intrust to the care or management of another; to
transfer; to assign; to commit.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>delegated</qex> administration of the law.</q>
<rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Delegated</qex> executive power.</q>
<rj><qau>Bancroft.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The power exercised by the legislature is the people's power,
<qex>delegated</qex> by the people to the legislative.</q> <rj><qau>J.
B. Finch.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>delegating</ent><br/
<hw>delegating</hw> <pos>n.</pos> <def>the act or process of authorizing
subordinates to make certain decisions.</def><br/
<syn><b>Syn. --</b> delegation, relegating, relegation,
deputation.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Delegation</ent><br/
<hw>Del`e*ga"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>delegatio</ets>: cf. F. <ets>d<eacute/l<eacute/gation</ets>.]</ety>
<sn>1.</sn> <def>The act of delegating, or investing with authority to
act for another; the appointment of a delegate or delegates.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One or more persons appointed or chosen, and
commissioned to represent others, as in a convention, in Congress, etc.;
the collective body of delegates; <as>as, the <ex>delegation</ex> from
Massachusetts</as>; a deputation.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Rom. Law)</fld> <def>A kind of novation by which a
debtor, to be liberated from his creditor, gives him a third person, who
becomes obliged in his stead to the creditor, or to the person appointed
by him.</def> <rj><au>Pothier.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delegatory</ent><br/
<hw>Del"e*ga*to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>delegatorius</ets> pert. to an assignment.]</ety> <def>Holding a
delegated position.</def> <rj><au>Nash.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delenda</ent><br/
\'d8<hw>De*len"da</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[L., fr.
<ets>delere</ets> to destroy.]</ety> <def>Things to be erased or blotted
out.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delenifical</ent><br/
<hw>Del`e*nif"ic*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>delenificus</ets>; <ets>delenire</ets> to soothe +
<ets>facere</ets> to make. See <er>Lenient</er>.]</ety> <def>Assuaging
pain.</def> <mark>[Obs.]</mark> <rj><au>Bailey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delete</ent><br/
<hw>De*lete"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Deleted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Deleting</conjf>.]</vmorph> <ety>[L. <ets>deletus</ets>, p. p. of
<ets>delere</ets> to destroy. Cf. 1st <er>Dele</er>.]</ety> <def>To blot
out; to erase; to expunge; to dele; to omit.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I have, therefore, . . . inserted eleven stanzas which do not
appear in Sir Walter Scott's version, and have <qex>deleted</qex>
eight.</q> <rj><qau>Aytoun.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deleterious</ent><br/
<hw>Del`e*te"ri*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[LL.
<ets>deleterius</ets> noxious, Gr. <grk>dhlhth`rios</grk>, fr.
<grk>dhlei^sqai</grk> to hurt, damage; prob. akin to L.
<ets>delere</ets> to destroy.]</ety> <def>Hurtful; noxious; destructive;
pernicious; <as>as, a <ex>deleterious</ex> plant or quality; a
<ex>deleterious</ex> example.</as></def> --
<wordforms><wf>Del`e*te"ri*ous*ly</wf>, <pos>adv.</pos> --
<wf>Del`e*te"ri*ous*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deletery</ent><br/
<hw>Del"e*ter*y</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[LL.
<ets>deleterius</ets>: cf. F.
<ets>d<eacute/l<eacute/t<egrave/re</ets>.]</ety> <def>Destructive;
poisonous.</def> <mark>[Obs.]</mark> <ldquo/<xex>Deletery</xex>
medicines.<rdquo/ <rj><au>Hudibras.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deletery</ent><br/
<hw>Del"e*ter*y</hw>, <pos>n.</pos> <def>That which destroys.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>They [the Scriptures] are the only <qex>deletery</qex> of
heresies.</q> <rj><qau>Jer. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deletion</ent><br/
<hw>De*le"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>deletio</ets>, fr. <ets>delere</ets>. See <er>Delete</er>.]</ety>
<def>Act of deleting, blotting out, or erasing; destruction.</def>
<mark>[Obs.]</mark> <rj><au>Jer. Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A total <qex>deletion</qex> of every person of the opposing
party.</q> <rj><qau>Sir M. Hale.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deletitious</ent><br/
<hw>Del`e*ti"tious</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>deleticius</ets>.]</ety> <def>Of such a nature that anything may be
erased from it; -- said of paper.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deletive</ent><br/
<hw>Del"e*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Adapted to destroy
or obliterate.</def> <mark>[R.]</mark> <rj><au>Evelyn.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deletory</ent><br/
<hw>Del"e*to*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Delete</er>.]</ety> <def>That which blots out.</def>
<mark>[Obs.]</mark> <ldquo/A <xex>deletory</xex> of sin.<rdquo/
<rj><au>Jer. Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delf</ent><br/
<hw>Delf</hw> <pr>(d<ecr/lf)</pr>, <pos>n.</pos> <ety>[AS.
<ets>delf</ets> a delving, digging. See <er>Delve</er>.]</ety> <def>A
mine; a quarry; a pit dug; a ditch.</def> <altsp>[Written also
<asp>delft</asp>, and <asp>delve</asp>.]</altsp> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>delfts</qex> would be so flown with waters, that no gins
or machines could . . . keep them dry.</q> <rj><qau>Ray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>delf</ent><br/
<hw>delf</hw>, <pos>n.</pos> <def>Same as <er>Delftware</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>delft</ent><br/
<hw>delft</hw> <pr>(d<ecr/lft)</pr>, <pos>n.</pos> <def>Same as
<er>Delftware</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delftware</ent><br/
<hw>Delft"ware`</hw> <pr>(?)</pr>, <pos>n.</pos> <sd>(a)</sd>
<def>Pottery made at the city of <city><etsep>Delft</etsep></city> in
Holland; hence:</def> <sd>(b)</sd> <def>Earthenware made in imitation of
the above; any glazed earthenware made for table use, and the
like.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delibate</ent><br/
<hw>Del"i*bate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>delibatus</ets>, p. p. of <ets>delibare</ets> to taste;
<ets>de-</ets> + <ets>libare</ets> to taste.]</ety> <def>To taste; to
take a sip of; to dabble in.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delibation</ent><br/
<hw>Del`i*ba"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>delibatio</ets>: cf. F. <ets>d<eacute/libation</ets>.]</ety>
<def>Act of tasting; a slight trial.</def> <mark>[Obs.]</mark>
<rj><au>Berkeley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deliber</ent><br/
<hw>Del"i*ber</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <def>To
deliberate.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deliberate</ent><br/
<hw>De*lib"er*ate</hw> <pr>(d<esl/*l<icr/b"<etil/r*<asl/t)</pr>,
<pos>a.</pos> <ety>[L. <ets>deliberatus</ets>, p. p. of
<ets>deliberare</ets> to deliberate; <ets>de-</ets> + <ets>librare</ets>
to weigh. See <er>Librate</er>.]</ety> <sn>1.</sn> <def>Weighing facts
and arguments with a view to a choice or decision; carefully considering
the probable consequences of a step; circumspect; slow in determining;
-- applied to persons; <as>as, a <ex>deliberate</ex> judge or
counselor</as>.</def> <ldquo/These <xex>deliberate</xex> fools.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Formed with deliberation; well-advised; carefully
considered; not sudden or rash; <as>as, a <ex>deliberate</ex> opinion; a
<ex>deliberate</ex> measure or result.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Settled visage and <qex>deliberate</qex> word.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Not hasty or sudden; slow.</def>
<rj><au>Hooker.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>His enunciation was so <qex>deliberate</qex>.</q> <rj><qau>W.
Wirt.</qau></rj></p>

<p><sn>4.</sn> <def>having awareness of the likely consequences;
intentional.</def><br/
[<source>PJC</source>]</p>

<p><ent>Deliberate</ent><br/
<hw>De*lib"er*ate</hw> <pr>(d<esl/*l<icr/b"<etil/r*<amac/t)</pr>,
<pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Deliberated</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Deliberating</conjf>.]</vmorph> <def>To weigh in the mind; to
consider the reasons for and against; to consider maturely; to reflect
upon; to ponder; <as>as, to <ex>deliberate</ex> a
question</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deliberate</ent><br/
<hw>De*lib"er*ate</hw>, <pos>v. i.</pos> <def>To take counsel with one's
self; to weigh the arguments for and against a proposed course of
action; to reflect; to consider; to hesitate in deciding; -- sometimes
with <xex>on</xex>, <xex>upon</xex>, <xex>about</xex>,
<xex>concerning</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The woman that <qex>deliberates</qex> is lost.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deliberately</ent><br/
<hw>De*lib"er*ate*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>With
careful consideration, or deliberation; circumspectly; warily; not
hastily or rashly; slowly; <as>as, a purpose <ex>deliberately</ex>
formed</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deliberateness</ent><br/
<hw>De*lib"er*ate*ness</hw>, <pos>n.</pos> <def>The quality of being
deliberate; calm consideration; circumspection.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deliberation</ent><br/
<hw>De*lib`er*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>deliberatio</ets>: cf. F.
<ets>d<eacute/lib<eacute/ration</ets>.]</ety> <sn>1.</sn> <def>The act
of deliberating, or of weighing and examining the reasons for and
against a choice or measure; careful consideration; mature
reflection.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Choosing the fairest way with a calm <qex>deliberation</qex>.</q>
<rj><qau>W. Montagu.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Careful discussion and examination of the reasons
for and against a measure; <as>as, the <ex>deliberations</ex> of a
legislative body or council</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deliberative</ent><br/
<hw>De*lib"er*a*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>deliberativus</ets>: cf. F.
<ets>d<eacute/lib<eacute/ratif</ets>.]</ety> <def>Pertaining to
deliberation; proceeding or acting by deliberation, or by discussion and
examination; deliberating; <as>as, a <ex>deliberative</ex>
body</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A consummate work of <qex>deliberative</qex> wisdom.</q>
<rj><qau>Bancroft.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The court of jurisdiction is to be distinguished from the
<qex>deliberative</qex> body, the advisers of the crown.</q>
<rj><qau>Hallam.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deliberative</ent><br/
<hw>De*lib"er*a*tive</hw>, <pos>n.</pos> <sn>1.</sn> <def>A discourse in
which a question is discussed, or weighed and examined.</def>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A kind of rhetoric employed in proving a thing and
convincing others of its truth, in order to persuade them to adopt
it.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deliberatively</ent><br/
<hw>De*lib"er*a*tive*ly</hw>, <pos>adv.</pos> <def>In a deliberative
manner; circumspectly; considerately.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deliberator</ent><br/
<hw>De*lib"er*a`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
deliberates.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delibrate</ent><br/
<hw>Del"i*brate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Delibrated</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Delibrating</conjf>.]</vmorph> <ety>[L. <ets>delibratus</ets>, p.
p. of <ets>delibrare</ets> to delibrate; <ets>de</ets> from +
<ets>liber</ets> bark.]</ety> <def>To strip off the bark; to peel.</def>
<mark>[Obs.]</mark> <rj><au>Ash.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delibration</ent><br/
<hw>Del`i*bra"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
stripping off the bark.</def> <mark>[Obs.]</mark>
<rj><au>Ash.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delicacy</ent><br/
<hw>Del"i*ca*cy</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Delicacies</plw> <pr>(#)</pr>.</plu> <ety>[From <er>Delicate</er>,
<pos>a.</pos>]</ety> <sn>1.</sn> <def>The state or condition of being
delicate; agreeableness to the senses; delightfulness; <as>as,
<ex>delicacy</ex> of flavor, of odor, and the like</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>What choice to choose for <qex>delicacy</qex> best.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Nicety or fineness of form, texture, or
constitution; softness; elegance; smoothness; tenderness; and hence,
frailty or weakness; <as>as, the <ex>delicacy</ex> of a fiber or a
thread; <ex>delicacy</ex> of a hand or of the human form;
<ex>delicacy</ex> of the skin; <ex>delicacy</ex> of
frame.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Nice propriety of manners or conduct; susceptibility
or tenderness of feeling; refinement; fastidiousness; and hence, in an
exaggerated sense, effeminacy; <as>as, great <ex>delicacy</ex> of
behavior; <ex>delicacy</ex> in doing a kindness; <ex>delicacy</ex> of
character that unfits for earnest action.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>You know your mother's <qex>delicacy</qex> in this point.</q>
<rj><qau>Cowper.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Addiction to pleasure; luxury; daintiness;
indulgence; luxurious or voluptuous treatment.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And to those dainty limbs which Nature lent<br/
For gentle usage and soft <qex>delicacy</qex>?</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Nice and refined perception and discrimination;
critical niceness; fastidious accuracy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That Augustan <qex>delicacy</qex> of taste which is the boast of
the great public schools of England.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>The state of being affected by slight causes;
sensitiveness; <as>as, the <ex>delicacy</ex> of a chemist's
balance</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>That which is alluring, delicate, or refined; a
luxury or pleasure; something pleasant to the senses, especially to the
sense of taste; a dainty; <as>as, <ex>delicacies</ex> of the
table</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The merchants of the earth are waxed rich through the abundance of
her <qex>delicacies</qex>.</q> <rj><qau>Rev. xviii. 3.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>Pleasure; gratification; delight.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He Rome brent for his <qex>delicacie</qex>.</q>
<rj><qau>Chaucer.</qau></rj></p>

<p><syn><b>Syn.</b> -- See <er>Dainty</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delicate</ent><br/
<hw>Del"i*cate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>delicatus</ets> pleasing the senses, voluptuous, soft and tender;
akin to <ets>deliciae</ets> delight: cf. F. <ets>d<eacute/licat</ets>.
See <er>Delight</er>.]</ety> <sn>1.</sn> <def>Addicted to pleasure;
luxurious; voluptuous; alluring.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Dives, for his <qex>delicate</qex> life, to the devil went.</q>
<rj><qau>Piers Plowman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Haarlem is a very <qex>delicate</qex> town.</q>
<rj><qau>Evelyn.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Pleasing to the senses; refinedly agreeable; hence,
adapted to please a nice or cultivated taste; nice; fine; elegant;
<as>as, a <ex>delicate</ex> dish; <ex>delicate</ex>
flavor.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Slight and shapely; lovely; graceful; <as>as,
<ldquo/a <ex>delicate</ex> creature</as>.<rdquo/</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Fine or slender; minute; not coarse; -- said of a
thread, or the like; <as>as, <ex>delicate</ex> cotton</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Slight or smooth; light and yielding; -- said of
texture; <as>as, <ex>delicate</ex> lace or silk</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Soft and fair; -- said of the skin or a surface;
<as>as, a <ex>delicate</ex> cheek; a <ex>delicate</ex>
complexion.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>Light, or softly tinted; -- said of a color; <as>as,
a <ex>delicate</ex> blue</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>Refined; gentle; scrupulous not to trespass or
offend; considerate; -- said of manners, conduct, or feelings; <as>as,
<ex>delicate</ex> behavior; <ex>delicate</ex> attentions;
<ex>delicate</ex> thoughtfulness.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>Tender; not able to endure hardship; feeble; frail;
effeminate; -- said of constitution, health, etc.; <as>as, a
<ex>delicate</ex> child; <ex>delicate</ex> health.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>delicate</qex> and tender prince.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <def>Requiring careful handling; not to be rudely or
hastily dealt with; nice; critical; <as>as, a <ex>delicate</ex> subject
or question</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There are some things too <qex>delicate</qex> and too sacred to be
handled rudely without injury to truth.</q> <rj><qau>F. W.
Robertson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>11.</sn> <def>Of exacting tastes and habits; dainty;
fastidious.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>12.</sn> <def>Nicely discriminating or perceptive; refinedly
critical; sensitive; exquisite; <as>as, a <ex>delicate</ex> taste; a
<ex>delicate</ex> ear for music.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>13.</sn> <def>Affected by slight causes; showing slight changes;
<as>as, a <ex>delicate</ex> thermometer</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delicate</ent><br/
<hw>Del"i*cate</hw>, <pos>n.</pos> <sn>1.</sn> <def>A choice dainty; a
delicacy.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>With abstinence all <qex>delicates</qex> he sees.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 386 --></p>

<p><sn>2.</sn> <def>A delicate, luxurious, or effeminate
person.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>All the vessels, then, which our <qex>delicates</qex> have, --
those I mean that would seem to be more fine in their houses than their
neighbors, -- are only of the Corinth metal.</q>
<rj><qau>Holland.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delicately</ent><br/
<hw>Del"i*cate*ly</hw> <pr>(d<ecr/l"<icr/*k<asl/t*l<ycr/)</pr>,
<pos>adv.</pos> <def>In a delicate manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delicateness</ent><br/
<hw>Del"i*cate*ness</hw>, <pos>n.</pos> <def>The quality of being
delicate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delicatessen</ent><br/
<hw>Del`i*ca*tes"sen</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[G., fr.
F. <ets>d<eacute/licatesse</ets>.]</ety> <sn>1.</sn> <def>Relishes for
the table; dainties; delicacies.</def> <ldquo/A dealer in
<xex>delicatessen</xex><rdquo/. <rj><au>G. H. Putnam.</au></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>ready-to-eat foods, such as cold cuts, cooked meats,
and prepared salads.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <singf>sing.</singf>; <plu><it>pl.</it>
<plw>delicatessens</plw>.</plu> <def>a store or section of a store where
delicatessen{2} is sold.</def> <ldquo/Get a sandwich for lunch at the
<ex>delicatessen</ex> counter.<rdquo/<br/
[<source>PJC</source>]</p>

<p><ent>Delices</ent><br/
<hw>Del"i*ces</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[F.
<ets>d<eacute/lices</ets>, fr. L. <ets>deliciae</ets>.]</ety>
<def>Delicacies; delights.</def> <mark>[Obs.]</mark> <ldquo/Dainty
<xex>delices</xex>.<rdquo/ <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deliciate</ent><br/
<hw>De*li"ci*ate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To delight
one's self; to indulge in feasting; to revel.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delicious</ent><br/
<hw>De*li"cious</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OF.
<ets>delicieus</ets>, F. <ets>d<eacute/licieux</ets>, L.
<ets>deliciosus</ets>, fr. <ets>deliciae</ets> delight, fr.
<ets>delicere</ets> to allure. See <er>Delight</er>.]</ety> <sn>1.</sn>
<def>Affording exquisite pleasure; delightful; most sweet or grateful to
the senses, especially to the taste; charming.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Some <qex>delicious</qex> landscape.</q>
<rj><qau>Coleridge.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>One draught of spring's <qex>delicious</qex> air.</q>
<rj><qau>Keble.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Were not his words <qex>delicious</qex>?</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Addicted to pleasure; seeking enjoyment; luxurious;
effeminate.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Others, lastly, of a more <qex>delicious</qex> and airy spirit,
retire themselves to the enjoyments of ease and luxury.</q>
<rj><qau>Milton.</qau></rj></p>

<p><syn><b>Syn.</b> -- <er>Delicious</er>, <er>Delightful</er>.</syn>
<usage> <xex>Delicious</xex> refers to the pleasure derived from certain
of the senses, particularly the taste and smell; as, <ex>delicious</ex>
food; a <xex>delicious</xex> fragrance. <xex>Delightful</xex> may also
refer to most of the senses (as, <xex>delightful</xex> music; a
<xex>delightful</xex> prospect; <xex>delightful</xex> sensations), but
has a higher application to matters of taste, feeling, and sentiment;
as, a <ex>delightful</ex> abode, conversation, employment;
<xex>delightful</xex> scenes, etc.</usage><br/
[<source>1913 Webster</source>]</p>

<p><q>Like the rich fruit he sings, <qex>delicious</qex> in decay.</q>
<rj><qau>Smith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>No spring, nor summer, on the mountain seen,<br/
Smiles with gay fruits or with <qex>delightful</qex> green.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deliciously</ent><br/
<hw>De*li"cious*ly</hw>, <pos>adv.</pos> <def>Delightfully; <as>as, to
feed <ex>deliciously</ex>; to be <ex>deliciously</ex>
entertained.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deliciousness</ent><br/
<hw>De*li"cious*ness</hw>, <pos>n.</pos> <sn>1.</sn> <def>The quality of
being delicious; <as>as, the <ex>deliciousness</ex> of a
repast</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Luxury.</def> <ldquo/To drive away all superfluity
and <xex>deliciousness</xex>.<rdquo/ <rj><au>Sir T. North.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delict</ent><br/
<hw>De*lict"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>delictum</ets> fault.]</ety> <fld>(Law)</fld> <def>An offense or
transgression against law; <fld>(Scots Law)</fld> an offense of a lesser
degree; a misdemeanor.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Every regulation of the civil code necessarily implies a
<qex>delict</qex> in the event of its violation.</q>
<rj><qau>Jeffrey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deligate</ent><br/
<hw>Del"i*gate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>deligatus</ets>, p. p. of <ets>deligare</ets> to bind up;
<ets>de-</ets> + <ets>ligare</ets> to bind.]</ety> <fld>(Surg.)</fld>
<def>To bind up; to bandage.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deligation</ent><br/
<hw>Del`i*ga"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>d<eacute/ligation</ets>.]</ety> <fld>(Surg.)</fld> <def>A binding
up; a bandaging.</def> <rj><au>Wiseman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delight</ent><br/
<hw>De*light"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>delit</ets>, OF. <ets>delit</ets>, <ets>deleit</ets>, fr.
<ets>delitier</ets>, to delight. See <er>Delight</er>, <pos>v.
t.</pos>]</ety> <sn>1.</sn> <def>A high degree of gratification of mind;
a high- wrought state of pleasurable feeling; lively pleasure; extreme
satisfaction; joy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Sounds and sweet airs, that give <qex>delight</qex> and hurt
not.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A fool hath no <qex>delight</qex> in understanding.</q>
<rj><qau>Prov. xviii. 2.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which gives great pleasure or
delight.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Heaven's last, best gift, my ever new <qex>delight</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Licentious pleasure; lust.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delight</ent><br/
<hw>De*light"</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Delighted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Delighting</conjf>.]</vmorph> <ety>[OE. <ets>deliten</ets>, OF.
<ets>delitier</ets>, <ets>deleitier</ets>, F.
<ets>d<eacute/lecter</ets>, fr. L. <ets>delectare</ets> to entice away,
to delight (sc. by attracting or alluring), intens. of
<ets>delicere</ets> to allure, delight; <ets>de-</ets> +
<ets>lacere</ets> to entice, allure; cf. <ets>laqueus</ets> a snare. Cf.
<er>Delectate</er>, <er>Delicate</er>, <er>Delicious</er>,
<er>Dilettante</er>, <er>Elicit</er>, <er>Lace</er>.]</ety> <def>To give
delight to; to affect with great pleasure; to please highly; <as>as, a
beautiful landscape <ex>delights</ex> the eye; harmony <ex>delights</ex>
the ear.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Inventions to <qex>delight</qex> the taste.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Delight</qex> our souls with talk of knightly deeds.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delight</ent><br/
<hw>De*light"</hw>, <pos>v. i.</pos> <def>To have or take great delight
or pleasure; to be greatly pleased or rejoiced; -- followed by an
infinitive, or by <xex>in</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Love <qex>delights</qex> in praises.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I <qex>delight</qex> to do thy will, O my God.</q> <rj><qau>Ps.
xl. 8.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delightable</ent><br/
<hw>De*light"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Delectable</er>.]</ety> <def>Capable of delighting;
delightful.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Many a spice <qex>delightable</qex>.</q> <rj><qau>Rom. of
R.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delighted</ent><br/
<hw>De*light"ed</hw>, <pos>a.</pos> <def>Endowed with delight.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If virtue no <qex>delighted</qex> beauty lack.</q>
<rj><qau>Shak.</qau></rj></p>

<p><syn><b>Syn.</b> -- Glad; pleased; gratified. See
<er>Glad</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delightedly</ent><br/
<hw>De*light"ed*ly</hw>, <pos>adv.</pos> <def>With delight;
gladly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delighter</ent><br/
<hw>De*light"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who gives or
takes delight.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delightful</ent><br/
<hw>De*light"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Highly pleasing;
affording great pleasure and satisfaction.</def>
<ldquo/<xex>Delightful</xex> bowers.<rdquo/ <au>Spenser.</au>
<ldquo/<xex>Delightful</xex> fruit.<rdquo/ <rj><au>Milton.</au></rj></p>

<p><syn><b>Syn.</b> -- Delicious; charming. See
<er>Delicious</er>.</syn></p>

<p>-- <wordforms><wf>De*light"ful*ly</wf>, <pos>adv.</pos> --
<wf>De*light"ful*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delighting</ent><br/
<hw>De*light"ing</hw>, <pos>a.</pos> <def>Giving delight;
gladdening.</def> -- <wordforms><wf>De*light"ing*ly</wf>,
<pos>adv.</pos></wordforms> <rj><au>Jer. Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delightless</ent><br/
<hw>De*light"less</hw>, <pos>a.</pos> <def>Void of delight.</def>
<rj><au>Thomson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delightous</ent><br/
<hw>De*light"ous</hw> <pr>(?)</pr> <pos>a.</pos> <ety>[OF.
<ets>delitos</ets>.]</ety> <def>Delightful.</def> <mark>[Obs.]</mark>
<rj><au>Rom. of R.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delightsome</ent><br/
<hw>De*light"some</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Very pleasing;
delightful.</def> <ldquo/<xex>Delightsome</xex> vigor.<rdquo/
<rj><au>Grew.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Ye shall be a <qex>delightsome</qex> land, . . . saith the
Lord.</q> <rj><qau>Mal. iii. 12.</qau></rj></p>

<p>-- <wordforms><wf>De*light"some*ly</wf>, <pos>adv.</pos> --
<wf>De*light"some*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delignate</ent><br/
<hw>De*lig"nate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Delignated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Delignating</conjf>.]</vmorph> <ety>[Pref.
<ets>de-</ets> + L. <ets>lignum</ets> wood.]</ety> <sn>1.</sn> <def>To
clear or strip of wood (by cutting down trees).</def> <mark>[R.]</mark>
<rj><au>Fuller.</au></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>To strip or remove the wood from; <as>as, to
<ex>delignate</ex> ramie, in the preparation of ribbons of the fiber for
further working</as>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Delilah</ent><br/
<hw>De*li"lah</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The mistress of
<person>Samson</person>, who betrayed him (<au>Judges xvi.</au>); hence,
a harlot; a temptress.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Other <qex>Delilahs</qex> on a smaller scale Burns met with during
his Dumfries sojourn.</q> <rj><qau>J. C. Shairp.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delimit</ent><br/
<hw>De*lim"it</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>delimitare</ets>: cf. F. <ets>d<eacute/limiter</ets>.]</ety>
<def>To fix the limits of; to demarcate; to bound.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>delimitate</ent><br/
<hw>delimitate</hw> <pos>v.</pos> <sn>1.</sn> <def>to determine the
essential quality of.</def><br/
<syn><b>Syn. --</b> specify, define, delineate, delimit.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>to set, mark, or draw the boundaries of
something.</def><br/
<syn><b>Syn. --</b> demarcate, delimit.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Delimitation</ent><br/
<hw>De*lim`i*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>delimitatio</ets>: cf. F. <ets>d<eacute/limitation</ets>.]</ety>
<def>The act or process of fixing limits or boundaries;
limitation.</def> <rj><au>Gladstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>deline</ent><br/
<hw>de*line"</hw> <pr>(d<esl/*l<imac/n")</pr>, <pos>v. t.</pos>
<sn>1.</sn> <def>To delineate.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To mark out.</def> <mark>[Obs.]</mark> <rj><au>R.
North.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delineable</ent><br/
<hw>De*lin"e*a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of
being, or liable to be, delineated.</def> <rj><au>Feltham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delineament</ent><br/
<hw>De*lin"e*a*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Delineate</er>.]</ety> <def>Delineation; sketch.</def> <rj><au>Dr.
H. More.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delineate</ent><br/
<hw>De*lin"e*ate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>delineatus</ets>, p. p. of <ets>delineare</ets> to delineate;
<ets>de-</ets> + <ets>lineare</ets> to draw, fr. <ets>linea</ets> line.
See <er>Line</er>.]</ety> <def>Delineated; portrayed.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delineate</ent><br/
<hw>De*lin"e*ate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Delineated</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Delineating</conjf>.]</vmorph> <sn>1.</sn> <def>To indicate by
lines drawn in the form or figure of; to represent by sketch, design, or
diagram; to sketch out; to portray; to picture; in drawing and
engraving, to represent in lines, as with the pen, pencil, or graver;
hence, to represent with accuracy and minuteness. See
<er>Delineation</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Adventurous to <qex>delineate</qex> nature's form.</q>
<rj><qau>Akenside.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To portray to the mind or understanding by words; to
set forth; to describe.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Customs or habits <qex>delineated</qex> with great accuracy.</q>
<rj><qau>Walpole.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>delineated</ent><br/
<hw>delineated</hw> <pos>adj.</pos> <sn>1.</sn> <def>represented
accurately or precisely.</def> [Narrower terms: <stype>diagrammatic,
diagrammatical</stype>; <stype>drawn</stype>;
<stype>painted</stype>]<br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>described in words with sharpness and detail or with
vivid imagery. Opposite of <ant>undelineated</ant>.</def><br/
<syn><b>Syn. --</b> represented, delineate.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Delineation</ent><br/
<hw>De*lin`e*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>delineatio</ets>: cf. F.
<ets>d<eacute/lin<eacute/ation</ets>.]</ety> <sn>1.</sn> <def>The act of
representing, portraying, or describing, as by lines, diagrams,
sketches, etc.; drawing an outline; <as>as, the <ex>delineation</ex> of
a scene or face</as>; in drawing and engraving, representation by means
of lines, as distinguished from representation by means of tints and
shades; accurate and minute representation, as distinguished from art
that is careless of details, or subordinates them excessively.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A delineated picture; representation; sketch;
description in words.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Their softest <qex>delineations</qex> of female beauty.</q>
<rj><qau>W. Irving.</qau></rj></p>

<p><syn><b>Syn.</b> -- Sketch; portrait; outline. See
<er>Sketch</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delineator</ent><br/
<hw>De*lin"e*a`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One
who, or that which, delineates; a sketcher.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Surv.)</fld> <def>A perambulator which records
distances and delineates a profile, as of a road.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delineatory</ent><br/
<hw>De*lin"e*a*to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <def>That
delineates; descriptive; drawing the outline; delineating.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delineature</ent><br/
<hw>De*lin"e*a*ture</hw> <pr>(?; 135)</pr>, <pos>n.</pos>
<def>Delineation.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delinition</ent><br/
<hw>Del`i*ni"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>delinere</ets> to smear. See <er>Liniment</er>.]</ety> <def>A
smearing.</def> <mark>[Obs.]</mark> <rj><au>Dr. H. More.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delinquency</ent><br/
<hw>De*lin"quen*cy</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Delinquencies</plw> <pr>(#)</pr>.</plu> <ety>[L.
<ets>delinquentia</ets>, fr. <ets>delinquens</ets>.]</ety> <def>Failure
or omission of duty; a fault; a misdeed; an offense; a misdemeanor; a
crime.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>delinquencies</qex> of the little commonwealth would be
represented in the most glaring colors.</q>
<rj><qau>Motley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delinquent</ent><br/
<hw>De*lin"quent</hw> <pr>(?)</pr> <pos>a.</pos> <ety>[L.
<ets>delinquens</ets>, <ets>-entis</ets>, p. pr. of
<ets>delinquere</ets> to fail, be wanting in one's duty, do wrong;
<ets>de-</ets> + <ets>linquere</ets> to leave. See <er>Loan</er>,
<pos>n.</pos>]</ety> <def>Failing in duty; offending by neglect of
duty.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delinquent</ent><br/
<hw>De*lin"quent</hw>, <pos>n.</pos> <def>One who fails or neglects to
perform his duty; an offender or transgressor; one who commits a fault
or a crime; a culprit.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>delinquent</qex> ought to be cited in the place or
jurisdiction where the delinquency was committed.</q>
<rj><qau>Ayliffe.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delinquently</ent><br/
<hw>De*lin"quent*ly</hw>, <pos>adv.</pos> <def>So as to fail in
duty.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deliquate</ent><br/
<hw>Del"i*quate</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[L.
<ets>deliquatus</ets>, p. p. of <ets>deliquare</ets> to clear off,
<ets>de-</ets> + <ets>liquare</ets> to make liquid, melt,
dissolve.]</ety> <def>To melt or be dissolved; to deliquesce.</def>
<mark>[Obs.]</mark> <rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deliquate</ent><br/
<hw>Del"i*quate</hw>, <pos>v. t.</pos> <def>To cause to melt away; to
dissolve; to consume; to waste.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Dilapidating, or rather <qex>deliquating</qex>, his bishopric.</q>
<rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deliquation</ent><br/
<hw>Del`i*qua"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A
melting.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deliquesce</ent><br/
<hw>Del`i*quesce"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Deliquesced</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Deliquescing</conjf>.]</vmorph> <ety>[L.
<ets>deliquescere</ets> to melt, dissolve; <ets>de-</ets> +
<ets>liquescere</ets> to become fluid, melt, fr. <ets>liquere</ets> to
be fluid. See <er>Liquid</er>.]</ety> <fld>(Chem.)</fld> <def>To
dissolve gradually and become liquid by attracting and absorbing
moisture from the air, as certain salts, acids, and alkalies.</def></p>

<-- Unexpected spelling of "alkalis", but not wrong. PCP -->
<p><q>In very moist air crystals of strontites <qex>deliquesce</qex>.</q> <rj><qau>Black.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deliquescence</ent><br/
<hw>Del`i*ques"cence</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F. <ets>d<eacute/liquescence</ets>.]</ety> <def>The act of deliquescing or liquefying; process by which anything deliquesces; tendency to melt.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deliquescent</ent><br/
<hw>Del`i*ques"cent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>deliquescens</ets>, <ets>-entis</ets>, p. pr. of <ets>deliquescere</ets>: cf. F. <ets>d<eacute/liquescent</ets>.]</ety> <sn>1.</sn> <def>Dissolving; liquefying by contact with the air; capable of attracting moisture from the atmosphere and becoming liquid; <as>as, <ex>deliquescent</ex> salts</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>Branching so that the stem is lost in branches, as in most deciduous trees.</def> <rj><au>Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deliquiate</ent><br/
<hw>De*liq"ui*ate</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[L. <ets>deliquia</ets> a flowing off, a gutter, <ets>deliquium</ets> a flowing down, fr. <ets>deliquare</ets>. See <er>Deliquate</er>.]</ety> <def>To melt and become liquid by absorbing water from the air; to deliquesce.</def> <rj><au>Fourcroy.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deliquiation</ent><br/
<hw>De*liq`ui*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of deliquiating.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deliquium</ent><br/
\'d8<hw>De*liq"ui*um</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. See <er>Deliquiate</er>.]</ety> <sn>1.</sn> <fld>(Chem.)</fld> <def>A melting or dissolution in the air, or in a moist place; a liquid condition; <as>as, a salt falls into a <ex>deliquium</ex></as>.</def> <mark>[R.]</mark><-- the result of deliquescence --><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A sinking away; a swooning.</def>
<mark>[Obs.]</mark> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A melting or maudlin mood.</def>
<rj><au>Carlyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deliracy</ent><br/
<hw>De*lir"a*cy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Delirate</er>.]</ety> <def>Delirium.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delirament</ent><br/
<hw>De*lir"a*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>deliramentum</ets>, fr. <ets>delirare</ets>. See
<er>Delirium</er>.]</ety> <def>A wandering of the mind; a crazy
fancy.</def> <mark>[Obs.]</mark> <rj><au>Heywood.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delirancy</ent><br/
<hw>De*lir"an*cy</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Delirium.</def>
<mark>[Obs.]</mark> <rj><au>Gauden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delirant</ent><br/
<hw>De*lir"ant</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>delirans</ets>, <ets>- antis</ets>, p. pr. of <ets>delirare</ets>.
See <er>Delirium</er>.]</ety> <def>Delirious.</def> <mark>[Obs.]</mark>
<rj><au>Owen.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delirate</ent><br/
<hw>De*lir"ate</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <ety>[L.
<ets>deliratus</ets>, p. p. of <ets>delirare</ets>. See
<er>Delirium</er>.]</ety> <def>To madden; to rave.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>An infatuating and <qex>delirating</qex> spirit in it.</q>
<rj><qau>Holland.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deliration</ent><br/
<hw>Del`i*ra"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>deliratio</ets>.]</ety> <def>Aberration of mind; delirium.</def>
<rj><au>J. Morley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Deliration</qex> or alienation of the understanding.</q>
<rj><qau>Mede.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deliriant</ent><br/
<hw>De*lir"i*ant</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Delirium</er>.]</ety> <fld>(Med.)</fld> <def>A poison which
occasions a persistent delirium, or mental aberration (as
belladonna).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delirifacient</ent><br/
<hw>De*lir`i*fa"cient</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Delirium</ets> + L. <ets>faciens</ets>, <ets>-entis</ets>, p.
pr. of <ets>facere</ets> to make.]</ety> <fld>(Med.)</fld>
<def>Producing, or tending to produce, delirium.</def> --
<def2><pos>n.</pos> <def>Any substance which tends to cause
delirium.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delirious</ent><br/
<hw>De*lir"i*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From
<er>Delirium</er>.]</ety> <def>Having a delirium; wandering in mind;
light-headed; insane; raving; wild; <as>as, a <ex>delirious</ex>
patient; <ex>delirious</ex> fancies.</as></def> --
<wordforms><wf>De*lir"i*ous*ly</wf>, <pos>adv.</pos> --
<wf>De*lir"i*ous*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delirium</ent><br/
<hw>De*lir"i*um</hw> <pr>(d<esl/*l<icr/r"<icr/*<ucr/m)</pr>,
<pos>n.</pos> <ety>[L., fr. <ets>delirare</ets> to rave, to wander in
mind, prop., to go out of the furrow in plowing; <ets>de-</ets> +
<ets>lira</ets> furrow, track; perh. akin to G. <ets>geleise</ets>
track, rut, and E. <ets>last</ets> to endure.]</ety> <sn>1.</sn>
<fld>(Med.)</fld> <def>A state in which the thoughts, expressions, and
actions are wild, irregular, and incoherent; mental aberration; a roving
or wandering of the mind, -- usually dependent on a fever or some other
disease, and so distinguished from <contr>mania</contr>, or
madness.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Strong excitement; wild enthusiasm;
madness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The popular <qex>delirium</qex> [of the French Revolution] at
first caught his enthusiastic mind.</q> <rj><qau>W.
Irving.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>delirium</qex> of the preceding session (of
Parliament).</q> <rj><qau>Morley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Delirium tremens</b></col> <pr>(<?/)</pr>. <ety>[L.,
trembling delirium]</ety> <fld>(Med.)</fld>, <cd>a violent delirium
induced by the excessive and prolonged use of intoxicating
liquors.</cd><-- colloq. called <altname>DT's</altname>,
<altname>d.t.'s</altname> or <altname>D&T</altname>--> --
<col><b>Traumatic delirium</b></col> <fld>(Med.)</fld>, <cd>a variety of
delirium following injury.</cd></cs></p>

<p><syn><b>Syn.</b> -- Insanity; frenzy; madness; derangement;
aberration; mania; lunacy; fury. See <er>Insanity</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delit</ent><br/
<hw>De*lit"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Delight.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delitable</ent><br/
<hw>De*lit"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Delightful;
delectable.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delitescence</ent><br/
<hw>Del`i*tes"cence</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Delitescent</er>.]</ety> <sn>1.</sn> <def>Concealment; seclusion;
retirement.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>delitescence</qex> of mental activities.</q> <rj><qau>Sir
W. Hamilton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Med.)</fld> <def>The sudden disappearance of
inflammation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delitescency</ent><br/
<hw>Del`i*tes"cen*cy</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Concealment;
seclusion.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The mental organization of the novelist must be characterized, to
speak craniologically, by an extraordinary development of the passion
for <qex>delitescency</qex>.</q> <rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delitescent</ent><br/
<hw>Del`i*tes"cent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>delitescens</ets>, <ets>-entis</ets>, p. pr. of
<ets>delitescere</ets> to lie hid.]</ety> <def>Lying hid;
concealed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delitigate</ent><br/
<hw>De*lit"i*gate</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[L.
<ets>delitigare</ets> to rail. See <er>Litigate</er>.]</ety> <def>To
chide; to rail heartily.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delitigation</ent><br/
<hw>De*lit`i*ga"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Chiding;
brawl.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deliver</ent><br/
<hw>De*liv"er</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Delivered</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Delivering</conjf>.]</vmorph> <ety>[F.
<ets>d<eacute/livrer</ets>, LL. <ets>deliberare</ets> to liberate, give
over, fr. L. <ets>de</ets> + <ets>liberare</ets> to set free. See
<er>Liberate</er>.]</ety> <sn>1.</sn> <def>To set free from restraint;
to set at liberty; to release; to liberate, as from control; to give up;
to free; to save; to rescue from evil actual or feared; -- often with
<xex>from</xex> or <xex>out of</xex>; <as>as, to <ex>deliver</ex> one
from captivity, or from fear of death</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He that taketh warning shall <qex>deliver</qex> his soul.</q>
<rj><qau>Ezek. xxxiii. 5.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Promise was that I<br/
Should Israel from Philistian yoke <qex>deliver</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To give or transfer; to yield possession or control
of; to part with (to); to make over; to commit; to surrender; to resign;
-- often with <xex>up</xex> or <xex>over</xex>, <xex>to</xex> or
<xex>into</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou shalt <qex>deliver</qex> Pharaoh's cup into his hand.</q>
<rj><qau>Gen. xl. 13.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The constables have <qex>delivered</qex> her over.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The exalted mind<br/
All sense of woe <qex>delivers</qex> to the wind.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To make over to the knowledge of another; to
communicate; to utter; to speak; to impart.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Till he these words to him <qex>deliver</qex> might.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Whereof the former <qex>delivers</qex> the precepts of the art,
and the latter the perfection.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To give forth in action or exercise; to discharge;
<as>as, to <ex>deliver</ex> a blow; to <ex>deliver</ex> a broadside, or
a ball.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Shaking his head and <qex>delivering</qex> some show of tears.</q>
<rj><qau>Sidney.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>An uninstructed bowler . . . thinks to attain the jack by
<qex>delivering</qex> his bowl straightforward upon it.</q> <rj><qau>Sir
W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To free from, or disburden of, young; to relieve of
a child in childbirth; to bring forth; -- often with
<xex>of</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>She was <qex>delivered</qex> safe and soon.</q>
<rj><qau>Gower.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Tully was long ere he could be <qex>delivered</qex> of a few
verses, and those poor ones.</q> <rj><qau>Peacham.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To discover; to show.</def>
<mark>[Poetic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I 'll <qex>deliver</qex><br/
Myself your loyal servant.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>To deliberate.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>To admit; to allow to pass.</def>
<mark>[Obs.]</mark> <rj><au>Bacon.</au></rj></p>

<p><syn><b>Syn.</b> -- To <er>Deliver</er>, <er>Give Forth</er>,
<er>Discharge</er>, <er>Liberate</er>, <er>Pronounce</er>,
<er>Utter</er>.</syn> <usage> <xex>Deliver</xex> denotes, literally,
<xex>to set free</xex>. Hence the term is extensively applied to cases
where a thing is made to pass from a <xex>confined</xex> state to one of
greater freedom or openness. Hence it may, in certain connections, be
used as synonymous with any or all of the above-mentioned words, as will
be seen from the following examples: One who <xex>delivers</xex> a
package <xex>gives it forth</xex>; one who <xex>delivers</xex> a cargo
<xex>discharges</xex> it; one who <xex>delivers</xex> a captive
<xex>liberates</xex> him; one who <xex>delivers</xex> a message or a
discourse <xex>utters</xex> or <xex>pronounces</xex> it; when soldiers
<xex>deliver</xex> their fire, they <xex>set it free</xex> or <xex>give
it forth</xex>.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deliver</ent><br/
<hw>De*liv"er</hw>, <pos>a.</pos> <ety>[OF. <ets>delivre</ets> free,
unfettered. See <er>Deliver</er>, <pos>v. t.</pos>]</ety> <def>Free;
nimble; sprightly; active.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Wonderly <qex>deliver</qex> and great of strength.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deliverable</ent><br/
<hw>De*liv"er*a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of
being, or about to be, delivered; necessary to be delivered.</def>
<rj><au>Hale.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deliverance</ent><br/
<hw>De*liv"er*ance</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>d<eacute/livrance</ets>, fr. <ets>d<eacute/livrer</ets>.]</ety>
<sn>1.</sn> <def>The act of delivering or freeing from restraint,
captivity, peril, and the like; rescue; <as>as, the <ex>deliverance</ex>
of a captive</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He hath sent me to heal the broken-hearted, to preach
<qex>deliverance</qex> to the captives.</q> <rj><qau>Luke iv.
18.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>One death or one <qex>deliverance</qex> we will share.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Act of bringing forth children.</def>
<mark>[Archaic]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Act of speaking; utterance.</def>
<mark>[Archaic]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In this and in the preceding sense <xex>delivery</xex>
is the word more commonly used.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The state of being delivered, or freed from
restraint.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I do desire <qex>deliverance</qex> from these officers.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Anything delivered or communicated; esp., an opinion
or decision expressed publicly.</def> <mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Metaph.)</fld> <def>Any fact or truth which is
decisively attested or intuitively known as a psychological or
philosophical datum; <as>as, the <ex>deliverance</ex> of
consciousness</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deliverer</ent><br/
<hw>De*liv"er*er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One
who delivers or rescues; a preserver.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who relates or communicates.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 387 --></p>

<p><ent>Deliveress</ent><br/
<hw>De*liv"er*ess</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A female
deliverer.</def> <mark>[R.]</mark> <rj><au>Evelyn.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deliverly</ent><br/
<hw>De*liv"er*ly</hw>, <pos>adv.</pos> <def>Actively; quickly;
nimbly.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Swim with your bodies,<br/
And carry it sweetly and <qex>deliverly</qex>.</q> <rj><qau>Beau. &
Fl.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deliverness</ent><br/
<hw>De*liv"er*ness</hw>, <pos>n.</pos> <def>Nimbleness; agility.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delivery</ent><br/
<hw>De*liv"er*y</hw>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Deliveries</plw> <pr>(<?/)</pr>.</plu> <sn>1.</sn> <def>The act of
delivering from restraint; rescue; release; liberation; <as>as, the
<ex>delivery</ex> of a captive from his dungeon</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The act of delivering up or over; surrender;
transfer of the body or substance of a thing; distribution; <as>as, the
<ex>delivery</ex> of a fort, of hostages, of a criminal, of goods, of
letters</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The act or style of utterance; manner of speaking;
<as>as, a good <ex>delivery</ex>; a clear
<ex>delivery</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The act of giving birth; parturition; the expulsion
or extraction of a fetus and its membranes.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>The act of exerting one's strength or
limbs.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Neater limbs and freer <qex>delivery</qex>.</q> <rj><qau>Sir H.
Wotton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>The act or manner of delivering a ball; <as>as, the
pitcher has a swift <ex>delivery</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dell</ent><br/
<hw>Dell</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS. <ets>del</ets>, akin
to E. <ets>dale</ets>; cf. D. <ets>delle</ets>, <ets>del</ets>, low
ground. See <er>Dale</er>.]</ety> <sn>1.</sn> <def>A small, retired
valley; a ravine.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In <qex>dells</qex> and dales, concealed from human sight.</q>
<rj><qau>Tickell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A young woman; a wench.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Sweet doxies and <qex>dells</qex>.</q> <rj><qau>B.
Jonson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Della Crusca</ent><br/
\'d8<hw>Del"la Crus"ca</hw> <pr>(?)</pr>. <def>A shortened form of
<xex>Accademia della Crusca</xex>, an academy in Florence, Italy,
founded in the 16th century, especially for conserving the purity of the
Italian language.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The Accademia della Crusca (literally, <xex>academy of
the bran</xex> or <xex>chaff</xex>) was so called in allusion to its
chief object of bolting or purifying the national language.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dellacruscan</ent><br/
<hw>Del`la*crus"can</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or
pertaining to the Accademia della Crusca in Florence.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>The Dellacruscan School</b></col>, <cd>a name given in
satire to a class of affected English writers, most of whom lived in
Florence, about <sc>a. d.</sc> 1785.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deloo</ent><br/
\'d8<hw>De"loo</hw> <pr>(d<asl/"l<omac/)</pr>, <pos>n.</pos>
<fld>(Zool.)</fld> <def>The duykerbok.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deloul</ent><br/
\'d8<hw>De*loul"</hw> <pr>(d<asl/*l<oomac/l")</pr>, <pos>n.</pos>
<ety>[Prob. of Arabic or Bedouin origin.]</ety> <fld>(Zool.)</fld>
<def>A special breed of the dromedary used for rapid traveling; the
swift camel; -- called also <altname>herire</altname>, and
<altname>maharik</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delph</ent><br/
<hw>Delph</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Delftware.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Five nothings in five plates of <qex>delph</qex>.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delph</ent><br/
<hw>Delph</hw>, <pos>n.</pos> <fld>(Hydraul. Engin.)</fld> <def>The
drain on the land side of a sea embankment.</def>
<rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delphian</ent><br/
<hw>Del"phi*an</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Delphic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delphic</ent><br/
<hw>Del"phic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>Delphicus</ets>, fr. Gr. <grk>Delfiko`s</grk>, fr.
<grk>Delfoi`</grk>, L. <ets>Delphi</ets>, a town of Phocis, in Greece,
now <ets>Kastri</ets>.]</ety> <fld>(Gr. Antiq.)</fld> <sn>1.</sn>
<def>Of or relating to Delphi, or to the famous oracle of that
place.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Ambiguous; mysterious.</def> <ldquo/If he is silent
or <xex>delphic</xex>.<rdquo/ <rj><au>New York Times.</au></rj></p>

<p><ent>Delphine</ent><br/
<ent>Delphin</ent><br/
<mhw>{ <hw>Del"phin</hw>, <hw>Del"phine</hw> }</mhw> <pr>(?)</pr>,
<pos>a.</pos> <ety>[See <er>Dauphin</er>.]</ety> <def>Pertaining to the
dauphin of France; <as>as, the <ex>Delphin</ex> classics, an edition of
the Latin classics, prepared in the reign of Louis XIV., for the use of
the dauphin (<xex>in usum Delphini</xex>).</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delphin</ent><br/
<hw>Del"phin</hw>, <pos>n.</pos> <ety>[L. <ets>delphinus</ets> a
dolphin.]</ety> <fld>(Chem.)</fld> <def>A fatty substance contained in
the oil of the dolphin and the porpoise; -- called also
<altname>phocenin</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delphine</ent><br/
<hw>Del"phine</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>delphinus</ets> a dolphin, Gr. <grk>delfi`s</grk>,
<grk>delfi`n</grk>.]</ety> <def>Pertaining to the dolphin, a genus of
fishes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delphinic</ent><br/
<hw>Del*phin"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Delphin</er>, <pos>n.</pos>]</ety> <fld>(Chem.)</fld>
<def>Pertaining to, or derived from, the dolphin; phocenic.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Delphinic acid</b></col>. <fld>(Chem.)</fld> <cd>See
<cref>Valeric acid</cref>, under <er>Valeric</er>.</cd>
<mark>[Obs.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delphinic</ent><br/
<hw>Del*phin"ic</hw>, <pos>a.</pos> <ety>[From NL.
<ets>Delphinium</ets>, the name of the genus.]</ety> <fld>(Chem.)</fld>
<def>Pertaining to, or derived from, the larkspur; specifically,
relating to the stavesacre (<spn>Delphinium
staphisagria</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delphinine</ent><br/
<hw>Del"phi*nine</hw> <pr>(?; 104)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>delphinine</ets>.]</ety> <fld>(Chem.)</fld> <def>A poisonous
alkaloid extracted from the stavesacre (<spn>Delphinium
staphisagria</spn>), as a colorless amorphous powder.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delphinoid</ent><br/
<hw>Del"phi*noid</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>delphinus</ets> a dolphin + <ets>-oid</ets>.]</ety>
<fld>(Zool.)</fld> <def>Pertaining to, or resembling, the
dolphin.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delphinoidea</ent><br/
\'d8<hw>Del`phi*noi"de*a</hw> <pr>(?)</pr>, <pos>n. pl.</pos>
<ety>[NL.]</ety> <fld>(Zool.)</fld> <def>The division of Cetacea which
comprises the dolphins, porpoises, and related forms.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delphinus</ent><br/
\'d8<hw>Del*phi"nus</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., a
dolphin, fr. Gr. <grk>delfi`s</grk>, <grk>delfi`n</grk>.]</ety>
<sn>1.</sn> <fld>(Zool.)</fld> <def>A genus of Cetacea, including the
dolphin. See <er>Dolphin</er>, 1.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Astron.)</fld> <def>The Dolphin, a constellation
near the equator and east of Aquila.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delsarte system</ent><br/
<ent>Delsarte</ent><br/
<mhw><hw>Del*sarte"</hw> <pr>(?)</pr>, <pos>n.</pos>, <it>or</it>
<hw>Delsarte system</hw></mhw>. <def>A system of calisthenics patterned
on the theories of <person>Fran<cced/ois
<etsep>Delsarte</etsep></person> (1811 -- 71), a French teacher of
dramatic and musical expression.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Delta</ent><br/
<hw>Del"ta</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Deltas</plw> <pr>(#)</pr>.</plu> <ety>[Gr. <grk>de`lta</grk>, the
name of the fourth letter of the Greek alphabet (the capital form of
which is <DELTA/, Eng. D), from the Ph<oe/nician name of the
corresponding letter. The Greeks called the alluvial deposit at the
mouth of the Nile, from its shape, the <ets>Delta</ets> of the
Nile.]</ety> <sn>1.</sn> <def>The fourth letter of the Greek alphabet
(<DELTA/ <delta/), corresponding to <er>D</er>.</def>
<specif>Hence,</specif> <def>an object having the shape of the capital
<DELTA/.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>A tract of land shaped like the letter delta
(<DELTA/), especially when the land is alluvial and inclosed between two
or more mouths of a river; <as>as, the <ex>delta</ex> of the Ganges, of
the Nile, or of the Mississippi</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Elec.)</fld> <def>The closed figure produced by
connecting three coils or circuits successively, end for end, esp. in a
three-phase system; -- often used attributively, <as>as <ex>delta</ex>
winding, <ex>delta</ex> connection (which see), etc.</as></def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Delta connection</ent><br/
<hw>Delta connection</hw>. <fld>(Elec.)</fld> <def>One of the usual
forms or methods for connecting apparatus to a three-phase circuit, the
three corners of the delta or triangle, as diagrammatically represented,
being connected to the three wires of the supply circuit.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Delta current</ent><br/
<hw>Delta current</hw>. <fld>(Elec.)</fld> <def>The current flowing
through a delta connection.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Deltafication</ent><br/
<hw>Del`ta*fi*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Delta</ets> + L. <ets>facere</ets> to make.]</ety> <def>The
formation of a delta or of deltas.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deltaic</ent><br/
<hw>Del*ta"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Relating to, or
like, a delta.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delthyris</ent><br/
\'d8<hw>Del*thy"ris</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<grk>de`lta</grk> the name of the letter <DELTA/ + <grk>thy`ra</grk>
door.]</ety> <fld>(Zool.)</fld> <def>A name formerly given to certain
Silurian brachiopod shells of the genus <er>Spirifer</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Delthyris limestone</b></col> <fld>(Geol.)</fld>, <cd>one
of the divisions of the Upper Silurian rocks in New York.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deltic</ent><br/
<hw>Del"tic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Deltaic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deltidium</ent><br/
\'d8<hw>Del*tid"i*um</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<grk>de`lta</grk>, the letter <DELTA/.]</ety> <fld>(Zool.)</fld>
<def>The triangular space under the beak of many brachiopod
shells.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deltohedron</ent><br/
<hw>Del`to*he"dron</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>de`lta</grk>, the letter <DELTA/ + <grk>'e`dra</grk> seat,
base.]</ety> <fld>(Crystallog.)</fld> <def>A solid bounded by twelve
quadrilateral faces. It is a hemihedral form of the isometric system,
allied to the tetrahedron.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deltoid</ent><br/
<hw>Del"toid</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>deltoeidh`s</grk> delta- shaped; <grk>de`lta</grk> the name of the
letter <DELTA/ + <grk>e'i^dos</grk> form: cf. F.
<ets>delto<ium/de</ets>. See <er>Delta</er>.]</ety> <sn>1.</sn>
<def>Shaped like the Greek <DELTA/ (delta); delta-shaped;
triangular.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Deltoid leaf</b></col> <fld>(Bot.)</fld>, <cd>a leaf in
the form of a triangle with the stem inserted at the middle of the
base.</cd> -- <col><b>Deltoid muscle</b></col> <fld>(Anat.)</fld>, <cd>a
large triangular muscle covering the shoulder joint, which serves to
raise the arm directly upward.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>of or pertaining to the <cref>deltoid
muscle</cref>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Deltoid</ent><br/
<hw>Del"toid</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[see
<er>deltoid</er>, <pos>a.</pos>]</ety> <def>the <cref>deltoid
muscle</cref>.</def><br/
[<source>PJC</source>]</p>

<p><ent>delts</ent><br/
<hw>delts</hw> <pr>(d<ecr/lts)</pr>, <pos>n. pl.</pos>
<fld>(Anat.)</fld> <def>The deltoid muscles; -- a contraction used by
body-building and health enthusiasts. Used similarly to <er>abs</er> and
<er>pecs</er>. See <cref>deltoid muscle</cref>.</def>
<mark>[abbrev.]</mark> <br/
[<source>PJC</source>]</p>

<p><ent>Deludable</ent><br/
<hw>De*lud"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of being
deluded; liable to be imposed on; gullible.</def> <rj><au>Sir T.
Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delude</ent><br/
<hw>De*lude"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Deluded</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Deluding</conjf>.]</vmorph> <ety>[L. <ets>deludere</ets>,
<ets>delusum</ets>; <ets>de-</ets> + <ets>ludere</ets> to play, make
sport of, mock. See <er>Ludicrous</er>.]</ety> <sn>1.</sn> <def>To lead
from truth or into error; to mislead the mind or judgment of; to
beguile; to impose on; to dupe; to make a fool of.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>delude</qex> the nation by an airy phantom.</q>
<rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To frustrate or disappoint.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It <qex>deludes</qex> thy search.</q>
<rj><qau>Dryden.</qau></rj></p>

<p><syn><b>Syn.</b> -- To mislead; deceive; beguile; cajole; cheat;
dupe. See <er>Deceive</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deluder</ent><br/
<hw>De*lud"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who deludes; a
deceiver; an impostor.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deluge</ent><br/
<hw>Del"uge</hw> <pr>(d<ecr/l"<usl/j)</pr>, <pos>n.</pos> <ety>[F.
<ets>d<eacute/luge</ets>, L. <ets>diluvium</ets>, fr. <ets>diluere</ets>
wash away; <ets>di-</ets> = <ets>dis-</ets> + <ets>luere</ets>, equiv.
to <ets>lavare</ets> to wash. See <er>Lave</er>, and cf.
<er>Diluvium</er>.]</ety> <sn>1.</sn> <def>A washing away; an
overflowing of the land by water; an inundation; a flood; specifically,
<xex>The Deluge</xex>, the great flood in the days of Noah (<au>Gen.
vii.</au>).</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Fig.: Anything which overwhelms, or causes great
destruction.</def> <ldquo/The <xex>deluge</xex> of summer.<rdquo/
<rj><au>Lowell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A fiery <qex>deluge</qex> fed<br/
With ever-burning sulphur unconsumed.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>As I grub up some quaint old fragment of a [London] street, or a
house, or a shop, or tomb or burial ground, which has still survived in
the <qex>deluge</qex>.</q> <rj><qau>F. Harrison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>After me the <qex>deluge</qex>.<br/
(Apr<eacute/s moi le d<eacute/luge.)</q> <rj><qau>Madame de
Pompadour.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deluge</ent><br/
<hw>Del"uge</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Deluged</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Deluging</conjf>.]</vmorph> <sn>1.</sn> <def>To overflow with
water; to inundate; to overwhelm.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>deluged</qex> earth would useless grow.</q>
<rj><qau>Blackmore.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To overwhelm, as with a deluge; to cover; to
overspread; to overpower; to submerge; to destroy; <as>as, the northern
nations <ex>deluged</ex> the Roman empire with their armies; the land is
<ex>deluged</ex> with woe.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>At length corruption, like a general flood . . . <br/
Shall <qex>deluge</qex> all.</q> <rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delundung</ent><br/
\'d8<hw>De*lun"dung</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Native
name.]</ety> <fld>(Zool.)</fld> <def>An East Indian carnivorous mammal
(<spn>Prionodon gracilis</spn>), resembling the civets, but without
scent pouches. It is handsomely spotted.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delusion</ent><br/
<hw>De*lu"sion</hw> <pr>(?)</pr> <pos>n.</pos> <ety>[L.
<ets>delusio</ets>, fr. <ets>deludere</ets>. See <er>Delude</er>.]</ety>
<sn>1.</sn> <def>The act of deluding; deception; a misleading of the
mind.</def> <rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The state of being deluded or misled.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which is falsely or delusively believed or
propagated; false belief; error in belief.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And fondly mourned the dear <qex>delusion</qex> gone.</q>
<rj><qau>Prior.</qau></rj></p>

<usage>
<p><syn><b>Syn.</b> -- <er>Delusion</er>, <er>Illusion</er>.</syn>
These words both imply some deception practiced upon the mind.
<xex>Delusion</xex> is deception from want of knowledge;
<xex>illusion</xex> is deception from morbid imagination. An
<xex>illusion</xex> is a false show, a mere cheat on the fancy or
senses. It is, in other words, some idea or image presented to the
bodily or mental vision which does not exist in reality. A
<xex>delusion</xex> is a false judgment, usually affecting the real
concerns of life. Or, in other words, it is an erroneous view of
something which exists indeed, but has by no means the qualities or
attributes ascribed to it. Thus we speak of the <xex>illusions</xex> of
fancy, the <xex>illusions</xex> of hope, <xex>illusive</xex> prospects,
<xex>illusive</xex> appearances, etc. In like manner, we speak of the
<xex>delusions</xex> of stockjobbing, the <xex>delusions</xex> of
honorable men, <xex>delusive</xex> appearances in trade, of being
<xex>deluded</xex> by a seeming excellence.</p>

<p><ldquo/A fanatic, either religious or political, is the subject of
strong <xex>delusions</xex>; while the term <xex>illusion</xex> is
applied solely to the visions of an uncontrolled imagination, the
chimerical ideas of one blinded by hope, passion, or credulity, or
lastly, to spectral and other ocular deceptions, to which the word
<xex>delusion</xex> is never applied.<rdquo/
<rj><au>Whately.</au></rj><br/
[<source>1913 Webster</source>]</p>
</usage>

<p><ent>Delusional</ent><br/
<hw>De*lu"sion*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining
to delusions; <as>as, <ex>delusional</ex> monomania</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delusive</ent><br/
<hw>De*lu"sive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Delude</er>.]</ety> <def>Apt or fitted to delude; tending to mislead
the mind; deceptive; beguiling; delusory; <as>as, <ex>delusive</ex>
arts; a <ex>delusive</ex> dream.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Delusive</qex> and unsubstantial ideas.</q>
<rj><qau>Whewell.</qau></rj></p>

<p>-- <wordforms><wf>De*lu"sive*ly</wf>, <pos>adv.</pos> --
<wf>De*lu"sive*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delusory</ent><br/
<hw>De*lu"so*ry</hw> <pr>(?)</pr> <pos>a.</pos> <def>Delusive;
fallacious.</def> <rj><au>Glanvill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>deluxe</ent><br/
<hw>deluxe</hw> <pos>adj.</pos> <sn>1.</sn> <def>impressively expensive;
notably exceeding typical price or quality.</def><br/
<syn><b>Syn. --</b> gilded, luxurious, opulent, princely,
sumptuous.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>especially elegant and sumptuous; of the highest
quality; <as>as, a <ex>deluxe</ex> car; <ex>deluxe</ex>
accommodations</as>.</def><br/
<syn><b>Syn. --</b> gilded, luxurious, opulent, princely, sumptuous, de
luxe, luxe, luxury(prenominal).</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Delve</ent><br/
<hw>Delve</hw> <pr>(?)</pr> <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Delved</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Delving</conjf>.]</vmorph> <ety>[AS. <ets>delfan</ets> to dig;
akin to OS. <ets>bidelban</ets> to bury, D. <ets>delven</ets> to dig,
MHG. <ets>telben</ets>, and possibly to E. <ets>dale</ets>. Cf.
<er>Delf</er> a mine.]</ety> <sn>1.</sn> <def>To dig; to open (the
ground) as with a spade.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Delve</qex> of convenient depth your thrashing floor.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To dig into; to penetrate; to trace out; to
fathom.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I can not <qex>delve</qex> him to the root.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delve</ent><br/
<hw>Delve</hw>, <pos>v. i.</pos> <def>To dig or labor with a spade, or
as with a spade; to labor as a drudge.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Delve</qex> may I not: I shame to beg.</q> <rj><qau>Wyclif
(Luke xvi. 3).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delve</ent><br/
<hw>Delve</hw>, <pos>n.</pos> <ety>[See <er>Delve</er>, <pos>v.
t.</pos>, and cf. <er>Delf</er> a mine.]</ety> <def>A place dug; a pit;
a ditch; a den; a cave.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Which to that shady <qex>delve</qex> him brought at last.</q>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The very tigers from their <qex>delves</qex><br/
Look out.</q> <rj><qau>Moore.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Delver</ent><br/
<hw>Delv"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who digs, as with
a spade.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>demagnetization</ent><br/
<hw>demagnetization</hw> <pos>n.</pos> <def>the act or process of
removing magnetization.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Demagnetize</ent><br/
<hw>De*mag"net*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <sn>1.</sn>
<def>To deprive of magnetic properties; to render nonmagnetic. See
<er>Magnetize</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If the bar be rapidly magnetized and <qex>demagnetized</qex>.</q>
<rj><qau>Am. Cyc.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To free from mesmeric influence; to
demesmerize.</def> <mark>[archaic]</mark><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p>-- <wordforms><wf>De*mag`net*i*za"tion</wf>, <pos>n.</pos> --
<wf>De*mag"net*i`zer</wf> <pr>(#)</pr>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demagog</ent><br/
<hw>Dem"a*gog</hw> <pr>(?; 115)</pr>, <pos>n.</pos>
<def>Demagogue.</def></p>

<p><ent>Demagogical</ent><br/
<ent>Demagogic</ent><br/
<mhw>{ <hw>Dem`a*gog"ic</hw> <pr>(?)</pr>, <hw>Dem`a*gog"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[Gr. <grk>dhmagwkiko`s</grk>:
cf. F. <ets>d<eacute/magogique</ets>.]</ety> <def>Relating to, or like,
a demagogue; factious.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demagogism</ent><br/
<hw>Dem"a*gog*ism</hw> <pr>(?; 115)</pr>, <pos>n.</pos> <def>The
practices of a demagogue.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demagogue</ent><br/
<hw>Dem"a*gogue</hw> <pr>(?; 115)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>dhmagwgo`s</grk> a popular leader; commonly in a bad sense, a
leader of the mob; <grk>dh^mos</grk> the people + <grk>'agwgo`s</grk>
leading, fr. <grk>'a`gein</grk> to lead; akin to E. <ets>act</ets>: cf.
F. <ets>d<eacute/magogue</ets>.]</ety> <def>A leader of the rabble; one
who attempts to control the multitude by specious or deceitful arts; an
unprincipled and factious mob orator or political leader.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>demagoguery</ent><br/
<hw>demagoguery</hw> <pos>n.</pos> <sn>1.</sn> <def>impassioned appeals
to the prejudices and emotions of the populace.</def><br/
<syn><b>Syn. --</b> demagogy, demagogism.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Demagogy</ent><br/
<hw>Dem"a*gog`y</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>d<eacute/magogie</ets>, Gr. <grk>dhmagwgi`a</grk> leadership of the
people.]</ety> <def>Demagogism.</def><br/
<syn><b>Syn. --</b> demagoguery.</syn>
[<source>1913 Webster</source>]</p>

<p><ent>Demain</ent><br/
<hw>De*main"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Demesne</er>.]</ety> <sn>1.</sn> <def>Rule; management.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>See <er>Demesne</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demand</ent><br/
<hw>De*mand"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Demanded</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Demanding</conjf>.]</vmorph> <ety>[F. <ets>demander</ets>, LL.
<ets>demandare</ets> to demand, summon, send word, fr. L.
<ets>demandare</ets> to give in charge, intrust; <ets>de-</ets> +
<ets>mandare</ets> to commit to one's charge, commission, order,
command. Cf. <er>Mandate</er>, <er>Commend</er>.]</ety> <sn>1.</sn>
<def>To ask or call for with authority; to claim or seek from, as by
authority or right; to claim, as something due; to call for urgently or
peremptorily; <as>as, to <ex>demand</ex> a debt; to <ex>demand</ex>
obedience.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>This, in our foresaid holy father's name,<br/
Pope Innocent, I do <qex>demand</qex> of thee.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To inquire authoritatively or earnestly; to ask,
esp. in a peremptory manner; to question.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I did <qex>demand</qex> what news from Shrewsbury.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To require as necessary or useful; to be in urgent
need of; hence, to call for; <as>as, the case <ex>demands</ex>
care</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Law)</fld> <def>To call into court; to
summon.</def> <rj><au>Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demand</ent><br/
<hw>De*mand"</hw>, <pos>v. i.</pos> <def>To make a demand; to
inquire.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The soldiers likewise <qex>demanded</qex> of him, saying, And what
shall we do?</q> <rj><qau>Luke iii. 14.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demand</ent><br/
<hw>De*mand"</hw>, <pos>n.</pos> <ety>[F. <ets>demande</ets>, fr.
<ets>demander</ets>. See <er>Demand</er>, <pos>v. t.</pos>]</ety>
<sn>1.</sn> <def>The act of demanding; an asking with authority; a
peremptory urging of a claim; a claiming or challenging as due;
requisition; <as>as, the <ex>demand</ex> of a creditor; a note payable
on <ex>demand</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>demand</qex> [is] by the word of the holy ones.</q>
<rj><qau>Dan. iv. 17.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He that has confidence to turn his wishes into <qex>demands</qex>
will be but a little way from thinking he ought to obtain them.</q>
<rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Earnest inquiry; question; query.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A diligent seeking or search; manifested want;
desire to possess; request; <as>as, a <ex>demand</ex> for certain goods;
a person's company is in great <ex>demand</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>In 1678 came forth a second edition [Pilgrim's Progress] with
additions; and then the <qex>demand</qex> became immense.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>That which one demands or has a right to demand;
thing claimed as due; claim; <as>as, <ex>demands</ex> on an
estate</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Law)</fld> <sd>(a)</sd> <def>The asking or seeking
for what is due or claimed as due.</def> <sd>(b)</sd> <def>The right or
title in virtue of which anything may be claimed; <as>as, to hold a
<ex>demand</ex> against a person</as>.</def> <sd>(c)</sd> <def>A thing
or amount claimed to be due.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>In demand</b></col>, <cd>in request; being much sought
after.</cd> -- <col><b>On demand</b></col>, <cd>upon presentation and
request of payment.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demandable</ent><br/
<hw>De*mand"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>That may be
demanded or claimed.</def> <ldquo/All sums <xex>demandable</xex>.<rdquo/
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demandant</ent><br/
<hw>De*mand"ant</hw> <pr>(?)</pr> <pos>n.</pos> <ety>[F.
<ets>demandant</ets>, p. pr. of <ets>demander</ets>.]</ety> <def>One who
demands; the plaintiff in a real action; any plaintiff.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demander</ent><br/
<hw>De*mand"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
demands.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demandress</ent><br/
<hw>De*mand"ress</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A woman who
demands.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demantoid</ent><br/
<hw>De*man"toid</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[G.
<ets>demant</ets> diamond + <ets>-oid</ets>.]</ety> <fld>(Min.)</fld>
<def>A yellow-green, transparent variety of garnet found in the Urals.
It is valued as a gem because of its brilliancy of luster, whence the
name.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demarcate</ent><br/
<hw>De*mar"cate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[See
<er>Demarcation</er>.]</ety> <def>To mark by bounds; to set the limits
of; to separate; to discriminate.</def> <rj><au>Wilkinson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demarcation</ent><br/
<hw>De`mar*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>d<eacute/marcation</ets>; pref. <ets>d<eacute/-</ets> (L.
<ets>de</ets>) + <ets>marquer</ets> to mark, of German origin. See
<er>Mark</er>.]</ety> <def>The act of marking, or of ascertaining and
setting a limit; separation; distinction.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The speculative line of <qex>demarcation</qex>, where obedience
ought to end and resistance must begin, is faint, obscure, and not
easily definable.</q> <rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demarch</ent><br/
<hw>De*march"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>d<eacute/marche</ets>. See <er>March</er>, <pos>n.</pos>]</ety>
<def>March; walk; gait.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demarch</ent><br/
<hw>De*march</hw> <pr>(d<emac/"m<aum/rk)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>dh`marchos</grk>; <grk>dh^mos</grk> people + <grk>'a`rchein</grk>
to rule.]</ety> <def>A chief or ruler of a deme or district in
Greece.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demarkation</ent><br/
<hw>De`mar*ka"tion</hw>, <pos>n.</pos> <def>Same as
<er>Demarcation</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>demasculinization</ent><br/
<hw>demasculinization</hw> <pos>n.</pos> <def>the act or process of
demasculinizing; the removal of the testicles of a male
animal.</def><br/
<syn><b>Syn. --</b> emasculation, castration.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>demasculinize</ent><br/
<hw>demasculinize</hw> <pos>v. t.</pos> <def>to remove the testicles of
a male animal.</def><br/
<syn><b>Syn. --</b> emasculate, castrate.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dematerialize</ent><br/
<hw>De`ma*te"ri*al*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To
deprive of material or physical qualities or characteristics.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Dematerializing</qex> matter by stripping it of everything
which . . . has distinguished matter.</q>
<rj><qau>Milman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deme</ent><br/
<hw>Deme</hw> <pr>(d<emac/m)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>dh^mos</grk>.]</ety> <sn>1.</sn> <fld>(Gr. Antiq.)</fld> <def>A
territorial subdivision of Attica (also of modern Greece), corresponding
to a township.</def> <rj><au>Jowett (Thucyd.).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Biol.)</fld> <def>An undifferentiated aggregate of
cells or plastids.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demean</ent><br/
<hw>De*mean"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Demeaned</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Demeaning</conjf>.]</vmorph> <ety>[OF.
<ets>demener</ets> to conduct, guide, manage, F. <ets>se
d<eacute/mener</ets> to struggle; pref. <ets>d<eacute/-</ets> (L.
<ets>de</ets>) + <ets>mener</ets> to lead, drive, carry on, conduct, fr.
L. <ets>minare</ets> to drive animals by threatening cries, fr.
<ets>minari</ets> to threaten. See <er>Menace</er>.]</ety> <sn>1.</sn>
<def>To manage; to conduct; to treat.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>[Our] clergy have with violence <qex>demeaned</qex> the
matter.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To conduct; to behave; to comport; -- followed by
the reflexive pronoun.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They have <qex>demeaned</qex> themselves<br/
Like men born to renown by life or death.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>They answered . . . that they should <qex>demean</qex> themselves
according to their instructions.</q> <rj><qau>Clarendon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 388 --></p>

<p><sn>3.</sn> <def>To debase; to lower; to degrade; -- followed by the
reflexive pronoun.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Her son would <qex>demean</qex> himself by a marriage with an
artist's daughter.</q> <rj><qau>Thackeray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ This sense is probably due to a false etymology which
regarded the word as connected with the adjective
<xex>mean</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demean</ent><br/
<hw>De*mean"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>demene</ets>. See <er>Demean</er>, <pos>v. t.</pos>]</ety>
<sn>1.</sn> <def>Management; treatment.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Vile <qex>demean</qex> and usage bad.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Behavior; conduct; bearing; demeanor.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>With grave <qex>demean</qex> and solemn vanity.</q>
<rj><qau>West.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demean</ent><br/
<hw>De*mean"</hw>, <pos>n.</pos> <ety>[See <er>Demesne</er>.]</ety>
<sn>1.</sn> <def>Demesne.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <pluf>pl.</pluf> <def>Resources; means.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>You know<br/
How narrow our <qex>demeans</qex> are.</q>
<rj><qau>Massinger.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demeanance</ent><br/
<hw>De*mean"ance</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Demeanor.</def>
<mark>[Obs.]</mark> <rj><au>Skelton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demeanor</ent><br/
<hw>De*mean"or</hw> <pr>(?)</pr>, <pos>n.</pos> <altsp>[Written also
<asp>demeanour</asp>.]</altsp> <ety>[For <ets>demeanure</ets>, fr.
<ets>demean</ets>. See <er>Demean</er>, <pos>v. t.</pos>]</ety>
<sn>1.</sn> <def>Management; treatment; conduct.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>God commits the managing so great a trust . . . wholly to the
<qex>demeanor</qex> of every grown man.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Behavior; deportment; carriage; bearing;
mien.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His <qex>demeanor</qex> was singularly pleasing.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The men, as usual, liked her artless kindness and simple refined
<qex>demeanor</qex>.</q> <rj><qau>Thackeray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demeanure</ent><br/
<hw>De*mean"ure</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Behavior.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demency</ent><br/
<hw>De"men*cy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>dementia</ets>, fr. <ets>demens</ets> mad. See
<er>Dement</er>.]</ety> <def>Dementia; loss of mental powers. See
<er>Insanity</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dement</ent><br/
<hw>De*ment"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>dementare</ets>, fr. <ets>demens</ets>, <ets>-mentis</ets>, out of
one's mind, mad; <ets>de</ets> + <ets>mens</ets> mind. See
<er>Mental</er>, and cf. <er>Dementate</er>.]</ety> <def>To deprive of
reason; to make mad.</def> <mark>[R.]</mark> <rj><au>Bale.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dement</ent><br/
<hw>De*ment"</hw>, <pos>a.</pos> <ety>[L. <ets>demens</ets>, <ets>-
mentis</ets>.]</ety> <def>Demented; dementate.</def> <mark>[R.]</mark>
<rj><au>J. H. Newman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dementate</ent><br/
<hw>De*men"tate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>dementatus</ets>, p. p. See <er>Dement</er>, <pos>v.
t.</pos>]</ety> <def>Deprived of reason.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Arise, thou <qex>dementate</qex> sinner!</q>
<rj><qau>Hammond.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dementate</ent><br/
<hw>De*men"tate</hw> <pr>(?)</pr> <pos>v. t.</pos> <def>To deprive of
reason; to dement.</def> <mark>[R.]</mark> <rj><au>Burton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dementation</ent><br/
<hw>De`men*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
depriving of reason; madness.</def> <rj><au>Whitlock.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demented</ent><br/
<hw>De*ment"ed</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From
<er>Dement</er>.]</ety> <def>Insane; mad; of unsound mind.</def> --
<wordforms><wf>De*ment"ed*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>dementedness</ent><br/
<hw>de*ment"ed*ness</hw> <pos>n.</pos> <def>mental deterioration of
organic or functional origin.</def><br/
<syn><b>Syn. --</b> dementia.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dementia</ent><br/
\'d8<hw>De*men"ti*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., fr.
<ets>demens</ets>. See <er>Dement</er>.]</ety> <def>Insanity; madness;
esp. that form which consists in weakness or total loss of thought and
reason; mental imbecility; idiocy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demephitize</ent><br/
<hw>De*meph"i*tize</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Demephitized</conjf>
<pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Demephitizing</conjf>.]</vmorph> <ety>[Cf. F.
<ets>m<eacute/phitiser</ets> to infect with <ets>mephitis</ets>.]</ety>
<def>To purify from mephitic or foul air.</def> --
<wordforms><wf>De*meph`i*ti*za"tion</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demerge</ent><br/
<hw>De*merge"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>demergere</ets>.]</ety> <def>To plunge down into; to sink; to
immerse.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The water in which it was <qex>demerged</qex>.</q>
<rj><qau>Boyle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demerit</ent><br/
<hw>De*mer"it</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>d<eacute/m<eacute/rite</ets> demerit (in sense 2), OF.
<ets>demerite</ets> demerit (in sense 1), fr. L. <ets>demerere</ets> to
deserve well, LL., to deserve well or ill; <ets>de-</ets> +
<ets>merere</ets> to deserve. See <er>De</er>-, and
<er>Merit</er>.]</ety> <sn>1.</sn> <def>That which one merits or
deserves, either of good or ill; desert.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>By many benefits and <qex>demerits</qex> whereby they obliged
their adherents, [they] acquired this reputation.</q>
<rj><qau>Holland.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which deserves blame; ill desert; a fault; a
vice; misconduct; -- the opposite of <ant>merit</ant>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They see no merit or <qex>demerit</qex> in any man or any
action.</q> <rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Secure, unless forfeited by any <qex>demerit</qex> or offense.</q>
<rj><qau>Sir W. Temple.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The state of one who deserves ill.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demerit</ent><br/
<hw>De*mer"it</hw>, <pos>v. t.</pos> <ety>[Cf. F.
<ets>d<eacute/m<eacute/riter</ets> to deserve ill. See <er>Demerit</er>,
<pos>n.</pos>]</ety> <sn>1.</sn> <def>To deserve; -- said in reference
to both praise and blame.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>If I have <qex>demerited</qex> any love or thanks.</q>
<rj><qau>Udall.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Executed as a traitor . . . as he well <qex>demerited</qex>.</q>
<rj><qau>State Trials (1645).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To depreciate or cry down.</def> <mark>[R.]</mark>
<rj><au>Bp. Woolton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demerit</ent><br/
<hw>De*mer"it</hw>, <pos>v. i.</pos> <def>To deserve praise or
blame.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demerse</ent><br/
<hw>De*merse"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>demersus</ets>, p. p. of <ets>demergere</ets>. See
<er>Merge</er>.]</ety> <def>To immerse.</def> <mark>[Obs.]</mark>
<rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demersed</ent><br/
<hw>De*mersed"</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Bot.)</fld>
<def>Situated or growing under water, as leaves; submersed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demersion</ent><br/
<hw>De*mer"sion</hw> <pr>(?)</pr> <pos>n.</pos> <ety>[L.
<ets>demersio</ets>.]</ety> <sn>1.</sn> <def>The act of plunging into a
fluid; a drowning.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The state of being overwhelmed in water, or as if in
water.</def> <rj><au>Ray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demesmerize</ent><br/
<hw>De*mes"mer*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To relieve
from mesmeric influence. See <er>Mesmerize</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demesne</ent><br/
<hw>De*mesne"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>demeine</ets>, <ets>demain</ets>, rule, demesne, OF.
<ets>demeine</ets>, <ets>demaine</ets>, <ets>demeigne</ets>,
<ets>domaine</ets>, power, F. <ets>domaine</ets> domain, fr. L.
<ets>dominium</ets> property, right of ownership, fr. <ets>dominus</ets>
master, proprietor, owner. See <er>Dame</er>, and cf. <er>Demain</er>,
<er>Domain</er>, <er>Danger</er>, <er>Dungeon</er>.]</ety>
<fld>(Law)</fld> <def>A lord's chief manor place, with that part of the
lands belonging thereto which has not been granted out in tenancy; a
house, and the land adjoining, kept for the proprietor's own use.</def>
<altsp>[Written also <asp>demain</asp>.]</altsp> <rj><au>Wharton's Law
Dict. Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Ancient demesne</b></col>. <fld>(Eng. Law)</fld> <cd>See
under <er>Ancient</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demesnial</ent><br/
<hw>De*mesn"i*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining
to a demesne; of the nature of a demesne.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demi-</ent><br/
<hw>Dem"i-</hw> <pr>(?)</pr>. <ety>[F. <ets>demi-</ets>, fr. L.
<ets>dimidius</ets> half; <ets>di-</ets> = <ets>dis-</ets> +
<ets>medius</ets> middle. See <er>Medium</er>, and cf. <er>Demy</er>,
<er>Dimidiate</er>.]</ety> <def>A prefix, signifying
<sig>half</sig>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demi</ent><br/
<hw>De*mi"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See <er>Demy</er>,
<pos>n.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demibastion</ent><br/
<hw>Dem"i*bas"tion</hw> <pr>(?; 106)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>demi- bastion</ets>.]</ety> <fld>(Fort.)</fld> <def>A half bastion,
or that part of a bastion consisting of one face and one
flank.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demibrigade</ent><br/
<hw>Dem"i*bri*gade"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>demi- brigade</ets>.]</ety> <def>A half brigade.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demicadence</ent><br/
<hw>Dem"i*ca`dence</hw> <pr>(?)</pr> <pos>n.</pos> <fld>(Mus.)</fld>
<def>An imperfect or half cadence, falling on the dominant instead of on
the key note.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demicannon</ent><br/
<hw>Dem"i*can"non</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Mil.
Antiq.)</fld> <def>A kind of ordnance, carrying a ball weighing from
thirty to thirty-six pounds.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demicircle</ent><br/
<hw>Dem"i*cir`cle</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>demi-cercle</ets>.]</ety> <def>An instrument for measuring angles,
in surveying, etc. It resembles a protractor, but has an alidade,
sights, and a compass.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demiculverin</ent><br/
<hw>Dem"i*cul"ver*in</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Mil.
Antiq.)</fld> <def>A kind of ordnance, carrying a ball weighing from
nine to thirteen pounds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demideify</ent><br/
<hw>Dem"i*de"i*fy</hw> <pr>(?)</pr> <pos>v. t.</pos> <def>To deify in
part.</def> <rj><au>Cowper.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demidevil</ent><br/
<hw>Dem"i*dev`il</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A half
devil.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demigod</ent><br/
<hw>Dem"i*god</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A half god, or an
inferior deity; a fabulous hero, the offspring of a deity and a
mortal.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demigoddess</ent><br/
<hw>Dem"i*god`dess</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A female
demigod.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demigorge</ent><br/
<hw>Dem"i*gorge`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>demi- gorge</ets>.]</ety> <fld>(Fort.)</fld> <def>Half the gorge,
or entrance into a bastion, taken from the angle of the flank to the
center of the bastion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demigrate</ent><br/
<hw>Dem"i*grate</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[L.
<ets>demigrare</ets>, <ets>demigratum</ets>, to emigrate. See
<er>De</er>-, and <er>Migrate</er>.]</ety> <def>To emigrate.</def>
<mark>[Obs.]</mark> <rj><au>Cockeram.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demigration</ent><br/
<hw>Dem`i*gra"tion</hw> <pr>(?)</pr> <pos>n.</pos> <ety>[L.
<ets>demigratio</ets>.]</ety> <def>Emigration.</def> <mark>[Obs.]</mark>
<rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demigroat</ent><br/
<hw>Dem"i*groat`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A half
groat.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demi-island</ent><br/
<hw>Dem"i-is`land</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Peninsula.</def>
<mark>[Obs.]</mark> <rj><au>Knolles.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demijohn</ent><br/
<hw>Dem"i*john</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>dame-jeanne</ets>, i.e., Lady Jane, a corruption of Ar.
<ets>damaj<amac/na</ets>, <ets>damj<amac/na</ets>, prob. fr.
<ets>Damaghan</ets> a town in the Persian province of Khorassan, once
famous for its glass works.]</ety> <def>A glass vessel or bottle with a
large body and small neck, inclosed in wickerwork.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demilance</ent><br/
<hw>Dem"i*lance`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A light lance; a
short spear; a half pike; also, a demilancer.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demilancer</ent><br/
<hw>Dem"i*lan`cer</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A soldier of
light cavalry of the 16th century, who carried a demilance.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demilune</ent><br/
<hw>Dem"i*lune`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>demi-
lune</ets>.]</ety> <sn>1.</sn> <fld>(Fort.)</fld> <def>A work
constructed beyond the main ditch of a fortress, and in front of the
curtain between two bastions, intended to defend the curtain; a ravelin.
See <er>Ravelin</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Physiol.)</fld> <def>A crescentic mass of granular
protoplasm present in the salivary glands.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Each crescent is made of polyhedral cells which under
some circumstances are supposed to give rise to new salivary
cells.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demiman</ent><br/
<hw>Dem"i*man`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A half man.</def>
<mark>[R.]</mark> <rj><au>Knolles.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demimonde</ent><br/
<hw>Dem`i*monde"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.;
<ets>demi</ets> + <ets>monde</ets> world, L. <ets>mundus</ets>.]</ety>
<def>Persons of doubtful reputation; esp., women who are kept as
mistresses, though not public prostitutes; demireps.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Literary demimonde</b></col>, <cd>writers of the lowest
kind.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deminatured</ent><br/
<hw>Dem"i*na"tured</hw> <pr>(?; 135)</pr>, <pos>a.</pos> <def>Having
half the nature of another.</def> <mark>[R.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demiquaver</ent><br/
<hw>Dem"i*qua`ver</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Mus.)</fld>
<def>A note of half the length of the quaver; a semiquaver.</def>
<mark>[R.]</mark></p>

<p><ent>Demirelievo</ent><br/
<ent>Demirelief</ent><br/
<mhw>{ <hw>Dem`i*re*lief"</hw> <pr>(?)</pr>, <hw>Dem`i*re*lie"vo</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <def>Half relief. See
<er>Demi-rilievo</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demirep</ent><br/
<hw>Dem"i*rep`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Contr. fr.
<ets>demi-reputation</ets>.]</ety> <def>A woman of doubtful reputation
or suspected character; an adventuress.</def> <mark>[Colloq.]</mark>
<rj><au>De Quincey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demi-rilievo</ent><br/
\'d8<hw>Dem"i-ri*lie"vo</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>demi-</ets> + It. <ets>rilievo</ets>.]</ety> <fld>(Fine Arts)</fld>
<sd>(a)</sd> <def>Half relief; sculpture in relief of which the figures
project from the background by one half their full roundness.</def>
<sd>(b)</sd> <def>A work of sculpture of the above character. See
<er>Alto-rilievo</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demisability</ent><br/
<hw>De*mis`a*bil"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Law)</fld>
<def>The state of being demisable.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demisable</ent><br/
<hw>De*mis"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From
<er>Demise</er>.]</ety> <fld>(Law)</fld> <def>Capable of being leased;
<as>as, a <ex>demisable</ex> estate</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demise</ent><br/
<hw>De*mise"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>d<eacute/mettre</ets>, p. p. <ets>d<eacute/mis</ets>,
<ets>d<eacute/mise</ets>, to put away, lay down; pref.
<ets>d<eacute/-</ets> (L. <ets>de</ets> or <ets>dis-</ets>) +
<ets>mettre</ets> to put, place, lay, fr. L. <ets>mittere</ets> to send.
See <er>Mission</er>, and cf. <er>Dismiss</er>, <er>Demit</er>.]</ety>
<sn>1.</sn> <def>Transmission by formal act or conveyance to an heir or
successor; transference; especially, the transfer or transmission of the
crown or royal authority to a successor.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The decease of a royal or princely person; hence,
also, the death of any illustrious person.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>After the <qex>demise</qex> of the Queen [of George II.], in 1737,
they [drawing- rooms] were held but twice a week.</q> <rj><qau>P.
Cunningham.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Law)</fld> <def>The conveyance or transfer of an
estate, either in fee for life or for years, most commonly the
latter.</def> <rj><au>Bouvier.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The <xex>demise</xex> of the crown is a transfer of the
crown, royal authority, or kingdom, to a successor. Thus, when Edward
IV. was driven from his throne for a few months by the house of
Lancaster, this temporary transfer of his dignity was called a
<xex>demise</xex>. Thus the natural death of a king or queen came to be
denominated a <xex>demise</xex>, as by that event the crown is
transferred to a successor.</note> <rj><au>Blackstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Demise and redemise</b></col>, <cd>a conveyance where
there are mutual leases made from one to another of the same land, or
something out of it.</cd></cs></p>

<p><syn><b>Syn.</b> -- Death; decease; departure. See
<er>Death</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demise</ent><br/
<hw>De*mise"</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Demised</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Demising</conjf>.]</vmorph> <sn>1.</sn> <def>To transfer or
transmit by succession or inheritance; to grant or bestow by will; to
bequeath.</def> <ldquo/Power to <xex>demise</xex> my lands.<rdquo/
<rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>What honor<br/
Canst thou <qex>demise</qex> to any child of mine?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To convey; to give.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>His soul is at his conception <qex>demised</qex> to him.</q>
<rj><qau>Hammond.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Law)</fld> <def>To convey, as an estate, by lease;
to lease.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demisemiquaver</ent><br/
<hw>Dem`i*sem"i*qua`ver</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Mus.)</fld> <def>A short note, equal in time to the half of a
semiquaver, or the thirty-second part of a whole note.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demiss</ent><br/
<hw>De*miss"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>demissus</ets>, p. p. of <ets>demittere</ets>.]</ety> <def>Cast
down; humble; submissive.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He down descended like a most <qex>demiss</qex><br/
And abject thrall.</q> <rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demission</ent><br/
<hw>De*mis"sion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>demissio</ets>, fr. <ets>demittere</ets>. See
<er>Demit</er>.]</ety> <sn>1.</sn> <def>The act of demitting, or the
state of being demitted; a letting down; a lowering; dejection.</def>
<ldquo/<xex>Demission</xex> of mind.<rdquo/
<rj><au>Hammond.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Demission</qex> of sovereign authority.</q>
<rj><qau>L'Estrange.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Resignation of an office.</def>
<mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demissionary</ent><br/
<hw>De*mis"sion*a*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Pertaining to transfer or conveyance; <as>as, a
<ex>demissionary</ex> deed</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Tending to lower, depress, or degrade.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demissive</ent><br/
<hw>De*miss"ive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Demiss</er>.]</ety> <def>Downcast; submissive; humble.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>They pray with <qex>demissive</qex> eyelids.</q> <rj><qau>Lord
(1630).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demissly</ent><br/
<hw>De*miss"ly</hw>, <pos>adv.</pos> <def>In a humble manner.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demisuit</ent><br/
<hw>Dem"i*suit`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Mil.
Antiq.)</fld> <def>A suit of light armor covering less than the whole
body, as having no protection for the legs below the thighs, no vizor to
the helmet, and the like.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demit</ent><br/
<hw>De*mit"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Demitted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Demitting</conjf>.]</vmorph> <ety>[L. <ets>demittere</ets> to
send or bring down, to lower; <ets>de-</ets> + <ets>mittere</ets> to
send. Cf. <er>Demise</er>.]</ety> <sn>1.</sn> <def>To let fall; to
depress.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>They [peacocks] <qex>demit</qex> and let fall the same [<it>i.
e.</it>, their train].</q> <rj><qau>Sir T. Browne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To yield or submit; to humble; to lower; <as>as, to
<ex>demit</ex> one's self to humble duties</as>.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To lay down, as an office; to resign.</def>
<mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>General Conway <qex>demitted</qex> his office.</q>
<rj><qau>Hume.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demit</ent><br/
<hw>De*mit"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[F.
<ets>d<eacute/mettre</ets> to remove, <ets>se d<eacute/mettre</ets> to
resign; <ets>d<eacute/-</ets> (L. <ets>dis-</ets>) + <ets>mettre</ets>
to put, fr. L. <ets>mittere</ets> to send. Cf. <er>Dismiss</er>.]</ety>
<def>To lay down or relinquish an office, membership, authority, or the
like; to resign, as from a Masonic lodge; -- generally used with an
implication that the act is voluntary.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Demit</ent><br/
<hw>De*mit"</hw>, <pos>n.</pos> <def>The act of demitting; also, a
letter, certificate, or the like, certifying that a person has
(honorably) demitted, as from a Masonic lodge.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Demi-tasse</ent><br/
\'d8<hw>De*mi"-tasse"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., half
cup.]</ety> <def>A small cup for, or of, black coffee.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Demitint</ent><br/
<hw>Dem"i*tint`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Fine Arts)</fld>
<sd>(a)</sd> <def>That part of a painting, engraving, or the like, which
is neither in full darkness nor full light.</def> <sd>(b)</sd> <def>The
shade itself; neither the darkest nor the lightest in a composition.
Also called <xex>half tint</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demitone</ent><br/
<hw>Dem"i*tone`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Mus.)</fld>
<def>Semitone.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demiurge</ent><br/
<hw>Dem"i*urge</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>dhmioyrgo`s</grk> a worker for the people, a workman, especially
the maker of the world, the Creator; <grk>dh`mios</grk> belonging to the
people (fr. <grk>dh^mos</grk> the people) + <grk>'e`rgon</grk> a
work.]</ety> <sn>1.</sn> <fld>(Gr. Antiq.)</fld> <def>The chief
magistrate in some of the Greek states.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>God, as the Maker of the world.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>According to the Gnostics, an agent or one employed
by the Supreme Being to create the material universe and man.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demiurgic</ent><br/
<hw>Dem`i*ur"gic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>dhmioyrgiko`s</grk>.]</ety> <def>Pertaining to a demiurge;
formative; creative.</def> <ldquo/<xex>Demiurgic</xex> power.<rdquo/
<rj><au>De Quincey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demivill</ent><br/
<hw>Dem"i*vill`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Old Law)</fld>
<def>A half vill, consisting of five freemen or frankpledges.</def>
<rj><au>Blackstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demivolt</ent><br/
<hw>Dem"i*volt`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F. <ets>demi-
volte</ets>.]</ety> <fld>(Man.)</fld> <def>A half vault; one of the
seven artificial motions of a horse, in which he raises his fore legs in
a particular manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demiwolf</ent><br/
<hw>Dem"i*wolf`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A half wolf; a
mongrel dog, between a dog and a wolf.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demobilization</ent><br/
<hw>De*mob`i*li*za"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>d<eacute/mobilisation</ets>. See <er>Mobilization</er>.]</ety>
<fld>(Mil.)</fld> <def>The disorganization or disarming of troops which
have previously been mobilized or called into active service; the change
from a war footing to a peace footing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demobilize</ent><br/
<hw>De*mob"i*lize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Cf. F.
<ets>d<eacute/mobiliser</ets>.]</ety> <fld>(Mil.)</fld> <def>To
disorganize, or disband and send home, as troops which have been
<xex>mobilized</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demochelys</ent><br/
<hw>Demochelys</hw> <pos>prop. n.</pos> <def>the type genus of the
<fam>Dermochelyidae</fam>, consisting of leatherback turtles.</def><br/
<syn><b>Syn. --</b> genus <gen>Dermochelys</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Democracy</ent><br/
<hw>De*moc"ra*cy</hw> <pr>(d<esl/*m<ocr/k"r<adot/*s<ycr/)</pr>,
<pos>n.</pos>; <plu><it>pl.</it> <plw>Democracies</plw>
<pr>(d<esl/*m<ocr/k"r<adot/*s<icr/z)</pr>.</plu> <ety>[F.
<ets>d<eacute/mocratie</ets>, fr. Gr. <grk>dhmokrati`a</grk>;
<grk>dh^mos</grk> the people + <grk>kratei^n</grk> to be strong, to
rule, <grk>kra`tos</grk> strength.]</ety> <sn>1.</sn> <def>Government by
the people; a form of government in which the supreme power is retained
and directly exercised by the people.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Government by popular representation; a form of
government in which the supreme power is retained by the people, but is
indirectly exercised through a system of representation and delegated
authority periodically renewed; a constitutional representative
government; a republic.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Collectively, the people, regarded as the source of
government.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The principles and policy of the Democratic party,
so called.</def> <mark>[U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Democrat</ent><br/
<hw>Dem"o*crat</hw> <pr>(d<ecr/m"<osl/*kr<acr/t)</pr>, <pos>n.</pos>
<ety>[Cf. F. <ets>d<eacute/mocrate</ets>.]</ety> <sn>1.</sn> <def>One
who is an adherent or advocate of democracy, or government by the
people.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Whatever they call him, what care I,<br/
Aristocrat, <qex>democrat</qex>, autocrat.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <mark>[capitalized]</mark> <def>A member of the
Democratic party.</def> <mark>[U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A large light uncovered wagon with two or more
seats.</def> <mark>[U. S.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Democratic</ent><br/
<hw>Dem`o*crat"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>dhmokrat'i`a</grk>: cf. F. <ets>d<eacute/mocratique</ets>.]</ety>
<sn>1.</sn> <def>Pertaining to democracy; favoring democracy, or
constructed upon the principle of government by the people.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>belonging to or relating to the Democratic party,
the political party so called.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Befitting the common people; -- opposed to
<contr>aristocratic</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>The Democratic party</b></col>, <cd>the name of one of
the chief political parties in the United States.</cd> <note>Presidents
of the United States who belonged to the Democratic party in the
twentieth century were <person>Woodrow Wilson</person>, <person>Franklin
D. Roosevelt</person>, <person>Harry Truman</person>, <person>John F.
Kennedy</person>, <person>Lyndon B. Johnson</person>, <person>Jimmy
Carter</person>, and <person>Bill Clinton</person>.</note></cs><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Democratical</ent><br/
<hw>Dem`o*crat"ic*al</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Democratic.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>democratical</qex> embassy was democratically
received.</q> <rj><qau>Algernon Sidney.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Democratically</ent><br/
<hw>Dem`o*crat"ic*al*ly</hw>, <pos>adv.</pos> <def>In a democratic
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Democratism</ent><br/
<hw>De*moc"ra*tism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The principles
or spirit of a democracy.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Democratist</ent><br/
<hw>De*moc"ra*tist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A
democrat.</def> <mark>[R.]</mark> <rj><au>Burke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Democratize</ent><br/
<hw>De*moc"ra*tize</hw> <pr>(?)</pr> <pos>v. t.</pos> <def>To render
democratic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Democraty</ent><br/
<hw>De*moc"ra*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Democracy.</def>
<mark>[Obs.]</mark> <rj><au>Milton.</au></rj></p>

<p><ent>demodulator</ent><br/
<hw>demodulator</hw> <pos>n.</pos> <fld>(Electronics)</fld> <def>An
electronic device which extracts the modulation from a radio carrier
wave, and outputs the original information-bearing signal.</def><br/
<syn><b>Syn. --</b> detector.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]<br/
[<source>1913 Webster</source>]</p>

<p><-- p. 389 --></p>

<p><ent>Demogorgon</ent><br/
<hw>De`mo*gor"gon</hw> <pr>(d<emac/"m<osl/*g<ocir/r*g<ocr/n <it>or</it>
d<ecr/m"<osl/*g<ocir/r*g<ocr/n)</pr>, <pos>n.</pos> <ety>[First
mentioned by <person>Lutatius</person>, or <person>Lactantius
Placidus</person>, the scholiast on Statius, perh. fr. Gr.
<grk>dai`mwn</grk> god, deity + <grk>gorgo`s</grk> fierce,
terrible]</ety> <def>A mysterious, terrible, and evil divinity, regarded
by some as the author of creation, by others as a great magician who was
supposed to command the spirits of the lower world. See
<er>Gorgon</er>.</def> <-- Demogorgon: etymology copied from later
edition of Websters, due to page torn in 1913 ed. PCP --><br/
[<source>1913 Webster</source>]</p>

<p><q>Orcus and Ades, and the dreaded name<br/
Of <qex>Demogorgon</qex>.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>demographic</ent><br/
<hw>demographic</hw> <pos>adj.</pos> <def>of or pertaining to
demography; <as>as, <ex>demographic</ex> surveys</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>demography</ent><br/
<hw>de*mog"ra*phy</hw> <pr>(d<esl/*m<ocr/g"r<adot/f<ycr/)</pr>,
<pos>n.</pos> <ety>[Gr. <grk>dh^mos</grk> the people +
<ets>-graphy</ets>.]</ety> <def>The study of vital statistics, such as
births, deaths, marriages, mortality, health, etc., in populations and
subgroups of populations.</def> -- <wordforms><wf>Dem`o*graph"ic</wf>,
<pos>a.</pos></wordforms><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Demoiselle</ent><br/
\'d8<hw>De`moi`selle"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. See
<er>Damsel</er>.]</ety> <sn>1.</sn> <def>A young lady; a damsel; a
lady's maid.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>The Numidian crane
(<spn>Anthropoides virgo</spn>); -- so called on account of the grace
and symmetry of its form and movements.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <def>A beautiful, small dragon fly of
the genus <gen>Agrion</gen>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demolish</ent><br/
<hw>De*mol"ish</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Demolished</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Demolishing</conjf>.]</vmorph> <ety>[F.
<ets>d<eacute/molir</ets>, fr. L. <ets>demoliri</ets>, p. p.
<ets>demolitus</ets>; <ets>de-</ets> + <ets>moliri</ets> to set a thing
in motion, to work, construct, from <ets>moles</ets> a huge mass or
structure. See <er>Mole</er> a mound, and <er>Finish</er>.]</ety>
<def>To throw or pull down; to raze; to destroy the fabric of; to pull
to pieces; to ruin; <as>as, to <ex>demolish</ex> an edifice, or a
wall</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I expected the fabric of my book would long since have been
<qex>demolished</qex>, and laid even with the ground.</q>
<rj><qau>Tillotson.</qau></rj></p>

<p><syn><b>Syn.</b> -- To <er>Demolish</er>, <er>Overturn</er>,
<er>Destroy</er>, <er>Dismantle</er>, <er>Raze</er>. That is
<xex>overturned</xex> or <xex>overthrown</xex> which had stood upright;
that is destroyed whose component parts are scattered; that is
<xex>demolished</xex> which had formed a mass or structure; that is
<xex>dismantled</xex> which is stripped of its covering, as a vessel of
its sails, or a fortress of its bastions, etc.; that is <xex>razed</xex>
which is brought down smooth, and level to the ground. An ancient pillar
is <xex>overturned</xex> or <xex>overthrown</xex> as the result of
decay; a city is <xex>destroyed</xex> by an invasion of its enemies; a
monument, the walls of a castle, a church, or any structure, real or
imaginary, may be <xex>demolished</xex>; a fortress may be
<xex>dismantled</xex> from motives of prudence, in order to render it
defenseless; a city may be <xex>razed</xex> by way of punishment, and
its ruins become a memorial of vengeance.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demolisher</ent><br/
<hw>De*mol"ish`er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, demolishes; <as>as, a <ex>demolisher</ex> of
towns</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demolishment</ent><br/
<hw>De*mol"ish*ment</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Demolition.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demolition</ent><br/
<hw>Dem`o*li"tion</hw> <pr>(?; 277)</pr>, <pos>n.</pos> <ety>[L.
<ets>demolitio</ets>, fr. <ets>demoliri</ets>: cf. F.
<ets>d<eacute/molition</ets>. See <er>Demolish</er>.]</ety> <def>The act
of overthrowing, pulling down, or destroying a pile or structure;
destruction by violence; utter overthrow; -- opposed to
<xex>construction</xex>; <as>as, the <ex>demolition</ex> of a house, of
military works, of a town, or of hopes</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demolitionist</ent><br/
<hw>Dem`o*li"tion*ist</hw>, <pos>n.</pos> <def>A demolisher.</def>
<mark>[R.]</mark> <rj><au>Carlyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demon</ent><br/
<hw>De"mon</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>d<eacute/mon</ets>, L. <ets>daemon</ets> a spirit, an evil spirit,
fr. Gr. <grk>dai`mwn</grk> a divinity; of uncertain origin.]</ety>
<sn>1.</sn> <fld>(Gr. Antiq.)</fld> <def>A spirit, or immaterial being,
holding a middle place between men and deities in pagan
mythology.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>demon</qex> kind is of an intermediate nature between the
divine and the human.</q> <rj><qau>Sydenham.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One's genius; a tutelary spirit or internal voice;
<as>as, the <ex>demon</ex> of Socrates</as>.</def> <altsp>[Often written
<asp>d<ae/mon</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>An evil spirit; a devil.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That same <qex>demon</qex> that hath gulled thee thus.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demoness</ent><br/
<hw>De"mon*ess</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A female
demon.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>demonetisation</ent><br/
<hw>demonetisation</hw> <pos>n.</pos> <def>same as
<er>demonetization</er>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>demonetization</ent><br/
<hw>de*mon`e*ti*za"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
demonetizing, or the condition of being demonetized;</def>
<specif>specificially,</specif> <def>the declaration by a government
that something (e.g. gold or silver) is no longer the legal tender of a
country; <as>as, the <ex>demonetization</ex> of gold</as>.</def><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><ent>demonetize</ent><br/
<hw>de*mon"e*tize</hw> <pr>(?; see <er>Monetary</er>)</pr>, <pos>v.
t.</pos> <def>To deprive of current value; to withdraw from use, as
money.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They [gold mohurs] have been completely <qex>demonetized</qex> by
the [East India] Company.</q> <rj><qau>R. Cobden.</qau></rj></p>

<p><ent>Demoniacal</ent><br/
<ent>Demoniac</ent><br/
<mhw>{ <hw>De*mo"ni*ac</hw> <pr>(?)</pr>, <hw>Dem`o*ni"a*cal</hw>
<pr>(?; 277)</pr>, }</mhw> <pos>a.</pos> <ety>[L.
<ets>daemoniacus</ets>, fr. <ets>daemon</ets>; cf. F.
<ets>d<eacute/moniaque</ets>. See <er>Demon</er>.]</ety> <sn>1.</sn>
<def>Pertaining to, or characteristic of, a demon or evil spirit;
devilish; <as>as, a <ex>demoniac</ex> being; <ex>demoniacal</ex>
practices.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Sarcastic, <qex>demoniacal</qex> laughter.</q>
<rj><qau>Thackeray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Influenced or produced by a demon or evil spirit;
<as>as, <ex>demoniac</ex> or <ex>demoniacal</ex> power</as>.</def>
<ldquo/<xex>Demoniac</xex> frenzy.<rdquo/ <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>resembling or suggesting possession by a demon;
<as>as, <ex>demoniac</ex> energy</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>4.</sn> <def>in a murderous frenzy as if possessed by a
demon.</def><br/
<syn><b>Syn. --</b> amuck, amok, berserk, demoniac,
possessed(predicate).</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Demoniac</ent><br/
<hw>De*mo"ni*ac</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A
human being possessed by a demon or evil spirit; one whose faculties are
directly controlled by a demon.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>demoniac</qex> in the gospel was sometimes cast into the
fire.</q> <rj><qau>Bates.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Eccl. Hist.)</fld> <def>One of a sect of
Anabaptists who maintain that the demons or devils will finally be
saved.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demoniacally</ent><br/
<hw>Dem`o*ni"a*cal*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a
demoniacal manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demoniacism</ent><br/
<hw>Dem`o*ni"a*cism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state of
being demoniac, or the practices of demoniacs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demonial</ent><br/
<hw>De*mo"ni*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining
to a demon.</def> <mark>[Obs.]</mark> <rj><au>Cudworth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demonian</ent><br/
<hw>De*mo"ni*an</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Relating to, or
having the nature of, a demon.</def> <ldquo/<xex>Demonian</xex>
spirits.<rdquo/ <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demonianism</ent><br/
<hw>De*mo"ni*an*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state of
being possessed by a demon or by demons.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demoniasm</ent><br/
<hw>De*mo"ni*asm</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Demonianism</er>.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demonic</ent><br/
<hw>De*mo"nic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>daemonicus</ets>, Gr. <grk>daimoniko`s</grk>.]</ety> <def>Of or
pertaining to a demon or to demons; demoniac.</def>
<ldquo/<xex>Demonic</xex> ambushes.<rdquo/ <rj><au>Lowell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demonism</ent><br/
<hw>De"mon*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>d<eacute/monisme</ets>.]</ety> <def>The belief in demons or false
gods.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The established theology of the heathen world . . . rested upon
the basis of <qex>demonism</qex>.</q> <rj><qau>Farmer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demonist</ent><br/
<hw>De"mon*ist</hw>, <pos>n.</pos> <def>A believer in, or worshiper of,
demons.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demonize</ent><br/
<hw>De"mon*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Demonized</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Demonizing</conjf>.]</vmorph> <ety>[Cf. LL.
<ets>daemonizare</ets> to be possessed by a demon, Gr.
<grk>dai`mwn</grk>.]</ety> <sn>1.</sn> <def>To convert into a demon; to
infuse the principles or fury of a demon into.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To control or possess by a demon.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demonocracy</ent><br/
<hw>De`mon*oc"ra*cy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>dai`mwn</grk> demon + <grk>kra`tos</grk> strength: cf. F.
<ets>d<eacute/monocratie</ets>.]</ety> <def>The power or government of
demons.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>demonocracy</qex> of unclean spirits.</q> <rj><qau>H.
Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demonographer</ent><br/
<hw>De`mon*og"ra*pher</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Demon</ets> + <ets>-graph</ets> + <ets>-er</ets>.]</ety>
<def>A demonologist.</def> <mark>[R.]</mark> <rj><au>Am.
Cyc.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demonolatry</ent><br/
<hw>De`mon*ol"a*try</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>dai`mwn</grk> demon + <grk>latrei`a</grk> worship, <?/ to serve,
worship: cf. F. <ets>d<eacute/monol<acir/trie</ets>.]</ety> <def>The
worship of demons.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demonologer</ent><br/
<hw>De`mon*ol"o*ger</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One versed in
demonology.</def> <rj><au>R. North.</au></rj></p>

<p><ent>Demonological</ent><br/
<ent>Demonologic</ent><br/
<mhw>{ <hw>De`mon*o*log"ic</hw> <pr>(?)</pr>,
<hw>De`mon*o*log"ic*al</hw> <pr>(?)</pr>, }</mhw> <pos>a.</pos>
<ety>[Cf. F. <ets>d<eacute/monologique</ets>.]</ety> <def>Of or
pertaining to demonology.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demonologist</ent><br/
<hw>De`mon*ol"o*gist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
writes on, or is versed in, demonology.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demonology</ent><br/
<hw>De`mon*ol"o*gy</hw> <pr>(?; 277)</pr>, <pos>n.</pos>
<ety>[<ets>Demon</ets> + <ets>-logy</ets>: cf. F.
<ets>d<eacute/monologie</ets>.]</ety> <def>A treatise on demons; a
supposititious science which treats of demons and their
manifestations.</def> <rj><au>Sir W. Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demonomagy</ent><br/
<hw>De`mon*om"a*gy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>dai`mwn</grk> demon + <grk>magei`a</grk> magic.]</ety> <def>Magic
in which the aid of demons is invoked; black or infernal magic.</def>
<rj><au>Bp. Hurd.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demonomania</ent><br/
<hw>De*mon`o*ma"ni*a</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Demon</ets> + <ets>mania</ets>.]</ety> <def>A form of madness
in which the patient conceives himself possessed of devils.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demonomist</ent><br/
<hw>De*mon"o*mist</hw> <pr>(?)</pr> <pos>n.</pos> <def>One in subjection
to a demon, or to demons.</def> <mark>[R.]</mark> <rj><au>Sir T.
Herbert.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demonomy</ent><br/
<hw>De*mon"o*my</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>dai`mwn</grk> demon + <grk>no`mos</grk> law.]</ety> <def>The
dominion of demons.</def> <mark>[R.]</mark> <rj><au>Sir T.
Herbert.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demonry</ent><br/
<hw>De"mon*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Demoniacal influence
or possession.</def> <rj><au>J. Baillie.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demonship</ent><br/
<hw>De"mon*ship</hw>, <pos>n.</pos> <def>The state of a demon.</def>
<rj><au>Mede.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demonstrability</ent><br/
<hw>De*mon`stra*bil"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The
quality of being demonstrable; demonstrableness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demonstrable</ent><br/
<hw>De*mon"stra*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>demonstrabilis</ets>: cf. OF. <ets>demonstrable</ets>, F.
<ets>d<eacute/montrable</ets>.]</ety> <sn>1.</sn> <def>Capable of being
demonstrated; that can be proved beyond doubt or question.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The grand articles of our belief are as <qex>demonstrable</qex> as
geometry.</q> <rj><qau>Glanvill.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Proved; apparent.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demonstrableness</ent><br/
<hw>De*mon"stra*ble*ness</hw>, <pos>n.</pos> <def>The quality of being
demonstrable; demonstrability.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demonstrably</ent><br/
<hw>De*mon"stra*bly</hw>, <pos>adv.</pos> <def>In a demonstrable manner;
incontrovertibly; clearly.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Cases that <qex>demonstrably</qex> concerned the public cause.</q>
<rj><qau>Clarendon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demonstrance</ent><br/
<hw>De*mon"strance</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>demonstrance</ets>.]</ety> <def>Demonstration; proof.</def>
<mark>[Obs.]</mark> <rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demonstrate</ent><br/
<hw>Dem"on*strate</hw> <pr>(?; 277)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>demonstratus</ets>, p. p. of <ets>demonstrare</ets> to demonstrate;
<ets>de-</ets> + <ets>monstrare</ets> to show. See
<er>Monster</er>.]</ety> <sn>1.</sn> <def>To point out; to show; to
exhibit; to make evident.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To show, or make evident, by reasoning or proof; to
prove by deduction; to establish so as to exclude the possibility of
doubt or denial.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We can not <qex>demonstrate</qex> these things so as to show that
the contrary often involves a contradiction.</q>
<rj><qau>Tillotson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Anat.)</fld> <def>To exhibit and explain (a
dissection or other anatomical preparation).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>demonstrated</ent><br/
<hw>demonstrated</hw> <pos>adj.</pos> <def>having been proved or
verified beyond doubt; proved by demonstration.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Demonstrater</ent><br/
<hw>Dem"on*stra`ter</hw>, <pos>n.</pos> <def>See
<er>Demonstrator</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demonstration</ent><br/
<hw>Dem`on*stra"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>demonstratio</ets>: cf. F. <ets>d<eacute/monstration</ets>.]</ety>
<sn>1.</sn> <def>The act of demonstrating; an exhibition; proof;
especially, proof beyond the possibility of doubt; indubitable evidence,
to the senses or reason.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Those intervening ideas which serve to show the agreement of any
two others are called <ldquo/proofs;<rdquo/ and where agreement or
disagreement is by this means plainly and clearly perceived, it is
called <qex>demonstration</qex>.</q> <rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An expression, as of the feelings, by outward signs;
a manifestation; a show. See also sense 7 for a more specific related
meaning.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><q>Did your letters pierce the queen to any <qex>demonstration</qex>
of grief?</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Loyal <qex>demonstrations</qex> toward the prince.</q>
<rj><qau>Prescott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Anat.)</fld> <def>The exhibition and explanation of
a dissection or other anatomical preparation.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>(Mil.) a decisive exhibition of force, or a movement
indicating an attack.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Logic)</fld> <def>The act of proving by the
syllogistic process, or the proof itself.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Math.)</fld> <def>A course of reasoning showing
that a certain result is a necessary consequence of assumed premises; --
these premises being definitions, axioms, and previously established
propositions.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>a public gathering of people to express some
sentiment or feelings by explicit means, such as picketing, parading,
carrying signs or shouting, usually in favor of or opposed to some
action of government or of a business.</def><br/
[<source>PJC</source>]</p>

<p><sn>8.</sn> <def>the act of showing how a certain device, machine or
product operates, or how a procedure is performed; -- usually done for
the purpose of inducing prospective customers to buy a product; <as>as,
a <ex>demonstration</ex> of the simple operation of a microwave
oven</as>.</def><br/
[<source>PJC</source>]</p>

<p><cs><mcol><col><b>Direct demonstration</b></col>, <it>or</it>
<col><b>Positive demonstration</b></col>,</mcol> <fld>(Logic &
Math.)</fld>, <cd>one in which the correct conclusion is the immediate
sequence of reasoning from axiomatic or established premises</cd>; --
opposed to <mcol><col><b>Indirect demonstration</b></col>, <it>or</it>
<col><b>Negative demonstration</b></col></mcol> <cd>(called also
<altname>reductio ad absurdum</altname>), in which the correct
conclusion is an inference from the demonstration that any other
hypothesis must be incorrect.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demonstrative</ent><br/
<hw>De*mon"stra*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F.
<ets>d<eacute/monstratif</ets>, L. <ets>demonstrativus</ets>.]</ety>
<sn>1.</sn> <def>Having the nature of demonstration; tending to
demonstrate; making evident; exhibiting clearly or conclusively.</def>
<ldquo/<xex>Demonstrative</xex> figures.<rdquo/
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>An argument necessary and <qex>demonstrative</qex>.</q>
<rj><qau>Hooker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Expressing, or apt to express, much; displaying
feeling or sentiment; <as>as, her nature was
<ex>demonstrative</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Consisting of eulogy or of invective.</def>
<ldquo/<xex>Demonstrative</xex> eloquence.<rdquo/
<rj><au>Blair.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Demonstrative pronoun</b></col> <fld>(Gram.)</fld>, <cd>a
pronoun distinctly designating that to which it refers.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demonstrative</ent><br/
<hw>De*mon"stra*tive</hw>, <pos>n.</pos> <fld>(Gram.)</fld> <def>A
demonstrative pronoun; <as>as, <ldquo/this<rdquo/ and <ldquo/that<rdquo/
are <ex>demonstratives</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demonstratively</ent><br/
<hw>De*mon"stra*tive*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a
manner fitted to demonstrate; clearly; convincingly; forcibly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demonstrativeness</ent><br/
<hw>De*mon"stra*tive*ness</hw>, <pos>n.</pos> <def>The state or quality
of being demonstrative.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demonstrator</ent><br/
<hw>Dem"on*stra`tor</hw> <pr>(?; 277)</pr>, <pos>n.</pos> <ety>[L.: cf.
F. <ets>d<eacute/monstrateur</ets>.]</ety> <sn>1.</sn> <def>One who
demonstrates;</def> <specif>specif.</specif> <sd>(a)</sd> <def>one who
proves anything with certainty, or establishes it by indubitable
evidence.</def> <sd>(b)</sd> <def>one who shows how a certain device
operates or a procedure is performed.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Anat.)</fld> <def>A teacher of practical
anatomy.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>a person who participates in a
demonstration{7}.</def><br/
[<source>PJC</source>]</p>

<p><ent>Demonstratory</ent><br/
<hw>De*mon"stra*to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Tending to
demonstrate; demonstrative.</def> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demorage</ent><br/
<hw>De*mor"age</hw> <pr>(?; 48)</pr>, <pos>n.</pos>
<def>Demurrage.</def> <mark>[Obs.]</mark> <rj><au>Pepys
(1663).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demoralization</ent><br/
<hw>De*mor`al*i*za"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>d<eacute/moralisation</ets>.]</ety> <def>The act of corrupting or
subverting morals. Especially: The act of corrupting or subverting
discipline, courage, hope, etc., or the state of being corrupted or
subverted in discipline, courage, etc.; <as>as, the
<ex>demoralization</ex> of an army or navy</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demoralize</ent><br/
<hw>De*mor"al*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Demoralized</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Demoralizing</conjf>.]</vmorph> <ety>[F.
<ets>d<eacute/moraliser</ets>; pref. <ets>d<eacute/-</ets> (L.
<ets>dis-</ets> or <ets>de</ets>) + <ets>moraliser</ets>. See
<er>Moralize</er>.]</ety> <def>To corrupt or undermine in morals; to
destroy or lessen the effect of moral principles on; to render corrupt
or untrustworthy in morals, in discipline, in courage, spirit, etc.; to
weaken in spirit or efficiency.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>demoralizing</qex> example of profligate power and
prosperous crime.</q> <rj><qau>Walsh.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The vices of the nobility had <qex>demoralized</qex> the army.</q>
<rj><qau>Bancroft.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>demoralized</ent><br/
<hw>demoralized</hw> <pos>adj.</pos> <def>made less hopeful or
enthusiastic; rendered pessimistic; <as>as, the <ex>demoralized</ex>
Iraqi ground troops put up little resistance</as>.</def><br/
<syn><b>Syn. --</b> discouraged, disheartened.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>demoralizing</ent><br/
<hw>demoralizing</hw> <pos>adj.</pos> <sn>1.</sn> <def>discouraging.
Opposite of <ant>encouraging</ant>.</def><br/
<syn><b>Syn. --</b> demoralising, disheartening, dispiriting.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Demosthenes</ent><br/
<hw>Demosthenes</hw> <pos>prop. n.</pos> <def>a famous Grecian orator,
born circa 385 BC, died circa 322 BC.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Demosthenic</ent><br/
<hw>Dem`os*then"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>Demosthenicus</ets>: cf. F.
<ets>D<eacute/mosth<eacute/nique</ets>.]</ety> <def>Pertaining to, or in
the style of, <person>Demosthenes</person>, the Grecian
orator.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demote</ent><br/
<hw>De*mote"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Demoted</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Demoting</conjf> <pr>(?)</pr>.]</vmorph> <ety>[Pref.
<ets>de-</ets> + <ets>mote</ets>, as in <ets>promote</ets>; cf. L.
<ets>demovere</ets> to remove.]</ety> <def>To reduce to a lower grade or
rank, as in the military, one's employment, or in school; to assign to a
lower position.</def><br/
<syn><b>Syn. --</b> bump, relegate, kick downstairs, break one's
rank.</syn><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source> <source>WordNet 1.5</source>]</p>

<p><ent>Demotic</ent><br/
<hw>De*mot"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>dhmotiko`s</grk>, fr. <grk>dh^mos</grk> the people: cf. F.
<ets>d<eacute/motique</ets>.]</ety> <def>Of or pertaining to the people;
popular; common.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Demotic alphabet</b></col> <it>or</it>
<col><b>Demotic character</b></col></mcol>, <cd>a form of writing used
in Egypt after six or seven centuries before Christ, for books, deeds,
and other such writings; a simplified form of the hieratic character; --
called also <altname>epistolographic character</altname>, and
<altname>enchorial character</altname>. See
<er>Enchorial</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demotics</ent><br/
<hw>De*mot"ics</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The department of
knowledge relative to the care and culture of the people; sociology in
its broadest sense; -- in library cataloguing.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Demount</ent><br/
<hw>De*mount"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To
dismount.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demountable</ent><br/
<hw>De*mount"a*ble</hw> <pr>(?)</pr>, <ety>[See <er>De-</er>;
<er>Mount</er>.]</ety> <def>Capable of being dismounted; -- said of a
form of rim, for an automobile wheel, which can be removed with its tire
from the wheel.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Dempne</ent><br/
<hw>Demp"ne</hw> <pr>(d<ecr/mp"n<eit/)</pr> <pos>v. t.</pos> <def>To
damn; to condemn.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj></p>

<p><ent>Demster</ent><br/
<ent>Dempster</ent><br/
<mhw>{ <hw>Demp"ster</hw> <pr>(?; 215)</pr>, <hw>Dem"ster</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[See <er>Deemster</er>.]</ety>
<sn>1.</sn> <def>A deemster.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(O. Scots Law)</fld> <def>An officer whose duty it
was to announce the doom or sentence pronounced by the court.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demulce</ent><br/
<hw>De*mulce"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>demulcere</ets>; <ets>de-</ets> + <ets>mulcere</ets> to stroke,
soothe.]</ety> <def>To soothe; to mollify; to pacify; to soften.</def>
<mark>[R.]</mark> <rj><au>Sir T. Elyot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demulcent</ent><br/
<hw>De*mul"cent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>demulcens</ets>, p. pr. of <ets>demulcere</ets>.]</ety>
<def>Softening; mollifying; soothing; assuasive; <as>as, oil is
<ex>demulcent</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demulcent</ent><br/
<hw>De*mul"cent</hw>, <pos>n.</pos> <fld>(Med.)</fld> <def>A substance,
usually of a mucilaginous or oily nature, supposed to be capable of
soothing an inflamed nervous membrane, or protecting it from irritation.
Gum Arabic, glycerin, olive oil, etc., are demulcents.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demulsion</ent><br/
<hw>De*mul"sion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
soothing; that which soothes.</def> <rj><au>Feltham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demur</ent><br/
<hw>De*mur"</hw> <pr>(d<esl/*m<ucir/r")</pr>, <pos>v. i.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Demurred</conjf>
<pr>(d<esl/*m<ucir/rd")</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Demurring</conjf>.]</vmorph> <ety>[OF. <ets>demurer</ets>,
<ets>demorer</ets>, <ets>demourer</ets>, to linger, stay, F.
<ets>demeurer</ets>, fr. L. <ets>demorari</ets>; <ets>de-</ets> +
<ets>morari</ets> to delay, tarry, stay, <ets>mora</ets> delay; prob.
originally, time for thinking, reflection, and akin to <ets>memor</ets>
mindful. See <er>Memory</er>.]</ety> <sn>1.</sn> <def>To linger; to
stay; to tarry.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Yet durst not <qex>demur</qex> nor abide upon the camp.</q>
<rj><qau>Nicols.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To delay; to pause; to suspend proceedings or
judgment in view of a doubt or difficulty; to hesitate; to put off the
determination or conclusion of an affair.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Upon this rub, the English embassadors thought fit to
<qex>demur</qex>.</q> <rj><qau>Hayward.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To scruple or object; to take exception, especially
on the basis of scruple or modesty; <as>as, I <ex>demur</ex> to that
statement; they wanted to make him president, but he
<ex>demurred</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>From the popular assertion that he was the smartest man in the
world <persfn>Gell-Mann</persfn> was not predisposed to
<qex>demur</qex>.</q> <rj><qau>Timothy Ferris, in <book>Coming of Age in
the Milky Way</book> (Doubleday, New York, 1989).</qau></rj><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <fld>(Law)</fld> <def>To interpose a demurrer. See
<er>Demurrer</er>, 2.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demur</ent><br/
<hw>De*mur"</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To suspend judgment
concerning; to doubt of or hesitate about.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The latter I <qex>demur</qex>, for in their looks<br/
Much reason, and in their actions, oft appears.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To cause delay to; to put off.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He demands a fee,<br/
And then <qex>demurs</qex> me with a vain delay.</q>
<rj><qau>Quarles.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demur</ent><br/
<hw>De*mur"</hw>, <pos>n.</pos> <ety>[OF. <ets>demor</ets>,
<ets>demore</ets>, stay, delay. See <er>Demur</er>, <pos>v.
i.</pos>]</ety> <def>Stop; pause; hesitation as to proceeding; suspense
of decision or action; scruple.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>All my <qex>demurs</qex> but double his attacks;<br/
At last he whispers, <ldquo/Do; and we go snacks.<rdquo/</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demure</ent><br/
<hw>De*mure"</hw> <pr>(d<esl/*m<umac/r")</pr>, <pos>a.</pos> <ety>[Perh.
from OF. <ets>de murs</ets> (i. e., <ets>de bonnes murs</ets> of good
manners); <ets>de</ets> of + <ets>murs</ets>, <ets>mours</ets>,
<ets>meurs</ets>, <ets>mors</ets>, F. <ets>m<oe/urs</ets>, fr. L.
<ets>mores</ets> (sing. <ets>mos</ets>) manners, morals (see
<er>Moral</er>); or more prob. fr. OF. <ets>me<uum/r</ets>, F.
<ets>m<ucir/r</ets> mature, ripe (see <er>Mature</er>) in a phrase
preceded by <ets>de</ets>, <ets>as de m<ucir/re conduite</ets> of mature
conduct.]</ety> <sn>1.</sn> <def>Of sober or serious mien; composed and
decorous in bearing; of modest look; staid; grave.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Sober, steadfast, and <qex>demure</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Nan was very much delighted in her <qex>demure</qex> way, and that
delight showed itself in her face and in her clear bright eyes.</q>
<rj><qau>W. Black.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Affectedly modest, decorous, or serious; making a
show of gravity.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A cat lay, and looked so <qex>demure</qex>, as if there had been
neither life nor soul in her.</q> <rj><qau>L'Estrange.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Miss Lizzy, I have no doubt, would be as <qex>demure</qex> and
coquettish, as if ten winters more had gone over her head.</q>
<rj><qau>Miss Mitford.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demure</ent><br/
<hw>De*mure"</hw>, <pos>v. i.</pos> <def>To look demurely.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demurely</ent><br/
<hw>De*mure"ly</hw>, <pos>adv.</pos> <def>In a demure manner; soberly;
gravely; -- now, commonly, with a mere show of gravity or
modesty.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They . . . looked as <qex>demurely</qex> as they could; for 't was
a hanging matter to laugh unseasonably.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 390 --></p>

<p><ent>Demureness</ent><br/
<hw>De*mure"ness</hw> <pr>(d<esl/*m<umac/r"n<ecr/s)</pr>, <pos>n.</pos>
<def>The state of being demure; gravity; the show of gravity or
modesty.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demurity</ent><br/
<hw>De*mur"i*ty</hw> <pr>(d<esl/*m<umac/r"<icr/*t<ycr/)</pr>,
<pos>n.</pos> <def>Demureness; also, one who is demure.</def>
<rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demurrable</ent><br/
<hw>De*mur"ra*ble</hw> <pr>(d<esl/*m<ucir/r"r<adot/*b'l)</pr>,
<pos>a.</pos> <def>That may be demurred to.</def>
<rj><au>Stormonth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demurrage</ent><br/
<hw>De*mur"rage</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. OF.
<ets>demorage</ets> delay. See <er>Demur</er>.]</ety> <fld>(Law)</fld>
<sd>(a)</sd> <def>The detention of a vessel by the freighter beyond the
time allowed in her charter party for loading, unloading, or
sailing.</def> <sd>(b)</sd> <def>The allowance made to the master or
owner of the ship for such delay or detention.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The claim for <qex>demurrage</qex> ceases as soon as the ship is
cleared out and ready for sailing.</q>
<rj><qau>M<lsquo/Culloch.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The term is also applied to similar delays and
allowances in land carriage, by wagons, railroads, etc.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demurral</ent><br/
<hw>De*mur"ral</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Demur; delay in
acting or deciding.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The same causes of <qex>demurral</qex> existed which prevented
British troops from assisting in the expulsion of the French from
Rome.</q> <rj><qau>Southey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demurrer</ent><br/
<hw>De*mur"rer</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who
demurs.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>A stop or pause by a party to an
action, for the judgment of the court on the question, whether, assuming
the truth of the matter alleged by the opposite party, it is sufficient
in law to sustain the action or defense, and hence whether the party
resting is bound to answer or proceed further.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Demurrer to evidence</b></col>, <cd>an exception taken by
a party to the evidence offered by the opposite party, and an objecting
to proceed further, on the allegation that such evidence is not
sufficient in law to maintain the issue, and a reference to the court to
determine the point.</cd> <rj><au>Bouvier.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demy</ent><br/
<hw>De*my"</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Demies</plw> <pr>(#)</pr>.</plu> <ety>[See <er>Demi-</er>.]</ety>
<sn>1.</sn> <def>A printing and a writing paper of particular sizes. See
under <er>Paper</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A half fellow at Magdalen College, Oxford.</def>
<altsp>[Written also <asp>demi</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><q>He was elected into Magdalen College as a <qex>demy</qex>; a term
by which that society denominates those elsewhere called
<ldquo/scholars,<rdquo/ young men who partake of the founder's
benefaction, and succeed in their order to vacant fellowships.</q>
<rj><qau>Johnson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Demy</ent><br/
<hw>De*my"</hw>, <pos>a.</pos> <def>Pertaining to, or made of, the size
of paper called <xex>demy</xex>; <as>as, a <ex>demy</ex>
book</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>demythologisation</ent><br/
<hw>demythologisation</hw> <pos>n.</pos> <def>same as
<er>demythologization</er>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>demythologization</ent><br/
<hw>demythologization</hw> <pos>n.</pos> <def>the restatement of a
message (as a religious one) in rational terms.</def><br/
<syn><b>Syn. --</b> demythologisation.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>demythologize</ent><br/
<hw>demythologize</hw> <pos>v. t.</pos> <def>to remove the mythical
elements from; -- of writings, such as the Bible.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>demythologized</ent><br/
<hw>demythologized</hw> <pos>adj.</pos> <def>having mythical elements
removed.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Den</ent><br/
<hw>Den</hw> <pr>(d<ecr/n)</pr>, <pos>n.</pos> <ety>[AS.
<ets>denn</ets>; perh. akin to G. <ets>tenne</ets> floor, thrashing
floor, and to AS. <ets>denu</ets> valley.]</ety> <sn>1.</sn> <def>A
small cavern or hollow place in the side of a hill, or among rocks;
esp., a cave used by a wild beast for shelter or concealment; <as>as, a
lion's <ex>den</ex>; a <ex>den</ex> of robbers.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A squalid place of resort; a wretched dwelling
place; a haunt; <as>as, a <ex>den</ex> of vice</as>.</def> <ldquo/Those
squalid <xex>dens</xex>, which are the reproach of great
capitals.<rdquo/ <rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Any snug or close retreat where one goes to be
alone.</def> <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <ety>[AS. <ets>denu</ets>.]</ety> <def>A narrow glen; a
ravine; a dell.</def> <mark>[Old Eng. & Scotch]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Den</ent><br/
<hw>Den</hw>, <pos>v. i.</pos> <def>To live in, or as in, a
den.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The sluggish salvages that <qex>den</qex> below.</q> <rj><qau>G.
Fletcher.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Denali</ent><br/
<hw>Denali</hw> <pos>prop. n.</pos> <sn>1.</sn> <def>The native name for
Mount McKinley in Alaska, translated as <xlati>the great
one</xlati>.</def><br/
<syn><b>Syn. --</b> Mount McKinley.</syn><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def> a national park in Alaska in which Mount McKinley
is located.</def><br/
<syn><b>Syn. --</b> Denali national park.</syn><br/
[<source>PJC</source>]</p>

<p><ent>Denarcotize</ent><br/
<hw>De*nar"co*tize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To deprive
of narcotine; <as>as, to <ex>denarcotize</ex> opium</as>.</def> --
<wordforms><wf>De*nar`co*ti*za"tion</wf> <pr>(#)</pr>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Denarius</ent><br/
\'d8<hw>De*na"ri*us</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Denarii</plw> <pr>(#)</pr>.</plu> <ety>[L. See 2d
<er>Denier</er>.]</ety> <def>A Roman silver coin of the value of about
fourteen cents; the <ldquo/penny<rdquo/ of the New Testament; -- so
called from being worth originally <xex>ten</xex> of the pieces called
<part>as</part>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Denary</ent><br/
<hw>Den"a*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>denarius</ets>. See 2d <er>Denier</er>.]</ety> <def>Containing ten;
tenfold; proceeding by tens; <as>as, the <ex>denary</ex>, or decimal,
scale</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Denary</ent><br/
<hw>Den"a*ry</hw>, <pos>n.</pos> <sn>1.</sn> <def>The number ten; a
division into ten.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A coin; the Anglicized form of
<xex>denarius</xex>.</def> <rj><au>Udall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>denationalisation</ent><br/
<hw>de*na"tion*al*i*sa"tion</hw> <pos>n.</pos> <def>same as
<er>denationalization</er>.</def><br/
<syn><b>Syn. --</b> privatization.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Denationalization</ent><br/
<hw>De*na`tion*al*i*za"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf.
F. <ets>d<eacute/nationalisation</ets>.]</ety> <def>The act or process
of denationalizing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Denationalize</ent><br/
<hw>De*na"tion*al*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Denationalized</conjf>
<pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Denationalizing</conjf>.]</vmorph> <ety>[Cf. F.
<ets>d<eacute/nationaliser</ets>.]</ety> <sn>1.</sn> <def>To divest or
deprive of national character or rights.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Bonaparte's decree <qex>denationalizes</qex>, as he calls it, all
ships that have touched at a British port.</q>
<rj><qau>Cobbett.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>An expatriated, <qex>denationalized</qex> race.</q> <rj><qau>G.
Eliot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>to change (something, as an industry or business)
from state to private ownership or control; <as>as, the British
<ex>denationalization</ex> of steel</as>.</def><br/
<syn><b>Syn. --</b> privatize, denationalise.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Denaturalize</ent><br/
<hw>De*nat"u*ral*ize</hw> <pr>(?; 135)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Denaturalized</conjf>
<pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Denaturalizing</conjf>.]</vmorph> <ety>[Cf. F.
<ets>d<eacute/naturaliser</ets>.]</ety> <sn>1.</sn> <def>To render
unnatural; to alienate from nature.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To renounce the natural rights and duties of; to
deprive of citizenship; to denationalize.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>They also claimed the privilege, when aggrieved, of
<qex>denaturalizing</qex> themselves, or, in other words, of publicly
renouncing their allegiance to their sovereign, and of enlisting under
the banners of his enemy.</q> <rj><qau>Prescott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>same as <er>denature</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Denature</ent><br/
<hw>De*na"ture</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[<ets>De-</ets>
+ <ets>nature</ets>.]</ety> <def>To deprive of its natural qualities;
change the nature of.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>to render (ethyl alcohol) unfit to drink by adding
in toxic or unpalatable substances (such as benzene or pyridine) which
nevertheless permit alcohol to be used as a solvent.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>modify the tertiary structure of (a protein or
nucleic acid) so as to reduce or destroy its characteristic biological
activity.</def> <note>Bioactive macromolecules such as enzymes or DNA
may be denatured by heat, acid, alkali, or solvent treatment; the extent
of such treatment required to denature a molecule varies with the
specific compound. In some cases the denatured molecules may regain
their original properties (renature) by other treatments. Denaturation
may also cause a change in the physical properties of such molecules,
e.g. proteins may become insoluble in water.</note><br/
[<source>PJC</source>]</p>

<p><ent>Denature</ent><br/
<hw>De*na"ture</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To become
denatured.</def><br/
[<source>PJC</source>]</p>

<p><ent>denaturized</ent><br/
<hw>denaturized</hw> <pos>adj.</pos> <def>changed in nature or natural
quality.</def><br/
<syn><b>Syn. --</b> denatured.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Denay</ent><br/
<hw>De*nay"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[See
<er>Deny</er>.]</ety> <def>To deny.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>That with great rage he stoutly doth <qex>denay</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Denay</ent><br/
<hw>De*nay"</hw>, <pos>n.</pos> <def>Denial; refusal.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dendrachate</ent><br/
<hw>Den"dra*chate</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>dendrachates</ets>; Gr. <grk>de`ndron</grk> a tree +
<grk>'acha`ths</grk> agate: cf. F. <ets>dendrachate</ets>,
<ets>dendragate</ets>.]</ety> <fld>(Min.)</fld> <def>Arborescent or
dendritic agate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dendranthema</ent><br/
<hw>Dendranthema</hw> <pos>n.</pos> <def>a genus comprising plants often
included in the genus <gen>Chrysanthemum</gen>.</def><br/
<syn><b>Syn. --</b> genus <gen>Dendranthema</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dendraspis</ent><br/
<hw>Dendraspis</hw> <pos>prop. n.</pos> <def>a genus of African snakes
comprising the mambas.</def><br/
<syn><b>Syn. --</b> <gen>Dendroaspis</gen>, genus
<gen>Dendroaspis</gen>, genus <gen>Dendraspis</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dendriform</ent><br/
<hw>Den"dri*form</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>de`ndron</grk> tree + <ets>-form</ets>.]</ety> <def>Resembling in
structure a tree or shrub; having a branching shape.</def><br/
<syn><b>Syn. --</b> arboreal, arboreous, arborescent, arboresque,
arboriform, dendroid, dendroidal, treelike, tree-shaped.</syn><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Dendrite</ent><br/
<hw>Den"drite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>dendri`ths</grk>, fem. <grk>dendri^tis</grk>, of a tree, fr.
<grk>de`ndron</grk> a tree: cf. F. <ets>dendrite</ets>.]</ety>
<fld>(Min.)</fld> <def>A stone or mineral on or in which are branching
figures resembling shrubs or trees, produced by a foreign mineral,
usually an oxide of manganese, as in the moss agate; also, a
crystallized mineral having an arborescent form, <it>e. g.</it>, gold or
silver; an arborization.</def></p>

<p><ent>Dendritical</ent><br/
<ent>Dendritic</ent><br/
<mhw>{ <hw>Den*drit"ic</hw> <pr>(?)</pr>, <hw>Den*drit"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <def>Pertaining to a dendrite, or to
arborescent crystallization; having a form resembling a shrub or tree;
arborescent.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dendroaspis</ent><br/
<hw>Dendroaspis</hw> <pos>prop. n.</pos> <def>a genus of African snakes
comprising the mambas.</def><br/
<syn><b>Syn. --</b> <gen>Dendraspis</gen>, genus <gen>Dendroaspis</gen>,
genus <gen>Dendroaspis</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dendrocoela</ent><br/
\'d8<hw>Den`dro*c<oe/"la</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
fr. Gr. <grk>de`ndron</grk> tree + <grk>koi^los</grk> hollow.]</ety>
<fld>(Zool.)</fld> <def>A division of the Turbellaria in which the
digestive cavity gives off lateral branches, which are often divided
into smaller branchlets.</def></p>

<p><ent>Dendroidal</ent><br/
<ent>Dendroid</ent><br/
<mhw>{ <hw>Den"droid</hw> <pr>(?)</pr>, <hw>Den*droid"al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[Gr. <?/ treelike;
<grk>de`ndron</grk> tree + <grk>e'i^dos</grk> form: cf. F.
<ets>dendro<ium/de</ets>.]</ety> <def>Resembling a shrub or tree in
form; treelike; branching.</def><br/
<syn><b>Syn. --</b> arboreal, arboreous, arborescent, arboresque,
arboriform, dendriform, treelike, tree-shaped.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dendrolagus</ent><br/
<hw>Dendrolagus</hw> <pos>prop. n.</pos> <def>a genus comprising the
tree wallabies.</def><br/
<syn><b>Syn. --</b> genus <gen>Dendrolagus</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dendrolite</ent><br/
<hw>Den"dro*lite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>de`ndron</grk> tree + <ets>-lite</ets>: cf. F.
<ets>dendrolithe</ets>.]</ety> <fld>(Paleon.)</fld> <def>A petrified or
fossil shrub, plant, or part of a plant.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dendrologist</ent><br/
<hw>Den*drol"o*gist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One versed in
the natural history of trees.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dendrologous</ent><br/
<hw>Den*drol"o*gous</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Relating to
dendrology.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>dendrology</ent><br/
<hw>den*drol"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>de`ndron</grk> tree + <ets>-logy</ets>: cf. F.
<ets>dendrologie</ets>.]</ety> <sn>1.</sn> <def>the branch of botany
studying trees and shrubs; the natural history of trees.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>A discourse or treatise on trees.</def><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>den`dro*log"ic*al</wf>, <pos>a.</pos> --
<wf>den`dro*log"ic</wf>, <pos>a.</pos> -- <wf>den*drol"o*gist</wf>,
<pos>a.</pos></wordforms><br/
[<source>PJC</source>]</p>

<p><ent>Dendromecon</ent><br/
<hw>Dendromecon</hw> <pos>prop. n.</pos> <def>a genus having only one
species, the bush poppy.</def><br/
<syn><b>Syn. --</b> genus <gen>Dendromecon</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dendrometer</ent><br/
<hw>Den*drom"e*ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>de`ndron</grk> tree + <ets>-meter</ets>: cf. F.
<ets>dendrom<egrave/tre</ets>.]</ety> <def>An instrument to measure the
height and diameter of trees.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Denegate</ent><br/
<hw>Den"e*gate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>denegatus</ets>, p. p. of <ets>denegare</ets>. See
<er>Deny</er>.]</ety> <def>To deny.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Denegation</ent><br/
<hw>Den`e*ga"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>d<eacute/n<eacute/gation</ets>.]</ety> <def>Denial.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dengue</ent><br/
<hw>Den"gue</hw> <pr>(d<ecr/<nsm/"g<asl/)</pr>, <pos>n.</pos> <ety>[See
Note, below.]</ety> <fld>(Med.)</fld> <def>A specific epidemic disease
attended with high fever, cutaneous eruption, and severe pains in the
head and limbs, resembling those of rheumatism; -- called also
<altname>breakbone fever</altname>. It occurs in India, Egypt, the West
Indies, etc., is of short duration, and rarely fatal.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ This disease, when it first appeared in the British West
India Islands, was called the <xex>dandy</xex> fever, from the stiffness
and constraint which it grave to the limbs and body. The Spaniards of
the neighboring islands mistook the term for their word
<xex>dengue</xex>, denoting prudery, which might also well express
stiffness, and hence the term <ex>dengue</ex> became, as last, the name
of the disease. <rj><au>Tully.</au></rj></note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deniable</ent><br/
<hw>De*ni"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Deny</er>.]</ety> <def>Capable of being, or liable to be,
denied.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Denial</ent><br/
<hw>De*ni"al</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Deny</er>.]</ety> <sn>1.</sn> <def>The act of gainsaying, refusing,
or disowning; negation; -- the contrary of
<ant>affirmation</ant>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>You ought to converse with so much sincerity that your bare
affirmation or <qex>denial</qex> may be sufficient.</q> <rj><qau>Bp.
Stillingfleet.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A refusal to admit the truth of a statement, charge,
imputation, etc.; assertion of the untruth of a thing stated or
maintained; a contradiction.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A refusal to grant; rejection of a
request.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The commissioners, . . . to obtain from the king's subjects as
much as they would willingly give, . . . had not to complain of many
peremptory <qex>denials</qex>.</q> <rj><qau>Hallam.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A refusal to acknowledge; disclaimer of connection
with; disavowal; -- the contrary of <xex>confession</xex>; <as>as, the
<ex>denial</ex> of a fault charged on one; a <ex>denial</ex> of
God.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Denial of one's self</b></col>, <cd>a declining of some
gratification; restraint of one's appetites or propensities;
self-denial.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deniance</ent><br/
<hw>De*ni"ance</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Denial.</def>
<mark>[Obs.]</mark> <rj><au>E. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Denier</ent><br/
<hw>De*ni"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who denies;
<as>as, a <ex>denier</ex> of a fact, or of the faith, or of
Christ</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Denier</ent><br/
\'d8<hw>De*nier"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>denier</ets>, fr. L. <ets>denarius</ets> a Roman silver coin orig.
equiv. to ten asses, later, a copper, fr. <ets>deni</ets> ten by ten,
fr. the root of <ets>decem</ets> ten; akin to E. <ets>ten</ets>. See
<er>Ten</er>, and cf. <er>Denary</er>, <er>Dinar</er>.]</ety> <def>A
small copper coin of insignificant value.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>My dukedom to a beggarly <qex>denier</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Denigrate</ent><br/
<hw>Den"i*grate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>denigrare</ets>; <ets>de-</ets> + <ets>nigrare</ets> to blacken,
<ets>niger</ets> black.]</ety> <sn>1.</sn> <def>To blacken thoroughly;
to make very black.</def> <rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Fig.: To blacken or sully; to defame.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>denigrate</qex> the memory of
<person>Voltaire</person>.</q> <rj><qau>Morley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>denigrating</ent><br/
<hw>denigrating</hw> <pos>adj.</pos> <def>harmful and often untrue;
tending to discredit or malign; -- used of statements.</def><br/
<syn><b>Syn. --</b> calumniatory, calumnious, defamatory, denigrative,
libellous, libelous, slanderous.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Denigration</ent><br/
<hw>Den`i*gra"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>denigratio</ets>.]</ety> <sn>1.</sn> <def>The act of making
black.</def> <rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Fig.: A blackening; defamation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The vigorous <qex>denigration</qex> of science.</q>
<rj><qau>Morley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Denigrator</ent><br/
<hw>Den"i*gra`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, blackens.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>denigratory</ent><br/
<hw>denigratory</hw> <pr>(?)</pr>, <pos>a.</pos> <def>same as
<er>denigrating</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Denim</ent><br/
<hw>Den"im</hw> <pr>(d<ecr/n"<icr/m)</pr>, <pos>n.</pos> <ety>[Of
uncertain origin.]</ety> <def>A coarse cotton drilling used for
overalls, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Denitration</ent><br/
<hw>Den`i*tra"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>de-</ets> + <ets>nitrate</ets>.]</ety> <def>A disengaging, or
removal, of nitric acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Denitrification</ent><br/
<hw>De*ni`tri*fi*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act
or process of freeing from nitrogen; also, the condition resulting from
the removal of nitrogen.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Denitrify</ent><br/
<hw>De*ni"tri*fy</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>de-</ets> + <ets>nitr</ets>ogen + <ets>-fy</ets>.]</ety> <def>To
deprive of, or free from, nitrogen.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Denization</ent><br/
<hw>Den`i*za"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
making one a denizen or adopted citizen; naturalization.</def>
<rj><au>Hallam.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Denize</ent><br/
<hw>De*nize"</hw> <pr>(d<esl/*n<imac/z")</pr>, <pos>v. t.</pos> <def>To
make a denizen; to confer the rights of citizenship upon; to
naturalize.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>There was a private act made for <qex>denizing</qex> the children
of Richard Hills.</q> <rj><qau>Strype.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Denizen</ent><br/
<hw>Den"i*zen</hw> <pr>(d<ecr/n"<icr/*z'n)</pr>, <pos>n.</pos> <ety>[OF.
<ets>denzein</ets>, <ets>deinzein</ets>, prop., one living (a city or
country); opposed to <ets>forain</ets> foreign, and fr. <ets>denz</ets>
within, F. <ets>dans</ets>, fr. L. <ets>de intus</ets>, prop., from
within, <ets>intus</ets> being from <ets>in</ets> in. See <er>In</er>,
and cf. <er>Foreign</er>.]</ety> <sn>1.</sn> <def>A dweller; an
inhabitant.</def> <ldquo/<xex>Denizens</xex> of air.<rdquo/
<rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Denizens</qex> of their own free, independent state.</q>
<rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who is admitted by favor to all or a part of the
rights of citizenship, where he did not possess them by birth; an
adopted or naturalized citizen.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>One admitted to residence in a foreign
country.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Ye gods,<br/
Natives, or <qex>denizens</qex>, of blest abodes.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Denizen</ent><br/
<hw>Den"i*zen</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To constitute
(one) a denizen; to admit to residence, with certain rights and
privileges.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>As soon as <qex>denizened</qex>, they domineer.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To provide with denizens; to populate with adopted
or naturalized occupants.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There [islets] were at once <qex>denizened</qex> by various
weeds.</q> <rj><qau>J. D. Hooker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Denizenation</ent><br/
<hw>Den`i*zen*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Denization;
denizening.</def> <rj><au>Abbott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Denizenize</ent><br/
<hw>Den"i*zen*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To constitute
(one) a denizen; to denizen.</def> <rj><au>Abbott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Denizenship</ent><br/
<hw>Den"i*zen*ship</hw>, <pos>n.</pos> <def>State of being a
denizen.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Denmark satin</ent><br/
<hw>Den"mark sat"in</hw> <pr>(?)</pr>. <def>See under
<er>Satin</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dennet</ent><br/
<hw>Den"net</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A light, open,
two-wheeled carriage for one horse; a kind of gig.</def> (<ldquo/The
term and vehicle common about 1825.<rdquo/ <au>Latham.</au>)<br/
[<source>1913 Webster</source>]</p>

<p><ent>Denominable</ent><br/
<hw>De*nom"i*na*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of
being denominated or named.</def> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Denominate</ent><br/
<hw>De*nom"i*nate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Denominated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Denominating</conjf> <pr>(?)</pr>.]</vmorph> <ety>[L.
<ets>denominatus</ets>, p. p. of <ets>denominare</ets> to name;
<ets>de-</ets> + <ets>nominare</ets> to call by name. See
<er>Nominate</er>.]</ety> <def>To give a name to; to characterize by an
epithet; to entitle; to name; to designate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Passions commonly <qex>denominating</qex> selfish.</q>
<rj><qau>Hume.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Denominate</ent><br/
<hw>De*nom"i*nate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>denominatus</ets>, p. p.]</ety> <def>Having a specific name or
denomination; specified in the concrete as opposed to abstract; thus, 7
<xex>feet</xex> is a <xex>denominate</xex> quantity, while 7 is mere
abstract quantity or number. See <cref>Compound number</cref>, under
<er>Compound</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Denomination</ent><br/
<hw>De*nom`i*na"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>denominatio</ets> metonymy: cf. F. <ets>d<eacute/nomination</ets> a
naming.]</ety> <sn>1.</sn> <def>The act of naming or
designating.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That by which anything is denominated or styled; an
epithet; a name, designation, or title; especially, a general name
indicating a class of like individuals; a category; <as>as, the
<ex>denomination</ex> of units, or of thousands, or of fourths, or of
shillings, or of tons</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Those [qualities] which are classed under the
<qex>denomination</qex> of sublime.</q> <rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A class, or society of individuals, called by the
same name; a sect; <as>as, a <ex>denomination</ex> of
Christians</as>.</def></p>

<p><syn><b>Syn.</b> -- Name; appellation; title. See
<er>Name</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Denominational</ent><br/
<hw>De*nom`i*na"tion*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining
to a denomination, especially to a sect or society.</def>
<ldquo/<xex>Denominational</xex> differences.<rdquo/
<rj><au>Buckle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Denominationalism</ent><br/
<hw>De*nom`i*na"tion*al*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A
denominational or class spirit or policy; devotion to the interests of a
sect or denomination.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Denominationalist</ent><br/
<hw>De*nom`i*na"tion*al*ist</hw>, <pos>n.</pos> <def>One imbued with a
denominational spirit.</def> <rj><au>The Century.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Denominationally</ent><br/
<hw>De*nom`i*na"tion*al*ly</hw>, <pos>adv.</pos> <def>In a
denominational manner; by denomination or sect.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Denominative</ent><br/
<hw>De*nom`i*na"tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>d<eacute/nominatif</ets>.]</ety> <sn>1.</sn> <def>Conferring a
denomination or name.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Logic)</fld> <def>Connotative; <as>as, a
<ex>denominative</ex> name</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Possessing, or capable of possessing, a distinct
denomination or designation; denominable.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The least <qex>denominative</qex> part of time is a minute.</q>
<rj><qau>Cocker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Gram.)</fld> <def>Derived from a substantive or an
adjective; <as>as, a <ex>denominative</ex> verb</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Denominative</ent><br/
<hw>De*nom`i*na"tive</hw>, <pos>n.</pos> <def>A denominative name or
term; denominative verb.</def> <rj><au>Jer. Taylor.
Harkness.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Denominatively</ent><br/
<hw>De*nom`i*na"tive*ly</hw>, <pos>adv.</pos> <def>By
denomination.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Denominator</ent><br/
<hw>De*nom"i*na`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>d<eacute/nominateur</ets>.]</ety> <sn>1.</sn> <def>One who, or that
which, gives a name; origin or source of a name.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This opinion that Aram . . . was the father and
<qex>denomination</qex> of the Syrians in general.</q> <rj><qau>Sir W.
Raleigh.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Arith.)</fld> <def>That number placed below the
line in common fractions which shows into how many parts the integer or
unit is divided.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Thus, in <frac35/, 5 is the <xex>denominator</xex>,
showing that the integer is divided into five parts; and the numerator,
3, shows how many parts are taken.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Alg.)</fld> <def>That part of any expression under
a fractional form which is situated below the horizontal line signifying
division.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In this sense, the <xex>denominator</xex> is not
necessarily a number, but may be any expression, either positive or
negative, real or imaginary.</note> <rj><au>Davies & Peck (Math.
Dict.)</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>common denominator</b></col> <cd>a number which can
divide either of two or more other numbers without leaving a remainder
in any of the divisions; <as>as, 2 and 4 are <ex>common
denominators</ex> of 12 and 28.</as>.</cd> -- <col><b>greatest common
denominator</b></col> <cd>the largest <cref>common denominator</cref> of
two or more numbers; <as>as, 9 is the <ex>greatest common
denominator</ex> of 18 and 27.</as>.</cd></cs><br/
[<source>PJC</source>]</p>

<p><ent>Denotable</ent><br/
<hw>De*not"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From
<er>Denote</er>.]</ety> <def>Capable of being denoted or marked.</def>
<rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>denotatum</ent><br/
<hw>denotatum</hw> <pos>n.</pos> <def>the actual object referred to by a
linguistic expression.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Denotate</ent><br/
<hw>De*no"tate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>denotatus</ets>, p. p. of <ets>denotare</ets>.]</ety> <def>To mark
off; to denote.</def> <mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>These terms <qex>denotate</qex> a longer time.</q>
<rj><qau>Burton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>What things should be <qex>denotated</qex> and signified by the
color.</q> <rj><qau>Urquhart.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Denotation</ent><br/
<hw>De`no*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>denotatio</ets>: cf. F. <ets>d<eacute/notation</ets>.]</ety>
<def>The marking off or separation of anything.</def>
<rj><au>Hammond.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Denotative</ent><br/
<hw>De*not"a*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having power to
denote; designating or marking off.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Proper names are pre<eum/minently <qex>denotative</qex>; telling
us that such as object has such a term to denote it, but telling us
nothing as to any single attribute.</q> <rj><qau>Latham.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Denote</ent><br/
<hw>De*note"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Denoted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Denoting</conjf>.]</vmorph> <ety>[L. <ets>denotare</ets>;
<ets>de-</ets> + <ets>notare</ets> to mark, <ets>nota</ets> mark, sign,
note: cf. F. <ets>d<eacute/noter</ets>. See <er>Note</er>.]</ety>
<sn>1.</sn> <def>To mark out plainly; to signify by a visible sign; to
serve as the sign or name of; to indicate; to point out; <as>as, the
hands of the clock <ex>denote</ex> the hour</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The better to <qex>denote</qex> her to the doctor.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To be the sign of; to betoken; to signify; to
mean.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A general expression to <qex>denote</qex> wickedness of every
sort.</q> <rj><qau>Gilpin.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Denotement</ent><br/
<hw>De*note"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Sign;
indication.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ A word found in some editions of Shakespeare.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Denotive</ent><br/
<hw>De*not"ive</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Serving to
denote.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Denouement</ent><br/
\'d8<hw>D<eacute/`noue`ment"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>d<eacute/nouement</ets>, fr. <ets>d<eacute/nouer</ets> to untie;
pref. <ets>d<eacute/-</ets> (L. <ets>dis-</ets>) + <ets>nouer</ets> to
tie, fr. L. <ets>nodus</ets> knot, perh. for <ets>gnodus</ets> and akin
to E. <ets>knot</ets>.]</ety> <sn>1.</sn> <def>The unraveling or
discovery of a plot; the catastrophe, especially of a drama or a
romance.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The solution of a mystery; issue; outcome.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 391 --></p>

<p><ent>Denounce</ent><br/
<hw>De*nounce"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Denounced</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Denouncing</conjf>.]</vmorph> <ety>[F.
<ets>d<eacute/noncer</ets>, OF. <ets>denoncier</ets>, fr. L.
<ets>denuntiare</ets>, <ets>denunciare</ets>; <ets>de-</ets> +
<ets>nunciare</ets>, <ets>nuntiare</ets>, to announce, report,
<ets>nuntius</ets> a messenger, message. See <er>Nuncio</er>, and cf.
<er>Denunciate</er>.]</ety> <sn>1.</sn> <def>To make known in a solemn
or official manner; to declare; to proclaim (especially an evil).</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Denouncing</qex> wrath to come.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I <qex>denounce</qex> unto you this day, that ye shall surely
perish.</q> <rj><qau>Deut. xxx. 18.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To proclaim in a threatening manner; to threaten by
some outward sign or expression.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His look <qex>denounced</qex> desperate.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To point out as deserving of reprehension or
punishment, etc.; to accuse in a threatening manner; to invoke censure
upon; to stigmatize.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Denounced</qex> for a heretic.</q> <rj><qau>Sir T.
More.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>denounce</qex> the immoralities of Julius C<ae/sar.</q>
<rj><qau>Brougham.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Denouncement</ent><br/
<hw>De*nounce"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. OF.
<ets>denoncement</ets>.]</ety> <def>Solemn, official, or menacing
announcement; denunciation.</def> <mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>False is the reply of Cain, upon the <qex>denouncement</qex> of
his curse.</q> <rj><qau>Sir T. Browne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Denouncer</ent><br/
<hw>De*noun"cer</hw> <pr>(?)</pr> <pos>n.</pos> <def>One who denounces,
or declares, as a menace.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Here comes the sad <qex>denouncer</qex> of my fate.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dense</ent><br/
<hw>Dense</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>densus</ets>;
akin to Gr. <grk>dasy`</grk> thick with hair or leaves: cf. F.
<ets>dense</ets>.]</ety> <sn>1.</sn> <def>Having the constituent parts
massed or crowded together; close; compact; thick; containing much
matter in a small space; heavy; opaque; <as>as, a <ex>dense</ex> crowd;
a <ex>dense</ex> forest; a <ex>dense</ex> fog.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>All sorts of bodies, firm and fluid, <qex>dense</qex> and
rare.</q> <rj><qau>Ray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To replace the cloudy barrier <qex>dense</qex>.</q>
<rj><qau>Cowper.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Stupid; gross; crass; <as>as, <ex>dense</ex>
ignorance</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Densely</ent><br/
<hw>Dense"ly</hw>, <pos>adv.</pos> <def>In a dense, compact
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Denseness</ent><br/
<hw>Dense"ness</hw>, <pos>n.</pos> <def>The quality of being dense;
density.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>densification</ent><br/
<hw>densification</hw> <pos>n.</pos> <def>an increase in the density of
something.</def><br/
<syn><b>Syn. --</b> compaction, compression, concretion.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Densimeter</ent><br/
<hw>Den*sim"e*ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>densus</ets> dense + <ets>-meter</ets>: cf. F.
<ets>densim<egrave/tre</ets>.]</ety> <def>An instrument for ascertaining
the specific gravity or density of a substance.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>densitometer</ent><br/
<hw>densitometer</hw> <pos>n.</pos> <sn>1.</sn> <def>an instrument for
determining optical or photographic density. A variety capable of
measuring optical density of a sample at a number of different
wavelengths, is called a <contr>spectrophotometer</contr>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>same as <er>densimeter</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>densitometry</ent><br/
<hw>densitometry</hw> <pos>n.</pos> <def>measuring the optical density
of a substance by shining light through it and measuring the intensity
of the transmitted light.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Density</ent><br/
<hw>Den"si*ty</hw> <pr>(d<ecr/n"s<icr/*t<ycr/)</pr>, <pos>n.</pos>
<ety>[L. <ets>densitas</ets>; cf. F. <ets>densit<eacute/</ets>.]</ety>
<sn>1.</sn> <def>The quality of being dense, close, or thick;
compactness; -- opposed to <contr>rarity</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Physics)</fld> <def>The ratio of mass, or quantity
of matter, to bulk or volume, esp. as compared with the mass and volume
of a portion of some substance used as a standard.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ For gases the standard substance is hydrogen, at a
temperature of 0<deg/ Centigrade and a pressure of 760 millimeters. For
liquids and solids the standard is water at a temperature of 4<deg/
Centigrade. The density of solids and liquids is usually called
<xex>specific gravity</xex>, and the same is true of gases when referred
to air as a standard.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Photog.)</fld> <def>Depth of shade.</def>
<rj><au>Abney.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dent</ent><br/
<hw>Dent</hw> <pr>(d<ecr/nt)</pr>, <pos>n.</pos> <ety>[A variant of
<er>Dint</er>.]</ety> <sn>1.</sn> <def>A stroke; a blow.</def>
<mark>[Obs.]</mark> <ldquo/That <xex>dent</xex> of thunder.<rdquo/
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A slight depression, or small notch or hollow, made
by a blow or by pressure; an indentation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A blow that would have made a <qex>dent</qex> in a pound of
butter.</q> <rj><qau>De Quincey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dent</ent><br/
<hw>Dent</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Dented</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Denting</conjf>.]</vmorph> <def>To make a dent upon; to
indent.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The houses <qex>dented</qex> with bullets.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dent</ent><br/
<hw>Dent</hw>, <pos>n.</pos> <ety>[F., fr. L. <ets>dens</ets>,
<ets>dentis</ets>, tooth. See <er>Tooth</er>.]</ety> <fld>(Mach.)</fld>
<def>A tooth, as of a card, a gear wheel, etc.</def>
<rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>dental</ent><br/
<hw>den"tal</hw> <pr>(d<ecr/n"t<ait/l)</pr>, <pos>a.</pos> <ety>[L.
<ets>dens</ets>, <ets>dentis</ets>, tooth: cf. F. <ets>dental</ets>. See
<er>Tooth</er>.]</ety> <sn>1.</sn> <def>Of or pertaining to the teeth or
to dentistry; <as>as, <ex>dental</ex> surgery</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Phon.)</fld> <def>Formed by the aid of the teeth;
-- said of certain articulations and the letters representing them;
<as>as, <it>d</it> and <it>t</it> are <ex>dental</ex>
letters</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dental formula</b></col> <fld>(Zool.)</fld>, <cd>a brief
notation used by zoologists to denote the number and kind of teeth of a
mammal.</cd> -- <col><b>Dental surgeon</b></col>, <cd>a
dentist.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dental</ent><br/
<hw>Den"tal</hw>, <pos>n.</pos> <ety>[Cf. F. <ets>dentale</ets>. See
<er>Dental</er>, <pos>a.</pos>]</ety> <sn>1.</sn> <def>An articulation
or letter formed by the aid of the teeth.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>A marine mollusk of the genus
<gen>Dentalium</gen>, with a curved conical shell resembling a tooth.
See <er>Dentalium</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dentalism</ent><br/
<hw>Den"tal*ism</hw> <pr>(d<ecr/n"t<ait/l*<icr/z'm)</pr>, <pos>n.</pos>
<def>The quality of being formed by the aid of the teeth.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dentalium</ent><br/
\'d8<hw>Den*ta"li*um</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. L.
<ets>dens</ets>, <ets>dentis</ets>, tooth.]</ety> <fld>(Zool.)</fld>
<def>A genus of marine mollusks belonging to the
<class>Scaphopoda</class>, having a tubular conical shell.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dentaria</ent><br/
<hw>Dentaria</hw> <pos>n.</pos> <def>a genus usually included in genus
<gen>Cardamine</gen>; in some classifications considered a separate
genus.</def><br/
<syn><b>Syn. --</b> genus <gen>Dentaria</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dentary</ent><br/
<hw>Den"ta*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Anat.)</fld>
<def>Pertaining to, or bearing, teeth.</def> -- <def2><pos>n.</pos>
<def>The distal bone of the lower jaw in many animals, which may or may
not bear teeth.</def></def2></p>

<p><ent>Dentated</ent><br/
<ent>Dentate</ent><br/
<mhw>{ <hw>Den"tate</hw> <pr>(d<ecr/n"t<asl/t)</pr>, <hw>Den"ta*ted</hw>
<pr>(d<ecr/n"t<asl/*t<ecr/d)</pr>, }</mhw> <pos>a.</pos> <ety>[L.
<ets>dentatus</ets>, fr. <ets>dens</ets>, <ets>dentis</ets>,
tooth.]</ety> <sn>1.</sn> <fld>(Bot.)</fld> <def>Toothed; especially,
with the teeth projecting straight out, not pointed either forward or
backward; <as>as, a <ex>dentate</ex> leaf</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>Having teeth or toothlike points.
See <xex>Illust.</xex> of <er>Antenn<ae/</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dentate-ciliate</ent><br/
<hw>Den"tate-cil"i*ate</hw> <pr>(?)</pr>, <pos>a.</pos>
<fld>(Bot.)</fld> <def>Having the margin dentate and also ciliate or
fringed with hairs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dentately</ent><br/
<hw>Den"tate*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a dentate or
toothed manner; <as>as, <ex>dentately</ex> ciliated, etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dentate-sinuate</ent><br/
<hw>Den"tate-sin"u*ate</hw> <pr>(?)</pr>, <pos>a.</pos>
<fld>(Bot.)</fld> <def>Having a form intermediate between dentate and
sinuate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dentation</ent><br/
<hw>Den*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Formation of
teeth; toothed form.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>How did it [a bill] get its barb, its <qex>dentation</qex>?</q>
<rj><qau>Paley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dented</ent><br/
<hw>Dent"ed</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From <er>Dent</er>,
<pos>v. t.</pos>]</ety> <def>Indented; impressed with little
hollows.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dentel</ent><br/
<hw>Dent"el</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Dentil</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dentelle</ent><br/
\'d8<hw>Den*telle"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<fld>(Bookbinding)</fld> <def>An ornamental tooling like lace.</def>
<rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dentelli</ent><br/
\'d8<hw>Den*tel"li</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[It., sing.
<ets>dentello</ets>, prop., little tooth, dim. of <ets>dente</ets>
tooth, L. <ets>dens</ets>, <ets>dentis</ets>. Cf.
<er>Dentil</er>.]</ety> <def>Modillions.</def>
<rj><au>Spectator.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dentex</ent><br/
\'d8<hw>Den"tex</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., cf. L.
<ets>dentix</ets> a sort of sea fish.]</ety> <fld>(Zool.)</fld> <def>An
edible European marine fish (<spn>Sparus dentex</spn>, or <spn>Dentex
vulgaris</spn>) of the family <fam>Percid<ae/</fam>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Denticete</ent><br/
\'d8<hw>Den`ti*ce"te</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL., fr.
L. <ets>dens</ets>, <ets>dentis</ets>, tooth + <ets>cetus</ets>, pl.
<ets>cete</ets>, whale, Gr. <grk>kh^tos</grk>.]</ety> <fld>(Zool.)</fld>
<def>The division of Cetacea in which the teeth are developed, including
the sperm whale, dolphins, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Denticle</ent><br/
<hw>Den"ti*cle</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>denticulus</ets> a little tooth, dim. of <ets>dens</ets>,
<ets>dentis</ets>, tooth. See <er>Dental</er>, and cf.
<er>Dentelli</er>.]</ety> <def>A small tooth or projecting
point.</def></p>

<p><ent>Denticulated</ent><br/
<ent>Denticulate</ent><br/
<mhw>{ <hw>Den*tic"u*late</hw> <pr>(?)</pr>, <hw>Den*tic"u*la`ted</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[L. <ets>denticulatus</ets>,
fr. <ets>denticulus</ets>. See <er>Denticle</er>.]</ety> <def>Furnished
with denticles; notched into little toothlike projections; <as>as, a
<ex>denticulate</ex> leaf of calyx</as>.</def> --
<wordforms><wf>Den*tic"u*late*ly</wf> <pr>(#)</pr>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Denticulation</ent><br/
<hw>Den*tic`u*la"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>The state of being set with small notches or teeth.</def>
<rj><au>Grew.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot. & Zool.)</fld> <def>A diminutive tooth; a
denticle.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dentiferous</ent><br/
<hw>Den*tif"er*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>dens</ets>, <ets>dentis</ets>, tooth + <ets>-ferous</ets>.]</ety>
<def>Bearing teeth; dentigerous.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dentiform</ent><br/
<hw>Den"ti*form</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>dens</ets>, <ets>dentis</ets>, tooth + <ets>-form</ets>: cf. F.
<ets>dentiforme</ets>.]</ety> <def>Having the form of a tooth or of
teeth; tooth-shaped.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dentifrice</ent><br/
<hw>Den"ti*frice</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>dentifricium</ets>; <ets>dens</ets>, <ets>dentis</ets>, tooth +
<ets>fricare</ets> to rub: cf. F. <ets>dentifrice</ets>. See
<er>Tooth</er>, and <er>Friction</er>.]</ety> <def>A powder or other
substance to be used in cleaning the teeth; tooth powder.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dentigerous</ent><br/
<hw>Den*tig"er*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>dens</ets>, <ets>dentis</ets>, tooth + <ets>-gerous</ets>.]</ety>
<def>Bearing teeth or toothlike structures.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dentil</ent><br/
<hw>Den"til</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL.
<ets>dentillus</ets>, for L. <ets>denticulus</ets>. Cf.
<er>Dentelli</er>, <er>Denticle</er>, <er>Dentile</er>.]</ety>
<fld>(Arch.)</fld> <def>A small square block or projection in cornices,
a number of which are ranged in an ornamental band; -- used particularly
in the Ionic, Corinthian, and Composite orders.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dentilabial</ent><br/
<hw>Den`ti*la"bi*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Formed by the
teeth and the lips, or representing a sound so formed.</def> --
<def2><pos>n.</pos> <def>A dentilabial sound or letter.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dentilated</ent><br/
<hw>Den"ti*la`ted</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Toothed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dentilation</ent><br/
<hw>Den`ti*la"tion</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Dentition.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dentilave</ent><br/
<hw>Den"ti*lave</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>dens</ets>, <ets>dentis</ets>, tooth + <ets>lavare</ets> to
wash.]</ety> <def>A wash for cleaning the teeth.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dentile</ent><br/
<hw>Den"tile</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL.
<ets>dentillus</ets>, for L. <ets>denticulus</ets>. See
<er>Dentil</er>.]</ety> <fld>(Zool.)</fld> <def>A small tooth, like that
of a saw.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dentilingual</ent><br/
<hw>Den`ti*lin"gual</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>dens</ets> tooth + E. <ets>lingual</ets>.]</ety> <def>Produced by
applying the tongue to the teeth or to the gums; or representing a sound
so formed.</def> -- <def2><pos>n.</pos> <def>A dentilingual sound or
letter.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><q>The letters of this fourth, <qex>dentilingual</qex> or
linguidental, class, viz., d, t, s, z, l, r.</q> <rj><qau>Am.
Cyc.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dentiloquist</ent><br/
<hw>Den*til"o*quist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who speaks
through the teeth, that is, with the teeth closed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dentiloquy</ent><br/
<hw>Den*til"o*quy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>dens</ets>, <ets>dentis</ets>, tooth + <ets>loqui</ets> to
speak.]</ety> <def>The habit or practice of speaking through the teeth,
or with them closed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dentinal</ent><br/
<hw>Den"ti*nal</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Anat.)</fld>
<def>Of or pertaining to dentine.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dentine</ent><br/
<hw>Den"tine</hw> <pr>(d<ecr/n"t<icr/n)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>dentine</ets>.]</ety> <fld>(Anat.)</fld> <def>The dense calcified
substance of which teeth are largely composed. It contains less animal
matter than bone, and in the teeth of man is situated beneath the
enamel.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dentiphone</ent><br/
<hw>Den"ti*phone</hw> <pr>(d<ecr/n"t<icr/*f<omac/n)</pr>, <pos>n.</pos>
<ety>[L. <ets>dens</ets>, <ets>dentis</ets>, tooth + Gr.
<grk>fwnh`</grk> sound.]</ety> <def>An instrument which, placed against
the teeth, conveys sound to the auditory nerve; an audiphone.</def>
<rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dentiroster</ent><br/
\'d8<hw>Den`ti*ros"ter</hw> <pr>(?)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Dentirostres</plw> <pr>(#)</pr>.</plu> <ety>[NL.,
fr. L. <ets>dens</ets>, <ets>dentis</ets>, tooth + <ets>rostrum</ets>
bill, beak: cf. F. <ets>dentirostre</ets>.]</ety> <fld>(Zool.)</fld>
<def>A dentirostral bird.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dentirostral</ent><br/
<hw>Den`ti*ros"tral</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Having a toothed bill; -- applied to a group of passerine birds,
having the bill notched, and feeding chiefly on insects, as the shrikes
and vireos. See <xex>Illust.</xex> (<xex>N</xex>) under
<er>Beak</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dentirostrate</ent><br/
<hw>Den`ti*ros"trate</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Dentirostral.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dentiscalp</ent><br/
<hw>Den"ti*scalp</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>dens</ets> tooth + <ets>scalpere</ets> to scrape.]</ety> <def>An
instrument for scraping the teeth.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dentist</ent><br/
<hw>Den"tist</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From L.
<ets>dens</ets>, <ets>dentis</ets>, tooth: cf. F. <ets>dentiste</ets>.
See <er>Tooth</er>.]</ety> <def>One whose business it is to clean,
extract, or repair natural teeth, and to make and insert artificial
ones; a dental surgeon.</def></p>

<p><ent>Dentistical</ent><br/
<ent>Dentistic</ent><br/
<mhw>{ <hw>Den*tis"tic</hw> <pr>(?)</pr>, <hw>Den*tis"ti*cal</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <def>Pertaining to dentistry or to
dentists.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dentistry</ent><br/
<hw>Den"tist*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The art or
profession of a dentist; dental surgery.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dentition</ent><br/
<hw>Den*ti"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>dentitio</ets>, fr. <ets>dentire</ets> to cut teeth, fr.
<ets>dens</ets>, <ets>dentis</ets>, tooth. See <er>Dentist</er>.]</ety>
<sn>1.</sn> <def>The development and cutting of teeth;
teething.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>The system of teeth peculiar to
an animal.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dentize</ent><br/
<hw>Den"tize</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Dentized</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Dentizing</conjf>.]</vmorph> <ety>[L. <ets>dens</ets>,
<ets>dentis</ets>, tooth.]</ety> <def>To breed or cut new teeth.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The old countess . . . did <qex>dentize</qex> twice or thrice.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dentoid</ent><br/
<hw>Den"toid</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>dens</ets>,
<ets>dentis</ets>, tooth + <ets>-oid</ets>.]</ety> <def>Shaped like a
tooth; tooth-shaped.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dentolingual</ent><br/
<hw>Den`to*lin"gual</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Dentilingual.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Denture</ent><br/
<hw>Den"ture</hw> <pr>(?; 135)</pr>, <pos>n.</pos> <ety>[L.
<ets>dens</ets>, <ets>dentis</ets>, tooth: cf. F. <ets>denture</ets>,
OF. <ets>denteure</ets>.]</ety> <fld>(Dentistry)</fld> <def>An
artificial tooth, block, or set of teeth.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Denudate</ent><br/
<hw>De*nud"ate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>denudatus</ets>, p. p. of <ets>denudare</ets>. See
<er>Denude</er>.]</ety> <def>To denude.</def> <mark>[Obs. or
R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Denudation</ent><br/
<hw>Den`u*da"tion</hw> <pr>(?; 277)</pr>, <pos>n.</pos> <ety>[L.
<ets>denudatio</ets>: cf. F. <ets>d<eacute/nudation</ets>.]</ety>
<sn>1.</sn> <def>The act of stripping off covering, or removing the
surface; a making bare.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Geol.)</fld> <def>The laying bare of rocks by the
washing away of the overlying earth, etc.; or the excavation and removal
of them by the action of running water.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Denude</ent><br/
<hw>De*nude"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>denudare</ets>; <ets>de-</ets> + <ets>nudare</ets> to make naked or
bare, <ets>nudus</ets> naked. See <er>Nude</er>.]</ety> <def>To divest
of all covering; to make bare or naked; to strip; to divest; <as>as, to
<ex>denude</ex> one of clothing, or lands; the hurricane
<ex>denuded</ex> the trees</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>denumerable</ent><br/
<hw>denumerable</hw> <pos>adj.</pos> <def>that can be counted.</def><br/
<syn><b>Syn. --</b> countable, enumerable, numerable.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Denunciate</ent><br/
<hw>De*nun"ci*ate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>denuntiatus</ets>, <ets>denunciatus</ets>, p. p. of
<ets>denuntiare</ets>, <ets>-ciare</ets>. See <er>Denounce</er>.]</ety>
<def>To denounce; to condemn publicly or solemnly.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>denunciate</qex> this new work.</q>
<rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Denunciation</ent><br/
<hw>De*nun`ci*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>denuntiatio</ets>, <ets>-ciatio</ets>.]</ety> <sn>1.</sn>
<def>Proclamation; announcement; a publishing.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Public . . . <qex>denunciation</qex> of banns before marriage.</q>
<rj><qau>Bp. Hall.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The act of denouncing; public menace or accusation;
the act of inveighing against, stigmatizing, or publicly arraigning;
arraignment.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That by which anything is denounced; threat of evil;
public menace or accusation; arraignment.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Uttering bold <qex>denunciations</qex> of ecclesiastical
error.</q> <rj><qau>Motley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Denunciative</ent><br/
<hw>De*nun"ci*a*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>denuntiativus</ets>, <ets>-ciativus</ets>, monitory.]</ety>
<def>Same as <er>Denunciatory</er>.</def> <rj><au>Farrar.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Denunciator</ent><br/
<hw>De*nun"ci*a`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>denuntiator</ets>, <ets>-ciator</ets>, a police officer.]</ety>
<def>One who denounces, publishes, or proclaims, especially intended or
coming evil; one who threatens or accuses.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Denunciatory</ent><br/
<hw>De*nun"ci*a*to*ry</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Characterized by or containing a denunciation; minatory; accusing;
threatening; <as>as, severe and <ex>denunciatory</ex>
language</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Denutrition</ent><br/
<hw>De`nu*tri"tion</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Physiol.)</fld> <def>The opposition of nutrition; the failure of
nutrition causing the breaking down of tissue.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deny</ent><br/
<hw>De*ny"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Denied</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Denying</conjf>.]</vmorph> <ety>[OE. <ets>denien</ets>,
<ets>denaien</ets>, OF. <ets>denier</ets>, <ets>deneer</ets>, F.
<ets>d<eacute/nier</ets>, fr. L. <ets>denegare</ets>; <ets>de-</ets> +
<ets>negare</ets> to say no, deny. See <er>Negation</er>.]</ety>
<sn>1.</sn> <def>To declare not to be true; to gainsay; to contradict;
-- opposed to <xex>affirm</xex>, <xex>allow</xex>, or
<xex>admit</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ We <xex>deny</xex> what another says, or we
<xex>deny</xex> the truth of an assertion, the force of it, or the
assertion itself.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To refuse (to do something or to accept something);
to reject; to decline; to renounce.</def> <mark>[Obs.]</mark> <ldquo/If
you <xex>deny</xex> to dance.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To refuse to grant; to withhold; to refuse to
gratify or yield to; <as>as, to <ex>deny</ex> a request</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Who finds not Providence all good and wise,<br/
Alike in what it gives, and what <qex>denies</qex>?</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To some men, it is more agreeable to <qex>deny</qex> a vicious
inclination, than to gratify it.</q> <rj><qau>J. Edwards.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To disclaim connection with, responsibility for, and
the like; to refuse to acknowledge; to disown; to abjure; to
disavow.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The falsehood of <qex>denying</qex> his opinion.</q>
<rj><qau>Bancroft.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou thrice <qex>denied</qex>, yet thrice beloved.</q>
<rj><qau>Keble.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To deny one's self</b></col>, <cd>to decline the
gratification of appetites or desires; to practice
self-denial.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><q>Let him <qex>deny</qex> himself, and take up his cross.</q>
<rj><qau>Matt. xvi. 24.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deny</ent><br/
<hw>De*ny"</hw>, <pos>v. i.</pos> <def>To answer in the negative; to
declare an assertion not to be true.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Then Sarah <qex>denied</qex>, saying, I laughed not; for she was
afraid.</q> <rj><qau>Gen. xviii. 15.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Denyingly</ent><br/
<hw>De*ny"ing*ly</hw>, <pos>adv.</pos> <def>In the manner of one denies
a request.</def> <rj><au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deobstruct</ent><br/
<hw>De`ob*struct"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To remove
obstructions or impediments in; to clear from anything that hinders the
passage of fluids; <as>as, to <ex>deobstruct</ex> the pores or
lacteals</as>.</def> <rj><au>Arbuthnot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deobstruent</ent><br/
<hw>De*ob"stru*ent</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Med.)</fld>
<def>Removing obstructions; having power to clear or open the natural
ducts of the fluids and secretions of the body; aperient.</def> --
<def2><pos>n.</pos> <fld>(Med.)</fld> <def>A medicine which removes
obstructions; an aperient.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deodand</ent><br/
<hw>De"o*dand`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL.
<ets>deodandum</ets>, fr. L. <ets>Deo dandum</ets> to be given to
God.]</ety> <fld>(Old Eng. Law)</fld> <def>A personal chattel which had
caused the death of a person, and for that reason was given to God, that
is, forfeited to the crown, to be applied to pious uses, and distributed
in alms by the high almoner. Thus, if a cart ran over a man and killed
him, it was forfeited as a <xex>deodand</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Deodands</xex> are unknown in American law, and in
1846 were abolished in England.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deodar</ent><br/
<hw>De`o*dar"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Native name, fr.
Skr. <ets>d<emac/vad<amac/ru</ets>, prop., timber of the gods.]</ety>
<fld>(Bot.)</fld> <def>A kind of cedar (<spn>Cedrus Deodara</spn>),
growing in India, highly valued for its size and beauty as well as for
its timber, and also grown in England as an ornamental tree.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deodate</ent><br/
<hw>De"o*date`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>Deo</ets>
to God (<ets>Deus</ets> God) + <ets>datum</ets> thing given.]</ety>
<def>A gift or offering to God.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Wherein that blessed widow's <qex>deodate</qex> was laid up.</q>
<rj><qau>Hooker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deodorant</ent><br/
<hw>De*o"dor*ant</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A
deodorizer.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deodorization</ent><br/
<hw>De*o`dor*i*za"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
depriving of odor, especially of offensive odors resulting from
impurities.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deodorize</ent><br/
<hw>De*o"dor*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To deprive of
odor, especially of such as results from impurities.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deodorizer</ent><br/
<hw>De*o"dor*i`zer</hw> <pr>(?)</pr>, <pos>n.</pos> <def>He who, or that
which, deodorizes; esp., an agent that destroys offensive
odors.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deonerate</ent><br/
<hw>De*on"er*ate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>deoneratus</ets>, p. p. of <ets>deonerare</ets>. See
<er>Onerate</er>.]</ety> <def>To unload; to disburden.</def>
<mark>[Obs.]</mark> <rj><au>Cockeram.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deontological</ent><br/
<hw>De*on`to*log"ic*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining
to deontology.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deontologist</ent><br/
<hw>De`on*tol"o*gist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One versed in
deontology.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deontology</ent><br/
<hw>De`on*tol"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ gen.
<?/, necessity, obligation (p. neut. of <?/ it is necessary) +
<ets>-logy</ets>.]</ety> <def>The science which relates to duty or moral
obligation.</def> <rj><au>J. Bentham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deoperculate</ent><br/
<hw>De`o*per"cu*late</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Bot.)</fld>
<def>Having the lid removed; -- said of the capsules of
mosses.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deoppilate</ent><br/
<hw>De*op"pi*late</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To free from
obstructions; to clear a passage through.</def> <mark>[Obs.]</mark>
<rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deoppilation</ent><br/
<hw>De*op`pi*la"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Removal of
whatever stops up the passages.</def> <mark>[Obs.]</mark> <rj><au>Sir T.
Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 392 --></p>

<p><ent>Deoppilative</ent><br/
<hw>De*op"pi*la*tive</hw> <pr>(?)</pr>, <pos>a. & n.</pos>
<fld>(Med.)</fld> <def>Deobstruent; aperient.</def> <mark>[Obs.]</mark>
<rj><au>Harvey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deordination</ent><br/
<hw>De*or`di*na"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL.
<ets>deordinatio</ets> depraved morality.]</ety> <def>Disorder;
dissoluteness.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Excess of riot and <qex>deordination</qex>.</q> <rj><qau>Jer.
Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deosculate</ent><br/
<hw>De*os"cu*late</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>deosculatus</ets>, p. p. of <ets>deosculari</ets>. See
<er>Osculate</er>.]</ety> <def>To kiss warmly.</def> <mark>[Obs.]</mark>
-- <wordforms><wf>De*os`cu*la"tion</wf> <pr>(#)</pr>, <pos>n.</pos>
<mark>[Obs.]</mark></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deoxidate</ent><br/
<hw>De*ox"i*date</hw> <pr>(?)</pr>, <pos>v. t.</pos> <fld>(Chem.)</fld>
<def>To deoxidize.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deoxidation</ent><br/
<hw>De*ox`i*da"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>The act or process of reducing from the state of an
oxide.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deoxidization</ent><br/
<hw>De*ox`i*di*za"tion</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Chem.)</fld> <def>Deoxidation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deoxidize</ent><br/
<hw>De*ox"i*dize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <fld>(Chem.)</fld>
<def>To deprive of oxygen; to reduce from the state of an
oxide.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deoxidizer</ent><br/
<hw>De*ox"i*di`zer</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>That which removes oxygen; hence, a reducing agent; <as>as, nascent
hydrogen is a <ex>deoxidizer</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deoxygenate</ent><br/
<hw>De*ox"y*gen*ate</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<fld>(Chem.)</fld> <def>To deoxidize.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deoxygenation</ent><br/
<hw>De*ox`y*gen*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Chem.)</fld> <def>The act or operation of depriving of
oxygen.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deoxygenize</ent><br/
<hw>De*ox"y*gen*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<fld>(Chem.)</fld> <def>To deoxidize.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>deoxyribonucleic acid</ent><br/
<hw>deoxyribonucleic acid</hw> <pos>n.</pos> <def>a nucleic acid,
usually of very high molecular weight, consisting of a linear sequence
of monomer units of deoxyribonucleotides, occurring in most organisms in
pairs of strands, wound together in the form of a double helix; it is
the main component of chromosomes and contains the genetic information
which is the basis of heredity, transmitted from parent to progeny, and
found in all living organisms except for certain viruses which have RNA
as their basic genetic material; -- usually referred to by the acronym
<altname>DNA</altname>.</def><br/
<syn><b>Syn. --</b> DNA, desoxyribonucleic acid.</syn><br/
[<source>PJC</source>]</p>

<p><note><hand/ The monomer units making up the DNA each contain one of
four heterocyclic bases: thymine, adenine, cytosine, or guanine. The
genetic information is contained in the precise sequence of these
monomer units, which ultimately specify the sequence of proteins to be
made by the organism's biosynthetic processes, mediated through the
synthesis of RNA having a base sequence corresponding to that of the
DNA. The DNA sequence also specifies the sequence of the various RNA
molecules the RNA base sequence being a copy of that on one of the DNA
strands. Most of the RNA synthesized is involved in protein synthesis.
In the double-helical form of DNA, the thymine on one strand is paired
with the adenine on the opposite strand, and cytosine of one strand is
paired with guanine on the opposite strand. There is in DNA also certain
controlling information concerning the timing and amount of RNA to be
made, encoded within the sequence of the DNA in ways that are still
being elucidated.<br/
When this structure is replicated in the course of cell multiplication,
two identical double-helical molecules are formed, each containing one
strand from the original molecule. Each resulting molecule is
distributred to either the parent or progeny organism, and this is the
basic mechanism for transmission of hereditary information. In RNA-based
viruses, or those having single strands of DNA (as certain viruses), the
genetic information transmission occurs through a double-stranded
intermediate by a similar mechanism.<br/
In some organisms slight modifications of the bases of DNA are found,
such as methylcytosine or, in some viruses, uracil or
hydroxymethyluracil; these unusual bases act analogously to the normal
bases in their genetic coding function. A small percentage of
methylcytosine is found in many organisms, and it serves in some cases
as a special signal, as for restriction enzymes.</note><br/
[<source>PJC</source>]</p>

<p><ent>deoxyribonucleotide</ent><br/
<hw>deoxyribonucleotide</hw> <pos>n.</pos> <def>an organic molecule
consisting of a hereocyclic base attached to the 1-carbon of a
deoxyribose ring, with a phosphate group esterified at the 5 position of
the deoxyribose. Deoxyribonuceotides are the monomer units which make up
<er>deoxyribonucleic acid</er>, the molecule carrying the hereditary
information in most organisms. The most common forms of
deoxyribonuceotide are <stype>thymidine-5<prime/-phosphate</stype>
(abbreviated <stype>TMP</stype>),
<stype>deoxyadenosine-5<prime/-phosphate</stype> (abbreviated
<stype>dAMP</stype>), <stype>deoxyguanosine-5<prime/-phosphate</stype>
(abbreviated <stype>dGMP</stype>), and
<stype>deoxycytidine-5<prime/-phosphate</stype> (abbreviated
<stype>dCMP</stype>).</def><br/
[<source>PJC</source>]</p>

<p><ent>deoxyribose</ent><br/
<hw>deoxyribose</hw> <pos>n.</pos> <def>a pentose
(<chform>C5H10O4</chform>) in which one of the hydroxyl groups of ribose
has been replaced by a hydrogen. In deoxyribonucleic acids, the
deoxyribose is <stype>D-2-deoxyribose</stype>, in which the hydroxyl at
the 2 position of ribose is the one which is replaced by
hydrogen.</def><br/
[<source>PJC</source>]</p>

<p><ent>deoxyribosenucleic acid</ent><br/
<hw>deoxyribosenucleic acid</hw> <pos>n.</pos> <def>same as
<er>deoxyribonucleic acid</er>.</def> <mark>[Rare]</mark> <br/
[<source>PJC</source>]</p>

<p><ent>Depaint</ent><br/
<hw>De*paint"</hw> <pr>(?)</pr>, <pos>p. p.</pos> <ety>[F.
<ets>d<eacute/peint</ets>, p. p. of <ets>d<eacute/peindre</ets> to
paint, fr. L. <ets>depingere</ets>. See <er>Depict</er>, <pos>p.
p.</pos>]</ety> <def>Painted.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depaint</ent><br/
<hw>De*paint"</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Depainted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Depainting</conjf>.]</vmorph> <sn>1.</sn> <def>To paint; to
picture; hence, to describe; to delineate in words; to depict.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>And do unwilling worship to the saint<br/
That on his shield <qex>depainted</qex> he did see.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>In few words shall see the nature of many memorable persons . . .
<qex>depainted</qex>.</q> <rj><qau>Holland.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To mark with, or as with, color; to color.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Silver drops her vermeil cheeks <qex>depaint</qex>.</q>
<rj><qau>Fairfax.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depainter</ent><br/
<hw>De*paint"er</hw> <pr>(?)</pr> <pos>n.</pos> <def>One who
depaints.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depardieux</ent><br/
<hw>De*par"dieux`</hw> <pr>(?)</pr>, <pos>interj.</pos> <ety>[OF., a
corruption of <ets>de part Dieu</ets>, lit., on the part of God.]</ety>
<def>In God's name; certainly.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depart</ent><br/
<hw>De*part"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Departed</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Departing</conjf>.]</vmorph> <ety>[OE. <ets>departen</ets> to
divide, part, depart, F. <ets>d<eacute/partir</ets> to divide,
distribute, <ets>se d<eacute/partir</ets> to separate one's self,
depart; pref. <ets>d<eacute/-</ets> (L. <ets>de</ets>) +
<ets>partir</ets> to part, depart, fr. L. <ets>partire</ets>,
<ets>partiri</ets>, to divide, fr. <ets>pars</ets> part. See
<er>Part</er>.]</ety> <sn>1.</sn> <def>To part; to divide; to
separate.</def> <mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To go forth or away; to quit, leave, or separate, as
from a place or a person; to withdraw; -- opposed to <xex>arrive</xex>;
-- often with <xex>from</xex> before the place, person, or thing left,
and <xex>for</xex> or <xex>to</xex> before the destination.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I will <qex>depart</qex> to mine own land.</q> <rj><qau>Num. x.
30.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Ere thou from hence <qex>depart</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He which hath no stomach to this fight,<br/
Let him <qex>depart</qex>.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To forsake; to abandon; to desist or deviate
(<xex>from</xex>); not to adhere to; -- with <xex>from</xex>; <as>as, we
can not <ex>depart</ex> from our rules; to <ex>depart</ex> from a title
or defense in legal pleading.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>If the plan of the convention be found to <qex>depart</qex> from
republican principles.</q> <rj><qau>Madison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To pass away; to perish.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The glory is <qex>departed</qex> from Israel.</q> <rj><qau>1 Sam.
iv. 21.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To quit this world; to die.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Lord, now lettest thou thy servant <qex>depart</qex> in peace.</q>
<rj><qau>Luke ii. 29.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To depart with</b></col>, <cd>to resign; to part
with.</cd> <mark>[Obs.]</mark> <rj><au>Shak.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depart</ent><br/
<hw>De*part"</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To part thoroughly;
to dispart; to divide; to separate.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Till death <qex>departed</qex> them, this life they lead.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To divide in order to share; to apportion.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>And here is gold, and that full great plentee,<br/
That shall <qex>departed</qex> been among us three.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To leave; to depart from.</def> <ldquo/He
<xex>departed</xex> this life.<rdquo/ <au>Addison.</au> <ldquo/Ere I
<xex>depart</xex> his house.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depart</ent><br/
<hw>De*part"</hw>, <pos>n.</pos> <ety>[Cf. F. <ets>d<eacute/part</ets>,
fr. <ets>d<eacute/partir</ets>.]</ety> <sn>1.</sn> <def>Division;
separation, as of compound substances into their ingredients.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The chymists have a liquor called water of <qex>depart</qex>.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A going away; departure; hence, death.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>At my <qex>depart</qex> for France.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Your loss and his <qex>depart</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Departable</ent><br/
<hw>De*part"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Divisible.</def>
<mark>[Obs.]</mark> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>departed</ent><br/
<hw>departed</hw> <pos>n. sing. & pl.</pos> <def>someone who is no
longer alive; <as>as, let us pray for the
<ex>departed</ex></as>.</def><br/
<syn><b>Syn. --</b> dead person, dead soul, deceased person, deceased,
decedent.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>departed</ent><br/
<hw>departed</hw> <pos>adj.</pos> <sn>1.</sn> <def>past; -- used of
time; <as>as, <ex>departed</ex> summers</as>.</def><br/
<syn><b>Syn. --</b> bygone, bypast, foregone, gone.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>dead; <as>as, our dear <ex>departed</ex>
parents</as>.</def> <mark>[euphemistic]</mark><br/
<syn><b>Syn. --</b> asleep(predicate), at peace(predicate), at
rest(predicate), cold, deceased, gone.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>departing</ent><br/
<hw>departing</hw> <pos>adj.</pos> <def>leaving a starting or stopping
point on a journey; <as>as, <ex>Departing</ex> flights were delayed by
the snowstorm</as>. Opposite of <ant>arriving</ant>.</def>
<mark>[prenominal]</mark><br/
<syn><b>Syn. --</b> outbound, outward, outward-bound.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Departer</ent><br/
<hw>De*part"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who
refines metals by separation.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who departs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Department</ent><br/
<hw>De*part"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>d<eacute/partement</ets>, fr. <ets>d<eacute/partir</ets>. See
<er>Depart</er>, <pos>v. i.</pos>]</ety> <sn>1.</sn> <def>Act of
departing; departure.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Sudden <qex>departments</qex> from one extreme to another.</q>
<rj><qau>Wotton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A part, portion, or subdivision.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A distinct course of life, action, study, or the
like; appointed sphere or walk; province.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Superior to Pope in Pope's own peculiar <qex>department</qex> of
literature.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Subdivision of business or official duty;
especially, one of the principal divisions of executive government;
<as>as, the treasury <ex>department</ex>; the war
<ex>department</ex></as>; also, in a university, one of the divisions of
instruction; <as>as, the medical <ex>department</ex>; the
<ex>department</ex> of physics.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A territorial division; a district; esp., in France,
one of the districts composed of several arrondissements into which the
country is divided for governmental purposes; <as>as, the
<ex>Department</ex> of the Loire</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>A military subdivision of a country; <as>as, the
<ex>Department</ex> of the Potomac</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Departmental</ent><br/
<hw>De`part*men"tal</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to
a department or division.</def> <rj><au>Burke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Department store</ent><br/
<hw>De*part"ment store</hw>. <def>A store keeping a great variety of
goods which are arranged in several departments.</def><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><ent>Departure</ent><br/
<hw>De*par"ture</hw> <pr>(?; 135)</pr>, <pos>n.</pos> <ety>[From
<er>Depart</er>.]</ety> <sn>1.</sn> <def>Division; separation; putting
away.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>No other remedy . . . but absolute <qex>departure</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Separation or removal from a place; the act or
process of departing or going away.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Departure</qex> from this happy place.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Removal from the present life; death;
decease.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The time of my <qex>departure</qex> is at hand.</q> <rj><qau>2
Tim. iv. 6.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>His timely <qex>departure</qex> . . . barred him from the
knowledge of his son's miseries.</q> <rj><qau>Sir P.
Sidney.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Deviation or abandonment, as from or of a rule or
course of action, a plan, or a purpose.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Any <qex>departure</qex> from a national standard.</q>
<rj><qau>Prescott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Law)</fld> <def>The desertion by a party to any
pleading of the ground taken by him in his last antecedent pleading, and
the adoption of another.</def> <rj><au>Bouvier.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Nav. & Surv.)</fld> <def>The distance due east or
west which a person or ship passes over in going along an oblique
line.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Since the meridians sensibly converge, the departure in
navigation is not measured from the beginning nor from the end of the
ship's course, but is regarded as the total easting or westing made by
the ship or person as he travels over the course.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To take a departure</b></col> <fld>(Nav. & Surv.)</fld>,
<cd>to ascertain, usually by taking bearings from a landmark, the
position of a vessel at the beginning of a voyage as a point from which
to begin her dead reckoning; as, the ship <xex>took her departure</xex>
from Sandy Hook.</cd></cs></p>

<p><syn><b>Syn.</b> -- Death; demise; release. See
<er>Death</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depascent</ent><br/
<hw>De*pas"cent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>depascens</ets>, p. pr. of <ets>depascere</ets>; <ets>de-</ets> +
<ets>pascere</ets> to feed.]</ety> <def>Feeding.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depasture</ent><br/
<hw>De*pas"ture</hw> <pr>(?; 135)</pr>, <pos>v. t. & i.</pos> <def>To
pasture; to feed; to graze; also, to use for pasture.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Cattle, to graze and <qex>departure</qex> in his grounds.</q>
<rj><qau>Blackstone.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A right to cut wood upon or <qex>departure</qex> land.</q>
<rj><qau>Washburn.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depatriate</ent><br/
<hw>De*pa"tri*ate</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <ety>[L.
<ets>de-</ets> + <ets>patria</ets> one's country.]</ety> <def>To
withdraw, or cause to withdraw, from one's country; to banish.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>A subject born in any state<br/
May, if he please, <qex>depatriate</qex>.</q>
<rj><qau>Mason.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depauperate</ent><br/
<hw>De*pau"per*ate</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Depauperated</conjf>
<pr>(?)</pr>; <pos>p. pr. & vb. n.</pos> <conjf>Depauperating</conjf>
<pr>(?)</pr>.]</vmorph> <ety>[LL. <ets>depauperatus</ets>, p. p.
<ets>depauperare</ets> to impoverish; L. <ets>de-</ets> +
<ets>pauperare</ets> to make poor, <ets>pauper</ets> poor.]</ety>
<def>To make poor; to impoverish.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Liming does not <qex>depauperate</qex>; the ground will last long,
and bear large grain.</q> <rj><qau>Mortimer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Humility of mind which <qex>depauperates</qex> the spirit.</q>
<rj><qau>Jer. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depauperate</ent><br/
<hw>De*pau"per*ate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>depauperatus</ets>, p. p.]</ety> <fld>(Bot.)</fld> <def>Falling
short of the natural size, from being impoverished or starved.</def>
<rj><au>Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depauperize</ent><br/
<hw>De*pau"per*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To free from
paupers; to rescue from poverty.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depeach</ent><br/
<hw>De*peach"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>d<eacute/p<ecir/cher</ets>. See <er>Dispatch</er>.]</ety> <def>To
discharge.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>As soon as the party . . . before our justices shall be
<qex>depeached</qex>.</q> <rj><qau>Hakluyt.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depectible</ent><br/
<hw>De*pec"ti*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>depectere</ets> to comb off; <ets>de-</ets> + <ets>pectere</ets> to
comb.]</ety> <def>Tough; thick; capable of extension.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Some bodies are of a more <qex>depectible</qex> nature than
oil.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depeculation</ent><br/
<hw>De*pec`u*la"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>depeculari</ets>, p. p. <ets>depeculatus</ets>, to rob. See
<er>Peculate</er>.]</ety> <def>A robbing or embezzlement.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Depeculation</qex> of the public treasure.</q>
<rj><qau>Hobbes.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depeinct</ent><br/
<hw>De*peinct"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[See
<er>Depaint</er>.]</ety> <def>To paint.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depend</ent><br/
<hw>De*pend"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Depended</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Depending</conjf>.]</vmorph> <ety>[F. <ets>d<eacute/pendre</ets>,
fr. L. <ets>d<emac/pend<emac/re</ets>; <ets>de-</ets> +
<ets>pendere</ets> to hang. See <er>Pendant</er>.]</ety> <sn>1.</sn>
<def>To hang down; to be sustained by being fastened or attached to
something above.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And ever-living lamps <qex>depend</qex> in rows.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To hang in suspense; to be pending; to be
undetermined or undecided; <as>as, a cause <ex>depending</ex> in
court</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>You will not think it unnatural that those who have an object
<qex>depending</qex>, which strongly engages their hopes and fears,
should be somewhat inclined to superstition.</q>
<rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To rely for support; to be conditioned or
contingent; to be connected with anything, as a cause of existence, or
as a necessary condition; -- followed by <xex>on</xex> or
<xex>upon</xex>, formerly by <xex>of</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The truth of God's word <qex>dependeth</qex> not of the truth of
the congregation.</q> <rj><qau>Tyndale.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The conclusion . . . that our happiness <qex>depends</qex> little
on political institutions, and much on the temper and regulation of our
own minds.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Heaven forming each on other to <qex>depend</qex>.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To trust; to rest with confidence; to rely; to
confide; to be certain; -- with <xex>on</xex> or <xex>upon</xex>;
<as>as, we <ex>depend</ex> on the word or assurance of our friends; we
<ex>depend</ex> on the mail at the usual hour.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>But if you 're rough, and use him like a dog,<br/
<qex>Depend</qex> upon it -- he 'll remain incog.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To serve; to attend; to act as a dependent or
retainer.</def> <mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To impend.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>dependability</ent><br/
<hw>dependability</hw> <pos>n.</pos> <def>the trait of being dependable
or reliable.</def><br/
<syn><b>Syn. --</b> dependableness, reliability, reliableness.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dependable</ent><br/
<hw>De*pend"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Worthy of being
depended on; trustworthy.</def> <ldquo/<xex>Dependable</xex>
friendships.<rdquo/ <rj><au>Pope.</au></rj></p>

<p><ent>Dependancy</ent><br/
<ent>Dependance</ent><br/
<ent>Dependant</ent><br/
<mhw>{ <hw>De*pend"ant</hw> <pr>(?)</pr>, <hw>De*pend"ance</hw>
<pr>(?)</pr>, <pos>n.</pos>, <hw>De*pend"an*cy</hw> <pr>(?)</pr>
}</mhw>, <pos>n.</pos> <def>See <er>Dependent</er>, <er>Dependence</er>,
<er>Dependency</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The forms <xex>dependant</xex>, <xex>dependance</xex>,
<xex>dependancy</xex> are from the French; the forms
<xex>dependent</xex>, etc., are from the Latin. Some authorities give
preference to the form <xex>dependant</xex> when the word is a noun,
thus distinguishing it from the adjective, usually written
<xex>dependent</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dependence</ent><br/
<hw>De*pend"ence</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL.
<ets>dependentia</ets>, fr. L. <ets>dependens</ets>. See
<er>Dependent</er>, and cf. <er>Dependance</er>.]</ety> <sn>1.</sn>
<def>The act or state of depending; state of being dependent; a hanging
down or from; suspension from a support.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The state of being influenced and determined by
something; subjection (as of an <xex>effect</xex> to its
<xex>cause</xex>).</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The cause of effects, and the <qex>dependence</qex> of one thing
upon another.</q> <rj><qau>Bp. Burnet.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Mutual connection and support; concatenation;
systematic inter-relation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>So dark and so intricate of purpose, without any
<qex>dependence</qex> or order.</q> <rj><qau>Sir T. More.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Subjection to the direction or disposal of another;
inability to help or provide for one's self; a lack of independence or
self-sufficiency.</def><br/
<syn><b>Syn. --</b> dependance, dependency.</syn><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><q>Reduced to a servile <qex>dependence</qex> on their mercy.</q>
<rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A resting with confidence; reliance;
trust.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Affectionate <qex>dependence</qex> on the Creator is the spiritual
life of the soul.</q> <rj><qau>T. Erskine.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>That on which one depends or relies; <as>as, he was
her sole <ex>dependence</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>That which depends; anything dependent or suspended;
anything attached a subordinate to, or contingent on, something
else.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Like a large cluster of black grapes they show<br/
And make a large <qex>dependence</qex> from the bough.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>A matter depending, or in suspense, and still to be
determined; ground of controversy or quarrel.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>To go on now with my first <qex>dependence</qex>.</q>
<rj><qau>Beau. & Fl.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dependency</ent><br/
<hw>De*pend"en*cy</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Dependencies</plw> <pr>(<?/)</pr>.</plu> <sn>1.</sn> <def>State of
being dependent; dependence; state of being subordinate; subordination;
concatenation; connection; reliance; trust.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Any long series of action, the parts of which have very much
<qex>dependency</qex> each on the other.</q> <rj><qau>Sir J.
Reynolds.</qau></rj> <-- #sic. "action" is the singular. Why? --><br/
[<source>1913 Webster</source>]</p>

<p><q>So that they may acknowledge their <qex>dependency</qex> on the
crown of England.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A thing hanging down; a dependence.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which is attached to something else as its
consequence, subordinate, satellite, and the like.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This earth and its <qex>dependencies</qex>.</q> <rj><qau>T.
Burnet.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Modes I call such complex ideas which . . . are considered as
<qex>dependencies</qex> on or affections of substances.</q>
<rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A territory remote from the kingdom or state to
which it belongs, but subject to its dominion; a colony; <as>as, Great
Britain has its <ex>dependencies</ex> in Asia, Africa, and
America</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Dependence</xex> is more used in the abstract, and
<xex>dependency</xex> in the concrete. The latter is usually restricted
in meaning to 3 and 4.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dependent</ent><br/
<hw>De*pend"ent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>dependens</ets>, <ets>-entis</ets>, p. pr. <ets>dependere</ets>.
See <er>Depend</er>, and cf. <er>Dependant</er>.]</ety> <sn>1.</sn>
<def>Hanging down; <as>as, a <ex>dependent</ex> bough or
leaf</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Relying on, or subject to, something else for
support; not able to exist, or sustain itself, or to perform anything,
without the will, power, or aid of something else; not self-sustaining;
subordinate; -- often with <xex>on</xex> or <xex>upon</xex>; <as>as,
<ex>dependent</ex> on God; <ex>dependent</ex> upon friends</as>.
Opposite of <ant>independent</ant>.</def> [Narrower terms:
<stype>interdependent, mutualist, mutually beneficial</stype>;
<stype>parasitic, parasitical, leechlike, bloodsucking</stype>;
<stype>subordinate</stype>; <stype>underage</stype>;
<stype>myrmecophilous</stype>; <stype>symbiotic</stype>] <see>Also See:
<er>unfree</er>.</see><br/
[<source>1913 Webster</source>]</p>

<p><q>England, long <qex>dependent</qex> and degraded, was again a power
of the first rank.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>conditional; contingent or conditioned. Opposite of
<ant>unconditional</ant>.</def><br/
<syn><b>Syn. --</b> qualified.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>4.</sn> <def>addicted to drugs.</def><br/
<syn><b>Syn. --</b> addicted, dependent, drug-addicted, hooked,
strung-out.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><cs><mcol><col><b>Dependent covenant</b></col> <it>or</it>
<col><b>Dependent contract</b></col></mcol> <fld>(Law)</fld>, <cd>one
not binding until some connecting stipulation is performed.</cd> --
<col><b>Dependent variable</b></col> <fld>(Math.)</fld>, <cd>a varying
quantity whose changes are arbitrary, but are regarded as produced by
changes in another variable, which is called the <contr>independent
variable</contr>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dependent</ent><br/
<hw>De*pend"ent</hw>, <pos>n.</pos> <sn>1.</sn> <def>One who depends;
one who is sustained by another, or who relies on another for financial
support or favor; a hanger-on; a retainer; <as>as, a numerous train of
<ex>dependents</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A host of <qex>dependents</qex> on the court, suborned to play
their part as witnesses.</q> <rj><qau>Hallam.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which depends; corollary;
consequence.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With all its circumstances and <qex>dependents</qex>.</q>
<rj><qau>Prynne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ See the Note under <er>Dependant</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dependently</ent><br/
<hw>De*pend"ent*ly</hw>, <pos>adv.</pos> <def>In a dependent
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depender</ent><br/
<hw>De*pend"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who depends; a
dependent.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dependingly</ent><br/
<hw>De*pend"ing*ly</hw>, <pos>adv.</pos> <def>As having
dependence.</def> <rj><au>Hale.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depeople</ent><br/
<hw>De*peo"ple</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To
depopulate.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deperdit</ent><br/
<hw>De*per"dit</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL.
<ets>deperditum</ets>, fr. L. <ets>deperditus</ets>, p. p. of
<ets>deperdere</ets>; <ets>de-</ets> + <ets>perdere</ets> to lose,
destroy.]</ety> <def>That which is lost or destroyed.</def>
<mark>[R.]</mark> <rj><au>Paley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deperditely</ent><br/
<hw>De*per"dite*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>Hopelessly;
despairingly; in the manner of one ruined; <as>as, <ex>deperditely</ex>
wicked</as>.</def> <mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deperdition</ent><br/
<hw>Dep`er*di"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>d<eacute/perdition</ets>.]</ety> <def>Loss; destruction.</def>
<mark>[Archaic]</mark> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depertible</ent><br/
<hw>De*per"ti*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Depart</er>.]</ety> <def>Divisible.</def> <mark>[Obs.]</mark>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dephase</ent><br/
<hw>De*phase"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <fld>(Elec.)</fld>
<def>To put out of phase, as two parts of a single alternating
current.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Dephlegm</ent><br/
<hw>De*phlegm"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>de-</ets> + <ets>phlegm</ets> water; cf. F.
<ets>d<eacute/phlegmer</ets>, <ets>d<eacute/flegmer</ets>.]</ety>
<fld>(O. Chem.)</fld> <def>To rid of phlegm or water; to
dephlegmate.</def> <mark>[Obs.]</mark> <rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dephlegmate</ent><br/
<hw>De*phleg"mate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Dephlegmated</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Dephlegmating</conjf>.]</vmorph> <ety>[See
<er>Dephlegm</er>.]</ety> <fld>(Chem.)</fld> <def>To deprive of
superabundant water, as by evaporation or distillation; to clear of
aqueous matter; to rectify; -- used of spirits and acids.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dephlegmation</ent><br/
<hw>De`phleg*ma"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>d<eacute/flegmation</ets>.]</ety> <fld>(Chem.)</fld> <def>The
operation of separating water from spirits and acids, by evaporation or
repeated distillation; -- called also <altname>concentration</altname>,
especially when acids are the subject of it.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dephlegmator</ent><br/
<hw>De*phleg"ma*tor</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An instrument
or apparatus in which water is separated by evaporation or distillation;
the part of a distilling apparatus in which the separation of the vapors
is effected.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dephlegmatory</ent><br/
<hw>De*phleg"ma*to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining
to, or producing, dephlegmation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dephlegmedness</ent><br/
<hw>De*phlegm"ed*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A state of
being freed from water.</def> <mark>[Obs.]</mark>
<rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dephlogisticcate</ent><br/
<hw>De`phlo*gis"tic*cate</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Dephlogisticated</conjf>
<pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Dephlogisticating</conjf>.]</vmorph> <ety>[Pref. <ets>de-</ets> +
<ets>phlosticate</ets>: cf. F. <ets>d<eacute/phlogistiguer</ets>.]</ety>
<fld>(O. Chem.)</fld> <def>To deprive of phlogiston, or the supposed
principle of inflammability.</def> <rj><au>Priestley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dephlogisticated air</b></col>, <cd>oxygen gas; -- so
called by Dr. Priestly and others of his time.</cd></cs></p>

<p>-- <wordforms><wf>De`phlo*gis`ti*ca"tion</wf> <pr>(#)</pr>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dephosphorization</ent><br/
<hw>De*phos`phor*i*za"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act
of freeing from phosphorous.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depict</ent><br/
<hw>De*pict"</hw> <pr>(d<esl/*p<icr/kt")</pr>, <pos>p. p.</pos> <ety>[L.
<ets>depictus</ets>, p. p. of <ets>depingere</ets> to depict;
<ets>de-</ets> + <ets>pingere</ets> to paint. See <er>Paint</er>, and
cf. <er>Depaint</er>, <pos>p. p.</pos>]</ety> <def>Depicted.</def>
<rj><au>Lydgate.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 393 --></p>

<p><ent>Depict</ent><br/
<hw>De*pict"</hw> <pr>(d<esl/*p<icr/kt")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Depicted</conjf>; <pos>p. pr. &
vb. n.</pos> <conjf>Depicting</conjf>.]</vmorph> <sn>1.</sn> <def>To
form a colored likeness of; to represent by a picture; to paint; to
portray.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His arms are fairly <qex>depicted</qex> in his chamber.</q>
<rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To represent in words; to describe
vividly.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>C<ae/sar's gout was then <qex>depicted</qex> in energetic
language.</q> <rj><qau>Motley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>depicted</ent><br/
<hw>depicted</hw> <pos>adj.</pos> <def>represented graphically by sketch
or design or lines.</def><br/
<syn><b>Syn. --</b> pictured, portrayed.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Depiction</ent><br/
<hw>De*pic"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>depictio</ets>.]</ety> <def>A painting or depicting; a
representation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depicture</ent><br/
<hw>De*pic"ture</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Depictured</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Depicturing</conjf>.]</vmorph> <def>To make a picture
of; to paint; to picture; to depict.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Several persons were <qex>depictured</qex> in caricature.</q>
<rj><qau>Fielding.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depilate</ent><br/
<hw>Dep"i*late</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Depilated</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Depilating</conjf>.]</vmorph> <ety>[L. <ets>depilatus</ets>, p.
p. of <ets>depilare</ets> to depilate; <ets>de-</ets> +
<ets>pilare</ets> to put forth hairs, <ets>pilus</ets> hair.]</ety>
<def>To strip of hair; to husk.</def> <rj><au>Venner.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depilation</ent><br/
<hw>Dep`i*la"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>d<eacute/pilation</ets>.]</ety> <def>Act of pulling out or removing
the hair; unhairing.</def> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depilatory</ent><br/
<hw>De*pil"a*to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>d<eacute/pilatoire</ets>.]</ety> <def>Having the quality or power
of removing hair.</def> -- <def2><pos>n.</pos> <def>An application used
to take off hair.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depilous</ent><br/
<hw>Dep"i*lous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>de-</ets> + <ets>pilous</ets>: cf. L. <ets>depilis</ets>.]</ety>
<def>Hairless.</def> <rj><au>Sir t. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deplanate</ent><br/
<hw>De*pla"nate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>deplanetus</ets>, p. p. of <ets>deplanare</ets> to make level. See
<er>Plane</er>, <pos>v. t.</pos>]</ety> <fld>(Bot.)</fld>
<def>Flattened; made level or even.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deplant</ent><br/
<hw>De*plant"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>de-</ets> + <ets>plan</ets>: cf. F. <ets>d<eacute/planter</ets>, L.
<ets>deplantare</ets> to take off a twig. See <er>Plant</er>, <pos>v.
t.</pos>]</ety> <def>To take up (plants); to transplant.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deplantation</ent><br/
<hw>De`plan*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>d<eacute/plantation</ets>.]</ety> <def>Act of taking up plants from
beds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deplete</ent><br/
<hw>De*plete"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Depleted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Depleting</conjf>.]</vmorph> <ety>[From L. <ets>deplere</ets> to
empty out; <ets>de-</ets> + <ets>plere</ets> to fill. Forined like
<ets>replete</ets>, <ets>complete</ets>. See <er>Fill</er>,
<er>Full</er>, <pos>a.</pos>]</ety> <sn>1.</sn> <fld>(Med.)</fld>
<def>To empty or unload, as the vessels of human system, by bloodletting
or by medicine.</def> <rj><au>Copland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To reduce by destroying or consuming the vital
powers of; to exhaust, as a country of its strength or resources, a
treasury of money, etc.</def> <rj><au>Saturday Review.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>depleted</ent><br/
<hw>depleted</hw> <pos>adj.</pos> <sn>1.</sn> <def>no longer sufficient;
<as>as, our funds are <ex>depleted</ex></as>.</def><br/
<syn><b>Syn. --</b> low.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>having resources completely depleted.</def><br/
<syn><b>Syn. --</b> drained.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Depletion</ent><br/
<hw>De*ple"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>d<eacute/pl<eacute/tion</ets>.]</ety> <sn>1.</sn> <def>The act of
depleting or emptying.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Med.)</fld> <def>the act or process of diminishing
the quantity of fluid in the vessels by bloodletting or otherwise; also
excessive evacuation, as in severe diarrhea.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depletive</ent><br/
<hw>De*ple"tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>d<eacute/pl<eacute/tif</ets>.]</ety> <def>Able or fitted to
deplete.</def> -- <def2><pos>n.</pos> <def>A substance used to
deplete.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depletory</ent><br/
<hw>De*ple"to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Serving to
deplete.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deplication</ent><br/
<hw>Dep`li*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL.
<ets>deplicare</ets> to unfold; L. <ets>de-</ets> + <ets>plicare</ets>
to fold.]</ety> <def>An unfolding, untwisting, or unplaiting.</def>
<mark>[Obs.]</mark> <rj><au>W. Montagu.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deploitation</ent><br/
<hw>Dep`loi*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf.
<er>Exploitation</er>, <er>Deploy</er>.]</ety> <def>Same as
Exploitation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deplorability</ent><br/
<hw>De*plor`a*bil"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Deplorableness.</def> <rj><au>Stormonth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deplorable</ent><br/
<hw>De*plor"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>d<eacute/plorable</ets>.]</ety> <def>Worthy of being deplored or
lamented; lamentable; causing grief; hence, sad; calamitous; grievous;
wretched; <as>as, life's evils are deplorable</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Individual sufferers are in a much more <qex>deplorable</qex>
conditious than any others.</q> <rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deplorableness</ent><br/
<hw>De*plor"a*ble*ness</hw>, <pos>n.</pos> <def>State of being
deplorable.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deplorably</ent><br/
<hw>De*plor"a*bly</hw>, <pos>adv.</pos> <def>In a deplorable
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deplorate</ent><br/
<hw>De*plo"rate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>deploratus</ets>, p. p. of <ets>deplorare</ets>. See
<er>Deplore</er>.]</ety> <def>Deplorable.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>A more <qex>deplorate</qex> estate.</q>
<rj><qau>Baker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deploration</ent><br/
<hw>Dep`lo*ra"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>deploratio</ets>: cf. F. <ets>d<eacute/ploration</ets>.]</ety>
<def>The act of deploring or lamenting; lamentation.</def>
<rj><au>Speed.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deplore</ent><br/
<hw>De*plore"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Deplored</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Deploring</conjf>.]</vmorph> <ety>[L.
<ets>deplorare</ets>; <ets>de-</ets> + <ets>plorare</ets> to cry out,
wail, lament; prob. akin to <ets>pluere</ets> to rain, and to E. flow:
cf. F. d<eacute/plorer. Cf. Flow.]</ety> <sn>1.</sn> <def>To feel or to
express deep and poignant grief for; to bewail; to lament; to mourn; to
sorrow over.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To find her, or forever to <qex>deplore</qex><br/
Her loss.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>As some sad turtle his lost love <qex>deplores</qex>.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To complain of.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To regard as hopeless; to give up.</def>
<mark>[Obs.]</mark> <rj><au>Bacon.</au></rj></p>

<p><syn><b>Syn.</b> -- To <er>Deplore</er>, <er>Mourn</er>,
<er>Lament</er>, <er>Bewail</er>, <er>Bemoan</er>.</syn> <usage>
<xex>Mourn</xex> is the generic term, denoting a state of grief or
sadness. To <xex>lament</xex> is to express grief by outcries, and
denotes an earnest and strong expression of sorrow. To
<xex>deplore</xex> marks a deeper and more prolonged emotion. To
<xex>bewail</xex> and to <xex>bemoan</xex> are appropriate only to cases
of poignant distress, in which the grief finds utterance either in
wailing or in moans and sobs. A man <xex>laments</xex> his errors, and
<xex>deplores</xex> the ruin they have brought on his family; mothers
<xex>bewail</xex> or <xex>bemoan</xex> the loss of their
children.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deplore</ent><br/
<hw>De*plore"</hw>, <pos>v. i.</pos> <def>To lament.</def>
<rj><au>Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deploredly</ent><br/
<hw>De*plor"ed*ly</hw> <pr>(?)</pr>, <pos>adv.</pos>
<def>Lamentably.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deploredness</ent><br/
<hw>De*plor"ed*ness</hw>, <pos>n.</pos> <def>The state of being deplored
or deplorable.</def> <mark>[R.]</mark> <rj><au>Bp. Hail.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deplorement</ent><br/
<hw>De*plore"ment</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Deploration.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deplorer</ent><br/
<hw>De*plor"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
deplores.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deploringly</ent><br/
<hw>De*plor"ing*ly</hw>, <pos>adv.</pos> <def>In a deploring
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deploy</ent><br/
<hw>De*ploy"</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Deployed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Deploying</conjf>.]</vmorph> <ety>[F.
<ets>d<eacute/ployer</ets>; pref. <ets>d<eacute/</ets> =
<ets>d<eacute/s</ets> (L. <ets>dis</ets>) + <ets>ployer</ets>, equiv. to
<ets>plier</ets> to fold, fr. L. <ets>plicare</ets>. See <er>Ply</er>,
and cf. <er>Display</er>.]</ety> <fld>(Mil.)</fld> <def>To open out; to
unfold; to spread out (a body of troops) in such a way that they shall
display a wider front and less depth; -- the reverse of <inv>ploy</inv>;
<as>as, to <ex>deploy</ex> a column of troops into line of
battle</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>deploy</ent><br/
<hw>de*ploy"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To place (people
or other resources) into a position so as to be ready to for action or
use.</def><br/
[<source>PJC</source>]</p>

<p><ent>Deployment</ent><br/
<ent>Deploy</ent><br/
<mhw>{ <hw>De*ploy"</hw> <pr>(?)</pr>, <hw>De*ploy"ment</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <fld>(Mil.)</fld> <def>The act of
deploying; a spreading out of a body of men in order to extend their
front.</def> <rj><au>Wilhelm.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Deployments</qex> . . . which cause the soldier to turn his
back to the enemy are not suited to war.</q> <rj><qau>H. L.
Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>deployment</ent><br/
<hw>deployment</hw> <pos>n.</pos> <def>the arrangement or distribution
(of resources such as people or equipment), in preparation for battle or
work.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Deplumate</ent><br/
<hw>De*plu"mate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[LL.
<ets>diplumatus</ets>, p. p. of <ets>deplumare</ets>. See
<er>Deplume</er>.]</ety> <fld>(Zool.)</fld> <def>Destitute or deprived
of features; deplumed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deplumation</ent><br/
<hw>Dep`lu*ma"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Deplumate</er>.]</ety> <sn>1.</sn> <def>The stripping or falling off
of plumes or feathers.</def> <rj><au>Bp. Stillingfleet</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Med.)</fld> <def>A disease of the eyelids, attended
with loss of the eyelashes.</def> <rj><au>Thomas.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deplume</ent><br/
<hw>De*plume"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Deplumed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Depluming</conjf>.]</vmorph> <ety>[LL.
<ets>deplumare</ets>; L. <ets>de-</ets> + <ets>plumare</ets> to cover
with feathers, <ets>pluma</ets> feather: cf. <ets>deplumis</ets>
featherless, and F. <ets>d<eacute/plumer</ets>.]</ety> <sn>1.</sn>
<def>To strip or pluck off the feather of; to deprive of of
plumage.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>On the <qex>depluming</qex> of the pope every bird had his own
feather.</q> <rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To lay bare; to expose.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The exposure and <qex>depluming</qex> of the leading humbugs of
the age.</q> <rj><qau>De Quincey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depolarization</ent><br/
<hw>De*po`lar*i*za"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>d<eacute/polarisation</ets>.]</ety> <def>The act of depriving of
polarity, or the result of such action; reduction to an unpolarized
condition.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Depolarization of light</b></col> <fld>(Opt.)</fld>,
<cd>a change in the plane of polarization of rays, especially by a
crystalline medium, such that the light which had been extinguished by
the analyzer reappears as if the polarization had been anulled. The word
is inappropriate, as the ray does not return to the unpolarized
condition.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depolarize</ent><br/
<hw>De*po"lar*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Depolarized</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Depolarizing</conjf>.]</vmorph> <ety>[Pref.
<ets>de-</ets> + <ets>polarize</ets>: cf. F.
<ets>d<eacute/polarizer</ets>.]</ety> <sn>1.</sn> <fld>(Opt.)</fld>
<def>To deprive of polarity; to reduce to an unpolarized
condition.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ This word has been inaccurately applied in optics to
describe the effect of a polarizing medium, as a crystalline plate, in
causing the reappearance of a ray, in consequence of a change in its
plane of polarization, which previously to the change was intercepted by
the analyzer.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Elec.)</fld> <def>To free from polarization, as the
negative plate of the voltaic battery.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depolarizer</ent><br/
<hw>De*po"lar*i`zer</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Elec.)</fld>
<def>A substance used to prevent polarization, as upon the negative
plate of a voltaic battery.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depolish</ent><br/
<hw>De*pol"ish</hw> <pr>(d<esl/*p<ocr/l"<icr/sh)</pr>, <pos>v. t.</pos>
<def>To remove the polish or glaze from.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depolishing</ent><br/
<hw>De*pol"ish*ing</hw> <pr>(d<esl/*p<ocr/l"<icr/sh*<icr/ng)</pr>,
<pos>n.</pos> <fld>(Ceramics)</fld> <def>The process of removing the
vitreous glaze from porcelain, leaving the dull luster of the surface of
ivory porcelain.</def> <rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depone</ent><br/
<hw>De*pone"</hw> <pr>(d<esl/*p<omac/n")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Deponed</conjf>
<pr>(-p<omac/nd")</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Deponing</conjf>.]</vmorph> <ety>[L. <ets>deponere</ets>,
<ets>depositum</ets>, to put down, in LL., to assert under oath;
<ets>de-</ets> + <ets>ponere</ets> to put, place. See <er>Position</er>,
and cf. <er>Deposit</er>.]</ety> <sn>1.</sn> <def>To lay, as a stake; to
wager.</def> <mark>[Obs.]</mark> <rj><au>Hudibras.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To lay down.</def> <mark>[R.]</mark>
<rj><au>Southey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To assert under oath; to depose.</def> <mark>[A
Scotticism]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Sprot <qex>deponeth</qex> that he entered himself thereafter in
conference.</q> <rj><qau>State Trials(1606).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depone</ent><br/
<hw>De*pone"</hw>, <pos>v. i.</pos> <def>To testify under oath; to
depose; to bear witness.</def> <mark>[A Scotticism]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The fairy Glorians, whose credibility on this point can not be
called in question, <qex>depones</qex> to the confinement of Merlin in a
tree.</q> <rj><qau>Dunlop.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deponent</ent><br/
<hw>De*po"nent</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>deponenes</ets>, <ets>-entis</ets>, laying down. See
<er>Depone</er>, <pos>v. t.</pos>]</ety> <sn>1.</sn> <fld>(Law)</fld>
<def>One who deposes or testifies under oath; one who gives evidence;
usually, one who testifies in writing.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Gr. & Lat. Gram.)</fld> <def>A deponent
verb.</def></p>

<p><syn><b>Syn.</b> -- <er>Deponent</er>, <er>Affiant</er>.</syn>
<usage> These are legal terms describing a person who makes a written
declaration under oath, with a view to establish certain facts. An
<xex>affiant</xex> is one who makes an affidavit, or declaration under
oath, in order to establish the truth of what he says. A
<xex>deponenet</xex> is one who makes a deposition, or gives written
testimony under oath, to be used in the trial of some case before a
court of justice. See under <er>Deposition</er>.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deponent</ent><br/
<hw>De*po"nent</hw>, <pos>a.</pos> <ety>[L. <ets>deponens</ets>,
<ets>-entis</ets>, laying down (its proper passive meaning), p. pr. of
<ets>deponere</ets>: cf. F. <ets>d<eacute/ponent</ets>. See
<er>Depone</er>.]</ety> <fld>(Gram.)</fld> <def>Having a passive form
with an active meaning, as certain Latin and Greek verbs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depopulacy</ent><br/
<hw>De*pop"u*la*cy</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Depopulation;
destruction of population.</def> <mark>[R.]</mark>
<rj><au>Chapman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depopulate</ent><br/
<hw>De*pop"u*late</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Depopulated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Depopulating</conjf> <pr>(?)</pr>.]</vmorph> <ety>[L.
<ets>depopulatus</ets>, p. p. of <ets>depopulari</ets> to ravage;
<ets>de-</ets> + <ets>populari</ets> to ravage, fr. <ets>populus</ets>
people: cf. OF. <ets>depopuler</ets>, F. <ets>d<eacute/peupler</ets>.
See <er>People</er>.]</ety> <def>To deprive of inhabitants, whether by
death or by expulsion; to reduce greatly the populousness of; to
dispeople; to unpeople.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Where is this viper,<br/
That would <qex>depopulate</qex> the city?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ It is not synonymous with <xex>laying waste</xex> or
destroying, being limited to the loss of inhabitants; as, an army or a
famine may <xex>depopulate</xex> a country. It rarely expresses an
entire loss of inhabitants, but often a great diminution of their
numbers; as, the deluge <xex>depopulated</xex> the earth.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depopulate</ent><br/
<hw>De*pop"u*late</hw>, <pos>v. i.</pos> <def>To become
dispeopled.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Whether the country be <qex>depopulating</qex> or not.</q>
<rj><qau>Goldsmith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depopulation</ent><br/
<hw>De*pop`u*la"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>depopulatio</ets> pillaging: cf. F. <ets>d<eacute/population</ets>
depopulation.]</ety> <def>The act of depopulating, or condition of being
depopulated; destruction or expulsion of inhabitants.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The desolation and <qex>depopulation</qex> [of St.Quentin] were
now complete.</q> <rj><qau>Motley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depopulator</ent><br/
<hw>De*pop"u*la`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.,
pillager.]</ety> <def>One who depopulates; a dispeopler.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deport</ent><br/
<hw>De*port"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Deported</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Deporting</conjf>.]</vmorph> <ety>[F. <ets>d<eacute/porter</ets>
to transport for life, OF., to divert, amuse, from L.
<ets>deportare</ets> to carry away; <ets>de-</ets> + <ets>portare</ets>
to carry. See <er>Port</er> demeanor.]</ety> <sn>1.</sn> <def>To
transport; to carry away; to exile; to send into banishment; to expel
(from a region or country).</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He told us he had been <qex>deported</qex> to Spain.</q>
<rj><qau>Walsh.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To carry or demean; to conduct; to behave; --
followed by the reflexive pronoun.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Let an ambassador <qex>deport</qex> himself in the most graceful
manner befor a prince.</q> <rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deport</ent><br/
<hw>De*port"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Behavior; carriage;
demeanor; deportment.</def> <mark>[Obs.]</mark> <ldquo/Goddesslike
<xex>deport</xex>.<rdquo/ <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deportation</ent><br/
<hw>De`por*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>depotatio</ets>: cf. F. <ets>d<eacute/portation</ets>.]</ety>
<def>The act of deporting or exiling, or the state of being deported;
banishment; transportation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In their <qex>deportations</qex>, they had often the favor of
their conquerors.</q> <rj><qau>Atterbury.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>deportee</ent><br/
<hw>deportee</hw> <pos>n.</pos> <def>a person who was expelled from home
or country by governmental authority; one who has been
deported.</def><br/
<syn><b>Syn. --</b> exile.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Deportment</ent><br/
<hw>De*port"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>d<eacute/portement</ets> misconduct, OF., demeanor. See
<er>Deport</er>.]</ety> <def>Manner of deporting or demeaning one's
self; manner of acting; conduct; carriage; especially, manner of acting
with respect to the courtesies and duties of life; behavior; demeanor;
bearing.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The gravity of his <qex>deportment</qex> carried him safe through
many difficulties.</q> <rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deporture</ent><br/
<hw>De*por"ture</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Deportment.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Stately port and majestical <qex>deporture</qex>.</q>
<rj><qau>Speed.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deposable</ent><br/
<hw>De*pos"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of being
deposed or deprived of office.</def> <rj><au>Howell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deposal</ent><br/
<hw>De*pos"al</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of deposing
from office; a removal from the throne.</def> <rj><au>Fox.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depose</ent><br/
<hw>De*pose"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Deposed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Deposing</conjf>.]</vmorph><ety>[FF. <ets>d<eacute/poser</ets>,
in the sense of L. <ets>deponere</ets> to put down; but from pref.
<ets>d<eacute/-</ets> (L. <ets>de</ets>) + <ets>poser</ets> to place.
See <er>Pose</er>, <er>Pause</er>.]</ety> <sn>1.</sn> <def>To lay down;
to divest one's self of; to lay aside.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Thus when the state one Edward did <qex>depose</qex>,<br/
A greater Edward in his room arose.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To let fall; to deposit.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Additional mud <qex>deposed</qex> upon it.</q>
<rj><qau>Woodward.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To remove from a throne or other high station; to
dethrone; to divest or deprive of office.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A tyrant over his subjects, and therefore worthy to be
<qex>deposed</qex>.</q> <rj><qau>Prynne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To testify under oath; to bear testimony to; -- now
usually said of bearing testimony which is officially written down for
future use.</def> <rj><au>Abbott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>depose</qex> the yearly rent or valuation of lands.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To put under oath.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Depose</qex> him in the justice of his cause.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depose</ent><br/
<hw>De*pose"</hw>, <pos>v. i.</pos> <def>To bear witness; to testify
under oath; to make deposition.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Then, seeing't was he that made you to <qex>despose</qex>,<br/
Your oath, my lord, is vain and frivolous.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deposer</ent><br/
<hw>De*pos"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who
deposes or degrades from office.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who testifies or deposes; a deponent.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deposit</ent><br/
<hw>De*pos"it</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Deposited</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Depositing</conjf>.]</vmorph> <ety>[L. <ets>depositus</ets>, p.
p. of <ets>deponere</ets>. See <er>Depone</er>, and cf.
<er>Deposit</er>, <pos>n.</pos>]</ety> <sn>1.</sn> <def>To lay down; to
place; to put; to let fall or throw down (as sediment); <as>as, a
crocodile <ex>deposits</ex> her eggs in the sand; the waters
<ex>deposited</ex> a rich alluvium.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>The fear is <qex>deposited</qex> in conscience.</q> <rj><qau>Jer.
Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To lay up or away for safe keeping; to put up; to
store; <as>as, to <ex>deposit</ex> goods in a warehouse</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To lodge in some one's hands for safe keeping; to
commit to the custody of another; to intrust; esp., to place in a bank,
as a sum of money subject to order.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To lay aside; to rid one's self of.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>If what is written prove useful to you, to the
<qex>depositing</qex> that which I can not but deem an error.</q>
<rj><qau>Hammond.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Both this verb and the noun following were formerly
written <asp>deposite</asp>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deposit</ent><br/
<hw>De*pos"it</hw>, <pos>n.</pos> <ety>[L. <ets>depositum</ets>, fr.
<ets>depositus</ets>, p. p. of <ets>deponere</ets>: cf. F.
<ets>d<eacute/p<ocir/t</ets>, OF. <ets>depost</ets>. See
<er>Deposit</er>, <pos>v. t.</pos>, and cf. <er>Depot</er>.]</ety>
<sn>1.</sn> <def>That which is deposited, or laid or thrown down;
<as>as, a <ex>deposit</ex> in a flue</as>; especially, matter
precipitated from a solution (as the siliceous deposits of hot springs),
or that which is mechanically deposited (as the mud, gravel, etc.,
<ex>deposits</ex> of a river).</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>deposit</qex> already formed affording to the succeeding
portion of the charged fluid a basis.</q>
<rj><qau>Kirwan.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mining)</fld> <def>A natural occurrence of a useful
mineral under the conditions to invite exploitation.</def>
<rj><au>Raymond.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which is placed anywhere, or in any one's
hands, for safe keeping; something intrusted to the care of another;
esp., money lodged with a bank or banker, subject to order; anything
given as pledge or security.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Law)</fld> <sd>(a)</sd> <def>A bailment of money or
goods to be kept gratuitously for the bailor.</def> <sd>(b)</sd>
<def>Money lodged with a party as earnest or security for the
performance of a duty assumed by the person depositing.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A place of deposit; a depository.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Bank of deposit</b></col>. <cd>See under
<er>Bank</er>.</cd> -- <mcol><col><b>In deposit</b></col>, or <col><b>On
deposit</b></col></mcol>, <cd>in trust or safe keeping as a deposit;
<as>as, coins were received <ex>on deposit</ex></as>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depositary</ent><br/
<hw>De*pos"i*ta*ry</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Depositaries</plw> <pr>(#)</pr>.</plu> <ety>[L.
<ets>depositarius</ets>, fr. <ets>deponere</ets>. See
<er>Deposit</er>.]</ety> <sn>1.</sn> <def>One with whom anything is
lodged in the trust; one who receives a deposit; -- the correlative of
<inv>depositor</inv>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I . . . made you my guardians, my <qex>depositaries</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>depositaries</qex> of power, who are mere delegates of
the people.</q> <rj><qau>J. S. Mill.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A storehouse; a depository.</def> <rj><au>Bp.
Hurd.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Law)</fld> <def>One to whom goods are bailed, to be
kept for the bailor without a recompense.</def>
<rj><au>Kent.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deposition</ent><br/
<hw>Dep`o*si"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>depositio</ets>, fr. <ets>deponere</ets>: cf. F.
<ets>d<eacute/position</ets>. See <er>Deposit</er>.]</ety> <sn>1.</sn>
<def>The act of depositing or deposing; the act of laying down or thrown
down; precipitation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>deposition</qex> of rough sand and rolled pebbles.</q>
<rj><qau>H. Miller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The act of bringing before the mind;
presentation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The influence of princes upon the dispositions of their courts
needs not the <qex>deposition</qex> of their examples, since it hath the
authority of a known principle.</q> <rj><qau>W. Montagu.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 394 --></p>

<p><sn>3.</sn> <def>The act of setting aside a sovereign or a public
officer; deprivation of authority and dignity; displacement;
removal.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ A <xex>deposition</xex> differs from an
<xex>abdication</xex>, an <xex>abdication</xex> being voluntary, and a
<xex>deposition</xex> compulsory.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>That which is deposited; matter laid or thrown down;
sediment; alluvial matter; <as>as, banks are sometimes
<ex>depositions</ex> of alluvial matter</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>An opinion, example, or statement, laid down or
asserted; a declaration.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Law)</fld> <def>The act of laying down one's
testimony in writing; also, testimony laid or taken down in writing,
under oath or affirmation, before some competent officer, and in reply
to interrogatories and cross-interrogatories.</def></p>

<p><syn><b>Syn.</b> -- <er>Deposition</er>, <er>Affidavit</er>.</syn>
<usage> <xex>Affidavit</xex> is the wider term. It denotes any
authorized <xex>ex parte</xex> written statement of a person, sworn to
or affirmed before some competent magistrate. It is made without
cross-examination, and requires no notice to an opposing party. It is
generally signed by the party making it, and may be drawn up by himself
or any other person. A <xex>deposition</xex> is the written testimony of
a witness, taken down in due form of law, and sworn to or affirmed by
the deponent. It must be taken before some authorized magistrate, and
upon a prescribed or reasonable notice to the opposing party, that may
attend and cross-examine. It is generally written down from the mouth of
the witness by the magistrate, or some person for him, and in his
presence.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depositor</ent><br/
<hw>De*pos"i*tor</hw> <pr>(d<esl/*p<ocr/z"<icr/*t<etil/r)</pr>,
<pos>n.</pos> <ety>[L., fr. <ets>deponere</ets>. See
<er>Depone</er>.]</ety> <def>One who makes a deposit, especially of
money in a bank; -- the correlative of <inv>depository</inv>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depository</ent><br/
<hw>De*pos"i*to*ry</hw> <pr>(-t<osl/*r<ycr/)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Depositories</plw> <pr>(-r<icr/z)</pr>.</plu>
<sn>1.</sn> <def>A place where anything is deposited for sale or
keeping; <as>as, warehouse is a <ex>depository</ex> for goods; a clerk's
office is a <ex>depository</ex> for records.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One with whom something is deposited; a
depositary.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I am the sole <qex>depository</qex> of my own secret, and it shall
perish with me.</q> <rj><qau>Junius.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depositum</ent><br/
\'d8<hw>De*pos"i*tum</hw> <pr>(-t<ucr/m)</pr>, <pos>n.</pos>
<ety>[L.]</ety> <def>Deposit.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depositure</ent><br/
<hw>De*pos"i*ture</hw> <pr>(-t<usl/r; 135)</pr>, <pos>n.</pos> <def>The
act of depositing; deposition.</def> <mark>[Obs.]</mark> <rj><au>Sir T.
Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depot</ent><br/
<hw>De"pot</hw> <pr>(d<emac/"p<osl/; <it>French</it> d<asl/*p<omac/";
277)</pr>, <pos>n.</pos> <ety>[F. <ets>d<eacute/p<ocir/t</ets>, OF.
<ets>depost</ets>, fr. L. <ets>depositum</ets> a deposit. See
<er>Deposit</er>, <pos>n.</pos>]</ety> <sn>1.</sn> <def>A place of
deposit for the storing of goods; a warehouse; a storehouse.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The islands of Guernsey and Jersey are at present the great
<qex>depots</qex> of this kingdom.</q> <rj><qau>Brit. Critic
(1794).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mil.)</fld> <sd>(a)</sd> <def>A military station
where stores and provisions are kept, or where recruits are assembled
and drilled.</def> <sd>(b)</sd> <fld>(Eng. & France)</fld> <def>The
headquarters of a regiment, where all supplies are received and
distributed, recruits are assembled and instructed, infirm or disabled
soldiers are taken care of, and all the wants of the regiment are
provided for.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A railway station; a building for the accommodation
and protection of railway passengers or freight.</def> <mark>[U.
S.]</mark></p>

<p><syn><b>Syn.</b> -- See <er>Station</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depper</ent><br/
<hw>Dep"per</hw> <pr>(d<ecr/p"p<etil/r)</pr>, <pos>a.</pos>
<def>Deeper.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depravation</ent><br/
<hw>Dep`ra*va"tion</hw> <pr>(d<ecr/p`r<adot/*v<amac/"sh<ucr/n)</pr>,
<pos>n.</pos> <ety>[L. <ets>depravitio</ets>, from depravare: cf. F.
<ets>d<eacute/pravation</ets>. See <er>Deprave</er>.]</ety> <sn>1.</sn>
<def>Detraction; depreciation.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>To stubborn critics, apt, without a theme,<br/
For <qex>depravation</qex>.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The act of depraving, or making anything bad; the
act of corrupting.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The state of being depraved or degenerated;
degeneracy; depravity.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>depravation</qex> of his moral character destroyed his
judgment.</q> <rj><qau>Sir G. C. Lewis.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Med.)</fld> <def>Change for the worse;
deterioration; morbid perversion.</def></p>

<p><syn><b>Syn.</b> -- Depravity; corruption. See
<er>Depravity</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deprave</ent><br/
<hw>De*prave"</hw> <pr>(d<esl/*pr<amac/v")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Depraved</conjf>
<pr>(d<esl/*pr<amac/vd")</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Depraving</conjf>.]</vmorph> <ety>[L. <ets>depravare</ets>,
<ets>depravatum</ets>; <ets>de-</ets> + <ets>pravus</ets> crooked,
distorted, perverse, wicked.]</ety> <sn>1.</sn> <def>To speak ill of; to
depreciate; to malign; to revile.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>And thou knowest, conscience, I came not to chide<br/
Nor <qex>deprave</qex> thy person with a proud heart.</q> <rj><qau>Piers
Plowman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To make bad or worse; to vitiate; to
corrupt.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Whose pride <qex>depraves</qex> each other better part.</q>
<rj><qau>Spenser.</qau></rj></p>

<p><syn><b>Syn.</b> -- To corrupt; vitiate; contaminate;
pollute.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depravedly</ent><br/
<hw>De*prav"ed*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a depraved
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depravedness</ent><br/
<hw>De*prav"ed*ness</hw>, <pos>n.</pos> <def>Depravity.</def>
<rj><au>Hammond.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depravement</ent><br/
<hw>De*prave"ment</hw> <pr>(d<esl/*pr<amac/v"m<eit/nt)</pr>,
<pos>n.</pos> <def>Depravity.</def> <mark>[Obs.]</mark>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depraver</ent><br/
<hw>De*prav"er</hw> <pr>(d<esl/*pr<amac/v"<etil/r)</pr>, <pos>n.</pos>
<def>One who depraves or corrupts.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depravingly</ent><br/
<hw>De*prav"ing*ly</hw>, <pos>adv.</pos> <def>In a depraving
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depravity</ent><br/
<hw>De*prav"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<er>Deprave</er>: cf. L. <ets>pravitas</ets> crookedness,
perverseness.]</ety> <def>The state of being depraved or corrupted; a
vitiated state of moral character; general badness of character;
wickedness of mind or heart; absence of religious feeling and
principle.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Total depravity</b></col>. <cd>See <er>Original sin</er>,
and <er>Calvinism</er>.</cd></cs></p>

<p><syn><b>Syn.</b> -- Corruption; vitiation; wickedness; vice;
contamination; degeneracy.</syn> <usage> -- <er>Depravity</er>,
<er>Depravation</er>, <er>Corruption</er>. <xex>Depravilty</xex> is a
vitiated state of mind or feeling; as, the <xex>depravity</xex> of the
human heart; <xex>depravity</xex> of public morals.
<xex>Depravation</xex> points to the act or process of <xex>making</xex>
depraved, and hence to the end thus reached; as, a gradual
<xex>depravation</xex> of principle; a <xex>depravation</xex> of
manners, of the heart, etc. <xex>Corruption</xex> is the only one of
these words which applies to physical substances, and in reference to
these denotes the process by which their component parts are dissolved.
Hence, when figuratively used, it denotes an utter vitiation of
principle or feeling. <xex>Depravity</xex> applies only to the mind and
heart: we can speak of a <xex>depraved</xex> taste, or a
<xex>corrupt</xex> taste; in the first we introduce the notion that
there has been the influence of bad training to pervert; in the second,
that there is a want of true principle to pervert; in the second, that
there is a want of true principles to decide. The other two words have a
wider use: we can speak of the <xex>depravation</xex> or the
<xex>corruption</xex> of taste and public sentiment.
<xex>Depravity</xex> is more or less open; corruption is more or less
disguised in its operations. What is <xex>depraved</xex> requires to be
reformed; what is <xex>corrupt</xex> requires to be
purified.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>deprecable</ent><br/
<hw>dep"re*ca*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>deprecabilis</ets> exorable.]</ety> <def>That may or should be
deprecated.</def> <rj><au>Paley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>deprecate</ent><br/
<hw>dep"re*cate</hw> <pr>(d<ecr/p"r<esl/*k<amac/t)</pr>, <pos>v.
t.</pos> <vmorph>[<pos>imp. & p. p.</pos> <conjf>Deprecated</conjf>
<pr>(-k<amac/`t<ecr/d)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Deprecating</conjf> <pr>(-k<amac/`t<icr/ng)</pr>.]</vmorph>
<ety>[L. <ets>deprecatus</ets>, p. p. of <ets>deprecari</ets> to avert
by prayer, to deprecate; <ets>de-</ets> + <ets>precari</ets> to pray.
See <er>Pray</er>.]</ety> <def>To pray against, as an evil; to seek to
avert by prayer; to seek deliverance from; to express deep regret for;
to desire the removal of.</def> <mark>[archaic]</mark> <br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To protest against; to advance reasons
against.</def><br/
[<source>PJC</source>]</p>

<p><q>His purpose was <qex>deprecated</qex> by all round him, and he was
with difficulty induced to adandon it.</q> <rj><qau>Sir W.
Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To disapprove of strongly; to express a low opinion
of.</def><br/
[<source>PJC</source>]</p>

<p><ent>Deprecatingly</ent><br/
<hw>Dep"re*ca`ting*ly</hw> <pr>(-k<amac/`t<icr/ng*l<ycr/)</pr>,
<pos>adv.</pos> <def>In a deprecating manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deprecation</ent><br/
<hw>Dep`re*ca"tion</hw> <pr>(d<ecr/p`r<esl/*k<amac/"sh<ucr/n)</pr>,
<pos>n.</pos> <ety>[L. <ets>deprecatio</ets>; cf. F.
<ets>d<eacute/pr<eacute/cation</ets>.]</ety> <sn>1.</sn> <def>The act of
deprecating; a praying against evil; prayer that an evil may be removed
or prevented.</def> <mark>[archaic]</mark> <br/
[<source>1913 Webster</source>]</p>

<p><q>Humble <qex>deprecation</qex>.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Entreaty for pardon; petitioning.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>An imprecation or curse.</def> <mark>[Obs.]</mark>
<rj><au>Gilpin.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A strong expression of disapprobation; an expression
of a low opinion.</def><br/
[<source>PJC</source>]</p>

<p><ent>Deprecative</ent><br/
<hw>Dep"re*ca*tive</hw> <pr>(d<ecr/p"r<esl/*k<asl/*t<icr/v)</pr>,
<pos>a.</pos> <ety>[L. <ets>deprecativus</ets>: cf. F.
<ets>d<eacute/pr<eacute/catif</ets>.]</ety> <def>Serving to deprecate;
deprecatory.</def><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn. --</b> belittling, derogatory, pejorative, disparaging,
depreciative, deprecatory, depreciatory, detractive, detracting,
slighting, denigratory, uncomplimentary.</syn><br/
[<source>PJC</source>]</p>

<p>-- <wordforms><wf>Dep"re*ca*tive*ly</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deprecator</ent><br/
<hw>Dep"re*ca`tor</hw> <pr>(d<ecr/p"r<esl/*k<amac/`t<etil/r)</pr>,
<pos>n.</pos> <ety>[L.]</ety> <def>One who deprecates.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>deprecatory</ent><br/
<hw>dep"re*ca*to*ry</hw>
<pr>(d<ecr/p"r<esl/*k<adot/*t<osl/*r<ycr/)</pr>, <pos>a.</pos> <ety>[L.
<ets>deprecatorius</ets>.]</ety> <sn>1.</sn> <def>Tending to remove or
avert evil by prayer; apologetic.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Humble and <qex>deprecatory</qex> letters.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Serving to deprecate; expressing a low opinion
of.</def><br/
<syn><b>Syn. --</b> belittling, disparaging, depreciative, deprecatory,
depreciatory, derogatory, detractive, detracting, slighting, pejorative,
denigratory.</syn><br/
[<source>PJC</source>]</p>

<p><ent>Depreciate</ent><br/
<hw>De*pre"ci*ate</hw> <pr>(d<esl/*pr<emac/"sh<icr/*<amac/t)</pr>,
<pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Depreciated</conjf>
<pr>(d<esl/*pr<emac/"sh<icr/*<amac/`t<ecr/d)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Depreciating</conjf>
<pr>(d<esl/*pr<emac/"sh<icr/*<amac/`t<icr/ng)</pr>.]</vmorph> <ety>[L.
<ets>depretiatus</ets>, <ets>depreciatus</ets>, p. p. of
<ets>depretiare</ets>, <ets>-ciare</ets>, to depreciate; <ets>de-</ets>
+ <ets>pretiare</ets> to prize, fr. <ets>pretium</ets> price. See
<er>Price</er>.]</ety> <def>To lessen in price or estimated value; to
lower the worth of; to represent as of little value or claim to esteem;
to undervalue.</def> <rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Which . . . some over-severe philosophers may look upon
fastidiously, or undervalue and <qex>depreciate</qex>.</q>
<rj><qau>Cudworth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To prove that the Americans ought not to be free, we are obliged
to <qex>depreciate</qex> the value of freedom itself.</q>
<rj><qau>Burke.</qau></rj></p>

<p><syn><b>Syn.</b> -- To decry; disparage; traduce; lower; detract;
underrate. See <er>Decry</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depreciate</ent><br/
<hw>De*pre"ci*ate</hw>, <pos>v. i.</pos> <def>To fall in value; to
become of less worth; to sink in estimation; <as>as, a paper currency
will <ex>depreciate</ex>, unless it is convertible into
specie</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depreciation</ent><br/
<hw>De*pre`ci*a"tion</hw>
<pr>(d<esl/*pr<emac/`sh<icr/*<amac/"sh<ucr/n)</pr>, <pos>n.</pos>
<ety>[Cf. F. <ets>d<eacute/pr<eacute/ciation</ets>.]</ety> <sn>1.</sn>
<def>The act of lessening, or seeking to lessen, price, value, or
reputation.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The falling of value; reduction of worth.</def>
<rj><au>Burke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>the state of being depreciated.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depreciative</ent><br/
<hw>De*pre"ci*a`tive</hw> <pr>(d<esl/*pr<emac/"sh<icr/*<amac/`t<icr/v
<it>or</it> d<esl/*pr<emac/"sh<adot/*t<icr/v)</pr>, <pos>a.</pos>
<def>Tending, or intended, to depreciate; expressing depreciation;
undervaluing.</def> -- <wordforms><wf>De*pre"ci*a`tive*ly</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depreciator</ent><br/
<hw>De*pre"ci*a`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.]</ety>
<def>One who depreciates.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depreciatory</ent><br/
<hw>De*pre"ci*a*to*ry</hw>
<pr>(d<esl/*pr<emac/"sh<icr/*<adot/*t<osl/*r<ycr/ <it>or</it>
d<esl/*pr<emac/"sh<adot/*t<osl/*r<ycr/)</pr>, <pos>a.</pos> <def>Tending
to depreciate; undervaluing; depreciative.</def><br/
<syn><b>Syn. --</b> belittling, depreciative, deprecatory, depreciatory,
derogatory, detractive, detracting, slighting, pejorative,
denigratory.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depredable</ent><br/
<hw>Dep"re*da*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Liable to
depredation.</def> <mark>[Obs.]</mark> <ldquo/Made less
<xex>depredable</xex>.<rdquo/ <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depredate</ent><br/
<hw>Dep"re*date</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Depredated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Depredating</conjf> <pr>(?)</pr>.]</vmorph> <ety>[L.
<ets>depraedatus</ets>, p. p. of <ets>depraedari</ets> to plunder;
<ets>de-</ets> + <ets>praedari</ets> to plunder, <ets>praeda</ets>
plunder, prey. See <er>Prey</er>.]</ety> <def>To subject to plunder and
pillage; to despoil; to lay waste; to prey upon.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It makes the substance of the body . . . less apt to be consumed
and <qex>depredated</qex> by the spirits.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depredate</ent><br/
<hw>Dep"re*date</hw>, <pos>v. i.</pos> <def>To take plunder or prey; to
commit waste; <as>as, the troops <ex>depredated</ex> on the
country</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depredation</ent><br/
<hw>Dep`re*da"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>depraedatio</ets>: cf. F.
<ets>d<eacute/pr<eacute/dation</ets>.]</ety> <def>The act of
depredating, or the state of being depredated; the act of despoiling or
making inroads; <as>as, the sea often makes <ex>depredation</ex> on the
land</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depredator</ent><br/
<hw>Dep"re*da`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>depraedator</ets>.]</ety> <def>One who plunders or pillages; a
spoiler; a robber.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depredatory</ent><br/
<hw>Dep"re*da`to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Tending or
designed to depredate; characterized by depredation; plundering; <as>as,
a <ex>depredatory</ex> incursion</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depredicate</ent><br/
<hw>De*pred"i*cate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>de-</ets> (intensive) + <ets>predicate</ets>.]</ety> <def>To
proclaim; to celebrate.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deprehend</ent><br/
<hw>Dep`re*hend"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Deprehended</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Deprehending</conjf>.]</vmorph> <ety>[L. <ets>deprehendere</ets>,
<ets>deprehensum</ets>; <ets>de-</ets> + <ets>prehendere</ets> to lay
hold of, seize. See <er>Prehensile</er>.]</ety> <sn>1.</sn> <def>To take
unawares or by surprise; to seize, as a person committing an unlawful
act; to catch; to apprehend.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>deprehended</qex> adulteress.Jer.</q>
<rj><qau>Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To detect; to discover; to find out.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The motion . . . are to be <qex>deprehended</qex> by
experience.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deprehensible</ent><br/
<hw>Dep`re*hen"si*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>That may be
caught or discovered; apprehensible.</def> <mark>[Obs.]</mark>
<rj><au>Petty.</au></rj></p>

<p>-- <wordforms><wf>Dep`re*hen"si*ble*ness</wf>, <pos>n.</pos>
<mark>[Obs.]</mark></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deprehension</ent><br/
<hw>Dep`re*hen"sion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>deprehensio</ets>.]</ety> <def>A catching; discovery.</def>
<mark>[Obs.]</mark> <rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depress</ent><br/
<hw>De*press"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Depressed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Depressing</conjf>.]</vmorph> <ety>[L.
<ets>depressus</ets>, p. p. of <ets>deprimere</ets>; <ets>de-</ets> +
<ets>premere</ets> to press. See <er>Press</er>.]</ety> <sn>1.</sn>
<def>To press down; to cause to sink; to let fall; to lower; <as>as, to
<ex>depress</ex> the muzzle of a gun; to <ex>depress</ex> the
eyes.</as></def> <ldquo/With lips <xex>depressed</xex>.<rdquo/
<rj><au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To bring down or humble; to abase, as
pride.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To cast a gloom upon; to sadden; <as>as, his spirits
were <ex>depressed</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To lessen the activity of; to make dull; embarrass,
as trade, commerce, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To lessen in price; to cause to decline in value; to
cheapen; to depreciate.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Math.)</fld> <def>To reduce (an equation) in a
lower degree.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To depress the pole</b></col> <fld>(Naut.)</fld>, <cd>to
cause the sidereal pole to appear lower or nearer the horizon, as by
sailing toward the equator.</cd></cs></p>

<p><syn><b>Syn.</b> -- To sink; lower; abase; cast down; deject; humble;
degrade; dispirit; discourage.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depress</ent><br/
<hw>De*press"</hw>, <pos>a.</pos> <ety>[L. <ets>depressus</ets>, p.
p.]</ety> <def>Having the middle lower than the border; concave.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>If the seal be <qex>depress</qex> or hollow.</q>
<rj><qau>Hammond.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depressant</ent><br/
<hw>De*press"ant</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Med.)</fld>
<def>An agent or remedy which lowers the vital powers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depressed</ent><br/
<hw>De*pressed"</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Pressed or forced down; lowed; sunk; dejected; dispirited; sad;
humbled.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <sd>(a)</sd> <def>Concave on the upper
side; -- said of a leaf whose disk is lower than the border.</def>
<sd>(b)</sd> <def>Lying flat; -- said of a stem or leaf which lies close
to the ground.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <def>Having the vertical diameter
shorter than the horizontal or transverse; -- said of the bodies of
animals, or of parts of the bodies.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depressingly</ent><br/
<hw>De*press"ing*ly</hw>, <pos>adv.</pos> <def>In a depressing
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depression</ent><br/
<hw>De*pres"sion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>depressio</ets>: cf. F. <ets>d<eacute/pression</ets>.]</ety>
<sn>1.</sn> <def>The act of depressing.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The state of being depressed; a sinking.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A falling in of the surface; a sinking below its
true place; a cavity or hollow; <as>as, roughness consists in little
protuberances and <ex>depressions</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Humiliation; abasement, as of pride.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Dejection; despondency; lowness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In a great <qex>depression</qex> of spirit.</q>
<rj><qau>Baker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Diminution, as of trade, etc.; inactivity;
dullness.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Astron.)</fld> <def>The angular distance of a
celestial object below the horizon.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <fld>(Math.)</fld> <def>The operation of reducing to a
lower degree; -- said of equations.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <fld>(Surg.)</fld> <def>A method of operating for
cataract; couching. See <er>Couch</er>, <pos>v. t.</pos>, 8.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Angle of depression</b></col> <fld>(Geod.)</fld>, <cd>one
which a descending line makes with a horizontal plane.</cd> --
<col><b>Depression of the dewpoint</b></col> <fld>(Meteor.)</fld>,
<cd>the number of degrees that the dew-point is lower than the actual
temperature of the atmosphere.</cd> -- <col><b>Depression of the
pole</b></col>, <cd>its apparent sinking, as the spectator goes toward
the equator.</cd> -- <col><b>Depression of the visible
horizon</b></col>. <fld>(Astron.)</fld> <cd>Same as <cref>Dip of the
horizon</cref>, under <er>Dip</er>.</cd></cs></p>

<p><syn><b>Syn.</b> -- Abasement; reduction; sinking; fall; humiliation;
dejection; melancholy.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depressive</ent><br/
<hw>De*press"ive</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Able or tending
to depress or cast down.</def> -- <wordforms><wf>De*press"ive*ness</wf>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depressomotor</ent><br/
<hw>De*pres`so*mo"tor</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Med.)</fld>
<def>Depressing or diminishing the capacity for movement, as
<xex>depressomotor</xex> nerves, which lower or inhibit muscular
activity.</def> -- <def2><pos>n.</pos> <def>Any agent that depresses the
activity of the motor centers, as bromides, etc.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depressor</ent><br/
<hw>De*press"or</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One
who, or that which, presses down; an oppressor.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Anat.)</fld> <def>A muscle that depresses or tends
to draw down a part.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Depressor nerve</b></col> <fld>(Physiol.)</fld>, <cd>a
nerve which lowers the activity of an organ; as, the <xex>depressor
nerve</xex> of the heart.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depriment</ent><br/
<hw>Dep"ri*ment</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>deprimens</ets>, p. pr. of <ets>deprimere</ets>. See
<er>Depress</er>.]</ety> <def>Serving to depress.</def>
<mark>[R.]</mark> <ldquo/<xex>Depriment</xex> muscles.<rdquo/
<rj><au>Derham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deprisure</ent><br/
<hw>De*pri"sure</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>d<eacute/priser</ets> to undervalue; pref. <ets>d<eacute/-</ets>
(L. <ets>dis-</ets>) + <ets>priser</ets> to prize, fr. <ets>prix</ets>
price, fr. L. <ets>pretium</ets>. See <er>Dispraise</er>.]</ety>
<def>Low estimation; disesteem; contempt.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deprivable</ent><br/
<hw>De*priv"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of
being, or liable to be, deprived; liable to be deposed.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Kings of Spain . . . <qex>deprivable</qex> for their
tyrannies.</q> <rj><qau>Prynne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deprivation</ent><br/
<hw>Dep`ri*va"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL.
<ets>deprivatio</ets>.]</ety> <sn>1.</sn> <def>The act of depriving,
dispossessing, or bereaving; the act of deposing or divesting of some
dignity.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The state of being deprived; privation; loss; want;
bereavement.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Eccl. Law)</fld> <def>the taking away from a
clergyman his benefice, or other spiritual promotion or
dignity.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Deprivation</xex> may be <xex>a beneficio</xex> or
<xex>ab officio</xex>; the first takes away the living, the last
degrades and deposes from the order.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deprive</ent><br/
<hw>De*prive"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Deprived</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Depriving</conjf>.]</vmorph> <ety>[LL.
<ets>deprivare</ets>, <ets>deprivatium</ets>, to divest of office; L.
<ets>de-</ets> + <ets>privare</ets> to bereave, deprive: cf. OF.
<ets>depriver</ets>. See <er>Private</er>.]</ety> <sn>1.</sn> <def>To
take away; to put an end; to destroy.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>'Tis honor to deprive <qex>dishonored</qex> life.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To dispossess; to bereave; to divest; to hinder from
possessing; to debar; to shut out from; -- with a remoter object,
usually preceded by of.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>God hath <qex>deprived</qex> her of wisdom.</q> <rj><qau>Job
xxxix. 17.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>It was seldom that anger <qex>deprived</qex> him of power over
himself.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To divest of office; to depose; to dispossess of
dignity, especially ecclesiastical.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A minister <qex>deprived</qex> for inconformity.</q>
<rj><qau>Bacon.</qau></rj></p>

<p><syn><b>Syn.</b> -- To strip; despoil; rob; abridge.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>deprived</ent><br/
<hw>deprived</hw> <pos>adj.</pos> <def>marked by deprivation especially
of the necessities of life or healthful environmental or social
influences; <as>as, a childhood that was unhappy and <ex>deprived</ex>,
the family living off charity; boys from a <ex>deprived</ex>
environment, wherein the family life revealed a pattern of neglect,
moral degradation, and disregard for law</as>.</def><br/
<syn><b>Syn. --</b> disadvantaged.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Deprivement</ent><br/
<hw>De*prive"ment</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Deprivation.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depriver</ent><br/
<hw>De*priv"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, deprives.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deprostrate</ent><br/
<hw>De*pros"trate</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Fully prostrate;
humble; low; rude.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>How may weak mortal ever hope to file<br/
His unsmooth tongue, and his <qex>deprostrate</qex> style.</q>
<rj><qau>G. Fletcher.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deprovincialize</ent><br/
<hw>De`pro*vin"cial*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To
divest of provincial quality or characteristics.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depth</ent><br/
<hw>Depth</hw> <pr>(s<ecr/pth)</pr>, <pos>n.</pos> <ety>[From
<er>Deep</er>; akin to D. <ets>diepte</ets>, Icel. <ets>d<ymac/pt</ets>,
<ets>d<ymac/p<edh/</ets>, Goth. <ets>diupi<thorn/a</ets>.]</ety>
<sn>1.</sn> <def>The quality of being deep; deepness; perpendicular
measurement downward from the surface, or horizontal measurement
backward from the front; <as>as, the <ex>depth</ex> of a river; the
<ex>depth</ex> of a body of troops.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Profoundness; extent or degree of intensity;
abundance; completeness; <as>as, <ex>depth</ex> of knowledge, or
color</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Mindful of that heavenly love<br/
Which knows no end in <qex>depth</qex> or height.</q>
<rj><qau>Keble.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Lowness; <as>as, <ex>depth</ex> of
sound</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>That which is deep; a deep, or the deepest, part or
place; the deep; the middle part; <as>as, the <ex>depth</ex> of night,
or of winter</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>From you unclouded <qex>depth</qex> above.</q>
<rj><qau>Keble.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>depth</qex> closed me round about.</q> <rj><qau>Jonah ii.
5.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Logic)</fld> <def>The number of simple elements
which an abstract conception or notion includes; the comprehension or
content.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Horology)</fld> <def>A pair of toothed wheels which
work together.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 395 --></p>

<p><sn>7.</sn> <fld>(A<eum/ronautics)</fld> <def>The perpendicular
distance from the chord to the farthest point of an arched
surface.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>8.</sn> <fld>(Computers)</fld> <def>the maximum number of times a
type of procedure is reiteratively called before the last call is
exited; -- of subroutines or procedures which are reentrant; -- used of
call stacks.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Depth of a sail</b></col> <fld>(Naut.)</fld>, <cd>the
extent of a square sail from the head rope to the foot rope; the length
of the after leach of a staysail or boom sail; -- commonly called the
<altname>drop of a sail</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depthen</ent><br/
<hw>Depth"en</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To deepen.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depthless</ent><br/
<hw>Depth"less</hw>, <pos>a.</pos> <sn>1.</sn> <def>Having no depth;
shallow.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of measureless depth; unfathomable.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In clouds of <qex>depthless</qex> night.</q>
<rj><qau>Francis.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depucelate</ent><br/
<hw>De*pu"ce*late</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>de</ets> + LL. <ets>pucella</ets> virgin, F. <ets>pucelle</ets>:
cf. F. <ets>d<eacute/puceler</ets>.]</ety> <def>To deflour; to deprive
of virginity.</def> <mark>[Obs.]</mark> <rj><au>Bailey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depudicate</ent><br/
<hw>De*pu"di*cate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>depudicatus</ets>, p. p. of <ets>depudicare</ets>.]</ety> <def>To
deflour; to dishonor.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depulse</ent><br/
<hw>De*pulse"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>depulsus</ets>, p. p. of <ets>depellere</ets> to drive out;
<ets>de-</ets> + <ets>pellere</ets> to drive.]</ety> <def>To drive
away.</def> <mark>[Obs.]</mark> <rj><au>Cockeram.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depulsion</ent><br/
<hw>De*pul"sion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>depulsio</ets>.]</ety> <def>A driving or thrusting away.</def>
<mark>[R.]</mark> <rj><au>Speed.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depulsory</ent><br/
<hw>De*pul"so*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>depulsorius</ets>.]</ety> <def>Driving or thrusting away;
averting.</def> <mark>[R.]</mark> <rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depurant</ent><br/
<hw>Dep"u*rant</hw> <pr>(?)</pr>, <pos>a. & n.</pos> <fld>(Med.)</fld>
<def>Depurative.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depurate</ent><br/
<hw>Dep"u*rate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[LL.
<ets>depuratus</ets>, p. p. of <ets>depurare</ets> to purify; L.
<ets>de-</ets> + <ets>purare</ets> to purify, <ets>purus</ets> clean,
pure. Cf. <er>Depure</er>.]</ety> <def>Depurated; cleansed; freed from
impurities.</def> <rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depurate</ent><br/
<hw>Dep"u*rate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Depurated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Depurating</conjf> <pr>(?)</pr>.]</vmorph> <def>To free
from impurities, heterogeneous matter, or feculence; to purify; to
cleanse.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>depurate</qex> the mass of blood.</q>
<rj><qau>Boyle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depuration</ent><br/
<hw>Dep`u*ra"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>d<eacute/puration</ets>.]</ety> <def>The act or process of
depurating or freeing from foreign or impure matter, as a liquid or
wound.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depurative</ent><br/
<hw>Dep"u*ra*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>d<eacute/puratif</ets>.]</ety> <fld>(Med.)</fld> <def>Purifying the
blood or the humors; depuratory.</def> -- <def2><pos>n.</pos> <def>A
depurative remedy or agent; or a disease which is believed to be
depurative.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depurator</ent><br/
<hw>Dep"u*ra`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, cleanses.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depuratory</ent><br/
<hw>Dep"u*ra*to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>d<eacute/puratoire</ets>.]</ety> <def>Depurating; tending to
depurate or cleanse; depurative.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depure</ent><br/
<hw>De*pure"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[F.
<ets>d<eacute/purer</ets>. See <er>Depurate</er>.]</ety> <def>To
depurate; to purify.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He shall first be <qex>depured</qex> and cleansed before that he
shall be laid up for pure gold in the treasures of God.</q> <rj><qau>Sir
T. More.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depurgatory</ent><br/
<hw>De*pur"ga*to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Serving to
purge; tending to cleanse or purify.</def> <mark>[Obs.]</mark>
<rj><au>Cotgrave.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depurition</ent><br/
<hw>Dep`u*ri"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Depuration</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deputable</ent><br/
<hw>Dep"u*ta*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Fit to be
deputed; suitable to act as a deputy.</def>
<rj><au>Carlyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deputation</ent><br/
<hw>Dep`u*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>d<eacute/putation</ets>. See <er>Depute</er>.]</ety> <sn>1.</sn>
<def>The act of deputing, or of appointing or commissioning a deputy or
representative; office of a deputy or delegate; vicegerency.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The authority of conscience stands founded upon its vicegerency
and <qex>deputation</qex> under God.</q> <rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The person or persons deputed or commissioned by
another person, party, or public body to act in his or its behalf;
delegation; <as>as, the general sent a <ex>deputation</ex> to the enemy
to propose a truce</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>By deputation</b></col>, or <col><b>In
deputation</b></col></mcol>, <cd>by delegated authority; as substitute;
through the medium of a deputy.</cd> <mark>[Obs.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><q>Say to great C<ae/sar this: <qex>In deputation</qex><br/
I kiss his conquering hand.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deputator</ent><br/
<hw>Dep"u*ta`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who deputes,
or makes a deputation.</def> <mark>[R.]</mark>
<rj><au>Locke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depute</ent><br/
<hw>De*pute"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Deputed</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Deputing</conjf>.]</vmorph> <ety>[F. <ets>d<eacute/puter</ets>,
fr. L. <ets>deputare</ets> to esteem, consider, in LL., to destine,
allot; <ets>de-</ets> + <ets>putare</ets> to clean, prune, clear up, set
in order, reckon, think. See <er>Pure</er>.]</ety> <sn>1.</sn> <def>To
appoint as deputy or agent; to commission to act in one's place; to
delegate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There is no man <qex>deputed</qex> of the king to hear thee.</q>
<rj><qau>2. Sam. xv. 3.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Some persons, <qex>deputed</qex> by a meeting.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To appoint; to assign; to choose.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The most conspicuous places in cities are usually
<qex>deputed</qex> for the erection of statues.</q>
<rj><qau>Barrow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Depute</ent><br/
<hw>De*pute"</hw>, <pos>n.</pos> <def>A person deputed; a deputy.</def>
<mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>deputise</ent><br/
<hw>dep"u*tise</hw> <pr>(d<ecr/p"<usl/*t<imac/z)</pr>, <pos>v. t.</pos>
<def>same as <er>deputize</er>.</def><br/
<syn><b>Syn. --</b> depute, deputize.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>deputize</ent><br/
<hw>dep"u*tize</hw> <pr>(d<ecr/p"<usl/*t<imac/z)</pr>, <pos>v. t.</pos>
<def>To appoint as one's deputy; to empower to act in one's stead; to
appoint as one's substitute; to depute.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>deputy</ent><br/
<hw>dep"u*ty</hw> <pr>(d<ecr/p"<usl/*t<ycr/)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Deputies</plw>
<pr>(d<ecr/p"<usl/*t<icr/z)</pr>.</plu> <ety>[F.
<ets>d<eacute/put<eacute/</ets>, fr. LL. <ets>deputatus</ets>. See
<er>Depute</er>.]</ety> <sn>1.</sn> <def>One appointed as the substitute
of another, and empowered to act for him, in his name or his behalf; a
substitute in office; a lieutenant; a representative; a delegate; a
vicegerent; <as>as, the <ex>deputy</ex> of a prince, of a sheriff, of a
township, etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>There was then [in the days of Jehoshaphat] no king in Edom; a
<qex>deputy</qex> was king.</q> <rj><qau>1 Kings xxii.
47.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>God's substitute,<br/
His <qex>deputy</qex> anointed in His sight.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Deputy</xex> is used in combination with the names
of various executive officers, to denote an assistant empowered to act
in their name; as, <xex>deputy</xex> collector, <xex>deputy</xex>
marshal, <xex>deputy</xex> sheriff.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A member of the Chamber of Deputies.</def>
<mark>[France]</mark><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Chamber of Deputies</b></col>, <cd>one of the two
branches of the French legislative assembly; -- formerly called
<altname>Corps L<eacute/gislatif</altname>. Its members, called
<member>deputies</member>, are elected by the people voting in
districts.</cd></cs></p>

<p><syn><b>Syn.</b> -- Substitute; representative; legate; delegate;
envoy; agent; factor.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dequantitate</ent><br/
<hw>De*quan"ti*tate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>de-</ets> + <ets>quantitas</ets>, <ets>-atis</ets>. See
<er>Quantity</er>.]</ety> <def>To diminish the quantity of; to
disquantity.</def> <mark>[Obs.]</mark> <rj><au>Sir T.
Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dequeen</ent><br/
<hw>De*queen"</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<fld>(Apiculture)</fld> <def>To remove the queen from (a hive of
bees).</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Deracinate</ent><br/
<hw>De*rac"i*nate</hw> <pr>(d<esl/*r<acr/s"<icr/*n<amac/t)</pr>, <pos>v.
t.</pos> <vmorph>[<pos>imp. & p. p.</pos> <conjf>Deracinated</conjf>
<pr>(d<esl/*r<acr/s"<icr/*n<amac/`t<ecr/d)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Deracinating</conjf>
<pr>(d<esl/*r<acr/s"<icr/*n<amac/`t<icr/ng)</pr>.]</vmorph> <ety>[F.
<ets>d<eacute/raciner</ets>; pref. <ets>d<eacute/-</ets> (L.
<ets>dis</ets>) + <ets>racine</ets> root, fr. an assumed LL.
<ets>radicina</ets>, fr. L. <ets>radix</ets>, <ets>radicis</ets>,
root.]</ety> <def>To pluck up by the roots; to extirpate.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>While that the colter rusts<br/
That should <qex>deracinate</qex> such savagery.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deracination</ent><br/
<hw>De*rac`i*na"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
pulling up by the roots; eradication.</def> <mark>[R.]</mark></p>

<p><ent>Derain</ent><br/
<ent>Deraign</ent><br/
<mhw>{ <hw>De*raign"</hw>, <hw>De*rain"</hw> }</mhw> <pr>(?)</pr>,
<pos>v. t.</pos> <ety>[See <er>Darraign</er>.]</ety> <fld>(Old
Law)</fld> <def>To prove or to refute by proof; to clear (one's
self).</def> <mark>[Obs.]</mark></p>

<p><ent>Derainment</ent><br/
<ent>Deraignment</ent><br/
<mhw>{ <hw>De*raign"ment</hw>, <hw>De*rain"ment</hw> }</mhw>
<pr>(?)</pr>, <pos>n.</pos> <ety>[See <er>Darraign</er>.]</ety>
<sn>1.</sn> <def>The act of deraigning.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The renunciation of religious or monastic
vows.</def> <mark>[Obs.]</mark> <rj><au>Blount.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Derail</ent><br/
<hw>De*rail"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Derailed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Derailing</conjf>.]</vmorph> <def>To cause to run off
from the rails of a railroad, as a locomotive.</def>
<rj><au>Lardner.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Derailment</ent><br/
<hw>De*rail"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of going
off, or the state of being off, the rails of a railroad.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Derange</ent><br/
<hw>De*range"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Deranged</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Deranging</conjf>.]</vmorph> <ety>[F.
<ets>d<eacute/ranger</ets>; pref. <ets>d<eacute/-</ets> =
<ets>d<eacute/s-</ets> (L. <ets>dis</ets>) + <ets>ranger</ets> to range.
See <er>Range</er>, and cf. <er>Disarrange</er>,
<er>Disrank</er>.]</ety> <sn>1.</sn> <def>To put out of place, order, or
rank; to disturb the proper arrangement or order of; to throw into
disorder, confusion, or embarrassment; to disorder; to disarrange;
<as>as, to <ex>derange</ex> the plans of a commander, or the affairs of
a nation</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To disturb in action or function, as a part or
organ, or the whole of a machine or organism.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A sudden fall <qex>deranges</qex> some of our internal parts.</q>
<rj><qau>Blair.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To disturb in the orderly or normal action of the
intellect; to render insane.</def></p>

<p><syn><b>Syn.</b> -- To disorder; disarrange; displace; unsettle;
disturb; confuse; discompose; ruffle; disconcert.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deranged</ent><br/
<hw>De*ranged"</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Disordered;
especially, disordered in mind; crazy; insane.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The story of a poor <qex>deranged</qex> parish lad.</q>
<rj><qau>Lamb.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Derangement</ent><br/
<hw>De*range"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>d<eacute/rangement</ets>.]</ety> <def>The act of deranging or
putting out of order, or the state of being deranged; disarrangement;
disorder; confusion; especially, mental disorder; insanity.</def></p>

<p><syn><b>Syn.</b> -- Disorder; confusion; embarrassment; irregularity;
disturbance; insanity; lunacy; madness; delirium; mania. See
<er>Insanity</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deranger</ent><br/
<hw>De*ran"ger</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
deranges.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deray</ent><br/
<hw>De*ray"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>derroi</ets>, <ets>desroi</ets>, <ets>desrei</ets>; pref.
<ets>des-</ets> (L. <ets>dis-</ets>) + <ets>roi</ets>, <ets>rei</ets>,
<ets>rai</ets>, order. See <er>Array</er>.]</ety> <def>Disorder;
merriment.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Derbio</ent><br/
\'d8<hw>Der"bi*o</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>A large European food fish (<spn>Lichia glauca</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Derby</ent><br/
<hw>Der"by</hw> <pr>(?; <it>usually</it> ? <it>in Eng.</it>; 85)</pr>,
<pos>n.</pos> <sn>1.</sn> <def>A race for three-old horses, run annually
at Epsom (near London), for the Derby stakes. It was instituted by the
12th Earl of Derby, in 1780.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Derby Day</b></col>, <cd>the day of the annual race for
the Derby stakes, -- Wednesday of the week before
Whitsuntide.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A stiff felt hat with a dome-shaped crown.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Derbyshire spar</ent><br/
<hw>Der"by*shire spar"</hw> <pr>(?)</pr>. <fld>(Min.)</fld> <def>A
massive variety of fluor spar, found in Derbyshire, England, and wrought
into vases and other ornamental work.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Derdoing</ent><br/
<hw>Der*do"ing</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See <er>Dere</er>,
<pos>v. t.</pos>]</ety> <def>Doing daring or chivalrous deeds.</def>
<mark>[Obs.]</mark> <ldquo/In <xex>derdoing</xex> arms.<rdquo/
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dere</ent><br/
<hw>Dere</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[AS. <ets>derian</ets>
to hurt.]</ety> <def>To hurt; to harm; to injure.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dere</ent><br/
<hw>Dere</hw>, <pos>n.</pos> <def>Harm.</def> <mark>[Obs.]</mark>
<rj><au>Robert of Brunne.</au></rj></p>

<p><ent>Derecho</ent><br/
<hw>De*re"cho</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sp.
<ets>derecho</ets> straight.]</ety> <def>A straight wind without
apparent cyclonic tendency, usually accompanied with rain and often
destructive, common in the prairie regions of the United
States.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Dereyne</ent><br/
<ent>Dereine</ent><br/
<mhw>{ <hw>De*reine</hw>, <hw>De*reyne"</hw> <pr>(?)</pr> }</mhw>,
<pos>v. t.</pos> <def>Same as <er>Darraign</er>.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Derelict</ent><br/
<hw>Der"e*lict</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>derelictus</ets>, p. p. of <ets>derelinquere</ets> to forsake
wholly, to abandon; <ets>de-</ets> + <ets>relinquere</ets> to leave. See
<er>Relinquish</er>.]</ety> <sn>1.</sn> <def>Given up or forsaken by the
natural owner or guardian; left and abandoned; <as>as, <ex>derelict</ex>
lands</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The affections which these exposed or <qex>derelict</qex> children
bear to their mothers, have no grounds of nature or assiduity but
civility and opinion.</q> <rj><au>Jer. Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Lost; adrift; hence, wanting; careless; neglectful;
unfaithful.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They easily prevailed, so as to seize upon the vacant, unoccupied,
and <qex>derelict</qex> minds of his [Chatham's] friends; and instantly
they turned the vessel wholly out of the course of his policy.</q>
<rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A government which is either unable or unwilling to redress such
wrongs is <qex>derelict</qex> to its highest duties.</q> <rj><qau>J.
Buchanan.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Derelict</ent><br/
<hw>Der"e*lict</hw>, <pos>n.</pos> <fld>(Law)</fld> <sd>(a)</sd> <def>A
thing voluntary abandoned or willfully cast away by its proper owner,
especially a ship abandoned at sea.</def> <sd>(b)</sd> <def>A tract of
land left dry by the sea, and fit for cultivation or use.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dereliction</ent><br/
<hw>Der`e*lic"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>derelictio</ets>.]</ety> <sn>1.</sn> <def>The act of leaving with
an intention not to reclaim or resume; an utter forsaking
abandonment.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Cession or <qex>dereliction</qex>, actual or tacit, of other
powers.</q> <rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A neglect or omission as if by willful
abandonment.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A total <qex>dereliction</qex> of military duties.</q>
<rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The state of being left or abandoned.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Law)</fld> <def>A retiring of the sea, occasioning
a change of high-water mark, whereby land is gained.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dereligionize</ent><br/
<hw>De`re*li"gion*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To make
irreligious; to turn from religion.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He would <qex>dereligionize</qex> men beyond all others.</q>
<rj><qau>De Quincey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dereling</ent><br/
<hw>Dere"ling</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Darling.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dereling</ent><br/
<hw>Dere"ling</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Darling.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dereplication</ent><br/
<hw>De`rep*li*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Biochem.)</fld> <def>the process of testing samples of mixtures
which are <b>active</b> in a screening process, so as to recognize and
eliminate from consideration those active substances already studied; --
a stage subsequent to the preliminary screening in the process of
discovery of new pharmacologically active substances in mixtures of
natural products; -- also called <altname>counterscreening</altname>.
See <er>screening</er>.</def> <note>In the process of pharmaceutical
screening (testing a large number of substances to find those having
desirable pharmacological activity), the testing of samples of
substances extracted from living organisms (plants, microorganisms,
etc.) often detects substances already detected in prior screening. Such
<ldquo/known<rdquo/ or <ldquo/replicate<rdquo/ activities must be
recognized at an early stage to avoid duplicating previous efforts at
purification and structural identification. The process of testing an
sample which is active in a primary screen, to determine if the activity
is due to a previously known substance, is called <ex>dereplication</ex>
or <ex>counterscreening</ex>.</note><br/
[<source>PJC</source>]</p>

<p><ent>Derf</ent><br/
<hw>Derf</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Icel.
<ets>djafr</ets>.]</ety> <def>Strong; powerful; fierce.</def>
<mark>[Obs.]</mark> -- <wordforms><wf>Derf"ly</wf>, <pos>adv.</pos>
<mark>[Obs.]</mark></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deride</ent><br/
<hw>De*ride"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Derided</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Deriding</conjf>.]</vmorph> <ety>[L. <ets>deridere</ets>,
<ets>derisum</ets>; <ets>de-</ets> + <ets>r<imac/d<emac/re</ets> to
laugh. See <er>Ridicule</er>.]</ety> <def>To laugh at with contempt; to
laugh to scorn; to turn to ridicule or make sport of; to mock; to scoff
at.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And the Pharisees, also, . . . <qex>derided</qex> him.</q>
<rj><qau>Luke xvi. 14.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Sport that wrinkled Care <qex>derides</qex>.<br/
And Laughter holding both his sides.</q> <rj><qau>Milton.</qau></rj></p>

<p><syn><b>Syn.</b> -- To mock; laugh at; ridicule; insult; taunt; jeer;
banter; rally.</syn> <usage> -- To <er>Deride</er>, <er>Ridicule</er>,
<er>Mock</er>, <er>Taunt</er>. A man may <xex>ridicule</xex> without any
unkindness of feeling; his object may be to correct; <as>as, to
<ex>ridicule</ex> the follies of the age</as>. He who <xex>derides</xex>
is actuated by a severe a contemptuous spirit; <as>as, to
<ex>deride</ex> one for his religious principles</as>. To
<xex>mock</xex> is stronger, and denotes open and scornful derision;
<as>as, to <ex>mock</ex> at sin</as>. To <xex>taunt</xex> is to reproach
with the keenest insult; <as>as, to <ex>taunt</ex> one for his
misfortunes</as>. <xex>Ridicule</xex> consists more in words than in
actions; <xex>derision</xex> and <xex>mockery</xex> evince themselves in
actions as well as words; <xex>taunts</xex> are always expressed in
words of extreme bitterness.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Derider</ent><br/
<hw>De*rid"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who derides, or
laughs at, another in contempt; a mocker; a scoffer.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deridingly</ent><br/
<hw>De*rid"ing*ly</hw>, <pos>adv.</pos> <def>By way of derision or
mockery.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>De rigueur</ent><br/
\'d8<hw>De ri`gueur"</hw> <pr>(?)</pr>. <ety>[F. See 2d
<er>Rigor</er>.]</ety> <def>According to strictness (of etiquette, rule,
or the like); obligatory; strictly required.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Derision</ent><br/
<hw>De*ri"sion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>derisio</ets>: cf. F. <ets>d<eacute/rision</ets>. See
<er>Deride</er>.]</ety> <sn>1.</sn> <def>The act of deriding, or the
state of being derided; mockery; scornful or contemptuous treatment
which holds one up to ridicule.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He that sitteth in the heavens shall laugh; the Lord shall have
them in <qex>derision</qex>.</q> <rj><qau>Ps. ii. 4.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Satan beheld their plight,<br/
And to his mates thus in <qex>derision</qex> called.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An object of derision or scorn; a
laughing-stock.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I was a <qex>derision</qex> to all my people.</q> <rj><qau>Lam.
iii. 14.</qau></rj></p>

<p><syn><b>Syn.</b> -- Scorn; mockery; contempt; insult;
ridicule.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Derisive</ent><br/
<hw>De*ri"sive</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Expressing, serving
for, or characterized by, derision.</def> <ldquo/<xex>Derisive</xex>
taunts.<rdquo/ <au>Pope.</au> -- <wordforms><wf>De*ri"sive*ly</wf>,
<pos>adv.</pos> -- <wf>De*ri"sive*ness</wf>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Derisory</ent><br/
<hw>De*ri"so*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>derisorius</ets>: cf. F. <ets>d<eacute/risoire</ets>.]</ety>
<def>Derisive; mocking.</def> <rj><au>Shaftesbury.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Derivable</ent><br/
<hw>De*riv"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From
<er>Derive</er>.]</ety> <def>That can be derived; obtainable by
transmission; capable of being known by inference, as from premises or
data; capable of being traced, as from a radical; <as>as, income is
<ex>derivable</ex> from various sources</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>All honor <qex>derivable</qex> upon me.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The exquisite pleasure <qex>derivable</qex> from the true and
beautiful relations of domestic life.</q> <rj><qau>H. G.
Bell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The argument <qex>derivable</qex> from the doxologies.</q>
<rj><qau>J. H. Newman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Derivably</ent><br/
<hw>De*riv"a*bly</hw>, <pos>adv.</pos> <def>By derivation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Derival</ent><br/
<hw>De*riv"al</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Derivation.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>derival</qex> of <qex>e</qex> from <qex>a</qex>.</q>
<rj><qau>Earle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Derivate</ent><br/
<hw>Der"i*vate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>derivatus</ets>, p. p. of <ets>derivare</ets>. See
<er>Derive</er>.]</ety> <def>Derived; derivative.</def>
<mark>[R.]</mark> <au>H. Taylor.</au> -- <def2><pos>n.</pos> <def>A
thing derived; a derivative.</def></def2> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Derivate</ent><br/
<hw>Der"i*vate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To derive.</def>
<mark>[Obs.]</mark> <rj><au>Huloet.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Derivation</ent><br/
<hw>Der`i*va"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>derivatio</ets>: cf. F. <ets>d<eacute/rivation</ets>. See
<er>Derive</er>.]</ety> <sn>1.</sn> <def>A leading or drawing off of
water from a stream or source.</def> <mark>[Obs.]</mark> <rj><au>T.
Burnet.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The act of receiving anything from a source; the act
of procuring an effect from a cause, means, or condition, as profits
from capital, conclusions or opinions from evidence.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>As touching traditional communication, . . . I do not doubt but
many of those truths have had the help of that
<qex>derivation</qex>.</q> <rj><qau>Sir M. Hale.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The act of tracing origin or descent, as in grammar
or genealogy; <as>as, the <ex>derivation</ex> of a word from an Aryan
root</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The state or method of being derived; the relation
of origin when established or asserted.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>That from which a thing is derived.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>That which is derived; a derivative; a
deduction.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>From the Euphrates into an artificial <qex>derivation</qex> of
that river.</q> <rj><qau>Gibbon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Math.)</fld> <def>The operation of deducing one
function from another according to some fixed law, called the <xex>law
of derivation</xex>, as the operation of differentiation or of
integration.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <fld>(Med.)</fld> <def>A drawing of humors or fluids from
one part of the body to another, to relieve or lessen a morbid
process.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>The formation of a word from its more original or
radical elements; also, a statement of the origin and history of a
word.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Derivational</ent><br/
<hw>Der`i*va"tion*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Relating to
derivation.</def> <rj><au>Earle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Derivative</ent><br/
<hw>De*riv"a*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>derivativus</ets>: cf. F. <ets>d<eacute/rivatif</ets>.]</ety>
<def>Obtained by derivation; derived; not radical, original, or
fundamental; originating, deduced, or formed from something else;
secondary; <as>as, a <ex>derivative</ex> conveyance; a
<ex>derivative</ex> word.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def><specif>Hence,</specif> unoriginal (said of art or
other intellectual products.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Derivative circulation</b></col>, <cd>a modification of
the circulation found in some parts of the body, in which the arteries
empty directly into the veins without the interposition of
capillaries.</cd> <rj><au>Flint.</au></rj></cs></p>

<p>-- <wordforms><wf>De*riv"a*tive*ly</wf>, <pos>adv.</pos> --
<wf>De*riv"a*tive*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Derivative</ent><br/
<hw>De*riv"a*tive</hw>, <pos>n.</pos> <sn>1.</sn> <def>That which is
derived; anything obtained or deduced from another.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Gram.)</fld> <def>A word formed from another word,
by a prefix or suffix, an internal modification, or some other change; a
word which takes its origin from a root.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Mus.)</fld> <def>A chord, not fundamental, but
obtained from another by inversion; or, <xex>vice versa</xex>, a ground
tone or root implied in its harmonics in an actual chord.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Med.)</fld> <def>An agent which is adapted to
produce a derivation (in the medical sense).</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Math.)</fld> <def>A derived function; a function
obtained from a given function by a certain algebraic process.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Except in the mode of derivation the derivative is the
same as the differential coefficient. See <cref>Differential
coefficient</cref>, under <er>Differential</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Chem.)</fld> <def>A substance so related to another
substance by modification or partial substitution as to be regarded as
derived from it; <as>thus, the amido compounds are <ex>derivatives</ex>
of ammonia, and the hydrocarbons are <ex>derivatives</ex> of methane,
benzene, etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>derivatize</ent><br/
<hw>derivatize</hw> <pos>v. t.</pos> <fld>(Chem.)</fld> <def>to alter
the chemical composition [of a compound] by a chemical reaction which
changes some part of the molecule, leaving most of the molecule
unchanged; to prepare a derivative{6} from.</def><br/
<syn><b>Syn. --</b> modify.</syn><br/
[<source>PJC</source>]</p>

<p><ent>Derive</ent><br/
<hw>De*rive"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Derived</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Deriving</conjf>.]</vmorph> <ety>[F. <ets>d<eacute/river</ets>,
L. <ets>derivare</ets>; <ets>de-</ets> + <ets>rivus</ets> stream, brook.
See <er>Rival</er>.]</ety> <sn>1.</sn> <def>To turn the course of, as
water; to divert and distribute into subordinate channels; to diffuse;
to communicate; to transmit; -- followed by <xex>to</xex>,
<xex>into</xex>, <xex>on</xex>, <xex>upon</xex>.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>For fear it [water] choke up the pits . . . they [the workman]
<qex>derive</qex> it by other drains.</q>
<rj><qau>Holland.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Her due loves <qex>derived</qex> to that vile witch's share.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Derived</qex> to us by tradition from Adam to Noah.</q>
<rj><qau>Jer. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To receive, as from a source or origin; to obtain by
descent or by transmission; to draw; to deduce; -- followed by
<xex>from</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 396 --></p>

<p><sn>3.</sn> <def>To trace the origin, descent, or derivation of; to
recognize transmission of; <as>as, he <ex>derives</ex> this word from
the Anglo-Saxon</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>From these two causes . . . an ancient set of physicians
<qex>derived</qex> all diseases.</q> <rj><qau>Arbuthnot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Chem.)</fld> <def>To obtain one substance from
another by actual or theoretical substitution; <as>as, to
<ex>derive</ex> an organic acid from its corresponding
hydrocarbon</as>.</def></p>

<p><syn><b>Syn.</b> -- To trace; deduce; infer.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Derive</ent><br/
<hw>De*rive"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To flow; to have
origin; to descend; to proceed; to be deduced.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Power from heaven<br/
<qex>Derives</qex>, and monarchs rule by gods appointed.</q>
<rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Derivement</ent><br/
<hw>De*rive"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>That which is
derived; deduction; inference.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I offer these <qex>derivements</qex> from these subjects.</q>
<rj><qau>W. Montagu.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deriver</ent><br/
<hw>De*riv"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
derives.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Derk</ent><br/
<hw>Derk</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Dark.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>-derm</ent><br/
<hw>-derm</hw> <pr>(?)</pr>. <ety>[See <er>Derm</er>,
<pos>n.</pos>]</ety> <def>A suffix or terminal formative, much used in
anatomical terms, and signifying <xex>skin</xex>, <xex>integument</xex>,
<xex>covering</xex>; <as>as, blasto<ex>derm</ex>, ecto<ex>derm</ex>,
etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Derm</ent><br/
<hw>Derm</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <grk>de`rma</grk>,
<grk>-atos</grk>, skin, fr. <grk>de`rein</grk> to skin, flay: cf. F.
<ets>derme</ets>. See <er>Tear</er>, <pos>v. t.</pos>]</ety> <sn>1.</sn>
<def>The integument of animal; the skin.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Anat.)</fld> <def>See <er>Dermis</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Derma</ent><br/
\'d8<hw>Der"ma</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. See
<er>Derm</er>.]</ety> <fld>(Anat.)</fld> <def>See
<er>Dermis</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dermacentor</ent><br/
<hw>Dermacentor</hw> <pos>n.</pos> <def>a genus comprising vectors of
important diseases of man and animals.</def><br/
<syn><b>Syn. --</b> genus <gen>Dermacentor</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dermal</ent><br/
<hw>Derm"al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From
<er>Derm</er>.]</ety> <sn>1.</sn> <def>Pertaining to the integument or
skin of animals; dermic; <as>as, the <ex>dermal</ex>
secretions</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Anat.)</fld> <def>Pertaining to the dermis or true
skin.</def></p>

<p><ent>Dermapteran</ent><br/
<ent>Dermaptera</ent><br/
<mhw>\'d8<hw>Der*map"te*ra</hw> <pr>(?)</pr>, <hw>Der*map"ter*an</hw>
<pr>(<?/)</pr></mhw>, <pos>n.</pos> <fld>(Zool.)</fld> <def>See
<er>Dermoptera</er>, <er>Dermopteran</er>.</def></p>

<p><ent>Dermatine</ent><br/
<ent>Dermatic</ent><br/
<mhw>{ <hw>Der*mat"ic</hw> <pr>(?)</pr>, <hw>Der"ma*tine</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[Gr. <grk>dermatico`s</grk>,
fr. <grk>de`rma</grk> skin.]</ety> <def>Of or pertaining to the
skin.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dermatitis</ent><br/
<hw>Der`ma*ti"tis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<grk>de`rma</grk>, <grk>-atos</grk>, skin + <ets>-itis</ets>.]</ety>
<fld>(Med.)</fld> <def>Inflammation of the skin.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dermatogen</ent><br/
<hw>Der*mat"o*gen</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>de`rma</grk>, <grk>-atos</grk>, skin + <ets>-gen</ets>.]</ety>
<fld>(Bot.)</fld> <def>Nascent epidermis, or external cuticle of plants
in a forming condition.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dermatogen</ent><br/
<hw>Der*mat"o*gen</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>de`rma</grk>, <grk>-atos</grk>, skin + <ets>-gen</ets>.]</ety>
<fld>(Bot.)</fld> <def>Nascent epidermis, or external cuticle of plants
in a forming condition.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dermatography</ent><br/
<hw>Der*ma*tog"ra*phy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>de`rma</grk>, <grk>-atos</grk>, skin + <ets>-graphy</ets>.]</ety>
<def>An anatomical description of, or treatise on, the skin.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dermatoid</ent><br/
<hw>Der"ma*toid</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>de`rma</grk>, <grk>-atos</grk>, skin + <ets>-oid</ets>: cf. F.
<ets>dermato<ium/de</ets>. Cf. <er>Dermoid</er>.]</ety> <def>Resembling
skin; skinlike.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>dermatological</ent><br/
<ent>dermatologic</ent><br/
<mhw><hw>dermatologic</hw>, <hw>dermatological</hw></mhw>
<pos>adj.</pos> <def>of or pertaining to dermatology.</def><br/
<syn><b>Syn. --</b> dermatologic.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>dermatologist</ent><br/
<hw>der`ma*tol"o*gist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
discourses on the skin and its diseases; one versed in
dermatology</def>; <specif>especially,</specif> <def>a physician with
specialized training in dermatology, licensed to practise as a
specialist in treating diseases of the skin.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Dermatology</ent><br/
<hw>Der`ma*tol"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>de`rma</grk>, <grk>-atos</grk>, skin + <ets>-logy</ets>: cf. F.
<ets>dermatologie</ets>.]</ety> <def>The science which treats of the
skin, its structure, functions, and diseases.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dermatopathic</ent><br/
<hw>Der`ma*to*path"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>de`rma</grk>, <grk>-atos</grk>, skin + <grk>pa`qos</grk>
suffering.]</ety> <fld>(Med.)</fld> <def>Of or pertaining to skin
diseases, or their cure.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dermatophyte</ent><br/
<hw>Der*mat"o*phyte</hw> <pr>(d<etil/r*m<acr/t"<osl/*f<imac/t
<it>or</it> d<etil/r"m<adot/*t<osl/*f<imac/t)</pr>, <pos>n.</pos>
<ety>[Gr. <grk>de`rma</grk>, <grk>-atos</grk>, skin + <grk>fyto`n</grk>
plant.]</ety> <fld>(Med.)</fld> <def>A fungus infecting and parasitic on
the skin, especially one which causes disease; <as>as, ringworm is
caused by a <ex>dermatophyte</ex></as>.</def></p>

<p><ent>Dermestes</ent><br/
\'d8<hw>Der*mes"tes</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., from Gr.
<grk>dermhsth`s</grk>; <grk>de`rma</grk> skin + root of
<grk>'esthi`ein</grk> to eat.]</ety> <fld>(Zool.)</fld> <def>A genus of
coleopterous insects, the larv<ae/ of which feed animal substances. They
are very destructive to dries meats, skins, woolens, and furs. The most
common species is <spn>Dermestes lardarius</spn>, known as the
<stype>bacon beetle</stype>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dermestoid</ent><br/
<hw>Der*mes"toid</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Dermestes</ets> + <ets>-oid</ets>.]</ety> <fld>(Zool.)</fld>
<def>Pertaining to or resembling the genus Dermestes.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The carpet beetle, called the buffalo moth, is a
<qex>dermestoid</qex> beetle.</q> <rj><qau>Pop. Sci.
Monthly.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dermic</ent><br/
<hw>Der"mic</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Relating
to the derm or skin.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Anat.)</fld> <def>Pertaining to the dermis;
dermal.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Underneath each nail the deep or <qex>dermic</qex> layer of the
integument is peculiarly modified.</q> <rj><qau>Huxley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dermic remedies</b></col> <fld>(Med.)</fld>, <cd>such as
act through the skin.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dermis</ent><br/
\'d8<hw>Der"mis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. See
<er>Derm</er>.]</ety> <fld>(Anat.)</fld> <def>The deep sensitive layer
of the skin beneath the scarfskin or epidermis; -- called also
<altname>true skin</altname>, <altname>derm</altname>,
<altname>derma</altname>, <altname>corium</altname>,
<altname>cutis</altname>, and <altname>enderon</altname>. See
<er>Skin</er>, and <xex>Illust.</xex> in Appendix.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dermobranchiata</ent><br/
\'d8<hw>Der`mo*bran`chi*a"ta</hw> <pr>(?)</pr>, <pos>n. pl.</pos>
<ety>[NL.]</ety> <fld>(Zool.)</fld> <def>A group of nudibranch mollusks
without special gills.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dermobranchiate</ent><br/
<hw>Der`mo*bran"chi*ate</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Derm</ets> + <ets>branchiate</ets>.]</ety> <fld>(Zool.)</fld>
<def>Having the skin modified to serve as a gill.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dermohaemal</ent><br/
<hw>Der`mo*h<ae/"mal</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Anat.)</fld>
<def>Pertaining to, or in relation with, both dermal and h<ae/mal
structures; <as>as, the <ex>dermoh<ae/mal</ex> spines or ventral fin
rays of fishes</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dermoid</ent><br/
<hw>Der"moid</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Derm</ets> +
<ets>-oid</ets>: cf. F. <ets>dermo<ium/de</ets>.]</ety> <def>Same as
<er>Dermatoid</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dermoid cyst</b></col> <fld>(Med.)</fld>, <cd>a cyst
containing skin, or structures connected with skin, such as
hair.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dermoneural</ent><br/
<hw>Der`mo*neu"ral</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Anat.)</fld>
<def>Pertaining to, or in relation with, both dermal and neural
structures; <as>as, the <ex>dermoneural</ex> spines or dorsal fin rays
of fishes</as>.</def> <rj><au>Owen.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dermopathic</ent><br/
<hw>Der`mo*path"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Med.)</fld>
<def>Dermatopathic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dermophyte</ent><br/
<hw>Der"mo*phyte</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A
dermatophyte.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dermoptera</ent><br/
\'d8<hw>Der*mop"te*ra</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
fr. Gr. <grk>de`rma</grk> skin + <grk>pte`rux</grk> wing.]</ety>
<sn>1.</sn> <fld>(Zool.)</fld> <def>The division of insects which
includes the earwigs (<fam>Forticulid<ae/</fam>).</def><-- now usu.
<ord>Dermaptera</ord> --><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>A group of lemuroid mammals
having a parachutelike web of skin between the fore and hind legs, of
which the colugo (<gen>Galeopithecus</gen>) is the type. See
<er>Colugo</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <def>An order of Mammalia; the
<er>Chiroptera</er>.</def></p>

<p><altsp>[Written also <asp>Dermaptera</asp>, and
<asp>Dermatoptera</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dermopteran</ent><br/
<hw>Der*mop"ter*an</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>An insect which has the anterior pair of wings coriaceous, and does
not use them in flight, as the earwig.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dermopteri</ent><br/
\'d8<hw>Der*mop"te*ri</hw> <pr>(?)</pr>, <pos>n. pl.</pos>
<ety>[NL.]</ety> <fld>(Zool.)</fld> <def>Same as
<er>Dermopterygii</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dermopterygii</ent><br/
\'d8<hw>Der*mop`te*ryg"i*i</hw> <pr>(?)</pr>, <pos>n. pl.</pos>
<ety>[NL., fr. Gr. <grk>de`rma</grk> skin + <grk>pteru`gion</grk> wing,
fin, dim. of <grk>pte`rux</grk> wing.]</ety> <fld>(Zool.)</fld> <def>A
group of fishlike animals including the Marsipobranchiata and
Leptocardia.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dermoskeleton</ent><br/
<hw>Der`mo*skel"e*ton</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Derm</ets> + <ets>skeleton</ets>.]</ety> <fld>(Anat.)</fld>
<def>See <er>Exoskeleton</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dermostosis</ent><br/
\'d8<hw>Der`mos*to"sis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., from
Gr. <grk>de`rma</grk> skin + <grk>'ostou^n</grk> bone.]</ety>
<fld>(Physiol.)</fld> <def>Ossification of the dermis.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dern</ent><br/
<hw>Dern</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Etymol.
uncertain.]</ety> <def>A gatepost or doorpost.</def> <mark>[Local
Eng.]</mark> <rj><au>C. Kingsley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dern</ent><br/
<hw>Dern</hw>, <pos>a.</pos> <ety>[See <er>Dearn</er>,
<pos>a.</pos>]</ety> <sn>1.</sn> <def>Hidden; concealed; secret.</def>
<mark>[Obs.]</mark> <ldquo/Ye must be full <xex>dern</xex>.<rdquo/
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Solitary; sad.</def> <mark>[Obs.]</mark> <rj><au>Dr.
H. More.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Derne</ent><br/
<hw>Derne</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <ety>[AS.
<ets>dyrnan</ets> to hide. See <er>Dern</er>, <pos>a.</pos>,
<er>Dearn</er>, <pos>a.</pos>]</ety> <def>To hide; to skulk.</def>
<mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He at length escaped them by <qex>derning</qex> himself in a
foxearth.</q> <rj><qau>H. Miller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dernful</ent><br/
<hw>Dern"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Secret; hence,
lonely; sad; mournful.</def> <mark>[Obs.]</mark>
<ldquo/<xex>Dernful</xex> noise.<rdquo/ <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dernier</ent><br/
\'d8<hw>Der`nier"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F., from OF.
<ets>darrein</ets>, <ets>derrain</ets>. See <er>Darrein</er>.]</ety>
<def>Last; final.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dernier ressort</b></col> <pr>(<?/)</pr> <ety>[F.]</ety>,
<cd>last resort or expedient.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dernly</ent><br/
<hw>Dern"ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>Secretly;
grievously; mournfully.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Derogant</ent><br/
<hw>Der"o*gant</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>derogans</ets>, p. pr.]</ety> <def>Derogatory.</def>
<mark>[R.]</mark> <rj><au>T. Adams.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Derogate</ent><br/
<hw>Der"o*gate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Derogated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Derogating</conjf> <pr>(?)</pr>.]</vmorph> <ety>[L.
<ets>derogatus</ets>, p. p. of <ets>derogare</ets> to derogate;
<ets>de-</ets> + <ets>rogare</ets> to ask, to ask the people about a
law. See <er>Rogation</er>.]</ety> <sn>1.</sn> <def>To annul in part; to
repeal partly; to restrict; to limit the action of; -- said of a
law.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>By several contrary customs, . . . many of the civil and canon
laws are controlled and <qex>derogated</qex>.</q> <rj><qau>Sir M.
Hale.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To lessen; to detract from; to disparage; to
depreciate; -- said of a person or thing.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Anything . . . that should <qex>derogate</qex>, minish, or hurt
his glory and his name.</q> <rj><qau>Sir T. More.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Derogate</ent><br/
<hw>Der"o*gate</hw> <pr>(?)</pr>, <pos>v. i.</pos> <sn>1.</sn> <def>To
take away; to detract; to withdraw; -- usually with
<xex>from</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If we did <qex>derogate</qex> from them whom their industry hath
made great.</q> <rj><qau>Hooker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>It <qex>derogates</qex> little from his fortitude, while it adds
infinitely to the honor of his humanity.</q>
<rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To act beneath one-s rank, place, birth, or
character; to degenerate.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>You are a fool granted; therefore your issues, being foolish, do
not <qex>derogate</qex>.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Would Charles X. <qex>derogate</qex> from his ancestors? Would he
be the degenerate scion of that royal line?</q>
<rj><qau>Hazlitt.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Derogate</ent><br/
<hw>Der"o*gate</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>derogatus</ets>, p. p.]</ety> <def>Diminished in value; dishonored;
degraded.</def> <mark>[R.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Derogately</ent><br/
<hw>Der"o*gate*ly</hw>, <pos>adv.</pos> <def>In a derogatory
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Derogation</ent><br/
<hw>Der`o*ga"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>derogatio</ets>: cf. F. <ets>d<eacute/rogation</ets>.]</ety>
<sn>1.</sn> <def>The act of derogating, partly repealing, or lessening
in value; disparagement; detraction; depreciation; -- followed by
<xex>of</xex>, <xex>from</xex>, or <xex>to</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I hope it is no <qex>derogation</qex> to the Christian
religion.</q> <rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He counted it no <qex>derogation</qex> of his manhood to be seen
to weep.</q> <rj><qau>F. W. Robertson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Stock Exch.)</fld> <def>An alteration of, or
subtraction from, a contract for a sale of stocks.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Derogative</ent><br/
<hw>De*rog"a*tive</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Derogatory.</def> -- <wordforms><wf>De*rog"a*tive*ly</wf>,
<pos>adv.</pos> <mark>[R.]</mark></wordforms> <rj><au>Sir T.
Browne.</au></rj><br/
<syn><b>Syn. --</b> belittling, depreciative, deprecatory, depreciatory,
derogatory, detractive, detracting, slighting, pejorative,
denigratory.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Derogator</ent><br/
<hw>Der"o*ga`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.]</ety> <def>A
detractor.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>derogatorily</ent><br/
<hw>de*rog"a*to*ri*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a
derogatory manner; disparagingly.</def> <rj><au>Aubrey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>derogatoriness</ent><br/
<hw>de*rog"a*to*ri*ness</hw>, <pos>n.</pos> <def>Quality of being
derogatory.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>derogatory</ent><br/
<hw>de*rog"a*to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Tending to
derogate, or lessen in value; expressing a low opinion; expressing
derogation; detracting; injurious; -- with <ptcl>from</ptcl>,
<ptcl>to</ptcl>, or <ptcl>unto</ptcl>.</def><br/
<syn><b>Syn. --</b> belittling, depreciative, deprecatory, depreciatory,
derogatory, detractive, detracting, slighting, pejorative,
denigratory.</syn><br/
[<source>1913 Webster</source>]</p>

<p><q>Acts of Parliament <qex>derogatory</qex> from the power of
subsequent Parliaments bind not.</q> <rj><qau>Blackstone.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>His language was severely censured by some of his brother peers as
<qex>derogatory</qex> to their other.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Derogatory clause in a testament</b></col>
<fld>(Law)</fld>, <cd>a sentence of secret character inserted by the
testator alone, of which he reserves the knowledge to himself, with a
condition that no will he may make thereafter shall be valid, unless
this clause is inserted word for word; -- a precaution to guard against
later wills extorted by violence, or obtained by
suggestion.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Derotremata</ent><br/
\'d8<hw>Der`o*tre"ma*ta</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
fr. Gr. <grk>de`ros</grk> skin + <grk>trh^ma</grk>, <grk>trh^mata</grk>,
hole.]</ety> <fld>(Zool.)</fld> <def>The tribe of aquatic Amphibia which
includes Amphiuma, Menopoma, etc. They have permanent gill openings, but
no external gills; -- called also <fam>Cryptobranchiata</fam>.</def>
<altsp>[Written also <asp>Derotrema</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Derre</ent><br/
<hw>Der"re</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Dearer.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Derrick</ent><br/
<hw>Der"rick</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Orig., a gallows,
from a hangman named <ets>Derrick</ets>. The name is of Dutch origin; D.
<ets>Diederik</ets>, <ets>Dierryk</ets>, prop. meaning, chief of the
people; cf. AS. <ets>pe<oacute/dric</ets>, E. <ets>Theodoric</ets>, G.
<ets>Dietrich</ets>. See <er>Dutch</er>, and <er>Rich</er>.]</ety>
<sn>1.</sn> <def>A mast, spar, or tall frame, supported at the top by
stays or guys, and usually pivoted at the base, with suitable tackle for
hoisting heavy weights, such as stones in building.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mining)</fld> <def>The pyramidal structure or tower
over a deep drill hole, such as that of an oil well (also called an
<ecol><b>oil derrick</b></ecol> .</def><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><cs><col><b>Derrick crane</b></col>, <cd>a combination of the derrick
and the crane, having facility for hoisting and also for swinging the
load horizontally.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Derring</ent><br/
<hw>Der"ring</hw>, <pos>a.</pos> <def>Daring or warlike.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Drad for his <qex>derring</qex> doe and bloody deed.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>derring-do</ent><br/
<hw>derring-do</hw> <pos>n.</pos> <def>brave and heroic deeds.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Derringer</ent><br/
<hw>Der"rin*ger</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From the American
inventor.]</ety> <def>A kind of short-barreled pocket pistol, of very
large caliber, often carrying a half-ounce ball.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Derth</ent><br/
<hw>Derth</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Dearth; scarcity.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dertrotheca</ent><br/
\'d8<hw>Der`tro*the"ca</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <grk>de`rtron</grk> beak + <grk>qh`kh</grk> box, case.]</ety>
<fld>(Zool.)</fld> <def>The horny covering of the end of the bill of
birds.</def></p>

<p><ent>Dervis</ent><br/
<ent>Dervise</ent><br/
<ent>Dervish</ent><br/
<mhw>{ <hw>Der"vish</hw> <pr>(?)</pr>, <hw>Der"vise</hw> <pr>(?)</pr>,
<hw>Der"vis</hw> <pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[Per.
<ets>derw<emac/sch</ets>, fr. OPer. <ets>derew</ets> to beg, ask alms:
cf. F. <ets>derviche</ets>.]</ety> <sn>1.</sn> <def>A Turkish or Persian
monk, especially one who professes extreme poverty and leads an austere
life.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One of the fanatical followers of the Mahdi, in the
Sudan, in the 1880's.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>3.</sn> <def>in modern times, a member of an ascetic Muslim sect
notable for its devotional exercises, which include energetic chanting
or shouting and rhythmic bodily movement, such as whirling, leading to a
trance-like state or ecstasy. From these exercises the phrase
<ecol><b>whirling dervish</b></ecol> is derived.</def><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <def>figuratively, a person who whirls or engages in
frenzied activity reminiscent of the dervish{3} dancing.</def><br/
[<source>PJC</source>]</p>

<p><ent>Derworth</ent><br/
<hw>Der"worth</hw> <pr>(d<emac/r"w<etil/rth)</pr>, <pos>a.</pos>
<ety>[AS. <ets>de<oacute/rwur<thorn/e</ets>, lit., dearworth.]</ety>
<def>Precious.</def> <mark>[Obs.]</mark> <rj><au>Piers
Plowman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>desalinate</ent><br/
<hw>desalinate</hw> <pos>v. t.</pos> <def>to remove the salt from,
especially from water; <as>as, it is necessary to <ex>desalinate</ex>
sea water to make it fit to drink</as>.</def> <note>several processes
are in comon use for desalinating sea water. Distillation is effective,
but expensive. <er>Reverse osmosis</er> is more economical.</note><br/
<syn><b>Syn. --</b> desalt, desalinize.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>desalination</ent><br/
<hw>desalination</hw> <pos>n.</pos> <def>same as
<er>desalinization</er>.</def><br/
<syn><b>Syn. --</b> desalinization, desalinisation.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>desalinisation</ent><br/
<hw>desalinisation</hw> <pos>n.</pos> <def>same as
<er>desalinization</er>.</def><br/
<syn><b>Syn. --</b> desalination, desalinization.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>desalinization</ent><br/
<hw>desalinization</hw> <pos>n.</pos> <def>the removal of salt
(especially from sea water); the act or process of
desalinating.</def><br/
<syn><b>Syn. --</b> desalination, desalinisation.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>desalinize</ent><br/
<hw>desalinize</hw> <pos>v. t.</pos> <def>same as
<er>desalinate</er>.</def><br/
<syn><b>Syn. --</b> desalinate, desalt.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>desalt</ent><br/
<hw>desalt</hw> <pos>v.</pos> <def>to remove the salt from (a solution
of salt).</def> <note>This term is used in a more general sense than
<er>desalinate</er>, which usually refers to the removal of common salt
(sodium chloride) from a water solution, such as sea water.
<ex>Desalt</ex> is commonly used to refer to any laboratory or
industrial process in which any salt may be removed from a mixture of
substances dssolved in a solvent, usually water. It is thus used as a
method of purification in chemical processes. The methods for desalting
are very varied.</note><br/
<syn><b>Syn. --</b> desalinate, desalinize.</syn><br/
[<source>PJC</source>]</p>

<p><ent>descale</ent><br/
<hw>descale</hw> <pos>v. t.</pos> <def>to remove the scales from; --
e.g. of fish, or water boilers.</def><br/
<syn><b>Syn. --</b> scale.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Descant</ent><br/
<hw>Des"cant</hw> <pr>(d<ecr/s"k<acr/nt)</pr>, <pos>n.</pos> <ety>[OF.
<ets>descant</ets>, <ets>deschant</ets>, F. <ets>d<eacute/chant</ets>,
<ets>discant</ets>, LL. <ets>discantus</ets>, fr. L. <ets>dis</ets> +
<ets>cantus</ets> singing, melody, fr. <ets>canere</ets> to sing. See
<er>Chant</er>, and cf. <er>Descant</er>, <pos>v. i.</pos>,
<er>Discant</er>.]</ety> <sn>1.</sn> <fld>(Mus.)</fld> <sd>(a)</sd>
<def>Originally, a double song; a melody or counterpoint sung above the
plain song of the tenor; a variation of an air; a variation by ornament
of the main subject or plain song.</def> <sd>(b)</sd> <def>The upper
voice in part music.</def> <sd>(c)</sd> <def>The <xex>canto</xex>,
<xex>cantus</xex>, or soprano voice; the treble.</def>
<rj><au>Grove.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Twenty doctors expound one text twenty ways, as children make
<qex>descant</qex> upon plain song.</q> <rj><qau>Tyndale.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>She [the nightingale] all night long her amorous
<qex>descant</qex> sung.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The term has also been used synonymously with
counterpoint, or polyphony, which developed out of the French
<xex>d<eacute/chant</xex>, of the 12th century.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A discourse formed on its theme, like variations on
a musical air; a comment or comments.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Upon that simplest of themes how magnificent a
<qex>descant</qex>!</q> <rj><qau>De Quincey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Descant</ent><br/
<hw>Des*cant"</hw> <pr>(d<ecr/s*k<acr/nt")</pr>, <pos>v. i.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Descanted</conjf>; <pos>p. pr. &
vb. n.</pos> <conjf>Descanting</conjf>.]</vmorph> <ety>[From
<ets>descant</ets>; <ets>n.</ets>; or directly fr. OF.
<ets>descanter</ets>, <ets>deschanter</ets>; L. <ets>dis-</ets> +
<ets>cantare</ets> to sing.]</ety> <sn>1.</sn> <def>To sing a variation
or accomplishment.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To comment freely; to discourse with fullness and
particularity; to discourse at large.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A virtuous man should be pleased to find people
<qex>descanting</qex> on his actions.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Descanter</ent><br/
<hw>Des*cant"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
descants.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Descartes</ent><br/
<hw>Descartes</hw> <pr>(d<asl/*k<aum/rt")</pr> <pos>prop. n.</pos>
<def><person>Ren<eacute/ Descartes</person>, a French philosopher and
mathematician, born 1596, died 1650. See biography, below.</def><br/
<syn><b>Syn. --</b> Rene Descartes.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><biography>Descartes, Ren<eacute/ (Latinized Renatus Cartesius). Born
at La Haye, Touraine, France, March 31, 1596: died at Stockholm, Feb.
11, 1650. A. celebrated French philosopher, founder of Cartesianism and
of modern philosophy in general. He was graduated at seventeen from the
Jesuit college of La Fl<egrave/che, spent five years in Paris (1613-18),
and then roamed about in search of knowledge in Germany, Italy, Holland,
and Poland. In 1628 he attended the siege of La Rochelle as a volunteer.
From 1629 to 1649 he led a retired life in Holland, spreading and
defending his philosophical ideas. He finally went to Stockholm on the
invitation of Queen Christina of Sweden; five months later he died there
of pneumonia. The work that has made him famous as a philosopher is a
short treatise entitled "Discours de la m<eacute/thode" (Leyden, 1637).
It was published in French together with three essays in support of his
theories, "La dioptrique," "Les m<eacute/t<eacute/ores," and "La
g<eacute/om<eacute/trie." In it he revolutionized the science of
thought. Descartes himself published during his lifetime "Meditationes
de prima philosophia "(Paris, 1641; Amsterdam, 1642; translated into
French, 1647), "Principia philosophiae" (Amsterdam, 1644),
"Trait<eacute/ des passions de l'<acir/me" (Amsterdam, 1649), and a
polemic pamphlet entitled "Epistola Renati Descartes ad Gisbertum
Vo<eum/itum" (Amsterdam, 1643). After his death his friends published
his "De l'homme" (1664), "Trait<eacute/ de la formation du foetus"
(1664), "Le monde ou trait<eacute/ de la lumi<egrave/re de Descartes"
(1664), "Lettres" (1657-67), and "Opuscula posthuma, physica et
mathematica" (Amsterdam, 1701). Descartes ranked among the foremost
mathematicians of his day. A separate reprint was made of his geometry,
and the work itself was translated into Latin in 1649, and re<eum/dited
in 1659 with notes and comments. In this form it constituted a classic
standard throughout Europe, and presented an entirely new basis for the
study of algebra and geometry.</biography><br/
[<source>Century Dict. 1906</source>]</p>

<p><ent>Descend</ent><br/
<hw>De*scend"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Descended</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Descending</conjf>.]</vmorph> <ety>[F. <ets>descendre</ets>, L.
<ets>descendere</ets>, <ets>descensum</ets>; <ets>de-</ets> +
<ets>scandere</ets> to climb. See <er>Scan</er>.]</ety> <sn>1.</sn>
<def>To pass from a higher to a lower place; to move downwards; to come
or go down in any way, as by falling, flowing, walking, etc.; to plunge;
to fall; to incline downward; -- the opposite of
<xex>ascend</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The rain <qex>descended</qex>, and the floods came.</q>
<rj><qau>Matt. vii. 25.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>We will here <qex>descend</qex> to matters of later date.</q>
<rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To enter mentally; to retire.</def>
<mark>[Poetic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>[He] with holiest meditations fed,<br/
Into himself <qex>descended</qex>.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To make an attack, or incursion, as if from a
vantage ground; to come suddenly and with violence; -- with
<ptcl>on</ptcl> or <ptcl>upon</ptcl>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And on the suitors let thy wrath <qex>descend</qex>.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To come down to a lower, less fortunate, humbler,
less virtuous, or worse, state or station; to lower or abase one's self;
<as>as, he <ex>descended</ex> from his high estate</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To pass from the more general or important to the
particular or less important matters to be considered.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To come down, as from a source, original, or stock;
to be derived; to proceed by generation or by transmission; to fall or
pass by inheritance; <as>as, the beggar may <ex>descend</ex> from a
prince; a crown <ex>descends</ex> to the heir.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Anat.)</fld> <def>To move toward the south, or to
the southward.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <fld>(Mus.)</fld> <def>To fall in pitch; to pass from a
higher to a lower tone.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Descend</ent><br/
<hw>De*scend"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To go down upon
or along; to pass from a higher to a lower part of; <as>as, they
<ex>descended</ex> the river in boats; to <ex>descend</ex> a
ladder.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>But never tears his cheek <qex>descended</qex>.</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Descendant</ent><br/
<hw>De*scend"ant</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F.
<ets>descendant</ets>, p. pr. of <ets>descendre</ets>. Cf.
<er>Descendent</er>.]</ety> <def>Descendent.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Descendant</ent><br/
<hw>De*scend"ant</hw>, <pos>n.</pos> <def>One who descends, as
offspring, however remotely; -- correlative to <xex>ancestor</xex> or
<xex>ascendant</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Our first parents and their <qex>descendants</qex>.</q>
<rj><qau>Hale.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>descendant</qex> of so many kings and emperors.</q>
<rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>descendants</ent><br/
<hw>descendants</hw> <pos>n.</pos> <def>all of the offspring of a given
progenitor.</def><br/
<syn><b>Syn. --</b> posterity.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Descendent</ent><br/
<hw>De*scend"ent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>descendens</ets>, <ets>-entis</ets>, p. pr. of
<ets>descendre</ets>. Cf. <er>Descendant</er>.]</ety> <def>Descending;
falling; proceeding from an ancestor or source.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>More than mortal grace<br/
Speaks thee <qex>descendent</qex> of ethereal race.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Descender</ent><br/
<hw>De*scend"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
descends.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Descendibility</ent><br/
<hw>De*scend`i*bil"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The
quality of being descendible; capability of being transmitted from
ancestors; <as>as, the <ex>descendibility</ex> of an
estate</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Descendible</ent><br/
<hw>De*scend"i*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Admitting descent; capable of being descended.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That may descend from an ancestor to an heir.</def>
<ldquo/A <xex>descendant</xex> estate.<rdquo/ <rj><au>Sir W.
Jones.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Descending</ent><br/
<hw>De*scend"ing</hw>, <pos>a.</pos> <def>Of or pertaining to descent;
moving downwards.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Descending constellations</b></col> <it>or</it>
<col><b>Descending signs</b></col></mcol> <fld>(Astron.)</fld>,
<cd>those through which the planets descent toward the south.</cd> --
<col><b>Descending node</b></col> <fld>(Astron.)</fld>, <cd>that point
in a planet's orbit where it intersects the ecliptic in passing
southward.</cd> -- <col><b>Descending series</b></col>
<fld>(Math.)</fld>, <cd>a series in which each term is numerically
smaller than the preceding one; also, a series arranged according to
descending powers of a quantity.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Descendingly</ent><br/
<hw>De*scend"ing*ly</hw>, <pos>adv.</pos> <def>In a descending
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Descension</ent><br/
<hw>De*scen"sion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>descension</ets>, L. <ets>descensio</ets>. See
<er>Descent</er>.]</ety> <def>The act of going downward; descent;
falling or sinking; declension; degradation.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Oblique descension</b></col> <fld>(Astron.)</fld>,
<cd>the degree or arc of the equator which descends, with a celestial
object, below the horizon of an oblique sphere.</cd> -- <col><b>Right
descension</b></col>, <cd>the degree or arc of the equator which
descends below the horizon of a right sphere at the same time with the
object.</cd> <mark>[Obs.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 397 --></p>

<p><ent>Descensional</ent><br/
<hw>De*scen"sion*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to
descension.</def> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Descensive</ent><br/
<hw>De*scen"sive</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Tending to
descend; tending downwards; descending.</def>
<rj><au>Smart.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Descensory</ent><br/
<hw>De*scen"so*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL.
<ets>descensorium</ets>: cf. OF. <ets>descensoire</ets>. See
<er>Descend</er>.]</ety> <def>A vessel used in alchemy to extract
oils.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Descent</ent><br/
<hw>De*scent"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>descente</ets>, fr. <ets>descendre</ets>; like <ets>vente</ets>,
from <ets>vendre</ets>. See <er>Descend</er>.]</ety> <sn>1.</sn>
<def>The act of descending, or passing downward; change of place from
higher to lower.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Incursion; sudden attack; especially, hostile
invasion from sea; -- often followed by <xex>upon</xex> or
<xex>on</xex>; <as>as, to make a <ex>descent</ex> upon the
enemy</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The United Provinces . . . ordered public prayer to God, when they
feared that the French and English fleets would make a
<qex>descent</qex> upon their coasts.</q>
<rj><qau>Jortin.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Progress downward, as in station, virtue, as in
station, virtue, and the like, from a higher to a lower state, from a
higher to a lower state, from the more to the less important, from the
better to the worse, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Derivation, as from an ancestor; procedure by
generation; lineage; birth; extraction.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Law)</fld> <def>Transmission of an estate by
inheritance, usually, but not necessarily, in the descending line; title
to inherit an estate by reason of consanguinity.</def>
<rj><au>Abbott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Inclination downward; a descending way; inclined or
sloping surface; declivity; slope; <as>as, a steep
<ex>descent</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>That which is descended; descendants;
issue.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If care of our <qex>descent</qex> perplex us most,<br/
Which must be born to certain woe.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>A step or remove downward in any scale of gradation;
a degree in the scale of genealogy; a generation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>No man living is a thousand <qex>descents</qex> removed from Adam
himself.</q> <rj><qau>Hooker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>Lowest place; extreme downward place.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>And from the extremest upward of thy head,<br/
To the <qex>descent</qex> and dust below thy foot.</q>
<rj><qau>Shak.</qau></rj> <sn>10.</sn> <fld>(Mus.)</fld> <def>A passing
from a higher to a lower tone.</def></p>

<p><syn><b>Syn.</b> -- Declivity; slope; degradation; extraction;
lineage; assault; invasion; attack.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Describable</ent><br/
<hw>De*scrib"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>That can be
described; capable of description.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Describe</ent><br/
<hw>De*scribe"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Described</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Describing</conjf>.]</vmorph> <ety>[L.
<ets>describere</ets>, <ets>descriptum</ets>; <ets>de-</ets> +
<ets>scribere</ets> to write: cf. OE. <ets>descriven</ets>, OF.
<ets>descrivre</ets>, F. <ets>d<eacute/crire</ets>. See <er>Scribe</er>,
and cf. <er>Descry</er>.]</ety> <sn>1.</sn> <def>To represent by
drawing; to draw a plan of; to delineate; to trace or mark out; <as>as,
to <ex>describe</ex> a circle by the compasses; a torch waved about the
head in such a way as to <ex>describe</ex> a circle.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To represent by words written or spoken; to give an
account of; to make known to others by words or signs; <as>as, the
geographer <ex>describes</ex> countries and cities</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To distribute into parts, groups, or classes; to
mark off; to class.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Passed through the land, and <qex>described</qex> it by cities
into seven parts in a book.</q> <rj><qau>Josh. xviii. 9.</qau></rj></p>

<p><syn><b>Syn.</b> -- To set forth; represent; delineate; relate;
recount; narrate; express; explain; depict; portray;
chracterize.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Describe</ent><br/
<hw>De*scribe"</hw>, <pos>v. i.</pos> <def>To use the faculty of
describing; to give a description; <as>as, Milton <ex>describes</ex>
with uncommon force and beauty</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Describent</ent><br/
<hw>De*scrib"ent</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>describens</ets>, p. pr. of <ets>describere</ets>.]</ety>
<fld>(Geom.)</fld> <def>Same as <er>Generatrix</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Describer</ent><br/
<hw>De*scrib"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
describes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Descrier</ent><br/
<hw>De*scri"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
descries.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Description</ent><br/
<hw>De*scrip"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>description</ets>, L. <ets>descriptio</ets>. See
<er>Describe</er>.]</ety> <sn>1.</sn> <def>The act of describing; a
delineation by marks or signs.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A sketch or account of anything in words; a
portraiture or representation in language; an enumeration of the
essential qualities of a thing or species.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Milton has <qex>descriptions</qex> of morning.</q> <rj><qau>D.
Webster.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A class to which a certain representation is
applicable; kind; sort.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A difference . . . between them and another <qex>description</qex>
of public creditors.</q> <rj><qau>A. Hamilton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The plates were all of the meanest <qex>description</qex>.</q>
<rj><qau>Macaulay.</qau></rj></p>

<p><syn><b>Syn.</b> -- Account; definition; recital; relation; detail;
narrative; narration; explanation; delineation; representation; kind;
sort. See <er>Definition</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Descriptive</ent><br/
<hw>De*scrip"tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>descriptivus</ets>: cf. F. <ets>descriptif</ets>.]</ety>
<def>Tending to describe; having the quality of representing; containing
description; <as>as, a <ex>descriptive</ex> figure; a
<ex>descriptive</ex> phrase; a <ex>descriptive</ex> narration; a story
<ex>descriptive</ex> of the age.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Descriptive anatomy</b></col>, <cd>that part of anatomy
which treats of the forms and relations of parts, but not of their
textures.</cd> -- <col><b>Descriptive geometry</b></col>, <cd>that
branch of geometry. which treats of the graphic solution of problems
involving three dimensions, by means of projections upon auxiliary
planes.</cd> <rj><au>Davies & Peck (Math. Dict. )</au></rj></cs></p>

<p>-- <wordforms><wf>De*scrip"tive*ly</wf>, <pos>adv.</pos> --
<wf>De*scrip"tive*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Descrive</ent><br/
<hw>De*scrive"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[OF.
<ets>descrivre</ets>. See <er>Describe</er>.]</ety> <def>To
describe.</def> <mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Descry</ent><br/
<hw>De*scry"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Descried</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Descrying</conjf>.]</vmorph> <ety>[OE.
<ets>descrien</ets>, <ets>discrien</ets>, to espy, prob. from the
proclaiming of what was espied, fr. OF. <ets>descrier</ets> to proclaim,
cry down, decry, F. <ets>d<eacute/crier</ets>. The word was confused
somewhat with OF. <ets>descriven</ets>, E. <ets>describe</ets>, OF.
<ets>descrivre</ets>, from L. <ets>describere</ets>. See
<er>Decry</er>.]</ety> <sn>1.</sn> <def>To spy out or discover by the
eye, as objects distant or obscure; to espy; to recognize; to discern;
to discover.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And the house of Joseph sent to <qex>descry</qex> Bethel.</q>
<rj><qau>Judg. i. 23.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Edmund, I think, is gone . . . to <qex>descry</qex><br/
The strength o' the enemy.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And now their way to earth they had <qex>descried</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To discover; to disclose; to reveal.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>His purple robe he had thrown aside, lest it should
<qex>descry</qex> him.</q> <rj><qau>Milton.</qau></rj></p>

<p><syn><b>Syn.</b> -- To see; behold; espy; discover;
discern.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Descry</ent><br/
<hw>De*scry"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Discovery or view, as
of an army seen at a distance.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Near, and on speedy foot; the main <qex>descry</qex><br/
Stands on the hourly thought.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desecate</ent><br/
<hw>Des"e*cate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>desecare</ets> to cut off.]</ety> <def>To cut, as with a scythe; to
mow.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desecrate</ent><br/
<hw>Des"e*crate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Desecrated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Desecrating</conjf> <pr>(?)</pr>.]</vmorph> <ety>[L.
<ets>desecratus</ets>, p. p. of <ets>desecrare</ets> (also
<ets>desacrare</ets>) to consecrate, dedicate; but taken in the sense if
to divest of a sacred character; <ets>de-</ets> + <ets>sacrare</ets> to
consecrate, fr. <ets>sacer</ets> sacred. See <er>Sacred</er>.]</ety>
<def>To divest of a sacred character or office; to divert from a sacred
purpose; to violate the sanctity of; to profane; to put to an unworthy
use; -- the opposite of <xex>consecrate</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The [Russian] clergy can not suffer corporal punishment without
being previously <qex>desecrated</qex>.</q> <rj><qau>W.
Tooke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The founders of monasteries imprecated evil on those who should
<qex>desecrate</qex> their donations.</q>
<rj><qau>Salmon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desecrater</ent><br/
<hw>Des"e*cra`ter</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
desecrates; a profaner.</def> <rj><au>Harper's Mag.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desecration</ent><br/
<hw>Des`e*cra"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
desecrating; profanation; condition of anything desecrated.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desecrator</ent><br/
<hw>Des"e*cra`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
desecrates.</def> <ldquo/<xex>Desecrators</xex> of the church.<rdquo/
<rj><au>Morley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desegmentation</ent><br/
<hw>De*seg`men*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Anat.)</fld> <def>The loss or obliteration of division into
segments; <as>as, a <ex>desegmentation</ex> of the body</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>desegregate</ent><br/
<hw>de*seg"re*gate</hw> <pos>v. t.</pos> <def>to eliminate laws,
regulations, or customs which prohibit members of a specific racial or
national group from using (certain locations, organizations, or
facilities); to introduce members of a racial or religious group into (a
community, facility, or organization from which they had been
barred).</def><br/
[<source>PJC</source>]</p>

<p><ent>desegregation</ent><br/
<hw>de`seg*re*ga"tion</hw> <pos>n.</pos> <def>the action of
incorporating a racial or religious group into a community; the
elimination of laws, regulations, or customs which prohibit members of a
specific racial or national group from using certain locations,
organizations, or facilities.</def> <note>In the 1960's and 1970's civil
rights legislation was passed by the U. S. congress, prohibiting
segregation by governmental agencies and in places of public
accommodation, which resulteo in widospread besegregotion of schools and
places of business. Some segregation remains in privately operated
organizations.</note><br/
<syn><b>Syn. --</b> integration, integrating.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>desensitisation</ent><br/
<hw>desensitisation</hw> <pos>n.</pos> <def>same as
<er>desensitization</er>.</def><br/
<syn><b>Syn. --</b> desensitization.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>desensitise</ent><br/
<hw>desensitise</hw> <pos>v. t.</pos> <def>same as
<er>desensitize</er>.</def><br/
<syn><b>Syn. --</b> deaden.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>desensitized</ent><br/
<hw>desensitized</hw> <pos>adj.</pos> <def>rendered
insensitive.</def><br/
<syn><b>Syn. --</b> deadened.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>desensitization</ent><br/
<hw>desensitization</hw> <pos>n.</pos> <def>the process of reducing or
eliminating sensitivity.</def><br/
<syn><b>Syn. --</b> desensitisation.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>desensitize</ent><br/
<hw>desensitize</hw> <pos>v. t.</pos> <def>to rendered insensitive or
less sensitive. Opposite of <er>sensitize</er>.</def><br/
<syn><b>Syn. --</b> deaden.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>desensitizing</ent><br/
<hw>desensitizing</hw> <pos>adj.</pos> <def>making less susceptible or
sensitive to either physical or emotional stimuli. Opposite of
<ant>sensitizing</ant>.</def> [Narrower terms:
<stype>numbing</stype>]<br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Desert</ent><br/
<hw>De*sert"</hw> <pr>(d<esl/*z<etil/rt")</pr>, <pos>n.</pos> <ety>[OF.
<ets>deserte</ets>, <ets>desserte</ets>, merit, recompense, fr.
<ets>deservir</ets>, <ets>desservir</ets>, to merit. See
<er>Deserve</er>.]</ety> <def>That which is deserved; the reward or the
punishment justly due; claim to recompense, usually in a good sense;
right to reward; merit.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>According to their <qex>deserts</qex> will I judge them.</q>
<rj><qau>Ezek. vii. 27.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Andronicus, surnamed Pius<br/
For many good and great <qex>deserts</qex> to Rome.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>His reputation falls far below his <qex>desert</qex>.</q>
<rj><qau>A. Hamilton.</qau></rj></p>

<p><syn><b>Syn.</b> -- Merit; worth; excellence; due.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desert</ent><br/
<hw>Des"ert</hw> <pr>(d<ecr/z"<etil/rt)</pr>, <pos>n.</pos> <ety>[F.
<ets>d<eacute/sert</ets>, L. <ets>desertum</ets>, from
<ets>desertus</ets> solitary, desert, pp. of <ets>deserere</ets> to
desert; <ets>de-</ets> + <ets>serere</ets> to join together. See
<er>Series</er>.]</ety> <sn>1.</sn> <def>A deserted or forsaken region;
a barren tract incapable of supporting population, as the vast sand
plains of Asia and Africa which are destitute of moisture and
vegetation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A dreary <qex>desert</qex> and a gloomy waste.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A tract, which may be capable of sustaining a
population, but has been left unoccupied and uncultivated; a wilderness;
a solitary place.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He will make her wilderness like Eden, and her <qex>desert</qex>
like the garden of the Lord.</q> <rj><qau>Is. li. 3.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note>Also figuratively.</note><br/
[<source>1913 Webster</source>]</p>

<p><q>Before her extended<br/
Dreary and vast and silent, the <qex>desert</qex> of life.</q>
<rj><qau>Longfellow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desert</ent><br/
<hw>Des"ert</hw>, <pos>a.</pos> <ety>[Cf. L. <ets>desertus</ets>, p. p.
of <ets>deserere</ets>, and F. <ets>d<eacute/sert</ets>. See 2d
<er>Desert</er>.]</ety> <def>Of or pertaining to a desert; forsaken;
without life or cultivation; unproductive; waste; barren; wild;
desolate; solitary; <as>as, they landed on a <ex>desert</ex>
island</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He . . . went aside privately into a <qex>desert</qex> place.</q>
<rj><qau>Luke ix. 10.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Full many a flower is born to blush unseen,<br/
And waste its sweetness on the <qex>desert</qex> air.</q>
<rj><qau>Gray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Desert flora</b></col> <fld>(Bot.)</fld>, <cd>the
assemblage of plants growing naturally in a desert, or in a dry and
apparently unproductive place.</cd> -- <col><b>Desert hare</b></col>
<fld>(Zool.)</fld>, <cd>a small hare (<spn>Lepus sylvaticus</spn>, var.
<varn>Arizon<ae/</varn>) inhabiting the deserts of the Western United
States.</cd> -- <col><b>Desert mouse</b></col> <fld>(Zool.)</fld>,
<cd>an American mouse (<spn>Hesperomys eremicus</spn>), living in the
Western deserts.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desert</ent><br/
<hw>De*sert"</hw> <pr>(d<esl/*z<etil/rt")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Deserted</conjf>; <pos>p. pr. &
vb. n.</pos> <conjf>Deserting</conjf>.]</vmorph> <ety>[Cf. L.
<ets>desertus</ets>, p. p. of <ets>deserere</ets> to desert, F.
<ets>d<eacute/serter</ets>. See 2d <er>Desert</er>.]</ety> <sn>1.</sn>
<def>To leave (especially something which one should stay by and
support); to leave in the lurch; to abandon; to forsake; -- implying
blame, except sometimes when used of <xex>localities</xex>; <as>as, to
<ex>desert</ex> a friend, a principle, a cause, one's
country</as>.</def> <ldquo/The <xex>deserted</xex> fortress.<rdquo/
<rj><au>Prescott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mil.)</fld> <def>To abandon (the service) without
leave; to forsake in violation of duty; to abscond from; <as>as, to
<ex>desert</ex> the army; to <ex>desert</ex> one's
colors.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desert</ent><br/
<hw>De*sert"</hw>, <pos>v. i.</pos> <def>To abandon a service without
leave; to quit military service without permission, before the
expiration of one's term; to abscond.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The soldiers . . . <qex>deserted</qex> in numbers.</q>
<rj><qau>Bancroft.</qau></rj></p>

<p><syn><b>Syn.</b> -- To abandon; forsake; leave; relinquish; renounce;
quit; depart from; abdicate. See <er>Abandon</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>deserted</ent><br/
<hw>deserted</hw> <pos>adj.</pos> <sn>1.</sn> <def>having no residents;
<as>as, <ex>deserted</ex> villages</as>.</def><br/
<syn><b>Syn. --</b> uninhabited.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>no longer used by people.</def><br/
<syn><b>Syn. --</b> abandoned, derelict.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>3.</sn> <def>remote from civilization; <as>as, the victim was
lured to a <ex>deserted</ex> spot</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>4.</sn> <def>being left by another without support or assistance;
left in the lurch; -- of people; <as>as, <ex>deserted</ex> wives and
children</as>.</def> <note>In this sense, the label implies some level
of dependence of the person(s) being deserted on those deserting
them.</note></p>

<p><ent>Deserter</ent><br/
<hw>De*sert"er</hw> <fld>(d<esl/*z<etil/rt"<etil/r)</fld>, <pos>n.</pos>
<def>One who forsakes a duty, a cause or a party, a friend, or any one
to whom he owes service; especially, a soldier or a seaman who abandons
the service without leave; one guilty of desertion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desertful</ent><br/
<hw>De*sert"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Meritorious.</def>
<mark>[R.]</mark> <rj><au>Beau. & Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desertion</ent><br/
<hw>De*ser"tion</hw> <pr>(d<esl/*z<etil/r"sh<ucr/n)</pr>, <pos>n.</pos>
<ety>[L. <ets>desertio</ets>: cf. F. <ets>d<eacute/sertion</ets>.]</ety>
<sn>1.</sn> <def>The act of deserting or forsaking; abandonment of a
service, a cause, a party, a friend, or any post of duty; the quitting
of one's duties willfully and without right; esp., an absconding from
military or naval service.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Such a resignation would have seemed to his superior a
<qex>desertion</qex> or a reproach.</q>
<rj><qau>Bancroft.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The state of being forsaken; desolation; <as>as, the
king in his <ex>desertion</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Abandonment by God; spiritual despondency.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The spiritual agonies of a soul under <qex>desertion</qex>.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desertless</ent><br/
<hw>De*sert"less</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Without
desert.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desertlessly</ent><br/
<hw>De*sert"less*ly</hw>, <pos>adv.</pos> <def>Undeservedly.</def>
<mark>[R.]</mark> <rj><au>Beau. & Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desertness</ent><br/
<hw>Des"ert*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A deserted
condition.</def> <mark>[R.]</mark> <ldquo/The <xex>desertness</xex> of
the country.<rdquo/ <rj><au>Udall.</au></rj></p>

<p><ent>Desertrice</ent><br/
<ent>Desertrix</ent><br/
<mhw>{ <hw>De*sert"rix</hw> <pr>(?)</pr>, <hw>De*sert"rice</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[L.
<ets>desertrix</ets>.]</ety> <def>A feminine deserter.</def>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deserve</ent><br/
<hw>De*serve"</hw> <pr>(d<esl/*z<etil/rv")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Deserved</conjf> <pr>(?)</pr>;
<pos>p. pr. & vb. n.</pos> <conjf>Deserving</conjf>.]</vmorph> <ety>[OF.
<ets>deservir</ets>, <ets>desservir</ets>, to merit, L.
<ets>deservire</ets> to serve zealously, be devoted to; <ets>de-</ets> +
<ets>servire</ets> to serve. See <er>Serve</er>.]</ety> <sn>1.</sn>
<def>To earn by service; to be worthy of (something due, either good or
evil); to merit; to be entitled to; <as>as, the laborer
<ex>deserves</ex> his wages; a work of value <ex>deserves</ex>
praise.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>God exacteth of thee less than thine iniquity
<qex>deserveth</qex>.</q> <rj><qau>Job xi. 6.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>John Gay <qex>deserved</qex> to be a favorite.</q>
<rj><qau>Thackeray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Encouragement is not held out to things that <qex>deserve</qex>
reprehension.</q> <rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To serve; to treat; to benefit.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>A man that hath<br/
So well <qex>deserved</qex> me.</q> <rj><qau>Massinger.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>deserve</ent><br/
<hw>de*serve"</hw> <pr>(d<esl/*z<etil/rv")</pr>, <pos>v. i.</pos>
<def>To be worthy of recompense; -- usually with <xex>ill</xex> or with
<xex>well</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>One man may merit or <qex>deserve</qex> of another.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>deserved</ent><br/
<hw>deserved</hw> <pos>adj.</pos> <def>properly earned; warranted;
merited. Opposite of <ant>undeserved</ant>.</def><br/
<syn><b>Syn. --</b> due.</syn>
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>deservedly</ent><br/
<hw>de*serv"ed*ly</hw> <pr>(d<esl/*z<etil/rv"<ecr/d*l<ycr/)</pr>,
<pos>adv.</pos> <def>According to desert (whether good or evil);
justly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deservedness</ent><br/
<hw>De*serv"ed*ness</hw>, <pos>n.</pos> <def>Meritoriousness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deserver</ent><br/
<hw>De*serv"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
deserves.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deserving</ent><br/
<hw>De*serv"ing</hw>, <pos>n.</pos> <def>Desert; merit.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A person of great <qex>deservings</qex> from the republic.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deserving</ent><br/
<hw>De*serv"ing</hw>, <pos>a.</pos> <def>Meritorious; worthy; <as>as, a
<ex>deserving</ex> person or act</as>.</def> --
<wordforms><wf>De*serv"ing*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>desex</ent><br/
<hw>desex</hw> <pos>v. t.</pos> <def>to make infertile, especially by
removing or incapacitating the sexual organs; -- used of both males and
females.</def><br/
<syn><b>Syn. --</b> sterilize, unsex, desexualize, fix.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>desexualize</ent><br/
<hw>desexualize</hw> <pos>v. i. & t.</pos> <def>to direct one's
libidinous urges into another direction.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>same as <er>desex</er>.</def><br/
<syn><b>Syn. --</b> sterilize, desex, unsex, fix, make
infertile.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Deshabille</ent><br/
<hw>Des`ha*bille</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>d<eacute/shabill<eacute/</ets>, fr. <ets>d<eacute/shabiller</ets>
to undress; pref. <ets>d<eacute/s-</ets> (L. <ets>dis-</ets>) +
<ets>habiller</ets> to dress. See <er>Habiliment</er>, and cf.
<er>Dishabille</er>.]</ety> <def>An undress; a careless
toilet.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>desicate</ent><br/
<hw>desicate</hw> <pos>v. t.</pos> <def>variant spelling of
<er>desiccate</er>.</def><br/
<syn><b>Syn. --</b> dehydrate, dry up, dessicate.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>dessicate</ent><br/
<hw>dessicate</hw> <pos>v. t.</pos> <def>variant spelling of
<er>desiccate</er>.</def><br/
<syn><b>Syn. --</b> dehydrate, dry up, desicate.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Desiccant</ent><br/
<hw>De*sic"cant</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>desiccans</ets>, p. pr. of <ets>desiccare</ets>. See
<er>Desiccate</er>.]</ety> <def>Drying; desiccative.</def> --
<def2><pos>n.</pos> <fld>(Med.)</fld> <def>A medicine or application for
drying up a sore.</def></def2> <rj><au>Wiseman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desiccate</ent><br/
<hw>Des"ic*cate</hw> <pr>(?; 277)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Desiccated</conjf>; <pos>p. pr.
& vb. n.</pos> <conjf>Desiccating</conjf>.]</vmorph> <ety>[L.
<ets>desiccatus</ets>, p. p. of <ets>desiccare</ets> to dry up;
<ets>de-</ets> + <ets>siccare</ets> to dry, <ets>siccus</ets> dry. See
<er>Sack</er> wine.]</ety> <def>To dry up; to deprive or exhaust of
moisture; to preserve by drying; <as>as, to <ex>desiccate</ex> fish or
fruit</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Bodies <qex>desiccated</qex> by heat or age.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desiccate</ent><br/
<hw>Des"ic*cate</hw>, <pos>v. i.</pos> <def>To become dry.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desiccation</ent><br/
<hw>Des`ic*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>dessiccation</ets>.]</ety> <def>The act of desiccating, or the
state of being desiccated.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desiccative</ent><br/
<hw>De*sic"ca*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>dessicatif</ets>.]</ety> <def>Drying; tending to dry.</def>
<au>Ferrand.</au> -- <def2><pos>n.</pos> <fld>(Med.)</fld> <def>An
application for drying up secretions.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desiccator</ent><br/
<hw>Des"ic*ca`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One
who, or that which, desiccates.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Chem.)</fld> <def>A short glass jar fitted with an
air-tight cover, and containing some desiccating agent, as sulphuric
acid, phosphorus pentoxide, or calcium chloride, above which is
supported on a perforated platform the material to be dried, or
preserved from moisture.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>3.</sn> <def>A machine or apparatus for drying fruit, milk, etc.,
usually by the aid of heat; an evaporator.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Desiccatory</ent><br/
<hw>De*sic"ca*to*ry</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Desiccative.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desiderable</ent><br/
<hw>De*sid"er*a*ble</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Desirable.</def> <mark>[R.]</mark> <ldquo/Good and
<xex>desiderable</xex> things.<rdquo/ <rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desiderata</ent><br/
\'d8<hw>De*sid`e*ra"ta</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <def>See
<er>Desideratum</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desiderate</ent><br/
<hw>De*sid"er*ate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Desiderated</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Desiderating</conjf>.]</vmorph> <ety>[L. <ets>desideratus</ets>,
p. p. of <ets>desiderare</ets> to desire, miss. See <er>Desire</er>, and
cf. <er>Desideratum</er>.]</ety> <def>To desire; to feel the want of; to
lack; to miss; to want.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Pray have the goodness to point out one word missing that ought to
have been there -- please to insert a <qex>desiderated</qex> stanza. You
can not.</q> <rj><qau>Prof. Wilson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Men were beginning . . . to <qex>desiderate</qex> for them an
actual abode of fire.</q> <rj><qau>A. W. Ward.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desideration</ent><br/
<hw>De*sid`er*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>desideratio</ets>.]</ety> <def>Act of desiderating; also, the thing
desired.</def> <mark>[R.]</mark> <rj><au>Jeffrey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desiderative</ent><br/
<hw>De*sid"er*a*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>desiderativus</ets>.]</ety> <def>Denoting desire; <as>as,
<ex>desiderative</ex> verbs</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desiderative</ent><br/
<hw>De*sid"er*a*tive</hw>, <pos>n.</pos> <sn>1.</sn> <def>An object of
desire.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Gram.)</fld> <def>A verb formed from another verb
by a change of termination, and expressing the desire of doing that
which is indicated by the primitive verb.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desideratum</ent><br/
\'d8<hw>De*sid`e*ra"tum</hw> <pr>(?)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Desiderata</plw> <pr>(#)</pr>.</plu> <ety>[L.,
fr. <ets>desideratus</ets>, p. p. See <er>Desiderate</er>.]</ety>
<def>Anything desired; that of which the lack is felt; a want generally
felt and acknowledge.</def></p>

<p><ent>Desidious</ent><br/
<ent>Desidiose</ent><br/
<mhw>{ <hw>De*sid"i*ose`</hw> <pr>(?)</pr>, <hw>De*sid"i*ous</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[L. <ets>desidiosus</ets>, fr.
<ets>desidia</ets> a sitting idle, fr. <ets>desid<emac/re</ets> to sit
idle; <ets>de-</ets> + <ets>sed<emac/re</ets> to sit.]</ety> <def>Idle;
lazy.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desidiousness</ent><br/
<hw>De*sid"i*ous*ness</hw>, <pos>n.</pos> <def>The state or quality of
being desidiose, or indolent.</def> <mark>[Obs.]</mark> <rj><au>N.
Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desight</ent><br/
<hw>De*sight"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>de-</ets> + <ets>sight</ets>.]</ety> <def>An unsightly
object.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desightment</ent><br/
<hw>De*sight"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
making unsightly; disfigurement.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>To substitute jury masts at whatever <qex>desightment</qex> or
damage in risk.</q> <rj><qau>London Times.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Design</ent><br/
<hw>De*sign"</hw> <pr>(?; 277)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Designed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Designing</conjf>.]</vmorph> <ety>[F.
<ets>d<eacute/signer</ets> to designate, cf. F. <ets>dessiner</ets> to
draw, <ets>dessin</ets> drawing, <ets>dessein</ets> a plan or scheme;
all, ultimately, from L. <ets>designare</ets> to designate;
<ets>de-</ets> + <ets>signare</ets> to mark, mark out, <ets>signum</ets>
mark, sign. See <er>Sign</er>, and cf. <er>Design</er>, <pos>n.</pos>,
<er>Designate</er>.]</ety> <sn>1.</sn> <def>To draw preliminary outline
or main features of; to sketch for a pattern or model; to delineate; to
trace out; to draw.</def> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To mark out and exhibit; to designate; to indicate;
to show; to point out; to appoint.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We shall see<br/
Justice <qex>design</qex> the victor's chivalry.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Meet me to-morrow where the master<br/
And this fraternity shall <qex>design</qex>.</q> <rj><qau>Beau. &
Fl.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To create or produce, as a work of art; to form a
plan or scheme of; to form in idea; to invent; to project; to lay out in
the mind; <as>as, a man <ex>designs</ex> an essay, a poem, a statue, or
a cathedral</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To intend or purpose; -- usually with <xex>for</xex>
before the remote object, but sometimes with <xex>to</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Ask of politicians the end for which laws were originally
<qex>designed</qex>.</q> <rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He was <qex>designed</qex> to the study of the law.</q>
<rj><qau>Dryden.</qau></rj></p>

<p><syn><b>Syn.</b> -- To sketch; plan; purpose; intend; propose;
project; mean.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Design</ent><br/
<hw>De*sign"</hw>, <pos>v. i.</pos> <def>To form a design or designs; to
plan.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Design for</b></col>, <cd>to intend to go to.</cd>
<mark>[Obs.]</mark> <ldquo/From this city she <xex>designed for</xex>
Collin [Cologne].<rdquo/ <rj><au>Evelyn.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 398 --></p>

<p><ent>Design</ent><br/
<hw>De*sign"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf.
<ets>dessein</ets>, <ets>dessin</ets>.]</ety> <sn>1.</sn> <def>A
preliminary sketch; an outline or pattern of the main features of
something to be executed, as of a picture, a building, or a decoration;
a delineation; a plan.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A plan or scheme formed in the mind of something to
be done; preliminary conception; idea intended to be expressed in a
visible form or carried into action; intention; purpose; -- often used
in a bad sense for evil intention or purpose; scheme; plot.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The vast <qex>design</qex> and purpose of the King.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The leaders of that assembly who withstood the <qex>designs</qex>
of a besotted woman.</q> <rj><qau>Hallam.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A . . . settled <qex>design</qex> upon another man's life.</q>
<rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>How little he could guess the secret <qex>designs</qex> of the
court!</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Specifically, intention or purpose as revealed or
inferred from the adaptation of means to an end; <as>as, the argument
from <ex>design</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The realization of an inventive or decorative plan;
esp., a work of decorative art considered as a new creation; conception
or plan shown in completed work; <as>as, this carved panel is a fine
<ex>design</ex>, or of a fine <ex>design</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Mus.)</fld> <def>The invention and conduct of the
subject; the disposition of every part, and the general order of the
whole.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Arts of design</b></col>, <cd>those into which the
designing of artistic forms and figures enters as a principal part, as
architecture, painting, engraving, sculpture.</cd> -- <col><b>School of
design</b></col>, <cd>one in which are taught the invention and
delineation of artistic or decorative figures, patterns, and the
like.</cd></cs></p>

<p><syn><b>Syn.</b> -- Intention; purpose; scheme; project; plan;
idea.</syn> <usage> -- <er>Design</er>, <er>Intention</er>,
<er>Purpose</er>. <xex>Design</xex> has reference to something
definitely aimed at. <xex>Intention</xex> points to the feelings or
desires with which a thing is sought. <xex>Purpose has</xex> reference
to a settled choice or determination for its attainment. <ldquo/I had no
<xex>design</xex> to injure you,<rdquo/ means it was no part of my aim
or object. <ldquo/I had no <xex>intention</xex> to injure you,<rdquo/
means, I had no wish or desire of that kind. <ldquo/My
<xex>purpose</xex> was directly the reverse,<rdquo/ makes the case still
stronger.</usage><br/
[<source>1913 Webster</source>]</p>

<p><q>Is he a prudent man . . . that lays <qex>designs</qex> only for a
day, without any prospect to the remaining part of his life?</q>
<rj><qau>Tillotson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I wish others the same <qex>intention</qex>, and greater
successes.</q> <rj><qau>Sir W. Temple.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>It is the <qex>purpose</qex> that makes strong the vow.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Designable</ent><br/
<hw>Des"ig*na*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of being
designated or distinctly marked out; distinguishable.</def>
<rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Designate</ent><br/
<hw>Des"ig*nate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>designatus</ets>, p. p. of <ets>designare</ets>. See
<er>Design</er>, <pos>v. t.</pos>]</ety> <def>Designated; appointed;
chosen.</def> <mark>[R.]</mark> <rj><au>Sir G. Buck.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Designate</ent><br/
<hw>Des"ig*nate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Designated</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Designating</conjf>.]</vmorph> <sn>1.</sn> <def>To mark out and
make known; to point out; to name; to indicate; to show; to distinguish
by marks or description; to specify; <as>as, to <ex>designate</ex> the
boundaries of a country; to <ex>designate</ex> the rioters who are to be
arrested.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To call by a distinctive title; to name.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To indicate or set apart for a purpose or duty; --
with <xex>to</xex> or <xex>for</xex>; <as>as, to <ex>designate</ex> an
officer for or to the command of a post or station</as>.</def></p>

<p><syn><b>Syn.</b> -- To name; denominate; style; entitle;
characterize; describe.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Designation</ent><br/
<hw>Des`ig*na"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>designatio</ets>: cf. F. <ets>d<eacute/signation</ets>.]</ety>
<sn>1.</sn> <def>The act of designating; a pointing out or showing;
indication.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Selection and appointment for a purpose; allotment;
direction.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which designates; a distinguishing mark or
name; distinctive title; appellation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The usual <qex>designation</qex> of the days of the week.</q>
<rj><qau>Whewell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Use or application; import; intention;
signification, as of a word or phrase.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Finite and infinite seem . . . to be attributed primarily, in
their first <qex>designation</qex>, only to those things which have
parts.</q> <rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Designative</ent><br/
<hw>Des"ig*na*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>d<eacute/signatif</ets>.]</ety> <def>Serving to designate or
indicate; pointing out.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Designator</ent><br/
<hw>Des"ig*na`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.]</ety>
<sn>1.</sn> <fld>(Rom. Antiq.)</fld> <def>An officer who assigned to
each his rank and place in public shows and ceremonies.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who designates.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Designatory</ent><br/
<hw>Des"ig*na*to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Serving to
designate; designative; indicating.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Designedly</ent><br/
<hw>De*sign"ed*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>By design;
purposely; intentionally; -- opposed to <xex>accidentally</xex>,
<xex>ignorantly</xex>, or <xex>inadvertently</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Designer</ent><br/
<hw>De*sign"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who
designs, marks out, or plans; a contriver.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Fine Arts)</fld> <def>One who produces or creates
original works of art or decoration.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A plotter; a schemer; -- used in a bad
sense.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Designful</ent><br/
<hw>De*sign"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Full of design;
scheming.</def> <mark>[R.]</mark> --
<wordforms><wf>De*sign"ful*ness</wf>, <pos>n.</pos>
<mark>[R.]</mark></wordforms> <rj><au>Barrow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Designing</ent><br/
<hw>De*sign"ing</hw>, <pos>a.</pos> <def>Intriguing; artful; scheming;
<as>as, a <ex>designing</ex> man</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Designing</ent><br/
<hw>De*sign"ing</hw>, <pos>n.</pos> <def>The act of making designs or
sketches; the act of forming designs or plans.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Designless</ent><br/
<hw>De*sign"less</hw>, <pos>a.</pos> <def>Without design.</def>
<mark>[Obs.]</mark> -- <wordforms><wf>De*sign"less*ly</wf>,
<pos>adv.</pos> <mark>[Obs.]</mark></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Designment</ent><br/
<hw>De*sign"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>Delineation; sketch; design; ideal; invention.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>For though that some mean artist's skill were shown<br/
In mingling colors, or in placing light,<br/
Yet still the fair <qex>designment</qex> was his own.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Design; purpose; scheme.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desilver</ent><br/
<hw>De*sil"ver</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To deprive of
silver; <as>as, to <ex>desilver</ex> lead</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desilverization</ent><br/
<hw>De*sil`ver*i*za"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act
or the process of freeing from silver; also, the condition resulting
from the removal of silver.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desilverize</ent><br/
<hw>De*sil"ver*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To deprive,
or free from, silver; to remove silver from.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desinence</ent><br/
<hw>Des"i*nence</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>d<eacute/sinence</ets>.]</ety> <def>Termination; ending.</def>
<rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desinent</ent><br/
<hw>Des"i*nent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>desinens</ets>, p. pr. of <ets>desinere</ets>, <ets>desitum</ets>,
to leave off, cease; <ets>de-</ets> + <ets>sinere</ets> to let,
allow.]</ety> <def>Ending; forming an end; lowermost.</def>
<mark>[Obs.]</mark> <ldquo/Their <xex>desinent</xex> parts, fish.<rdquo/
<rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desinential</ent><br/
<hw>Des`i*nen"tial</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>d<eacute/sinentiel</ets>.]</ety> <def>Terminal.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Furthermore, <qex>b</qex>, as a <qex>desinential</qex> element,
has a dynamic function.</q> <rj><qau>Fitzed. Hall.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desipient</ent><br/
<hw>De*sip"i*ent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>desipiens</ets>, p. pr. of <ets>desipere</ets> to be foolish;
<ets>de-</ets> + <ets>sapere</ets> to be wise.]</ety> <def>Foolish;
silly; trifling.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desirability</ent><br/
<hw>De*sir`a*bil"i*ty</hw>, <pos>n.</pos> <def>The state or quality of
being desirable; desirableness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desirable</ent><br/
<hw>De*sir"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F.
<ets>d<eacute/sirable</ets>, fr. L. <ets>desiderabilis</ets>. See
<er>Desire</er>, <pos>v. t.</pos>]</ety> <def>Worthy of desire or
longing; fitted to excite desire or a wish to possess; pleasing;
agreeable.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>All of them <qex>desirable</qex> young men.</q> <rj><qau>Ezek.
xxiii. 12.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>As things <qex>desirable</qex> excite<br/
Desire, and objects move the appetite.</q>
<rj><qau>Blackmore.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desirableness</ent><br/
<hw>De*sir"a*ble*ness</hw>, <pos>n.</pos> <def>The quality of being
desirable.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>desirableness</qex> of the Austrian alliance.</q>
<rj><qau>Froude.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desirably</ent><br/
<hw>De*sir"a*bly</hw>, <pos>adv.</pos> <def>In a desirable
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desire</ent><br/
<hw>De*sire"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Desired</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Desiring</conjf>.]</vmorph> <ety>[F. <ets>d<eacute/sirer</ets>,
L. <ets>desiderare</ets>, origin uncertain, perh. fr. <ets>de-</ets> +
<ets>sidus</ets> star, constellation, and hence orig., to turn the eyes
from the stars. Cf. <er>Consider</er>, and <er>Desiderate</er>, and see
<er>Sidereal</er>.]</ety> <sn>1.</sn> <def>To long for; to wish for
earnestly; to covet.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Neither shall any man <qex>desire</qex> thy land.</q> <rj><qau>Ex.
xxxiv. 24.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Ye <qex>desire</qex> your child to live.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To express a wish for; to entreat; to
request.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Then she said, Did I <qex>desire</qex> a son of my lord?</q>
<rj><qau>2 Kings iv. 28.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Desire</qex> him to go in; trouble him no more.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To require; to demand; to claim.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>A doleful case <qex>desires</qex> a doleful song.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To miss; to regret.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>She shall be pleasant while she lives, and <qex>desired</qex> when
she dies.</q> <rj><qau>Jer. Taylor.</qau></rj></p>

<p><syn><b>Syn.</b> -- To long for; hanker after; covet; wish; ask;
request; solicit; entreat; beg.</syn> <usage> -- To <er>Desire</er>,
<er>Wish</er>. In <xex>desire</xex> the feeling is usually more eager
than in <xex>wish</xex>. <ldquo/I <xex>wish</xex> you to do this<rdquo/
is a milder form of command than <ldquo/I <xex>desire</xex> you to do
this,<rdquo/ though the feeling prompting the injunction may be the
same. <au>C. J. Smith.</au></usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desire</ent><br/
<hw>De*sire"</hw>, <pos>n.</pos> <ety>[F. <ets>d<eacute/sir</ets>, fr.
<ets>d<eacute/sirer</ets>. See <er>Desire</er>, <pos>v. t.</pos>]</ety>
<sn>1.</sn> <def>The natural longing that is excited by the enjoyment or
the thought of any good, and impels to action or effort its continuance
or possession; an eager wish to obtain or enjoy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Unspeakable <qex>desire</qex> to see and know.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An expressed wish; a request; petition.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And slowly was my mother brought<br/
To yield consent to my <qex>desire</qex>.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Anything which is desired; an object of
longing.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>Desire</qex> of all nations shall come.</q> <rj><qau>Hag.
ii. 7.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Excessive or morbid longing; lust;
appetite.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Grief; regret.</def> <mark>[Obs.]</mark>
<rj><au>Chapman.</au></rj></p>

<p><syn><b>Syn.</b> -- Wish; appetency; craving; inclination; eagerness;
aspiration; longing.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desireful</ent><br/
<hw>De*sire"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Filled with
desire; eager.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>desireful</qex> troops.</q> <rj><qau>Godfrey
(1594).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desirefulness</ent><br/
<hw>De*sire"ful*ness</hw>, <pos>n.</pos> <def>The state of being
desireful; eagerness to obtain and possess.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>desirefulness</qex> of our minds much augmenteth and
increaseth our pleasure.</q> <rj><qau>Udall.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desireless</ent><br/
<hw>De*sire"less</hw>, <pos>a.</pos> <def>Free from desire.</def>
<rj><au>Donne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desirer</ent><br/
<hw>De*sir"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who desires,
asks, or wishes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desirous</ent><br/
<hw>De*sir"ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F.
<ets>d<eacute/sireux</ets>, OF. <ets>desiros</ets>, fr.
<ets>desir</ets>. See <er>Desire</er>, <pos>n.</pos>]</ety> <def>Feeling
desire; eagerly wishing; solicitous; eager to obtain;
covetous.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Jesus knew that they were <qex>desirous</qex> to ask him.</q>
<rj><qau>John xvi. 19.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Be not <qex>desirous</qex> of his dainties.</q> <rj><qau>Prov.
xxiii. 3.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desirously</ent><br/
<hw>De*sir"ous*ly</hw>, <pos>adv.</pos> <def>With desire;
eagerly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desirousness</ent><br/
<hw>De*sir"ous*ness</hw>, <pos>n.</pos> <def>The state of being
desirous.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desist</ent><br/
<hw>De*sist"</hw> <pr>(?; 277)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Desisted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Desisting</conjf>.]</vmorph> <ety>[L. <ets>desistere</ets>;
<ets>de-</ets> + <ets>sistere</ets> to stand, stop, fr. <ets>stare</ets>
to stand: cf. F. <ets>d<eacute/sister</ets>. See <er>Stand</er>.]</ety>
<def>To cease to proceed or act; to stop; to forbear; -- often with
<xex>from</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Never <qex>desisting</qex> to do evil.</q> <rj><qau>E.
Hall.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>desist</qex> from his bad practice.</q>
<rj><qau>Massinger.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Desist</qex> (thou art discern'd,<br/
And toil'st in vain).</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desistance</ent><br/
<hw>De*sist"ance</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>desistance</ets>.]</ety> <def>The act or state of desisting;
cessation.</def> <mark>[R.]</mark> <rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>If fatigue of body or brain were in every case followed by
<qex>desistance</qex> . . . then would the system be but seldom out of
working order.</q> <rj><qau>H. Spencer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desistive</ent><br/
<hw>De*sist"ive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Desist</er>.]</ety> <def>Final; conclusive; ending.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desition</ent><br/
<hw>De*si"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Desinent</er>.]</ety> <def>An end or ending.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desitive</ent><br/
<hw>Des"i*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Final; serving to
complete; conclusive.</def> <mark>[Obs.]</mark>
<ldquo/<xex>Desitive</xex> propositions.<rdquo/ <rj><au>I.
Watts.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desitive</ent><br/
<hw>Des"i*tive</hw>, <pos>n.</pos> <fld>(Logic)</fld> <def>A proposition
relating to or expressing an end or conclusion.</def>
<mark>[Obs.]</mark> <rj><au>I. Watts.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desk</ent><br/
<hw>Desk</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>deske</ets>,
the same word as <ets>dish</ets>, <ets>disk</ets>. See <er>Dish</er>,
and cf. <er>Disk</er>.]</ety> <sn>1.</sn> <def>A table, frame, or case,
usually with sloping top, but often with flat top, for the use writers
and readers. It often has a drawer or repository underneath.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A reading table or lectern to support the book from
which the liturgical service is read, differing from the pulpit from
which the sermon is preached; also (esp. in the United States), a
pulpit. Hence, used symbolically for <ldquo/the clerical
profession.<rdquo/</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desk</ent><br/
<hw>Desk</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Desked</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Desking</conjf>.]</vmorph> <def>To shut up, as in a desk; to
treasure.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deskwork</ent><br/
<hw>Desk"work`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Work done at a
desk, as by a clerk or writer.</def> <rj><au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desman</ent><br/
<hw>Des"man</hw> <pr>(d<ecr/s"m<ait/n)</pr>, <pos>n.</pos> <ety>[Cf. Sw.
<ets>desman</ets> musk.]</ety> <fld>(Zool.)</fld> <def>An amphibious,
insectivorous mammal found in Russia (<spn>Myogale moschata</spn>). It
is allied to the moles, but is called <altname>muskrat</altname> by some
English writers.</def> <altsp>[Written also
<asp>d<ae/sman</asp>.]</altsp></p>

<p><ent>Desmidian</ent><br/
<ent>Desmid</ent><br/
<mhw>{ <hw>Des"mid</hw> <pr>(?)</pr>, <hw>Des*mid"i*an</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[Gr. <grk>desmo`s</grk> chain +
<grk>e'i^dos</grk> form.]</ety> <fld>(Bot.)</fld> <def>A microscopic
plant of the family <fam>Desmidi<ae/</fam>, a group of unicellular
alg<ae/ in which the species have a greenish color, and the cells
generally appear as if they consisted of two coalescing
halves.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desmine</ent><br/
<hw>Des"mine</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>de`smh</grk>, <grk>desmo`s</grk>, bundle, fr. <grk>dei^n</grk> to
bind.]</ety> <fld>(Min.)</fld> <def>Same as <er>Stilbite</er>. It
commonly occurs in bundles or tufts of crystals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desmobacteria</ent><br/
\'d8<hw>Des`mo*bac*te"ri*a</hw>
<pr>(d<ecr/s`m<osl/*b<acr/k*t<emac/"r<icr/*<adot/)</pr>, <pos>n.
pl.</pos> <ety>[Gr. <grk>desmo`s</grk> bond + E.
<ets>bacteria</ets>.]</ety> <def>See <er>Microbacteria</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desmodontidae</ent><br/
<hw>Desmodontidae</hw> <pos>n.</pos> <def>a natural family comprising
the true vampire bats.</def><br/
<syn><b>Syn. --</b> family <fam>Desmodontidae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Desmodus</ent><br/
<hw>Desmodus</hw> <pos>n.</pos> <def>the type genus of the
<fam>Desmodontidae</fam>, consisting of vampire bats.</def><br/
<syn><b>Syn. --</b> genus <gen>Desmodus</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Desmodont</ent><br/
<hw>Des"mo*dont</hw> <pr>(d<ecr/s"m<osl/*d<ocr/nt)</pr>, <pos>n.</pos>
<ety>[Gr. <grk>desmo`s</grk> bond + <grk>'odoy`s</grk>,
<grk>'odo`ntos</grk>, tooth.]</ety> <fld>(Zool.)</fld> <def>A member of
a group of South American blood-sucking bats, of the genera
<gen>Desmodus</gen> and <gen>Diphylla</gen>. See
<er>Vampire</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desmognathous</ent><br/
<hw>Des*mog"na*thous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>desmo`s</grk> bond + <grk>gna`qos</grk> jaw.]</ety>
<fld>(Zool.)</fld> <def>Having the maxillo-palatine bones united; --
applied to a group of carinate birds (<ord>Desmognath<ae/</ord>),
including various wading and swimming birds, as the ducks and herons,
and also raptorial and other kinds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desmoid</ent><br/
<hw>Des"moid</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>desmo`s</grk> ligament + <ets>-oid</ets>.]</ety> <fld>(Anat.)</fld>
<def>Resembling, or having the characteristics of, a ligament;
ligamentous.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desmology</ent><br/
<hw>Des*mol"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>desmo`s</grk> ligament + <ets>-logy</ets>.]</ety> <def>The science
which treats of the ligaments.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desmomyaria</ent><br/
\'d8<hw>Des`mo*my*a"ri*a</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
fr. Gr. <grk>desmo`s</grk> bond + <grk>mu^s</grk> muscle.]</ety>
<fld>(Zool.)</fld> <def>The division of Tunicata which includes the
Salp<ae/. See <er>Salpa</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desolate</ent><br/
\'d8<hw>Des"o*late</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>desolatus</ets>, p. p. of <ets>desolare</ets> to leave alone,
forsake; <ets>de-</ets> + <ets>solare</ets> to make lonely,
<ets>solus</ets> alone. See <er>Sole</er>, <pos>a.</pos>]</ety>
<sn>1.</sn> <def>Destitute or deprived of inhabitants; deserted;
uninhabited; hence, gloomy; <as>as, a <ex>desolate</ex> isle; a
<ex>desolate</ex> wilderness; a <ex>desolate</ex> house.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>I will make Jerusalem . . . a den of dragons, and I will make the
cities of Judah <qex>desolate</qex>, without an inhabitant.</q>
<rj><qau>Jer. ix. 11.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And the silvery marish flowers that throng<br/
The <qex>desolate</qex> creeks and pools among.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Laid waste; in a ruinous condition; neglected;
destroyed; <as>as, <ex>desolate</ex> altars</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Left alone; forsaken; lonely; comfortless.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Have mercy upon, for I am <qex>desolate</qex>.</q> <rj><qau>Ps.
xxv. 16.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Voice of the poor and <qex>desolate</qex>.</q>
<rj><qau>Keble.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Lost to shame; dissolute.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Destitute of; lacking in.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I were right now of tales <qex>desolate</qex>.</q>
<rj><qau>Chaucer.</qau></rj></p>

<p><syn><b>Syn.</b> -- Desert; uninhabited; lonely; waste.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desolate</ent><br/
<hw>Des"o*late</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Desolated</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Desolating</conjf>.]</vmorph> <sn>1.</sn> <def>To make desolate;
to leave alone; to deprive of inhabitants; <as>as, the earth was nearly
<ex>desolated</ex> by the flood</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To lay waste; to ruin; to ravage; <as>as, a fire
<ex>desolates</ex> a city</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Constructed in the very heart of a <qex>desolating</qex> war.</q>
<rj><qau>Sparks.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>desolated</ent><br/
<hw>desolated</hw> <pos>adj.</pos> <def>reduced to a barren and lifeless
state.</def><br/
<syn><b>Syn. --</b> blasted, desolate, devastated, ravaged, ruined,
wasted.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Desolately</ent><br/
<hw>Des"o*late*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a desolate
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desolateness</ent><br/
<hw>Des"o*late*ness</hw>, <pos>n.</pos> <def>The state of being
desolate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desolater</ent><br/
<hw>Des"o*la`ter</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, desolates or lays waste.</def> <rj><au>Mede.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desolation</ent><br/
<hw>Des`o*la"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>d<eacute/solation</ets>, L. <ets>desolatio</ets>.]</ety>
<sn>1.</sn> <def>The act of desolating or laying waste; destruction of
inhabitants; depopulation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Unto the end of the war <qex>desolations</qex> are determined.</q>
<rj><qau>Dan. ix. 26.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The state of being desolated or laid waste; ruin;
solitariness; destitution; gloominess.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>You would have sold your king to slaughter, . . . <br/
And his whole kingdom into <qex>desolation</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A place or country wasted and forsaken.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>How is Babylon become a <qex>desolation</qex>!</q> <rj><qau>Jer.
l. 23.</qau></rj></p>

<p><syn><b>Syn.</b> -- Waste; ruin; destruction; havoc; devastation;
ravage; sadness; destitution; melancholy; gloom; gloominess.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desolator</ent><br/
<hw>Des"o*la`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.]</ety>
<def>Same as <er>Desolater</er>.</def> <rj><au>Byron.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desolatory</ent><br/
<hw>Des"o*la*to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>desolatorius</ets>.]</ety> <def>Causing desolation.</def>
<mark>[R.]</mark> <rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desophisticate</ent><br/
<hw>De`so*phis"ti*cate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To clear
from sophism or error.</def> <mark>[R.]</mark>
<rj><au>Hare.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desoxalic</ent><br/
<hw>Des`ox*al"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F. pref.
<ets>des-</ets> from + E. <ets>oxalic</ets>.]</ety> <fld>(Chem.)</fld>
<def>Made or derived from oxalic acid; <as>as, <ex>desoxalic</ex>
acid</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>desoxyribonucleic acid</ent><br/
<hw>desoxyribonucleic acid</hw> <pos>n.</pos> <def>same as
<er>deoxyribonucleic acid</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Despair</ent><br/
<hw>De*spair"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Despaired</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Despairing</conjf>.]</vmorph> <ety>[OE.
<ets>despeiren</ets>, <ets>dispeiren</ets>, OF. <ets>desperer</ets>, fr.
L. <ets>desperare</ets>; <ets>de-</ets> + <ets>sperare</ets> to hope;
akin to <ets>spes</ets> hope, and perh. to <ets>spatium</ets> space, E.
<ets>space</ets>, <ets>speed</ets>; cf. OF. <ets>espeir</ets> hope, F.
<ets>espoir</ets>. Cf. <er>Prosper</er>, <er>Desperate</er>.]</ety>
<def>To be hopeless; to have no hope; to give up all hope or
expectation; -- often with <xex>of</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We <qex>despaired</qex> even of life.</q> <rj><qau>2 Cor. i.
8.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Never <qex>despair</qex> of God's blessings here.</q>
<rj><qau>Wake.</qau></rj></p>

<p><syn><b>Syn.</b> -- See <er>Despond</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Despair</ent><br/
<hw>De*spair"</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To give up as
beyond hope or expectation; to despair of.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I would not <qex>despair</qex> the greatest design that could be
attempted.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To cause to despair.</def> <mark>[Obs.]</mark>
<rj><au>Sir W. Williams.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Despair</ent><br/
<hw>De*spair"</hw>, <pos>n.</pos> <ety>[Cf. OF. <ets>despoir</ets>, fr.
<ets>desperer</ets>.]</ety> <sn>1.</sn> <def>Loss of hope; utter
hopelessness; complete despondency.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We in dark dreams are tossing to and fro,<br/
Pine with regret, or sicken with <qex>despair</qex>.</q>
<rj><qau>Keble.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Before he [Bunyan] was ten, his sports were interrupted by fits of
remorse and <qex>despair</qex>.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 399 --></p>

<p><sn>2.</sn> <def>That which is despaired of.</def> <ldquo/The mere
<xex>despair</xex> of surgery he cures.<rdquo/
<rj><au>Shak.</au></rj></p>

<p><syn><b>Syn.</b> -- Desperation; despondency; hopelessness.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Despairer</ent><br/
<hw>De*spair"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
despairs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Despairful</ent><br/
<hw>De*spair"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Hopeless.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Despairing</ent><br/
<hw>De*spair"ing</hw>, <pos>a.</pos> <def>Feeling or expressing despair;
hopeless.</def> -- <wordforms><wf>De*spair"ing*ly</wf>, <pos>adv.</pos>
-- <wf>De*spair"ing*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desparple</ent><br/
<hw>De*spar"ple</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <ety>[OF.
<ets>desparpeillier</ets>.]</ety> <def>To scatter; to disparkle.</def>
<mark>[Obs.]</mark> <rj><au>Mandeville.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Despatch</ent><br/
<hw>De*spatch"</hw> <pr>(?)</pr>, <pos>n. & v.</pos> <def>Same as
<er>Dispatch</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Despecificate</ent><br/
<hw>De`spe*cif"i*cate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>de-</ets> (intens.) + <ets>specificate</ets>.]</ety> <def>To
discriminate; to separate according to specific signification or
qualities; to specificate; to desynonymize.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Inaptitude and ineptitude have been usefully
<qex>despecificated</qex>.</q> <rj><qau>Fitzed. Hall.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Despecification</ent><br/
<hw>De*spec`i*fi*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Discrimination.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Despect</ent><br/
<hw>De*spect"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>despectus</ets>, fr. <ets>despicere</ets>. See <er>Despite</er>,
<pos>n.</pos>]</ety> <def>Contempt.</def> <mark>[R.]</mark>
<rj><au>Coleridge.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Despection</ent><br/
<hw>De*spec"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>despectio</ets>.]</ety> <def>A looking down; a despising.</def>
<mark>[R.]</mark> <rj><au>W. Montagu.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Despeed</ent><br/
<hw>De*speed"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To send
hastily.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Despeeded</qex> certain of their crew.</q>
<rj><qau>Speed.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Despend</ent><br/
<hw>De*spend"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To spend; to
squander. See <er>Dispend</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Some noble men in Spain can <qex>despend</qex> <pound/50,000.</q>
<rj><qau>Howell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desperado</ent><br/
<hw>Des`per*a"do</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Desperadoes</plw> <pr>(#)</pr>.</plu> <ety>[OSp.
<ets>desperado</ets>, p. p. of <ets>desperar</ets>, fr. L.
<ets>desperare</ets>. See <er>Desperate</er>.]</ety> <def>A reckless,
furious man; a person urged by furious passions, and regardless of
consequence; a wild ruffian.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desperate</ent><br/
<hw>Des"per*ate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>desperatus</ets>, p. p. of <ets>desperare</ets>. See
<er>Despair</er>, and cf. <er>Desperado</er>.]</ety> <sn>1.</sn>
<def>Without hope; given to despair; hopeless.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I am <qex>desperate</qex> of obtaining her.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Beyond hope; causing despair; extremely perilous;
irretrievable; past cure, or, at least, extremely dangerous; <as>as, a
<ex>desperate</ex> disease; <ex>desperate</ex> fortune.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Proceeding from, or suggested by, despair; without
regard to danger or safety; reckless; furious; <as>as, a
<ex>desperate</ex> effort</as>.</def> <ldquo/<xex>Desperate</xex>
expedients.<rdquo/ <rj><au>Macaulay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Extreme, in a bad sense; outrageous; -- used to mark
the extreme predominance of a bad quality.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>desperate</qex> offendress against nature.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The most <qex>desperate</qex> of reprobates.</q>
<rj><qau>Macaulay.</qau></rj></p>

<p><syn><b>Syn.</b> -- Hopeless; despairing; desponding; rash; headlong;
precipitate; irretrievable; irrecoverable; forlorn; mad; furious;
frantic.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desperate</ent><br/
<hw>Des"per*ate</hw>, <pos>n.</pos> <def>One desperate or
hopeless.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desperately</ent><br/
<hw>Des"per*ate*ly</hw>, <pos>adv.</pos> <def>In a desperate manner;
without regard to danger or safety; recklessly; extremely; <as>as, the
troops fought <ex>desperately</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>She fell <qex>desperately</qex> in love with him.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desperateness</ent><br/
<hw>Des"per*ate*ness</hw> <pos>n.</pos> <def>Desperation;
virulence.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desperation</ent><br/
<hw>Des`per*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>desperatio</ets>: cf. OF. <ets>desperation</ets>.]</ety>
<sn>1.</sn> <def>The act of despairing or becoming desperate; a giving
up of hope.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This <qex>desperation</qex> of success chills all our
industry.</q> <rj><qau>Hammond.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A state of despair, or utter hopeless; abandonment
of hope; extreme recklessness; reckless fury.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In the <qex>desperation</qex> of the moment, the officers even
tried to cut their way through with their swords.</q> <rj><qau>W.
Irving.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Despicability</ent><br/
<hw>Des`pi*ca*bil"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Despicableness.</def> <mark>[R.]</mark>
<rj><au>Carlyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Despicable</ent><br/
<hw>Des"pi*ca*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>despicabilis</ets>, fr. <ets>despicari</ets> to despise; akin to
<ets>despicere</ets>. See <er>Despise</er>.]</ety> <def>Fit or deserving
to be despised; contemptible; mean; vile; worthless; <as>as, a
<ex>despicable</ex> man; <ex>despicable</ex> company; a
<ex>despicable</ex> gift.</as></def></p>

<p><syn><b>Syn.</b> -- Contemptible; mean; vile; worthless; pitiful;
paltry; sordid; low; base. See <er>Contemptible</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Despicableness</ent><br/
<hw>Des"pi*ca*ble*ness</hw>, <pos>n.</pos> <def>The quality of being
despicable; meanness; vileness; worthlessness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Despicably</ent><br/
<hw>Des"pi*ca*bly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a
despicable or mean manner; contemptibly; <as>as, <ex>despicably</ex>
stingy</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Despiciency</ent><br/
<hw>Des*pi"cien*cy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>despicientia</ets>. See <er>Despise</er>.]</ety> <def>A looking
down; despection.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Despisable</ent><br/
<hw>De*spis"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. OF.
<ets>despisable</ets>.]</ety> <def>Despicable; contemptible.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Despisal</ent><br/
<hw>De*spis"al</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A despising;
contempt.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>despisal</qex> of religion.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Despise</ent><br/
<hw>De*spise"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Despised</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Despising</conjf>.]</vmorph> <ety>[OF.
<ets>despis-</ets>, in some forms of <ets>despire</ets> to despise, fr.
L. <ets>despicere</ets>, <ets>despectum</ets>, to look down upon,
despise; <ets>de-</ets> + <ets>spicere</ets>, <ets>specere</ets>, to
look. See <er>Spy</er>, and cf. <er>Despicable</er>,
<er>Despite</er>.]</ety> <def>To look down upon with disfavor or
contempt; to contemn; to scorn; to disdain; to have a low opinion or
contemptuous dislike of.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Fools <qex>despise</qex> wisdom and instruction.</q>
<rj><qau>Prov. i. 7.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Men naturally <qex>despise</qex> those who court them, but respect
those who do not give way to them.</q> <rj><qau>Jowett (Thucyd.
).</qau></rj></p>

<p><syn><b>Syn.</b> -- To contemn; scorn; disdain; slight; undervalue.
See <er>Contemn</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Despisedness</ent><br/
<hw>De*spis"ed*ness</hw>, <pos>n.</pos> <def>The state of being
despised.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Despisement</ent><br/
<hw>De*spise"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A
despising.</def> <mark>[R.]</mark> <rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Despiser</ent><br/
<hw>De*spis"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who despises; a
contemner; a scorner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Despisingly</ent><br/
<hw>De*spis"ing*ly</hw>, <pos>adv.</pos> <def>Contemptuously.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Despite</ent><br/
<hw>De*spite"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>despit</ets>, F. <ets>d<eacute/pit</ets>, fr. L.
<ets>despectus</ets> contempt, fr. <ets>despicere</ets>. See
<er>Despise</er>, and cf. <er>Spite</er>, <er>Despect</er>.]</ety>
<sn>1.</sn> <def>Malice; malignity; spite; malicious anger; contemptuous
hate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With all thy <qex>despite</qex> against the land of Israel.</q>
<rj><qau>Ezek. xxv. 6.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An act of malice, hatred, or defiance; contemptuous
defiance; a deed of contempt.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>despite</qex> done against the Most High.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>In despite</b></col>, <cd>in defiance of another's power
or inclination.</cd> -- <col><b>In despite of</b></col>, <cd>in defiance
of; in spite of. See under <er>Spite</er>.</cd> <ldquo/Seized my hand
<xex>in despite of</xex> my efforts to the contrary.<rdquo/ <au>W.
Irving.</au> -- <col><b>In your despite</b></col>, <cd>in defiance or
contempt of you; in spite of you.</cd> <mark>[Obs.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Despite</ent><br/
<hw>De*spite"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Despited</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Despiting</conjf>.]</vmorph> <ety>[OF. <ets>despitier</ets>, fr.
L. <ets>despectare</ets>, intens. of <ets>despicere</ets>. See
<er>Despite</er>, <pos>n.</pos>]</ety> <def>To vex; to annoy; to offend
contemptuously.</def> <mark>[Obs.]</mark> <rj><au>Sir W.
Raleigh.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Despite</ent><br/
<hw>De*spite"</hw>, <pos>prep.</pos> <def>In spite of; against, or in
defiance of; notwithstanding; <as>as, <ex>despite</ex> his
prejudices</as>.</def></p>

<p><syn><b>Syn.</b> -- See <er>Notwithstanding</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Despiteful</ent><br/
<hw>De*spite"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Despite</er>, and cf. <er>Spiteful</er>.]</ety> <def>Full of
despite; expressing malice or contemptuous hate; malicious.</def> --
<wordforms><wf>De*spite"ful*ly</wf>, <pos>adv.</pos> --
<wf>De*spite"ful*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><q>Haters of God, <qex>despiteful</qex>, proud, boasters.</q>
<rj><qau>Rom. i. 30.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Pray for them which <qex>despitefully</qex> use you.</q>
<rj><qau>Matt. v. 44.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Let us examine him with <qex>despitefulness</qex> and fortune.</q>
<rj><qau>Book of Wisdom ii. 19.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Despiteous</ent><br/
<hw>Des*pit"e*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OE.
<ets>despitous</ets>, OF. <ets>despiteus</ets>, fr. <ets>despit</ets>;
affected in form by E. <ets>piteous</ets>. See <er>Despite</er>.]</ety>
<def>Feeling or showing despite; malicious; angry to excess; cruel;
contemptuous.</def> <mark>[Obs.]</mark> <ldquo/<xex>Despiteous</xex>
reproaches.<rdquo/ <rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Despiteously</ent><br/
<hw>Des*pit"e*ous*ly</hw>, <pos>adv.</pos> <def>Despitefully.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Despitous</ent><br/
<hw>De*spit"ous</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Despiteous; very
angry; cruel.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He was to sinful man not <qex>despitous</qex>.</q>
<rj><qau>Chaucer.</qau></rj></p>

<p>- <wordforms><wf>De*spit"ous*ly</wf>, <pos>adv.</pos>
<mark>[Obs.]</mark></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Despoil</ent><br/
<hw>De*spoil"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Despoiled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Despoiling</conjf>.]</vmorph> <ety>[OF.
<ets>despoiller</ets>, F. <ets>d<eacute/pouiller</ets>, L.
<ets>despoliare</ets>, <ets>despoliatum</ets>; <ets>de-</ets> +
<ets>spoliare</ets> to strip, rob, <ets>spolium</ets> spoil, booty. Cf.
<er>Spoil</er>, <er>Despoliation</er>.]</ety> <sn>1.</sn> <def>To strip,
as of clothing; to divest or unclothe.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To deprive for spoil; to plunder; to rob; to
pillage; to strip; to divest; -- usually followed by
<xex>of</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The clothed earth is then bare,<br/
<qex>Despoiled</qex> is the summer fair.</q>
<rj><qau>Gower.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A law which restored to them an immense domain of which they had
been <qex>despoiled</qex>.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Despoiled</qex> of innocence, of faith, of bliss.</q>
<rj><qau>Milton.</qau></rj></p>

<p><syn><b>Syn.</b> -- To strip; deprive; rob; bereave; rifle.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>despoil</ent><br/
<hw>de*spoil"</hw>, <pos>n.</pos> <def>Spoil.</def> <mark>[Obs.]</mark>
<rj><au>Wolsey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>despoiled</ent><br/
<hw>despoiled</hw> <pos>adj.</pos> <def>having been robbed and destroyed
by force and violence.</def><br/
<syn><b>Syn. --</b> pillaged, raped, ravaged, sacked.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>despoiler</ent><br/
<hw>de*spoil"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
despoils.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>despoilment</ent><br/
<hw>de*spoil"ment</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Despoliation.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Despoina</ent><br/
<hw>Despoina</hw> <pos>prop. n.</pos> <fld>(Classical Mythology)</fld>
<def>the daughter of <person>Zeus</person> and <person>Demeter</person>;
made queen of the underworld by <person>Pluto</person> in ancient
mythology; identified with Roman
<altname>Proserpina</altname>.</def><br/
<syn><b>Syn. --</b> Persephone, Kore, Cora.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>despoliation</ent><br/
<hw>de*spo`li*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>despoliatio</ets>. See <er>Despoil</er>.]</ety> <def>A stripping or
plundering; spoliation.</def> <rj><au>Bailey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>despond</ent><br/
<hw>de*spond"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Desponded</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Desponding</conjf>.]</vmorph> <ety>[L.
<ets>despond<emac/re</ets>, <ets>desponsum</ets>, to promise away,
promise in marriage, give up, to lose (courage); <ets>de-</ets> +
<ets>spond<emac/re</ets> to promise solemnly. See
<er>Sponsor</er>.]</ety> <def>To give up the will, courage, or spirit;
to be thoroughly disheartened; to lose all courage; to become dispirited
or depressed; to take an unhopeful view.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I should despair, or at least <qex>despond</qex>.</q>
<rj><qau>Scott's Letters.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Others depress their own minds, [and] <qex>despond</qex> at the
first difficulty.</q> <rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>We wish that . . . <qex>desponding</qex> patriotism may turn its
eyes hitherward, and be assured that the foundations of our national
power still stand strong.</q> <rj><qau>D. Webster.</qau></rj></p>

<p><syn><b>Syn.</b> -- <er>Despond</er>, <er>Dispair</er>.</syn> <usage>
<xex>Despair</xex> implies a total loss of hope, which
<xex>despond</xex> does not, at least in every case; yet
<xex>despondency</xex> is often more lasting than <xex>despair</xex>, or
than <xex>desperation</xex>, which impels to violent action.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Despond</ent><br/
<hw>De*spond"</hw> <pos>n.</pos> <def>Despondency.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The slough of <qex>despond</qex>.</q>
<rj><qau>Bunyan.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Despondence</ent><br/
<hw>De*spond"ence</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Despondency.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The people, when once infected, lose their relish for happiness
[and] saunter about with looks of <qex>despondence</qex>.</q>
<rj><qau>Goldsmith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Despondency</ent><br/
<hw>De*spond"en*cy</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state of
desponding; loss of hope and cessation of effort; discouragement;
depression or dejection of the mind.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The unhappy prince seemed, during some days, to be sunk in
<qex>despondency</qex>.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Despondent</ent><br/
<hw>De*spond"ent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>despondens</ets>, <ets>-entis</ets>, p. pr. of
<ets>despond<emac/re</ets>.]</ety> <def>Marked by despondence; given to
despondence; low-spirited; <as>as, a <ex>despondent</ex> manner; a
<ex>despondent</ex> prisoner.</as></def> --
<wordforms><wf>De*spond"ent*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desponder</ent><br/
<hw>De*spond"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
desponds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Despondingly</ent><br/
<hw>De*spond"ing*ly</hw>, <pos>adv.</pos> <def>In a desponding
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desponsage</ent><br/
<hw>De*spon"sage</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From L.
<ets>desponsus</ets>, p. p. See <er>Despond</er>.]</ety>
<def>Betrothal.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Ethelbert . . . went peaceably to King Offa for
<qex>desponsage</qex> of Athilrid, his daughter.</q>
<rj><qau>Foxe.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desponsate</ent><br/
<hw>De*spon"sate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>desponsatus</ets>, p. p. of <ets>desponsare</ets>, intens. of
<ets>despondere</ets> to betroth. See <er>Despond</er>.]</ety> <def>To
betroth.</def> <mark>[Obs.]</mark> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desponsation</ent><br/
<hw>Des`pon*sa"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>desponsatio</ets>: cf. OF. <ets>desponsation</ets>.]</ety> <def>A
betrothing; betrothal.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>For all this <qex>desponsation</qex> of her . . . she had not set
one step toward the consummation of her marriage.</q> <rj><qau>Jer.
Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desponsory</ent><br/
<hw>De*spon"so*ry</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Desponsories</plw> <pr>(<?/)</pr>.</plu> <def>A written pledge of
marriage.</def> <rj><au>Clarendon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desport</ent><br/
<hw>De*sport"</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <def>See
<er>Disport</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Despot</ent><br/
<hw>Des"pot</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>despote</ets>, LL. <ets>despotus</ets>, fr. Gr.
<grk>despo`ths</grk> master, lord, the second part of which is akin to
<grk>po`sis</grk> husband, and L. <ets>potens</ets>. See
<er>Potent</er>.]</ety> <sn>1.</sn> <def>A master; a lord; especially,
an absolute or irresponsible ruler or sovereign.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Irresponsible power in human hands so naturally leads to it, that
cruelty has become associated with <qex>despot</qex> and tyrant.</q>
<rj><qau>C. J. Smith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who rules regardless of a constitution or laws;
a tyrant.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Despotat</ent><br/
<hw>Des"po*tat</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>despotat</ets>.]</ety> <def>The station or government of a despot;
also, the domain of a despot.</def> <rj><au>Freeman.</au></rj></p>

<p><ent>Despotical</ent><br/
<ent>Despotic</ent><br/
<mhw>{ <hw>Des*pot"ic</hw> <pr>(?)</pr>, <hw>Des*pot"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[Gr. <grk>despotiko`s</grk>:
cf. F. <ets>despotique</ets>.]</ety> <def>Having the character of, or
pertaining to, a despot; absolute in power; possessing and abusing
unlimited power; evincing despotism; tyrannical; arbitrary.</def> --
<wordforms><wf>Des*pot"ic*al*ly</wf>, <pos>adv.</pos> --
<wf>Des*pot"ic*al*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Despotism</ent><br/
<hw>Des"po*tism</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>despotisme</ets>.]</ety> <sn>1.</sn> <def>The power, spirit, or
principles of a despot; absolute control over others; tyrannical sway;
tyranny.</def> <ldquo/The <xex>despotism</xex> of vice.<rdquo/
<rj><au>Byron.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A government which is directed by a despot; a
despotic monarchy; absolutism; autocracy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Despotism</qex> . . . is the only form of government which
may with safety to itself neglect the education of its infant poor.</q>
<rj><qau>Bp. Horsley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Despotist</ent><br/
<hw>Des"po*tist</hw>, <pos>n.</pos> <def>A supporter of despotism.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Despotize</ent><br/
<hw>Des"po*tize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To act the
despot.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Despread</ent><br/
<hw>De*spread"</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <def>See
<er>Dispread</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Despumate</ent><br/
<hw>Des"pu*mate</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Despumated</conjf> <pr>(?)</pr>;
<pos>p. pr. & vb. n.</pos> <conjf>Despumating</conjf>
<pr>(?)</pr>.]</vmorph> <ety>[L. <ets>despumatus</ets>, p. p. of
<ets>despumare</ets> to despume; <ets>de-</ets> + <ets>spumare</ets> to
foam, froth, <ets>spuma</ets> froth, scum.]</ety> <def>To throw off
impurities in spume; to work off in foam or scum; to foam.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Despumation</ent><br/
<hw>Des`pu*ma"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>despumatio</ets>: cf. F. <ets>despumation</ets>.]</ety> <def>The
act of throwing up froth or scum; separation of the scum or impurities
from liquids; scumming; clarification.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Despume</ent><br/
<hw>De*spume"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Cf. F.
<ets>despumer</ets>. See <er>Despumate</er>.]</ety> <def>To free from
spume or scum.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>If honey be <qex>despumed</qex>.</q>
<rj><qau>Holland.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desquamate</ent><br/
<hw>Des"qua*mate</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[L.
<ets>desquamatus</ets>, p. p. of <ets>desquamare</ets> to scale off;
<ets>de-</ets> + <ets>squama</ets> scale.]</ety> <fld>(Med.)</fld>
<def>To peel off in the form of scales; to scale off, as the skin in
certain diseases.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desquamation</ent><br/
<hw>Des`qua*ma"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>desquamation</ets>.]</ety> <fld>(Med.)</fld> <def>The separation or
shedding of the cuticle or epidermis in the form of flakes or scales;
exfoliation, as of bones.</def></p>

<p><ent>Desquamatory</ent><br/
<ent>Desquamative</ent><br/
<mhw>{ <hw>De*squam"a*tive</hw> <pr>(?)</pr>, <hw>De*squam"a*to*ry</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <def>Of, pertaining to, or attended
with, desquamation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desquamatory</ent><br/
<hw>De*squam"a*to*ry</hw>, <pos>n.</pos> <fld>(Surg.)</fld> <def>An
instrument formerly used in removing the lamin<ae/ of exfoliated
bones.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dess</ent><br/
<hw>Dess</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Dais.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dessert</ent><br/
<hw>Des*sert"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr.
<ets>desservir</ets> to remove from table, to clear the table; pref.
<ets>des-</ets> (L. <ets>dis-</ets>) + <ets>servir</ets> to serve, to
serve at table. See <er>Serve</er>.]</ety> <def>A service of pastry,
fruits, or sweetmeats, at the close of a feast or entertainment; pastry,
fruits, etc., forming the last course at dinner.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><ldquo/An 't please your honor,<rdquo/ quoth the peasant,<br/
<ldquo/This same <qex>dessert</qex> is not so pleasant.<rdquo/</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dessert spoon</b></col>, <cd>a spoon used in eating
dessert; a spoon intermediate in size between a teaspoon and a
tablespoon.</cd> -- <mcol><col><b>Dessert-spoonful</b></col>,
<pos>n.</pos>, <pos>pl.</pos>
<col><b>Dessert-spoonfuls</b></col></mcol>, <cd>as much as a dessert
spoon will hold, usually reckoned at about two and a half fluid
drams.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Destemper</ent><br/
<hw>Des*tem"per</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>d<eacute/trempe</ets>, fr. <ets>d<eacute/tremper</ets>.]</ety>
<def>A kind of painting. See <er>Distemper</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Destin</ent><br/
<hw>Des"tin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>destin</ets>.]</ety> <def>Destiny.</def> <mark>[Obs.]</mark>
<rj><au>Marston.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Destinable</ent><br/
<hw>Des"ti*na*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. OF.
<ets>destinable</ets>.]</ety> <def>Determined by destiny; fated.</def>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Destinably</ent><br/
<hw>Des"ti*na*bly</hw>, <pos>adv.</pos> <def>In a destinable
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Destinal</ent><br/
<hw>Des"ti*nal</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Determined by
destiny; fated.</def> <mark>[Obs.]</mark> <ldquo/The order
<xex>destinal</xex>.<rdquo/ <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Destinate</ent><br/
<hw>Des"ti*nate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>destinatus</ets>, p. p. of <ets>destinare</ets>. See
<er>Destine</er>.]</ety> <def>Destined.</def> <mark>[Obs.]</mark>
<ldquo/<xex>Destinate</xex> to hell.<rdquo/ <rj><au>Foxe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Destinate</ent><br/
<hw>Des"ti*nate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To destine,
design, or choose.</def> <mark>[Obs.]</mark> <ldquo/That name that God .
. . did <xex>destinate</xex>.<rdquo/ <rj><au>Udall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Destination</ent><br/
<hw>Des`ti*na"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>destinatio</ets> determination: cf. F. <ets>destination</ets>
destination.]</ety> <sn>1.</sn> <def>The act of destining or
appointing.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Purpose for which anything is destined;
predetermined end, object, or use; ultimate design.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The place set for the end of a journey, or to which
something is sent; place or point aimed at.</def></p>

<p><syn><b>Syn.</b> -- Appointment; design; purpose; intention; destiny;
lot; fate; end.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Destine</ent><br/
<hw>Des"tine</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Destined</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Destining</conjf>.]</vmorph> <ety>[F.
<ets>destiner</ets>, L. <ets>destinare</ets>; <ets>de</ets> + the root
of <ets>stare</ets> to stand. See <er>Stand</er>, and cf.
<er>Obstinate</er>.]</ety> <def>To determine the future condition or
application of; to set apart by design for a future use or purpose; to
fix, as by destiny or by an authoritative decree; to doom; to ordain or
preordain; to appoint; -- often with the remoter object preceded by
<xex>to</xex> or <xex>for</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We are decreed,<br/
Reserved, and <qex>destined</qex> to eternal woe.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Till the loathsome opposite<br/
Of all my heart had <qex>destined</qex>, did obtain.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Not enjoyment and not sorrow<br/
Is our <qex>destined</qex> end or way.</q>
<rj><qau>Longfellow.</qau></rj></p>

<p><syn><b>Syn.</b> -- To design; mark out; determine; allot; choose;
intend; devote; consecrate; doom.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Destinist</ent><br/
<hw>Des"ti*nist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A believer in
destiny; a fatalist.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Destiny</ent><br/
<hw>Des"ti*ny</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Destinies</plw> <pr>(#)</pr>.</plu> <ety>[OE. <ets>destinee</ets>,
<ets>destene</ets>, F. <ets>destin<eacute/e</ets>, from
<ets>destiner</ets>. See <er>Destine</er>.]</ety> <sn>1.</sn> <def>That
to which any person or thing is destined; predetermined state; condition
foreordained by the Divine or by human will; fate; lot; doom.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thither he<br/
Will come to know his <qex>destiny</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>No man of woman born,<br/
Coward or brave, can shun his <qex>destiny</qex>.</q>
<rj><qau>Bryant.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The fixed order of things; invincible necessity;
fate; a resistless power or agency conceived of as determining the
future, whether in general or of an individual.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>But who can turn the stream of <qex>destiny</qex>?</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Fame comes only when deserved, and then is as inevitable as
<qex>destiny</qex>, for it is <qex>destiny</qex>.</q>
<rj><qau>Longfellow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>The Destinies</b></col> <fld>(Anc. Myth.)</fld>, <cd>the
three Parc<ae/, or Fates; the supposed powers which preside over human
life, and determine its circumstances and duration.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><q>Marked by <qex>the Destinies</qex> to be avoided.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 400 --></p>

<p><ent>Destituent</ent><br/
<hw>De*stit"u*ent</hw> <pr>(?; 135)</pr>, <pos>a.</pos> <ety>[L.
<ets>destituens</ets>, p. pr. of <ets>destituere</ets>.]</ety>
<def>Deficient; wanting; <as>as, a <ex>destituent</ex>
condition</as>.</def> <mark>[Obs.]</mark> <rj><au>Jer.
Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Destitute</ent><br/
<hw>Des"ti*tute</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>destitutus</ets>, p. p. of <ets>destituere</ets> to set away, leave
alone, forsake; <ets>de</ets> + <ets>statuere</ets> to set. See
<er>Statute</er>.]</ety> <sn>1.</sn> <def>Forsaken; not having in
possession (something necessary, or desirable); deficient; lacking;
devoid; -- often followed by <xex>of</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In thee is my trust; leave not my soul <qex>destitute</qex>.</q>
<rj><qau>Ps. cxli. 8.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Totally <qex>destitute</qex> of all shadow of influence.</q>
<rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Not possessing the necessaries of life; in a
condition of want; needy; without possessions or resources; very
poor.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They wandered about in sheepskins and goatskins; being
<qex>destitute</qex>, afflicted, tormented.</q> <rj><qau>Heb. xi.
37.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Destitute</ent><br/
<hw>Des"ti*tute</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To leave
destitute; to forsake; to abandon.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>To forsake or <qex>destitute</qex> a plantation.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To make destitute; to cause to be in want; to
deprive; -- followed by <xex>of</xex>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Destituted</qex> of all honor and livings.</q>
<rj><qau>Holinshed.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To disappoint.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>When his expectation is <qex>destituted</qex>.</q>
<rj><qau>Fotherby.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Destitutely</ent><br/
<hw>Des"ti*tute*ly</hw>, <pos>adv.</pos> <def>In destitution.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Destituteness</ent><br/
<hw>Des"ti*tute*ness</hw>, <pos>n.</pos> <def>Destitution.</def>
<mark>[R.]</mark> <rj><au>Ash.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Destitution</ent><br/
<hw>Des`ti*tu"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>destitutio</ets> a forsaking.]</ety> <def>The state of being
deprived of anything; the state or condition of being destitute, needy,
or without resources; deficiency; lack; extreme poverty; utter want;
<as>as, the inundation caused general
<ex>destitution</ex></as>.</def></p>

<p><ent>Dextrer</ent><br/
<ent>Destrer</ent><br/
<mhw>{ <hw>Des*trer"</hw> <pr>(?)</pr>, <hw>Dex"trer</hw> <pr>(?)</pr>
}</mhw>, <pos>n.</pos> <ety>[OF. <ets>destrier</ets>, fr. L.
<ets>dextra</ets> on the right side. The squire led his master's horse
beside him, on his right hand. <ets>Skeat</ets>.]</ety> <def>A war
horse.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Destrie</ent><br/
<hw>De*strie"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To destroy.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Destroy</ent><br/
<hw>De*stroy"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Destroyed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Destroying</conjf>.]</vmorph> <ety>[OE.
<ets>destroien</ets>, <ets>destruien</ets>, <ets>destrien</ets>, OF.
<ets>destruire</ets>, F. <ets>d<eacute/truire</ets>, fr. L.
<ets>destruere</ets>, <ets>destructum</ets>; <ets>de</ets> +
<ets>struere</ets> to pile up, build. See <er>Structure</er>.]</ety>
<sn>1.</sn> <def>To unbuild; to pull or tear down; to separate
virulently into its constituent parts; to break up the structure and
organic existence of; to demolish.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>But ye shall <qex>destroy</qex> their altars, break their images,
and cut down their groves.</q> <rj><qau>Ex. xxxiv. 13.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To ruin; to bring to naught; to put an end to; to
annihilate; to consume.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I will utterly pluck up and <qex>destroy</qex> that nation.</q>
<rj><qau>Jer. xii. 17.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To put an end to the existence, prosperity, or
beauty of; to kill.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If him by force he can <qex>destroy</qex>, or, worse,<br/
By some false guile pervert.</q> <rj><qau>Milton.</qau></rj></p>

<p><syn><b>Syn.</b> -- To demolish; lay waste; consume; raze; dismantle;
ruin; throw down; overthrow; subvert; desolate; devastate; deface;
extirpate; extinguish; kill; slay. See <er>Demolish</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Destroyable</ent><br/
<hw>De*stroy"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Destructible.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Plants . . . scarcely <qex>destroyable</qex> by the weather.</q>
<rj><qau>Derham.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>destroyed</ent><br/
<hw>destroyed</hw> <pos>adj.</pos> <sn>1.</sn> <def><pos>p. p.</pos> of
<er>destroy</er>.</def> [Narrower terms: <stype>annihilated,
exterminated, wiped out(predicate)</stype>; <stype>blasted, desolate,
desolated, devastated, ravaged, ruined, wasted</stype>; <stype>blighted,
spoilt</stype>; <stype>blotted out, obliterate, obliterated</stype>;
<stype>demolished, dismantled, razed</stype>; <stype>done
for(predicate), kaput(predicate), gone(prenominal), lost,
finished(predicate)</stype>; <stype>extinguished</stype>; <stype>ruined,
wiped out(predicate), impoverished</stype>; <stype>totaled,
wrecked</stype>; <stype>war-torn, war-worn</stype>; <stype>despoiled,
pillaged, raped, ravaged, sacked</stype>] <def>Also See:
<er>damaged</er>.</def> Antonym: <ant>preserved</ant><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>destroyed physically or morally.</def><br/
<syn><b>Syn. --</b> ruined.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Destroyer</ent><br/
<hw>De*stroy"er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. OF.
<ets>destruior</ets>.]</ety> <sn>1.</sn> <def>One who destroys, ruins,
kills, or desolates.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Nav.)</fld> <def>a small fast warship used
primarily as an escort to larger vessels and typically armed with a
combination of 5-inch guns, torpedoes, depth charges, and missiles;
formerly identical to the <er>Torpedo-boat destroyer</er>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Destruct</ent><br/
<hw>De*struct"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>destructus</ets>, p. p. of <ets>destruere</ets>. See
<er>Destroy</er>.]</ety> <def>To destroy.</def> <mark>[Obs.]</mark>
<rj><au>Mede.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Destructibility</ent><br/
<hw>De*struc`ti*bil"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>destructibilit<eacute/</ets>.]</ety> <def>The quality of being
capable of destruction; destructibleness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Destructible</ent><br/
<hw>De*struc"ti*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>destructibilis</ets>.]</ety> <def>Liable to destruction; capable of
being destroyed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Destructibleness</ent><br/
<hw>De*struc"ti*ble*ness</hw>, <pos>n.</pos> <def>The quality of being
destructible.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Destruction</ent><br/
<hw>De*struc"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>destructio</ets>: cf. F. <ets>destruction</ets>. See
<er>Destroy</er>.]</ety> <sn>1.</sn> <def>The act of destroying; a
tearing down; a bringing to naught; subversion; demolition; ruin;
slaying; devastation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The Jews smote all their enemies with the stroke of the sword, and
slaughter, and <qex>destruction</qex>.</q> <rj><qau>Esth. ix.
5.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>'Tis safer to be that which we destroy<br/
Than by <qex>destruction</qex> dwell in doubtful joy.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Destruction</qex> of venerable establishment.</q>
<rj><qau>Hallam.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The state of being destroyed, demolished, ruined,
slain, or devastated.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This town came to <qex>destruction</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou castedst them down into <qex>destruction</qex>.</q>
<rj><qau>Ps. lxxiii. 18.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A destroying agency; a cause of ruin or of
devastation; a destroyer.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>destruction</qex> that wasteth at noonday.</q>
<rj><qau>Ps. xci. 6.</qau></rj></p>

<p><syn><b>Syn.</b> -- Demolition; subversion; overthrow; desolation;
extirpation; extinction; devastation; downfall; extermination; havoc;
ruin.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Destructionist</ent><br/
<hw>De*struc"tion*ist</hw>, <pos>n.</pos> <sn>1.</sn> <def>One who
delights in destroying that which is valuable; one whose principles and
influence tend to destroy existing institutions; a
destructive.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Theol.)</fld> <def>One who believes in the final
destruction or complete annihilation of the wicked; -- called also
<altname>annihilationist</altname>.</def> <rj><au>Shipley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Destructive</ent><br/
<hw>De*struc"tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>destructivus</ets>: cf. F. <ets>destructif</ets>.]</ety>
<def>Causing destruction; tending to bring about ruin, death, or
devastation; ruinous; fatal; productive of serious evil; mischievous;
pernicious; -- often with <xex>of</xex> or <xex>to</xex>; <as>as,
intemperance is <ex>destructive</ex> of health; evil examples are
<ex>destructive</ex> to the morals of youth.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Time's <qex>destructive</qex> power.</q>
<rj><qau>Wordsworth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Destructive distillation</b></col>. <cd>See
<er>Distillation</er>.</cd> -- <col><b>Destructive sorties</b></col>
<pr>(<?/)</pr> <fld>(Logic)</fld>, <cd>a process of reasoning which
involves the denial of the first of a series of dependent propositions
as a consequence of the denial of the last; a species of <xex>reductio
ad absurdum</xex>.</cd> <rj><au>Whately.</au></rj></cs></p>

<p><syn><b>Syn.</b> -- Mortal; deadly; poisonous; fatal; ruinous;
malignant; baleful; pernicious; mischievous.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Destructive</ent><br/
<hw>De*struc"tive</hw>, <pos>n.</pos> <def>One who destroys; a radical
reformer; a destructionist.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Destructively</ent><br/
<hw>De*struc"tive*ly</hw>, <pos>adv.</pos> <def>In a destructive
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>destructive-metabolic</ent><br/
<hw>destructive-metabolic</hw> <pos>adj. prenom.</pos>
<fld>(Biochemistry & Physiology)</fld> <def>energy-releasing
(prenominal); same as <er>catabolic</er>.</def><br/
<syn><b>Syn. --</b> .</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Destructiveness</ent><br/
<hw>De*struc"tive*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>The quality of destroying or ruining.</def>
<rj><au>Prynne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Phren.)</fld> <def>The faculty supposed to impel to
the commission of acts of destruction; propensity to destroy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Destructor</ent><br/
<hw>De*struc"tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., from
<ets>destruere</ets>. See <er>Destroy</er>, and cf.
<er>Destroyer</er>.]</ety> <sn>1.</sn> <def>A destroyer.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Fire, the <qex>destructor</qex> and the artificial death of
things.</q> <rj><qau>Boyle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A furnace or oven for the burning or carbonizing of
refuse</def>; <specif>specif.</specif> <fld>(Sewage Disposal)</fld>,
<def>a furnace (called in full <col><b>refuse destructor</b></col>) in
which the more solid constituents of sewage are burnt. Destructors are
often so constructed as to utilize refuse as fuel.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>3.</sn> <fld>(Computers)</fld> <def>in object-oriented
programming, a function which destroys an object which was previously
created by a different function.</def><br/
[<source>PJC</source>]</p>

<p><ent>Destruie</ent><br/
<hw>De*struie"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To
destroy.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desudation</ent><br/
<hw>Des`u*da"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>desudatio</ets>, fr. <ets>desudare</ets> to sweat greatly;
<ets>de</ets> + <ets>sudare</ets> to sweat.]</ety> <fld>(Med.)</fld>
<def>A sweating; a profuse or morbid sweating, often succeeded by an
eruption of small pimples.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desuete</ent><br/
<hw>De*suete"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>desuetus</ets>, p. p. of <ets>desuescere</ets> to disuse.]</ety>
<def>Disused; out of use.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desuetude</ent><br/
<hw>Des"ue*tude</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>desuetudo</ets>, from <ets>desuescere</ets>, to grow out of use,
disuse; <ets>de</ets> + <ets>suescere</ets> to become used or
accustomed: cf. F. <ets>d<eacute/su<eacute/tude</ets>. See
<er>Custom</er>.]</ety> <def>The cessation of use; disuse;
discontinuance of practice, custom, or fashion.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>desuetude</qex> abrogated the law, which, before, custom
had established.</q> <rj><qau>Jer. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desulphurate</ent><br/
<hw>De*sul"phu*rate</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Desulphurated</conjf>; <pos>p.
pr. & vb. n.</pos> <conjf>Desulphurating</conjf>.]</vmorph> <def>To
deprive of sulphur.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desulphuration</ent><br/
<hw>De*sul`phu*ra"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>d<eacute/sulfuration</ets>.]</ety> <def>The act or process of
depriving of sulphur.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desulphurize</ent><br/
<hw>De*sul"phur*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To
desulphurate; to deprive of sulphur.</def> --
<wordforms><wf>De*sul`phur*i*za"tion</wf> <pr>(#)</pr>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desultorily</ent><br/
<hw>Des"ul*to*ri*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a
desultory manner; without method; loosely; immethodically.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desultoriness</ent><br/
<hw>Des"ul*to*ri*ness</hw>, <pos>n.</pos> <def>The quality of being
desultory or without order or method; unconnectedness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The seeming <qex>desultoriness</qex> of my method.</q>
<rj><qau>Boyle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desultorious</ent><br/
<hw>Des`ul*to"ri*ous</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Desultory.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desultory</ent><br/
<hw>Des"ul*to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>desultorius</ets>, fr. <ets>desultor</ets> a leaper, fr.
<ets>desilire</ets>, <ets>desultum</ets>, to leap down; <ets>de</ets> +
<ets>salire</ets> to leap. See <er>Saltation</er>.]</ety> <sn>1.</sn>
<def>Leaping or skipping about.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I shot at it [a bird], but it was so <qex>desultory</qex> that I
missed my aim.</q> <rj><qau>Gilbert White.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Jumping, or passing, from one thing or subject to
another, without order or rational connection; without logical sequence;
disconnected; immethodical; aimless; <as>as, <ex>desultory</ex>
minds</as>.</def> <rj><au>Atterbury.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He [Goldsmith] knew nothing accurately; his reading had been
<qex>desultory</qex>.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Out of course; by the way; as a digression; not
connected with the subject; <as>as, a <ex>desultory</ex>
remark</as>.</def></p>

<p><syn><b>Syn.</b> -- Rambling; roving; immethodical; discursive;
inconstant; unsettled; cursory; slight; hasty; loose.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desume</ent><br/
<hw>De*sume"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>desumere</ets>; <ets>de</ets> + <ets>sumere</ets> to take.]</ety>
<def>To select; to borrow.</def> <mark>[Obs.]</mark> <rj><au>Sir. M.
Hale.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>desynchronize</ent><br/
<hw>desynchronize</hw>, <pos>v. t.</pos> <def>to cause a process to
occur at times or in cycles independent of another process.</def><br/
[<source>PJC</source>]</p>

<p><ent>desynchronizing</ent><br/
<ent>desynchronization</ent><br/
<mhw><hw>desynchronization</hw>, <hw>desynchronizing</hw></mhw>
<pos>n.</pos> <def>a process causing an absence of synchronization; the
relation that exists when things occur at unrelated times; <as>as, the
stimulus produced a <ex>desynchronizing</ex> of the brain
waves</as>.</def><br/
<syn><b>Syn. --</b> asynchronism, asynchrony, desynchronization,
desynchronisation.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Desynonymization</ent><br/
<hw>De`syn*on`y*mi*za"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act
of desynonymizing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Desynonymize</ent><br/
<hw>De`syn*on"y*mize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To deprive
of synonymous character; to discriminate in use; -- applied to words
which have been employed as synonyms.</def> <rj><au>Coleridge.
Trench.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detach</ent><br/
<hw>De*tach"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Detached</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Detaching</conjf>.]</vmorph> <ety>[F.
<ets>d<eacute/tacher</ets> (cf. It. <ets>distaccare</ets>,
<ets>staccare</ets>); pref. <ets>d<eacute/</ets> (L. <ets>dis</ets>) +
the root found also in E. <ets>attach</ets>. See <er>Attach</er>, and
cf. <er>Staccato</er>.]</ety> <sn>1.</sn> <def>To part; to separate or
disunite; to disengage; -- the opposite of <xex>attach</xex>; <as>as, to
<ex>detach</ex> the coats of a bulbous root from each other; to
<ex>detach</ex> a man from a leader or from a party.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To separate for a special object or use; -- used
especially in military language; <as>as, to <ex>detach</ex> a ship from
a fleet, or a company from a regiment</as>.</def></p>

<p><syn><b>Syn.</b> -- To separate; disunite; disengage; sever; disjoin;
withdraw; draw off. See <er>Detail</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detach</ent><br/
<hw>De*tach"</hw>, <pos>v. i.</pos> <def>To push asunder; to come off or
separate from anything; to disengage.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>[A vapor] <qex>detaching</qex>, fold by fold,<br/
From those still heights.</q> <rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detachable</ent><br/
<hw>De*tach"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>That can be
detached.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detached</ent><br/
<hw>De*tached"</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Separate;
unconnected, or imperfectly connected; <as>as, <ex>detached</ex>
parcels</as>.</def> <ldquo/Extensive and <xex>detached</xex>
empire.<rdquo/ <rj><au>Burke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Detached escapement</b></col>. <cd>See
<er>Escapement</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detachment</ent><br/
<hw>De*tach"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>d<eacute/tachement</ets>.]</ety> <sn>1.</sn> <def>The act of
detaching or separating, or the state of being detached.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is detached; especially, a body of troops
or part of a fleet sent from the main body on special service.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Troops . . . widely scattered in little
<qex>detachments</qex>.</q> <rj><qau>Bancroft.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Abstraction from worldly objects;
renunciation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A trial which would have demanded of him a most heroic faith and
the <qex>detachment</qex> of a saint.</q> <rj><qau>J. H.
Newman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detail</ent><br/
<hw>De"tail</hw> <pr>(d<emac/"t<amac/l <it>or</it> d<esl/*t<amac/l";
277)</pr>, <pos>n.</pos> <ety>[F. <ets>d<eacute/tail</ets>, fr.
<ets>d<eacute/tailler</ets> to cut in pieces, tell in detail; pref.
<ets>d<eacute/-</ets> (L. <ets>de</ets> or <ets>dis-</ets>) +
<ets>tailler</ets> to cut. See <er>Tailor</er>.]</ety> <sn>1.</sn>
<def>A minute portion; one of the small parts; a particular; an item; --
used chiefly in the plural; <as>as, the <ex>details</ex> of a scheme or
transaction</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>details</qex> of the campaign in Italy.</q>
<rj><qau>Motley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A narrative which relates minute points; an account
which dwells on particulars.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Mil.)</fld> <def>The selection for a particular
service of a person or a body of men; hence, the person or the body of
men so selected.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Arch. & Mach.)</fld> <sd>(a)</sd> <def>A minor
part, as, in a building, the cornice, caps of the buttresses, capitals
of the columns, etc., or (called <altname>larger details</altname>) a
porch, a gable with its windows, a pavilion, or an attached tower.</def>
<sd>(b)</sd> <def>A detail drawing.</def></p>

<p><cs><col><b>Detail drawing</b></col>, <cd>a drawing of the full size,
or on a large scale, of some part of a building, machine, etc.</cd> --
<col><b>In detail</b></col>, <cd>in subdivisions; part by part; item by
item; circumstantially; with particularity.</cd></cs></p>

<p><syn><b>Syn.</b> -- Account; relation; narrative; recital;
explanation; narration.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detail</ent><br/
<hw>De"tail</hw> <pr>(d<esl/*t<amac/l")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Detailed</conjf> <pr>(?)</pr>;
<pos>p. pr. & vb. n.</pos> <conjf>Detailing</conjf>.]</vmorph> <ety>[Cf.
F. <ets>d<eacute/tailler</ets> to cut up in pieces, tell in detail. See
<er>Detail</er>, <pos>n.</pos>]</ety> <sn>1.</sn> <def>To relate in
particulars; to particularize; to report minutely and distinctly; to
enumerate; to specify; <as>as, he <ex>detailed</ex> all the facts in due
order</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mil.)</fld> <def>To tell off or appoint for a
particular service, as an officer, a troop, or a squadron.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To provide with fine or intricate added
decoration.</def><br/
[<source>PJC</source>]</p>

<p><syn><b>Syn.</b> -- <er>Detail</er>, <er>Detach</er>.</syn>
<usage><xex>Detail</xex> respects the act of individualizing the person
or body that is separated; <xex>detach</xex>, the removing for the given
end or object.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>detailed</ent><br/
<hw>de*tailed"</hw> <pr>(d<esl/*t<amac/ld")</pr>, <pos>adj.</pos>
<sn>1.</sn> <def>Developed or executed with care and in minute detail;
<as>as, a <ex>detailed</ex> plan</as>.</def><br/
<syn><b>Syn. --</b> elaborate, elaborated.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>Containing details; containing subordinate parts as
well as more general discussion; -- of a discourse; <as>as, a specific
and <ex>detailed</ex> account of the accident</as>. Opposite of
<ant>sketchy</ant>, <ant>general</ant>, <ant>vague</ant>.</def><br/
<syn><b>Syn. --</b> circumstantial, particularized,
particularised.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>3.</sn> <def>having fine or intricate added decoration.</def><br/
[<source>PJC</source>]</p>

<p><ent>Detailer</ent><br/
<hw>De*tail"er</hw> <pr>(d<esl/*t<amac/l"<etil/r)</pr>, <pos>n.</pos>
<def>One who details.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>detailing</ent><br/
<hw>detailing</hw> <pos>n.</pos> <sn>1.</sn> <def>description of
something in detail.</def><br/
<syn><b>Syn. --</b> particularization.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>Thorough cleaning, esp. of the interior of
automobiles.</def><br/
<syn><b>Syn. --</b> detailed cleaning.</syn><br/
[<source>PJC</source>]</p>

<p><ent>details</ent><br/
<hw>details</hw> <pos>n.</pos> <def>confidential information.</def><br/
<syn><b>Syn. --</b> dope, low-down, poop, inside information.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Detain</ent><br/
<hw>De*tain"</hw> <pr>(d<esl/*t<amac/n")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Detained</conjf> <pr>(?)</pr>;
<pos>p. pr. & vb. n.</pos> <conjf>Detaining</conjf>.]</vmorph> <ety>[F.
<ets>d<eacute/tenir</ets>, L. <ets>detinere</ets>, <ets>detentum</ets>;
<ets>de</ets> + <ets>tenere</ets> to hold. See <er>Tenable</er>.]</ety>
<sn>1.</sn> <def>To keep back or from; to withhold.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Detain</qex> not the wages of the hireling.</q> <rj><qau>Jer.
Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To restrain from proceeding; to stay or stop; to
delay; <as>as, we were <ex>detained</ex> by an accident</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Let us <qex>detain</qex> thee, until we shall have made ready a
kid for thee.</q> <rj><qau>Judges xiii. 15.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To hold or keep in custody.</def></p>

<p><syn><b>Syn.</b> -- To withhold; retain; stop; stay; arrest; check;
retard; delay; hinder.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detain</ent><br/
<hw>De*tain"</hw>, <pos>n.</pos> <def>Detention.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detainder</ent><br/
<hw>De*tain"der</hw> <pr>(-d<etil/r)</pr>, <pos>n.</pos>
<fld>(Law)</fld> <def>A writ. See <er>Detinue</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detainer</ent><br/
<hw>De*tain"er</hw> <pr>(-<etil/r)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>One who detains.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <sd>(a)</sd> <def>The keeping possession
of what belongs to another; detention of what is another's, even though
the original taking may have been lawful. Forcible detainer is
indictable at common law.</def> <sd>(b)</sd> <def>A writ authorizing the
keeper of a prison to continue to keep a person in custody.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detainment</ent><br/
<hw>De*tain"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. OF.
<ets>detenement</ets>.]</ety> <def>Detention.</def> <mark>[R.]</mark>
<rj><au>Blackstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detect</ent><br/
<hw>De*tect"</hw> <pr>(d<esl/*t<ecr/kt")</pr>, <pos>a.</pos> <ety>[L.
<ets>detectus</ets>, p. p. of <ets>detegere</ets> to uncover, detect;
<ets>de</ets> + <ets>tegere</ets> to cover. See
<er>Tegument</er>.]</ety> <def>Detected.</def> <mark>[Obs.]</mark>
<rj><au>Fabyan.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detect</ent><br/
<hw>De*tect"</hw> <pr>(d<esl/*t<ecr/kt")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Detected</conjf>; <pos>p. pr. &
vb. n.</pos> <conjf>Detecting</conjf>.]</vmorph> <sn>1.</sn> <def>To
uncover; to discover; to find out; to bring to light; <as>as, to
<ex>detect</ex> a crime or a criminal; to <ex>detect</ex> a mistake in
an account.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Plain good intention . . . is as easily discovered at the first
view, as fraud is surely <qex>detected</qex> at last.</q>
<rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Like following life through creatures you dissect,<br/
You lose it in the moment you <qex>detect</qex>.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To inform against; to accuse.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He was untruly judged to have preached such articles as he was
<qex>detected</qex> of.</q> <rj><qau>Sir T. More.</qau></rj></p>

<p><syn><b>Syn.</b> -- To discover; find out; lay bare;
expose.</syn></p>

<p><ent>Detectible</ent><br/
<ent>Detectable</ent><br/
<mhw>{ <hw>De*tect"a*ble</hw> <pr>(-<adot/*b'l)</pr>,
<hw>De*tect"i*ble</hw> <pr>(?)</pr>, }</mhw> <pos>a.</pos> <def>Capable
of being detected or found out; <as>as, parties not
<ex>detectable</ex></as>.</def> <ldquo/Errors <xex>detectible</xex> at a
glance.<rdquo/ <rj><au>Latham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detecter</ent><br/
<hw>De*tect"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, detects or brings to light; one who finds out what another
attempts to conceal; a detector.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detection</ent><br/
<hw>De*tec"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>detectio</ets> an uncovering, revealing.]</ety> <def>The act of
detecting; the laying open what was concealed or hidden; discovery;
<as>as, the <ex>detection</ex> of a thief; the <ex>detection</ex> of
fraud, forgery, or a plot.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Such secrets of guilt are never from <qex>detection</qex>.</q>
<rj><qau>D. Webster.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detective</ent><br/
<hw>De*tect"ive</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Fitted for, or
skilled in, detecting; employed in detecting crime or criminals; <as>as,
a <ex>detective</ex> officer</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detective</ent><br/
<hw>De*tect"ive</hw>, <pos>n.</pos> <def>One who business it is so
detect criminals or discover matters of secrecy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detector</ent><br/
<hw>De*tect"or</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., a
revealer.]</ety> <def>One who, or that which, detects; a detecter.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A deathbed's <qex>detector</qex> of the heart.</q>
<rj><qau>Young.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <specif>Specifically:</specif> <sd>(a)</sd> <def>An
indicator showing the depth of the water in a boiler.</def> <sd>(b)</sd>
<fld>(Elec.)</fld> <def>A galvanometer, usually portable, for indicating
the direction of a current.</def> <sd>(c)</sd> <fld>(Elec.)</fld>
<def>Any of various devices for detecting the presence of electric
waves.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><cs><col><b>Bank-note detector</b></col>, <cd>a publication
containing a description of genuine and counterfeit bank notes, designed
to enable persons to discriminate between them.</cd> -- <col><b>Detector
lock</b></col>. <cd>See under <er>Lock</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detector bar</ent><br/
<hw>De*tect"or bar</hw>. <fld>(Railroads)</fld> <def>A bar, connected
with a switch, longer than the distance between any two consecutive
wheels of a train (45 to 50 feet), laid inside a rail and operated by
the wheels so that the switch cannot be thrown until all the train is
past the switch.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Detenebrate</ent><br/
<hw>De*ten"e*brate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>de</ets> + <ets>tenebrare</ets> to make dark, fr.
<ets>tenebrae</ets> darkness.]</ety> <def>To remove darkness from.</def>
<mark>[Obs.]</mark> <rj><au>Ash.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detent</ent><br/
<hw>De*tent"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>d<eacute/tente</ets>, fr. <ets>d<eacute/tendre</ets> to unbend,
relax; pref. <ets>d<eacute/-</ets> (L. <ets>dis-</ets> or <ets>de</ets>)
+ <ets>tendre</ets> to stretch. See <er>Distend</er>.]</ety>
<fld>(Mech.)</fld> <def>That which locks or unlocks a movement; a catch,
pawl, or dog; especially, in clockwork, the catch which locks and
unlocks the wheelwork in striking.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>detente</ent><br/
<hw>detente</hw> <pr>(d<asl/*t<aum/nt")</pr>, <pos>n.</pos> <def>the
easing of tensions or strained relations (especially between nations),
as by agreement, negotiation, or tacit understandings.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Detention</ent><br/
<hw>De*ten"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>detentio</ets>: cf. F. <ets>d<eacute/tention</ets>. See
<er>Detain</er>.]</ety> <sn>1.</sn> <def>The act of detaining or keeping
back; a withholding.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The state of being detained (stopped or hindered);
delay from necessity.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Confinement; restraint; custody.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The archduke Philip . . . found himself in a sort of honorable
<qex>detention</qex> at Henry's court.</q>
<rj><qau>Hallam.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deter</ent><br/
<hw>De*ter"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Deterred</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Deterring</conjf>.]</vmorph> <ety>[L.
<ets>deterrere</ets>; <ets>de</ets> + <ets>terrere</ets> to frighten,
terrify. See <er>Terror</er>.]</ety> <def>To prevent by fear; hence, to
hinder or prevent from action by fear of consequences, or difficulty,
risk, etc.</def> <rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Potent enemies tempt and <qex>deter</qex> us from our duty.</q>
<rj><qau>Tillotson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>My own face <qex>deters</qex> me from my glass.</q>
<rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deterge</ent><br/
<hw>De*terge"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Deterged</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Deterging</conjf>.]</vmorph> <ety>[L.
<ets>detergere</ets>, <ets>detersum</ets>; <ets>de</ets> +
<ets>tergere</ets> to rub or wipe off: cf. F.
<ets>d<eacute/terger</ets>.]</ety> <def>To cleanse; to purge away, as
foul or offending matter from the body, or from an ulcer.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detergency</ent><br/
<hw>De*ter"gen*cy</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A cleansing
quality or power.</def> <rj><au>De Foe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detergent</ent><br/
<hw>De*ter"gent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>detergens</ets>, <ets>-entis</ets>, p. pr. of <ets>detergere</ets>:
cf. F. <ets>d<eacute/tergent</ets>.]</ety> <def>Cleansing;
purging.</def> -- <def2><pos>n.</pos> <def>A substance which cleanses
the skin, as water or soap; a medicine to cleanse wounds, ulcers,
etc.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deteriorate</ent><br/
<hw>De*te"ri*o*rate</hw>
<pr>(d<esl/*t<emac/"r<icr/*<osl/*r<amac/t)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Deteriorated</conjf>
<pr>(d<esl/*t<emac/"r<icr/*<osl/*r<amac/`t<ecr/d)</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>Deteriorating</conjf>
<pr>(d<esl/*t<emac/"r<icr/*<osl/*r<amac/`t<icr/ng)</pr>.]</vmorph>
<ety>[L. <ets>deterioratus</ets>, p. p. of <ets>deteriorare</ets> to
deteriorate, fr. <ets>deterior</ets> worse, prob. a comparative fr.
<ets>de</ets> down, away.]</ety> <def>To make worse; to make inferior in
quality or value; to impair; <as>as, to <ex>deteriorate</ex> the
mind</as>.</def> <rj><au>Whately.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The art of war . . . was greatly <qex>deteriorated</qex>.</q>
<rj><qau>Southey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 401 --></p>

<p><ent>deteriorate</ent><br/
<hw>de*te"ri*o*rate</hw>
<pr>(d<esl/*t<emac/"r<icr/*<osl/*r<amac/t)</pr>, <pos>v. i.</pos>
<def>To grow worse; to be impaired in quality; to degenerate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Under such conditions, the mind rapidly
<qex>deteriorates</qex>.</q> <rj><qau>Goldsmith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>deteriorating</ent><br/
<hw>deteriorating</hw> <pos>adj.</pos> <def>going from better to
worse.</def><br/
<syn><b>Syn. --</b> declining, failing, regressing, retrograde,
retrogressive.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Deterioration</ent><br/
<hw>De*te`ri*o*ra"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL.
<ets>deterioratio</ets>: cf. F.
<ets>d<eacute/t<eacute/rioration</ets>.]</ety> <def>The process of
growing worse, or the state of having grown worse.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>deteriority</ent><br/
<hw>de*te`ri*or"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>deterior</ets> worse. See <er>Deteriorate</er>.]</ety> <def>Worse
state or quality; inferiority.</def> <ldquo/The <xex>deteriority</xex>
of the diet.<rdquo/ <mark>[R.]</mark> <rj><au>Ray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Determent</ent><br/
<hw>De*ter"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<er>Deter</er>.]</ety> <def>The act of deterring; also, that which
deters.</def> <rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Determinability</ent><br/
<hw>De*ter`mi*na*bil"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The
quality of being determinable; determinableness.</def>
<rj><au>Coleridge.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Determinable</ent><br/
<hw>De*ter"mi*na*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>determinabilis</ets> finite. See <er>Determine</er>, <pos>v.
t.</pos>]</ety> <def>Capable of being determined, definitely
ascertained, decided upon, or brought to a conclusion.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Not wholly <qex>determinable</qex> from the grammatical use of the
words.</q> <rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Determinableness</ent><br/
<hw>De*ter"mi*na*ble*ness</hw>, <pos>n.</pos> <def>Capability of being
determined; determinability.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Determinacy</ent><br/
<hw>De*ter"mi*na*cy</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Determinateness.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Determinant</ent><br/
<hw>De*ter"mi*nant</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>determinans</ets>, p. pr. of <ets>determinare</ets>: cf. F.
<ets>d<eacute/terminant</ets>.]</ety> <def>Serving to determine or
limit; determinative.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Determinant</ent><br/
<hw>De*ter"mi*nant</hw>, <pos>n.</pos> <sn>1.</sn> <def>That which
serves to determine; that which causes determination.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Math.)</fld> <def>The sum of a series of products
of several numbers, these products being formed according to certain
specified laws</def>; <note>thus, the <ex>determinant</ex> of the nine
numbers<br/
<matrix><row>a, b, c,</row><row>a<prime/, b<prime/,
c<prime/,</row><row>a<prime/<prime/, b<prime/<prime/,
c<prime/<prime/,</row></matrix><br/
is <mathex>a b<prime/ c<prime/<prime/ - a b<prime/<prime/ c<prime/ +
a<prime/ b<prime/<prime/ c] - a<prime/ b c<prime/<prime/ +
a<prime/<prime/ b<prime/ c</mathex>. The determinant is written by
placing the numbers from which it is formed in a square between two
vertical lines. The theory of <ex>determinants</ex> forms a very
important branch of modern mathematics.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Logic)</fld> <def>A mark or attribute, attached to
the subject or predicate, narrowing the extent of both, but rendering
them more definite and precise.</def> <rj><au>Abp.
Thomson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Determinate</ent><br/
<hw>De*ter"mi*nate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>determinatus</ets>, p. p. of <ets>determinare</ets>. See
<er>Determine</er>.]</ety> <sn>1.</sn> <def>Having defined limits; not
uncertain or arbitrary; fixed; established; definite.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Quantity of words and a <qex>determinate</qex> number of feet.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Conclusive; decisive; positive.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>determinate</qex> counsel and foreknowledge of God.</q>
<rj><qau>Acts ii. 23.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Determined or resolved upon.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>My <qex>determinate</qex> voyage.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Of determined purpose; resolute.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>More <qex>determinate</qex> to do than skillful how to do.</q>
<rj><qau>Sir P. Sidney.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Determinate inflorescence</b></col> <fld>(Bot.)</fld>,
<cd>that in which the flowering commences with the terminal bud of a
stem, which puts a limit to its growth; -- also called
<altname>centrifugal inflorescence</altname>.</cd> --
<col><b>Determinate problem</b></col> <fld>(Math.)</fld>, <cd>a problem
which admits of a limited number of solutions.</cd> --
<mcol><col><b>Determinate quantities</b></col>, <col><b>Determinate
equations</b></col></mcol> <fld>(Math.)</fld>, <cd>those that are finite
in the number of values or solutions, that is, in which the conditions
of the problem or equation determine the number.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Determinate</ent><br/
<hw>De*ter"mi*nate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To bring to
an end; to determine. See <er>Determine</er>.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The sly, slow hours shall not <qex>determinate</qex><br/
The dateless limit of thy dear exile.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Determinately</ent><br/
<hw>De*ter"mi*nate*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <sn>1.</sn>
<def>In a determinate manner; definitely; ascertainably.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The principles of religion are already either
<qex>determinately</qex> true or false, before you think of them.</q>
<rj><qau>Tillotson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Resolutely; unchangeably.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Being <qex>determinately</qex> . . . bent to marry.</q>
<rj><qau>Sir P. Sidney.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Determinateness</ent><br/
<hw>De*ter"mi*nate*ness</hw>, <pos>n.</pos> <def>State of being
determinate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Determination</ent><br/
<hw>De*ter`mi*na"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>determinatio</ets> boundary, end: cf. F.
<ets>d<eacute/termination</ets>.]</ety> <sn>1.</sn> <def>The act of
determining, or the state of being determined.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Bringing to an end; termination; limit.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A speedy <qex>determination</qex> of that war.</q>
<rj><qau>Ludlow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Direction or tendency to a certain end;
impulsion.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Remissness can by no means consist with a constant
<qex>determination</qex> of the will . . . to the greatest apparent
good.</q> <rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The quality of mind which reaches definite
conclusions; decision of character; resoluteness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He only is a well-made man who has a good
<qex>determination</qex>.</q> <rj><qau>Emerson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>The state of decision; a judicial decision, or
ending of controversy.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>That which is determined upon; result of
deliberation; purpose; conclusion formed; fixed resolution.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>So bloodthirsty a <qex>determination</qex> to obtain
convictions.</q> <rj><qau>Hallam.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Med.)</fld> <def>A flow, rush, or tendency to a
particular part; <as>as, a <ex>determination</ex> of blood to the
head</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <fld>(Physical Sciences)</fld> <def>The act, process, or
result of any accurate measurement, as of length, volume, weight,
intensity, etc.; <as>as, the <ex>determination</ex> of the ohm or of the
wave length of light; the <ex>determination</ex> of the salt in sea
water, or the oxygen in the air.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <fld>(Logic)</fld> <sd>(a)</sd> <def>The act of defining
a concept or notion by giving its essential constituents.</def>
<sd>(b)</sd> <def>The addition of a differentia to a concept or notion,
thus limiting its extent; -- the opposite of
<ant>generalization</ant>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <fld>(Nat. Hist.)</fld> <def>The act of determining the
relations of an object, as regards genus and species; the referring of
minerals, plants, or animals, to the species to which they belong;
classification; <as>as, I am indebted to a friend for the
<ex>determination</ex> of most of these shells</as>.</def></p>

<p><syn><b>Syn.</b> -- Decision; conclusion; judgment; purpose;
resolution; resolve; firmness. See <er>Decision</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Determinative</ent><br/
<hw>De*ter"mi*na*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>d<eacute/terminatif</ets>.]</ety> <def>Having power to determine;
limiting; shaping; directing; conclusive.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Incidents . . . <qex>determinative</qex> of their course.</q>
<rj><qau>I. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Determinative tables</b></col> <fld>(Nat. Hist.)</fld>,
<cd>tables presenting the specific character of minerals, plants, etc.,
to assist in determining the species to which a specimen
belongs.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Determinative</ent><br/
<hw>De*ter"mi*na*tive</hw> <pr>(?)</pr>, <pos>n.</pos> <def>That which
serves to determine.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Explanatory <qex>determinatives</qex> . . . were placed after
words phonetically expressed, in order to serve as an aid to the reader
in determining the meaning.</q> <rj><qau>I. Taylor (The
Alphabet).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Determinator</ent><br/
<hw>De*ter"mi*na`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.]</ety>
<def>One who determines.</def> <mark>[R.]</mark> <rj><au>Sir T.
Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Determine</ent><br/
<hw>De*ter"mine</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Determined</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Determining</conjf>.]</vmorph> <ety>[F.
<ets>d<eacute/terminer</ets>, L. <ets>determinare</ets>,
<ets>determinatum</ets>; <ets>de</ets> + <ets>terminare</ets> limit,
<ets>terminus</ets> limit. See <er>Term</er>.]</ety> <sn>1.</sn> <def>To
fix the boundaries of; to mark off and separate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>[God] hath <qex>determined</qex> the times before appointed.</q>
<rj><qau>Acts xvii. 26.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To set bounds to; to fix the determination of; to
limit; to bound; to bring to an end; to finish.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The knowledge of men hitherto hath been <qex>determined</qex> by
the view or sight.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Now, where is he that will not stay so long<br/
Till his friend sickness hath <qex>determined</qex> me?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To fix the form or character of; to shape; to
prescribe imperatively; to regulate; to settle.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The character of the soul is <qex>determined</qex> by the
character of its God.</q> <rj><qau>J. Edwards.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Something divinely beautiful . . . that at some time or other
might influence or even <qex>determine</qex> her course of life.</q>
<rj><qau>W. Black.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To fix the course of; to impel and direct; -- with a
remoter object preceded by <xex>to</xex>; <as>as, another's will
<ex>determined</ex> me to this course</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To ascertain definitely; to find out the specific
character or name of; to assign to its true place in a system; <as>as,
to <ex>determine</ex> an unknown or a newly discovered plant or its
name</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To bring to a conclusion, as a question or
controversy; to settle authoritative or judicial sentence; to decide;
<as>as, the court has <ex>determined</ex> the cause</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>To resolve on; to have a fixed intention of; also,
to cause to come to a conclusion or decision; to lead; <as>as, this
<ex>determined</ex> him to go immediately</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <fld>(Logic)</fld> <def>To define or limit by adding a
differentia.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <fld>(Physical Sciences)</fld> <def>To ascertain the
presence, quantity, or amount of; <as>as, to <ex>determine</ex> the
parallax; to <ex>determine</ex> the salt in sea water.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Determine</ent><br/
<hw>De*ter"mine</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To come to an
end; to end; to terminate.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He who has vented a pernicious doctrine or published an ill book
must know that his life <qex>determine</qex> not together.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Estates may <qex>determine</qex> on future contingencies.</q>
<rj><qau>Blackstone.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To come to a decision; to decide; to resolve; --
often with <xex>on</xex>.</def> <ldquo/<xex>Determine</xex> on some
course.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He shall pay as the judges <qex>determine</qex>.</q> <rj><qau>Ex.
xxi. 22.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Determined</ent><br/
<hw>De*ter"mined</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Decided;
resolute.</def> <ldquo/A<xex>determined</xex> foe.<rdquo/
<rj><au>Sparks.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Determinedly</ent><br/
<hw>De*ter"min*ed*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a
determined manner; with determination.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Determiner</ent><br/
<hw>De*ter"min*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, determines or decides.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Determinism</ent><br/
<hw>De*ter"min*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Metaph.)</fld>
<def>The doctrine that the will is not free, but is inevitably and
invincibly determined by motives, preceding events, and natural
laws.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Its superior suitability to produce courage, as contrasted with
scientific physical <qex>determinism</qex>, is obvious.</q> <rj><qau>F.
P. Cobbe.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Determinist</ent><br/
<hw>De*ter"min*ist</hw>, <pos>n.</pos> <fld>(Metaph.)</fld> <def>One who
believes in determinism. Also <pos>adj.</pos>; <as>as,
<ex>determinist</ex> theories</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>deterministic</ent><br/
<hw>de*ter`min*ist"ic</hw>, <pos>a.</pos> <sn>1.</sn> <def>of or
pertaining to determinism; <as>as, <ex>deterministic</ex>
theories</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>causally determined and not subject to random
chance.</def><br/
[<source>PJC</source>]</p>

<p><ent>Deterration</ent><br/
<hw>De`ter*ra"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>de</ets> + <ets>terra</ets> earth: cf. F.
<ets>d<eacute/terrer</ets> to unearth.]</ety> <def>The uncovering of
anything buried or covered with earth; a taking out of the earth or
ground.</def> <rj><au>Woodward.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deterrence</ent><br/
<hw>De*ter"rence</hw> <pr>(?)</pr>, <pos>n.</pos> <def>That which
deters; a deterrent; a hindrance.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deterrent</ent><br/
<hw>De*ter"rent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>deterrens</ets>, p. pr. of <ets>deterrere</ets>. See
<er>Deter</er>.]</ety> <def>Serving to deter.</def> <ldquo/The
<xex>deterrent</xex> principle.<rdquo/ <rj><au>E. Davis.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deterrent</ent><br/
<hw>De*ter"rent</hw>, <pos>n.</pos> <def>That which deters or
prevents.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detersion</ent><br/
<hw>De*ter"sion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>d<eacute/tersion</ets>. See <er>Deterge</er>.]</ety> <def>The act
of deterging or cleansing, as a sore.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detersive</ent><br/
<hw>De*ter"sive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf.
<ets>d<eacute/tersif</ets>.]</ety> <def>Cleansing; detergent.</def> --
<def2><pos>n.</pos> <def>A cleansing agent; a
detergent.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detersively</ent><br/
<hw>De*ter"sive*ly</hw>, <pos>adv.</pos> <def>In a way to
cleanse.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detersiveness</ent><br/
<hw>De*ter"sive*ness</hw>, <pos>n.</pos> <def>The quality of
cleansing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detest</ent><br/
<hw>De*test"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Detested</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Detesting</conjf>.]</vmorph> <ety>[L. <ets>detestare</ets>,
<ets>detestatum</ets>, and <ets>detestari</ets>, to curse while calling
a deity to witness, to execrate, detest; <ets>de</ets> +
<ets>testari</ets> to be a witness, testify, <ets>testis</ets> a
witness: cf. F. <ets>d<eacute/tester</ets>. See <er>Testify</er>.]</ety>
<sn>1.</sn> <def>To witness against; to denounce; to condemn.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The heresy of Nestorius . . . was <qex>detested</qex> in the
Eastern churches.</q> <rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>God hath <qex>detested</qex> them with his own mouth.</q>
<rj><qau>Bale.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To hate intensely; to abhor; to abominate; to
loathe; <as>as, we <ex>detest</ex> what is contemptible or
evil</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Who dares think one thing, and another tell,<br/
My heart <qex>detests</qex> him as the gates of hell.</q>
<rj><qau>Pope.</qau></rj></p>

<p><syn><b>Syn.</b> -- To abhor; abominate; execrate. See
<er>Hate</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detestability</ent><br/
<hw>De*test`a*bil"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Capacity of
being odious.</def> <mark>[R.]</mark> <rj><au>Carlyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detestable</ent><br/
<hw>De*test"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>detestabilis</ets>: cf. F. <ets>d<eacute/testable</ets>.]</ety>
<def>Worthy of being detested; abominable; extremely hateful; very
odious; deserving abhorrence; <as>as, <ex>detestable</ex>
vices</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou hast defiled my sanctuary will all thy <qex>detestable</qex>
things, and with all thine abominations.</q> <rj><qau>Ezek. v.
11.</qau></rj></p>

<p><syn><b>Syn.</b> -- Abominable; odious; execrable;
abhorred.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detestableness</ent><br/
<hw>De*test"a*ble*ness</hw>, <pos>n.</pos> <def>The quality or state of
being detestable.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detestably</ent><br/
<hw>De*test"a*bly</hw>, <pos>adv.</pos> <def>In a detestable
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detestate</ent><br/
<hw>De*tes"tate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To
detest.</def> <mark>[Obs.]</mark> <rj><au>Udall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detestation</ent><br/
<hw>Det`es*ta"tion</hw> <pr>(?; 277)</pr>, <pos>n.</pos> <ety>[L.
<ets>detestatio</ets>: cf. F. <ets>d<eacute/testation</ets>.]</ety>
<def>The act of detesting; extreme hatred or dislike; abhorrence;
loathing.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We are heartily agreed in our <qex>detestation</qex> of civil
war.</q> <rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detester</ent><br/
<hw>De*test"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
detests.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>dethrone</ent><br/
<hw>de*throne"</hw> <pr>(d<esl/*thr<omac/n")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Dethroned</conjf>
<pr>(d<esl/*thr<omac/nd")</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Dethroning</conjf>.]</vmorph> <ety>[Pref. <ets>de-</ets> +
<ets>throne</ets>: cf. F. <ets>d<eacute/tr<ocir/ner</ets>; pref.
<ets>d<eacute/-</ets> (L. <ets>dis-</ets>) + <ets>tr<ocir/ne</ets>
throne. See <er>Throne</er>.]</ety> <def>To remove or drive from a
throne; to depose; to divest of supreme authority and dignity.</def>
<ldquo/The Protector was <xex>dethroned</xex>.<rdquo/
<rj><au>Hume.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>dethronement</ent><br/
<hw>de*throne"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>d<eacute/tr<ocir/nement</ets>.]</ety> <def>Deposal from a throne;
deposition from regal power.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>dethroner</ent><br/
<hw>de*thron"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
dethrones.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dethronization</ent><br/
<hw>De*thron`i*za"tion</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Dethronement.</def> <mark>[Obs.]</mark>
<rj><au>Speed.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dethronize</ent><br/
<hw>De*thron"ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Cf. LL.
<ets>dethronizare</ets>.]</ety> <def>To dethrone or unthrone.</def>
<mark>[Obs.]</mark> <rj><au>Cotgrave.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detinue</ent><br/
<hw>Det"i*nue</hw> <pr>(?; 277)</pr>, <pos>n.</pos> <ety>[OF.
<ets>detinu</ets>, <ets>detenu</ets>, p. p. of <ets>detenir</ets> to
detain. See <er>Detain</er>.]</ety> <def>A person or thing
detained</def>; <fld>(Law)</fld> <def>A form of action for the recovery
of a personal chattel wrongfully detained.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Writ of detinue</b></col> <fld>(Law)</fld>, <cd>one that
lies against him who wrongfully <xex>detains</xex> goods or chattels
delivered to him, or in possession, to recover the thing itself, or its
value and damages, from the detainer. It is now in a great measure
superseded by other remedies.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detonate</ent><br/
<hw>Det"o*nate</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Detonated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Detonating</conjf> <pr>(?)</pr>.]</vmorph> <ety>[L.
<ets>detonare</ets>, v. i., to thunder down; <ets>de</ets> +
<ets>tonare</ets> to thunder; akin to E. <ets>thunder</ets>. See
<er>Thunder</er>, and cf. <er>Detonize</er>.]</ety> <def>To explode with
a sudden report; <as>as, niter <ex>detonates</ex> with
sulphur</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detonate</ent><br/
<hw>Det"o*nate</hw>, <pos>v. t.</pos> <def>To cause to explode; to cause
to burn or inflame with a sudden report.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detonating</ent><br/
<hw>Det"o*na`ting</hw>, <pos>a. & n.</pos> <def>from
<er>Detonate</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Detonating gas</b></col>, <cd>a mixture of two volumes of
hydrogen with one volume of oxygen, which explodes with a loud report
upon ignition.</cd> -- <col><b>Detonating powder</b></col>, <cd>any
powder or solid substance, as fulminate of mercury, which when struck,
explodes with violence and a loud report.</cd> -- <col><b>Detonating
primer</b></col>, <cd>a primer exploded by a fuse; -- used to explode
gun cotton in blasting operations.</cd> -- <col><b>Detonating
tube</b></col>, <cd>a strong tube of glass, usually graduated, closed at
one end, and furnished with two wires passing through its sides at
opposite points, and nearly meeting, for the purpose of exploding
gaseous mixtures by an electric spark, as in gas analysis,
etc.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detonation</ent><br/
<hw>Det`o*na"tion</hw> <pr>(d<ecr/t`<osl/*n<amac/"sh<ucr/n)</pr>,
<pos>n.</pos> <ety>[Cf. F. <ets>d<eacute/tonation</ets>.]</ety> <def>An
explosion or sudden report made by the instantaneous decomposition or
combustion of unstable substances; <as>as, the <ex>detonation</ex> of
gun cotton</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detonator</ent><br/
<hw>Det"o*na`tor</hw> <pr>(d<ecr/t"<osl/*n<amac/`t<etil/r)</pr>,
<pos>n.</pos> <def>One that detonates</def>; <specif>specif.:</specif>
<sd>(a)</sd> <def>An explosive whose action is practically
instantaneous.</def> <sd>(b)</sd> <def>Something used to detonate a
charge, as a detonating fuse.</def> <sd>(c)</sd> <def>A case containing
detonating powder, the explosion of which serves as a signal, as on
railroads.</def> <sd>(d)</sd> <def>A gun fired by a percussion
cap.</def> <mark>[Obs.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Detonization</ent><br/
<hw>Det`o*ni*za"tion</hw>
<pr>(d<ecr/t`<osl/*n<icr/*z<amac/"sh<ucr/n)</pr>, <pos>n.</pos> <def>The
act of detonizing; detonation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detonize</ent><br/
<hw>Det"o*nize</hw> <pr>(d<ecr/t"<osl/*n<imac/z)</pr>, <pos>v. t. &
i.</pos> <ety>[See <er>Detonate</er>.]</ety> <vmorph>[<pos>imp. & p.
p.</pos><conjf>Detonized</conjf> <pr>(#)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Detonizing</conjf>.]</vmorph> <def>To explode, or cause
to explode; to burn with an explosion; to detonate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detorsion</ent><br/
<hw>De*tor"sion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Detortion</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detort</ent><br/
<hw>De*tort"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Detorted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Detorting</conjf>.]</vmorph> <ety>[L. <ets>detortus</ets>, p. p.
of <ets>detorquere</ets> to turn away; <ets>de</ets> +
<ets>torquere</ets> to turn about, twist: cf. F.
<ets>d<eacute/torquer</ets>, <ets>d<eacute/tordre</ets>.]</ety> <def>To
turn form the original or plain meaning; to pervert; to wrest.</def>
<rj><au>Hammond.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detortion</ent><br/
<hw>De*tor"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
detorting, or the state of being detorted; a twisting or
warping.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detour</ent><br/
<hw>De`tour"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>d<eacute/tour</ets>, fr. <ets>d<eacute/tourner</ets> to turn aside;
pref. <ets>d<eacute/-</ets> (L. <ets>dis-</ets>) + <ets>tourner</ets> to
turn. See <er>Turn</er>.]</ety> <def>A turning; a circuitous route; a
deviation from a direct course; <as>as, the <ex>detours</ex> of the
Mississippi</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>detox</ent><br/
<hw>detox</hw> <pos>n.</pos> <sn>1.</sn> <def>the hospital ward or
clinic in which patients are detoxified; -- often used
attributively.</def><br/
<syn><b>Syn. --</b> detox ward.</syn>
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>detoxification.</def><br/
[<source>PJC</source>]</p>

<p><ent>detox</ent><br/
<hw>detox</hw> <pos>v. t.</pos> <def>to detoxify.</def>
<mark>[informal]</mark> <br/
[<source>PJC</source>]</p>

<p><ent>detoxicate</ent><br/
<hw>detoxicate</hw> <pos>v. t.</pos> <def>to remove poison
from.</def><br/
<syn><b>Syn. --</b> detoxify.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>detoxify</ent><br/
<hw>detoxify</hw> <pos>v. t.</pos> <sn>1.</sn> <def>to remove poison
from; to rid of the effects of poison.</def><br/
<syn><b>Syn. --</b> detoxicate.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>to render (a poisonous substance) non-toxic or
harmless.</def><br/
[<source>PJC</source>]</p>

<p><ent>detoxification</ent><br/
<hw>detoxification</hw> <pos>n.</pos> <sn>1.</sn> <def>a medically
supervised treatment for addiction to drugs or alcohol intended to rid
the body of the addictive substances.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>treatment for poisoning by counteracting its toxic
properties.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>3.</sn> <def>conversion (of a poisonous substance) to a non-toxic
or harmless state.</def><br/
[<source>PJC</source>]</p>

<p><ent>Detract</ent><br/
<hw>De*tract"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Detracted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Detracting</conjf>.]</vmorph> <ety>[L. <ets>detractus</ets>, p.
p. of <ets>detrahere</ets> to detract; <ets>de</ets> +
<ets>trahere</ets> to draw: cf. F. <ets>d<eacute/tracter</ets>. See
<er>Trace</er>.]</ety> <sn>1.</sn> <def>To take away; to
withdraw.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Detract</qex> much from the view of the without.</q>
<rj><qau>Sir H. Wotton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To take credit or reputation from; to
defame.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That calumnious critic . . . <br/
<qex>Detracting</qex> what laboriously we do.</q>
<rj><qau>Drayton.</qau></rj></p>

<p><syn><b>Syn.</b> -- To derogate; decry; disparage; depreciate;
asperse; vilify; defame; traduce. See <er>Decry</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detract</ent><br/
<hw>De*tract"</hw>, <pos>v. i.</pos> <def>To take away a part or
something, especially from one's credit; to lessen reputation; to
derogate; to defame; -- often with <xex>from</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It has been the fashion to <qex>detract</qex> both from the moral
and literary character of Cicero.</q> <rj><qau>V. Knox.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detracter</ent><br/
<hw>De*tract"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who detracts;
a detractor.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Other <qex>detracters</qex> and malicious writers.</q>
<rj><qau>Sir T. North.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detractingly</ent><br/
<hw>De*tract"ing*ly</hw>, <pos>adv.</pos> <def>In a detracting
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detraction</ent><br/
<hw>De*trac"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>d<eacute/traction</ets>, L. <ets>detractio</ets>.]</ety>
<sn>1.</sn> <def>A taking away or withdrawing.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>detraction</qex> of the eggs of the said wild fowl.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The act of taking away from the reputation or good
name of another; a lessening or cheapening in the estimation of others;
the act of depreciating another, from envy or malice; calumny.</def></p>

<p><syn><b>Syn.</b> -- Depreciation; disparagement; derogation; slander;
calumny; aspersion; censure.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detractious</ent><br/
<hw>De*trac"tious</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Containing
detraction; detractory.</def> <mark>[R.]</mark>
<rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detractive</ent><br/
<hw>De*tract"ive</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Tending to detractor draw.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Tending to lower in estimation;
depreciative.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detractiveness</ent><br/
<hw>De*tract"ive*ness</hw>, <pos>n.</pos> <def>The quality of being
detractive.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detractor</ent><br/
<hw>De*tract"or</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.: cf. F.
<ets>d<eacute/tracteur</ets>.]</ety> <def>One who detracts; a derogator;
a defamer.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His <qex>detractors</qex> were noisy and scurrilous.</q>
<rj><qau>Macaulay.</qau></rj></p>

<p><syn><b>Syn.</b> -- Slanderer; calumniator; defamer;
vilifier.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detractory</ent><br/
<hw>De*tract"o*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Defamatory by
denial of desert; derogatory; calumnious.</def> <rj><au>Sir T.
Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detractress</ent><br/
<hw>De*tract"ress</hw>, <pos>n.</pos> <def>A female detractor.</def>
<rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detrain</ent><br/
<hw>De*train"</hw> <pr>(?)</pr>, <pos>v. i. & t.</pos> <def>To alight,
or to cause to alight, from a railway train.</def> <mark>[Eng.]</mark>
<rj><au>London Graphic.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detrect</ent><br/
<hw>De*trect"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>detrectare</ets>; <ets>de</ets> + <ets>tractare</ets>, intens. of
<ets>trahere</ets> to draw.]</ety> <def>To refuse; to decline.</def>
<mark>[Obs.]</mark> <ldquo/To <xex>detrect</xex> the battle.<rdquo/
<rj><au>Holinshed.</au></rj></p>

<p><ent>detribalisation</ent><br/
<hw>detribalisation</hw> <pos>n.</pos> <def>same as
<er>detribalization</er>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>detribalization</ent><br/
<hw>detribalization</hw> <pos>n.</pos> <def>the act of causing tribal
people to abandon their customs and adopt urban ways of
living.</def><br/
<syn><b>Syn. --</b> detribalisation.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>detribalize</ent><br/
<hw>detribalize</hw> <pos>v. t.</pos> <def>to cause (members of a tribe)
to lose their cultural identity and adopt other customs.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><-- p. 402 --></p>

<p><ent>Detriment</ent><br/
<hw>Det"ri*ment</hw> <pr>(d<ecr/t"r<icr/*m<eit/nt)</pr>, <pos>n.</pos>
<ety>[L. <ets>detrimentum</ets>, fr. <ets>deterere</ets>,
<ets>detritum</ets>, to rub or wear away; <ets>de</ets> +
<ets>terere</ets> to rub: cf. F. <ets>d<eacute/triment</ets>. See
<er>Trite</er>.]</ety> <sn>1.</sn> <def>That which injures or causes
damage; mischief; harm; diminution; loss; damage; -- used very
generically; <as>as, <ex>detriments</ex> to property, religion, morals,
etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>I can repair<br/
That <qex>detriment</qex>, if such it be.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A charge made to students and barristers for
incidental repairs of the rooms they occupy.</def>
<mark>[Eng.]</mark></p>

<p><syn><b>Syn.</b> -- Injury; loss; damage; disadvantage; prejudice;
hurt; mischief; harm.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detriment</ent><br/
<hw>Det"ri*ment</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To do injury
to; to hurt.</def> <mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Other might be <qex>determined</qex> thereby.</q>
<rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detrimental</ent><br/
<hw>Det`ri*men"tal</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Causing
detriment; injurious; hurtful.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Neither dangerous nor <qex>detrimental</qex> to the donor.</q>
<rj><qau>Addison.</qau></rj></p>

<p><syn><b>Syn.</b> -- Injurious; hurtful; prejudicial; disadvantageous;
mischievous; pernicious.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detrimentalness</ent><br/
<hw>Det`ri*men"tal*ness</hw>, <pos>n.</pos> <def>The quality of being
detrimental; injuriousness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detrital</ent><br/
<hw>De*tri"tal</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Geol.)</fld>
<def>Pertaining to, or composed of, detritus.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detrite</ent><br/
<hw>De*trite"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>detritus</ets>, p. p.]</ety> <def>Worn out.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detrition</ent><br/
<hw>De*tri"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL.
<ets>detritio</ets>. See <er>Detriment</er>.]</ety> <def>A wearing off
or away.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Phonograms which by process long-continued <qex>detrition</qex>
have reached a step of extreme simplicity.</q> <rj><qau>I. Taylor (The
Alphabet).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detritus</ent><br/
<hw>De*tri"tus</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>d<eacute/tritus</ets>, fr. L. <ets>detritus</ets>, p. p. of
<ets>deterere</ets>. See <er>Detriment</er>.]</ety> <sn>1.</sn>
<fld>(Geol.)</fld> <def>A mass of substances worn off from solid bodies
by attrition, and reduced to small portions; <as>as, diluvial
<ex>detritus</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ For large portions, the word <xex>d<eacute/bris</xex> is
used.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence: Any fragments separated from the body to
which they belonged; any product of disintegration.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The mass of <qex>detritus</qex> of which modern languages are
composed.</q> <rj><qau>Farrar.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detrude</ent><br/
<hw>De*trude"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Detruded</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Detruding</conjf>.]</vmorph> <ety>[L. <ets>detrudere</ets>,
<ets>detrusum</ets>; <ets>de</ets> + <ets>trudere</ets> to thrust,
push.]</ety> <def>To thrust down or out; to push down with force.</def>
<rj><au>Locke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detruncate</ent><br/
<hw>De*trun"cate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Detruncated</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Detruncating</conjf>.]</vmorph> <ety>[L. <ets>detruncatus</ets>,
p. p. of <ets>detruncare</ets> to cut off; <ets>de</ets> +
<ets>truncare</ets> to maim, shorten, cut off. See
<er>Truncate</er>.]</ety> <def>To shorten by cutting; to cut off; to lop
off.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detruncation</ent><br/
<hw>De`trun*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>detruncatio</ets>: cf. F. <ets>d<eacute/troncation</ets>.]</ety>
<def>The act of lopping or cutting off, as the head from the
body.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detrusion</ent><br/
<hw>De*tru"sion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>detrusio</ets>. See <er>Detrude</er>.]</ety> <def>The act of
thrusting or driving down or outward; outward thrust.</def> --
<wordforms><wf>De*tru"sive</wf>, <pos>a.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dette</ent><br/
<hw>Dette</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Debt.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detteles</ent><br/
<hw>Dette"les</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Free from
debt.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detumescence</ent><br/
<hw>De`tu*mes"cence</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>detumescere</ets> to cease swelling; <ets>de</ets> +
<ets>tumescere</ets>, <ets>tumere</ets>, to swell.]</ety>
<def>Diminution of swelling; subsidence of anything swollen.</def>
<mark>[R.]</mark> <rj><au>Cudworth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Detur</ent><br/
\'d8<hw>De"tur</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>detur</ets> let it be given.]</ety> <def>A present of books given
to a meritorious undergraduate student as a prize.</def> <mark>[Harvard
Univ., U. S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deturb</ent><br/
<hw>De*turb"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>deturbare</ets>.]</ety> <def>To throw down.</def>
<mark>[Obs.]</mark> <rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deturbate</ent><br/
<hw>De*tur"bate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[LL.
<ets>deturbatus</ets>, p. p. of <ets>deturbare</ets>, fr. L.
<ets>deturbare</ets> to thrust down.]</ety> <def>To evict; to
remove.</def> <mark>[Obs.]</mark> <rj><au>Foxe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deturbation</ent><br/
<hw>Det`ur*ba"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
deturbating.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deturn</ent><br/
<hw>De*turn"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>de-</ets> + <ets>turn</ets>. Cf. <er>Detour</er>.]</ety> <def>To
turn away.</def> <mark>[Obs.]</mark> <rj><au>Sir K. Digby.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deturpate</ent><br/
<hw>De*tur"pate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>deturpare</ets>; <ets>de</ets> + <ets>turpare</ets> to make ugly,
defile, <ets>turpis</ets> ugly, foul.]</ety> <def>To defile; to
disfigure.</def> <mark>[Obs.]</mark> <rj><au>Jer. Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deturpation</ent><br/
<hw>Det`ur*pa"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A making
foul.</def> <mark>[Obs.]</mark> <rj><au>Jer. Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deuce</ent><br/
<hw>Deuce</hw> <pr>(d<umac/s)</pr>, <pos>n.</pos> <ety>[F.
<ets>deux</ets> two, OF. <ets>deus</ets>, fr. L. <ets>duo</ets>. See
<er>Two</er>.]</ety> <sn>1.</sn> <fld>(Gaming)</fld> <def>Two; a card or
a die with two spots; <as>as, the <ex>deuce</ex> of
hearts</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Tennis)</fld> <def>A condition of the score
beginning whenever each side has won three strokes in the same game
(also reckoned <ldquo/40 all<rdquo/), and reverted to as often as a tie
is made until one of the sides secures two successive strokes following
a tie or <xex>deuce</xex>, which decides the game.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deuce</ent><br/
<hw>Deuce</hw>, <pos>n.</pos> <ety>[Cf. LL. <ets>dusius</ets>, Armor,
<ets>dus</ets>, <ets>te<ucir/z</ets>, phantom, specter; Gael.
<ets>taibhs</ets>, <ets>taibhse</ets>, apparition, ghost; or fr. OF.
<ets>deus</ets> God, fr. L. <ets>deus</ets> (cf. <er>Deity</er>).]</ety>
<def>The devil; a demon.</def> <altsp>[A euphemism, written also
<asp>deuse</asp>.]</altsp> <mark>[Low]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deuced</ent><br/
<hw>Deu"ced</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Devilish; excessive;
extreme.</def> <mark>[Low]</mark> -- <wordforms><wf>Deu"ced*ly</wf>,
<pos>adv.</pos></wordforms></p>

<p><ent>Deused</ent><br/
<ent>Deuse</ent><br/
<mhw><hw>Deuse</hw> <pr>(d<umac/s)</pr>, <pos>n.</pos>; <hw>Deu"sed</hw>
<pr>(d<umac/"s<ecr/d)</pr>, <pos>a.</pos></mhw> <def>See <er>Deuce</er>,
<er>Deuced</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deuterocanonical</ent><br/
<hw>Deu`ter*o*ca*non"ic*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>deu`teros</grk> second + E. <ets>canonical</ets>.]</ety>
<def>Pertaining to a second canon, or ecclesiastical writing of inferior
authority; -- said of the Apocrypha, certain Epistles, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deuterogamist</ent><br/
<hw>Deu`ter*og"a*mist</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Deuterogamy</er>.]</ety> <def>One who marries the second
time.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deuterogamy</ent><br/
<hw>Deu`ter*og"a*my</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>deu`teros</grk> second + <grk>ga`mos</grk> wedding,
marriage.]</ety> <def>A second marriage, after the death of the first
husband of wife; -- in distinction from bigamy, as defined in the old
canon law. See <er>Bigamy</er>.</def> <rj><au>Goldsmith.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deuterogenic</ent><br/
<hw>Deu`ter*o*gen"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>deu`teros</grk> second + root of <grk>gi`gnesqai</grk> to be
born.]</ety> <fld>(Geol.)</fld> <def>Of secondary origin; -- said of
certain rocks whose material has been derived from older
rocks.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deuteronomist</ent><br/
<hw>Deu`ter*on"o*mist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The writer
of Deuteronomy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deuteronomy</ent><br/
<hw>Deu`ter*on"o*my</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>deu`teros</grk> second + <grk>no`mos</grk> law: cf. L.
<ets>Deuteronomium</ets>.]</ety> <fld>(Bibl.)</fld> <def>The fifth book
of the Pentateuch, containing the second giving of the law by
Moses.</def></p>

<p><ent>Deuteropathy</ent><br/
<ent>Deuteropathia</ent><br/
<mhw>{ \'d8<hw>Deu`ter*o*pa*thi"a</hw> <pr>(?)</pr>,
<hw>Deu`ter*op"a*thy</hw> <pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[NL.
<ets>deuteropathia</ets>, fr. Gr. <grk>deu`teros</grk> second +
<grk>pa`qh</grk> suffering, fr. <grk>pa`schw</grk>,
<grk>pa`schein</grk>, to suffer: cf. F.
<ets>deut<eacute/ropathie</ets>.]</ety> <fld>(Med.)</fld> <def>A
sympathetic affection of any part of the body, as headache from an
overloaded stomach.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deuteropathic</ent><br/
<hw>Deu`ter*o*path"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining
to deuteropathy; of the nature of deuteropathy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deuteroscopy</ent><br/
<hw>Deu`ter*os"co*py</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>deu`teros</grk> second + <ets>-scopy</ets>.]</ety> <sn>1.</sn>
<def>Second sight.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I felt by anticipation the horrors of the Highland seers, whom
their gift of <qex>deuteroscopy</qex> compels to witness things unmeet
for mortal eye.</q> <rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is seen at a second view; a meaning
beyond the literal sense; the second intention; a hidden
signification.</def> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deuterozooid</ent><br/
<hw>Deu`ter*o*zo"oid</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>deu`teros</grk> second + E. <ets>zooid</ets>.]</ety>
<fld>(Zool.)</fld> <def>One of the secondary, and usually sexual, zooids
produced by budding or fission from the primary zooids, in animals
having alternate generations. In the tapeworms, the joints are
deuterozooids.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deuthydroguret</ent><br/
<hw>Deut`hy*drog"u*ret</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Chem.)</fld> <def>Same as <er>Deutohydroguret</er>.</def></p>

<p><ent>Deut-</ent><br/
<ent>Deuto-</ent><br/
<mhw><hw>Deu"to-</hw> <pr>(?)</pr> <it>or</it> <hw>Deut-</hw>
<pr>(d<umac/t-)</pr></mhw> <ety>[Contr. from Gr. <grk>dey`teros</grk>
second.]</ety> <fld>(Chem.)</fld> <def>A prefix which formerly properly
indicated <xex>the second</xex> in a regular series of compound in the
series, and not to its composition, but which is now generally employed
in the same sense as <altname>bi-</altname> or <altname>di-</altname>,
although little used.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deutohydroguret</ent><br/
<hw>Deu`to*hy*drog"u*ret</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>deut-</ets>, <ets>deuto-</ets> + <ets>hydroguret</ets>.]</ety>
<fld>(Chem.)</fld> <def>A compound containing in the molecule two atoms
of hydrogen united with some other element or radical.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deutoplasm</ent><br/
<hw>Deu"to*plasm</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>deuto-</ets> + Gr. <grk>pla`sma</grk> form.]</ety>
<fld>(Biol.)</fld> <def>The lifeless food matter in the cytoplasm of an
ovum or a cell, as distinguished from the active or true protoplasm;
yolk substance; yolk.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deutoplastic</ent><br/
<hw>Deu`to*plas"tic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>deuto-</ets> + Gr. <grk>plastiko`s</grk> plastic.]</ety>
<fld>(Biol.)</fld> <def>Pertaining to, or composed of,
deutoplasm.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deutosulphuret</ent><br/
<hw>Deu`to*sul"phu*ret</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>deuto-</ets> + <ets>sulphuret</ets>.]</ety> <fld>(Chem.)</fld>
<def>A disulphide.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deutoxide</ent><br/
<hw>Deu*tox"ide</hw> <pr>(?; 104)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>deut-</ets> + <ets>oxide</ets>.]</ety> <fld>(Chem.)</fld> <def>A
compound containing in the molecule two atoms of oxygen united with some
other element or radical; -- usually called <altname>dioxide</altname>,
or less frequently, <altname>binoxide</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deutzia</ent><br/
\'d8<hw>Deut"zi*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. Named after
<person>Jan <etsep>Deutz</etsep></person> of Holland.]</ety>
<fld>(Bot.)</fld> <def>A genus of shrubs with pretty white flowers, much
cultivated.</def></p>

<p><ent>Deva</ent><br/
<ent>Dev</ent><br/
<mhw>\'d8<hw>Dev</hw> <pr>(?)</pr>, <it>or</it> \'d8<hw>De"va</hw>
(<?/)</mhw>, <pos>n.</pos> <ety>[Skr. <ets>d<?/va</ets>. Cf.
<er>Deity</er>.]</ety> <fld>(Hind. Myth.)</fld> <def>A god; a deity; a
divine being; an idol; a king.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devanagari</ent><br/
\'d8<hw>De`va*na"ga*ri</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Skr.
<ets>d<emac/van<amac/gar<imac/</ets>; <ets>d<emac/va</ets> god +
<ets>nagara</ets> city, <it>i. e.</it>, divine city.]</ety> <def>The
script or characters in which Sanskrit and Hindi are written.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Devaporation</ent><br/
<hw>De*vap`o*ra"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The change of
vapor into water, as in the formation of rain.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devast</ent><br/
<hw>De*vast"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Cf. F.
<ets>d<eacute/vaster</ets>. See <er>Devastate</er>.]</ety> <def>To
devastate.</def> <mark>[Obs.]</mark> <rj><au>Bolingbroke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devastate</ent><br/
<hw>Dev"as*tate</hw> <pr>(?; 277)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Devastated</conjf>; <pos>p. pr.
& vb. n.</pos> <conjf>Devastating</conjf>.]</vmorph> <ety>[L.
<ets>devastatus</ets>, p. p. of <ets>devastare</ets> to devastate;
<ets>de</ets> + <ets>vastare</ets> to lay waste, <ets>vastus</ets>
waste. See <er>Vast</er>.]</ety> <def>To lay waste; to ravage; to
desolate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Whole countries . . . were <qex>devastated</qex>.</q>
<rj><qau>Macaulay.</qau></rj></p>

<p><syn><b>Syn.</b> -- To waste; ravage; desolate; destroy; demolish;
plunder; pillage.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>devastated</ent><br/
<hw>devastated</hw> <pos>adj.</pos> <def>same as
<er>desolated</er>.</def><br/
<syn><b>Syn. --</b> blasted, desolate, desolated, ravaged, ruined,
wasted.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>devastating</ent><br/
<hw>devastating</hw> <pos>adj.</pos> <sn>1.</sn> <def>highly critical;
making light of; <as>as, a <ex>devastating</ex> portrait of human
folly</as>.</def><br/
<syn><b>Syn. --</b> annihilating, withering.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>causing or capable of causing complete destruction;
<as>as, a <ex>devastating</ex> hurricane</as>.</def><br/
<syn><b>Syn. --</b> annihilative.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Devastation</ent><br/
<hw>Dev`as*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>d<eacute/vastation</ets>.]</ety> <sn>1.</sn> <def>The act of
devastating, or the state of being devastated; a laying waste.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Even now the <qex>devastation</qex> is begun,<br/
And half the business of destruction done.</q>
<rj><qau>Goldsmith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>Waste of the goods of the deceased
by an executor or administrator.</def> <rj><au>Blackstone.</au></rj></p>

<p><syn><b>Syn.</b> -- Desolation; ravage; waste; havoc; destruction;
ruin; overthrow.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devastator</ent><br/
<hw>Dev"as*ta`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.]</ety>
<def>One who, or that which, devastates.</def>
<rj><au>Emerson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devastavit</ent><br/
\'d8<hw>Dev`as*ta"vit</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., he has
wasted.]</ety> <fld>(Law)</fld> <def>Waste or misapplication of the
assets of a deceased person by an executor or an administrator.</def>
<rj><au>Bouvier.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devata</ent><br/
\'d8<hw>De"va*ta</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Hind., fr. Skr.
<ets>d<?/va</ets> god.]</ety> <fld>(Hind. Myth.)</fld> <def>A deity; a
divine being; a good spirit; an idol.</def> <altsp>[Written also
<asp>dewata</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deve</ent><br/
<hw>Deve</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Deaf</er>.]</ety> <def>Deaf.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Develin</ent><br/
<hw>Dev"el*in</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>The European swift.</def> <mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Develop</ent><br/
<hw>De*vel"op</hw> <pr>(d<esl/*v<ecr/l"<ocr/p)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Developed</conjf> <pr>(?)</pr>;
<pos>p. pr. & vb. n.</pos> <conjf>Developing</conjf>.]</vmorph> <ety>[F.
<ets>d<eacute/veloper</ets>; <ets>d<eacute/-</ets> (L. <ets>dis-</ets>)
+ OF. <ets>voluper</ets>, <ets>voleper</ets>, to envelop, perh. from L.
<ets>volup</ets> agreeably, delightfully, and hence orig., to make
agreeable or comfortable by enveloping, to keep snug (cf.
<er>Voluptuous</er>); or. perh. fr. a derivative of <ets>volvere</ets>,
<ets>volutum</ets>, to roll (cf. <er>Devolve</er>). Cf.
<er>Envelop</er>.]</ety> <altsp>[Written also
<asp>develope</asp>.]</altsp> <sn>1.</sn> <def>To free from that which
infolds or envelops; to unfold; to lay open by degrees or in detail; to
make visible or known; to disclose; to produce or give forth; <as>as, to
<ex>develop</ex> theories; a motor that <ex>develops</ex> 100 horse
power.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>These serve to <qex>develop</qex> its tenets.</q>
<rj><qau>Milner.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The 20th was spent in strengthening our position and
<qex>developing</qex> the line of the enemy.</q> <rj><qau>The
Century.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To unfold gradually, as a flower from a bud; hence,
to bring through a succession of states or stages, each of which is
preparatory to the next; to form or expand by a process of growth; to
cause to change gradually from an embryo, or a lower state, to a higher
state or form of being; <as>as, sunshine and rain <ex>develop</ex> the
bud into a flower; to <ex>develop</ex> the mind.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>The sound <qex>developed</qex> itself into a real compound.</q>
<rj><qau>J. Peile.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>All insects . . . acquire the jointed legs before the wings are
fully <qex>developed</qex>.</q> <rj><qau>Owen.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To advance; to further; to prefect; to make to
increase; to promote the growth of.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We must <qex>develop</qex> our own resources to the utmost.</q>
<rj><qau>Jowett (Thucyd).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Math.)</fld> <def>To change the form of, as of an
algebraic expression, by executing certain indicated operations without
changing the value.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Photog.)</fld> <def>To cause to become visible, as
an invisible or latent image upon plate, by submitting it to chemical
agents; to bring to view.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To develop a curved surface on a plane</b></col>
<fld>(Geom.)</fld>, <cd>to produce on the plane an equivalent surface,
as if by rolling the curved surface so that all parts shall successively
touch the plane.</cd></cs></p>

<p><syn><b>Syn.</b> -- To uncover; unfold; evolve; promote; project; lay
open; disclose; exhibit; unravel; disentangle.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Develop</ent><br/
<hw>De*vel"op</hw> <pr>(?)</pr>, <pos>v. i.</pos> <sn>1.</sn> <def>To go
through a process of natural evolution or growth, by successive changes
from a less perfect to a more perfect or more highly organized state; to
advance from a simpler form of existence to one more complex either in
structure or function; <as>as, a blossom <ex>develops</ex> from a bud;
the seed <ex>develops</ex> into a plant; the embryo <ex>develops</ex>
into a well-formed animal; the mind <ex>develops</ex> year by
year.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Nor poets enough to understand<br/
That life <qex>develops</qex> from within.</q> <rj><qau>Mrs.
Browning.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To become apparent gradually; <as>as, a picture on
sensitive paper <ex>develops</ex> on the application of heat; the plans
of the conspirators <ex>develop</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Developable</ent><br/
<hw>De*vel"op*a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of
being developed.</def> <rj><au>J. Peile.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Developable surface</b></col> <fld>(Math.)</fld>, <cd>a
surface described by a moving right line, and such that consecutive
positions of the generator intersect each other. Hence, the surface can
be developed into a plane.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>developed</ent><br/
<hw>developed</hw> <pos>adj.</pos> <sn>1.</sn> <def>being changed over
time so as to be e.g. stronger or more complete or more useful; <as>as,
the <ex>developed</ex> qualities of the Hellenic outlook; the state's
well-<ex>developed</ex> industries</as>. Opposite of
<ant>undeveloped</ant>.</def> [Narrower terms:
<stype>formulated</stype>; <stype>mature</stype>]<br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>made more useful and profitable as by building or
laying out roads; -- of real estate.</def> <illu>new houses are
springing up on the <ex>developed</ex> tract of land near the
river</illu><br/
<syn><b>Syn. --</b> improved.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>developing</ent><br/
<hw>developing</hw> <pos>adj.</pos> <sn>1.</sn> <def>not industrialized
but undergoing industrialization; -- sometimes used as a euphemism for
"undeveloped"; -- of nations.</def><br/
<syn><b>Syn. --</b> underdeveloped.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <ety>[<pos>pr. p.</pos> of <er>develop</er> (WN
definition 5)]</ety> <def>becoming or arising; <as>as, the rushing
yellow of the <ex>developing</ex> day</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>developing</ent><br/
<hw>developing</hw> <pos>n.</pos> <def>the process of treating a
photosensitive material with chemicals in order to make a latent image
visible.</def><br/
<syn><b>Syn. --</b> development.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Developer</ent><br/
<hw>De*vel"op*er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One
who, or that which, develops.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Photog.)</fld> <def>A chemical bath or reagent used
in developing photographs.</def> <note>By the action of the developer,
the latent image on a photographic plate or film, not perceptible to the
eye after exposure in the camera, is developed and becomes
visible.</note><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>3.</sn> <fld>(Dyeing)</fld> <def>A reagent used to produce an
ingrain color by its action upon some substance on the fiber.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>4.</sn> <def>a corporation or individual who finances or
organizes a real estate development{5}.</def><br/
[<source>PJC</source>]</p>

<p><ent>Development</ent><br/
<hw>De*vel"op*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>d<eacute/veloppement</ets>.]</ety> <altsp>[Written also
<asp>developement</asp>.]</altsp> <sn>1.</sn> <def>The act of developing
or disclosing that which is unknown; a gradual unfolding process by
which anything is developed, as a plan or method, or an image upon a
photographic plate; gradual advancement or growth through a series of
progressive changes; also, the result of developing, or a developed
state.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A new <qex>development</qex> of imagination, taste, and
poetry.</q> <rj><qau>Channing.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Biol.)</fld> <def>The series of changes which
animal and vegetable organisms undergo in their passage from the
embryonic state to maturity, from a lower to a higher state of
organization.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Math.)</fld> <sd>(a)</sd> <def>The act or process
of changing or expanding an expression into another of equivalent value
or meaning.</def> <sd>(b)</sd> <def>The equivalent expression into which
another has been developed.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Mus.)</fld> <def>The elaboration of a theme or
subject; the unfolding of a musical idea; the evolution of a whole piece
or movement from a leading theme or motive.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A tract of land on which a number of buildings have
been constructed; -- especially used for tract on which from two to
hundreds of houses have been constructed by a commercial developer{4}
for sale to individuals.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Development theory</b></col> <fld>(Biol.)</fld>, <cd>the
doctrine that animals and plants possess the power of passing by slow
and successive stages from a lower to a higher state of organization,
and that all the higher forms of life now in existence were thus
developed by uniform laws from lower forms, and are not the result of
special creative acts. See the Note under
<er>Darwinian</er>.</cd></cs></p>

<p><syn><b>Syn.</b> -- Unfolding; disclosure; unraveling; evolution;
elaboration; growth.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Developmental</ent><br/
<hw>De*vel`op*men"tal</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining
to, or characteristic of, the process of development; <as>as, the
<ex>developmental</ex> power of a germ</as>.</def>
<rj><au>Carpenter.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devenustate</ent><br/
<hw>Dev`e*nus"tate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>devenustatus</ets>, p. p. of <ets>devenustare</ets> to disfigure;
<ets>de</ets> + <ets>venustus</ets> lovely, graceful.]</ety> <def>To
deprive of beauty or grace.</def> <mark>[Obs.]</mark></p>

<p><ent>Devergency</ent><br/
<ent>Devergence</ent><br/
<mhw>{ <hw>De*ver"gence</hw> <pr>(?)</pr>, <hw>De*ver"gen*cy</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <def>See <er>Divergence</er>.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devest</ent><br/
<hw>De*vest"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Devested</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Devesting</conjf>.]</vmorph> <ety>[L. <ets>devestire</ets> to
undress; <ets>de</ets> + <ets>vestire</ets> to dress: cf. OF.
<ets>devestir</ets>, F. <ets>d<eacute/v<ecir/tir</ets>. Cf.
<er>Divest</er>.]</ety> <sn>1.</sn> <def>To divest; to undress.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To take away, as an authority, title, etc., to
deprive; to alienate, as an estate.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ This word is now generally written <xex>divest</xex>,
except in the legal sense.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devest</ent><br/
<hw>De*vest"</hw>, <pos>v. i.</pos> <fld>(Law)</fld> <def>To be taken
away, lost, or alienated, as a title or an estate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devex</ent><br/
<hw>De*vex"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>devexus</ets>, from <ets>devehere</ets> to carry down.]</ety>
<def>Bending down; sloping.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devex</ent><br/
<hw>De*vex"</hw>, <pos>n.</pos> <def>Devexity.</def> <mark>[Obs.]</mark>
<rj><au>May (Lucan).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devexity</ent><br/
<hw>De*vex"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>devexitas</ets>, fr. <ets>devexus</ets>. See <er>Devex</er>,
<pos>a.</pos>]</ety> <def>A bending downward; a sloping; incurvation
downward; declivity.</def> <mark>[R.]</mark> <rj><au>Davies (Wit's
Pilgr.)</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devi</ent><br/
\'d8<hw>De"vi</hw> <pr>(?)</pr>, <pos>n.</pos><def>; <xex>fem</xex>. of
<er>Deva</er>. A goddess.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>deviance</ent><br/
<hw>deviance</hw> <pos>n.</pos> <sn>1.</sn> <def>an aberrant state or
condition.</def><br/
<syn><b>Syn. --</b> aberrance, aberrancy, aberration.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>deviate behavior.</def><br/
<syn><b>Syn. --</b> deviation.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Deviant</ent><br/
<hw>De"vi*ant</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Deviating.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>having behavior or characteristics differing from
that which is normal or expected, especially in an undesirable or
socially disapproved manner; <as>as, <ex>deviant</ex>
behavior</as>.</def><br/
<syn><b>Syn. --</b> deviate.</syn>
[<source>PJC</source>]</p>

<p><ent>Deviate</ent><br/
<hw>De"vi*ate</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Deviated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Deviating</conjf> <pr>(?)</pr>.]</vmorph> <ety>[L.
<ets>deviare</ets> to deviate; <ets>de</ets> + <ets>viare</ets> to go,
travel, <ets>via</ets> way. See <er>Viaduct</er>.]</ety> <def>To go out
of the way; to turn aside from a course or a method; to stray or go
astray; to err; to digress; to diverge; to vary.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thus Pegasus, a nearer way to take,<br/
May boldly <qex>deviate</qex> from the common track.</q>
<rj><qau>Pope.</qau></rj></p>

<p><syn><b>Syn.</b> -- To swerve; stray; wander; digress; depart;
deflect; err.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deviate</ent><br/
<hw>De"vi*ate</hw>, <pos>v. t.</pos> <def>To cause to deviate.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>deviate</qex> a needle.</q> <rj><qau>J. D.
Forbes.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>deviate</ent><br/
<hw>de"vi*ate</hw> <pr>(d<emac/"v<esl/*<icr/t)</pr>, <pos>a.</pos>
<def>having behavior differing from that which is normal or expected,
especially in an undesirable or socially disapproved manner; <as>as,
<ex>deviate</ex> behavior</as>.</def><br/
<syn><b>Syn. --</b> deviant.</syn>
[<source>PJC</source>]</p>

<p><ent>deviate</ent><br/
<hw>de"vi*ate</hw> <pr>(d<emac/"v<esl/*<icr/t)</pr>, <pos>n.</pos>
<def>a person having behavior differing from that which is normal or
socially acceptable; -- used especially to characterize persons whose
sexual behavior is considered morally unacceptable.</def><br/
<syn><b>Syn. --</b> deviant.</syn>
[<source>PJC</source>]</p>

<p><ent>deviation</ent><br/
<hw>de`vi*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL.
<ets>deviatio</ets>: cf. F. <ets>d<eacute/viation</ets>.]</ety>
<sn>1.</sn> <def>The act of deviating; a wandering from the way;
variation from the common way, from an established rule, etc.;
departure, as from the right course or the path of duty.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The state or result of having deviated; a
transgression; an act of sin; an error; an offense.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 403 --></p>

<p><sn>3.</sn> <fld>(Com.)</fld> <def>The voluntary and unnecessary
departure of a ship from, or delay in, the regular and usual course of
the specific voyage insured, thus releasing the underwriters from their
responsibility.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Statistics, Physics)</fld> <def>the difference
between an expected value of an observation or measurement and the
actual value.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Deviation of a falling body</b></col>
<fld>(Physics)</fld>, <cd>that deviation from a strictly vertical line
of descent which occurs in a body falling freely, in consequence of the
rotation of the earth.</cd> -- <col><b>Deviation of the
compass</b></col>, <cd>the angle which the needle of a ship's compass
makes with the magnetic meridian by reason of the magnetism of the iron
parts of the ship.</cd> -- <col><b>Deviation of the line of the
vertical</b></col>, <cd>the difference between the actual direction of a
plumb line and the direction it would have if the earth were a perfect
ellipsoid and homogeneous, -- caused by the attraction of a mountain, or
irregularities in the earth's density.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deviator</ent><br/
<hw>De"vi*a`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., a
forsaker.]</ety> <def>One who, or that which, deviates.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deviatory</ent><br/
<hw>De"vi*a*to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Tending to
deviate; devious; <as>as, <ex>deviatory</ex> motion</as>.</def>
<mark>[R.]</mark> <rj><au>Tully.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Device</ent><br/
<hw>De*vice"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>devis</ets>, <ets>devise</ets>, will, intention, opinion,
invention, fr. F. <ets>devis</ets> architect's plan and estimates (in
OF., division, plan, wish), <ets>devise</ets> device (in sense 3), in
OF. also, division, wish, last will, fr. <ets>deviser</ets>. See
<er>Devise</er>, <pos>v. t.</pos>, and cf. <er>Devise</er>,
<pos>n.</pos>]</ety> <sn>1.</sn> <def>That which is devised, or formed
by design; a contrivance; an invention; a project; a scheme; often, a
scheme to deceive; a stratagem; an artifice.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His <qex>device</qex> in against Babylon, to destroy it.</q>
<rj><qau>Jer. li. 11.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Their recent <qex>device</qex> of demanding benevolences.</q>
<rj><qau>Hallam.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He disappointeth the <qex>devices</qex> of the crafty.</q>
<rj><qau>Job v. 12.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Power of devising; invention; contrivance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I must have instruments of my own <qex>device</qex>.</q>
<rj><qau>Landor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <sd>(a)</sd> <def>An emblematic design, generally
consisting of one or more figures with a motto, used apart from heraldic
bearings to denote the historical situation, the ambition, or the desire
of the person adopting it. See <er>Cognizance</er>.</def> <sd>(b)</sd>
<def>Improperly, an heraldic bearing.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Knights-errant used to distinguish themselves by
<qex>devices</qex> on their shields.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A banner with this strange <qex>device</qex> -<br/
Excelsior.</q> <rj><qau>Longfellow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Anything fancifully conceived.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A spectacle or show.</def> <mark>[Obs.]</mark>
<rj><au>Beau. & Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Opinion; decision.</def> <mark>[Obs.]</mark>
<rj><au>Rom. of R.</au></rj></p>

<p><sn>7.</sn> <def>any artifactual object designed to perform an action
or process, with or without an operator in attendance.</def><br/
[<source>PJC</source>]</p>

<p><syn><b>Syn.</b> -- Contrivance; invention; design; scheme; project;
stratagem; shift.</syn> <usage>-- <er>Device</er>, <er>Contrivance</er>.
<xex>Device</xex> implies more of inventive power, and
<xex>contrivance</xex> more of skill and dexterity in execution. A
<xex>device</xex> usually has reference to something worked out for
exhibition or show; a <xex>contrivance</xex> usually respects the
arrangement or disposition of things with reference to securing some
end. <xex>Devices</xex> were worn by knights-errant on their shields;
<xex>contrivances</xex> are generally used to promote the practical
convenience of life. The word <xex>device</xex> is often used in a bad
sense; <as>as, a crafty <ex>device</ex></as>; <xex>contrivance</xex> is
almost always used in a good sense; <as>as, a useful
<ex>contrivance</ex></as>.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deviceful</ent><br/
<hw>De*vice"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Full of devices;
inventive.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>A carpet, rich, and of <qex>deviceful</qex> thread.</q>
<rj><qau>Chapman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devicefully</ent><br/
<hw>De*vice"ful*ly</hw>, <pos>adv.</pos> <def>In a deviceful
manner.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devil</ent><br/
<hw>Dev"il</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS.
<ets>de<oacute/fol</ets>, <ets>de<oacute/ful</ets>; akin to G.
<ets>teufel</ets>, Goth. <ets>diaba<uacute/lus</ets>; all fr. L.
<ets>diabolus</ets> the devil, Gr. <grk>dia`bolos</grk> the devil, the
slanderer, fr. <grk>diaba`llw</grk> to slander, calumniate, orig., to
throw across; <grk>dia`</grk> across + <grk>ba`llw</grk> to throw, let
fall, fall; cf. Skr. <ets>gal</ets> to fall. Cf.
<er>Diabolic</er>.]</ety> <sn>1.</sn> <def>The Evil One; Satan,
represented as the tempter and spiritual of mankind.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>[Jesus] being forty days tempted of the <qex>devil</qex>.</q>
<rj><qau>Luke iv. 2.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>That old serpent, called the <qex>Devil</qex>, and Satan, which
deceiveth the whole world.</q> <rj><qau>Rev. xii. 9.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An evil spirit; a demon.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A dumb man possessed with a <qex>devil</qex>.</q> <rj><qau>Matt.
ix. 32.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A very wicked person; hence, any great evil.</def>
<ldquo/That <xex>devil</xex> Glendower.<rdquo/ <ldquo/The
<xex>devil</xex> drunkenness.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Have not I chosen you twelve, and one of you is a
<qex>devil</qex>?</q> <rj><qau>John vi. 70.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>An expletive of surprise, vexation, or emphasis, or,
ironically, of negation.</def> <mark>[Low]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>devil</qex> a puritan that he is, . . . but a
timepleaser.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The things, we know, are neither rich nor rare,<br/
But wonder how the <qex>devil</qex> they got there.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Cookery)</fld> <def>A dish, as a bone with the
meat, broiled and excessively peppered; a grill with Cayenne
pepper.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Men and women busy in baking, broiling, roasting oysters, and
preparing <qex>devils</qex> on the gridiron.</q> <rj><qau>Sir W.
Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Manuf.)</fld> <def>A machine for tearing or cutting
rags, cotton, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Blue devils</b></col>. <cd>See under <er>Blue</er>.</cd>
-- <col><b>Cartesian devil</b></col>. <cd>See under
<er>Cartesian</er>.</cd> -- <col><b>Devil bird</b></col>
<fld>(Zool.)</fld>, <cd>one of two or more South African drongo shrikes
(<spn>Edolius retifer</spn>, and <spn>Edolius remifer</spn>), believed
by the natives to be connected with sorcery.</cd> -- <col><b>Devil may
care</b></col>, <cd>reckless, defiant of authority; -- used
adjectively.</cd> <au>Longfellow.</au> -- <col><b>Devil's
apron</b></col> <fld>(Bot.)</fld>, <cd>the large kelp (<spn>Laminaria
saccharina</spn>, and <spn>Laminaria longicruris</spn>) of the Atlantic
ocean, having a blackish, leathery expansion, shaped somewhat like an
apron.</cd> -- <col><b>Devil's coachhorse</b></col>. <fld>(Zool.)</fld>
<sd>(a)</sd> <cd>The black rove beetle (<spn>Ocypus olens</spn>).</cd>
<mark>[Eng.]</mark> <sd>(b)</sd> <cd>A large, predacious, hemipterous
insect (<spn>Prionotus cristatus</spn>); the wheel bug.</cd>
<mark>[U.S.]</mark> -- <col><b>Devil's darning-needle</b></col>.
<fld>(Zool.)</fld> <cd>See under <er>Darn</er>, <pos>v. t.</pos></cd> --
<mcol><col><b>Devil's fingers</b></col>, <col><b>Devil's
hand</b></col></mcol> <fld>(Zool.)</fld>, <cd>the common British
starfish (<spn>Asterias rubens</spn>); -- also applied to a sponge with
stout branches.</cd> <mark>[Prov. Eng., Irish & Scot.]</mark> --
<col><b>Devil's riding-horse</b></col> <fld>(Zool.)</fld>, <cd>the
American mantis (<spn>Mantis Carolina</spn>).</cd> -- <col><b>The
Devil's tattoo</b></col>, <cd>a drumming with the fingers or feet.</cd>
<ldquo/Jack played <xex>the Devil's tattoo</xex> on the door with his
boot heels.<rdquo/ <au>F. Hardman (Blackw. Mag.).</au> -- <col><b>Devil
worship</b></col>, <cd>worship of the power of evil; -- still practiced
by barbarians who believe that the good and evil forces of nature are of
equal power.</cd> -- <col><b>Printer's devil</b></col>, <cd>the youngest
apprentice in a printing office, who runs on errands, does dirty work
(as washing the ink rollers and sweeping), etc.</cd> <ldquo/Without
fearing the <xex>printer's devil</xex> or the sheriff's officer.<rdquo/
<au>Macaulay.</au> -- <col><b>Tasmanian devil</b></col>
<fld>(Zool.)</fld>, <cd>a very savage carnivorous marsupial of Tasmania
(<spn>Dasyurus ursinus</spn> syn. <spn>Diabolus ursinus</spn>).</cd> --
<col><b>To play devil with</b></col>, <cd>to molest extremely; to
ruin.</cd> <mark>[Low]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>devil</ent><br/
<hw>dev"il</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Deviled</conjf> <pr>(?)</pr> or <conjf>Devilled</conjf>;
<pos>p. pr. & vb. n.</pos> <conjf>Deviling</conjf> <pr>(?)</pr> or
<conjf>Devilling</conjf>.]</vmorph> <sn>1.</sn> <def>To make like a
devil; to invest with the character of a devil.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To grill with Cayenne pepper; to season highly in
cooking, as with pepper.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>deviled</qex> leg of turkey.</q> <rj><qau>W.
Irving.</qau></rj></p>

<p><ent>Devil bird</ent><br/
<ent>Devil-diver</ent><br/
<mhw><hw>Dev"il-div`er</hw> <pr>(?)</pr>, <hw>Dev"il bird`</hw>
<pr>(<?/)</pr></mhw>, <pos>n.</pos>. <fld>(Zool.)</fld> <def>A small
water bird. See <er>Dabchick</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>deviled egg</ent><br/
<hw>deviled egg</hw> <def>a hard-boiled egg, sliced into halves and with
the yolk removed and replaced with a paste, usually made from the yolk
and mayonnaise, seasoned with salt and/or spices such as
paprika.</def><br/
[<source>PJC</source>]</p>

<p><ent>Deviless</ent><br/
<hw>Dev"il*ess</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A she-devil.</def>
<mark>[R.]</mark> <rj><au>Sterne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devilet</ent><br/
<hw>Dev"il*et</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A little
devil.</def> <mark>[R.]</mark> <rj><au>Barham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devilfish</ent><br/
<hw>Dev"il*fish`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<sd>(a)</sd> <def>A huge ray (<spn>Manta birostris</spn> <it>or</it>
<spn>Cephaloptera vampyrus</spn>) of the Gulf of Mexico and Southern
Atlantic coasts. Several other related species take the same name. See
<er>Cephaloptera</er>.</def> <sd>(b)</sd> <def>A large cephalopod,
especially the very large species of <gen>Octopus</gen> and
<gen>Architeuthis</gen>. See <er>Octopus</er>.</def> <sd>(c)</sd>
<def>The gray whale of the Pacific coast. See <er>Gray whale</er>.</def>
<sd>(d)</sd> <def>The goosefish or angler (<gen>Lophius</gen>), and
other allied fishes. See <er>Angler</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deviling</ent><br/
<hw>Dev"il*ing</hw>, <pos>n.</pos> <def>A young devil.</def>
<mark>[Obs.]</mark> <rj><au>Beau. & Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devilish</ent><br/
<hw>Dev"il*ish</hw>, <pos>a.</pos> <sn>1.</sn> <def>Resembling,
characteristic of, or pertaining to, the devil; diabolical; wicked in
the extreme.</def> <ldquo/<xex>Devilish</xex> wickedness.<rdquo/
<rj><au>Sir P. Sidney.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>This wisdom descendeth not from above, but is earthly, sensual,
<qex>devilish</qex>.</q> <rj><qau>James iii. 15.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Extreme; excessive.</def> <mark>[Colloq.]</mark>
<rj><au>Dryden.</au></rj></p>

<p><syn><b>Syn.</b> -- Diabolical; infernal; hellish; satanic; wicked;
malicious; detestable; destructive.</syn></p>

<p>-- <wordforms><wf>Dev"il*ish*ly</wf>, <pos>adv.</pos> --
<wf>Dev"il*ish*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devilism</ent><br/
<hw>Dev"il*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state of the
devil or of devils; doctrine of the devil or of devils.</def>
<rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devilize</ent><br/
<hw>Dev"il*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To make a devil
of.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He that should deify a saint, should wrong him as much as he that
should <qex>devilize</qex> him.</q> <rj><qau>Bp. Hall.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devilkin</ent><br/
<hw>Dev"il*kin</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A little devil; a
devilet.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>devil-may-care</ent><br/
<hw>devil-may-care</hw> <pos>adj.</pos> <sn>1.</sn> <def>cheerfully
irresponsible.</def><br/
<syn><b>Syn. --</b> carefree, happy-go-lucky, harum-scarum,
slaphappy.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>marked by a carefree unconventionality or
disreputableness.</def><br/
<syn><b>Syn. --</b> raffish, rakish.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Devilment</ent><br/
<hw>Dev"il*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Deviltry.</def>
<rj><au>Bp. Warburton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devilry</ent><br/
<hw>Dev"il*ry</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Devilries</plw> <pr>(<?/)</pr>.</plu> <sn>1.</sn> <def>Conduct
suitable to the devil; extreme wickedness; deviltry.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Stark lies and <qex>devilry</qex>.</q> <rj><qau>Sir T.
More.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The whole body of evil spirits.</def>
<rj><au>Tylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devil's darning-needle</ent><br/
<hw>Dev"il's darn"ing-nee`dle</hw>. <fld>(Zool.)</fld> <def>A dragon
fly. See <cref>Darning needle</cref>, under <er>Darn</er>, <pos>v.
t.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devilship</ent><br/
<hw>Dev"il*ship</hw>, <pos>n.</pos> <def>The character or person of a
devil or the devil.</def> <rj><au>Cowley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deviltry</ent><br/
<hw>Dev"il*try</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Deviltries</plw> <pr>(<?/)</pr>.</plu> <def>Diabolical conduct;
malignant mischief; devilry.</def> <rj><au>C. Reade.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devilwood</ent><br/
<hw>Dev"il*wood`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>A kind of tree (<spn>Osmanthus Americanus</spn>), allied to the
European olive.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devious</ent><br/
<hw>De"vi*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>devius</ets>; <ets>de</ets> + <ets>via</ets> way. See
<er>Viaduct</er>.]</ety> <sn>1.</sn> <def>Out of a straight line;
winding; varying from directness; <as>as, a <ex>devious</ex> path or
way</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Going out of the right or common course; going
astray; erring; wandering; <as>as, a <ex>devious</ex>
step</as>.</def></p>

<p><syn><b>Syn.</b> -- Wandering; roving; rambling; vagrant.</syn></p>

<p>-- <wordforms><wf>De"vi*ous*ly</wf>, <pos>adv.</pos> --
<wf>De"vi*ous*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devirginate</ent><br/
<hw>De*vir"gin*ate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>devirginatus</ets>, p. p. of <ets>devirginare</ets>.]</ety>
<def>Deprived of virginity.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devirginate</ent><br/
<hw>De*vir"gin*ate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To deprive
of virginity; to deflower.</def> <mark>[R.]</mark>
<rj><au>Sandys.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devirgination</ent><br/
<hw>De*vir`gi*na"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>devirginatio</ets>.]</ety> <def>A deflowering.</def>
<mark>[R.]</mark> <rj><au>Feltham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devisable</ent><br/
<hw>De*vis"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From
<er>Devise</er>.]</ety> <sn>1.</sn> <def>Capable of being devised,
invented, or contrived.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Capable of being bequeathed, or given by
will.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devisal</ent><br/
<hw>De*vis"al</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A devising.</def>
<rj><au>Whitney.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devise</ent><br/
<hw>De*vise"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Devised</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Devising</conjf>.]</vmorph> <ety>[OF. <ets>deviser</ets> to
distribute, regulate, direct, relate, F., to chat, fr. L.
<ets>divisus</ets> divided, distributed, p. p. of <ets>dividere</ets>.
See <er>Divide</er>, and cf. <er>Device</er>.]</ety> <sn>1.</sn> <def>To
form in the mind by new combinations of ideas, new applications of
principles, or new arrangement of parts; to formulate by thought; to
contrive; to excogitate; to invent; to plan; to scheme; <as>as, to
<ex>devise</ex> an engine, a new mode of writing, a plan of defense, or
an argument</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>devise</qex> curious works.</q> <rj><qau>Ex. CCTV.
32.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Devising</qex> schemes to realize his ambitious views.</q>
<rj><qau>Bancroft.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To plan or scheme for; to purpose to
obtain.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>For wisdom is most riches; fools therefore<br/
They are which fortunes do by vows <qex>devise</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To say; to relate; to describe.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To imagine; to guess.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Law)</fld> <def>To give by will; -- used of real
estate; formerly, also, of chattels.</def></p>

<p><syn><b>Syn.</b> -- To bequeath; invent; discover; contrive;
excogitate; imagine; plan; scheme. See <er>Bequeath</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devise</ent><br/
<hw>De*vise"</hw>, <pos>v. i.</pos> <def>To form a scheme; to lay a
plan; to contrive; to consider.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I thought, <qex>devised</qex>, and Pallas heard my prayer.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Devise</xex> was formerly followed by
<xex>of</xex>; as, let us <xex>devise of</xex> ease.</note>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devise</ent><br/
<hw>De*vise"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>devise</ets> division, deliberation, wish, will, testament. See
<er>Device</er>.]</ety> <sn>1.</sn> <def>The act of giving or disposing
of real estate by will; -- sometimes improperly applied to a bequest of
personal estate.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A will or testament, conveying real estate; the
clause of a will making a gift of real property.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Fines upon <qex>devises</qex> were still exacted.</q>
<rj><qau>Bancroft.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Property devised, or given by will.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devise</ent><br/
<hw>De*vise"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Device. See
<er>Device</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devisee</ent><br/
<hw>Dev`i*see"</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Law)</fld>
<def>One to whom a devise is made, or real estate given by
will.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deviser</ent><br/
<hw>De*vis"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
devises.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devisor</ent><br/
<hw>De*vis"or</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Law)</fld> <def>One
who devises, or gives real estate by will; a testator; -- correlative to
<xex>devisee</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devitable</ent><br/
<hw>Dev"i*ta*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>devitare</ets> to avoid; <ets>de</ets> + <ets>vitare</ets> to shun,
avoid.]</ety> <def>Avoidable.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devitalize</ent><br/
<hw>De*vi"tal*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To deprive of
life or vitality.</def> -- <wordforms><wf>De*vi`tal*i*za"tion</wf>
<pr>(#)</pr>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devitation</ent><br/
<hw>Dev`i*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>devitatio</ets>.]</ety> <def>An avoiding or escaping; also, a
warning.</def> <mark>[Obs.]</mark> <rj><au>Bailey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devitrification</ent><br/
<hw>De*vit`ri*fi*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act
or process of devitrifying, or the state of being devitrified.
Specifically, the conversion of molten glassy matter into a stony mass
by slow cooling, the result being the formation of crystallites,
microbites, etc., in the glassy base, which are then called
<xex>devitrification products</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devitrify</ent><br/
<hw>De*vit"ri*fy</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To deprive of
glasslike character; to take away vitreous luster and transparency
from.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devocalize</ent><br/
<hw>De*vo"cal*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To make
toneless; to deprive of vowel quality.</def> --
<wordforms><wf>De*vo`cal*i*za"tion</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><q>If we take a high vowel, such as (i) [= nearly i of bit], and
<qex>devocalize</qex> it, we obtain a hiss which is quite distinct
enough to stand for a weak (jh).</q> <rj><qau>H. Sweet.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devocation</ent><br/
<hw>Dev`o*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>devocare</ets> to call off or away; <ets>de</ets> +
<ets>vocare</ets> to call.]</ety> <def>A calling off or away.</def>
<mark>[R.]</mark> <rj><au>Hallywell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devoid</ent><br/
<hw>De*void"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[OE.
<ets>devoiden</ets> to leave, OF. <ets>desvuidier</ets>,
<ets>desvoidier</ets>, to empty out. See <er>Void</er>.]</ety> <def>To
empty out; to remove.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devoid</ent><br/
<hw>De*void"</hw>, <pos>a.</pos> <ety>[See <er>Devoid</er>, <pos>v.
t.</pos>]</ety> <sn>1.</sn> <def>Void; empty; vacant.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Destitute; not in possession; -- with <xex>of</xex>;
<as>as, <ex>devoid</ex> of sense; <ex>devoid</ex> of pity or of
pride.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devoir</ent><br/
\'d8<hw>De*voir"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr. L.
<ets>debere</ets> to owe. See <er>Due</er>.]</ety> <def>Duty; service
owed; hence, due act of civility or respect; -- now usually in the
plural; <as>as, they paid their <ex>devoirs</ex> to the
ladies</as>.</def> <ldquo/Do now your <xex>devoid</xex>, young
knights!<rdquo/ <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devolute</ent><br/
<hw>Dev"o*lute</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>devolutus</ets>, p. p. of <ets>devolvere</ets>. See
<er>Devolve</er>.]</ety> <def>To devolve.</def> <mark>[Obs.]</mark>
<rj><au>Foxe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devolution</ent><br/
<hw>Dev`o*lu"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL.
<ets>devolutio</ets>: cf. F. <ets>d<eacute/volution</ets>.]</ety>
<sn>1.</sn> <def>The act of rolling down.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>devolution</qex> of earth down upon the valleys.</q>
<rj><qau>Woodward.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Transference from one person to another; a passing
or devolving upon a successor.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>devolution</qex> of the crown through a . . . channel
known and conformable to old constitutional requisitions.</q>
<rj><qau>De Quincey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devolve</ent><br/
<hw>De*volve"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Devolved</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Devolving</conjf>.]</vmorph> <ety>[L.
<ets>devolvere</ets>, <ets>devolutum</ets>, to roll down; <ets>de</ets>
+ <ets>volvere</ets> to roll down; <ets>de</ets> + <ets>volvere</ets> to
roll. See <er>Voluble</er>.]</ety> <sn>1.</sn> <def>To roll onward or
downward; to pass on.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Every headlong stream<br/
<qex>Devolves</qex> its winding waters to the main.</q>
<rj><qau>Akenside.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Devolved</qex> his rounded periods.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To transfer from one person to another; to deliver
over; to hand down; -- generally with <xex>upon</xex>, sometimes with
<xex>to</xex> or <xex>into</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They <qex>devolved</qex> a considerable share of their power upon
their favorite.</q> <rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>They <qex>devolved</qex> their whole authority into the hands of
the council of sixty.</q> <rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devolve</ent><br/
<hw>De*volve"</hw>, <pos>v. i.</pos> <def>To pass by transmission or
succession; to be handed over or down; -- generally with <xex>on</xex>
or <xex>upon</xex>, sometimes with <xex>to</xex> or <xex>into</xex>;
<as>as, after the general fell, the command <ex>devolved</ex> upon (or
on) the next officer in rank</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His estate . . . <qex>devolved</qex> to Lord Somerville.</q>
<rj><qau>Johnson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devolvement</ent><br/
<hw>De*volve"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act or
process of devolving;; devolution.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devon</ent><br/
<hw>De"von</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One of a breed of hardy
cattle originating in the country of Devon, England. Those of pure blood
have a deep red color. The small, longhorned variety, called <xex>North
Devons</xex>, is distinguished by the superiority of its working
oxen.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devonian</ent><br/
<hw>De*vo"ni*an</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Geol.)</fld>
<def>Of or pertaining to Devon or Devonshire in England; <as>as, the
<ex>Devonian</ex> rocks, period, or system</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Devonian age</b></col> <fld>(Geol.)</fld>, <cd>the age
next older than the Carboniferous and later than the Silurian; -- called
also the <altname>Age of fishes</altname>. The various strata of this
age compose the <xex>Devonian formation</xex> or <xex>system</xex>, and
include the old red sandstone of Great Britain. They contain, besides
plants and numerous invertebrates, the bony portions of many large and
remarkable fishes of extinct groups. See the Diagram under
<er>Geology</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devonian</ent><br/
<hw>De*vo"ni*an</hw>, <pos>n.</pos> <def>The Devonian age or
formation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devoration</ent><br/
<hw>Dev`o*ra"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>devoratio</ets>. See <er>Devour</er>.]</ety> <def>The act of
devouring.</def> <mark>[Obs.]</mark> <rj><au>Holinshed.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devotary</ent><br/
<hw>De*vo"ta*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Devote</er>, <er>Votary</er>.]</ety> <def>A votary.</def>
<mark>[Obs.]</mark> <rj><au>J. Gregory.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devote</ent><br/
<hw>De*vote"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Devoted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Devoting</conjf>.]</vmorph> <ety>[L. <ets>devotus</ets>, p. p. of
<ets>devovere</ets>; <ets>de</ets> + <ets>vovere</ets> to vow. See
<er>Vow</er>, and cf. <er>Devout</er>, <er>Devow</er>.]</ety>
<sn>1.</sn> <def>To appropriate by vow; to set apart or dedicate by a
solemn act; to consecrate; also, to consign over; to doom; to evil; to
<xex>devote</xex> one to destruction; the city was <xex>devoted</xex> to
the flames.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>No <qex>devoted</qex> thing that a man shall <qex>devote</qex>
unto the Lord . . . shall be sold or redeemed.</q> <rj><qau>Lev. xxvii.
28.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To execrate; to curse.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To give up wholly; to addict; to direct the
attention of wholly or compound; to attach; -- often with a reflexive
pronoun; <as>as, to <ex>devote</ex> one's self to science, to one's
friends, to piety, etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 404 --></p>

<p><q>Thy servant who is <qex>devoted</qex> to thy fear.</q>
<rj><qau>Ps. cxix. 38.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>They <qex>devoted</qex> themselves unto all wickedness.</q>
<rj><qau>Grew.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A leafless and simple branch . . . <qex>devoted</qex> to the
purpose of climbing.</q> <rj><qau>Gray.</qau></rj></p>

<p><syn><b>Syn.</b> -- To addict; apply; dedicate; consecrate; resign;
destine; doom; consign. See <er>Addict</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devote</ent><br/
<hw>De*vote"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>devotus</ets>, p. p.]</ety> <def>Devoted; addicted; devout.</def>
<mark>[Obs.]</mark> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devote</ent><br/
<hw>De*vote"</hw>, <pos>n.</pos> <def>A devotee.</def>
<mark>[Obs.]</mark> <rj><au>Sir E. Sandys.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devoted</ent><br/
<hw>De*vot"ed</hw>, <pos>a.</pos> <def>Consecrated to a purpose;
strongly attached; zealous; devout; <as>as, a <ex>devoted</ex>
admirer</as>.</def> -- <wordforms><wf>De*vot"ed*ly</wf>, <pos>adv.</pos>
-- <wf>De*vot"ed*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devotee</ent><br/
<hw>Dev`o*tee"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who is wholly
devoted; esp., one given wholly to religion; one who is superstitiously
given to religious duties and ceremonies; a bigot.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>While Father Le Blanc was very devout he was not a
<qex>devotee</qex>.</q> <rj><qau>A. S. Hardy.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devotement</ent><br/
<hw>De*vote"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state of
being devoted, or set apart by a vow.</def> <mark>[R.]</mark>
<rj><au>Bp. Hurd.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devoter</ent><br/
<hw>De*vot"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who devotes; a
worshiper.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devotion</ent><br/
<hw>De*vo"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>d<eacute/votion</ets>, L. <ets>devotio</ets>.]</ety> <sn>1.</sn>
<def>The act of devoting; consecration.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The state of being devoted; addiction; eager
inclination; strong attachment love or affection; zeal; especially,
feelings toward God appropriately expressed by acts of worship;
devoutness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Genius animated by a fervent spirit of <qex>devotion</qex>.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Act of devotedness or devoutness; manifestation of
strong attachment; act of worship; prayer.</def> <ldquo/The love of
public <xex>devotion</xex>.<rdquo/ <rj><au>Hooker.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Disposal; power of disposal.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>They are entirely at our <qex>devotion</qex>, and may be turned
backward and forward, as we please.</q> <rj><qau>Godwin.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A thing consecrated; an object of devotion.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Churches and altars, priests and all <qex>devotions</qex>,<br/
Tumbled together into rude chaos.</q> <rj><qau>Beau. &
Fl.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Days of devotion</b></col>. <cd>See under
<er>Day</er>.</cd></cs></p>

<p><syn><b>Syn.</b> -- Consecration; devoutness; religiousness; piety;
attachment; devotedness; ardor; earnestness.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devotional</ent><br/
<hw>De*vo"tion*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>devotionalis</ets>.]</ety> <def>Pertaining to, suited to, or used
in, devotion; <as>as, a <ex>devotional</ex> posture; <ex>devotional</ex>
exercises; a <ex>devotional</ex> frame of mind.</as></def></p>

<p><ent>Devotionist</ent><br/
<ent>Devotionalist</ent><br/
<mhw>{ <hw>De*vo"tion*al*ist</hw>, <hw>De*vo"tion*ist</hw>, }</mhw>
<pos>n.</pos> <def>One given to devotion, esp. to excessive formal
devotion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devotionality</ent><br/
<hw>De*vo`tion*al"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The
practice of a devotionalist.</def> <rj><au>A. H. Clough.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devotionally</ent><br/
<hw>De*vo"tion*al*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a
devotional manner; toward devotion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devoto</ent><br/
\'d8<hw>De*vo"to</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[It.]</ety>
<def>A devotee.</def> <rj><au>Dr. J. Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devotor</ent><br/
<hw>De*vo"tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.]</ety> <def>A
worshiper; one given to devotion.</def> <mark>[Obs.]</mark>
<rj><au>Beau. & Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devour</ent><br/
<hw>De*vour"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Devoured</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Devouring</conjf>.]</vmorph> <ety>[F.
<ets>d<eacute/vorer</ets>, fr. L. <ets>devorare</ets>; <ets>de</ets> +
<ets>vorare</ets> to eat greedily, swallow up. See
<er>Voracious</er>.]</ety> <sn>1.</sn> <def>To eat up with greediness;
to consume ravenously; to feast upon like a wild beast or a glutton; to
prey upon.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Some evil beast hath <qex>devoured</qex> him.</q> <rj><qau>Gen.
xxxvii. 20.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To seize upon and destroy or appropriate greedily,
selfishly, or wantonly; to consume; to swallow up; to use up; to waste;
to annihilate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Famine and pestilence shall <qex>devour</qex> him.</q>
<rj><qau>Ezek. vii. 15.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I waste my life and do my days <qex>devour</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To enjoy with avidity; to appropriate or take in
eagerly by the senses.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Longing they look, and gaping at the sight,<br/
<qex>Devour</qex> her o'er with vast delight.</q>
<rj><qau>Dryden.</qau></rj></p>

<p><syn><b>Syn.</b> -- To consume; waste; destroy; annihilate.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devourable</ent><br/
<hw>De*vour"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>That may be
devoured.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devourer</ent><br/
<hw>De*vour"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, devours.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devouringly</ent><br/
<hw>De*vour"ing*ly</hw>, <pos>adv.</pos> <def>In a devouring
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devout</ent><br/
<hw>De*vout"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OE.
<ets>devot</ets>, <ets>devout</ets>, F. <ets>d<eacute/vot</ets>, from L.
<ets>devotus</ets> devoted, p. p. of <ets>devovere</ets>. See
<er>Devote</er>, <pos>v. t.</pos>]</ety> <sn>1.</sn> <def>Devoted to
religion or to religious feelings and duties; absorbed in religious
exercises; given to devotion; pious; reverent; religious.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>devout</qex> man, and one that feared God.</q>
<rj><qau>Acts x. 2.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>We must be constant and <qex>devout</qex> in the worship of
God.</q> <rj><qau>Rogers.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Expressing devotion or piety; <as>as, eyes
<ex>devout</ex>; sighs <ex>devout</ex>; a <ex>devout</ex>
posture.</as></def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Warmly devoted; hearty; sincere; earnest; <as>as,
<ex>devout</ex> wishes for one's welfare</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>The devout</b></col>, <cd>devoutly religious persons,
those who are sincerely pious.</cd></cs></p>

<p><syn><b>Syn.</b> -- Holy; pure; religious; prayerful; pious; earnest;
reverent; solemn; sincere.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devout</ent><br/
<hw>De*vout"</hw>, <pos>n.</pos> <sn>1.</sn> <def>A devotee.</def>
<mark>[Obs.]</mark> <rj><au>Sheldon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A devotional composition, or part of a composition;
devotion.</def> <mark>[Obs.]</mark> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devoutful</ent><br/
<hw>De*vout"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Full
of devotion.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Sacred.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>To take her from austerer check of parents,<br/
To make her his by most <qex>devoutful</qex> rights.</q>
<rj><qau>Marston.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devoutless</ent><br/
<hw>De*vout"less</hw>, <pos>a.</pos> <def>Destitute of devotion.</def>
-- <wordforms><wf>De*vout"less*ly</wf>, <pos>adv.</pos> --
<wf>De*vout"less*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devoutly</ent><br/
<hw>De*vout"ly</hw>, <pos>adv.</pos> <sn>1.</sn> <def>In a devout and
reverent manner; with devout emotions; piously.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Cast her fair eyes to heaven and prayed <qex>devoutly</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Sincerely; solemnly; earnestly.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>'T is a consummation<br/
<qex>Devoutly</qex> to be wished.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devoutness</ent><br/
<hw>De*vout"ness</hw>, <pos>n.</pos> <def>Quality or state of being
devout.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devove</ent><br/
<hw>De*vove"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[See
<er>Devote</er>, <pos>v. t.</pos>]</ety> <def>To devote.</def>
<mark>[Obs.]</mark> <rj><au>Cowley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devow</ent><br/
<hw>De*vow"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[F.
<ets>d<eacute/vouer</ets>, L. <ets>devovere</ets>. See <er>Devote</er>,
<pos>v. t.</pos>]</ety> <sn>1.</sn> <def>To give up; to devote.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <ety>[Cf. OF. <ets>desvoer</ets>. Cf.
<er>Disavow</er>.]</ety> <def>To disavow; to disclaim.</def>
<mark>[Obs.]</mark> <rj><au>G. Fletcher.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Devulgarize</ent><br/
<hw>De*vul"gar*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To free from
what is vulgar, common, or narrow.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Shakespeare and Plutarch's <ldquo/Lives<rdquo/ are very
<qex>devulgarizing</qex> books.</q> <rj><qau>E. A.
Abbott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dew</ent><br/
<hw>Dew</hw> <pr>(d<umac/)</pr>, <pos>n.</pos> <ety>[AS.
<ets>de<aacute/w</ets>; akin to D. <ets>dauw</ets>, G. <ets>thau</ets>,
<ets>tau</ets>, Icel. <ets>d<oum/gg</ets>, Sw. <ets>dagg</ets>, Dan.
<ets>dug</ets>; cf. Skr. <ets>dhav</ets>, <ets>dh<amac/v</ets>, to flow.
<root/72. Cf. <er>Dag</er> dew.]</ety> <sn>1.</sn> <def>Moisture from
the atmosphere condensed by cool bodies upon their surfaces,
particularly at night.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Her tears fell with the <qex>dews</qex> at even.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Figuratively, anything which falls lightly and in a
refreshing manner.</def> <ldquo/The golden <xex>dew</xex> of
sleep.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>An emblem of morning, or fresh vigor.</def>
<ldquo/The <xex>dew</xex> of his youth.<rdquo/
<rj><au>Longfellow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Dew</xex> is used in combination; as,
<xex>dew</xex>-bespangled, <xex>dew</xex>-drenched, <xex>dew</xex>drop,
etc.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dew</ent><br/
<hw>Dew</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Dewed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Dewing</conjf>.]</vmorph> <def>To wet with dew or as with dew; to
bedew; to moisten; as with dew.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The grasses grew<br/
A little ranker since they <qex>dewed</qex> them so.</q> <rj><qau>A. B.
Saxton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dew</ent><br/
<hw>Dew</hw>, <pos>a. & n.</pos> <def>Same as <er>Due</er>, or
<er>Duty</er>.</def> <mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dewar flask</ent><br/
<ent>Dewar vessel</ent><br/
<ent>Dewar</ent><br/
<mhw><hw>Dew"ar</hw> <pr>(d<umac/"<etil/r)</pr>, <hw>Dew"ar
ves`sel</hw>, <hw>Dew"ar flask</hw></mhw>. <ety>[After Sir James
<etsep>Dewar</etsep>, British physicist.]</ety> <def>A double-walled
glass vessel for holding liquid air, liquid nitrogen, etc., having the
space between the walls exhausted so as to prevent conduction of heat,
and sometimes having the glass silvered to prevent absorption of radiant
heat; -- called also, according to the particular shape, <col><b>Dewar
bulb</b></col>, <col><b>Dewar tube</b></col>, etc.</def><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><ent>Dewberry</ent><br/
<hw>Dew"ber`ry</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<sd>(a)</sd> <def>The fruit of certain species of bramble
(<gen>Rubus</gen>); in England, the fruit of <spn>Rubus c<ae/sius</spn>,
which has a glaucous bloom; in America, that of <spn>Rubus
canadensis</spn> and <spn>Rubus hispidus</spn>, species of low
blackberries.</def> <sd>(b)</sd> <def>The plant which bears the
fruit.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Feed him with apricots and <qex>dewberries</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dewclaw</ent><br/
<hw>Dew"claw`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>In any animal, esp.
of the Herbivora, a rudimentary claw or small hoof not reaching the
ground.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Some cut off the <qex>dewclaws</qex> [of greyhounds].</q>
<rj><qau>J. H. Walsh.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dewdrop</ent><br/
<hw>Dew"drop`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A drop of dew.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deweyan</ent><br/
<hw>Deweyan</hw> <pos>prop. adj.</pos> <def>of or pertaining to
<etsep>Dewey</etsep>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>dewfall</ent><br/
<hw>dew"fall`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The falling of dew;
the time when dew begins to fall.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>dewiness</ent><br/
<hw>dew"i*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>State of being
dewy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dewlap</ent><br/
<hw>Dew"lap`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Dew</ets> +
<ets>lap</ets> to lick.]</ety> <sn>1.</sn> <def>The pendulous skin under
the neck of an ox, which laps or licks the dew in grazing.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The flesh upon the human throat, especially when
with age.</def> <mark>[Burlesque]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>On her withered <qex>dewlap</qex> pour the ale.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dewlapped</ent><br/
<hw>Dew"lapped`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Furnished with a
dewlap.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dewless</ent><br/
<hw>Dew"less</hw>, <pos>a.</pos> <def>Having no dew.</def>
<rj><au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dew-point</ent><br/
<hw>Dew"-point`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Meteor.)</fld>
<def>The temperature at which dew begins to form. It varies with the
humidity and temperature of the atmosphere.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dewret</ent><br/
<hw>Dew"ret`</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[<ets>Dew</ets> +
<ets>ret</ets>, v. t.]</ety> <def>To ret or rot by the process called
<xex>dewretting</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dewretting</ent><br/
<hw>Dew"ret`ting</hw>, <pos>n.</pos> <def>Dewrotting; the process of
decomposing the gummy matter of flax and hemp and setting the fibrous
part, by exposure on a sward to dew, rain, and sunshine.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dewrot</ent><br/
<hw>Dew"rot`</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To rot, as flax or
hemp, by exposure to rain, dew, and sun. See
<er>Dewretting</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dewworm</ent><br/
<hw>Dew"worm`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>See <er>Earthworm</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dewy</ent><br/
<hw>Dew"y</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Pertaining
to dew; resembling, consisting of, or moist with, dew.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>dewy</qex> mist<br/
Went and watered all the ground.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>When <qex>dewy</qex> eve her curtain draws.</q>
<rj><qau>Keble.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Falling gently and beneficently, like the
dew.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Dewy</qex> sleep ambrosial.</q>
<rj><qau>Cowper.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Bot.)</fld> <def>Resembling a dew-covered surface;
appearing as if covered with dew.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>dexamethasone</ent><br/
<hw>dexamethasone</hw> <pos>n.</pos> <def>a corticosteroid drug used to
treat allergies or inflammation.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dexedrine</ent><br/
<hw>Dexedrine</hw> <pos>n.</pos> <def>an isomer of amphetamine used as a
central nervous system stimulant (Dexedrine is a trademark).</def><br/
<syn><b>Syn. --</b> dextroamphetamine sulphate.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dexter</ent><br/
<hw>Dex"ter</hw> <pr>(d<ecr/ks"t<etil/r)</pr>, <pos>a.</pos> <ety>[L.,;
akin to Gr. <grk>dexitero`s</grk>, <grk>dexio`s</grk>, Skr.
<ets>dakshi<nsdot/a</ets> (cf. <ets>daksh</ets> to be strong, suit);
Goth. <ets>taihswa</ets>, OHG. <ets>zeso</ets>. Cf.
<er>Dexterous</er>.]</ety> <sn>1.</sn> <def>Pertaining to, or situated
on, the right hand; right, as opposed to <ant>sinister</ant>, or
<ant>left</ant>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>On sounding wings a <qex>dexter</qex> eagle flew.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Her.)</fld> <def>On the right-hand side of a
shield, <it>i. e.</it>, towards the right hand of its wearer. To a
spectator in front, as in a pictorial representation, this would be the
left side.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Dexter chief</b></col>, <it>or</it> <col><b>Dexter
point</b></col></mcol> <fld>(Her.)</fld>, <cd>a point in the dexter
upper corner of the shield, being in the dexter extremity of the chief,
as A in the cut.</cd> -- <col><b>Dexter base</b></col>, <cd>a point in
the dexter lower part or base of the shield, as B in the
cut.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dexter</ent><br/
<hw>Dex"ter</hw>, <pos>n.</pos> <ety>[Prob. so named after the original
breeder.]</ety> <def>One of a breed of small hardy cattle originating
from the Kerry breed of Ireland, valuable both for beef and milk. They
are usually chiefly black, sometimes red, and somewhat resemble a small
shorthorn in build. Called also <altname><ecol><b>Dexter
Kerry</b></ecol></altname>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Dexterical</ent><br/
<hw>Dex*ter"i*cal</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Dexterous.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dexterity</ent><br/
<hw>Dex*ter"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>dexteritas</ets>, fr. <ets>dexter</ets>: cf. F.
<ets>dext<eacute/rit<eacute/</ets>. See <er>Dexter</er>.]</ety>
<sn>1.</sn> <def>Right-handedness.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Readiness and grace in physical activity; skill and
ease in using the hands; expertness in manual acts; <as>as,
<ex>dexterity</ex> with the chisel</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In youth quick bearing and <qex>dexterity</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Readiness in the use or control of the mental
powers; quickness and skill in managing any complicated or difficult
affair; adroitness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His wisdom . . . was turned . . . into a <qex>dexterity</qex> to
deliver himself.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He had conducted his own defense with singular boldness and
<qex>dexterity</qex>.</q> <rj><qau>Hallam.</qau></rj></p>

<p><syn><b>Syn.</b> -- Adroitness; activity; nimbleness; expertness;
skill; cleverness; art; ability; address; tact; facility; aptness;
aptitude; faculty. See <er>Skill</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dexterous</ent><br/
<hw>Dex"ter*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>dexter</ets>. See <er>Dexter</er>.]</ety> <altsp>[Written also
<asp>dextrous</asp>.]</altsp> <sn>1.</sn> <def>Ready and expert in the
use of the body and limbs; skillful and active with the hands; handy;
ready; <as>as, a <ex>dexterous</ex> hand; a <ex>dexterous</ex>
workman.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Skillful in contrivance; quick at inventing
expedients; expert; <as>as, a <ex>dexterous</ex> manager</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Dexterous</qex> the craving, fawning crowd to quit.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Done with dexterity; skillful; artful; <as>as,
<ex>dexterous</ex> management</as>.</def> <ldquo/<xex>Dexterous</xex>
sleights of hand.<rdquo/ <rj><au>Trench.</au></rj></p>

<p><syn><b>Syn.</b> -- Adroit; active; expert; skillful; clever; able;
ready; apt; handy; versed.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dexterously</ent><br/
<hw>Dex"ter*ous*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a
dexterous manner; skillfully.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dexterousness</ent><br/
<hw>Dex"ter*ous*ness</hw>, <pos>n.</pos> <def>The quality of being
dexterous; dexterity.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dextrad</ent><br/
<hw>Dex"trad</hw> <pr>(?)</pr>, <pos>adv.</pos> <ety>[L.
<ets>dextra</ets> the right hand + <ets>ad</ets> to.]</ety>
<fld>(Anat.)</fld> <def>Toward the right side; dextrally.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dextral</ent><br/
<hw>Dex"tral</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From
<er>Dexter</er>.]</ety> <def>Right, as opposed to <xex>sinistral</xex>,
or <xex>left</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dextral shell</b></col> <fld>(Zool.)</fld>, <cd>a spiral
shell the whorls of which turn from left right, or like the hands of a
watch when the apex of the spire is toward the eye of the
observer.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dextrality</ent><br/
<hw>Dex*tral"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state of
being on the right-hand side; also, the quality of being right-handed;
right-handedness.</def> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dextrally</ent><br/
<hw>Dex"tral*ly</hw> <pr>(<?/)</pr>, <pos>adv.</pos> <def>Towards the
right; <as>as, the hands of a watch rotate
<ex>dextrally</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dextrer</ent><br/
<hw>Dex*trer"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A war horse; a
destrer.</def> <mark>[Obs.]</mark> <ldquo/By him baiteth his
<xex>dextrer</xex>.<rdquo/ <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dextrin</ent><br/
<hw>Dex"trin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>dextrine</ets>, G. <ets>dextrin</ets>. See <er>Dexter</er>.]</ety>
<fld>(Chem.)</fld> <def>A translucent, gummy, amorphous substance,
nearly tasteless and odorless, used as a substitute for gum, for sizing,
etc., and obtained from starch by the action of heat, acids, or
diastase. It is of somewhat variable composition, containing several
carbohydrates which change easily to their respective varieties of
sugar. It is so named from its rotating the plane of polarization to the
right; -- called also <altname>British gum</altname>, <altname>Alsace
gum</altname>, <altname>gommelin</altname>, <altname>leiocome</altname>,
etc. See <er>Achroodextrin</er>, and <er>Erythrodextrin</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dextro-</ent><br/
<hw>Dex"tro-</hw> <pr>(?)</pr>. <def>A prefix, from L.
<ets>dexter</ets>, meaning, pertaining to, or toward, the
<sig>right</sig></def>; <fld>(Chem. & Opt.)</fld> <def>having the
property of turning the plane of polarized light to the
<sig>right</sig>; <as>as, <ex>dextro</ex>tartaric acid</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dextrogerous</ent><br/
<hw>Dex*trog"er*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Physics &
Chem.)</fld> <def>See <er>Dextrogyrate</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dextroglucose</ent><br/
<hw>Dex`tro*glu"cose`</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Dextro-</ets> + <ets>glucose</ets>.]</ety> <fld>(Chem.)</fld>
<def>Same as <er>Dextrose</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dextrogyrate</ent><br/
<hw>Dex`tro*gy"rate</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Dextro-</ets> + <ets>gyrate</ets>.]</ety> <fld>(Chem. &
Opt.)</fld> <def>Same as <er>Dextrorotatory</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dextronic</ent><br/
<hw>Dex*tron"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Chem.)</fld>
<def>Pertaining to, or derived from, dextrose; <as>as,
<ex>dextronic</ex> acid</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dextronic acid</b></col>, <cd>a sirupy substance obtained
by the partial oxidation of various carbohydrates, as dextrose,
etc.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dextrorotary</ent><br/
<hw>Dex`tro*ro"ta*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Physics &
Chem.)</fld> <def>See <er>Dextrotatory</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dextrorotatory</ent><br/
<hw>Dex`tro*ro"ta*to*ry</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Dextro-</ets> + <ets>rotatory</ets>.]</ety> <fld>(Chem. &
Opt.)</fld> <def>Turning, or causing to turn, toward the right hand;
esp., turning the plane of polarization of luminous rays toward the
right hand; <as>as, <ex>dextrorotatory</ex> crystals, sugars, etc.</as>
Cf. <er>Levorotatory</er>.</def></p>

<p><ent>Dextrorse</ent><br/
<ent>Dextrorsal</ent><br/
<mhw>{ <hw>Dex*tror"sal</hw> <pr>(?)</pr>, <hw>Dex"trorse`</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[L. <ets>dextrorsum</ets>,
contr. fr. <ets>dextrovorsum</ets>, <ets>dextroversum</ets>, toward the
right side; <ets>dexter</ets> right + <ets>versus</ets>,
<ets>vorsus</ets>, p. p. of <ets>vertere</ets>, <ets>vortere</ets>, to
turn.]</ety> <fld>(Botany)</fld> <def>Turning from the left to the
right, in the ascending line, as in the spiral inclination of the stem
of the common morning-glory; <as>as, <ex>dextrorse</ex>
vines</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ At present scientists predicate dextrorse or sinistrorse
quality of the plant regarded objectively; formerly the plant was
regarded subjectively, and what is now called dextrorse was then
considered sinistrorse.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dextrose</ent><br/
<hw>Dex"trose`</hw> <pr>(d<ecr/ks"tr<omac/s`)</pr>, <pos>n.</pos>
<ety>[See <er>Dexter</er>.]</ety> <fld>(Chem.)</fld> <def>A sirupy, or
white crystalline, variety of sugar, <chform>C6H12O6</chform> (so called
from turning the plane of polarization to the right), occurring in many
ripe fruits, and also called <altname>glucose</altname>. Dextrose and
levulose are obtained by the inversion of cane sugar or sucrose, and
hence the mixture is called called <partof>invert sugar</partof>.
Dextrose is chiefly obtained by the action of heat and acids on starch,
and hence called also <altname>starch sugar</altname>. It is also formed
from starchy food by the action of the amylolytic ferments of saliva and
pancreatic juice.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The solid products are known to the trade as
<altname>grape sugar</altname>; the sirupy products as
<altname>glucose</altname>, or <altname>mixing sirup</altname>. These
are harmless, but are only about half as sweet as cane sugar or
sucrose.</note></p>

<p><ent>Dextrousness</ent><br/
<ent>Dextrously</ent><br/
<ent>Dextrous</ent><br/
<mhw><hw>Dex"trous</hw> <pr>(?)</pr>, <pos>a.</pos>,
<hw>Dex"trous*ly</hw>, <pos>adv.</pos>, <hw>Dex"trous*ness</hw>,
<pos>n.</pos></mhw> <def>Same as <er>Dexterous</er>,
<er>Dexterously</er>, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dey</ent><br/
<hw>Dey</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Dairy</er>.]</ety> <def>A servant who has charge of the dairy; a
dairymaid.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dey</ent><br/
<hw>Dey</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Deys</plw> <pr>(#)</pr>.</plu> <ety>[Turk. <ets>d<amac/i</ets>,
orig., a maternal uncle, then a friendly title formerly given to
middle-aged or old people, especially among the Janizaries; and hence,
in Algiers, consecrated at length to the commanding officer of that
corps, who frequently became afterward pasha or regent of that province;
hence the European misnomer of <ets>dey</ets>, as applied to the latter:
cf. F. <ets>dey</ets>.]</ety> <def>The governor of Algiers; -- so called
before the French conquest in 1830.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Deye</ent><br/
<hw>Deye</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To die.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj></p>

<p><ent>Deyntee</ent><br/
<ent>Deynte</ent><br/
<mhw>{ <hw>Deyn"te</hw>, <hw>Deyn"tee</hw> <pr>(?)</pr> }</mhw>, <pos>n.
& a.</pos> <def>See <er>Dainty</er>.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dezincification</ent><br/
<hw>De*zinc`i*fi*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act
or process of freeing from zinc; also, the condition resulting from the
removal of zinc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dezincify</ent><br/
<hw>De*zinc"i*fy</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>de-</ets> + <ets>zinc + -fy</ets>.]</ety> <def>To deprive of, or
free from, zinc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dhaka</ent><br/
<hw>Dhaka</hw> <pos>prop. n.</pos> <fld>(Geography)</fld> <def>The
capital <isa>city</isa> of <country>Bangladesh</country>. Population
(2000) = 3,839,000.</def><br/
[<source>PJC</source>]</p>

<p><ent>Dharma</ent><br/
<hw>Dharma</hw> <pos>prop. n.</pos> <fld>(Hinduism)</fld> <def>The basic
principles of the cosmos; also: an ancient sage in Hindu mythology
worshipped as a god by some lower castes;.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dhaulagiri</ent><br/
<hw>Dhaulagiri</hw> <pos>prop. n.</pos> <def>a mountain in Nepal, 26,810
feet high.</def> <mark>[proper name]</mark><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dhole</ent><br/
\'d8<hw>Dhole</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>A
fierce, wild dog (<spn>Canis Dukhunensis</spn>), found in the mountains
of India. It is remarkable for its propensity to hunt the tiger and
other wild animals in packs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dhony</ent><br/
\'d8<hw>Dho"ny</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A Ceylonese boat.
See <er>Doni</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 405 --></p>

<p><ent>Dhurra</ent><br/
<ent>Dhourra</ent><br/
<ent>Dhoorra</ent><br/
<mhw>\'d8<hw>Dhoor"ra</hw>, \'d8<hw>Dhour"ra</hw>, <it>or</it>
<hw>Dhur"ra</hw> <pr>(<?/)</pr></mhw>, <pos>n.</pos> <def>Indian millet.
See <er>Durra</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dhow</ent><br/
\'d8<hw>Dhow</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Ar.
<ets>d<amac/o</ets>?]</ety> <def>A coasting vessel of Arabia, East
Africa, and the Indian Ocean. It has generally but one mast and a lateen
sail.</def> <altsp>[Also written <asp>dow</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Di-</ent><br/
<hw>Di-</hw> <pr>(?)</pr>. <ety>[Gr. <grk>di`s-</grk> twice; akin to <?/
two, L. <ets>bis</ets> twice. See <er>Two</er>, and cf. <er>Bi-</er>,
<er>Dia-</er>. The L. pref. <ets>dis-</ets> sometimes assumes the form
<ets>di</ets>-. See <er>Dis-</er>.]</ety> <def>A prefix, signifying
<sig>twofold</sig>, <sig>double</sig>, <sig>twice</sig></def>;
<fld>(Chem.)</fld> <def>denoting <sig>two</sig> atoms, radicals, groups,
or equivalents, as the case may be. See <er>Bi-</er>, 2.</def></p>

<p><ent>Di-</ent><br/
<ent>Dia-</ent><br/
<mhw>{ <hw>Di"a-</hw> <pr>(?)</pr>, <hw>Di-</hw> }</mhw>. <ety>[Gr.
<grk>dia`</grk> through; orig., dividing into two parts; akin to <?/
two. See <er>Two</er>, and cf. 1st <er>Di-</er>.]</ety> <def>A prefix
denoting <sig>through</sig>; also, <sig>between</sig>, <sig>apart</sig>,
<sig>asunder</sig>, <sig>across</sig>. Before a vowel <ex>dia-</ex>
becomes <altname>di-</altname>; <as>as, <ex>di</ex>actinic;
<ex>di</ex>electric, etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diabase</ent><br/
<hw>Di"a*base</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>diabase</ets>, fr. Gr. <grk>dia`basis</grk> a crossing or passing
over, fr. <grk>dia`</grk> + <grk>bai`nw</grk> to go; -- so called by
<person>Brongniart</person>, because it passes over to diorite.]</ety>
<fld>(Min.)</fld> <def>A basic, dark-colored, holocrystalline, igneous
rock, consisting essentially of a triclinic feldspar and pyroxene with
magnetic iron; -- often limited to rocks pretertiary in age. It includes
part of what was early called <partof>greenstone</partof>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diabaterial</ent><br/
<hw>Di*ab`a*te"ri*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/ <?/
(sc. <?/) offerings before crossing the border, fr. <?/ to pass over.
See <er>Diabase</er>.]</ety> <def>Passing over the borders.</def>
<mark>[R.]</mark> <rj><au>Mitford.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>diabatic</ent><br/
<hw>diabatic</hw> <pos>adj.</pos> <fld>(Physics)</fld> <def>involving a
transfer of heat.</def> <illu>a <ex>diabatic</ex> process</illu>
<ant>adiabatic</ant><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>diabetes</ent><br/
<hw>di`a*be"tes</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., from Gr.
<grk>diabh`ths</grk>, fr. <grk>diabai`nw</grk> to pass or cross over.
See <er>Diabase</er>.]</ety> <fld>(Med.)</fld> <def>Any of several
diseases which is attended with a persistent, excessive discharge of
urine; when used without qualification, the term usually refers to
<cref>diabetes mellitus</cref>. The most common form is <stype>diabetes
mellitus</stype>, in which the urine is not only increased in quantity,
but contains saccharine matter, and the condition if untreated is
generally fatal.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The two major subtypes recognized are <col><b>diabetes
insipidus</b></col> and <col><b>diabetes mellitus</b></col>. In
<stype>diabetes insipidus</stype> there is excretion of large amounts of
urine of relatively low density, accompanied by extreme thirst, but the
urine contains no abnormal constituent. The more serious form
<stype>diabetes mellitus</stype> (from Latin <ets>mellitus</ets>,
sweetened with honey) is a metabolic disease in which the utilization of
carbohydrate is reduced and that of lipids and proteins is increased.
This form is caused by a deficiency in insulin (which is mostly formed
in the pancreas), and may be accompanied by glucosuria, hyperglycemia,
elecrolyte loss, ketoacidosis, and sometimes coma. It has severe
long-term effects, including damage to the nerves, the retina, and the
kidney, and degeneration of blood vessels which may lead to poor
circulation, especially in the limbs, subsequent infection, and eventual
loss of limbs.<br/
Diabetes mellitus itself has recognized variants, being divided into
<stype>insulin-dependent diabetes mellitus</stype> and
<stype>non-insulin-dependent diabetes mellitus</stype>.
Non-insulin-dependent diabetes mellitus is also called
<stype>adult-onset diabetes</stype> (abbreviated <abbr>NIDDM</abbr>),
and is the less severe form of diabetes mellitus, occurring mostly in
obese individuals over the age of 35. It may be treated by diet and oral
hypoglycemic agents, though occasionally serious degenerative effects
may develop. Insulin-dependent diabetes mellitus (abbreviated
<abbr>IDDM</abbr>), also called <stype>type I diabetes</stype>, is a
severe form of the disease, usually starting when the affected person is
young (hence also called <stype>juvenile-onset diabetes</stype>). In
addition to the increased urine (polyuria) common to all forms of
diabetes, this form is characterized by low levels of insulin in the
blood, ketoacidosis, increased appetite, and increased fluid intake, and
may lead to weight loss and eventually the severe degenerative effects
mentioned above. Treatment requires administration of insulin and
careful regulation of the diet.</note> <au>Stedman</au><br/
[<source>PJC</source>]</p>

<p><cs><col><b>\'d8Diabetes mellitus</b></col> <ety>[NL., sweet
diabetes]</ety>, <cd>that form of diabetes in which the urine contains
saccharine matter.</cd> -- <col><b>\'d8Diabetes insipidus</b></col>
<ety>[NL., lit., diabetes]</ety>, <cd>the form of diabetes in which the
urine contains no abnormal constituent.</cd></cs></p>

<p><ent>Diabetical</ent><br/
<ent>Diabetic</ent><br/
<mhw>{ <hw>Di`a*bet"ic</hw> <pr>(?)</pr>, <hw>Di`a*bet"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <def>Pertaining to diabetes; <as>as,
<ex>diabetic</ex> or <ex>diabetical</ex> treatment</as>.</def>
<rj><au>Quian.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Diabetic sugar</b></col>. <fld>(Chem.)</fld> <cd>Same as
<er>Dextrose</er>.</cd></cs></p>

<p><ent>Diabley</ent><br/
<ent>Diablerie</ent><br/
<mhw>{ \'d8<hw>Dia`ble*rie"</hw> <pr>(?)</pr>, <hw>Di*ab"le*y</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[F. <ets>diablerie</ets>, fr.
<ets>diable</ets> devil, L. <ets>diabolus</ets>. See
<er>Devil</er>.]</ety> <def>Devilry; sorcery or incantation; a
diabolical deed; mischief.</def></p>

<p><ent>Diabolical</ent><br/
<ent>Diabolic</ent><br/
<mhw>{ <hw>Di`a*bol"ic</hw> <pr>(?)</pr>, <hw>Di`a*bol"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[L. <ets>diabolicus</ets>, Gr.
<grk>diaboliko`s</grk> devilish, slanderous: cf. F.
<ets>diabolique</ets>. See <er>Devil</er>.]</ety> <sn>1.</sn>
<def>Pertaining to the devil; resembling, or appropriate, or appropriate
to, the devil; befitting hell or satan; devilish; infernal; impious;
<as>as, a <ex>diabolic</ex> or <ex>diabolical</ex> temper or act; the
<ex>diabolical</ex> expression on his face; fires lit up a
<ex>diabolic</ex> scene</as>.</def> <ldquo/<xex>Diabolic</xex>
power.<rdquo/ <au>Milton.</au> <ldquo/The <xex>diabolical</xex>
institution.<rdquo/ <au>Motley.</au><br/
<syn><b>Syn. --</b> devilish, mephistophelian,
mephistophelean.</syn><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>showing a wicked cunning or ingenuity; <as>as, the
cold calculation and <ex>diabolic</ex> art of some
statesmen</as>.</def><br/
<syn><b>Syn. --</b> devilish, mephistophelian,
mephistophelean.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>3.</sn> <def>extremely evil or cruel; atrocious; outrageously
wicked; <as>as, <ex>diabolical</ex> sorcerers under the influence of
devils; <ex>diabolical</ex> torturers taking pleasure in their
craft</as>.</def><br/
<syn><b>Syn. --</b> demonic, fiendish, hellish, infernal, nefarious,
satanic.</syn><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p> -- <wordforms><wf>Di`a*bol"ic*al*ly</wf>, <pos>adv.</pos> --
<wf>Di`a*bol"ic*al*ness</wf>, <pos>n.</pos></wordforms></p>

<p><ent>Diabolify</ent><br/
<hw>Di`a*bol"i*fy</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>diabolus</ets> devil + <ets>-fy</ets>.]</ety> <def>To ascribed
diabolical qualities to; to change into, or to represent as, a
devil.</def> <mark>[R.]</mark> <rj><au>Farindon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diabolism</ent><br/
<hw>Di*ab"o*lism</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>Character, action, or principles appropriate to the
devil.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Possession by the devil.</def> <rj><au>Bp.
Warburton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diabolize</ent><br/
<hw>Di*ab"o*lize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To render
diabolical.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diabolo</ent><br/
<hw>Di*ab"o*lo</hw> <pr>(d<icr/*<acr/b"<osl/*l<omac/)</pr>,
<pos>n.</pos> <def>An old game or sport (revived under this name)
consisting in whirling on a string, fastened to two sticks, a small
somewhat spool-shaped object (called the <xex>diabolo</xex>) so as to
balance it on a string, toss it in the air and catch it, etc.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Diacatholicon</ent><br/
<hw>Di`a*ca*thol"i*con</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>dia-</ets> + <ets>catholicon</ets>.]</ety> <fld>(Med.)</fld> <def>A
universal remedy; -- a name formerly given to a purgative
electuary.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diacaustic</ent><br/
<hw>Di`a*caus"tic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>dia-</ets> + <ets>caustic</ets>.]</ety> <fld>(Opt.)</fld>
<def>Pertaining to, or possessing the properties of, a species of
caustic curves formed by refraction. See <cref>Caustic surface</cref>,
under <er>Caustic</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diacaustic</ent><br/
<hw>Di`a*caus"tic</hw>, <pos>n.</pos> <sn>1.</sn> <fld>(Med.)</fld>
<def>That which burns by refraction, as a double convex lens, or the
sun's rays concentrated by such a lens, sometimes used as a
cautery.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Math.)</fld> <def>A curved formed by the
consecutive intersections of rays of light refracted through a
lens.</def></p>

<p><ent>Diachylum</ent><br/
<ent>Diachylon</ent><br/
<mhw>{ \'d8<hw>Di*ach"y*lon</hw> <pr>(?)</pr>, \'d8<hw>Di*ach"y*lum</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[NL. <ets>diachylum</ets>, fr.
Gr. <grk>dia`chulos</grk> very juicy; <grk>dia`</grk> thoroughly +
<grk>chylo`s</grk> juice.]</ety> <fld>(Med. & Chem.)</fld> <def>A
plaster originally composed of the juices of several plants (whence its
name), but now made of an oxide of lead and oil, and consisting
essentially of glycerin mixed with lead salts of the fat
acids.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diacid</ent><br/
<hw>Di*ac"id</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref. <ets>di-</ets>
+ <ets>acid</ets>.]</ety> <fld>(Chem.)</fld> <def>Divalent; -- said of a
base or radical as capable of saturating two acid monad radicals or a
dibasic acid. Cf. <er>Dibasic</er>, <pos>a.</pos>, and
<er>Biacid</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diacodium</ent><br/
\'d8<hw>Di`a*co"di*um</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., from
Gr. <grk>diakw`deion</grk> from poppy heads; <grk>dia`</grk> through,
from + <grk>kw`deia</grk> head, a poppy head.]</ety> <def>A sirup made
of poppies.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diaconal</ent><br/
<hw>Di*ac"o*nal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[LL.
<ets>diaconalis</ets>: cf. F. <ets>diaconal</ets>. Cf.
<er>Deacon</er>.]</ety> <def>Of or pertaining to a deacon.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diaconate</ent><br/
<hw>Di*ac"o*nate</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>diaconatus</ets>: cf. F. <ets>diaconat</ets>.]</ety> <def>The
office of a deacon; deaconship; also, a body or board of
deacons.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diaconate</ent><br/
<hw>Di*ac"o*nate</hw>, <pos>a.</pos> <def>Governed by deacons.</def>
<ldquo/<xex>Diaconate</xex> church.<rdquo/ <rj><au>T.
Goodwin.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diacope</ent><br/
\'d8<hw>Di*ac"o*pe</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., fr. Gr.
<grk>diakoph`</grk> a cutting in two; <grk>dia`</grk> through +
<grk>koph`</grk>.]</ety> <fld>(Gram.)</fld> <def>Tmesis.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diacoustic</ent><br/
<hw>Di`a*cous"tic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>di-</ets> + <ets>acoustic</ets>.]</ety> <def>Pertaining to the
science or doctrine of refracted sounds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diacoustics</ent><br/
<hw>Di`a*cous"tics</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>diacoustique</ets>.]</ety> <def>That branch of natural philosophy
which treats of the properties of sound as affected by passing through
different mediums; -- called also <altname>diaphonics</altname>. See the
Note under <er>Acoustics</er>.</def></p>

<p><ent>Diacritical</ent><br/
<ent>Diacritic</ent><br/
<mhw>{ <hw>Di`a*crit"ic</hw> <pr>(?)</pr>, <hw>Di`a*crit"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[Gr. <grk>diakritiko`s</grk>,
fr. <grk>diakri`nein</grk> to separate, distinguish; <grk>dia`</grk>
through + <grk>kri`nw</grk> to separate. See <er>Critic</er>.]</ety>
<def>That separates or distinguishes; -- applied to points or marks used
to distinguish letters of similar form, or different sounds of the same
letter, as, <amac/, <acr/, <aum/, <omac/, <ocr/, etc.</def>
<ldquo/<xex>Diacritical</xex> points.<rdquo/ <rj><au>Sir W.
Jones.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A glance at this typography will reveal great difficulties, which
<qex>diacritical</qex> marks necessarily throw in the way of both
printer and writer.</q> <rj><qau>A. J. Ellis.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diactinic</ent><br/
<hw>Di`ac*tin"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>di-</ets> + <ets>actinic</ets>.]</ety> <fld>(Physics)</fld>
<def>Capable of transmitting the chemical or actinic rays of light;
<as>as, <ex>diactinic</ex> media</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diadelphia</ent><br/
\'d8<hw>Di`a*del"phi*a</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
fr. Gr. <grk>di-</grk> = <grk>di`s-</grk> twice + <grk>'adelfo`s</grk>
brother.]</ety> <fld>(Bot.)</fld> <def>A Linn<ae/an class of plants
whose stamens are united into two bodies or bundles by their
filaments.</def></p>

<p><ent>Diadelphous</ent><br/
<ent>Diadelphian</ent><br/
<mhw>{ <hw>Di`a*del"phi*an</hw> <pr>(?)</pr>, <hw>Di`a*del"phous</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[Cf. F.
<ets>diadelphe</ets>.]</ety> <fld>(Bot.)</fld> <def>Of or pertaining to
the class Diadelphia; having the stamens united into two bodies by their
filaments (said of a plant or flower); grouped into two bundles or sets
by coalescence of the filaments (said of stamens).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diadem</ent><br/
<hw>Di"a*dem</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>diad<egrave/me</ets>, L. <ets>diadema</ets>, fr. Gr.
<grk>dia`dhma</grk>, fr. <grk>diade`w</grk> to bind round;
<grk>dia`</grk> through, across + <grk>de`w</grk> to bind; cf. Skr.
<ets>d<amac/</ets> to bind.]</ety> <sn>1.</sn> <def>Originally, an
ornamental head band or fillet, worn by Eastern monarchs as a badge of
royalty; hence (later), also, a crown, in general.</def> <ldquo/The
regal <xex>diadem</xex>.<rdquo/ <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Regal power; sovereignty; empire; -- considered as
symbolized by the crown.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Her.)</fld> <def>An arch rising from the rim of a
crown (rarely also of a coronet), and uniting with others over its
center.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Diadem lemur</b></col>. <fld>(Zool.)</fld> <cd>See
<er>Indri</er>.</cd> -- <col><b>Diadem spider</b></col>
<fld>(Zool.)</fld>, <cd>the garden spider.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diadem</ent><br/
<hw>Di"a*dem</hw>, <pos>v. t.</pos> <def>To adorn with a diadem; to
crown.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Not so, when <qex>diadem'd</qex> with rays divine.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To terminate the evil,<br/
To <qex>diadem</qex> the right.</q> <rj><qau>R. H. Neale.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diadrom</ent><br/
<hw>Di"a*drom</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>dia`dromos</grk> a running through; <grk>dia`</grk> through +
<grk>dro`mos</grk>, used as inf. aor. of <grk>tre`chw</grk> to
run.]</ety> <def>A complete course or vibration; time of vibration, as
of a pendulum.</def> <mark>[Obs.]</mark> <rj><au>Locke.</au></rj></p>

<p><ent>Dieresis</ent><br/
<ent>Diaeresis</ent><br/
<mhw>{ <hw>Di*<ae/r"e*sis</hw>, <hw>Di*er"e*sis</hw> }</mhw> <pr>(?;
277)</pr>, <pos>n.</pos>; <plu><it>pl.</it> <plw>Di<ae/reses</plw>
<it>or</it> <plw>Diereses</plw> <pr>(#)</pr>.</plu> <ety>[L.
<ets>diaeresis</ets>, Gr. <grk>diai`resis</grk>, fr. <grk>diaire`w</grk>
to divide; <grk>dia`</grk> through, asunder + <grk>a'ire`w</grk> to
take. See <er>Heresy</er>.]</ety> <sn>1.</sn> <fld>(Gram.)</fld>
<def>The separation or resolution of one syllable into two; -- the
opposite of <inv>syn<ae/resis</inv>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A mark consisting of two dots [<umlaut/], placed
over the second of two adjacent vowels, to denote that they are to be
pronounced as distinct letters; <as>as, <ex>co<oum/perate</ex>,
<ex>a<eum/rial</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diaeretic</ent><br/
<hw>Di`<ae/*ret"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>diairetiko`s</grk> dividing.]</ety> <fld>(Med.)</fld>
<def>Caustic.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diageotropic</ent><br/
<hw>Di`a*ge`o*trop"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>dia`</grk> through, at variance + <grk>gew</grk> (fr.
<grk>gh^</grk>) earth + <grk>tropiko`s</grk> turning.]</ety>
<fld>(Bot.)</fld> <def>Relating to, or exhibiting,
diageotropism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diageotropism</ent><br/
<hw>Di`a*ge*ot"ro*pism</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Bot.)</fld> <def>The tendency of organs (as roots) of plants to
assume a position oblique or transverse to a direction towards the
center of the earth.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diaglyph</ent><br/
<hw>Di"a*glyph</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>diagly`fw</grk> to engrave; <grk>dia`</grk> through +
<grk>gly`fw</grk> to carve.]</ety> <def>An intaglio.</def>
<rj><au>Mollett.</au></rj></p>

<p><ent>Diaglyphtic</ent><br/
<ent>Diaglyphic</ent><br/
<mhw>{ <hw>Di`a*glyph"ic</hw> <pr>(?)</pr>, <hw>Di`a*glyph"tic</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <def>Represented or formed by
depressions in the general surface; <as>as, <ex>diaglyphic</ex>
sculpture or engraving</as>; -- opposed to
<contr>anaglyphic</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diagnose</ent><br/
<hw>Di`ag*nose"</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <def>To
ascertain by diagnosis; to diagnosticate. See
<er>Diagnosticate</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>diagnosing</ent><br/
<hw>diagnosing</hw> <pos>n.</pos> <def>the act or process of identifying
the nature or cause of some phenomenon.</def><br/
<syn><b>Syn. --</b> diagnosis.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Diagnosis</ent><br/
<hw>Di`ag*no"sis</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Diagnoses</plw> <pr>(#)</pr>.</plu> <ety>[NL., fr. Gr.
<grk>dia`gnwsis</grk>, fr. <grk>diagignw`skw</grk> to distinguish;
<grk>dia`</grk> through, asunder + <grk>gignw`skw</grk> to know. See
<er>Know</er>.]</ety> <sn>1.</sn> <fld>(Med.)</fld> <def>The art or act
of recognizing the presence of disease from its signs or symptoms, and
deciding as to its character; also, the decision arrived at.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def><specif>Hence,</specif> the act or process of
identifying the nature or cause of some phenomenon, especially the
abnormal behavior of an animal or artifactual device; <as>as,
<ex>diagnosis</ex> of a vibration in an automobile; <ex>diagnosis</ex>
of the failure of a sales campaign; <ex>diagnosis</ex> of a computer
malfunction</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>Scientific determination of any kind; the concise
description of characterization of a species.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Critical perception or scrutiny; judgment based on
such scrutiny; esp., perception of, or judgment concerning, motives and
character.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The quick eye for effects, the clear <qex>diagnosis</qex> of men's
minds, and the love of epigram.</q> <rj><qau>Compton
Reade.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>My <qex>diagnosis</qex> of his character proved correct.</q>
<rj><qau>J. Payn.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Differential diagnosis</b></col> <fld>(Med.)</fld>,
<cd>the determination of the distinguishing characteristics as between
two similar diseases or conditions.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diagnostic</ent><br/
<hw>Di`ag*nos"tic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/ able to
distinguish, fr. <?/: cf. F. <ets>diagnostique</ets>.]</ety>
<def>Pertaining to, or furnishing, a diagnosis; indicating the nature of
a disease.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diagnostic</ent><br/
<hw>Di`ag*nos"tic</hw>, <pos>n.</pos> <def>The mark or symptom by which
one disease is known or distinguished from others.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diagnosticate</ent><br/
<hw>Di`ag*nos"ti*cate</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos>
<ety>[From <er>Diagnostic</er>.]</ety> <def>To make a diagnosis of; to
recognize by its symptoms, as a disease.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diagnostics</ent><br/
<hw>Di`ag*nos"tics</hw> <pr>(?)</pr>, <pos>n.</pos> <def>That part of
medicine which has to do with ascertaining the nature of diseases by
means of their symptoms or signs.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His rare skill in <qex>diagnostics</qex>.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diagometer</ent><br/
<hw>Di`a*gom"e*ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ to
transmit + <ets>-meter</ets>.]</ety> <def>A sort of electroscope,
invented by Rousseau, in which the dry pile is employed to measure the
amount of electricity transmitted by different bodies, or to determine
their conducting power.</def> <rj><au>Nichol.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diagonal</ent><br/
<hw>Di*ag"o*nal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>diagonalis</ets>, fr. Gr. <grk>diagw`nios</grk> from to angle;
<grk>dia`</grk> through + <grk>gwni`a</grk> an angle; perh. akin to E.
<ets>knee</ets>: cf. F. <ets>diagonal</ets>.]</ety> <fld>(Geom.)</fld>
<def>Joining two not adjacent angles of a quadrilateral or multilateral
figure; running across from corner to corner; crossing at an angle with
one of the sides.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Diagonal bond</b></col> <fld>(Masonry)</fld>,
<cd>herringbone work. See <er>Herringbone</er>, <pos>a.</pos></cd> --
<col><b>Diagonal built</b></col> <fld>(Shipbuilding)</fld>, <cd>built by
forming the outer skin of two layers of planking, making angles of about
45<deg/ with the keel, in opposite directions.</cd> -- <col><b>Diagonal
cleavage</b></col>. <cd>See under <er>Cleavage</er>.</cd> --
<col><b>Diagonal molding</b></col> <fld>(Arch.)</fld>, <cd>a chevron or
zigzag molding.</cd> -- <col><b>Diagonal rib</b></col>.
<fld>(Arch.)</fld> <cd>See <er>Cross-springer</er>.</cd> --
<col><b>Diagonal scale</b></col>, <cd>a scale which consists of a set of
parallel lines, with other lines crossing them obliquely, so that their
intersections furnish smaller subdivisions of the unit of measure than
could be conveniently marked on a plain scale.</cd> -- <col><b>Diagonal
stratification</b></col>. <fld>(Geol.)</fld> <cd>Same as <cref>Cross
bedding</cref>, under <er>Cross</er>, <pos>a.</pos></cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diagonal</ent><br/
<hw>Di*ag"o*nal</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A
right line drawn from one angle to another not adjacent, of a figure of
four or more sides, and dividing it into two parts.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Engin.)</fld> <def>A member, in a framed structure,
running obliquely across a panel.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A diagonal cloth; a kind of cloth having diagonal
stripes, ridges, or welts made in the weaving.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>diagonalizable</ent><br/
<hw>diagonalizable</hw> <pos>adj.</pos> <fld>(Math.)</fld> <def>able to
be diagonalized; -- of a matrix.</def><br/
[<source>PJC</source>]</p>

<p><ent>diagonalize</ent><br/
<hw>diagonalize</hw> <pos>v. t.</pos> <fld>(Math.)</fld> <def>to
transform a matrix to a diagonal matrix.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Diagonally</ent><br/
<hw>Di*ag"o*nal*ly</hw>, <pos>adv.</pos> <def>In a diagonal
direction.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diagonial</ent><br/
<hw>Di`a*go"ni*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Diagonal;
diametrical; hence; diametrically opposed.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Sin can have no tenure by law at all, but is rather an eternal
outlaw, and in hostility with law past all atonement; both
<qex>diagonal</qex> contraries, as much allowing one another as day and
night together in one hemisphere.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diagram</ent><br/
<hw>Di"a*gram</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>diagra`mma</grk>, fr. <grk>diagra`fein</grk> to mark out by lines;
<grk>dia`</grk> through + <grk>gra`fein</grk> to draw, write: cf. F.
<ets>diagramme</ets>. See <er>Graphic</er>.]</ety> <sn>1.</sn>
<fld>(Geom.)</fld> <def>A figure or drawing made to illustrate a
statement, or facilitate a demonstration; a plan.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Any simple drawing made for mathematical or
scientific purposes, or to assist a verbal explanation which refers to
it; a mechanical drawing, as distinguished from an artistical
one.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Indicator diagram</b></col>. <fld>(Steam Engine)</fld>
<cd>See <cref>Indicator card</cref>, under
<er>indicator</er></cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diagram</ent><br/
<hw>Di"a*gram</hw>, <pos>v. t.</pos> <def>To put into the form of a
diagram.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diagrammatic</ent><br/
<hw>Di`a*gram*mat"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining
to, or of the nature of, a diagram; showing by diagram.</def> --
<wordforms><wf>Di`a*gram*mat"ic*ly</wf> <pr>(#)</pr>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diagraph</ent><br/
<hw>Di"a*graph</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>gra`fein</grk> to draw: cf. F. <ets>diagraphe</ets>. See
<er>Diagram</er>.]</ety> <def>A drawing instrument, combining a
protractor and scale.</def></p>

<p><ent>Diagraphical</ent><br/
<ent>Diagraphic</ent><br/
<mhw>{ <hw>Di`a*graph"ic</hw> <pr>(?)</pr>, <hw>Di`a*graph"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[Cf. F.
<ets>diagraphique</ets>.]</ety> <def>Descriptive.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diagraphics</ent><br/
<hw>Di`a*graph"ics</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The art or
science of descriptive drawing; especially, the art or science of
drawing by mechanical appliances and mathematical rule.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diaheliotropic</ent><br/
<hw>Di`a*he`li*o*trop"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>dia`</grk> through, at variance + <grk>"h`lios</grk> sun +
<grk>tropiko`s</grk> turning.]</ety> <fld>(Bot.)</fld> <def>Relating or,
or manifesting, diaheliotropism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diaheliotropism</ent><br/
<hw>Di`a*he`li*ot"ro*pism</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Bot.)</fld> <def>A tendency of leaves or other organs of plants to
have their dorsal surface faced towards the rays of light.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dial</ent><br/
<hw>Di"al</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL. <ets>dialis</ets>
daily, fr. L. <ets>dies</ets> day. See <er>Deity</er>.]</ety>
<sn>1.</sn> <def>An instrument, formerly much used for showing the time
of day from the shadow of a style or gnomon on a graduated arc or
surface; esp., a sundial; but there are lunar and astral
<xex>dials</xex>. The style or gnomon is usually parallel to the earth's
axis, but the dial plate may be either horizontal or vertical.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The graduated face of a timepiece, on which the time
of day is shown by pointers or hands.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A miner's compass.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dial bird</b></col> <fld>(Zool.)</fld>, <cd>an Indian
bird (<spn>Copsychus saularius</spn>), allied to the European robin. The
name is also given to other related species.</cd> -- <col><b>Dial
lock</b></col>, <cd>a lock provided with one or more plates having
numbers or letters upon them. These plates must be adjusted in a certain
determined way before the lock can be operated.</cd> -- <col><b>Dial
plate</b></col>, <cd>the plane or disk of a dial or timepiece on which
lines and figures for indicating the time are placed.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dial</ent><br/
<hw>Di"al</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Dialed</conjf> <pr>(?)</pr> or <conjf>Dialled</conjf>; <pos>p.
pr. & vb. n.</pos> <conjf>Dialing</conjf> or
<conjf>Dialling</conjf>.]</vmorph> <sn>1.</sn> <def>To measure with a
dial.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Hours of that true time which is <qex>dialed</qex> in heaven.</q>
<rj><qau>Talfourd.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mining)</fld> <def>To survey with a dial.</def>
<rj><au>Raymond.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dialect</ent><br/
<hw>Di"a*lect</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>dialecte</ets>, L. <ets>dialectus</ets>, fr. Gr.
<grk>dia`lektos</grk>, fr. <grk>diale`gomai</grk> to converse,
discourse. See <er>Dialogue</er>.]</ety> <sn>1.</sn> <def>Means or mode
of expressing thoughts; language; tongue; form of speech.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This book is writ in such a <qex>dialect</qex><br/
As may the minds of listless men affect.<br/
<qex>Bunyan</qex>.<br/
The universal <qex>dialect</qex> of the world.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The form of speech of a limited region or people, as
distinguished from ether forms nearly related to it; a variety or
subdivision of a language; speech characterized by local peculiarities
or specific circumstances; <as>as, the Ionic and Attic were
<ex>dialects</ex> of Greece; the Yorkshire <ex>dialect</ex>; the
<ex>dialect</ex> of the learned.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>In the midst of this Babel of <qex>dialects</qex> there suddenly
appeared a standard English language.</q> <rj><qau>Earle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>[Charles V.] could address his subjects from every quarter in
their native <qex>dialect</qex>.</q> <rj><qau>Prescott.</qau></rj></p>

<p><syn><b>Syn.</b> -- Language; idiom; tongue; speech; phraseology. See
<er>Language</er>, and <er>Idiom</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dialectal</ent><br/
<hw>Di`a*lec"tal</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Relating to a
dialect; dialectical; <as>as, a <ex>dialectical</ex>
variant</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dialectic</ent><br/
<hw>Di`a*lec"tic</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Dialectics</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Plato placed his <qex>dialectic</qex> above all sciences.</q>
<rj><qau>Liddell & Scott.</qau></rj></p>

<p><ent>Dialectical</ent><br/
<ent>Dialectic</ent><br/
<mhw>{ <hw>Di`a*lec"tic</hw> <pr>(?)</pr>, <hw>Di`a*lec"tic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[L. <ets>dialecticus</ets>, Gr.
<?/: cf. F. <ets>dialectique</ets>. See <er>Dialect</er>.]</ety>
<sn>1.</sn> <def>Pertaining to dialectics; logical;
argumental.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Pertaining to a dialect or to dialects.</def>
<rj><au>Earle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 406 --></p>

<p><ent>Dialectically</ent><br/
<hw>Di`a*lec"tic*al*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a
dialectical manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dialectician</ent><br/
<hw>Di`a*lec*ti"cian</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>dialecticien</ets>.]</ety> <def>One versed in dialectics; a
logician; a reasoner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dialectics</ent><br/
<hw>Di`a*lec"tics</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>dialectica</ets> (sc. <ets>ars</ets>), Gr. <?/ (sc. <?/): cf. F.
<ets>dialectique</ets>.]</ety> <def>That branch of logic which teaches
the rules and modes of reasoning; the application of logical principles
to discursive reasoning; the science or art of discriminating truth from
error; logical discussion.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Dialectics</xex> was defined by Aristotle to be the
method of arguing with probability on any given problem, and of
defending a tenet without inconsistency. By Plato, it was used in the
following senses: <sn>1.</sn> Discussion by dialogue as a method of
scientific investigation. <sn>2.</sn> The method of investigating the
truth by analysis. <sn>3.</sn> The science of ideas or of the nature and
laws of being -- higher metaphysics. By Kant, it was employed to signify
the logic of appearances or illusions, whether these arise from accident
or error, or from those necessary limitations which, according to this
philosopher, originate in the constitution of the human
intellect.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dialectology</ent><br/
<hw>Di`a*lec*tol"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Dialect</ets> + <ets>-logy</ets>.]</ety> <def>That branch of
philology which is devoted to the consideration of dialects.</def>
<rj><au>Beck.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dialector</ent><br/
<hw>Di`a*lec"tor</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One skilled in
dialectics.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dialing</ent><br/
<hw>Di"al*ing</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The art
of constructing dials; the science which treats of measuring time by
dials.</def> <altsp>[Written also <asp>dialling</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A method of surveying, especially in mines, in which
the bearings of the courses, or the angles which they make with each
other, are determined by means of the circumferentor.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dialist</ent><br/
<hw>Di"al*ist</hw>, <pos>n.</pos> <def>A maker of dials; one skilled in
dialing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diallage</ent><br/
\'d8<hw>Di*al"la*ge</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<?/ interchange, change, fr. <?/ to interchange.]</ety>
<fld>(Rhet.)</fld> <def>A figure by which arguments are placed in
various points of view, and then turned to one point.</def>
<rj><au>Smart.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diallage</ent><br/
<hw>Di"al*lage</hw> <pr>(?; 277)</pr>, <pos>n.</pos> <ety>[Gr. <?/
change, alluding to the change and inequality of luster between the
natural joints of the mineral.]</ety> <fld>(Min.)</fld> <def>A dark
green or bronze-colored laminated variety of pyroxene, common in certain
igneous rocks.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diallel</ent><br/
<hw>Di"al*lel</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/
crossing.]</ety> <def>Meeting and intersecting, as lines; not parallel;
-- opposed to <contr>parallel</contr>.</def> <mark>[Obs.]</mark>
<rj><au>Ash.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diallyl</ent><br/
<hw>Di*al"lyl</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld> <def>A
volatile, pungent, liquid hydrocarbon, <chform>C6H10</chform>,
consisting of two allyl radicals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dialogical</ent><br/
<hw>Di`a*log"ic*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/
belonging to discourse.]</ety> <def>Relating to a dialogue;
dialogistical.</def> <rj><au>Burton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dialogically</ent><br/
<hw>Di`a*log"ic*al*ly</hw>, <pos>adv.</pos> <def>In the manner or nature
of a dialogue.</def> <rj><au>Goldsmith.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dialogism</ent><br/
<hw>Di*al"o*gism</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/, fr.
<?/: cf. F. <ets>dialogisme</ets>. See <er>Dialogue</er>.]</ety> <def>An
imaginary speech or discussion between two or more; dialogue.</def>
<rj><au>Fulke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dialogist</ent><br/
<hw>Di*al"o*gist</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>dialogista</ets>: cf. F. <ets>dialogiste</ets>.]</ety> <sn>1.</sn>
<def>A speaker in a dialogue.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A writer of dialogues.</def> <rj><au>P.
Skelton.</au></rj></p>

<p><ent>Dialogistical</ent><br/
<ent>Dialogistic</ent><br/
<mhw>{ <hw>Di*al`o*gis"tic</hw> <pr>(?)</pr>,
<hw>Di*al`o*gis"tic*al</hw> <pr>(?)</pr>, }</mhw> <pos>a.</pos>
<ety>[Gr. <?/.]</ety> <def>Pertaining to a dialogue; having the form or
nature of a dialogue.</def> --
<wordforms><wf>Di*al`o*gis"tic*al*ly</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dialogite</ent><br/
<hw>Di*al"o*gite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From Gr. <?/ an
arguing.]</ety> <fld>(Min.)</fld> <def>Native carbonate of manganese;
rhodochrosite.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dialogize</ent><br/
<hw>Di*al"o*gize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Gr. <?/: cf.
F. <ets>dialogiser</ets>.]</ety> <def>To discourse in dialogue.</def>
<rj><au>Fotherby.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dialogue</ent><br/
<hw>Di"a*logue</hw> <pr>(?; 115)</pr>, <pos>n.</pos> <ety>[OE.
<ets>dialogue</ets>, L. <ets>dialogus</ets>, fr. Gr. <?/, fr. <?/ to
converse, <grk>dia`</grk> through + <?/ to speak: cf. F.
<ets>dialogue</ets>. See <er>Legend</er>.]</ety> <sn>1.</sn> <def>A
conversation between two or more persons; particularly, a formal
conservation in theatrical performances or in scholastic
exercises.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A written composition in which two or more persons
are represented as conversing or reasoning on some topic; <as>as, the
<ex>Dialogues</ex> of Plato</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dialogue</ent><br/
<hw>Di"a*logue</hw>, <pos>v. i.</pos> <ety>[Cf. F.
<ets>dialoguer</ets>.]</ety> <def>To take part in a dialogue; to
dialogize.</def> <mark>[R.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dialogue</ent><br/
<hw>Di"a*logue</hw>, <pos>v. t.</pos> <def>To express as in
dialogue.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>And <qex>dialogued</qex> for him what he would say.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dialypetalous</ent><br/
<hw>Di`al*y*pet"al*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>dia`</grk> through, asunder + <?/ to loose + <?/ leaf.]</ety>
<fld>(Bot.)</fld> <def>Having separate petals; polypetalous.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dialysis</ent><br/
\'d8<hw>Di*al"y*sis</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Dialyses</plw> <pr>(#)</pr>.</plu> <ety>[L., separation, fr. Gr.
<?/, fr. <?/ to part asunder, dissolve; <grk>dia`</grk> through + <?/ to
loose.]</ety> <sn>1.</sn> <fld>(Gram.)</fld> <def>Di<ae/resis. See
<er>Di<ae/resis</er>, 1.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Rhet.)</fld> <def>Same as
<er>Asyndeton</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Med.)</fld> <sd>(a)</sd> <def>Debility.</def>
<sd>(b)</sd> <def>A solution of continuity; division; separation of
parts.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Chem.)</fld> <def>The separation of different
substances in solution, as crystalloids and colloids, by means of their
unequal diffusion, especially through natural or artificial
membranes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dialytic</ent><br/
<hw>Di`a*lyt"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/, fr. <?/.
See <er>Dialysis</er>.]</ety> <def>Having the quality of unloosing or
separating.</def> <rj><au>Clarke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dialytic telescope</b></col>, <cd>an achromatic telescope
in which the colored dispersion produced by a single object lens of
crown glass is corrected by a smaller concave lens, or combination of
lenses, of high dispersive power, placed at a distance in the narrower
part of the converging cone of rays, usually near the middle of the
tube.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dialyzate</ent><br/
<hw>Di*al"y*zate</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>The material subjected to dialysis.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dialyzation</ent><br/
<hw>Di`a*ly*za"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>The act or process of dialysis.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dialyze</ent><br/
<hw>Di"a*lyze</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Dialyzed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Dialyzing</conjf>.]</vmorph> <fld>(Chem.)</fld> <def>To
separate, prepare, or obtain, by dialysis or osmose; to pass through an
animal membrane; to subject to dialysis.</def> <altsp>[Written also
<asp>dialyse</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dialyzed</ent><br/
<hw>Di"a*lyzed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Prepared by
diffusion through an animal membrane; <as>as, <ex>dialyzed</ex>
iron</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dialyzer</ent><br/
<hw>Di"a*ly`zer</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The instrument or
medium used to effect chemical dialysis.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diamagnet</ent><br/
<hw>Di`a*mag"net</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>dia-</ets> + <ets>magnet</ets>.]</ety> <def>A body having
diamagnetic polarity.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diamagnetic</ent><br/
<hw>Di`a*mag*net"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to,
or exhibiting the phenomena of, diamagnetism; taking, or being of a
nature to take, a position at right angles to the lines of magnetic
force. See <er>Paramagnetic</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Diamagnetic attraction</b></col>. <cd>See under
<er>Attraction</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diamagnetic</ent><br/
<hw>Di`a*mag*net"ic</hw>, <pos>n.</pos> <def>Any substance, as bismuth,
glass, phosphorous, etc., which in a field of magnetic force is
differently affected from the ordinary magnetic bodies, as iron; that
is, which tends to take a position at right angles to the lines of
magnetic force, and is repelled by either pole of the magnet. Contrasted
with <contr>paramagnetic</contr> and
<contr>ferromagnetic</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diamagnetically</ent><br/
<hw>Di`a*mag*net"ic*al*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In the
manner of, or according to, diamagnetism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diamagnetism</ent><br/
<hw>Di`a*mag"net*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>The science which treats of diamagnetic phenomena, and of the
properties of diamagnetic bodies.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The magnetic action which characterizes diamagnetic
substances, the magnetic moments of which tend to oppose an externally
applied magnetic field. Contrasted with <contr>paramagnetism</contr> and
<contr>ferromagnetism</contr>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Diamantiferous</ent><br/
<hw>Di`a*man*tif"er*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F.
<ets>diamant</ets> diamond + <ets>-ferous</ets>.]</ety> <def>Yielding
diamonds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diamantine</ent><br/
<hw>Di`a*man"tine</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Adamantine.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diameter</ent><br/
<hw>Di*am"e*ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>diam<egrave/tre</ets>, L. <ets>diametros</ets>, fr. Gr. <?/;
<grk>dia`</grk> through + <?/ measure. See <er>Meter</er>.]</ety>
<sn>1.</sn> <fld>(Geom.)</fld> <sd>(a)</sd> <def>Any right line passing
through the center of a figure or body, as a circle, conic section,
sphere, cube, etc., and terminated by the opposite boundaries; a
straight line which bisects a system of parallel chords drawn in a
curve.</def> <sd>(b)</sd> <def>A diametral plane.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The length of a straight line through the center of
an object from side to side; width; thickness; <as>as, the
<ex>diameter</ex> of a tree or rock</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In an elongated object the diameter is usually taken at
right angles to the longer axis.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Arch.)</fld> <def>The distance through the lower
part of the shaft of a column, used as a standard measure for all parts
of the order. See <er>Module</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Conjugate diameters</b></col>. <cd>See under
<er>Conjugate</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diametral</ent><br/
<hw>Di*am"e*tral</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. F.
<ets>diam<eacute/tral</ets>.]</ety> <def>Pertaining to a diameter;
diametrical.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Diametral curve</b></col>, <col><b>Diametral
surface</b></col></mcol> <fld>(Geom.)</fld>, <cd>any line or surface
which bisects a system of parallel chords drawn in a curve or
surface.</cd> -- <col><b>Diametral planes</b></col>
<fld>(Crystal.)</fld>, <cd>planes in which two of the axes
lie.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diametral</ent><br/
<hw>Di*am"e*tral</hw>, <pos>n.</pos> <def>A diameter.</def>
<mark>[Obs.]</mark> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diametrally</ent><br/
<hw>Di*am"e*tral*ly</hw>, <pos>adv.</pos> <def>Diametrically.</def></p>

<p><ent>Diametrical</ent><br/
<ent>Diametric</ent><br/
<mhw>{ <hw>Di*am"e*tric</hw> <pr>(?)</pr>, <hw>Di*am"e*tric*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <sn>1.</sn> <def>Of or pertaining to
a diameter.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>As remote as possible, as if at the opposite end of
a diameter; directly adverse.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diametrically</ent><br/
<hw>Di*am"e*tric*al*ly</hw>, <pos>adv.</pos> <def>In a diametrical
manner; directly; <as>as, <ex>diametrically</ex>
opposite</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Whose principles were <qex>diametrically</qex> opposed to his.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diamide</ent><br/
<hw>Di*am"ide</hw> <pr>(?; 104)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>di-</ets> + <ets>amide</ets>.]</ety> <fld>(Chem.)</fld> <def>Any
compound containing two amido groups united with one or more acid or
negative radicals, -- as distinguished from a diamine. Cf. <xex>Amido
acid</xex>, under <er>Amido</er>, and <xex>Acid amide</xex>, under
<er>Amide</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diamido-</ent><br/
<hw>Di*am"i*do-</hw> <pr>(<?/)</pr>, <pos>a.</pos> <fld>(Chem.)</fld>
<def>A prefix or combining form of <er>Diamine</er>.</def> <note>[Also
used adjectively.]</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diamine</ent><br/
<hw>Di*am"ine</hw> <pr>(?; 104)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>di-</ets> + <ets>amine</ets>.]</ety> <fld>(Chem.)</fld> <def>A
compound containing two amido groups united with one or more basic or
positive radicals, -- as contrasted with a <xex>diamide</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In chemical nomenclature, if any amine or diamine is
named by prefixing the nitrogen group, the name of the latter takes the
form of <xex>amido</xex>, <xex>diamido</xex>, etc., thus <xex>ethylene
diamine</xex>, <chform>C2H4.(NH2)2</chform>, is also called
<xex>diamido-ethylene</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diamond</ent><br/
<hw>Di"a*mond</hw> <pr>(?; 277)</pr>, <pos>n.</pos> <ety>[OE.
<ets>diamaund</ets>, <ets>diamaunt</ets>, F. <ets>diamant</ets>,
corrupted, fr. L. <ets>adamas</ets>, the hardest iron, steel, diamond,
Gr. <?/. Perh. the corruption is due to the influence of Gr. <?/
transparent. See <er>Adamant</er>, <er>Tame</er>.]</ety> <sn>1.</sn>
<def>A precious stone or gem excelling in brilliancy and beautiful play
of prismatic colors, and remarkable for extreme hardness.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The diamond is native carbon in isometric crystals,
often octahedrons with rounded edges. It is usually colorless, but some
are yellow, green, blue, and even black. It is the hardest substance
known. The diamond as found in nature (called a <xex>rough
diamond</xex>) is cut, for use in jewelry, into various forms with many
reflecting faces, or facets, by which its brilliancy is much increased.
See <er>Brilliant</er>, <er>Rose</er>. Diamonds are said to be of the
<xex>first water</xex> when very transparent, and of the
<xex>second</xex> or <xex>third water</xex> as the transparency
decreases.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A geometrical figure, consisting of four equal
straight lines, and having two of the interior angles acute and two
obtuse; a rhombus; a lozenge.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>One of a suit of playing cards, stamped with the
figure of a diamond.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Arch.)</fld> <def>A pointed projection, like a
four-sided pyramid, used for ornament in lines or groups.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Baseball)</fld> <def>The infield; the square space,
90 feet on a side, having the bases at its angles.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Print.)</fld> <def>The smallest kind of type in
English printing, except that called <xex>brilliant</xex>, which is
seldom seen.</def><br/
[<source>1913 Webster</source>]</p>

<p><note> <hand/ This line is printed in the type called
<er>Diamond</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Black diamond</b></col>, <cd>coal; <fld>(Min.)</fld> See
<er>Carbonado</er>.</cd> -- <col><b>Bristol diamond</b></col>. <cd>See
<cref>Bristol stone</cref>, under <er>Bristol</er>.</cd> --
<col><b>Diamond beetle</b></col> <fld>(Zool.)</fld>, <cd>a large South
American weevil (<spn>Entimus imperialis</spn>), remarkable for its
splendid luster and colors, due to minute brilliant scales.</cd> --
<col><b>Diamond bird</b></col> <fld>(Zool.)</fld>, <cd>a small
Australian bird (<spn>Pardalotus punctatus</spn>, family
<fam>Ampelid<ae/</fam>.). It is black, with white spots.</cd> --
<col><b>Diamond drill</b></col> <fld>(Engin.)</fld>, <cd>a rod or tube
the end of which is set with black diamonds; -- used for perforating
hard substances, esp. for boring in rock.</cd> -- <col><b>Diamond
finch</b></col> <fld>(Zool.)</fld>, <cd>a small Australian sparrow,
often kept in a cage. Its sides are black, with conspicuous white spots,
and the rump is bright carmine.</cd> -- <col><b>Diamond groove</b></col>
<fld>(Iron Working)</fld>, <cd>a groove of V-section in a roll.</cd> --
<col><b>Diamond mortar</b></col> <fld>(Chem.)</fld>, <cd>a small steel
mortar used for pulverizing hard substances.</cd> --
<col><b>Diamond-point tool</b></col>, <cd>a cutting tool whose point is
diamond-shaped.</cd> -- <col><b>Diamond snake</b></col>
<fld>(Zool.)</fld>, <cd>a harmless snake of Australia (<spn>Morelia
spilotes</spn>); the carpet snake.</cd> -- <col><b>Glazier's
diamond</b></col>, <cd>a small diamond set in a glazier's tool, for
cutting glass.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diamond</ent><br/
<hw>Di"a*mond</hw> <pr>(?; 277)</pr>, <pos>a.</pos> <def>Resembling a
diamond; made of, or abounding in, diamonds; <as>as, a <ex>diamond</ex>
chain; a <ex>diamond</ex> field.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diamond jubilee</ent><br/
<ent>Diamond anniversary</ent><br/
<mhw>{ <hw>Diamond anniversary</hw>, <hw>Diamond jubilee</hw>, etc.
}</mhw> <def>an anniversary celebrated upon the completion of sixty, or,
according to some, seventy-five, years from the beginning of the event
commemorated.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Diamond-back</ent><br/
<hw>Di"a*mond-back`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>The salt-marsh terrapin of the Atlantic coast (<spn>Malacoclemmys
palustris</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diamonded</ent><br/
<hw>Di"a*mond*ed</hw>, <pos>a.</pos> <sn>1.</sn> <def>Having figures
like a diamond or lozenge.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Adorned with diamonds; diamondized.</def>
<rj><au>Emerson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diamondize</ent><br/
<hw>Di"a*mond*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To set with
diamonds; to adorn; to enrich.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Diamondizing</qex> of your subject.</q> <rj><qau>B.
Jonson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diamond-shaped</ent><br/
<hw>Di"a*mond-shaped`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Shaped like
a diamond or rhombus.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diamond State</ent><br/
<hw>Diamond State</hw>. <def>Delaware; -- a nickname alluding to its
small size.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Diamylene</ent><br/
<hw>Di*am"y*lene</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>di-</ets> + <ets>amylene</ets>.]</ety> <fld>(Chem.)</fld> <def>A
liquid hydrocarbon, <chform>C10H20</chform>, of the ethylene series,
regarded as a polymeric form of amylene.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dian</ent><br/
<hw>Di"an</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Diana.</def>
<mark>[Poetic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diana</ent><br/
<hw>Di*a"na</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>Diana</ets>.]</ety> <fld>(Myth.)</fld> <def>The daughter of Jupiter
and Latona; a virgin goddess who presided over hunting, chastity, and
marriage; -- identified with the Greek goddess
<altname>Artemis</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And chaste <qex>Diana</qex> haunts the forest shade.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Diana monkey</b></col> <fld>(Zool.)</fld>, <cd>a
handsome, white-bearded monkey of West Africa (<spn>Cercopithecus
Diana</spn>).</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diandria</ent><br/
\'d8<hw>Di*an"dri*a</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL., fr.
Gr. <grk>di-</grk> = <grk>di`s-</grk> twice + <?/, <?/, a man, a
male.]</ety> <fld>(Bot.)</fld> <def>A Linn<ae/an class of plants having
two stamens.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diandrian</ent><br/
<hw>Di*an"dri*an</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Diandrous.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diandrous</ent><br/
<hw>Di*an"drous</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>diandre</ets>.]</ety> <fld>(Bot.)</fld> <def>Of or pertaining to
the class Diandria; having two stamens.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dianium</ent><br/
\'d8<hw>Di*a"ni*um</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. L.
<ets>Diana</ets>; either as the name of the Roman goddess, or from its
use in OE. as a name of silver.]</ety> <fld>(Chem.)</fld> <def>Same as
<er>Columbium</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dianoetic</ent><br/
<hw>Di`a*no*et"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/;
<grk>dia`</grk> through + <?/ to revolve in the mind.]</ety>
<fld>(Metaph.)</fld> <def>Pertaining to the discursive faculty, its acts
or products.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I would employ . . . <qex>dianoetic</qex> to denote the operation
of the discursive, elaborative, or comparative faculty.</q> <rj><qau>Sir
W. Hamilton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dianoialogy</ent><br/
<hw>Di`a*noi*al"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/
thought + <ets>-logy</ets>.]</ety> <def>The science of the dianoetic
faculties, and their operations.</def> <rj><au>Sir W.
Hamilton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dianthus</ent><br/
<hw>Di*an"thus</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr. <?/,
gen. <?/, Zeus + <grk>'a`nqos</grk> flower.]</ety> <fld>(Bot.)</fld>
<def>A genus of plants containing some of the most popular of cultivated
flowers, including the pink, carnation, and Sweet William.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diapase</ent><br/
<hw>Di"a*pase</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Diapason</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>A tuneful <qex>diapase</qex> of pleasures.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diapasm</ent><br/
<hw>Di"a*pasm</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>diapasma</ets>, Gr. <?/, fr. <?/; <grk>dia`</grk> through + <?/ to
sprinkle: cf. F. <ets>diapasme</ets>.]</ety> <def>Powdered aromatic
herbs, sometimes made into little balls and strung together.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diapason</ent><br/
<hw>Di`a*pa"son</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., fr. Gr.
<grk>diapasw^n</grk> (<it>i. e.</it>, <grk>"h dia` pasw^n chordw^n
symfoni`a</grk> the concord of the first and last notes, the octave);
<grk>dia`</grk> through + <grk>pasw^n</grk>, gen. pl. of <grk>pa^s</grk>
all: cf. F. <ets>diapason</ets>. Cf. <er>Panacea</er>.]</ety>
<sn>1.</sn> <fld>(Gr. Mus.)</fld> <def>The octave, or interval which
includes all the tones of the diatonic scale. Compare
<er>disdiapason</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Concord, as of notes an octave apart;
harmony.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The fair music that all creatures made . . . <br/
In perfect <qex>diapason</qex>.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The entire compass of tones; the entire compass of
tones of a voice or an instrument.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Through all the compass of the notes it ran,<br/
The <qex>diapason</qex> closing full in man.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A standard of pitch; a tuning fork; <as>as, the
French normal <ex>diapason</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>One of certain stops in the organ, so called because
they extend through the scale of the instrument. They are of several
kinds, as <stype>open diapason</stype>, <stype>stopped diapason</stype>,
<stype>double diapason</stype>, and the like.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diapedesis</ent><br/
\'d8<hw>Di`a*pe*de"sis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <?/ a leaping or oozing through, fr. <?/ to leap through;
<grk>dia`</grk> through + <?/ to leap.]</ety> <fld>(Med.)</fld> <def>The
passage of the corpuscular elements of the blood from the blood vessels
into the surrounding tissues, without rupture of the walls of the blood
vessels.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diapensiaceae</ent><br/
<hw>Diapensiaceae</hw> <pos>n.</pos> <def>a natural family of northern
temperate low evergreen plants; in some classifications placed in its
own order <ord>Diapensiales</ord>.</def><br/
<syn><b>Syn. --</b> family <fam>Diapensiaceae</fam>, diapensia
family.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Diapensiales</ent><br/
<hw>Diapensiales</hw> <pos>n.</pos> <def>an order of plants, used in
some classifications as coextensive with the family
<altname><fam>Diapensiaceae</fam></altname>.</def><br/
<syn><b>Syn. --</b> order <ord>Diapensiales</ord>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Diapente</ent><br/
\'d8<hw>Di`a*pen"te</hw> <pr>(-p<ecr/n"t<esl/)</pr>, <pos>n.</pos>
<ety>[L., fr. Gr. <grk>dia`pente</grk> a fifth; <grk>dia`</grk> through
+ <grk>pe`nte</grk> five: cf. F. <ets>diapente</ets>.]</ety> <sn>1.</sn>
<fld>(Anc. Mus.)</fld> <def>The interval of the fifth.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Med.)</fld> <def>A composition of five
ingredients.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diaper</ent><br/
<hw>Di"a*per</hw> <pr>(d<imac/"<adot/*p<etil/r)</pr>, <pos>n.</pos>
<ety>[OF. <ets>diaspre</ets>, <ets>diapre</ets>, <ets>diaspe</ets>, sort
of figured cloth, It. <ets>diaspro</ets> jasper, <ets>diaspo</ets>
figured cloth, from L. <ets>jaspis</ets> a green-colored precious stone.
See <er>Jasper</er>.]</ety> <sn>1.</sn> <def>Any textile fabric (esp.
linen or cotton toweling) woven in diaper pattern. See 2.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Fine Arts)</fld> <def>Surface decoration of any
sort which consists of the constant repetition of one or more simple
figures or units of design evenly spaced.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 407 --></p>

<p><sn>3.</sn> <def>A towel or napkin for wiping the hands,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Let one attend him with a silver basin, . . . <br/
Another bear the ewer, the third a <qex>diaper</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>An infant's breechcloth.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diaper</ent><br/
<hw>Di"a*per</hw> <pr>(?)</pr>, <pos>v. t.</pos> <sn>1.</sn> <def>To
ornament with figures, etc., arranged in the pattern called diaper, as
cloth in weaving.</def> <ldquo/<xex>Diapered</xex> light.<rdquo/
<rj><au>H. Van Laun.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Engarlanded and <qex>diapered</qex><br/
With in wrought flowers.</q> <rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To put a diaper on (a child).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diaper</ent><br/
<hw>Di"a*per</hw>, <pos>v. i.</pos> <def>To draw flowers or figures, as
upon cloth.</def> <ldquo/If you <xex>diaper</xex> on folds.<rdquo/
<rj><au>Peacham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diapering</ent><br/
<hw>Di"a*per*ing</hw>, <pos>n.</pos> <def>Same as <er>Diaper</er>,
<pos>n.</pos>, 2.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diaphane</ent><br/
<hw>Di"a*phane</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>diaphane</ets> diaphanous. See <er>Diaphanous</er>.]</ety> <def>A
woven silk stuff with transparent and colored figures; diaper
work.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diaphaned</ent><br/
<hw>Di"a*phaned</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. OF.
<ets>diaphaner</ets> to make transparent. See
<er>Diaphanous</er>.]</ety> <def>Transparent or translucent.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diaphaneity</ent><br/
<hw>Di`a*pha*ne"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>diaphan<eacute/it<eacute/</ets>. See <er>Diaphanous</er>.]</ety>
<def>The quality of being diaphanous; transparency;
pellucidness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diaphanic</ent><br/
<hw>Di`a*phan"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Diaphanous</er>.]</ety> <def>Having power to transmit light;
transparent; diaphanous.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diaphanie</ent><br/
<hw>Di*aph"a*nie</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The art of
imitating stained glass with translucent paper.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diaphanometer</ent><br/
<hw>Di`a*pha*nom"e*ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/
transparent + <ets>-meter</ets>.]</ety> <def>An instrument for measuring
the transparency of the air.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diaphanoscope</ent><br/
<hw>Di`a*phan"o*scope</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/
transparent + <ets>-scope</ets>.]</ety> <fld>(Photog.)</fld> <def>A dark
box constructed for viewing transparent pictures, with or without a
lens.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diaphanotype</ent><br/
<hw>Di`a*phan"o*type</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/
transparent + <ets>-type</ets>.]</ety> <fld>(Photog.)</fld> <def>A
colored photograph produced by superimposing a translucent colored
positive over a strong uncolored one.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diaphanous</ent><br/
<hw>Di*aph"a*nous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/, fr.
<?/ to show or shine through; <grk>dia`</grk> through + <?/ to show, and
in the passive, to shine: cf. F. <ets>diaphane</ets>. See
<er>Phantom</er>, and cf. <er>Diaphane</er>, <er>Diaphanic</er>.]</ety>
<def>Allowing light to pass through, as porcelain; translucent or
transparent; pellucid; clear.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Another cloud in the region of them, light enough to be fantastic
and <qex>diaphanous</qex>.</q> <rj><qau>Landor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diaphanously</ent><br/
<hw>Di*aph"a*nous*ly</hw>, <pos>adv.</pos> <def>Translucently.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diaphemetric</ent><br/
<hw>Di*aph`e*met"ric</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>dia`</grk> through + <?/ touch + <?/ measure.]</ety>
<fld>(Physiol.)</fld> <def>Relating to the measurement of the tactile
sensibility of parts; <as>as, <ex>diaphemetric</ex>
compasses</as>.</def> <rj><au>Dunglison.</au></rj></p>

<p><ent>Diaphonical</ent><br/
<ent>Diaphonic</ent><br/
<mhw>{ <hw>Di`a*phon"ic</hw> <pr>(?)</pr>, <hw>Di`a*phon"ic*al</hw>
<pr>(?)</pr> }</mhw>, <pos>a.</pos> <ety>[Gr. <grk>dia`</grk> through +
<?/ sound, tone.]</ety> <def>Diacoustic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diaphonics</ent><br/
<hw>Di`a*phon"ics</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The doctrine of
refracted sound; diacoustics.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diaphoresis</ent><br/
\'d8<hw>Di`a*pho*re"sis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., fr.
Gr. <?/, fr. <?/ to carry through, to throw off by perspiration;
<grk>dia`</grk> through + <?/ to carry.]</ety> <fld>(Med.)</fld>
<def>Perspiration, or an increase of perspiration.</def></p>

<p><ent>Diaphoretical</ent><br/
<ent>Diaphoretic</ent><br/
<mhw>{ <hw>Di`a*pho*ret"ic</hw> <pr>(?)</pr>,
<hw>Di`a*pho*ret"ic*al</hw> <pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[L.
<ets>diaphoreticus</ets>, Gr. <?/: cf. F.
<ets>diaphor<eacute/tique</ets>. See <er>Diaphoresis</er>.]</ety>
<def>Having the power to increase perspiration.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diaphoretic</ent><br/
<hw>Di`a*pho*ret"ic</hw>, <pos>n.</pos> <fld>(Med.)</fld> <def>A
medicine or agent which promotes perspiration.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Diaphoretics</xex> differ from
<xex>sudorifics</xex>; the former only increase the insensible
perspiration, the latter excite the sensible discharge called
<xex>sweat</xex>.</note> <rj><au>Parr.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diaphote</ent><br/
<hw>Di"a*phote</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>dia-</ets> + Gr. <?/, light.]</ety> <fld>(Elec.)</fld> <def>An
instrument designed for transmitting pictures by telegraph.</def>
<rj><au>Fallows.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diaphragm</ent><br/
<hw>Di"a*phragm</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>diaphragma</ets>, Gr. <?/, fr. <?/ to fence by a partition wall;
<grk>dia`</grk> through + <?/, <?/, to fence, inclose; prob. akin to L.
<ets>fareire</ets> to stuff: cf. F. <ets>diaphragme</ets>. See
<er>Farce</er>.]</ety> <sn>1.</sn> <def>A dividing membrane or thin
partition, commonly with an opening through it.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Anat.)</fld> <def>The muscular and tendinous
partition separating the cavity of the chest from that of the abdomen;
the midriff.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <def>A calcareous plate which divides
the cavity of certain shells into two parts.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Opt.)</fld> <def>A plate with an opening, which is
generally circular, used in instruments to cut off marginal portions of
a beam of light, as at the focus of a telescope.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Mach.)</fld> <def>A partition in any compartment,
for various purposes.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Diaphragm pump</b></col>, <cd>one in which a flexible
diaphragm takes the place of a piston.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diaphragmatic</ent><br/
<hw>Di`a*phrag*mat"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>diaphragmatique</ets>.]</ety> <def>Pertaining to a diaphragm;
<as>as, <ex>diaphragmatic</ex> respiration; the <ex>diaphragmatic</ex>
arteries and nerves.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>diaphyseal</ent><br/
<hw>diaphyseal</hw> <pos>adj.</pos> <def>of or pertaining to
diaphysis.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Diaphysis</ent><br/
<hw>Di*aph"y*sis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ a
growing through; <grk>dia`</grk> through + <?/ to bring forth.]</ety>
<sn>1.</sn> <fld>(Bot.)</fld> <def>An abnormal prolongation of the axis
of inflorescence.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Anat.)</fld> <def>The shaft, or main part, of a
bone, which is first ossified.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diapnoic</ent><br/
<hw>Di`ap*no"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/ outlet
for the wind, exhalation, fr. <?/ to blow through; <grk>dia`</grk>
through + <?/ to blow, breathe: cf. F. <ets>diapno<ium/que</ets>.]</ety>
<fld>(Med.)</fld> <def>Slightly increasing an insensible perspiration;
mildly diaphoretic.</def> -- <def2><pos>n.</pos> <def>A gentle
diaphoretic.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diapophysical</ent><br/
<hw>Di*ap`o*phys"ic*al</hw> <pr>(?)</pr>, <pos>a.</pos>
<fld>(Anat.)</fld> <def>Pertaining to a diapophysis.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diapophysis</ent><br/
\'d8<hw>Di`a*poph"y*sis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. See
<er>Dia-</er>, and <er>Apophysis</er>.]</ety> <fld>(Anat.)</fld>
<def>The dorsal transverse, or tubercular, process of a vertebra. See
<er>Vertebra</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diarchy</ent><br/
<hw>Di"arch*y</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <grk>di-</grk>
= <grk>di`s-</grk> twice + <?/ to rule.]</ety> <def>A form of government
in which the supreme power is vested in two persons.</def></p>

<p><ent>Diarian</ent><br/
<ent>Diarial</ent><br/
<mhw>{ <hw>Di*a"ri*al</hw> <pr>(?)</pr>, <hw>Di*a"ri*an</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[See <er>Diary</er>.]</ety>
<def>Pertaining to a diary; daily.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diarist</ent><br/
<hw>Di"a*rist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who keeps a
diary.</def></p>

<p><ent>Diarrhoea</ent><br/
<ent>Diarrhea</ent><br/
<mhw>{ <hw>Di`ar*rhe"a</hw>, <hw>Di`ar*rh<oe/"a</hw> }</mhw>,
<pr>(d<imac/`<ait/r*r<emac/"<adot/)</pr>, <pos>n.</pos> <ety>[L.
<ets>diarrhoea</ets>, Gr. <grk>dia`rroia</grk>, fr.
<grk>dia`rrei^n</grk> to flow through; <grk>dia`</grk> +
<grk>"rei^n</grk> to flow; akin to E. <ets>stream</ets>. See
<er>Stream</er>.]</ety> <fld>(Med.)</fld> <def>A morbidly frequent and
profuse discharge of loose or fluid evacuations from the intestines,
without tenesmus; a purging or looseness of the bowels; a
flux.</def></p>

<p><ent>Diarrhoeal</ent><br/
<ent>Diarrheal</ent><br/
<mhw>{ <hw>Di`ar*rhe"al</hw>, <hw>Di`ar*rh<oe/"al</hw> }</mhw>
<pos>a.</pos> <fld>(Med.)</fld> <def>Of or pertaining to diarrhea; like
diarrhea.</def></p>

<p><ent>Diarrhoetic</ent><br/
<ent>Diarrhetic</ent><br/
<mhw>{ <hw>Di`ar*rhet"ic</hw>, <hw>Di`ar*rh<oe/t"ic</hw> }</mhw>
<pr>(?)</pr>, <pos>a.</pos> <fld>(Med.)</fld> <def>Producing diarrhea,
or a purging.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diarthrodial</ent><br/
<hw>Di`ar*thro"di*al</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Anat.)</fld>
<def>Relating to diarthrosis, or movable articulations.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diarthrosis</ent><br/
\'d8<hw>Di`ar*thro"sis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <?/, fr. <?/ to joint, articulate; <grk>dia`</grk> through, asunder
+ <?/ to fasten by a joint, <grk>'a`rqron</grk> joint.]</ety>
<fld>(Anat.)</fld> <def>A form of articulation which admits of
considerable motion; a complete joint; abarticulation. See
<er>Articulation</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diary</ent><br/
<hw>Di"a*ry</hw> <pr>(d<imac/"<adot/*r<ycr/)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Diaries</plw> <pr>(#)</pr>.</plu> <ety>[L.
<ets>diarium</ets>, fr. <ets>dies</ets> day. See <er>Deity</er>.]</ety>
<def>A register of daily events or transactions; a daily record; a
journal; a blank book dated for the record of daily memoranda; <as>as, a
<ex>diary</ex> of the weather; a physician's
<ex>diary</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diary</ent><br/
<hw>Di"a*ry</hw>, <pos>a.</pos> <def>lasting for one day; <as>as, a
<ex>diary</ex> fever</as>.</def> <mark>[Obs.]</mark>
<ldquo/<xex>Diary</xex> ague.<rdquo/ <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diaspora</ent><br/
\'d8<hw>Di*as"po*ra</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/. See
<er>Diaspore</er>.]</ety> <def>Lit., <ldquo/Dispersion.<rdquo/ --
applied collectively: (<it>a</it>) To those Jews who, after the Exile,
were scattered through the Old World, and afterwards to Jewish
Christians living among heathen. Cf. <au>James i. 1</au>. (<it>b</it>)
By extension, to Christians isolated from their own communion, as among
the Moravians to those living, usually as missionaries, outside of the
parent congregation.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Diaspore</ent><br/
<hw>Di"a*spore</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From Gr. <?/ a
scattering; <grk>dia`</grk> through, asunder + <?/ to sow, scatter like
seed: cf. F. <ets>diaspore</ets>.]</ety> <fld>(Min.)</fld> <def>A
hydrate of alumina, often occurring in white lamellar masses with
brilliant pearly luster; -- so named on account of its decrepitating
when heated before the blowpipe.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diastase</ent><br/
<hw>Di"a*stase</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/
separation, fr. <?/, <?/ to stand apart; <grk>dia`</grk> through + <?/,
<?/, to stand, set: cf. F. <ets>diastase</ets>. Cf.
<er>Diastasis</er>.]</ety> <fld>(Physiol. Chem.)</fld> <def>A soluble
enzyme, capable of converting starch and dextrin into sugar.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The name is more particularly applied to that enzyme
formed during the germination of grain, as in the malting of barley; but
it is also occasionally used to designate the amylolytic enzyme
contained in animal fluids, as in the saliva.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diastasic</ent><br/
<hw>Di`a*sta"sic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to, or
consisting of, diastase; <as>as, <ex>diastasic</ex>
ferment</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diastasis</ent><br/
\'d8<hw>Di*as"ta*sis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. See
<er>Diastase</er>.]</ety> <fld>(Surg.)</fld> <def>A forcible separation
of bones without fracture.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diastatic</ent><br/
<hw>Di`a*stat"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/
separative. See <er>Diastase</er>.]</ety> <fld>(Physiol. Chem.)</fld>
<def>Relating to diastase; having the properties of diastase; effecting
the conversion of starch into sugar.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The influence of acids and alkalies on the <qex>diastatic</qex>
action of saliva.</q> <rj><qau>Lauder Brunton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diastem</ent><br/
<hw>Di"a*stem</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>diastema</ets>, Gr. <?/, fr. <?/: cf. F.
<ets>diast<egrave/me</ets>.]</ety> <sd>(a)</sd> <def>Intervening space;
interval.</def> <sd>(b)</sd> <fld>(Anc. Mus.)</fld> <def>An
interval.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diastema</ent><br/
\'d8<hw>Di`a*ste"ma</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. See
<er>Diastem</er>.]</ety> <fld>(Anat.)</fld> <def>A vacant space, or gap,
esp. between teeth in a jaw.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diaster</ent><br/
<hw>Di*as"ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <grk>di-</grk>
= <grk>di`s-</grk> twice + <?/ star.]</ety> <fld>(Biol.)</fld> <def>A
double star; -- applied to the nucleus of a cell, when, during cell
division, the loops of the nuclear network separate into two groups,
preparatory to the formation of two daughter nuclei. See
<er>Karyokinesis</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diastole</ent><br/
\'d8<hw>Di*as"to*le</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., fr. Gr.
<?/, fr. <?/ to put asunder, to separate; <grk>dia`</grk> through + <?/
to set, to place.]</ety> <sn>1.</sn> <fld>(Physiol.)</fld> <def>The
rhythmical expansion or dilatation of the heart and arteries; --
correlative to <contr>systole</contr>, or contraction.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Gram.)</fld> <def>A figure by which a syllable
naturally short is made long.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diastolic</ent><br/
<hw>Di`as*tol"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Physiol.)</fld>
<def>Of or pertaining to diastole.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diastyle</ent><br/
<hw>Di"a*style</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>diastylus</ets>, Gr. <?/; <grk>dia`</grk> through, asunder + <?/
pillar, column: cf. F. <ets>diastyle</ets>.]</ety> <fld>(Arch.)</fld>
<def>See under <er>Intercolumniation</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diatessaron</ent><br/
\'d8<hw>Di`a*tes"sa*ron</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., fr.
Gr. <?/ (sc. <?/); <grk>dia`</grk> through + <?/, gen. of <?/ four (sc.
<?/.).]</ety> <sn>1.</sn> <fld>(Anc. Mus.)</fld> <def>The interval of a
fourth.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Theol.)</fld> <def>A continuous narrative arranged
from the first four books of the New Testament.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>An electuary compounded of four medicines.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diathermal</ent><br/
<hw>Di`a*ther"mal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/
thoroughly warm; <grk>dia`</grk> through + <?/ warm, hot. Cf.
<er>Diathermous</er>.]</ety> <def>Freely permeable by radiant
heat.</def></p>

<p><ent>Diathermaneity</ent><br/
<ent>Diathermancy</ent><br/
<mhw>{ <hw>Di`a*ther"man*cy</hw> <pr>(?)</pr>,
<hw>Di`a*ther`ma*ne"i*ty</hw> <pr>(?)</pr>, }</mhw> <pos>n.</pos>
<ety>[See <er>Diathermanous</er>.]</ety> <def>The property of
transmitting radiant heat; the quality of being diathermous.</def>
<rj><au>Melloni.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diathermanism</ent><br/
<hw>Di`a*ther"ma*nism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The doctrine
or the phenomena of the transmission of radiant heat.</def>
<rj><au>Nichol.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diathermanous</ent><br/
<hw>Di`a*ther"ma*nous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/ to
warm through; <grk>dia`</grk> through + <?/ to warm, <?/ warm.]</ety>
<def>Having the property of transmitting radiant heat; diathermal; --
opposed to <contr>athermanous</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diathermic</ent><br/
<hw>Di`a*ther"mic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Affording a free
passage to heat; <as>as, <ex>diathermic</ex> substances</as>.</def>
<rj><au>Melloni.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diathermometer</ent><br/
<hw>Di`a*ther*mom"e*ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/
warm + <ets>-meter</ets>. See <er>Diathermal</er>.]</ety>
<fld>(Physics)</fld> <def>An instrument for examining the thermal
resistance or heat-conducting power of liquids.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diathermous</ent><br/
<hw>Di`a*ther"mous</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Same as
<er>Diathermal</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diathesis</ent><br/
\'d8<hw>Di*ath"e*sis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<?/, fr. <?/ to place separately, arrange; <grk>dia`</grk> through,
asunder + <?/ to place, put.]</ety> <fld>(Med.)</fld> <def>Bodily
condition or constitution, esp. a morbid habit which predisposes to a
particular disease, or class of diseases.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diathetic</ent><br/
<hw>Di`a*thet"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to, or
dependent on, a diathesis or special constitution of the body; <as>as,
<ex>diathetic</ex> disease</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diatom</ent><br/
<hw>Di"a*tom</hw> <pr>(d<imac/`<adot/*t<ocr/m)</pr>, <pos>n.</pos>
<ety>[Gr. <grk>dia`tomos</grk> cut in two. See
<er>Diatomous</er>.]</ety> <sn>1.</sn> <fld>(Bot.)</fld> <def>One of the
<fam>Diatomace<ae/</fam>, a family of minute unicellular Alg<ae/ having
a siliceous covering of great delicacy, each individual multiplying by
spontaneous division. By some authors diatoms are called
<altname>Bacillari<ae/</altname>, but this word is not in general
use.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A particle or atom endowed with the vital
principle.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The individual is nothing. He is no more than the
<qex>diatom</qex>, the bit of protoplasm.</q> <rj><qau>Mrs. E. Lynn
Linton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>diatomaceous</ent><br/
<hw>di`a*to*ma"ceous</hw>
<pr>(d<imac/`<adot/*t<osl/*m<amac/"sh<ucr/s)</pr>, <pos>a.</pos>
<ety>[See <er>Diatomous</er>.]</ety> <def>consisting of or containing
diatoms or their fossils; <as>as, <ex>diatomaceous</ex> earth (used as a
component of dynamite)</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>diatomaceous earth</ent><br/
<hw>di`a*to*ma"ceous earth`</hw> <fld>(Geol.)</fld>, <def>a deposit of
fine, usually white, siliceous material, composed mainly of the shells
of the microscopic plants called <compof>diatoms</compof>; also called
<altname>infusorial earth</altname>, <altname>kieselguhr</altname>, and
<altname>diatomite</altname>. It is used in polishing powder, and in the
manufacture of dynamite.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>diatomic</ent><br/
<hw>di`a*tom"ic</hw> <pr>(d<imac/`<adot/*t<ocr/m"<icr/k)</pr>,
<pos>a.</pos> <ety>[Pref. <ets>di-</ets> + <ets>atomic</ets>.]</ety>
<fld>(Chem.)</fld> <sd>(a)</sd> <def>Containing two atoms.</def>
<sd>(b)</sd> <def>Having two replaceable atoms or radicals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diatomophyceae</ent><br/
<hw>Diatomophyceae</hw> <pos>n.</pos> <def>a class of marine and
freshwater eukaryotic algae comprising the diatoms.</def><br/
<syn><b>Syn. --</b> Bacillariophyceae, class
<class>Bacillariophyceae</class>, class
<class>Diatomophyceae</class>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Diatomous</ent><br/
<hw>Di*at"o*mous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>dia`tomos</grk> cut through, fr. <grk>diate`mnein</grk> to cut
through; <grk>dia`</grk> through + <grk>te`mnein</grk> to cut. Cf.
<er>Diatom</er>.]</ety> <fld>(Min.)</fld> <def>Having a single,
distinct, diagonal cleavage; -- said of crystals.</def>
<rj><au>Mohs.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diatonic</ent><br/
<hw>Di`a*ton"ic</hw> <pr>(d<imac/`<adot/*t<ocr/n"<icr/k)</pr>,
<pos>a.</pos> <ety>[L. <ets>diatonicus</ets>, <ets>diatonus</ets>, Gr.
<?/, <?/, fr. <?/ to stretch out; <grk>dia`</grk> through + <?/ to
stretch: cf. F. <ets>diatonique</ets>. See <er>Tone</er>.]</ety>
<fld>(Mus.)</fld> <def>Pertaining to the scale of eight tones, the
eighth of which is the octave of the first.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Diatonic scale</b></col> <fld>(Mus.)</fld>, <cd>a scale
consisting of eight sounds with seven intervals, of which two are
semitones and five are whole tones; a modern major or minor scale, as
distinguished from the <contr>chromatic</contr> scale.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diatonically</ent><br/
<hw>Di`a*ton"ic*al*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a
diatonic manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diatribe</ent><br/
<hw>Di"a*tribe</hw> <pr>(?; 277)</pr>, <pos>n.</pos> <ety>[L.
<ets>diatriba</ets> a learned discussion, Gr. <?/, prop., a wearing away
of time, fr. <?/ to rub away, spend time; <grk>dia`</grk> through + <?/
to rub: cf. L. <ets>terere</ets>, F. <ets>trite</ets>: cf. F.
<ets>diatribe</ets>.]</ety> <def>A prolonged or exhaustive discussion;
especially, an acrimonious or invective harangue; a strain of abusive or
railing language; a philippic.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The ephemeral <qex>diatribe</qex> of a faction.</q> <rj><qau>John
Morley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diatribist</ent><br/
<hw>Di*at"ri*bist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who makes a
diatribe or diatribes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diatryma</ent><br/
\'d8<hw>Di`a*try"ma</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., from Gr.
<grk>dia`</grk> through + <?/ hole.]</ety> <fld>(Paleon.)</fld> <def>An
extinct eocene bird from New Mexico, larger than the ostrich.</def></p>

<p><ent>Diazeutic</ent><br/
<ent>Diazeuctic</ent><br/
<mhw>{ <hw>Di`a*zeuc"tic</hw> <pr>(?)</pr>, <hw>Di`a*zeu"tic</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[Gr. <?/ disjunctive, fr. <?/
to disjoin; <grk>dia`</grk> through, asunder + <?/ to join, yoke.]</ety>
<fld>(Anc. Mus.)</fld> <def>Disjoining two fourths; <as>as, the
<ex>diazeutic</ex> tone, which, like that from F to G in modern music,
lay between two fourths, and, being joined to either, made a
fifth</as>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diazo-</ent><br/
<hw>Di*az"o-</hw> <pr>(<?/)</pr>. <ety>[Pref. <ets>di-</ets> +
<ets>azo-</ets>]</ety> <fld>(Chem.)</fld> <def>A combining form (also
used adjectively), meaning <xex>pertaining to</xex>, or <xex>derived
from</xex>, a series of compounds containing a radical of <sig>two
nitrogen atoms</sig>, united usually to an aromatic radical; <as>as,
<ex>diazo-</ex>benzene, <chform>C6H5.N2.OH</chform></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Diazo compounds</xex> are in general unstable, but
are of great importance in recent organic chemistry. They are obtained
by a partial reduction of the salts of certain amido
compounds.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Diazo reactions</b></col> <fld>(Chem.)</fld>, <cd>a
series of reactions whereby diazo compounds are employed in
substitution. These reactions are of great importance in organic
chemistry.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diazotize</ent><br/
<hw>Di*az"o*tize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <fld>(Chem.)</fld>
<def>To subject to such reactions or processes that diazo compounds, or
their derivatives, shall be produced by chemical exchange or
substitution.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dib</ent><br/
<hw>Dib</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To dip.</def>
<mark>[Prov. Eng.]</mark> <rj><au>Walton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dib</ent><br/
<hw>Dib</hw>, <pos>n.</pos> <sn>1.</sn> <def>One of the small bones in
the knee joints of sheep uniting the bones above and below the
joints.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <pluf>pl.</pluf> <def>A child's game, played with dib
bones.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dibasic</ent><br/
<hw>Di*ba"sic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>di-</ets> + <ets>basic</ets>.]</ety> <fld>(Chem.)</fld> <def>Having
two acid hydrogen atoms capable of replacement by basic atoms or
radicals, in forming salts; bibasic; -- said of acids, as oxalic or
sulphuric acids. Cf. <er>Diacid</er>, <er>Bibasic</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In the case of certain acids <xex>dibasic</xex> and
<xex>divalent</xex> are not synonymous; as, tartaric acid is
<xex>tetravalent</xex> and <xex>dibasic</xex>, lactic acid is
<xex>divalent</xex> but <xex>monobasic</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dibasicity</ent><br/
<hw>Di`ba*sic"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>The property or condition of being dibasic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dibber</ent><br/
<hw>Dib"ber</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A dibble.</def>
<rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dibble</ent><br/
<hw>Dib"ble</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See <er>Dibble</er>,
<pos>v. i.</pos>]</ety> <def>A pointed implement used to make holes in
the ground in which no set out plants or to plant seeds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dibble</ent><br/
<hw>Dib"ble</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Dibbled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Dibbling</conjf> <pr>(?)</pr>.]</vmorph> <ety>[Freq. of Prov. E.
<ets>dib</ets>, for <ets>dip</ets> to thrust in. See
<er>Dip</er>.]</ety> <def>To dib or dip frequently, as in angling.</def>
<rj><au>Walton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dibble</ent><br/
<hw>Dib"ble</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To plant with a
dibble; to make holes in (soil) with a dibble, for planting.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To make holes or indentations in, as if with a
dibble.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The clayey soil around it was <qex>dibbled</qex> thick at the time
by the tiny hoofs of sheep.</q> <rj><qau>H. Miller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dibbler</ent><br/
<hw>Dib"bler</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, dibbles, or makes holes in the ground for seed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>dibrach</ent><br/
<hw>dibrach</hw> <pos>n.</pos> <fld>(Prosody)</fld> <def>a foot of two
short (unstressed-unstressed) syllables.</def><br/
<syn><b>Syn. --</b> pyrrhic.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>dibranch</ent><br/
<hw>dibranch</hw> <pos>n.</pos> <def>a cephalopod having two gills; a
member of the <ord>Dibranchiata</ord>.</def><br/
<syn><b>Syn. --</b> dibranchiate, dibranchiate mollusk.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Dibranchia</ent><br/
<hw>Dibranchia</hw> <pos>n.</pos> <sn>1.</sn> <def>comprising all living
cephalopods except the family Nautilidae: the orders Octopoda
(octopuses) and Decapoda (squids and cuttlefish).</def><br/
<syn><b>Syn. --</b> Dibranchiata, subclass ta, Dibranchia, subclass
Dibranchia.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dibranchiata</ent><br/
\'d8<hw>Di*bran`chi*a"ta</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
fr. Gr. <grk>di-</grk> = <grk>di`s-</grk> twice + <?/ gills.]</ety>
<fld>(Zool.)</fld> <def>An order of cephalopods which includes those
with two gills, an apparatus for emitting an inky fluid, and either
eight or ten cephalic arms bearing suckers or hooks, as the octopi and
squids. See <er>Cephalopoda</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dibranchiate</ent><br/
<hw>Di*bran"chi*ate</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Having two gills.</def> -- <def2><pos>n.</pos> <def>One of the
Dibranchiata.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 408 --></p>

<p><ent>dibs</ent><br/
<hw>dibs</hw> <pr>(d<icr/bz)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A
sweet preparation or treacle of grape juice, much used in the
East.</def> <rj><au>Johnston.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A small amount of money.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>A right or claim, such as the right of use, or of
first choice; <as>as, I have <ex>dibs</ex> on the binoculars after Jim
is finished.</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>dibstone</ent><br/
<hw>dib"stone`</hw> <pr>(d<icr/b"st<omac/n`; 110)</pr>, <pos>n.</pos>
<def>A pebble used in a child's game called <xex>dibstones</xex>.</def>
<rj><au>Locke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>dibutyl</ent><br/
<hw>di*bu"tyl</hw> <pr>(d<isl/*b<umac/"t<icr/l)</pr>, <pos>n.</pos>
<ety>[Pref. <ets>di-</ets> + <ets>butyl</ets>.]</ety> <fld>(Chem.)</fld>
<def>A liquid hydrocarbon, <chform>C8H18</chform>, of the alkane series,
being one of several octanes, and consisting of two butyl radicals. Cf.
<er>Octane</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>dicacious</ent><br/
<hw>di*ca"cious</hw> <pr>(d<icr/*k<amac/"sh<ucr/s)</pr>, <pos>a.</pos>
<ety>[L. <ets>dicax</ets>, <ets>dicacis</ets>, fr. <ets>dicere</ets> to
say.]</ety> <def>Talkative; pert; saucy.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>dicacity</ent><br/
<hw>di*cac"i*ty</hw> <pr>(d<icr/*k<acr/s"<icr/*t<ycr/)</pr>,
<pos>n.</pos> <ety>[L. <ets>dicacitas</ets>: cf. F.
<ets>dicacit<eacute/</ets>. See <er>Dicacious</er>.]</ety>
<def>Pertness; sauciness.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>dicalcic</ent><br/
<hw>di*cal"cic</hw> <pr>(d<isl/*k<acr/l"s<icr/k)</pr>, <pos>a.</pos>
<ety>[Pref. <ets>di-</ets> + <ets>calcic</ets>.]</ety>
<fld>(Chem.)</fld> <def>Having two atoms or equivalents of calcium to
the molecule.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>dicarbonic</ent><br/
<hw>di`car*bon"ic</hw> <pr>(d<imac/`k<aum/r*b<ocr/n"<icr/k)</pr>,
<pos>a.</pos> <ety>[Pref. <ets>di-</ets> + <ets>carbonic</ets>.]</ety>
<fld>(Chem.)</fld> <def>Containing two carbon residues, or two carboxyl
groups or radicals; <as>as, oxalic acid is the simplest
<ex>dicarbonic</ex> acid</as>. In the latter sense, synonymous with
<altname>dicarboxylic</altname>; <as>as, succinic acid is a
<altname>dicarboxylic</altname> acid</as>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>dicast</ent><br/
<hw>di"cast</hw> <pr>(d<imac/"k<adot/st)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>dikasth`s</grk>, fr. <grk>dika`zein</grk> to judge,
<grk>di`kh</grk> right, judgment, justice.]</ety> <def>A functionary in
ancient Athens resembling closely to the modern juryman.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>dicastery</ent><br/
<hw>di*cas"ter*y</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>dikasth`rion</grk>, fr. <grk>dikasth`s</grk> juryman. See
<er>Dicast</er>.]</ety> <def>A court of justice; judgment hall.</def>
<mark>[R.]</mark> <rj><au>J. S. Mill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>dice</ent><br/
<hw>dice</hw> <pr>(d<imac/s)</pr>, <pos>n.</pos>; <plu><it>pl.</it> of
<plw>Die</plw>.</plu> <def>Small cubes used in gaming or in determining
by chance; also, the game played with dice. See <er>Die</er>,
<pos>n.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>dice coal</b></col>, <cd>a kind of coal easily splitting
into cubical fragments.</cd> <rj><au>Brande & C.</au></rj> </cs> <--
Illustr. of Dice. --><br/
[<source>1913 Webster</source>]</p>

<p><ent>dice</ent><br/
<hw>dice</hw> <pr>(d<imac/s)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>diced</conjf> <pr>(d<imac/st)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>dicing</conjf>.]</vmorph> <def>To play games with
dice.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I . . . <qex>diced</qex> not above seven times a week.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>dice</ent><br/
<hw>dice</hw> <pr>(d<imac/s)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Diced</conjf> <pr>(d<imac/st)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Dicing</conjf>.]</vmorph> <sn>1.</sn>
<fld>(Cooking)</fld> <def>To cut into small cubes; <as>as, to slice and
<ex>dice</ex> carrots</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>To ornament with squares, diamonds, or
cubes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>dicebox</ent><br/
<hw>dice"box`</hw> <pr>(d<imac/s"b<ocr/ks`)</pr>, <pos>n.</pos> <def>A
box from which dice are thrown in gaming.</def>
<rj><au>Thackeray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dicentra</ent><br/
\'d8<hw>Di*cen"tra</hw> <pr>(d<isl/*s<ecr/n"tr<adot/)</pr>, <pos>Prop.
n.</pos> <ety>[NL., fr. Gr. <grk>di-</grk> = <grk>di`s-</grk> twice +
<grk>ke`ntron</grk> spur.]</ety> <fld>(Bot.)</fld> <def>A genus of
herbaceous plants, with racemes of two-spurred or heart-shaped flowers,
including the <stype>Dutchman's breeches</stype>, and the more showy
<stype>Bleeding heart</stype> (<spn>Dicentra spectabilis</spn>).</def>
<altsp>[Corruptly written <asp>dielytra</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>dicephalous</ent><br/
<hw>di*ceph"a*lous</hw> <pr>(d<isl/*s<ecr/f"<adot/*l<ucr/s)</pr>,
<pos>a.</pos> <ety>[Gr. <grk>dike`falos</grk>; <grk>di-</grk> =
<grk>di`s-</grk> twice + <grk>kefalh`</grk> head.]</ety> <def>Having two
heads on one body; double-headed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dicer</ent><br/
<hw>Di"cer</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A player at dice; a
dice player; a gamester.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>As false as <qex>dicers'</qex> oaths.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dich</ent><br/
<hw>Dich</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To ditch.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dichastic</ent><br/
<hw>Di*chas"tic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/ to part
asunder, fr. <?/ in two, asunder, fr. <grk>di`s-</grk> twice.]</ety>
<fld>(Biol.)</fld> <def>Capable of subdividing spontaneously.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dichlamydeous</ent><br/
<hw>Di`chla*myd"e*ous</hw>
<pr>(d<imac/`kl<adot/*m<icr/d"<esl/*<ucr/s)</pr>, <pos>a.</pos>
<ety>[Gr. <grk>di-</grk> = <grk>di`s-</grk> twice + <grk>chlamy`s</grk>,
<grk>chlamy`dos</grk>, a cloak.]</ety> <fld>(Bot.)</fld> <def>Having two
coverings, a calyx and a corolla.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dichloride</ent><br/
<hw>Di*chlo"ride</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>di-</ets> + <ets>chloride</ets>.]</ety> <fld>(Chem.)</fld>
<def>Same as <er>Bichloride</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dichogamous</ent><br/
<hw>Di*chog"a*mous</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Bot.)</fld>
<def>Manifesting dichogamy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dichogamy</ent><br/
<hw>Di*chog"a*my</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ in two,
asunder + <?/ marriage.]</ety> <fld>(Bot.)</fld> <def>The condition of
certain species of plants, in which the stamens and pistil do not mature
simultaneously, so that these plants can never fertilize
themselves.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dichotomist</ent><br/
<hw>Di*chot"o*mist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
dichotomizes.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dichotomize</ent><br/
<hw>Di*chot"o*mize</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Dichotomized</conjf>
<pr>(?)</pr>; <pos>p. pr. & vb. n.</pos> <conjf>Dichotomizing</conjf>
<pr>(?)</pr>.]</vmorph> <ety>[See <er>Dichotomous</er>.]</ety>
<sn>1.</sn> <def>To cut into two parts; to part into two divisions; to
divide into pairs; to bisect.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The apostolical benediction <qex>dichotomizes</qex> all good
things into grace and peace.</q> <rj><qau>Bp. Hall.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Astron.)</fld> <def>To exhibit as a half disk. See
<er>Dichotomy</er>, 3.</def> <ldquo/[The moon] was
<xex>dichotomized</xex>.<rdquo/ <rj><au>Whewell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dichotomize</ent><br/
<hw>Di*chot"o*mize</hw>, <pos>v. i.</pos> <def>To separate into two
parts; to branch dichotomously; to become dichotomous.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dichotomous</ent><br/
<hw>Di*chot"o*mous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>dichotomos</ets>, Gr. <?/; <?/ in two, asunder +
<grk>diate`mnein</grk> to cut.]</ety> <def>Regularly dividing by pairs
from bottom to top; <as>as, a <ex>dichotomous</ex> stem</as>.</def> --
<wordforms><wf>Di*chot"o*mous*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dichotomy</ent><br/
<hw>Di*chot"o*my</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/, fr.
<?/: cf. F. <ets>dichotomie</ets>. See <er>Dichotomous</er>.]</ety>
<sn>1.</sn> <def>A cutting in two; a division.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A general breach or <qex>dichotomy</qex> with their church.</q>
<rj><qau>Sir T. Browne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Division or distribution of genera into two species;
division into two subordinate parts.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Astron.)</fld> <def>That phase of the moon in which
it appears bisected, or shows only half its disk, as at the
quadratures.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Biol.)</fld> <def>Successive division and
subdivision, as of a stem of a plant or a vein of the body, into two
parts as it proceeds from its origin; successive bifurcation.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>The place where a stem or vein is forked.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Logic)</fld> <def>Division into two; especially,
the division of a class into two subclasses opposed to each other by
contradiction, as the division of the term <xex>man</xex> into
<xex>white</xex> and <xex>not white</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dichroic</ent><br/
<hw>Di*chro"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Dichroism</er>.]</ety> <def>Having the property of dichroism;
<as>as, a <ex>dichroic</ex> crystal</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dichroiscope</ent><br/
<hw>Di*chro"i*scope</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Dichroscope</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dichroism</ent><br/
<hw>Di"chro*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/
two-colored; <grk>di-</grk> = <grk>di`s-</grk> twice + <?/ color.]</ety>
<fld>(Opt.)</fld> <def>The property of presenting different colors by
transmitted light, when viewed in two different directions, the colors
being unlike in the direction of unlike or unequal axes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dichroite</ent><br/
<hw>Di"chro*ite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Dichroism</er>.]</ety> <fld>(Min.)</fld> <def>Iolite; -- so called
from its presenting two different colors when viewed in two different
directions. See <er>Iolite</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dichroitic</ent><br/
<hw>Di`chro*it"ic</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Dichroic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dichromate</ent><br/
<hw>Di*chro"mate</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>A salt of chromic acid containing two equivalents of the acid
radical to one of the base; -- called also
<altname>bichromate</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dichromatic</ent><br/
<hw>Di`chro*mat"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>di-</ets> + <ets>chromatic</ets>: cf. Gr. <?/.]</ety> <sn>1.</sn>
<def>Having or exhibiting two colors.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>Having two color varieties, or
two phases differing in color, independently of age or sex, as in
certain birds and insects.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dichromatism</ent><br/
<hw>Di*chro"ma*tism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state of
being dichromatic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dichromic</ent><br/
<hw>Di*chro"mic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/
two-colored; <grk>di-</grk> = <grk>di`s-</grk> twice + <?/ color.]</ety>
<def>Furnishing or giving two colors; -- said of defective vision, in
which all the compound colors are resolvable into two elements instead
of three.</def> <rj><au>Sir J. Herschel.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dichroous</ent><br/
<hw>Di"chro*ous</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Dichroic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dichroscope</ent><br/
<hw>Di"chro*scope</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>di-</grk> = <grk>di`s-</grk> twice + <?/ color + <?/ to
view.]</ety> <def>An instrument for examining the dichroism of
crystals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dichroscopic</ent><br/
<hw>Di`chro*scop"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to
the dichroscope, or to observations with it.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dicing</ent><br/
<hw>Di"cing</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>An
ornamenting in squares or cubes.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Gambling with dice.</def> <rj><au>J. R.
Green.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dickcissel</ent><br/
<hw>Dick*cis"sel</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>The American black-throated bunting (<spn>Spiza
Americana</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dickens</ent><br/
<hw>Dick"ens</hw> <pr>(?)</pr>, <pos>n. <or/ interj.</pos> <ety>[Perh. a
contr. of the dim. <ets>devilkins</ets>.]</ety> <def>The devil.</def>
<mark>[A vulgar euphemism.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I can not tell what the <qex>dickens</qex> his name is.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dicker</ent><br/
<hw>Dick"er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Also
<ets>daker</ets>, <ets>dakir</ets>; akin to Icel. <ets>dekr</ets>, Dan.
<ets>deger</ets>, G. <ets>decher</ets>; all prob. from LL.
<ets>dacra</ets>, <ets>dacrum</ets>, the number ten, akin to L.
<ets>decuria</ets> a division consisting of ten, fr. <ets>decem</ets>
ten. See <er>Ten</er>.]</ety> <sn>1.</sn> <def>The number or quantity of
ten, particularly ten hides or skins; a dakir; <as>as, a <ex>dicker</ex>
of gloves</as>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>dicker</qex> of cowhides.</q>
<rj><qau>Heywood.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A chaffering, barter, or exchange, of small wares;
<as>as, to make a <ex>dicker</ex></as>.</def> <mark>[U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>For peddling <qex>dicker</qex>, not for honest sales.</q>
<rj><qau>Whittier.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dicker</ent><br/
<hw>Dick"er</hw>, <pos>v. i. & t.</pos> <def>To negotiate a dicker; to
barter.</def> <mark>[U.S.]</mark> <ldquo/Ready to <xex>dicker</xex>. and
to swap.<rdquo/ <rj><au>Cooper.</au></rj></p>

<p><ent>Dicky</ent><br/
<ent>Dickey</ent><br/
<mhw>{ <hw>Dick"ey</hw>, <hw>Dick"y</hw> }</mhw> <pr>(?)</pr>,
<pos>n.</pos> <sn>1.</sn> <sn>1.</sn> <def>A false detachable shirt
front or bosom.</def> <altsp>[Also spelled
<asp>dickie</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A gentleman's shirt collar.</def> <mark>[Local, U.
S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A hat; esp., in U. S., a stiff hat or derby; in
Eng., a straw hat.</def> <mark>[Slang]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>4.</sn> <sd>(a)</sd> <def>A seat for the driver (In a carriage);
-- called also <ecol><b>dickey box</b></ecol> or <ecol><b>dickie
seat</b></ecol>.</def> <sd>(b)</sd> <def>A seat at the back for
servants.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>5.</sn> <def>One of various animals</def>;
<specif>specif.:</specif> <sd>(a)</sd> <def>A donkey.</def> <sd>(b)</sd>
<def>Any small bird; -- called also <altname>dickeybird</altname> or
<altname>dickey bird</altname>.</def> <mark>[Colloq.]</mark>
<sd>(c)</sd> <def>The hedge sparrow.</def> <mark>[Dial. Eng.]</mark>
<sd>(d)</sd> <def>The haddock.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>dickey bird</ent><br/
<ent>dickeybird</ent><br/
<mhw><hw>dickeybird</hw>, <hw>dickey bird</hw></mhw> <pos>n.</pos>
<def>Any small bird; <as>as, adults talking to children sometimes call
small birds <ex>dickeybirds</ex></as>.</def> <mark>[informal]</mark><br/
<syn><b>Syn. --</b> dickybird.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>dickie</ent><br/
<hw>dickie</hw> <pos>n.</pos> <sn>1.</sn> <def>A small 3rd seat in the
back of an old-fashioned 2-seat car.</def> <mark>[British
English]</mark><br/
<syn><b>Syn. --</b> dickey, dicky, dickey-seat, dickie-seat, dicky-seat,
dickey box.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>An article of clothing worn by men, consisting of a
detachable insert (usually starched), worn suspended from the neck,
which simulates the front of a shirt.</def><br/
<syn><b>Syn. --</b> dickey, dicky, shirtfront.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>dickie-seat</ent><br/
<hw>dickie-seat</hw> <pos>n.</pos> <sn>1.</sn> <def>A small 3rd seat in
the back of an old-fashioned 2-seat car.</def> <mark>[British
English]</mark><br/
<syn><b>Syn. --</b> dickey, dickie, dicky, dickey-seat, dicky-seat,
dickey box.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dicksonia</ent><br/
<hw>Dicksonia</hw> <pos>prop. n.</pos> <def>A genus of tree ferns of
temperate Australasia having bipinnatifid or tripinnatifid fronds and
usually marginal sori; in some classification systems it is placed in
the family <fam>Cyatheaceae</fam>.</def><br/
<syn><b>Syn. --</b> genus <gen>Dicksonia</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dicksoniaceae</ent><br/
<hw>Dicksoniaceae</hw> <pos>prop. n.</pos> <sn>1.</sn> <def>A family of
plants comprising the tree ferns; it includes the genera
<gen>Dicksonia</gen>; <gen>Cibotium</gen>; <gen>Culcita</gen>; and
<gen>Thyrsopteris</gen>.</def><br/
<syn><b>Syn. --</b> family <fam>Dicksoniaceae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>dicky</ent><br/
<hw>dicky</hw> <pos>adj.</pos> <def>Faulty.</def> <mark>[British
informal]</mark><br/
<syn><b>Syn. --</b> dickey.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><q>I've got this <qex>dicky</qex> heart</q> <qau>John le
Carre</qau></p>

<p><ent>dicky</ent><br/
<hw>dicky</hw> <pos>n.</pos> <def>See <er>dickey</er>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>dickybird</ent><br/
<hw>dickybird</hw> <pos>n.</pos> <def>same as
<er>dickeybird</er>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>dicky-seat</ent><br/
<hw>dicky-seat</hw> <pos>n.</pos> <sn>1.</sn> <def>same as
<er>dickie-seat</er>.</def><br/
<syn><b>Syn. --</b> dickey, dickie, dicky, dickey-seat,
dickie-seat.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Diclinic</ent><br/
<hw>Di*clin"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <grk>di-</grk>
= <grk>di`s-</grk> twice + <?/ to incline.]</ety>
<fld>(Crystallog.)</fld> <def>Having two of the intersections between
the three axes oblique. See <er>Crystallization</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diclinous</ent><br/
<hw>Dic"li*nous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/ = <?/
bed.]</ety> <def>Having the stamens and pistils in separate
flowers.</def> <rj><au>Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dicoccous</ent><br/
<hw>Di*coc"cous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>di-</grk> = <grk>di`s-</grk> twice + <?/ grain, seed.]</ety>
<fld>(Bot.)</fld> <def>Composed of two coherent, one-seeded carpels;
<as>as, a <ex>dicoccous</ex> capsule</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>dicot</ent><br/
<hw>di"cot</hw> <pr>(d<imac/"k<ocr/t)</pr>, <pos>n.</pos> <ety>[by
shortening from <ets>dicotyledon</ets>.]</ety> <fld>(Bot.)</fld>
<def>same as <er>dicotyledon</er>.</def><br/
<syn><b>Syn. --</b> dicotyledon, dicotyl.</syn><br/
[<source>PJC</source>]</p>

<p><ent>dicotyl</ent><br/
<hw>di*cot"yl</hw> <pr>(d<isl/*k<ocr/t"'l)</pr>, <pos>n.</pos> <ety>[by
shortening from <ets>dicotyledon</ets>.]</ety> <fld>(Bot.)</fld>
<def>same as <er>dicotyledon</er>.</def><br/
<syn><b>Syn. --</b> dicotyledon, dicot.</syn><br/
[<source>PJC</source>]</p>

<p><ent>dicotyledon</ent><br/
<hw>di*cot`y*le"don</hw>
<pr>(d<isl/*k<ocr/t`<icr/*l<emac/"d<ucr/n)</pr>, <pos>n.</pos>
<ety>[Pref. <ets>di-</ets> + <ets>cotyledon</ets>.]</ety>
<fld>(Bot.)</fld> <def>A plant whose seeds divide into two seed lobes,
or cotyledons, in germinating.</def><br/
<syn><b>Syn. --</b> dicot, dicotyl.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dicotyledonae</ent><br/
<hw>Dicotyledonae</hw> <pos>n.</pos> <fld>(Bot.)</fld> <def>a class of
plants comprising those seed plants that produce an embryo with two
cotyledons and net-veined leaves; divided into six (not always well
distinguished) subclasses (or superorders):
<subclass><stype>Magnoliidae</stype></subclass> and
<subclass><stype>Hamamelidae</stype></subclass> (considered primitive);
<subclass><stype>Caryophyllidae</stype></subclass> (an early and
distinctive offshoot); and three more or less advanced groups:
<subclass><stype>Dilleniidae</stype></subclass>;
<subclass><stype>Rosidae</stype></subclass>;
<subclass><stype>Asteridae</stype></subclass>.</def><br/
<syn><b>Syn. --</b> Dicotyledones, class <class>Dicotyledones</class>,
class <class>Dicotyledonae</class>, Magnoliopsida, class
<class>Magnoliopsida</class>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dicotyledones</ent><br/
<hw>Dicotyledones</hw> <pos>n.</pos> <fld>(Bot.)</fld> <def>same as
<er>Dicotyledonae</er>.</def><br/
<syn><b>Syn. --</b> Dicotyledones, class <class>Dicotyledones</class>,
class <class>Dicotyledonae</class>, Magnoliopsida, class
<class>Magnoliopsida</class>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>dicotyledonous</ent><br/
<hw>di*cot`y*led"on*ous</hw>
<pr>(d<isl/*k<ocr/t`<icr/*l<ecr/d"<ucr/n*<ucr/s)</pr>, <pos>a.</pos>
<fld>(Bot.)</fld> <def>Having two cotyledons or seed lobes; <as>as, a
<ex>dicotyledonous</ex> plant</as>.</def></p>

<p><ent>Dicrotous</ent><br/
<ent>Dicrotal</ent><br/
<mhw>{ <hw>Di"cro*tal</hw> <pr>(?)</pr>, <hw>Di"cro*tous</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[Gr. <?/ a double
beating.]</ety> <def>Dicrotic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dicrotic</ent><br/
<hw>Di*crot"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/ = <?/ to
knock, beat.]</ety> <fld>(Physiol.)</fld> <sd>(a)</sd> <def>Of or
pertaining to dicrotism; <as>as, a <ex>dicrotic</ex> pulse</as>.</def>
<sd>(b)</sd> <def>Of or pertaining to the second expansion of the artery
in the dicrotic pulse; <as>as, the <ex>dicrotic</ex>
wave</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dicrotism</ent><br/
<hw>Di"cro*tism</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Physiol.)</fld>
<def>A condition in which there are two beats or waves of the arterial
pulse to each beat of the heart.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dicta</ent><br/
\'d8<hw>Dic"ta</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[L.]</ety>
<def>See <er>Dictum</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dictagraph</ent><br/
<hw>Dic"ta*graph</hw> <pr>(d<icr/k"t<adot/*gr<adot/f)</pr>. <def>Var. of
<er>Dictograph</er>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Dictamen</ent><br/
\'d8<hw>Dic*ta"men</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL., fr.
<ets>dictare</ets> to dictate.]</ety> <def>A dictation or dictate.</def>
<mark>[R.]</mark> <rj><au>Falkland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dictamnus</ent><br/
\'d8<hw>Dic*tam"nus</hw> <pr>(d<icr/k*t<acr/m"n<ucr/s)</pr>,
<pos>n.</pos> <ety>[L. See <er>Dittany</er>.]</ety> <fld>(Bot.)</fld>
<def>A suffrutescent herb, <spn>Dictamnus Fraxinella</spn> (the only
species), with strong perfume and showy flowers. The volatile oil of the
leaves is highly inflammable.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dictaphone</ent><br/
<hw>Dic"ta*phone</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Dicta</ets>te + <ets>-phone</ets>, as in
<ets>telephone</ets>.]</ety> <def>A form of phonographic recorder and
reproducer adapted for use in dictation, as in business.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Dictate</ent><br/
<hw>Dic"tate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Dictated</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Dictating</conjf>.]</vmorph> <ety>[L. <ets>dictatus</ets>, p. p.
of <ets>dictare</ets>, freq. of <ets>dicere</ets> to say. See
<er>Diction</er>, and cf. <er>Dight</er>.]</ety> <sn>1.</sn> <def>To
tell or utter so that another may write down; to inspire; to compose;
<as>as, to <ex>dictate</ex> a letter to an amanuensis</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The mind which <qex>dictated</qex> the Iliad.</q>
<rj><qau>Wayland.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Pages <qex>dictated</qex> by the Holy Spirit.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To say; to utter; to communicate authoritatively; to
deliver (a command) to a subordinate; to declare with authority; to
impose; <as>as, to <ex>dictate</ex> the terms of a treaty; a general
<ex>dictates</ex> orders to his troops.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Whatsoever is <qex>dictated</qex> to us by God must be
believed.</q> <rj><qau>Watts.</qau></rj></p>

<p><syn><b>Syn.</b> -- To suggest; prescribe; enjoin; command; point
out; urge; admonish.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dictate</ent><br/
<hw>Dic"tate</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To speak as a
superior; to command; to impose conditions (on).</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Who presumed to <qex>dictate</qex> to the sovereign.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To compose literary works; to tell what shall be
written or said by another.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Sylla could not skill of letters, and therefore knew not how to
<qex>dictate</qex>.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dictate</ent><br/
<hw>Dic"tate</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>dictatum</ets>. See <er>Dictate</er>, <pos>v. t.</pos>]</ety>
<def>A statement delivered with authority; an order; a command; an
authoritative rule, principle, or maxim; a prescription; <as>as, listen
to the <ex>dictates</ex> of your conscience; the <ex>dictates</ex> of
the gospel.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>I credit what the Grecian <qex>dictates</qex> say.</q>
<rj><qau>Prior.</qau></rj></p>

<p><syn><b>Syn.</b> -- Command; injunction; direction suggestion;
impulse; admonition.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dictation</ent><br/
<hw>Dic*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>dictatio</ets>.]</ety> <sn>1.</sn> <def>The act of dictating; the
act or practice of prescribing; also that which is dictated.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It affords security against the <qex>dictation</qex> of laws.</q>
<rj><qau>Paley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The speaking to, or the giving orders to, in an
overbearing manner; authoritative utterance; <as>as, his habit, even
with friends, was that of <ex>dictation</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dictator</ent><br/
<hw>Dic*ta"tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.]</ety>
<sn>1.</sn> <def>One who dictates; one who prescribes rules and maxims
authoritatively for the direction of others.</def>
<rj><au>Locke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One invested with absolute authority; especially, a
magistrate created in times of exigence and distress, and invested with
unlimited power.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Invested with the authority of a <qex>dictator</qex>, nay, of a
pope, over our language.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dictatorial</ent><br/
<hw>Dic`ta*to"ri*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>dictatorial</ets>.]</ety> <sn>1.</sn> <def>Pertaining or suited to
a dictator; absolute.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Military powers quite <qex>dictatorial</qex>.</q> <rj><qau>W.
Irving.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Characteristic of a dictator; imperious; dogmatical;
overbearing; <as>as, a <ex>dictatorial</ex> tone or
manner</as>.</def></p>

<p>-- <wordforms><wf>Dic`ta*to"ri*al*ly</wf>, <pos>adv.</pos> --
<wf>Dic`ta*to"ri*al*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dictatorian</ent><br/
<hw>Dic`ta*to"ri*an</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Dictatorial.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dictatorship</ent><br/
<hw>Dic*ta"tor*ship</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The office, or
the term of office, of a dictator; hence, absolute power.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dictatory</ent><br/
<hw>Dic"ta*to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>dictatorius</ets>.]</ety> <def>Dogmatical; overbearing;
dictatorial.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dictatress</ent><br/
<hw>Dic*ta"tress</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A woman who
dictates or commands.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Earth's chief <qex>dictatress</qex>, ocean's mighty queen.</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dictatrix</ent><br/
<hw>Dic*ta"trix</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.]</ety> <def>A
dictatress.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dictature</ent><br/
<hw>Dic*ta"ture</hw> <pr>(?; 135)</pr>, <pos>n.</pos> <ety>[L.
<ets>dictatura</ets>: cf. F. <ets>dictature</ets>.]</ety> <def>Office of
a dictator; dictatorship.</def> <mark>[R.]</mark>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diction</ent><br/
<hw>Dic"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>dicto</ets>
a saying, a word, fr. <ets>dicere</ets>, <ets>dictum</ets>, to say; akin
to <ets>dicare</ets> to proclaim, and to E. <ets>teach</ets>,
<ets>token</ets>: cf. F. <ets>diction</ets>. See <er>Teach</er>, and cf.
<er>Benison</er>, <er>Dedicate</er>, <er>Index</er>, <er>Judge</er>,
<er>Preach</er>, <er>Vengeance</er>.]</ety> <def>Choice of words for the
expression of ideas; the construction, disposition, and application of
words in discourse, with regard to clearness, accuracy, variety, etc.;
mode of expression; language; <as>as, the <ex>diction</ex> of Chaucer's
poems</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His <qex>diction</qex> blazes up into a sudden explosion of
prophetic grandeur.</q> <rj><qau>De Quincey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- <er>Diction</er>, <er>Style</er>,
<er>Phraseology</er>.</syn> <usage><xex>Style</xex> relates both to
language and thought; <xex>diction</xex>, to language only;
<xex>phraseology</xex>, to the mechanical structure of sentences, or the
mode in which they are <xex>phrased</xex>. The <xex>style</xex> of Burke
was enriched with all the higher graces of composition; his
<xex>diction</xex> was varied and copious; his <xex>phraseology</xex>,
at times, was careless and cumbersome. <ldquo/<xex>Diction</xex> is a
general term applicable alike to a single sentence or a connected
composition. Errors in grammar, false construction, a confused
disposition of words, or an improper application of them, constitute bad
<xex>diction</xex>; but the niceties, the elegancies, the peculiarities,
and the beauties of composition, which mark the genius and talent of the
writer, are what is comprehended under the name of
<xex>style</xex>.<rdquo/</usage> <rj><au>Crabb.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dictionalrian</ent><br/
<hw>Dic`tion*al"ri*an</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A
lexicographer.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dictionary</ent><br/
<hw>Dic"tion*a*ry</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Dictionaries</plw> <pr>(#)</pr>.</plu> <ety>[Cf. F.
<ets>dictionnaire</ets>. See <er>Diction</er>.]</ety> <sn>1.</sn> <def>A
book containing the words of a language, arranged alphabetically, with
explanations of their meanings; a lexicon; a vocabulary; a
wordbook.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I applied myself to the perusal of our writers; and noting
whatever might be of use to ascertain or illustrate any word or phrase,
accumulated in time the materials of a <qex>dictionary</qex>.</q>
<rj><qau>Johnson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence, a book containing the words belonging to any
system or province of knowledge, arranged alphabetically; <as>as, a
<ex>dictionary</ex> of medicine or of botany; a biographical
<ex>dictionary</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dictograph</ent><br/
<hw>Dic"to*graph</hw> <pr>(d<icr/k"t<osl/*gr<adot/f)</pr>, <pos>n.</pos>
<ety>[L. <ets>dictum</ets> a thing said + E. <ets>-graph</ets>.]</ety>
<def>A telephonic instrument for office or other similar use, having a
sound-magnifying device enabling the ordinary mouthpiece to be dispensed
with. Much use has been made of it for overhearing, or for recording,
conversations for the purpose of obtaining evidence for use in
litigation.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><note><hand/ The makers of this instrument spell it
<xex>dictograph</xex>.</note><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>dictostylium</ent><br/
<hw>dictostylium</hw> <pos>n.</pos> <sn>1.</sn> <def>any slime mold of
the genus Dictostylium.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dictum</ent><br/
\'d8<hw>Dic"tum</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it> L.
<plw>Dicta</plw> <pr>(#)</pr>, E. <plw>Dictums</plw> <pr>(#)</pr>.</plu>
<ety>[L., neuter of <ets>dictus</ets>, p. p. of <ets>dicere</ets> to
say. See <er>Diction</er>, and cf. <er>Ditto</er>.]</ety> <sn>1.</sn>
<def>An authoritative statement; a dogmatic saying; an
apothegm.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A class of critical <qex>dicta</qex> everywhere current.</q>
<rj><qau>M. Arnold.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <sd>(a)</sd> <def>A judicial opinion
expressed by judges on points that do not necessarily arise in the case,
and are not involved in it.</def> <sd>(b)</sd> <fld>(French Law)</fld>
<def>The report of a judgment made by one of the judges who has given
it.</def> <au>Bouvier.</au> <sd>(c)</sd> <def>An arbitrament or
award.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dictyogen</ent><br/
<hw>Dic*ty"o*gen</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ a net +
<ets>-gen</ets>.]</ety> <fld>(Bot.)</fld> <def>A plant with net-veined
leaves, and monocotyledonous embryos, belonging to the class
<class>Dictyogen<ae/</class>, proposed by Lindley for the orders
<ord>Dioscoreace<ae/</ord>, <ord>Smilace<ae/</ord>,
<ord>Trilliace<ae/</ord>, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dicyanide</ent><br/
<hw>Di*cy"a*nide</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>di-</ets> + <ets>cyan</ets>ogen.]</ety> <fld>(Chem.)</fld> <def>A
compound of a binary type containing two cyanogen groups or radicals; --
called also <altname>bicyanide</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dicyemata</ent><br/
\'d8<hw>Di`cy*e"ma*ta</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
fr. Gr. <grk>di-</grk> = <grk>di`s-</grk> twice + <?/ an embryo.]</ety>
<fld>(Zool.)</fld> <def>An order of worms parasitic in cephalopods. They
are remarkable for the extreme simplicity of their structure. The embryo
exists in two forms.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dicyemid</ent><br/
<hw>Di`cy*e"mid</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Like or belonging to the Dicyemata.</def> -- <def2><pos>n.</pos>
<def>One of the <ord>Dicyemata</ord>.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 409 --></p>

<p><ent>Dicynodont</ent><br/
<hw>Di*cyn"o*dont</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>di-</grk> = <grk>di`s-</grk> twice + <?/ dog + <grk>'odoy`s</grk>,
<grk>'odo`ntos</grk>, tooth.]</ety> <fld>(Paleon.)</fld> <def>One of a
group of extinct reptiles having the jaws armed with a horny beak, as in
turtles, and in the genus <gen>Dicynodon</gen>, supporting also a pair
of powerful tusks. Their remains are found in triassic strata of South
Africa and India.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Did</ent><br/
<hw>Did</hw> <pr>(?)</pr>, <def><pos>imp.</pos> of
<er>Do</er>.</def></p>

<p><ent>Didactical</ent><br/
<ent>Didactic</ent><br/
<mhw>{ <hw>Di*dac"tic</hw> <pr>(?)</pr>, <hw>Di*dac"tic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[Gr. <?/, fr. <?/ to teach;
akin to L. <ets>docere</ets> to teach: cf. F. <ets>didactique</ets>. See
<er>Docile</er>.]</ety> <sn>1.</sn> <def>Fitted or intended to teach;
conveying instruction; preceptive; instructive; teaching some moral
lesson; <as>as, <ex>didactic</ex> essays</as>.</def>
<ldquo/<xex>Didactical</xex> writings.<rdquo/ <rj><au>Jer.
Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The finest <qex>didactic</qex> poem in any language.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>excessively prone to instruct, even those who do not
wish to be instructed; -- of people.</def> <mark>[Pejorative]</mark><br/
<syn><b>Syn. --</b> didactic.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Didactic</ent><br/
<hw>Di*dac"tic</hw>, <pos>n.</pos> <def>A treatise on teaching or
education.</def> <mark>[Obs.]</mark> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Didactically</ent><br/
<hw>Di*dac"tic*al*ly</hw>, <pos>adv.</pos> <def>In a didactic
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Didacticism</ent><br/
<hw>Di*dac"ti*cism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The didactic
method or system.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Didacticity</ent><br/
<hw>Di`dac*tic"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Aptitude for
teaching.</def> <rj><au>Hare.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Didactics</ent><br/
<hw>Di*dac"tics</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The art or science
of teaching.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Didactyl</ent><br/
<hw>Di*dac"tyl</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <grk>di-</grk>
= <grk>di`s-</grk> twice + <?/ finger, toe: cf. F.
<ets>didactyle</ets>.]</ety> <fld>(Zool.)</fld> <def>An animal having
only two digits.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Didactylous</ent><br/
<hw>Di*dac"tyl*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Having only two digits; two-toed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Didal</ent><br/
<hw>Di"dal</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A kind of triangular
spade.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Didapper</ent><br/
<hw>Di"dap`per</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[For
<ets>divedapper</ets>. See <er>Dive</er>, <er>Dap</er>, <er>Dip</er>,
and cf. <er>Dabchick</er>.]</ety> <fld>(Zool.)</fld> <def>See
<er>Dabchick</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Didascalar</ent><br/
<hw>Di*das"ca*lar</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Didascalic.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Didascalic</ent><br/
<hw>Di`das*cal"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>didascalius</ets>, Gr. <?/, fr. <?/ to teach: cf. F.
<ets>didascalique</ets>.]</ety> <def>Didactic; preceptive.</def>
<mark>[R.]</mark> <rj><au>Prior.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diddle</ent><br/
<hw>Did"dle</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[Cf.
<er>Daddle</er>.]</ety> <def>To totter, as a child in walking.</def>
<mark>[Obs.]</mark> <rj><au>Quarles.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diddle</ent><br/
<hw>Did"dle</hw>, <pos>v. t.</pos> <ety>[Perh. from AS.
<ets>dyderian</ets> to deceive, the letter <it>r</it> being changed to
<it>l</it>.]</ety> <def>To cheat or overreach.</def>
<mark>[Colloq.]</mark> <rj><au>Beaconsfield.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diddler</ent><br/
<hw>Did"dler</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A cheat.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Jeremy Diddler</b></col>, <cd>a character in a play by
<person>James Kenney</person>, entitled <ldquo/Raising the wind.<rdquo/
The name is applied to any needy, tricky, constant borrower; a
confidence man.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Didelphia</ent><br/
\'d8<hw>Di*del"phi*a</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL., fr.
Gr. <?/ = <?/ matrix, uterus.]</ety> <fld>(Zool.)</fld> <def>The
subclass of Mammalia which includes the marsupials. See
<er>Marsupialia</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Didelphian</ent><br/
<hw>Di*del"phi*an</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Of or relating to the Didelphia.</def> -- <def2><pos>n.</pos>
<def>One of the Didelphia.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Didelphic</ent><br/
<hw>Di*del"phic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Having the uterus double; of or pertaining to the
Didelphia.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Didelphid</ent><br/
<hw>Di*del"phid</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Same as <er>Didelphic</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Didelphid</ent><br/
<hw>Di*del"phid</hw>, <pos>n.</pos> <fld>(Zool.)</fld> <def>A marsupial
animal.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Didelphous</ent><br/
<hw>Di*del"phous</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Didelphic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Didelphyc</ent><br/
<hw>Di*del"phyc</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Same as <er>Didelphic</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Didelphys</ent><br/
\'d8<hw>Di*del"phys</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. See
<er>Didelphia</er>.]</ety> <fld>(Zool.)</fld> <def>Formerly, any
marsupial; but the term is now restricted to an American genus which
includes the opossums, of which there are many species. See
<er>Opossum</er>. <altsp>[Written also <asp>Didelphis</asp>.]</altsp>
See <xex>Illustration</xex> in Appendix.</def>
<rj><au>Cuvier.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Didine</ent><br/
<hw>Di"dine</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Like or pertaining to the genus <gen>Didus</gen>, or the
dodo.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dido</ent><br/
<hw>Di"do</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Didos</plw> <pr>(<?/)</pr>.</plu> <def>A shrewd trick; an antic; a
caper.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To cut a dido</b></col>, <cd>to play a trick; to cut a
caper; -- perhaps so called from the trick of Dido, who having bought so
much land as a hide would cover, is said to have cut it into thin strips
long enough to inclose a spot for a citadel.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Didonia</ent><br/
\'d8<hw>Di*do"ni*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. So called
in allusion to the classical story of Dido and the bull's hide.]</ety>
<fld>(Geom.)</fld> <def>The curve which on a given surface and with a
given perimeter contains the greatest area.</def>
<rj><au>Tait.</au></rj></p>

<p><ent>Didrachma</ent><br/
<ent>Didrachm</ent><br/
<mhw>{ <hw>Di"drachm</hw> <pr>(?)</pr>, <hw>Di*drach"ma</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[Gr. <?/; <grk>di-</grk> =
<grk>di`s-</grk> twice + <?/ a drachm.]</ety> <def>A two-drachma piece;
an ancient Greek silver coin, worth nearly forty cents.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Didst</ent><br/
<hw>Didst</hw> <pr>(?)</pr>, <def>the <pos>2d pers. sing. imp.</pos> of
<er>Do</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diducement</ent><br/
<hw>Di*duce"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Diduction;
separation into distinct parts.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diduction</ent><br/
<hw>Di*duc"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>diductio</ets>, fr. <ets>diducere</ets>, <ets>diductum</ets>, to
draw apart; <ets>di-</ets> = <ets>dis-</ets> + <ets>ducere</ets> to
lead, draw.]</ety> <def>The act of drawing apart; separation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Didym</ent><br/
<hw>Di"dym</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld> <def>See
<er>Didymium</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Didymium</ent><br/
<hw>Di*dym"i*um</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr. <?/
twin.]</ety> <fld>(Chem.)</fld> <def>A rare metallic substance usually
associated with the metal cerium; -- hence its name. It was formerly
supposed to be an element, but has since been found to consist of two
simpler elementary substances, neodymium and praseodymium. See
<er>Neodymium</er>, and <er>Praseodymium</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Didymous</ent><br/
<hw>Did"y*mous</hw> <pr>(d<icr/d"<icr/*m<ucr/s)</pr>, <pos>a.</pos>
<ety>[Gr. <grk>di`dymos</grk> twofold, twin.]</ety> <fld>(Bot.)</fld>
<def>Growing in pairs or twins.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Didynamia</ent><br/
\'d8<hw>Did`y*na"mi*a</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
fr. Gr. <grk>di-</grk> = <grk>di`s-</grk> twice + <?/ power.]</ety>
<fld>(Bot.)</fld> <def>A Linn<ae/an class of plants having four stamens
disposed in pairs of unequal length.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Didynamian</ent><br/
\'d8<hw>Did`y*na"mi*an</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Didynamous.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Didynamous</ent><br/
<hw>Di*dyn"a*mous</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Bot.)</fld>
<def>Of or pertaining to the Didynamia; containing four stamens disposed
in pairs of unequal length.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Die</ent><br/
<hw>Die</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Died</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Dying</conjf>.]</vmorph> <ety>[OE. <ets>deyen</ets>,
<ets>dien</ets>, of Scand. origin; cf. Icel. <ets>deyja</ets>; akin to
Dan. <ets>d<oum/e</ets>, Sw. <ets>d<oum/</ets>, Goth. <ets>diwan</ets>
(cf. Goth. <ets>afd<?/jan</ets> to harass), OFries. <ets>d<?/ia</ets> to
kill, OS. <ets>doian</ets> to die, OHG. <ets>touwen</ets>, OSlav.
<ets>daviti</ets> to choke, Lith. <ets>dovyti</ets> to torment. Cf.
<er>Dead</er>, <er>Death</er>.]</ety> <sn>1.</sn> <def>To pass from an
animate to a lifeless state; to cease to live; to suffer a total and
irreparable loss of action of the vital functions; to become dead; to
expire; to perish; -- said of animals and vegetables; often with
<xex>of</xex>, <xex>by</xex>, <xex>with</xex>, <xex>from</xex>, and
rarely <xex>for</xex>, before the cause or occasion of death; <as>as, to
<ex>die</ex> of disease or hardships; to <ex>die</ex> by fire or the
sword; to <ex>die</ex> with horror at the thought.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>die</qex> by the roadside of grief and hunger.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>She will <qex>die</qex> from want of care.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To suffer death; to lose life.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In due time Christ <qex>died</qex> for the ungodly.</q>
<rj><qau>Rom. v. 6.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To perish in any manner; to cease; to become lost or
extinct; to be extinguished.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Letting the secret <qex>die</qex> within his own breast.</q>
<rj><qau>Spectator.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Great deeds can not <qex>die</qex>.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To sink; to faint; to pine; to languish, with
weakness, discouragement, love, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His heart <qex>died</qex> within, and he became as a stone.</q>
<rj><qau>1 Sam. xxv. 37.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The young men acknowledged, in love letters, that they
<qex>died</qex> for Rebecca.</q> <rj><qau>Tatler.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To become indifferent; to cease to be subject;
<as>as, to <ex>die</ex> to pleasure or to sin</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To recede and grow fainter; to become imperceptible;
to vanish; -- often with <xex>out</xex> or <xex>away</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Blemishes may <qex>die</qex> away and disappear amidst the
brightness.</q> <rj><qau>Spectator.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Arch.)</fld> <def>To disappear gradually in another
surface, as where moldings are lost in a sloped or curved
face.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>To become vapid, flat, or spiritless, as
liquor.</def><br/
[<source>1913 Webster</source>]</p>

<cs><p><col><b>To die in the last ditch</b></col>, <cd>to fight till
death; to die rather than surrender.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q><ldquo/There is one certain way,<rdquo/ replied the Prince
[William of Orange] <ldquo/ by which I can be sure never to see my
country's ruin, -- I <qex>will die in the last ditch</qex>.<rdquo/</q>
<rj><qau>Hume (Hist. of Eng. ).</qau></rj></p>

<p>-- <col><b>To die out</b></col>, <cd>to cease gradually; as, the
prejudice has <xex>died out</xex>.</cd></p></cs>

<p><syn><b>Syn.</b> -- To expire; decease; perish; depart;
vanish.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Die</ent><br/
<hw>Die</hw>, <pos>n.</pos>; <plu><it>pl.</it> in 1 and (usually) in 2,
<plw>Dice</plw> <pr>(d<imac/s)</pr>; in 4 & 5, <plw>Dies</plw>
<pr>(d<imac/z)</pr>.</plu> <ety>[OE. <ets>dee</ets>, <ets>die</ets>, F.
<ets>d<eacute/</ets>, fr. L. <ets>datus</ets> given, thrown, p. p. of
<ets>dare</ets> to give, throw. See <er>Date</er> a point of
time.]</ety> <sn>1.</sn> <def>A small cube, marked on its faces with
spots from one to six, and used in playing games by being shaken in a
box and thrown from it. See <er>Dice</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Any small cubical or square body.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Words . . . pasted upon little flat tablets or
<qex>dies</qex>.</q> <rj><qau>Watts.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which is, or might be, determined, by a throw
of the die; hazard; chance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Such is the <qex>die</qex> of war.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Arch.)</fld> <def>That part of a pedestal included
between base and cornice; the dado.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Mach.)</fld> <sd>(a)</sd> <def>A metal or plate
(often one of a pair) so cut or shaped as to give a certain desired form
to, or impress any desired device on, an object or surface, by pressure
or by a blow; used in forging metals, coining, striking up sheet metal,
etc.</def> <sd>(b)</sd> <def>A perforated block, commonly of hardened
steel used in connection with a punch, for punching holes, as through
plates, or blanks from plates, or for forming cups or capsules, as from
sheet metal, by drawing.</def> <sd>(c)</sd> <def>A hollow internally
threaded screw-cutting tool, made in one piece or composed of several
parts, for forming screw threads on bolts, etc.; one of the separate
parts which make up such a tool.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Cutting die</b></col> <fld>(Mech.)</fld>, <cd>a thin,
deep steel frame, sharpened to a cutting edge, for cutting out articles
from leather, cloth, paper, etc.</cd> -- <col><b>The die is
cast</b></col>, <cd>the hazard must be run; the step is taken, and it is
too late to draw back; the last chance is taken.</cd></cs></p>

<p><ent>Diecious</ent><br/
<ent>Diecian</ent><br/
<mhw><hw>Di*e"cian</hw> <pr>(?)</pr>, <pos>a.</pos>, <hw>Di*e"cious</hw>
<pr>(<?/)</pr></mhw>, <pos>a.</pos> <fld>(Bot.)</fld> <def>See
<er>Di<oe/cian</er>, and <er>Di<oe/cious</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diedral</ent><br/
<hw>Di*e"dral</hw> <pr>(?)</pr>, <pos>a.</pos> <def>The same as
<er>Dihedral</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dieffenbachia</ent><br/
<hw>Dieffenbachia</hw> <pos>n.</pos> <def>a genus of evergreen perennial
herbs of tropical America with lush foliage and poisonous sap; often
cultivated as houseplants.</def><br/
<syn><b>Syn. --</b> genus <gen>Dieffenbachia</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Diegesis</ent><br/
\'d8<hw>Di`e*ge"sis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<?/, fr. <?/ to narrate; <grk>dia`</grk> through + <?/ to lead.]</ety>
<def>A narrative or history; a recital or relation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>diehard</ent><br/
<hw>die"hard`</hw> <pr>(d<imac/"h<aum/rd`)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>one who stubbornly adheres to traditional and outdated
views.</def><br/
<syn><b>Syn. --</b> traditionalist.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>one who vigorously defends an apparently hopeless
position, a lost cause, etc.</def><br/
[<source>PJC</source>]</p>

<p><ent>diehard</ent><br/
<hw>die"hard`</hw> <pr>(d<imac/"h<aum/rd`)</pr>, <pos>a.</pos>
<def>stubbornly and vigorously resisting in the face of seemingly
hopeless odds; <as>as, <ex>diehard</ex> opposition</as>.</def><br/
<syn><b>Syn. --</b> never-say-die.</syn>
[<source>PJC</source>]</p>

<p><ent>Dielectric</ent><br/
<hw>Di`e*lec"tric</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>dia-</ets> + <ets>electric</ets>.]</ety> <fld>(Elec.)</fld>
<def>Any substance or medium that transmits the electric force by a
process different from conduction, as in the phenomena of induction; a
nonconductor, separating a body electrified by induction, from the
electrifying body.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dielytra</ent><br/
\'d8<hw>Di*el"y*tra</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>See <er>Dicentra</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diencephalon</ent><br/
\'d8<hw>Di`en*ceph"a*lon</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. See
<er>Dia-</er>, and <er>Encephalon</er>.]</ety> <fld>(Anat.)</fld>
<def>The interbrain or thalamencephalon; -- sometimes abbreviated to
<abbr>dien</abbr>. See <er>Thalamencephalon</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dieresis</ent><br/
\'d8<hw>Di*er"e*sis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL.]</ety>
<def>Same as <er>Di<ae/resis</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diervilla</ent><br/
<hw>Diervilla</hw> <pos>n.</pos> <def>small genus of low deciduous
shrubs; the bush honeysuckles.</def><br/
<syn><b>Syn. --</b> genus <gen>Diervilla</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Diesel motor</ent><br/
<ent>Diesel engine</ent><br/
<ent>Diesel</ent><br/
<mhw>{ <hw>Diesel</hw>, <hw>Die"sel en`gine</hw> <it>or</it> <hw>Die"sel
mo`tor</hw> <pr>(d<emac/"z<eit/l)</pr> }</mhw>. <ety>[After Dr.
<person>Rudolf <etsep>Diesel</etsep></person>, of Munich, the
inventor.]</ety> <def>A type of <isa>internal-combustion engine</isa> in
which the air drawn in by the suction stroke is so highly compressed
that the heat generated ignites the fuel (usually a heavy oil), the fuel
being automatically sprayed into the cylinder under pressure. The Diesel
engine has a very high thermal efficiency.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>dieses</ent><br/
<hw>dieses</hw> <pos>n.</pos> <def>plural of <er>diesis</er>.</def><br/
<syn><b>Syn. --</b> double daggers, double obelisks.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Diesinker</ent><br/
<hw>Die"sink`er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An engraver of
dies for stamping coins, medals, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diesinking</ent><br/
<hw>Die"sink`ing</hw>, <pos>n.</pos> <def>The process of engraving
dies.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dies Irae</ent><br/
\'d8<hw>Di"es I"r<ae/</hw> <pr>(?)</pr>. <def>Day of wrath; -- the name
and beginning of a famous medi<ae/val Latin hymn on the Last
Judgment.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><pre><tt>  The text of the Dies Irae follows:<br/
		    DIES IRAE
    attributed to Tomaso de Celano
=========================================================
    Latin                          English
=========================================================
Dies irae, dies illa          The day of wrath, that day
solvet saeclum in favilla:    which will reduce the world to ashes,
teste David cum Sibylla.      as foretold by David and the Sybil.

Quantus tremor est futurus,   What terror there will be,
quando judex est venturus,    when the Lord will come
cuncta stricte discussurus!   to rigorously judge all!

Tuba mirum spargens sonum     The trumpet, scattering a wondrous sound
per sepulcra regionum,        among the graves of all the lands,
coget omnes ante thronum.     will assemble all before the Throne.

Mors stupebit et natura,      Death and Nature will be astounded
cum resurget creatura,        when they see a creature rise again
judicanti responsura.         to answer to the Judge.

Liber scriptus proferetur,    The book will be brought forth
in quo totum continetur,      in which all deeds are noted,
unde mundus judicetur.        for which humanity will answer.

Judex ergo cum sedebit,       When the judge will be seated,
quidquid latet apparebit,     all that is hidden will appear,
nil inultum remanebit.        and nothing will go unpunished.

Quid sum miser tunc dicturus? Alas, what will I then say?
Quem patronum rogaturus,      To what advocate shall I appeal,
cum vix justus sit securus?   when even the just tremble?

Rex tremendae majestatis,     O king of redoutable majesty,
qui salvandos salvas gratis,  who freely saves the elect,
salva me fons pietatis.       save me, o fount of piety!

Recordare Jesu pie,           Remember, good Jesus,
quod sum causa tuae viae,     that I am the cause of your journey,
ne me perdas illa die.        do not lose me on that day.

Quaerens me sedisti lassus,   You wearied yourself in finding me.
redemisti crucem passus,      You have redeemed me through the cross.
tantus labor non sit cassus.  Let not such great efforts be in vain.

Juste judex ultionis,         O judge of vengeance, justly
donum fac remissionis         make a gift of your forgiveness
ante diem rationis.           before the day of reckoning.

Ingemisco tanquam reus,       I lament like a guilty one.
culpa rubet vultus meus,      My faults cause me to blush,
supplicanti parce, Deus.      I beg you, spare me.

Qui Mariam absolvisti,        You who have absolved Mary
et latronem exaudisti,        and have heard the thief's prayer,
mihi quoque spem dedisti.     have also given me hope.

Preces meae non sunt dignae:  My prayers are not worthy,
sed tu bonus fac benigne,     but you, o Good One, please grant freely
ne perenni cremer igne.       that I do not burn in the eternal fire.

Inter oves locum praesta,     Give me a place among the sheep,
et ab haedis me sequestra,    separate me from the goats
statuens in parte dextra.     by placing me at your right.

Confutatis maledictis,        Having destroyed the accursed,
flammis acribus addictis:     condemned them to the fierce flames,
voca me cum benedictis.       Count me among the blessed.

Oro Supplex Et Acclinis,      I prostrate myself, supplicating,
Cor Contritum Quasi Cinis,    my heart in ashes, repentant;
Gere Curam Mei Finis.         take good care of my last moment!

Lacrimosa dies illa,          That tearful day,
qua resurget ex favilla       when shall rise again from the ashes
judicandus homo reus.         sinful man to be judged.
Huic ergo parce, Deus:        Therefore pardon him, o God.

pie Jesu Domine,              Holy Lord Jesus,
dona eis requiem.             give them rest.

Amen.                         Amen.</tt></pre></note><br/
[<source>PJC</source>]</p>

<p><ent>Diesis</ent><br/
\'d8<hw>Di"e*sis</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Dieses</plw> <pr>(#)</pr>.</plu> <ety>[NL., fr. Gr. <?/, fr. <?/ to
let go through, dissolve; <grk>dia`</grk> through + <?/ to let go,
send.]</ety> <sn>1.</sn> <fld>(Mus.)</fld> <def>A small interval, less
than any in actual practice, but used in the mathematical calculation of
intervals.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Print.)</fld> <def>The mark <Dagger/; -- called
also <altname>double dagger</altname>. It is used in printing to
indicate a cross reference or footnote</def><br/
<syn><b>Syn. --</b> double obelisk.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dies juridicus</ent><br/
\'d8<hw>Di"es ju*rid"i*cus</hw> <pr>(?)</pr>; <plu><it>pl.</it>
<plw>Dies juridici</plw> <pr>(#)</pr>.</plu> <ety>[L.]</ety>
<fld>(Law)</fld> <def>A court day.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dies non</ent><br/
\'d8<hw>Di"es non"</hw> <pr>(?)</pr>. <ety>[L. <ets>dies non
juridicus</ets>.]</ety> <fld>(Law)</fld> <def>A day on which courts are
not held, as Sunday or any legal holiday.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diestock</ent><br/
<hw>Die"stock`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A stock to hold the
dies used for cutting screws.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>diestrual</ent><br/
<ent>diestrous</ent><br/
<mhw><hw>diestrous</hw> <hw>diestrual</hw></mhw> <pos>adj.</pos> <def>in
a period of sexual inactivity; -- of animals that have several estrous
cycles in one breeding season.</def><br/
<syn><b>Syn. --</b> dioestrous, dioestrual.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>diestrum</ent><br/
<hw>diestrum</hw> <pos>n.</pos> <def>same as
<er>diestrus</er>.</def><br/
<syn><b>Syn. --</b> diestrus.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>diestrus</ent><br/
<hw>diestrus</hw> <pos>n.</pos> <def>a state or interval of sexual
inactivity or quiescence between periods of activity; -- of animals
having several estrous cycles in one breeding season.</def><br/
<syn><b>Syn. --</b> diestrum.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Diet</ent><br/
<hw>Di"et</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>di<egrave/te</ets>, L. <ets>diaeta</ets>, fr. Gr. <?/ manner of
living.]</ety> <sn>1.</sn> <def>Course of living or nourishment; what is
eaten and drunk habitually; food; victuals; fare.</def> <ldquo/No
inconvenient <xex>diet</xex>.<rdquo/ <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A course of food selected with reference to a
particular state of health; prescribed allowance of food; regimen
prescribed.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To fast like one that takes <qex>diet</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Diet kitchen</b></col>, <cd>a kitchen in which diet is
prepared for invalids; a charitable establishment that provides proper
food for the sick poor.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diet</ent><br/
<hw>Di"et</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Dieted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Dieting</conjf>.]</vmorph> <sn>1.</sn> <def>To cause to take
food; to feed.</def> <mark>[R.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To cause to eat and drink sparingly, or by
prescribed rules; to regulate medicinally the food of.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>She <qex>diets</qex> him with fasting every day.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diet</ent><br/
<hw>Di"et</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To eat; to take one's
meals.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Let him . . . <qex>diet</qex> in such places, where there is good
company of the nation, where he traveleth.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To eat according to prescribed rules; to ear
sparingly; <as>as, the doctor says he must <ex>diet</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diet</ent><br/
<hw>Di"et</hw>, <pos>n.</pos> <ety>[F. <ets>di<egrave/te</ets>, LL.
<ets>dieta</ets>, <ets>diaeta</ets>, an assembly, a day's journey; the
same word as <ets>diet</ets> course of living, but with the sense
changed by L. <ets>dies</ets> day: cf. G. <ets>tag</ets> day, and
<er>Reichstag</er>.]</ety> <def>A legislative or administrative assembly
in Germany, Poland, and some other countries of Europe; a deliberative
convention; a council; <as>as, the <ex>Diet</ex> of Worms, held in
1521</as>.</def> <specif>Specifically:</specif> <def>Any of various
national or local assemblies;</def> <specif>as,</specif> <sd>(a)</sd>
<def>Occasionally, the Reichstag of the German Empire, Reichsrath of the
Austrian Empire, the federal legislature of Switzerland, etc.</def>
<sd>(b)</sd> <def>The legislature of Denmark, Sweden, Japan, or
Hungary.</def> <sd>(c)</sd> <def>The state assembly or any of various
local assemblies in the states of the German Empire, as the legislature
(Landtag) of the kingdom of Prussia, and the Diet of the Circle
(Kreistag) in its local government.</def> <sd>(d)</sd> <def>The local
legislature (Landtag) of an Austrian province.</def> <sd>(e)</sd>
<def>The federative assembly of the old Germanic Confederation (1815 --
66).</def> <sd>(f)</sd> <def>In the old German or Holy Roman Empire, the
great formal assembly of counselors (the Imperial Diet or Reichstag) or
a small, local, or informal assembly of a similar kind (the Court Diet,
or Hoftag).</def> <note>The most celebrated Imperial Diets are the three
following, all held under Charles V.: <col><b>Diet of Worms</b></col>,
1521, the object of which was to check the Reformation and which
condemned Luther as a heretic; <mcol><col><b>Diet of Spires</b></col>,
<it>or</it> <col><b>Diet of Speyer</b></col></mcol>, 1529, which had the
same object and issued an edict against the further dissemination of the
new doctrines, against which edict Lutheran princes and deputies
protested (hence <xex>Protestants</xex>): <col><b>Diet of
Augsburg</b></col>, 1530, the object of which was the settlement of
religious disputes, and at which the Augsburg Confession was presented
but was denounced by the emperor, who put its adherents under the
imperial ban.</note><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Dietarian</ent><br/
<hw>Di`e*ta"ri*an</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who lives in
accordance with prescribed rules for diet; a dieter.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dietary</ent><br/
<hw>Di"et*a*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to diet,
or to the rules of diet.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dietary</ent><br/
<hw>Di"et*a*ry</hw>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Dietaries</plw> <pr>(<?/)</pr>.</plu> <def>A rule of diet; a fixed
allowance of food, as in workhouse, prison, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dieter</ent><br/
<hw>Di"et*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who diets; one
who prescribes, or who partakes of, food, according to hygienic
rules.</def></p>

<p><ent>Dietetical</ent><br/
<ent>Dietetic</ent><br/
<mhw>{ <hw>Di`e*tet"ic</hw> <pr>(?)</pr>, <hw>Di`e*tet"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[Gr. <?/: cf. F.
<ets>di<eacute/t<eacute/tique</ets>. See <er>Diet</er>.]</ety> <def>Of
or performance to diet, or to the rules for regulating the kind and
quantity of food to be eaten.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dietetically</ent><br/
<hw>Di`e*tet"ic*al*ly</hw>, <pos>adv.</pos> <def>In a dietetical
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dietetics</ent><br/
<hw>Di`e*tet"ics</hw> <pr>(?)</pr>, <pos>n.</pos> <def>That part of the
medical or hygienic art which relates to diet or food; rules for
diet.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To suppose that the whole of <qex>dietetics</qex> lies in
determining whether or not bread is more nutritive than potatoes.</q>
<rj><qau>H. Spencer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dietetist</ent><br/
<hw>Di`e*tet"ist</hw>, <pos>n.</pos> <def>A physician who applies the
rules of dietetics to the cure of diseases.</def>
<rj><au>Dunglison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diethylamine</ent><br/
<hw>Di*eth`yl*am"ine</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>di-</ets> + <ets>ethylamine</ets>.]</ety> <fld>(Chem.)</fld> <def>A
colorless, volatile, alkaline liquid, <chform>NH(C2H5)2</chform>, having
a strong fishy odor resembling that of herring or sardines. Cf.
<er>Methylamine</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dietic</ent><br/
<hw>Di*et"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Dietetic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dietical</ent><br/
<hw>Di*et"ic*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Dietetic.</def>
<mark>[R.]</mark> <rj><au>Ferrand.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dietine</ent><br/
<hw>Di"et*ine</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>di<eacute/tine</ets>.]</ety> <def>A subordinate or local assembly;
a diet of inferior rank.</def></p>

<p><ent>Dietitian</ent><br/
<ent>Dietist</ent><br/
<mhw>{ <hw>Di"et*ist</hw> <pr>(?)</pr>, <hw>Di`e*ti"tian</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <def>One skilled in dietetics.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diffame</ent><br/
<hw>Dif*fame`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Defame</er>.]</ety> <def>Evil name; bad reputation;
defamation.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diffarreation</ent><br/
<hw>Dif*far`re*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>diffarreatio</ets>; <ets>dif-</ets> = <ets>farreum</ets> a spelt
cake. See <er>Confarreation</er>.]</ety> <def>A form of divorce, among
the ancient Romans, in which a cake was used. See
<er>Confarreation</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Differ</ent><br/
<hw>Dif"fer</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Differed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Differing</conjf>.]</vmorph> <ety>[L.
<ets>differre</ets>; <ets>dif- = dis-</ets> + <ets>ferre</ets> to bear,
carry: cf. F. <ets>diff<eacute/rer</ets>. See 1st <er>Bear</er>, and cf.
<er>Defer</er>, <er>Delay</er>.]</ety> <sn>1.</sn> <def>To be or stand
apart; to disagree; to be unlike; to be distinguished; -- with
<xex>from</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>One star <qex>differeth</qex> from another star in glory.</q>
<rj><qau>1 Cor. xv. 41.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Minds <qex>differ</qex>, as rivers <qex>differ</qex>.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To be of unlike or opposite opinion; to disagree in
sentiment; -- often with <xex>from</xex> or <xex>with</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To have a difference, cause of variance, or quarrel;
to dispute; to contend.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We 'll never <qex>differ</qex> with a crowded pit.</q>
<rj><qau>Rowe.</qau></rj></p>

<p><syn><b>Syn.</b> -- To vary; disagree; dissent; dispute; contend;
oppose; wrangle.</syn> <usage>-- To <er>Differ with</er>, <er>Differ
from</er>. Both <xex>differ from</xex> and <xex>differ with</xex> are
used in reference to opinions; <as>as, <ldquo/I <ex>differ from</ex> you
or <ex>with</ex> you in that opinion</as>.<rdquo/ In all other cases,
expressing simple unlikeness, <xex>differ from</xex> is used; <as>as,
these two persons or things <ex>differ</ex> entirely <ex>from</ex> each
other</as>.</usage><br/
[<source>1913 Webster</source>]</p>

<p><q>Severely punished, not for <qex>differing from</qex> us in
opinion, but for committing a nuisance.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Davidson, whom on a former occasion we quoted, to <qex>differ
from</qex> him.</q> <rj><qau>M. Arnold.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Much as I <qex>differ from</qex> him concerning an essential part
of the historic basis of religion.</q>
<rj><qau>Gladstone.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I <qex>differ with</qex> the honorable gentleman on that
point.</q> <rj><qau>Brougham.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>If the honorable gentleman <qex>differs with</qex> me on that
subject, I <qex>differ</qex> as heartily <qex>with</qex> him, and shall
always rejoice to differ.</q> <rj><qau>Canning.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Differ</ent><br/
<hw>Dif"fer</hw>, <pos>v. t.</pos> <def>To cause to be different or
unlike; to set at variance.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>But something 'ts that <qex>differs</qex> thee and me.</q>
<rj><qau>Cowley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Difference</ent><br/
<hw>Dif"fer*ence</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>diff<eacute/rence</ets>, L. <ets>differentia</ets>.]</ety>
<sn>1.</sn> <def>The act of differing; the state or measure of being
different or unlike; distinction; dissimilarity; unlikeness; variation;
<as>as, a <ex>difference</ex> of quality in paper; a <ex>difference</ex>
in degrees of heat, or of light; what is the <ex>difference</ex> between
the innocent and the guilty?</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Differencies</qex> of administration, but the same Lord.</q>
<rj><qau>1 Cor. xii. 5.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Disagreement in opinion; dissension; controversy;
quarrel; hence, cause of dissension; matter in controversy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>What was the <qex>difference</qex>? It was a contention in
public.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Away therefore went I with the constable, leaving the old warden
and the young constable to compose their <qex>difference</qex> as they
could.</q> <rj><qau>T. Ellwood.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 410 --></p>

<p><sn>3.</sn> <def>That by which one thing differs from another; that
which distinguishes or causes to differ; mark of distinction;
characteristic quality; specific attribute.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The marks and <qex>differences</qex> of sovereignty.</q>
<rj><qau>Davies.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Choice; preference.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>That now he chooseth with vile <qex>difference</qex><br/
To be a beast, and lack intelligence.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Her.)</fld> <def>An addition to a coat of arms to
distinguish the bearings of two persons, which would otherwise be the
same. See <er>Augmentation</er>, and <cref>Marks of cadency</cref>,
under <er>Cadency</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Logic)</fld> <def>The quality or attribute which is
added to those of the genus to constitute a species; a
differentia.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Math.)</fld> <def>The quantity by which one
quantity differs from another, or the remainder left after subtracting
the one from the other.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Ascensional difference</b></col>. <cd>See under
<er>Ascensional</er>.</cd></cs></p>

<p><syn><b>Syn.</b> -- Distinction; dissimilarity; dissimilitude;
variation; diversity; variety; contrariety; disagreement; variance;
contest; contention; dispute; controversy; debate; quarrel; wrangle;
strife.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Difference</ent><br/
<hw>Dif"fer*ence</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Differenced</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Differencing</conjf>.]</vmorph> <def>To cause to differ;
to make different; to mark as different; to distinguish.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou mayest <qex>difference</qex> gods from men.</q>
<rj><qau>Chapman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Kings, in receiving justice and undergoing trial, are not
<qex>differenced</qex> from the meanest subject.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>So completely <qex>differenced</qex> by their separate and
individual characters that we at once acknowledge them as distinct
persons.</q> <rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Different</ent><br/
<hw>Dif"fer*ent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>differens</ets>, <ets>-entis</ets>, p. pr. of <ets>differre</ets>:
cf. F. <ets>diff<eacute/rent</ets>.]</ety> <sn>1.</sn> <def>Distinct;
separate; not the same; other.</def> <ldquo/Five <xex>different</xex>
churches.<rdquo/ <rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of various or contrary nature, form, or quality;
partially or totally unlike; dissimilar; <as>as, <ex>different</ex>
kinds of food or drink; <ex>different</ex> states of health;
<ex>different</ex> shapes; <ex>different</ex> degrees of
excellence.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Men are as <qex>different</qex> from each other, as the regions in
which they are born are <qex>different</qex>.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <ex>Different</ex> is properly followed by
<xex>from</xex>. <xex>Different to</xex>, for <xex>different from</xex>,
is a common English colloquialism. <xex>Different than</xex> is quite
inadmissible.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>differentia</ent><br/
<hw>dif`fer*en"ti*a</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Differenti<ae/</plw> <pr>(#)</pr>.</plu> <ety>[L. See
<er>Difference</er>.]</ety> <sn>1.</sn> <fld>(Logic)</fld> <def>The
formal or distinguishing part of the essence of a species, by which it
is distinguished from other members of its genus; the characteristic
attribute of a species; specific difference; <as>as, a proper definition
must have both genus and <ex>differentia</ex></as>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>the set of characteristics distinguishing an entity
from related entities.</def><br/
[<source>PJC</source>]</p>

<p><ent>differentiable</ent><br/
<hw>differentiable</hw> <pos>adj.</pos> <sn>1.</sn> <fld>(Math.)</fld>
<def>possessing a differential coefficient or derivative; -- of a
mathematical expression.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>capable of being perceived as different; <as>as,
<ex>differentiable</ex> species</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>differentiated</ent><br/
<hw>differentiated</hw> <pos>adj.</pos> <sn>1.</sn> <def>made different
(especially in the course of development) or shown to be different;
<as>as, the <ex>differentiated</ex> markings of butterflies; the
<ex>regionally</ex> differentiated results</as>. Opposite of
<ant>undifferentiated</ant>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <fld>(Biol.)</fld> <def>exhibiting biological
specialization; adapted during development to a specific function or
environment; <as>as, <ex>differentiated</ex> cells</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>differential</ent><br/
<hw>dif`fer*en"tial</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>diff<eacute/rentiel</ets>.]</ety> <sn>1.</sn> <def>Relating to or
indicating a difference; creating a difference; discriminating; special;
<as>as, <ex>differential</ex> characteristics; <ex>differential</ex>
duties; a <ex>differential</ex> rate.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>For whom he produced <qex>differential</qex> favors.</q>
<rj><qau>Motley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Math.)</fld> <def>Of or pertaining to a
differential, or to differentials.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Mech.)</fld> <def>Relating to differences of motion
or leverage; producing effects by such differences; said of
mechanism.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Differential calculus</b></col>. <fld>(Math.)</fld>
<cd>See under <er>Calculus</er>.</cd> -- <col><b>Differential
coefficient</b></col>, <cd>the limit of the ratio of the increment of a
function of a variable to the increment of the variable itself, when
these increments are made indefinitely small.</cd> --
<col><b>Differential coupling</b></col>, <cd>a form of slip coupling
used in light machinery to regulate at pleasure the velocity of the
connected shaft.</cd> -- <col><b>Differential duties</b></col>
<fld>(Polit. Econ.)</fld>, <cd>duties which are not imposed equally upon
the same products imported from different countries.</cd> --
<col><b>Differential galvanometer</b></col> <fld>(Elec.)</fld>, <cd>a
galvanometer having two coils or circuits, usually equal, through which
currents passing in opposite directions are measured by the difference
of their effect upon the needle.</cd> -- <col><b>Differential
gearing</b></col>, <cd>a train of toothed wheels, usually an epicyclic
train, so arranged as to constitute a <cref>differential
motion</cref>.</cd> -- <col><b>Differential motion</b></col>, <cd>a
mechanism in which a simple <xex>differential</xex> combination produces
such a change of motion or force as would, with ordinary compound
arrangements, require a considerable train of parts. It is used for
overcoming great resistance or producing very slow or very rapid
motion.</cd> -- <col><b>Differential pulley</b></col>.
<fld>(Mach.)</fld> <sd>(a)</sd> <cd>A portable hoisting apparatus, the
same in principle as the differential windlass.</cd> <sd>(b)</sd> <cd>A
hoisting pulley to which power is applied through a differential
gearing.</cd> -- <col><b>Differential screw</b></col>, <cd>a compound
screw by which a motion is produced equal to the difference of the
motions of the component screws.</cd> -- <col><b>Differential
thermometer</b></col>, <cd>a thermometer usually with a U-shaped tube
terminating in two air bulbs, and containing a colored liquid, used for
indicating the difference between the temperatures to which the two
bulbs are exposed, by the change of position of the colored fluid, in
consequence of the different expansions of the air in the bulbs. A
graduated scale is attached to one leg of the tube.</cd> --
<mcol><col><b>Differential windlass</b></col>, <it>or</it>
<col><b>Chinese windlass</b></col></mcol>, <cd>a windlass whose barrel
has two parts of different diameters. The hoisting rope winds upon one
part as it unwinds from the other, and a pulley sustaining the weight to
be lifted hangs in the bight of the rope. It is an ancient example of a
differential motion.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Differential</ent><br/
<hw>Dif`fer*en"tial</hw>, <pos>n.</pos> <sn>1.</sn> <fld>(Math.)</fld>
<def>An increment, usually an indefinitely small one, which is given to
a variable quantity.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ According to the more modern writers upon the
differential and integral calculus, if two or more quantities are
dependent on each other, and subject to increments of value, their
<ex>differentials</ex> need not be small, but are any quantities whose
ratios to each other are the limits to which the ratios of the
increments approximate, as these increments are reduced nearer and
nearer to zero.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A small difference in rates which competing railroad
lines, in establishing a common tariff, allow one of their number to
make, in order to get a fair share of the business. The lower rate is
called a <xex>differential</xex> rate. Differentials are also sometimes
granted to cities.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Elec.)</fld> <sd>(a)</sd> <def>One of two coils of
conducting wire so related to one another or to a magnet or armature
common to both, that one coil produces polar action contrary to that of
the other.</def> <sd>(b)</sd> <def>A form of conductor used for dividing
and distributing the current to a series of electric lamps so as to
maintain equal action in all.</def> <rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Partial differential</b></col> <fld>(Math.)</fld>,
<cd>the differential of a function of two or more variables, when only
one of the variables receives an increment.</cd> -- <col><b>Total
differential</b></col> <fld>(Math.)</fld>, <cd>the differential of a
function of two or more variables, when each of the variables receives
an increment. The <ex>total differential</ex> of the function is the sum
of all the <cref>partial differentials</cref>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Differentially</ent><br/
<hw>Dif`fer*en"tial*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In the
way of differentiation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Differentiate</ent><br/
<hw>Dif`fer*en"ti*ate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <sn>1.</sn>
<def>To distinguish or mark by a specific difference; to effect a
difference in, as regards classification; to develop differential
characteristics in; to specialize; to desynonymize.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The word <qex>then</qex> was <qex>differentiated</qex> into the
two forms <qex>then</qex> and <qex>than</qex>.</q>
<rj><qau>Earle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Two or more of the forms assumed by the same original word become
<qex>differentiated</qex> in signification.</q> <rj><qau>Dr.
Murray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To express the specific difference of; to describe
the properties of (a thing) whereby it is differenced from another of
the same class; to discriminate.</def> <rj><au>Earle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Math.)</fld> <def>To obtain the differential, or
differential coefficient, of; <as>as, to <ex>differentiate</ex> an
algebraic expression, or an equation</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Differentiate</ent><br/
<hw>Dif`fer*en"ti*ate</hw>, <pos>v. i.</pos> <fld>(Biol.)</fld> <def>To
acquire a distinct and separate character.</def>
<rj><au>Huxley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Differentiation</ent><br/
<hw>Dif`fer*en`ti*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>The act of differentiating.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Further investigation of the Sanskrit may lead to
<qex>differentiation</qex> of the meaning of such of these roots as are
real roots.</q> <rj><qau>J. Peile.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Logic)</fld> <def>The act of distinguishing or
describing a thing, by giving its different, or specific difference;
exact definition or determination.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Biol.)</fld> <def>The gradual formation or
production of organs or parts by a process of evolution or development,
as when the seed develops the root and the stem, the initial stem
develops the leaf, branches, and flower buds; or in animal life, when
the germ evolves the digestive and other organs and members, or when the
animals as they advance in organization acquire special organs for
specific purposes.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Metaph.)</fld> <def>The supposed act or tendency in
being of every kind, whether organic or inorganic, to assume or produce
a more complex structure or functions.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Differentiator</ent><br/
<hw>Dif`fer*en"ti*a`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who,
or that which, differentiates.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Differently</ent><br/
<hw>Dif"fer*ent*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a
different manner; variously.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Differingly</ent><br/
<hw>Dif"fer*ing*ly</hw>, <pos>adv.</pos> <def>In a differing or
different manner.</def> <rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Difficile</ent><br/
<hw>Dif"fi*cile</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>difficilis</ets>: cf. F. <ets>difficile</ets>. See
<er>Difficult</er>.]</ety> <def>Difficult; hard to manage;
stubborn.</def> <mark>[Obs.]</mark> --
<wordforms><wf>Dif"fi*cile*ness</wf>, <pos>n.</pos>
<mark>[Obs.]</mark></wordforms> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Difficilitate</ent><br/
<hw>Dif`fi*cil"i*tate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To make
difficult.</def> <mark>[Obs.]</mark> <rj><au>W. Montagu.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Difficult</ent><br/
<hw>Dif"fi*cult</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From
<er>Difficulty</er>.]</ety> <sn>1.</sn> <def>Hard to do or to make;
beset with difficulty; attended with labor, trouble, or pains; not easy;
arduous.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Difficult</xex> implies the notion that
considerable mental effort or skill is required, or that obstacles are
to be overcome which call for sagacity and skill in the agent; as, a
<xex>difficult</xex> task; hard work is not always <xex>difficult</xex>
work; a <xex>difficult</xex> operation in surgery; a
<xex>difficult</xex> passage in an author.</note><br/
[<source>1913 Webster</source>]</p>

<p><q>There is not the strength or courage left me to venture into the
wide, strange, and <qex>difficult</qex> world, alone.</q>
<rj><qau>Hawthorne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hard to manage or to please; not easily wrought
upon; austere; stubborn; <as>as, a <ex>difficult</ex>
person</as>.</def></p>

<p><syn><b>Syn.</b> -- Arduous; painful; crabbed; perplexed; laborious;
unaccommodating; troublesome. See <er>Arduous</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Difficult</ent><br/
<hw>Dif"fi*cult</hw>, <pos>v. t.</pos> <def>To render difficult; to
impede; to perplex.</def> <mark>[R.]</mark> <rj><au>Sir W.
Temple.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Difficultate</ent><br/
<hw>Dif"fi*cult*ate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To render
difficult; to difficilitate.</def> <mark>[Obs.]</mark>
<rj><au>Cotgrave.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Difficultly</ent><br/
<hw>Dif"fi*cult*ly</hw>, <pos>adv.</pos> <def>With difficulty.</def>
<rj><au>Cowper.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Difficultness</ent><br/
<hw>Dif"fi*cult*ness</hw>, <pos>n.</pos> <def>Difficulty.</def>
<mark>[R.]</mark> <rj><au>Golding.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Difficulty</ent><br/
<hw>Dif"fi*cul*ty</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Difficulties</plw> <pr>(#)</pr>.</plu> <ety>[L.
<ets>difficultas</ets>, fr. <ets>difficilis</ets> difficult;
<ets>dif-</ets> <ets>= dis-</ets> + <ets>facilis</ets> easy: cf. F.
<ets>difficult<eacute/</ets>. See <er>Facile</er>.]</ety> <sn>1.</sn>
<def>The state of being difficult, or hard to do; hardness; arduousness;
-- opposed to <ant>easiness</ant> or <ant>facility</ant>; <as>as, the
<ex>difficulty</ex> of a task or enterprise; a work of
<ex>difficulty</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Not being able to promote them [the interests of life] on account
of the <qex>difficulty</qex> of the region.</q> <rj><qau>James
Byrne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Something difficult; a thing hard to do or to
understand; that which occasions labor or perplexity, and requires skill
and perseverance to overcome, solve, or achieve; a hard enterprise; an
obstacle; an impediment; <as>as, the <ex>difficulties</ex> of a science;
<ex>difficulties</ex> in theology.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>They lie under some <qex>difficulties</qex> by reason of the
emperor's displeasure.</q> <rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A controversy; a falling out; a disagreement; an
objection; a cavil.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Measures for terminating all local <qex>difficulties</qex>.</q>
<rj><qau>Bancroft.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Embarrassment of affairs, especially financial
affairs; -- usually in the plural; <as>as, to be in
<ex>difficulties</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In days of <qex>difficulty</qex> and pressure.</q>
<rj><qau>Tennyson.</qau></rj></p>

<p><syn><b>Syn.</b> -- Impediment; obstacle; obstruction; embarrassment;
perplexity; exigency; distress; trouble; trial; objection; cavil. See
<er>Impediment</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diffide</ent><br/
<hw>Dif*fide"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[L.
<ets>diffidere</ets>. See <er>Diffident</er>.]</ety> <def>To be
distrustful.</def> <mark>[Obs.]</mark> <rj><au>Dr. H.
More.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diffidence</ent><br/
<hw>Dif"fi*dence</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>diffidentia</ets>.]</ety> <sn>1.</sn> <def>The state of being
diffident; distrust; want of confidence; doubt of the power, ability, or
disposition of others.</def> <mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>That affliction grew heavy upon me, and weighed me down even to a
<qex>diffidence</qex> of God's mercy.</q> <rj><qau>Donne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Distrust of one's self or one's own powers; lack of
self-reliance; modesty; modest reserve; bashfulness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It is good to speak on such questions with
<qex>diffidence</qex>.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>An Englishman's habitual <qex>diffidence</qex> and awkwardness of
address.</q> <rj><qau>W. Irving.</qau></rj></p>

<p><syn><b>Syn.</b> -- Humility; bashfulness; distrust; suspicion;
doubt; fear; timidity; apprehension; hesitation. See <er>Humility</er>,
and <er>Bashfulness</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diffidency</ent><br/
<hw>Dif"fi*den*cy</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Diffidence</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diffident</ent><br/
<hw>Dif"fi*dent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>diffidens</ets>, <ets>-entis</ets>, p. pr. of <ets>diffidere</ets>;
<ets>dif-</ets> = <ets>dis + fidere</ets> to trust; akin to
<ets>fides</ets> faith. See <er>Faith</er>, and cf.
<er>Defy</er>.]</ety> <sn>1.</sn> <def>Wanting confidence in others;
distrustful.</def> <mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>You were always extremely <qex>diffident</qex> of their
success.</q> <rj><qau>Melmoth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Wanting confidence in one's self; distrustful of
one's own powers; not self-reliant; timid; modest; bashful;
characterized by modest reserve.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>diffident</qex> maidens,<br/
Folding their hands in prayer.</q> <rj><qau>Longfellow.</qau></rj></p>

<p><syn><b>Syn.</b> -- Distrustful; suspicious; hesitating; doubtful;
modest; bashful; lowly; reserved.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diffidently</ent><br/
<hw>Dif"fi*dent*ly</hw>, <pos>adv.</pos> <def>In a diffident
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To stand <qex>diffidently</qex> against each other with their
thoughts in battle array.</q> <rj><qau>Hobbes.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diffind</ent><br/
<hw>Dif*find</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>diffindere</ets>, <ets>diffissum</ets>; <ets>dif-</ets> =
<ets>dis-</ets> + <ets>findere</ets> to split.]</ety> <def>To
split.</def> <mark>[Obs.]</mark> <rj><au>Bailey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diffine</ent><br/
<hw>Dif*fine"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To define.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diffinitive</ent><br/
<hw>Dif*fin"i*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[For
<ets>definitive</ets>.]</ety> <def>Definitive; determinate; final.</def>
<mark>[Obs.]</mark> <rj><au>Sir H. Wotton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diffission</ent><br/
<hw>Dif*fis"sion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Diffind</er>.]</ety> <def>Act of cleaving or splitting.</def>
<mark>[R.]</mark> <rj><au>Bailey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Difflation</ent><br/
<hw>Dif*fla"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL.
<ets>difflatio</ets>, fr. L. <ets>difflare</ets>, <ets>difflatum</ets>,
to disperse by blowing.]</ety> <def>A blowing apart or away.</def>
<mark>[Obs.]</mark> <rj><au>Bailey.</au></rj></p>

<p><ent>Diffluency</ent><br/
<ent>Diffluence</ent><br/
<mhw>{ <hw>Dif"flu*ence</hw> <pr>(?)</pr>, <hw>Dif"flu*en*cy</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <def>A flowing off on all sides;
fluidity.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diffluent</ent><br/
<hw>Dif"flu*ent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>diffluens</ets>, p. pr. of <ets>diffluere</ets> to flow off;
<ets>dif-</ets> = <ets>dis-</ets> + <ets>fluere</ets> to flow.]</ety>
<def>Flowing apart or off; dissolving; not fixed.</def>
<mark>[R.]</mark> <rj><au>Bailey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Difform</ent><br/
<hw>Dif"form`</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>difforme</ets>, fr. L. <ets>dif-</ets> = <ets>dis-</ets> +
<ets>forma</ets> form. Cf. <er>Deform</er>.]</ety> <def>Irregular in
form; -- opposed to <contr>uniform</contr>; anomalous; hence, unlike;
dissimilar; <as>as, to <ex>difform</ex> corolla, the parts of which do
not correspond in size or proportion; <ex>difform</ex>
leaves.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>The unequal refractions of <qex>difform</qex> rays.</q>
<rj><qau>Sir I. Newton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Difformity</ent><br/
<hw>Dif*form"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>difformit<eacute/</ets>. See <er>Difform</er>,
<er>Deformity</er>.]</ety> <def>Irregularity of form; diversity of form;
want of uniformity.</def> <mark>[Obs.]</mark> <rj><au>Sir T.
Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diffract</ent><br/
<hw>Dif*fract"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Diffracted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Diffracting</conjf>.]</vmorph> <ety>[L. <ets>diffractus</ets>, p.
p. of <ets>diffringere</ets> to break in pieces; <ets>dif- = dis-</ets>
+ <ets>frangere</ets> to break. See <er>Fracture</er>.]</ety> <def>To
break or separate into parts; to deflect, or decompose by deflection,
a<?/ rays of light.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diffraction</ent><br/
<hw>Dif*frac"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>diffraction</ets>.]</ety> <fld>(Opt.)</fld> <def>The deflection and
decomposition of light in passing by the edges of opaque bodies or
through narrow slits, causing the appearance of parallel bands or
fringes of prismatic colors, as by the action of a grating of fine lines
or bars.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Remarked by Grimaldi (1665), and referred by him to a property of
light which he called <qex>diffraction</qex>.</q>
<rj><qau>Whewell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Diffraction grating</b></col>. <fld>(Optics)</fld>
<cd>See under <er>Grating</er>.</cd> -- <col><b>Diffraction
spectrum</b></col>. <fld>(Optics)</fld> <cd>See under
<er>Spectrum</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diffractive</ent><br/
<hw>Dif*frac"tive</hw> <pr>(?)</pr>, <pos>a.</pos> <def>That produces
diffraction.</def></p>

<p><ent>Diffranchisement</ent><br/
<ent>Diffranchise</ent><br/
<mhw>{ <hw>Dif*fran"chise</hw> <pr>(?)</pr>,
<hw>Dif*fran"chise*ment</hw> <pr>(?)</pr> }</mhw>. <def>See
<er>Disfranchise</er>, <er>Disfranchisement</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diffusate</ent><br/
<hw>Dif*fus"ate</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>Material which, in the process of catalysis, has diffused or passed
through the separating membrane.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diffuse</ent><br/
<hw>Dif*fuse"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Diffused</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Diffusing</conjf>.]</vmorph> <ety>[L.
<ets>diffusus</ets>, p. p. of <ets>diffundere</ets> to pour out, to
diffuse; <ets>dif- = dis-</ets> + <ets>fundere</ets> to pour. See
<er>Fuse</er> to melt.]</ety> <def>To pour out and cause to spread, as a
fluid; to cause to flow on all sides; to send out, or extend, in all
directions; to spread; to circulate; to disseminate; to scatter; as to
<xex>diffuse</xex> information.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thence <qex>diffuse</qex><br/
His good to worlds and ages infinite.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>We find this knowledge <qex>diffused</qex> among all civilized
nations.</q> <rj><qau>Whewell.</qau></rj></p>

<p><syn><b>Syn.</b> -- To expand; spread; circulate; extend; scatter;
disperse; publish; proclaim.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diffuse</ent><br/
<hw>Dif*fuse"</hw>, <pos>v. i.</pos> <def>To pass by spreading every
way, to diffuse itself.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diffuse</ent><br/
<hw>Dif*fuse"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>diffusus</ets>, p. p.]</ety> <def>Poured out; widely spread; not
restrained; copious; full; esp., of style, opposed to
<contr>concise</contr> or <contr>terse</contr>; verbose; prolix; <as>as,
a <ex>diffuse</ex> style; a <ex>diffuse</ex> writer.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>diffuse</qex> and various knowledge of divine and human
things.</q> <rj><qau>Milton.</qau></rj></p>

<p><syn><b>Syn.</b> -- Prolix; verbose; wide; copious; full. See
<er>Prolix</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diffused</ent><br/
<hw>Dif*fused"</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Spread abroad;
dispersed; loose; flowing; diffuse.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It grew to be a widely <qex>diffused</qex> opinion.</q>
<rj><qau>Hawthorne.</qau></rj></p>

<p>-- <wordforms><wf>Dif*fus"ed*ly</wf> <pr>(#)</pr>, <pos>adv.</pos> --
<wf>Dif*fus"ed*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diffusely</ent><br/
<hw>Dif*fuse"ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a diffuse
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diffuseness</ent><br/
<hw>Dif*fuse"ness</hw>, <pos>n.</pos> <def>The quality of being diffuse;
especially, in writing, the use of a great or excessive number of word
to express the meaning; copiousness; verbosity; prolixity.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 411 --></p>

<p><ent>Diffuser</ent><br/
<hw>Dif*fus"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, diffuses.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diffusibility</ent><br/
<hw>Dif*fu`si*bil"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The quality
of being diffusible; capability of being poured or spread out.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diffusible</ent><br/
<hw>Dif*fu"si*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Capable of flowing or spreading in all directions; that may be
diffused.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Physiol.)</fld> <def>Capable of passing through
animal membranes by osmosis.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diffusibleness</ent><br/
<hw>Dif*fu"si*ble*ness</hw>, <pos>n.</pos> <def>Diffusibility.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diffusion</ent><br/
<hw>Dif*fu"sion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>diffusio</ets>: cf. F. <ets>diffusion</ets>.]</ety> <sn>1.</sn>
<def>The act of diffusing, or the state of being diffused; a spreading;
extension; dissemination; circulation; dispersion.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>diffusion</qex> of knowledge which has undermined
superstition.</q> <rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Physiol.)</fld> <def>The act of passing by osmosis
through animal membranes, as in the distribution of poisons, gases,
etc., through the body. Unlike <xex>absorption</xex>, diffusion may go
on after death, that is, after the blood ceases to circulate.</def></p>

<p><syn><b>Syn.</b> -- Extension; spread; propagation; circulation;
expansion; dispersion.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diffusive</ent><br/
<hw>Dif*fu"sive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>diffusif</ets>.]</ety> <def>Having the quality of diffusing;
capable of spreading every way by flowing; spreading widely; widely
reaching; copious; diffuse.</def> <ldquo/A plentiful and
<xex>diffusive</xex> perfume.<rdquo/ <rj><au>Hare.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diffusively</ent><br/
<hw>Dif*fu"sive*ly</hw>, <pos>adv.</pos> <def>In a diffusive
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diffusiveness</ent><br/
<hw>Dif*fu"sive*ness</hw>, <pos>n.</pos> <def>The quality or state of
being diffusive or diffuse; extensiveness; expansion; dispersion.
Especially of style: Diffuseness; want of conciseness;
prolixity.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The fault that I find with a modern legend, it its
<qex>diffusiveness</qex>.</q> <rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diffusivity</ent><br/
<hw>Dif`fu*siv"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Tendency to
become diffused; tendency, as of heat, to become equalized by spreading
through a conducting medium.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dig</ent><br/
<hw>Dig</hw> <pr>(d<icr/g)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Dug</conjf> <pr>(d<ucr/g)</pr> or
<conjf>Digged</conjf> <pr>(d<icr/gd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Digging</conjf>. -- <xex>Digged</xex> is archaic.]</vmorph>
<ety>[OE. <ets>diggen</ets>, perh. the same word as <ets>diken</ets>,
<ets>dichen</ets> (see <er>Dike</er>, <er>Ditch</er>); cf. Dan.
<ets>dige</ets> to dig, <ets>dige</ets> a ditch; or (?) akin to E. 1st
<ets>dag</ets>. <root/67.]</ety> <sn>1.</sn> <def>To turn up, or delve
in, (earth) with a spade or a hoe; to open, loosen, or break up (the
soil) with a spade, or other sharp instrument; to pierce, open, or
loosen, as if with a spade.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Be first to <qex>dig</qex> the ground.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To get by digging; <as>as, to <ex>dig</ex> potatoes,
or gold</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To hollow out, as a well; to form, as a ditch, by
removing earth; to excavate; <as>as, to <ex>dig</ex> a ditch or a
well</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To thrust; to poke.</def> <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>You should have seen children . . . <qex>dig</qex> and push their
mothers under the sides, saying thus to them: Look, mother, how great a
lubber doth yet wear pearls.</q> <rj><qau>Robynson (More's
Utopia).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To like; enjoy; admire.</def> <illu>The whole class
<ex>digs</ex> Pearl Jam.</illu> <mark>[Colloq.]</mark><br/
[<source>PJC</source>]</p>

<p><cs><col><b>To dig down</b></col>, <cd>to undermine and cause to fall
by digging; as, to <xex>dig down</xex> a wall.</cd> -- <mcol><col><b>To
dig from</b></col>, <col><b>To dig out of</b></col>, <col><b>To dig
out</b></col>, <col><b>To dig up</b></col></mcol>, <cd>to get out or
obtain by digging; <as>as, to <ex>dig</ex> coal <ex>from</ex> or <ex>out
of</ex> a mine; to <ex>dig out</ex> fossils; to <ex>dig up</ex> a
tree</as>. The preposition is often omitted; as, the men are
<ex>digging</ex> coal, <ex>digging</ex> iron ore, <ex>digging</ex>
potatoes.</cd> -- <col><b>To dig in</b></col>, <sd>(a)</sd> <cd>to cover
by digging; <as>as, to <ex>dig in</ex> manure</as>.</cd> <sd>(b)</sd>
<cd>To entrench oneself so as to give stronger resistance; -- used of
warfare or negotiating situations.</cd> -- <col><b>to dig in one's
heels</b></col> <cd>To offer stubborn resistance.</cd></cs><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Dig</ent><br/
<hw>Dig</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To work with a spade or
other like implement; to do servile work; to delve.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Dig</qex> for it more than for hid treasures.</q>
<rj><qau>Job iii. 21.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I can not <qex>dig</qex>; to beg I am ashamed.</q> <rj><qau>Luke
xvi. 3.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mining)</fld> <def>To take ore from its bed, in
distinction from making excavations in search of ore.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To work hard or drudge;</def>
<specif>specif.</specif> (<mark>U. S.</mark>): <def>To study ploddingly
and laboriously.</def> <mark>[Colloq.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><q>Peter <qex>dug</qex> at his books all the harder.</q>
<rj><qau>Paul L. Ford.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>4.</sn> <fld>(Mach.)</fld> <def>Of a tool: To cut deeply into the
work because ill set, held at a wrong angle, or the like, as when a
lathe tool is set too low and so sprung into the work.</def></p>

<p><cs><col><b>To dig out</b></col>, <cd>to depart; to leave, esp.
hastily; decamp.</cd> <mark>[Slang, U. S.]</mark></cs><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>dig</ent><br/
<hw>dig</hw> <pr>(d<icr/g)</pr>, <pos>v. t.</pos> <sn>1.</sn> <def>To
understand; <as>as, do you <ex>dig</ex> me?</as>.</def>
<mark>[slang]</mark><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>To notice; to look at; <as>as, <ex>dig</ex> that
crazy hat!</as>.</def> <mark>[slang]</mark><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>To appreciate and enjoy; <as>as, he <ex>digs</ex>
classical music as well as rock</as>.</def> <mark>[slang]</mark><br/
[<source>PJC</source>]</p>

<p><ent>Dig</ent><br/
<hw>Dig</hw>, <pos>n.</pos> <sn>1.</sn> <def>A thrust; a punch; a poke;
<as>as, a <ex>dig</ex> in the side or the ribs</as>. See <er>Dig</er>,
<pos>v. t.</pos>, 4.</def> <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A plodding and laborious student.</def> <mark>[Cant,
U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A tool for digging.</def> <mark>[Dial.
Eng.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>4.</sn> <def>An act of digging.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>5.</sn> <def>An amount to be dug.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>6.</sn> <fld>(Mining)</fld> <def>same as
<er>Gouge</er>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>7.</sn> <def>a critical and sometimes sarcastic or insulting
remark, but often good-humored; <as>as, celebrities at a roast must
suffer through countless <ex>digs</ex></as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>8.</sn> <def>An archeological excavation site.</def><br/
[<source>PJC</source>]</p>

<p><ent>Digamist</ent><br/
<hw>Dig"a*mist</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ = <?/
twice + <?/ to marry. Cf. <er>Bigamist</er>.]</ety> <def>One who marries
a second time; a deuterogamist.</def> <rj><au>Hammond.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Digamma</ent><br/
<hw>Di*gam"ma</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/; <?/ = <?/
twice + <grk>ga`mma</grk> the letter <GAMMA/. So called because it
resembled two <ets>gammas</ets> placed one above the other.]</ety>
<fld>(Gr. Gram.)</fld> <def>A letter (<?/, <?/) of the Greek alphabet,
which early fell into disuse.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ This form identifies it with the Latin F, though in
sound it is said to have been nearer V. It was pronounced, probably,
much like the English W.</note></p>

<p><ent>Digammated</ent><br/
<ent>Digammate</ent><br/
<mhw>{ <hw>Di*gam"mate</hw> <pr>(?)</pr>, <hw>Di*gam"mated</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <def>Having the digamma or its
representative letter or sound; <as>as, the Latin word <ex>vis</ex> is a
<ex>digammated</ex> form of the Greek <grk>'i`s</grk></as>.</def>
<rj><au>Andrews.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Digamous</ent><br/
<hw>Dig"a*mous</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to a
second marriage, that is, one after the death of the first wife or the
first husband.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Digamy</ent><br/
<hw>Dig"a*my</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ a second
marriage; <grk>di-</grk> = <grk>di`s-</grk> twice + <?/ marriage. Cf.
<er>Bigamy</er>.]</ety> <def>Act, or state, of being twice married;
deuterogamy.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Digastric</ent><br/
<hw>Di*gas"tric</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>di-</grk> = <grk>di`s-</grk> twice + <?/ belly: cf. F.
<ets>digastrique</ets>.]</ety> <fld>(Anat.)</fld> <sd>(a)</sd>
<def>Having two bellies; biventral; -- applied to muscles which are
fleshy at each end and have a tendon in the middle, and esp. to the
muscle which pulls down the lower jaw.</def> <sd>(b)</sd>
<def>Pertaining to the digastric muscle of the lower jaw; <as>as, the
<ex>digastric</ex> nerves</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Digenea</ent><br/
\'d8<hw>Di*ge"ne*a</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL., fr.
Gr. <grk>di-</grk> = <grk>di`s-</grk> twice + <?/ race,
offspring.]</ety> <fld>(Zool.)</fld> <def>A division of Trematoda in
which alternate generations occur, the immediate young not resembling
their parents.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Digenesis</ent><br/
<hw>Di*gen"e*sis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>di-</ets> + <ets>genesis</ets>.]</ety> <fld>(Biol.)</fld> <def>The
faculty of multiplying in two ways; -- by ova fecundated by spermatic
fluid, and asexually, as by buds. See
<er>Parthenogenesis</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Digenous</ent><br/
<hw>Dig"e*nous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>di-</ets> + <ets>-genous</ets>.]</ety> <fld>(Biol.)</fld>
<def>Sexually reproductive.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Digenous reproduction</b></col>. <fld>(Biol.)</fld>
<cd>Same as <er>Digenesis</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Digerent</ent><br/
<hw>Dig"er*ent</hw> <pr>(?)</pr>, . <ety>[L. <ets>digerens</ets>, p. pr.
of <ets>digerere</ets>. See <er>Digest</er>.]</ety>
<def>Digesting.</def> <mark>[Obs.]</mark> <rj><au>Bailey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Digest</ent><br/
<hw>Di*gest"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Digested</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Digesting</conjf>.]</vmorph> <ety>[L. <ets>digestus</ets>, p. p.
of <ets>digerere</ets> to separate, arrange, dissolve, digest; <ets>di-
= dis-</ets> + <ets>gerere</ets> to bear, carry, wear. See
<er>Jest</er>.]</ety> <sn>1.</sn> <def>To distribute or arrange
methodically; to work over and classify; to reduce to portions for ready
use or application; <as>as, to <ex>digest</ex> the laws,
etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Joining them together and <qex>digesting</qex> them into
order.</q> <rj><qau>Blair.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>We have cause to be glad that matters are so well
<qex>digested</qex>.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Physiol.)</fld> <def>To separate (the food) in its
passage through the alimentary canal into the nutritive and nonnutritive
elements; to prepare, by the action of the digestive juices, for
conversion into blood; to convert into chyme.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To think over and arrange methodically in the mind;
to reduce to a plan or method; to receive in the mind and consider
carefully; to get an understanding of; to comprehend.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Feelingly <qex>digest</qex> the words you speak in prayer.</q>
<rj><qau>Sir H. Sidney.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>How shall this bosom multiplied <qex>digest</qex><br/
The senate's courtesy?</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To appropriate for strengthening and
comfort.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Grant that we may in such wise hear them [the Scriptures], read,
mark, learn, and inwardly <qex>digest</qex> them.</q> <rj><qau>Book of
Common Prayer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Hence: To bear comfortably or patiently; to be
reconciled to; to brook.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I never can <qex>digest</qex> the loss of most of Origin's
works.</q> <rj><qau>Coleridge.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Chem.)</fld> <def>To soften by heat and moisture;
to expose to a gentle heat in a boiler or matrass, as a preparation for
chemical operations.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Med.)</fld> <def>To dispose to suppurate, or
generate healthy pus, as an ulcer or wound.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>To ripen; to mature.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Well-<qex>digested</qex> fruits.</q> <rj><qau>Jer.
Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>To quiet or abate, as anger or grief.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Digest</ent><br/
<hw>Di*gest"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <sn>1.</sn> <def>To
undergo digestion; <as>as, food <ex>digests</ex> well or
ill</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Med.)</fld> <def>To suppurate; to generate pus, as
an ulcer.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Digest</ent><br/
<hw>Di"gest</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>digestum</ets>, pl. <ets>digesta</ets>, neut., fr.
<ets>digestus</ets>, p. p.: cf. F. <ets>digeste</ets>. See
<er>Digest</er>, <pos>v. t.</pos>]</ety> <def>That which is digested;
especially, that which is worked over, classified, and arranged under
proper heads or titles</def>; esp. <fld>(Law)</fld>, <def>A compilation
of statutes or decisions analytically arranged. The term is applied in a
general sense to the Pandects of Justinian (see <er>Pandect</er>), but
is also specially given by authors to compilations of laws on particular
topics; a summary of laws; <as>as, Comyn's <ex>Digest</ex>; the United
States <ex>Digest</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>A complete <qex>digest</qex> of Hindu and Mahommedan laws after
the model of Justinian's celebrated Pandects.</q> <rj><qau>Sir W.
Jones.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>They made a sort of institute and <qex>digest</qex> of anarchy,
called the Rights of Man.</q> <rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Digestedly</ent><br/
<hw>Di*gest"ed*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a digested
or well-arranged manner; methodically.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Digester</ent><br/
<hw>Di*gest"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who
digests.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A medicine or an article of food that aids
digestion, or strengthens digestive power.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Rice is . . . a great restorer of health, and a great
<qex>digester</qex>.</q> <rj><qau>Sir W. Temple.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A strong closed vessel, in which bones or other
substances may be subjected, usually in water or other liquid, to a
temperature above that of boiling, in order to soften them.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Digestibility</ent><br/
<hw>Di*gest`i*bil"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The quality
of being digestible.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Digestible</ent><br/
<hw>Di*gest"i*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F.
<ets>digestible</ets>, L. <ets>digestibilis</ets>.]</ety> <def>Capable
of being digested.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Digestibleness</ent><br/
<hw>Di*gest"i*ble*ness</hw>, <pos>n.</pos> <def>The quality of being
digestible; digestibility.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Digestion</ent><br/
<hw>Di*ges"tion</hw> <pr>(?; 106)</pr>, <pos>n.</pos> <ety>[F.
<ets>digestion</ets>, L. <ets>digestio</ets>.]</ety> <sn>1.</sn>
<def>The act or process of digesting; reduction to order;
classification; thoughtful consideration.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Physiol.)</fld> <def>The conversion of food, in the
stomach and intestines, into soluble and diffusible products, capable of
being absorbed by the blood.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Med.)</fld> <def>Generation of pus;
suppuration.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Digestive</ent><br/
<hw>Di*gest"ive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F.
<ets>digestif</ets>, L. <ets>digestivus</ets>.]</ety> <def>Pertaining to
digestion; having the power to cause or promote digestion; <as>as, the
<ex>digestive</ex> ferments</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Digestive</qex> cheese and fruit there sure will be.</q>
<rj><qau>B. Jonson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Digestive apparatus</b></col>, <cd>the organs of food
digestion, esp. the alimentary canal and glands connected with it.</cd>
-- <col><b>Digestive salt</b></col>, <cd>the chloride of
potassium.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Digestive</ent><br/
<hw>Di*gest"ive</hw>, <pos>n.</pos> <sn>1.</sn> <def>That which aids
digestion, as a food or medicine.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>That <qex>digestive</qex> [a cigar] had become to me as necessary
as the meal itself.</q> <rj><qau>Blackw. Mag.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Med.)</fld> <sd>(a)</sd> <def>A substance which,
when applied to a wound or ulcer, promotes suppuration.</def>
<au>Dunglison.</au> <sd>(b)</sd> <def>A tonic.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Digestor</ent><br/
<hw>Di*gest"or</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Digester</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Digesture</ent><br/
<hw>Di*ges"ture</hw> <pr>(?; 135)</pr>, <pos>n.</pos>
<def>Digestion.</def> <mark>[Obs.]</mark> <rj><au>Harvey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diggable</ent><br/
<hw>Dig"ga*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of being
dug.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Digger</ent><br/
<hw>Dig"ger</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, digs.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Digger wasp</b></col> <fld>(Zool.)</fld>, <cd>any one of
the fossorial Hymenoptera.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diggers</ent><br/
<hw>Dig"gers</hw> <pr>(?)</pr>, <pos>n. pl.</pos>; <sing>sing.
<singw>Digger</singw></sing>. <fld>(Ethnol.)</fld> <def>A degraded tribe
of California Indians; -- so called from their practice of digging roots
for food.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Digging</ent><br/
<hw>Dig"ging</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The act
or the place of digging or excavating.</def><br/
<syn><b>Syn. --</b> excavation, dig.</syn><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <pluf>pl.</pluf> <def>Places where ore is dug;
especially, certain localities in California, Australia, and elsewhere,
at which gold is obtained.</def> <mark>[Recent]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <pluf>pl.</pluf> <def>Region; locality.</def>
<mark>[Low]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>a thorough search for something (often causing
disorder or confusion).</def><br/
<syn><b>Syn. --</b> ransacking, rummage.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>diggings</ent><br/
<hw>diggings</hw> <pos>n.</pos> <def>temporary living
quarters.</def><br/
<syn><b>Syn. --</b> digs, domiciliation, lodgings, pad.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dight</ent><br/
<hw>Dight</hw> <pr>(d<imac/t)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Dight</conjf> <it>or</it> <conjf>Dighted</conjf>;
<pos>p. pr. & vb. n.</pos> <conjf>Dighting</conjf>.]</vmorph> <ety>[OF.
<ets>dihten</ets>, AS. <ets>dihtan</ets> to dictate, command, dispose,
arrange, fr. L. <ets>dictare</ets> to say often, dictate, order; cf. G.
<ets>dichten</ets> to write poetry, fr. L. <ets>dictare</ets>. See
<er>Dictate</er>.]</ety> <sn>1.</sn> <def>To prepare; to put in order;
hence, to dress, or put on; to array; to adorn.</def>
<mark>[Archaic]</mark> <ldquo/She gan the house to
<au>dight.</au><rdquo/ <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Two harmless turtles, <qex>dight</qex> for sacrifice.</q>
<rj><qau>Fairfax.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The clouds in thousand liveries <qex>dight</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To have sexual intercourse with.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dighter</ent><br/
<hw>Dight"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who dights.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>digit</ent><br/
<hw>dig"it</hw> <pr>(d<icr/j"<icr/t)</pr>, <pos>n.</pos> <ety>[L.
<ets>digitus</ets> finger; prob. akin to Gr. <grk>da`ktylos</grk>, of
uncertain origin; possibly akin to E. <ets>toe</ets>. Cf.
<er>Dactyl</er>.]</ety> <sn>1.</sn> <fld>(Zool.)</fld> <def>One of the
terminal divisions of a limb appendage; a finger or toe.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The ruminants have the <ldquo/cloven foot,<rdquo/ <it>i. e.</it>,
two hoofed <qex>digits</qex> on each foot.</q>
<rj><qau>Owen.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A finger's breadth, commonly estimated to be three
fourths of an inch.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Math.)</fld> <def>One of the ten figures or
symbols, 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, by which all numbers are
expressed; -- so called because of the use of the fingers in counting
and computing.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ By some authorities the symbol 0 is not included with
the <xex>digits</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Anat.)</fld> <def>One twelfth part of the diameter
of the sun or moon; -- a term used to express the quantity of an
eclipse; <as>as, an eclipse of eight <ex>digits</ex> is one which hides
two thirds of the diameter of the disk</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>digit</ent><br/
<hw>dig"it</hw>, <pos>v. t.</pos> <def>To point at or out with the
finger.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>digital</ent><br/
<hw>dig"i*tal</hw> <pr>(d<icr/j"<icr/*t<ait/l)</pr>, <pos>a.</pos>
<ety>[L. <ets>digitals</ets>.]</ety> <sn>1.</sn> <def>Of or pertaining
to the fingers; done with the fingers; <as>as, <ex>digital</ex>
compression; <ex>digital</ex> examination.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>of or pertaining to digits{3}; expressed in
digits{3}, or using <ex>digits{3}</ex>; <as>as, a <ex>digital</ex>
display; a <ex>digital</ex> clock</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <fld>(Computers)</fld> <def>performing internal logical
and arithmetic operations by means of digits, usually represented as
binary numbers. Contrasted to <contr>analog</contr>, wherein variables
are represented as continuous physical quantities such as voltages or
the position of a pointer on a continuous scale; <as>as, a
<ex>digital</ex> computer</as>.</def><br/
[<source>PJC</source>]</p>

<p><note><hand/ In digital computers, physical quantities in analog
form, such as images, sounds, distances, voltages, etc., must first be
converted to an internal digital representation before calculations can
be performed on them. The conversion may be done by the data enterer, by
approximation, in the case of numerical values, or by analog-to-digital
conversion in the case of light or sound intensities. The latter case
uses special equipment to convert the physical impulses into a digital
value, using a pre-defined encoding system.</note><br/
[<source>PJC</source>]</p>

<p><ent>digital computer</ent><br/
<hw>digital computer</hw> <pos>n.</pos> <sn>1.</sn>
<fld>(Computers)</fld> <def>a computer that represents information by
numerical digits with a fixed number of values; -- most commonly each
piece of information is internally represented in binary code, as an
array of <er>bits</er>, which are information units each of which can
take only two values. The possible values of each <er>bit</er> are
conventionally represented as the numbers 1 or 0.</def> <note>The bits
of information are usually further organized, maniplulated, and
discussed as <er>nybbles</er> (4 bits, rarely used), <er>bytes</er> (8
bits, most commonly used), or <er>words</er> (from 16 to 128 bits, and
in the future probably more). A <er>word</er> is usually defined as the
number of bits that are processed at one time by the central procesor
unit.</note><br/
<syn><b>Syn. --</b> .</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>digitalin</ent><br/
<hw>dig"i*ta`lin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>digitaline</ets>.]</ety> <sd>(a)</sd> <fld>(Medicine,
Pharmacy)</fld> <def>Any one of several extracts of foxglove
(<gen>Digitalis</gen>), as the <ldquo/French extract,<rdquo/ the
<ldquo/German extract,<rdquo/ etc., which differ among themselves in
composition and properties. Both <spn>Digitalis lanata</spn> and
<spn>Digitalis purpurea</spn> have been used to prepare such
extracts.</def> <sd>(b)</sd> <fld>(Chem.)</fld> <def>the distinctive
chemical substance, a <isa>steroid glycoside</isa>, which is the
essential ingredient of the extracts of <prodby>foxglove</prodby>. It is
a white, crystalline substance (<chform>C36H56O14</chform>), and is a
3-substituted diglucoside of a steroid. It is a powerful cardiac
stimulant and is used as a cardiotonic for treatment of certain heart
conditions, such as congestive heart failure. Chemically it is
<chname>(3<beta/,5<beta/,16<beta/)-3-[6-Deoxy-4-O-<beta/-D-glucopyranosyl-3-O-methyl-<beta/-D-galactopyranosyl)oxy]-14,16-dihyroxy-card-20(22)-enolide</chname>.
The related compounds <er>digitoxin</er> and <er>digoxin</er> are also
extracted from the foxglove. The class of steroid glycosides having
cardiotonic properties are referred to as the <isa><ecol><b>cardiac
glycosides</b></ecol></isa>.</def> <au>MI11</au><br/
<syn><b>Syn. --</b> digitalinum verum, Diginorgin, Schmiedeberg's
digitalin, digitalis, digitalis glycoside.</syn>
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Digitalis</ent><br/
<hw>Dig`i*ta"lis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL.: cf. F.
<ets>digitale</ets>. So named (according to Linn<ae/us) from its
finger-shaped corolla.]</ety> <sn>1.</sn> <fld>(Bot.)</fld> <def>A genus
of plants of the family <isa><fam>Schrophulariaceae</fam></isa>,
including the foxglove.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Med.)</fld> <def>The dried leaves of the purple
foxglove (<spn>Digitalis purpurea</spn>), formerly used in heart
disease, disturbance of the circulation, etc. Its use has been largely
replaced by that of the pure active ingredient, <er>digitalin</er>. See
<er>digitalin</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>digitalisation</ent><br/
<hw>digitalisation</hw> <pos>n.</pos> <def>same as
<er>digitalization</er>.</def><br/
<syn><b>Syn. --</b> digitalization.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>digitalization</ent><br/
<hw>digitalization</hw> <pos>n.</pos> <sn>1.</sn> <def>the
administration of digitalis for the treatment of certain heart
disorders.</def><br/
<syn><b>Syn. --</b> digitalisation.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>the effect produced by the administration of
digitalis.</def><br/
[<source>PJC</source>]</p>

<p><ent>digitalize</ent><br/
<hw>digitalize</hw> <pos>v. t.</pos> <sn>1.</sn> <def>to record
digitally, <it>e. g.</it> on digital tape or compact disks.</def><br/
<syn><b>Syn. --</b> digitize.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>to convert from a non-digital form (such as a
voltage or an image or an analog recording) to a digital{2} form, for
storage or transmission.</def><br/
<syn><b>Syn. --</b> digitize.</syn><br/
[<source>PJC</source>]</p>

<p><ent>Digitaria</ent><br/
<hw>Digitaria</hw> <pos>n.</pos> <def>a genus of plants including the
crab grass (<spn>Digitaria sanguinalis</spn>); finger grass.</def><br/
<syn><b>Syn. --</b> genus <gen>Digitaria</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>digitate</ent><br/
<hw>dig"i*tate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[LL.
<ets>digitatus</ets>, p. p. of <ets>digitare</ets>, fr. L.
<ets>digitus</ets>. See <er>Digit</er>.]</ety> <def>To point out as with
the finger.</def> <mark>[R.]</mark> <rj><au>Robinson
(Eudoxa).</au></rj></p>

<p><ent>Digitated</ent><br/
<ent>Digitate</ent><br/
<mhw>{ <hw>Dig"i*tate</hw> <pr>(?)</pr>, <hw>Dig"i*ta`ted</hw>
<pr>(?)</pr> }</mhw>, <pos>a.</pos> <ety>[L. <ets>digitatus</ets> having
fingers.]</ety> <fld>(Bot.)</fld> <def>Having several leaflets arranged,
like the fingers of the hand, at the extremity of a stem or petiole.
Also, in general, characterized by digitation.</def> --
<wordforms><wf>Dig"i*tate*ly</wf> <pr>(#)</pr>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Digitation</ent><br/
<hw>Dig`i*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>digitation</ets>.]</ety> <def>A division into fingers or fingerlike
processes; also, a fingerlike process.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Digitiform</ent><br/
<hw>Dig"i*ti*form</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>digitus</ets> a finger + <ets>-form</ets>.]</ety> <def>Formed like
a finger or fingers; finger-shaped; <as>as, a <ex>digitiform</ex>
root</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Digitigrade</ent><br/
<hw>Dig"i*ti*grade</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>digitus</ets> finger, toe + <ets>gradi</ets> to step, walk: cf. F.
<ets>digitigrade</ets>.]</ety> <fld>(Zool.)</fld> <def>Walking on the
toes; -- distinguished from <contr>plantigrade</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Digitigrade</ent><br/
<hw>Dig"i*ti*grade</hw>, <pos>n.</pos> <fld>(Zool.)</fld> <def>An animal
that walks on its toes, as the cat, lion, wolf, etc.; -- distinguished
from a <xex>plantigrade</xex>, which walks on the palm of the
foot.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Digitipartite</ent><br/
<hw>Dig`i*ti*par"tite</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>digitus</ets> finger + <ets>partite</ets>.]</ety> <fld>(Bot.)</fld>
<def>Parted like the fingers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>digitize</ent><br/
<hw>dig"i*tize</hw> <pr>(d<icr/j"<icr/*t<imac/z)</pr>, <pos>v. t.</pos>
<ety>[<ets>Digit</ets> + <ets>-ize</ets>.]</ety> <sn>1.</sn> <def>To
finger; <as>as, to <ex>digitize</ex> a pen</as>.</def> <mark>[R.]</mark>
<rj><au>Sir T. Browne.</au></rj></p>

<p><sn>2.</sn> <fld>(Computers)</fld> <def>To convert (information, a
signal, an image) into a form expressible in numbers or in binary
notation. The original signal before <ex>digitization</ex> is usually in
<er>analog</er> form.</def> <note><ex>Digitization</ex> allows
convenient storage, accurate reproduction, modification and other
manipulations by digital computers.</note><br/
[<source>PJC</source>]</p>

<p><ent>Digitorium</ent><br/
<hw>Dig`i*to"ri*um</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. L.
<ets>digitus</ets> a finger.]</ety> <def>A small dumb keyboard used by
pianists for exercising the fingers; -- called also <altname>dumb
piano</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>digitoxin</ent><br/
<hw>dig`i*tox"in</hw> <pr>(d<icr/j`<icr/*t<ocr/k"s<icr/n)</pr>,
<pos>n.</pos> <fld>(Chem.)</fld> <def>A <isa>steroid glycoside</isa>,
one of the cardiotonic chemical substances which is extracted from the
<prodby>foxglove</prodby>. It is a white, crystalline substance
(<chform>C41H64O13</chform>), and is a 3-substituted triglucoside of a
steroid, related structurally to digitalin and digoxin. It is used as a
cardiotonic for treatment of certain heart conditions, such as
congestive heart failure. Chemically it is
<chname>(3<beta/,5<beta/)-3-[(O-2,6-Dideoxy-<beta/-D-ribo-hexopyranosyl-(1<rarr/4)-O-2,6-dideoxy-<beta/-D-ribo-hexopyranosyl-(1<rarr/4)-2,6-dideoxy-<beta/-D-ribo-hexopyranosyl)oxy]-14-hydroxy-card-20(22)-enolide</chname>.
The related compounds <er>digitalin</er> and <er>digoxin</er> are also
extracted from the foxglove (<spn>Digitalis lanata</spn> and
<spn>Digitalis purpurea</spn>). The class of steroid glycosides having
cardiotonic properties are refereed to as the <isa><ecol><b>cardiac
glycoside</b></ecol></isa> group.</def> <au>MI11</au><br/
<br/
[<source>PJC</source>]</p>

<p><ent>Digitule</ent><br/
<hw>Dig"i*tule</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>digitulus</ets>, dim. of <ets>digitus</ets>.]</ety>
<fld>(Zool.)</fld> <def>A little finger or toe, or something resembling
one.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Digladiate</ent><br/
<hw>Di*gla"di*ate</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[L.
<ets>digladiari</ets>; <ets>di- = dis-</ets> + <ets>gladius</ets> a
sword.]</ety> <def>To fight like gladiators; to contend fiercely; to
dispute violently.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Digladiating</qex> like <AE/schines and Demosthenes.</q>
<rj><qau>Hales.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Digladiation</ent><br/
<hw>Di*gla`di*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Act of
digladiating.</def> <mark>[Obs.]</mark> <ldquo/Sore
<xex>digladiations</xex> and contest.<rdquo/
<rj><au>Evelyn.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diglottism</ent><br/
<hw>Di*glot"tism</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ speaking
two languages; <grk>di-</grk> = <grk>di`s-</grk> twice + <?/ tongue. See
<er>Glottis</er>.]</ety> <def>Bilingualism.</def> <mark>[R.]</mark>
<rj><au>Earle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diglyph</ent><br/
<hw>Di"glyph</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/;
<grk>di-</grk> = <grk>di`s-</grk> twice + <?/ to hollow out,
carve.]</ety> <fld>(Arch.)</fld> <def>A projecting face like the
triglyph, but having only two channels or grooves sunk in it.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dignation</ent><br/
<hw>Dig*na"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>dignatio</ets>.]</ety> <def>The act of thinking worthy;
honor.</def> <mark>[Obs.]</mark> <rj><au>Jer. Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 412 --></p>

<p><ent>Digne</ent><br/
<hw>Digne</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F., fr. L.
<ets>dignus</ets>. See <er>Design</er>.]</ety> <sn>1.</sn> <def>Worthy;
honorable; deserving.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Suitable; adequate; fit.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Haughty; disdainful.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dignification</ent><br/
<hw>Dig`ni*fi*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Dignify</er>.]</ety> <def>The act of dignifying;
exaltation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dignified</ent><br/
<hw>Dig"ni*fied</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Marked with
dignity; stately; <as>as, a <ex>dignified</ex> judge</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>dignify</ent><br/
<hw>dig"ni*fy</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Dignified</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Dignifying</conjf>.]</vmorph> <ety>[OF.
<ets>dignifier</ets>, fr. LL. <ets>dignificare</ets>; L.
<ets>dignus</ets> worthy + <ets>ficare</ets> (in comp.),
<ets>facere</ets> to make. See <er>Deign</er>, and <er>Fact</er>.]</ety>
<def>To invest with dignity or honor; to make illustrious; to give
distinction to; to exalt in rank; to honor.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Your worth will <qex>dignify</qex> our feast.</q> <rj><qau>B.
Jonson.</qau></rj></p>

<p><syn><b>Syn.</b> -- To exalt; elevate; prefer; advance; honor;
illustrate; adorn; ennoble.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>dignifying</ent><br/
<hw>dignifying</hw> <pos>adj.</pos> <def>serving to make
dignified.</def><br/
<syn><b>Syn. --</b> ennobling.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>dignitary</ent><br/
<hw>dig"ni*ta*ry</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>dignitaries</plw> <pr>(#)</pr>.</plu> <ety>[Cf. F.
<ets>dignitaire</ets>, fr. L. <ets>dignitas</ets>.]</ety> <def>One who
possesses exalted rank or holds a position of dignity or honor;
especially, one who holds an ecclesiastical rank above that of a
parochial priest or clergyman.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dignity</ent><br/
<hw>Dig"ni*ty</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Dignities</plw> <pr>(#)</pr>.</plu> <ety>[OE. <ets>dignete</ets>,
<ets>dignite</ets>, OF. <ets>dignet<eacute/</ets>,
<ets>dignit<eacute/</ets>, F. <ets>dignit<eacute/</ets>, fr. L.
<ets>dignitas</ets>, from <ets>dignus</ets> worthy. See <er>Dainty</er>,
<er>Deign</er>.]</ety> <sn>1.</sn> <def>The state of being worthy or
honorable; elevation of mind or character; true worth;
excellence.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Elevation; grandeur.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>dignity</qex> of this act was worth the audience of
kings.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Elevated rank; honorable station; high office,
political or ecclesiastical; degree of excellence; preferment;
exaltation.</def> <rj><au>Macaulay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And the king said, What honor and <qex>dignity</qex> hath been
done to Mordecai for this?</q> <rj><qau>Esth. vi. 3.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Reuben, thou art my firstborn, . . . the excellency of
<qex>dignity</qex>, and the excellency of power.</q> <rj><qau>Gen. xlix.
3.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Quality suited to inspire respect or reverence;
loftiness and grace; impressiveness; stateliness; -- said of mien,
manner, style, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A letter written with singular energy and <qex>dignity</qex> of
thought and language.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>One holding high rank; a dignitary.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>These filthy dreamers . . . speak evil of
<qex>dignities</qex>.</q> <rj><qau>Jude. 8.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Fundamental principle; axiom; maxim.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Sciences concluding from <qex>dignities</qex>, and principles
known by themselves.</q> <rj><qau>Sir T. Browne.</qau></rj></p>

<p><syn><b>Syn.</b> -- See <er>Decorum</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To stand upon one's dignity</b></col>, <cd>to have or to
affect a high notion of one's own rank, privilege, or
character.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><q>They did not <qex>stand upon their dignity</qex>, nor give their
minds to being or to seeming as elegant and as fine as anybody else.</q>
<rj><qau>R. G. White.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dignotion</ent><br/
<hw>Dig*no"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>dignoscere</ets> to distinguish; <ets>di- = dis-</ets> +
<ets>gnoscere</ets>, <ets>noscere</ets>, to learn to know.]</ety>
<def>Distinguishing mark; diagnostic.</def> <mark>[Obs.]</mark>
<rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Digonous</ent><br/
<hw>Dig"o*nous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/ = <?/
double + <?/ an angle.]</ety> <def>Having two angles.</def>
<rj><au>Smart.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>digoxin</ent><br/
<hw>di*gox"in</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld> <def>a
<isa>steroid glycoside</isa>, one of the cardiotonic chemical substances
which is extracted from the <prodby>foxglove</prodby>. It is a white,
crystalline substance (<chform>C41H64O14</chform>), and is a
3-substituted triglucoside of a steroid, related structurally to
digitalin and digitoxin. It is used as a cardiotonic for treatment of
certain heart conditions, such as congestive heart failure. Chemically
it is
<chname>(3<beta/,5<beta/,12<beta/)-3-[(O-2,6-Dideoxy-<beta/-D-ribo-hexopyranosyl-(1->4)-O-2,6-dideoxy-<beta/-D-ribo-hexopyranosyl-(1->4)-2,6-dideoxy-<beta/-D-ribo-hexopyranosyl)oxy]-12,14-dihydroxy-card-20(22)-enolide</chname>.
The related compounds <er>digitalin</er> and <er>digoxin</er> are also
extracted from the foxglove (<spn>Digitalis lanata</spn> and
<spn>Digitalis purpurea</spn>). The class of steroid glycosides having
cardiotonic properties are referred to as the <isa><ecol><b>cardiac
glycosides</b></ecol></isa>.</def> <au>MI11</au><br/
<br/
[<source>PJC</source>]</p>

<p><ent>Digram</ent><br/
<hw>Di"gram</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <grk>di-</grk> =
<grk>di`s-</grk> twice + <?/ letter.]</ety> <def>A digraph.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Digraph</ent><br/
<hw>Di"graph</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <grk>di-</grk> =
<grk>di`s-</grk> twice + <?/ a writing, <?/ to write.]</ety> <def>Two
signs or characters combined to express a single articulated sound; as
<examp>ea</examp> in <xex>head</xex>, or <examp>th</examp> in
<xex>bath</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Digraphic</ent><br/
<hw>Di*graph"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining
to a digraph.</def> <rj><au>H. Sweet.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Digress</ent><br/
<hw>Di*gress"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Digressed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Digressing</conjf>.]</vmorph> <ety>[L.
<ets>digressus</ets>, p. p. of <ets>digredi</ets> to go apart, to
deviate; <ets>di-</ets> = <ets>dis-</ets> + <ets>gradi</ets> to step,
walk. See <er>Grade</er>.]</ety> <sn>1.</sn> <def>To step or turn aside;
to deviate; to swerve; especially, to turn aside from the main subject
of attention, or course of argument, in writing or speaking.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Moreover she beginneth to <qex>digress</qex> in latitude.</q>
<rj><qau>Holland.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>In the pursuit of an argument there is hardly room to
<qex>digress</qex> into a particular definition as often as a man varies
the signification of any term.</q> <rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To turn aside from the right path; to transgress; to
offend.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Thy abundant goodness shall excuse<br/
This deadly blot on thy <qex>digressing</qex> son.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Digress</ent><br/
<hw>Di*gress"</hw>, <pos>n.</pos> <def>Digression.</def>
<mark>[Obs.]</mark> <rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Digression</ent><br/
<hw>Di*gres"sion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>digressio</ets>: cf. F. <ets>digression</ets>.]</ety> <sn>1.</sn>
<def>The act of digressing or deviating, esp. from the main subject of a
discourse; hence, a part of a discourse deviating from its main design
or subject.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>digressions</qex> I can not excuse otherwise, than by the
confidence that no man will read them.</q> <rj><qau>Sir W.
Temple.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A turning aside from the right path; transgression;
offense.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Then my <qex>digression</qex> is so vile, so base,<br/
That it will live engraven in my face.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Anat.)</fld> <def>The elongation, or angular
distance from the sun; -- said chiefly of the inferior planets.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Digressional</ent><br/
<hw>Di*gres"sion*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to,
or having the character of, a digression; departing from the main
purpose or subject.</def> <rj><au>T. Warton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Digressive</ent><br/
<hw>Di*gress"ive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>digressif</ets>.]</ety> <def>Departing from the main subject;
partaking of the nature of digression.</def>
<rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Digressively</ent><br/
<hw>Di*gress"ive*ly</hw>, <pos>adv.</pos> <def>By way of
digression.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>digs</ent><br/
<hw>digs</hw> <pos>n.</pos> <def>same as <er>diggings</er>.</def>
<mark>[Coll.]</mark> <br/
<syn><b>Syn. --</b> diggings, domiciliation, lodgings, pad.</syn><br/
[<source>PJC</source>]</p>

<p><ent>Digue</ent><br/
<hw>Digue</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. See
<er>Dike</er>.]</ety> <def>A bank; a dike.</def> <mark>[Obs.]</mark>
<rj><au>Sir W. Temple.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Digynia</ent><br/
\'d8<hw>Di*gyn"i*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<grk>di-</grk> = <grk>di`s-</grk> twice + <?/ a woman, a female.]</ety>
<fld>(Bot.)</fld> <def>A Linn<ae/an order of plants having two
styles.</def></p>

<p><ent>Digynous</ent><br/
<ent>Digynian</ent><br/
<mhw>{ <hw>Di*gyn"i*an</hw> <pr>(?)</pr>, <hw>Dig"y*nous</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[Cf. F.
<ets>digyne</ets>.]</ety> <fld>(Bot.)</fld> <def>Of or pertaining to the
Digynia; having two styles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dihedral</ent><br/
<hw>Di*he"dral</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <grk>di-</grk>
= <grk>di`s-</grk> twice + <?/ a seat, bottom, base, fr. <?/ to sit. Cf.
<er>Diedral</er>.]</ety> <sn>1.</sn> <def>Having two plane faces;
<as>as, the <ex>dihedral</ex> summit of a crystal</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of a kite or an a<eum/roplane, having wings that
make with one another a dihedral angle, esp. when the angle between the
upper sides is less than 180<deg/.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>3.</sn> <fld>(A<eum/ronautics)</fld> <def>Of wing pairs, inclined
at an upward angle to each other.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><cs><col><b>Dihedral angle</b></col>, <cd>the angular space contained
between planes which intersect. It is measured by the angle made by any
two lines at right angles to the two planes.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dihedron</ent><br/
<hw>Di*he"dron</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Dihedral</er>.]</ety> <def>A figure with two sides or
surfaces.</def> <rj><au>Buchanan.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dihexagonal</ent><br/
<hw>Di`hex*ag"o*nal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>di-</ets> + <ets>hexagonal</ets>.]</ety> <sd>(a)</sd>
<def>Consisting of two hexagonal parts united; thus, a
<xex>dihexagonal</xex> pyramid is composed of two hexagonal pyramids
placed base to base.</def> <sd>(b)</sd> <def>Having twelve similar
faces; <as>as, a <ex>dihexagonal</ex> prism</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diiamb</ent><br/
<hw>Di`i*amb"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A
diiambus.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diiambus</ent><br/
<hw>Di`i*am"bus</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr. <?/;
<grk>di-</grk> = <grk>di`s-</grk> twice + <?/. See
<er>Lambus</er>.]</ety> <fld>(Pros.)</fld> <def>A double iambus; a foot
consisting of two iambuses (<?/ <?/ <?/ <?/).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diiodide</ent><br/
<hw>Di*i"o*dide</hw> <pr>(?; 104)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>di-</ets> + <ets>iod</ets>ine.]</ety> <fld>(Chem.)</fld> <def>A
compound of a binary type containing two atoms of iodine; -- called also
<altname>biniodide</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>di-iodotyrosine</ent><br/
<ent>diiodotyrosine</ent><br/
<mhw><hw>di*i`o*do*tyr"o*sine</hw>, <hw>di-iodotyrosine</hw></mhw>
<pos>n.</pos> <fld>(Chem., Med.)</fld> <def>a chemical substance
consisting of tyrosine with two hydrogen atoms on the benzene ring
replaced by iodine atoms.</def> <note>The isomer
<chname>3,5-diiodotyrosine</chname> is an inhibitor of thyroid
function.</note><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Diisatogen</ent><br/
<hw>Di`i*sat"o*gen</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>di-</ets> + <ets>isat</ets>ine + <ets>-gen</ets>.]</ety>
<fld>(Chem.)</fld> <def>A red crystalline nitrogenous substance of
artificial production, which by reduction passes directly to
indigo.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dijudicant</ent><br/
<hw>Di*ju"di*cant</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>dijudicans</ets>, p. pr.]</ety> <def>One who dijudicates.</def>
<mark>[R.]</mark> <rj><au>Wood.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dijudicate</ent><br/
<hw>Di*ju"di*cate</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Dijudicated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Dijucating</conjf> <pr>(?)</pr>.]</vmorph> <ety>[L.
<ets>dijudicatus</ets>, p. p. of <ets>dijudicare</ets> to decide;
<ets>di- = dis-</ets> + <ets>judicare</ets> to judge.]</ety> <def>To
make a judicial decision; to decide; to determine.</def>
<mark>[R.]</mark> <rj><au>Hales.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dijudication</ent><br/
<hw>Di*ju`di*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>dijudicatio</ets>.]</ety> <def>The act of dijudicating;
judgment.</def> <mark>[R.]</mark> <rj><au>Cockeram.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dika</ent><br/
\'d8<hw>Di"ka</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Native West African
name.]</ety> <def>A kind of food, made from the almondlike seeds of the
<spn>Irvingia Barteri</spn>, much used by natives of the west coast of
Africa; -- called also <altname>dika bread</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dike</ent><br/
<hw>Dike</hw> <pr>(d<imac/)</pr>, <pos>n.</pos> <ety>[OE.
<ets>dic</ets>, <ets>dike</ets>, <ets>diche</ets>, ditch, AS.
<ets>d<imac/c</ets> dike, ditch; akin to D. <ets>dijk</ets> dike, G.
<ets>deich</ets>, and prob. <ets>teich</ets> pond, Icel.
<ets>d<imac/ki</ets> dike, ditch, Dan. <ets>dige</ets>; perh. akin to
Gr. <grk>tei^chos</grk> (for <grk>qei^chos</grk>) wall, and even E.
<ets>dough</ets>; or perh. to Gr. <grk>ti^fos</grk> pool, marsh. Cf.
<er>Ditch</er>.]</ety> <sn>1.</sn> <def>A ditch; a channel for water
made by digging.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Little channels or <qex>dikes</qex> cut to every bed.</q>
<rj><qau>Ray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An embankment to prevent inundations; a
levee.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Dikes</qex> that the hands of the farmers had raised . . .
<br/
Shut out the turbulent tides.</q> <rj><qau>Longfellow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A wall of turf or stone.</def>
<mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Geol.)</fld> <def>A wall-like mass of mineral
matter, usually an intrusion of igneous rocks, filling up rents or
fissures in the original strata.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dike</ent><br/
<hw>Dike</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Diked</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Diking</conjf>.]</vmorph> <ety>[OE. <ets>diken</ets>,
<ets>dichen</ets>, AS. <ets>d<imac/cian</ets> to dike. See
<er>Dike</er>.]</ety> <sn>1.</sn> <def>To surround or protect with a
dike or dry bank; to secure with a bank.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To drain by a dike or ditch.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dike</ent><br/
<hw>Dike</hw>, <pos>v. i.</pos> <def>To work as a ditcher; to dig.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He would thresh and thereto <qex>dike</qex> and delve.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diker</ent><br/
<hw>Dik"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A
ditcher.</def> <rj><au>Piers Plowman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who builds stone walls; usually, one who builds
them without lime.</def> <mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dilacerate</ent><br/
<hw>Di*lac"er*ate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Dilacerated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Dilacerating</conjf> <pr>(?)</pr>.]</vmorph> <ety>[L.
<ets>dilaceratus</ets>, p. p. of <ets>dilacerare</ets> to tear apart;
<ets>di-</ets> = <ets>dis-</ets> + <ets>lacerare</ets> to tear.]</ety>
<def>To rend asunder; to tear to pieces.</def> <rj><au>Sir T.
Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dilaceration</ent><br/
<hw>Di*lac`er*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>dilaceratio</ets>: cf. F. <ets>dilac<eacute/ration</ets>.]</ety>
<def>The act of rending asunder.</def> <rj><au>Arbuthnot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dilaniate</ent><br/
<hw>Di*la"ni*ate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>dilaniatus</ets>, p. p. of <ets>dilaniare</ets> to dilacerate;
<ets>di- = dis-</ets> + <ets>laniare</ets> to tear to pieces.]</ety>
<def>To rend in pieces; to tear.</def> <mark>[R.]</mark>
<rj><au>Howell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dilaniation</ent><br/
<hw>Di*la`ni*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A rending or
tearing in pieces; dilaceration.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dilapidate</ent><br/
<hw>Di*lap"i*date</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Dilapidated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Dilapidating</conjf> <pr>(?)</pr>.]</vmorph> <ety>[L.
<ets>dilapidare</ets> to scatter like stones; <ets>di- = dis-</ets> +
<ets>lapidare</ets> to throw stones, fr. <ets>lapis</ets> a stone. See
<er>Lapidary</er>.]</ety> <sn>1.</sn> <def>To bring into a condition of
decay or partial ruin, by misuse or through neglect; to destroy the
fairness and good condition of; -- said of a building.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If the bishop, parson, or vicar, etc., <qex>dilapidates</qex> the
buildings, or cuts down the timber of the patrimony.</q>
<rj><qau>Blackstone.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To impair by waste and abuse; to squander.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The patrimony of the bishopric of Oxon was much
<qex>dilapidated</qex>.</q> <rj><qau>Wood.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dilapidate</ent><br/
<hw>Di*lap"i*date</hw>, <pos>v. i.</pos> <def>To get out of repair; to
fall into partial ruin; to become decayed; <as>as, the church was
suffered to <ex>dilapidate</ex></as>.</def>
<rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dilapidated</ent><br/
<hw>Di*lap"i*da`ted</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Decayed;
fallen into partial ruin; injured by bad usage or neglect.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A deserted and <qex>dilapidated</qex> buildings.</q>
<rj><qau>Cooper.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dilapidation</ent><br/
<hw>Di*lap`i*da"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>dilapidatio</ets>: cf. F. <ets>dilapidation</ets>.]</ety>
<sn>1.</sn> <def>The act of dilapidating, or the state of being
dilapidated, reduced to decay, partially ruined, or
squandered.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Tell the people that are relived by the <qex>dilapidation</qex> of
their public estate.</q> <rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Ecclesiastical waste; impairing of church property
by an incumbent, through neglect or by intention.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The business of <qex>dilapidations</qex> came on between our
bishop and the Archibishop of York.</q> <rj><qau>Strype.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Law)</fld> <def>The pulling down of a building, or
suffering it to fall or be in a state of decay.</def>
<rj><au>Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dilapidator</ent><br/
<hw>Di*lap"i*da`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>dilapidateur</ets>.]</ety> <def>One who causes dilapidation.</def>
<rj><au>Strype.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dilatability</ent><br/
<hw>Di*la`ta*bil"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>dilatabilit<eacute/</ets>.]</ety> <def>The quality of being
dilatable, or admitting expansion; -- opposed to
<contr>contractibility</contr>.</def> <rj><au>Ray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dilatable</ent><br/
<hw>Di*lat"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>dilatable</ets>.]</ety> <def>Capable of expansion; that may be
dilated; -- opposed to <contr>contractible</contr>; <as>as, the lungs
are <ex>dilatable</ex> by the force of air; air is <ex>dilatable</ex> by
heat.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dilatation</ent><br/
<hw>Dil`a*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>dilatacioun</ets>, F. <ets>dilatation</ets>, L.
<ets>dilatatio</ets>, fr. <ets>dilatare</ets>. See <er>Dilate</er>, and
cf. 2d <er>Dilation</er>.]</ety> <sn>1.</sn> <def>Prolixity; diffuse
discourse.</def> <mark>[Obs.]</mark> <ldquo/What needeth greater
<xex>dilatation</xex>?<rdquo/ <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The act of dilating; expansion; an enlarging on
al<?/ sides; the state of being dilated; dilation.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Anat.)</fld> <def>A dilation or enlargement of a
canal or other organ.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dilatator</ent><br/
\'d8<hw>Dil`a*ta"tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. Cf. L.
<ets>dilatator</ets> a propagator.]</ety> <fld>(Anat.)</fld> <def>A
muscle which dilates any part; a dilator.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dilate</ent><br/
<hw>Di*late"</hw> <pr>(?; 277)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Dilated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Dilating</conjf> <pr>(?)</pr>.]</vmorph> <ety>[L.
<ets>dilatare</ets>; either fr. <ets>di-</ets> = <ets>dis-</ets> +
<ets>latus</ets> wide, not the same word as <ets>latus</ets>, used as p.
p. of <ets>ferre</ets> to bear (see <er>Latitude</er>); or fr.
<ets>dilatus</ets>, used as p. p. of <ets>differre</ets> to separate
(see <er>Delay</er>, <er>Tolerate</er>, <er>Differ</er>, and cf.
<er>Dilatory</er>): cf. F. <ets>dilater</ets>.]</ety> <sn>1.</sn>
<def>To expand; to distend; to enlarge or extend in all directions; to
swell; -- opposed to <ant>contract</ant>; <as>as, the air
<ex>dilates</ex> the lungs; air is <ex>dilated</ex> by increase of
heat.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To enlarge upon; to relate at large; to tell
copiously or diffusely.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Do me the favor to <qex>dilate</qex> at full<br/
What hath befallen of them and thee till now.</q>
<rj><qau>Shak.</qau></rj></p>

<p><syn><b>Syn.</b> -- To expand; swell; distend; enlarge; spread out;
amplify; expatiate.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dilate</ent><br/
<hw>Di*late"</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To grow wide; to
expand; to swell or extend in all directions.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His heart <qex>dilates</qex> and glories in his strength.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To speak largely and copiously; to dwell in
narration; to enlarge; -- with <xex>on</xex> or
<xex>upon</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>But still on their ancient joys <qex>dilate</qex>.</q>
<rj><qau>Crabbe.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dilate</ent><br/
<hw>Di*late"</hw>, <pos>a.</pos> <def>Extensive; expanded.</def>
<mark>[Obs.]</mark> <rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dilated</ent><br/
<hw>Di*lat"ed</hw>, <pos>a.</pos> <sn>1.</sn> <def>Expanded;
enlarged.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>Widening into a lamina or into
lateral winglike appendages.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <def>Having the margin wide and
spreading.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dilatedly</ent><br/
<hw>Di*lat"ed*ly</hw>, <pos>adv.</pos> <def>In a dilated manner.</def>
<rj><au>Feltham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dilater</ent><br/
<hw>Di*lat"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, dilates, expands, or enlarges.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dilation</ent><br/
<hw>Di*la"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>dilatio</ets>. See <er>Dilatory</er>.]</ety> <def>Delay.</def>
<mark>[Obs.]</mark> <rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dilation</ent><br/
<hw>Di*la"tion</hw>, <pos>n.</pos> <ety>[From <ets>dilate</ets>, v., cf.
<er>Dilatation</er>, <er>Dilator</er>.]</ety> <def>The act of dilating,
or the state of being dilated; expansion; dilatation.</def> <rj><au>Mrs.
Browning.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>At first her eye with slow <qex>dilation</qex> rolled.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A gigantic <qex>dilation</qex> of the hateful figure.</q>
<rj><qau>Dickens.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dilative</ent><br/
<hw>Di*lat"ive</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Causing dilation;
tending to dilate, on enlarge; expansive.</def>
<rj><au>Coleridge.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dilatometer</ent><br/
<hw>Dil`a*tom"e*ter</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Dilate</ets> + <ets>-meter</ets>.]</ety>
<fld>(Physiol.)</fld> <def>An instrument for measuring the dilatation or
expansion of a substance, especially of a fluid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dilator</ent><br/
<hw>Di*lat"or</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Dilate</er>.]</ety> <sn>1.</sn> <def>One who, or that which, widens
or expands.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Anat.)</fld> <def>A muscle that dilates any
part.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Med.)</fld> <def>An instrument for expanding a
part; <as>as, a urethral <ex>dilator</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dilatorily</ent><br/
<hw>Dil"a*to*ri*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>With delay;
tardily.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dilatoriness</ent><br/
<hw>Dil"a*to*ri*ness</hw>, <pos>n.</pos> <def>The quality of being
dilatory; lateness; slowness; tardiness; sluggishness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dilatory</ent><br/
<hw>Dil"a*to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>dilatorius</ets>, fr. <ets>dilator</ets> a delayer, fr.
<ets>dilatus</ets>, used as p. p. of <ets>differe</ets> to defer, delay:
cf. F. <ets>dilatoire</ets>. See <er>Dilate</er>, <er>Differ</er>,
<er>Defer</er>.]</ety> <sn>1.</sn> <def>Inclined to defer or put off
what ought to be done at once; given the procrastination; delaying;
procrastinating; loitering; <as>as, a <ex>dilatory</ex>
servant</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Marked by procrastination or delay; tardy; slow;
sluggish; -- said of actions or measures.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Alva, as usual, brought his <qex>dilatory</qex> policy to bear
upon his adversary.</q> <rj><qau>Motley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dilatory plea</b></col> <fld>(Law)</fld>, <cd>a plea
designed to create delay in the trial of a cause, generally founded upon
some matter not connected with the merits of the case.</cd></cs></p>

<p><syn><b>Syn.</b> -- Slow; delaying; sluggish; inactive; loitering;
behindhand; backward; procrastinating. See <er>Slow</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>dildo</ent><br/
<hw>dil"do</hw> <pr>(d<icr/l"d<osl/)</pr>, <pos>n.</pos> <def>A burden
in popular songs.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Delicate burthens of <qex>dildos</qex> and fadings.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dildo</ent><br/
<hw>Dil"do</hw>, <pos>n.</pos> <fld>(Bot.)</fld> <def>A columnar
cactaceous plant of the West Indies (<spn>Cereus
Swartzii</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>dildo</ent><br/
<hw>dil"do</hw> <pr>(d<icr/l"d<osl/)</pr>, <pos>n.</pos> <def>a device
shaped like an erect penis, used by some women for sexual
stimulation.</def> <mark>[Slang]</mark><br/
[<source>PJC</source>]</p>

<p><ent>Dilection</ent><br/
<hw>Di*lec"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>dilectio</ets>: <ets>dilection</ets>. See <er>Diligent</er>.]</ety>
<def>Love; choice.</def> <mark>[Obs.]</mark> <rj><au>T.
Martin.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dilemma</ent><br/
<hw>Di*lem"ma</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>dilemma</ets>, Gr. <?/; <grk>di-</grk> = <grk>di`s-</grk> twice +
<?/ to take. See <er>Lemma</er>.]</ety> <sn>1.</sn> <fld>(Logic)</fld>
<def>An argument which presents an antagonist with two or more
alternatives, but is equally conclusive against him, whichever
alternative he chooses.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The following are instances of the <xex>dilemma</xex>. A
young rhetorician applied to an old sophist to be taught the art of
pleading, and bargained for a certain reward to be paid when he should
gain a cause. The master sued for his reward, and the scholar endeavored
to elude his claim by a <xex>dilemma</xex>. <ldquo/If I gain my cause, I
shall withhold your pay, because the judge's award will be against you;
if I lose it, I may withhold it, because I shall not yet have gained a
cause.<rdquo/ <ldquo/On the contrary,<rdquo/ says the master, <ldquo/if
you gain your cause, you must pay me, because you are to pay me when you
gain a cause; if you lose it, you must pay me, because the judge will
award it.<rdquo/</note> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A state of things in which evils or obstacles
present themselves on every side, and it is difficult to determine what
course to pursue; a vexatious alternative or predicament; a difficult
choice or position.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A strong <qex>dilemma</qex> in a desperate case!<br/
To act with infamy, or quit the place.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Horns of a dilemma</b></col>, <cd>alternatives, each of
which is equally difficult of encountering.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dilettant</ent><br/
<hw>Dil"et*tant`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining
to dilettanteism; amateur; <as>as, <ex>dilettant</ex>
speculation</as>.</def> <rj><au>Carlyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dilettant</ent><br/
<hw>Dil`et*tant"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A
dilettante.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Though few art lovers can be connoisseurs, many are
<qex>dilettants</qex>.</q> <rj><qau>Fairholt.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dilettante</ent><br/
\'d8<hw>Dil`et*tan"te</hw> <pr>(?)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Dilettanti</plw> <pr>(#)</pr>.</plu> <ety>[It.,
prop. p. pr. of <ets>dillettare</ets> to take delight in, fr. L.
<ets>delectare</ets> to delight. See <er>Delight</er>, <pos>v.
t.</pos>]</ety> <def>An admirer or lover of the fine arts; popularly, an
amateur; especially, one who follows an art or a branch of knowledge,
desultorily, or for amusement only.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 413 --></p>

<p><q>The true poet is not an eccentric creature, not a mere artist
living only for art, not a dreamer or a <qex>dilettante</qex>, sipping
the nectar of existence, while he keeps aloof from its deeper
interests.</q> <rj><qau>J. C. Shairp.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dilettanteish</ent><br/
<hw>Dil`et*tan"te*ish</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Somewhat
like a dilettante.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dilettanteism</ent><br/
<hw>Dil`et*tan"te*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state or
quality of being a dilettante; the desultory pursuit of art, science, or
literature.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dilettantish</ent><br/
<hw>Dil`et*tant"ish</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Dilettanteish.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dilettantism</ent><br/
<hw>Dil`et*tant"ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Dilettanteism</er>.</def> <rj><au>F. Harrison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diligence</ent><br/
<hw>Dil"i*gence</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>diligence</ets>, L. <ets>diligentia</ets>.]</ety> <sn>1.</sn>
<def>The quality of being diligent; carefulness; careful attention; --
the opposite of <xex>negligence</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Interested and persevering application; devoted and
painstaking effort to accomplish what is undertaken; assiduity in
service.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That which ordinary men are fit for, I am qualified in; and the
best of me is <qex>diligence</qex>.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Scots Law)</fld> <def>Process by which persons,
lands, or effects are seized for debt; process for enforcing the
attendance of witnesses or the production of writings.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>To do one's diligence</b></col>, <col><b>give
diligence</b></col>, <col><b>use diligence</b></col></mcol>, <cd>to
exert one's self; to make interested and earnest endeavor.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><q>And each of them <qex>doth</qex> all <qex>his diligence</qex><br/
To do unto the fest<eacute/ reverence.</q>
<rj><qau>Chaucer.</qau></rj></p>

<p><syn><b>Syn.</b> -- Attention; industry; assiduity; sedulousness;
earnestness; constancy; heed; heedfulness; care; caution. --
<er>Diligence</er>, <er>Industry</er>. <xex>Industry</xex> has the wider
sense of the two, implying an habitual devotion to labor for some
valuable end, as knowledge, property, etc. <xex>Diligence</xex> denotes
earnest application to some specific object or pursuit, which more or
less directly has a strong hold on one's interests or feelings. A man
may be <xex>diligent</xex> for a time, or in seeking some favorite end,
without meriting the title of <xex>industrious</xex>. Such was the case
with Fox, while Burke was eminent not only for <xex>diligence</xex>, but
<xex>industry</xex>; he was always at work, and always looking out for
some new field of mental effort.</syn><br/
[<source>1913 Webster</source>]</p>

<p><q>The sweat of <qex>industry</qex> would dry and die,<br/
But for the end it works to.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Diligence</qex> and accuracy are the only merits which an
historical writer ascribe to himself.</q>
<rj><qau>Gibbon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diligence</ent><br/
\'d8<hw>Di`li*gence"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<def>A four-wheeled public stagecoach, used in France.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diligency</ent><br/
<hw>Dil"i*gen*cy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>diligentia</ets>.]</ety> <def>Diligence; care; persevering
endeavor.</def> <mark>[Obs.]</mark> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diligent</ent><br/
<hw>Dil"i*gent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F.
<ets>diligent</ets>, L. <ets>diligens</ets>, <ets>-entis</ets>, p. pr.
of <ets>diligere</ets>, <ets>dilectum</ets>, to esteem highly, prefer;
<ets>di- = dis-</ets> + <ets>legere</ets> to choose. See
<er>Legend</er>.]</ety> <sn>1.</sn> <def>Prosecuted with careful
attention and effort; careful; painstaking; not careless or
negligent.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The judges shall make <qex>diligent</qex> inquisition.</q>
<rj><qau>Deut. xix. 18.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Interestedly and perseveringly attentive; steady and
earnest in application to a subject or pursuit; assiduous;
industrious.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Seest thou a man <qex>diligent</qex> in his business? he shall
stand before kings.</q> <rj><qau>Prov. xxii. 29.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Diligent</qex> cultivation of elegant literature.</q>
<rj><qau>Prescott.</qau></rj></p>

<p><syn><b>Syn.</b> -- Active; assiduous; sedulous; laborious;
persevering; attentive; industrious.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diligently</ent><br/
<hw>Dil"i*gent*ly</hw>, <pos>adv.</pos> <def>In a diligent manner; not
carelessly; not negligently; with industry or assiduity.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Ye <qex>diligently</qex> keep commandments of the Lord your
God.</q> <rj><qau>Deut. vi. 17.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dill</ent><br/
<hw>Dill</hw> <pr>(d<icr/l)</pr>, <pos>n.</pos> <ety>[AS
<ets>dile</ets>; akin to D. <ets>dille</ets>, OHG. <ets>tilli</ets>, G.
<ets>dill</ets>, <ets>dille</ets>, Sw. <ets>dill</ets>, Dan.
<ets>dild</ets>.]</ety> <fld>(Bot.)</fld> <def>An herb (<spn>Peucedanum
graveolens</spn>), the seeds of which are moderately warming, pungent,
and aromatic, and were formerly used as a soothing medicine for
children; -- called also <altname>dillseed</altname>.</def><-- now
<spn>Anethum graveolens</spn> --> <rj><au>Dr. Prior.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dill</ent><br/
<hw>Dill</hw>, <pos>v. t.</pos> <ety>[OE. <ets>dillen</ets>, fr.
<ets>dul</ets> dull, <pos>a.</pos>]</ety> <def>To still; to calm; to
soothe, as one in pain.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>dillenia</ent><br/
<hw>dillenia</hw> <pos>n.</pos> <def>any of several evergreen trees or
shrubs of the genus <gen>Dillenia</gen> grown for their foliage and
nodding magnolialike flowers which are followed by fruit that is used in
curries and jellies and preserves.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dilleniaceae</ent><br/
<hw>Dilleniaceae</hw> <pos>n.</pos> <def>a natural family of chiefly
tropical shrubs and trees and climbers having leathery leaves or
flattened leaflike stems, including the genera
<styp><gen>Dillenia</gen></styp> and
<styp><gen>Hibbertia</gen></styp>.</def><br/
<syn><b>Syn. --</b> family <fam>Dilleniaceae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dilleniidae</ent><br/
<hw>Dilleniidae</hw> <pos>n.</pos> <def>a group of families of more or
less advanced trees and shrubs and herbs having either polypetalous or
gamopetalous corollas and often with ovules attached to the walls of the
ovary; it contains 69 families including <fam>Ericaceae</fam> and
<fam>Cruciferae</fam> and <fam>Malvaceae</fam>; it is sometimes
classified as a superorder.</def><br/
<syn><b>Syn. --</b> subclass <subclass>Dilleniidae</subclass>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dilling</ent><br/
<hw>Dil"ling</hw> <pr>(d<icr/l"l<icr/ng)</pr>, <pos>n.</pos> <def>A
darling; a favorite.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Whilst the birds billing,<br/
Each one with his <qex>dilling</qex>.</q>
<rj><qau>Drayton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dilluing</ent><br/
<hw>Dil*lu"ing</hw> <pr>(d<icr/l*l<umac/"<icr/ng)</pr>, <pos>n.</pos>
<fld>(Min.)</fld> <def>A process of sorting ore by washing in a hand
sieve.</def> <altsp>[Written also <asp>deluing</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>dilly</ent><br/
<hw>dil"ly</hw> <pr>(d<icr/l"l<ycr/)</pr>, <pos>n.</pos> <ety>[Contr.
fr. <ets>diligence</ets>.]</ety> <def>A kind of stagecoach.</def>
<ldquo/The Derby <xex>dilly</xex>.<rdquo/ <rj><au>J. H.
Frere.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>dilly</ent><br/
<hw>dil"ly</hw> <pr>(d<icr/l"l<ycr/)</pr>, <pos>n.</pos> <def>something
remarkable, highly unusual, or exceptionally effective; <as>as, a
<ex>dilly</ex> of a movie; when I make a mistake, it's a
<ex>dilly</ex></as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>dilly-dally</ent><br/
<hw>dil"ly-dal`ly</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[See
<er>Dally</er>.]</ety> <def>To loiter or trifle; to waste
time.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dilogical</ent><br/
<hw>Di*log"ic*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Ambiguous; of
double meaning.</def> <mark>[Obs.]</mark> <rj><au>T.
Adams.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dilogy</ent><br/
<hw>Dil"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Dilogies</plw> <pr>(#)</pr>.</plu> <ety>[L. <ets>dilogia</ets>, Gr.
<?/, fr. <?/ doubtful; <grk>di-</grk> = <grk>di`s-</grk> twice + <?/ to
speak.]</ety> <fld>(Rhet.)</fld> <def>An ambiguous speech; a figure in
which a word is used an equivocal sense.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dilucid</ent><br/
<hw>Di*lu"cid</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>dilucidus</ets>, fr. <ets>dilucere</ets> to be light enough to
distinguish objects apart. See <er>Lucid</er>.]</ety> <def>Clear;
lucid.</def> <mark>[Obs.]</mark> <au>Bacon.</au> --
<wordforms><wf>Di*lu"cid*ly</wf>, <pos>adv.</pos> <mark>[Obs.]</mark> --
<wf>Di`lu*cid"i*ty</wf> <pr>(#)</pr>, <pos>n.</pos>
<mark>[Obs.]</mark></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dilucidate</ent><br/
<hw>Di*lu"ci*date</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>dilucidatus</ets>, p. p. of <ets>dilucidare</ets>.]</ety> <def>To
elucidate.</def> <mark>[Obs.]</mark> <rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dilucidation</ent><br/
<hw>Di*lu`ci*da"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>dilucidatio</ets>.]</ety> <def>The act of making clear.</def>
<mark>[Obs.]</mark> <rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diluent</ent><br/
<hw>Dil"u*ent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>diluens</ets>, p. pr. <ets>diluere</ets>. See
<er>Dilute</er>.]</ety> <def>Diluting; making thinner or weaker by
admixture, esp. of water.</def> <rj><au>Arbuthnot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diluent</ent><br/
<hw>Dil"u*ent</hw>, <pos>n.</pos> <sn>1.</sn> <def>That which
dilutes.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Med.)</fld> <def>An agent used for effecting
dilution of the blood; a weak drink.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There is no real <qex>diluent</qex> but water.</q>
<rj><qau>Arbuthnot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dilute</ent><br/
<hw>Di*lute"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Diluted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Diluting</conjf>.]</vmorph> <ety>[L. <ets>dilutus</ets>, p. p. of
<ets>diluere</ets> to wash away, dilute; <ets>di- = dis-</ets> +
<ets>luere</ets>, equiv. to <ets>lavare</ets> to wash, lave. See
<er>Lave</er>, and cf. <er>Deluge</er>.]</ety> <sn>1.</sn> <def>To make
thinner or more liquid by admixture with something; to thin and dissolve
by mixing.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Mix their watery store.<br/
With the chyle's current, and <qex>dilute</qex> it more.</q>
<rj><qau>Blackmore.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To diminish the strength, flavor, color, etc., of,
by mixing; to reduce, especially by the addition of water; to temper; to
attenuate; to weaken.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Lest these colors should be <qex>diluted</qex> and weakened by the
mixture of any adventitious light.</q> <rj><qau>Sir I.
Newton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dilute</ent><br/
<hw>Di*lute"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To become
attenuated, thin, or weak; <as>as, it <ex>dilutes</ex>
easily</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dilute</ent><br/
<hw>Di*lute"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>dilutus</ets>, p. p.]</ety> <def>Diluted; thin; weak.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>dilute</qex> and waterish exposition.</q>
<rj><qau>Hopkins.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diluted</ent><br/
<hw>Di*lut"ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Reduced in strength;
thin; weak.</def> -- <wordforms><wf>Di*lut"ed*ly</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diluteness</ent><br/
<hw>Di*lute"ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The quality or
state of being dilute.</def> <rj><au>Bp. Wilkins.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diluter</ent><br/
<hw>Di*lut"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, dilutes or makes thin, more liquid, or weaker.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dilution</ent><br/
<hw>Di*lu"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>dilution</ets>.]</ety> <def>The act of diluting, or the state of
being diluted.</def> <rj><au>Arbuthnot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diluvial</ent><br/
<hw>Di*lu"vi*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>diluvialis</ets>. fr. <ets>diluvium</ets>.]</ety> <sn>1.</sn>
<def>Of or pertaining to a flood or deluge, esp. to the great deluge in
the days of Noah; diluvian.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Geol.)</fld> <def>Effected or produced by a flood
or deluge of water; -- said of coarse and imperfectly stratified
deposits along ancient or existing water courses. Similar unstratified
deposits were formed by the agency of ice. The time of deposition has
been called the <xex>Diluvian epoch</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diluvialist</ent><br/
<hw>Di*lu"vi*al*ist</hw>, <pos>n.</pos> <def>One who explains geological
phenomena by the Noachian deluge.</def> <rj><au>Lyell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diluvian</ent><br/
<hw>Di*lu"vi*an</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>diluvien</ets>.]</ety> <def>Of or pertaining to a deluge, esp. to
the Noachian deluge; diluvial; <as>as, of <ex>diluvian</ex>
origin</as>.</def> <rj><au>Buckland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diluviate</ent><br/
<hw>Di*lu"vi*ate</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[L.
<ets>diluviare</ets>.]</ety> <def>To run as a flood.</def>
<mark>[Obs.]</mark> <rj><au>Sir E. Sandys.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diluvium</ent><br/
<hw>Di*lu"vi*um</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it> E.
<plw>Diluviums</plw> <pr>(#)</pr>, L. <plw>Diluvia</plw>
<pr>(#)</pr>.</plu> <ety>[L. <ets>diluvium</ets>. See <er>Dilute</er>,
<er>Deluge</er>.]</ety> <fld>(Geol.)</fld> <def>A deposit of superficial
loam, sand, gravel, stones, etc., caused by former action of flowing
waters, or the melting of glacial ice.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The accumulation of matter by the ordinary operation of
water is termed <xex>alluvium</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dim</ent><br/
<hw>Dim</hw> <pr>(?)</pr>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Dimmer</adjf> <pr>(?)</pr>; <pos>superl.</pos>
<adjf>Dimmest</adjf> <pr>(?)</pr>.]</amorph> <ety>[AS. <ets>dim</ets>;
akin to OFries. <ets>dim</ets>, Icel. <ets>dimmr</ets>: cf. MHG.
<ets>timmer</ets>, <ets>timber</ets>; of uncertain origin.]</ety>
<sn>1.</sn> <def>Not bright or distinct; wanting luminousness or
clearness; obscure in luster or sound; dusky; darkish; obscure;
indistinct; overcast; tarnished.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>dim</qex> magnificence of poetry.</q>
<rj><qau>Whewell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>How is the gold become <qex>dim</qex>!</q> <rj><qau>Lam. iv.
1.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I never saw<br/
The heavens so <qex>dim</qex> by day.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Three sleepless nights I passed in sounding on,<br/
Through words and things, a <qex>dim</qex> and perilous way.</q>
<rj><qau>Wordsworth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of obscure vision; not seeing clearly; hence, dull
of apprehension; of weak perception; obtuse.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Mine eye also is <qex>dim</qex> by reason of sorrow.</q>
<rj><qau>Job xvii. 7.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The understanding is <qex>dim</qex>.</q>
<rj><qau>Rogers.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Obvious compounds: <xex>dim</xex>-eyed;
<xex>dim</xex>-sighted, etc.</note></p>

<p><syn><b>Syn.</b> -- Obscure; dusky; dark; mysterious; imperfect;
dull; sullied; tarnished.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dim</ent><br/
<hw>Dim</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Dimmed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Dimming</conjf>.]</vmorph> <sn>1.</sn> <def>To render dim,
obscure, or dark; to make less bright or distinct; to take away the
luster of; to darken; to dull; to obscure; to eclipse.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A king among his courtiers, who <qex>dims</qex> all his
attendants.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Now set the sun, and twilight <qex>dimmed</qex> the ways.</q>
<rj><qau>Cowper.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To deprive of distinct vision; to hinder from seeing
clearly, either by dazzling or clouding the eyes; to darken the senses
or understanding of.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Her starry eyes were <qex>dimmed</qex> with streaming tears.</q>
<rj><qau>C. Pitt.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dim</ent><br/
<hw>Dim</hw>, <pos>v. i.</pos> <def>To grow dim.</def> <rj><au>J. C.
Shairp.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dimble</ent><br/
<hw>Dim"ble</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Prob. orig., a
cavity, and the same word as <ets>dimple</ets>. See
<er>Dimple</er>.]</ety> <def>A bower; a dingle.</def>
<mark>[Obs.]</mark> <rj><au>Drayton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dime</ent><br/
<hw>Dime</hw> <pr>(d<imac/m)</pr>, <pos>n.</pos> <ety>[F.
<ets>d<icir/me</ets> tithe, OF. <ets>disme</ets>, fr. L.
<ets>decimus</ets> the tenth, fr. <ets>decem</ets> ten. See
<er>Decimal</er>.]</ety> <def>A silver coin of the United States, of the
value of ten cents; the tenth of a dollar.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dime novel</b></col>, <cd>a novel, commonly sensational
and trashy, which is sold for a dime, or ten cents; -- they were popular
from ca. 1850 to ca. 1920. Sometimes the term is still applied to any
novel of the type, though the price has greatly increased.</cd></cs><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Dimension</ent><br/
<hw>Di*men"sion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>dimensio</ets>, fr. <ets>dimensus</ets>, p. p. of
<ets>dimetiri</ets> to measure out; <ets>di- = dis-</ets> +
<ets>metiri</ets> to measure: cf. F. <ets>dimension</ets>. See
<er>Measure</er>.]</ety> <sn>1.</sn> <def>Measure in a single line, as
length, breadth, height, thickness, or circumference; extension;
measurement; -- usually, in the plural, measure in length and breadth,
or in length, breadth, and thickness; extent; size; <as>as, the
<ex>dimensions</ex> of a room, or of a ship; the <ex>dimensions</ex> of
a farm, of a kingdom.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Gentlemen of more than ordinary <qex>dimensions</qex>.</q>
<rj><qau>W. Irving.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Space of dimension</b></col>, <cd>extension that has
length but no breadth or thickness; a straight or curved line.</cd> --
<col><b>Space of two dimensions</b></col>, <cd>extension which has
length and breadth, but no thickness; a plane or curved surface.</cd> --
<col><b>Space of three dimensions</b></col>, <cd>extension which has
length, breadth, and thickness; a solid.</cd> -- <col><b>Space of four
dimensions</b></col>, <cd>as imaginary kind of extension, which is
assumed to have length, breadth, thickness, and also a fourth imaginary
dimension. Space of five or six, or more dimensions is also sometimes
assumed in mathematics.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Extent; reach; scope; importance; <as>as, a project
of large <ex>dimensions</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Math.)</fld> <def>The degree of manifoldness of a
quantity; <as>as, time is quantity having one <ex>dimension</ex>; volume
has three <ex>dimensions</ex>, relative to extension.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Alg.)</fld> <def>A literal factor, as numbered in
characterizing a term. The term <xex>dimensions</xex> forms with the
cardinal numbers a phrase equivalent to <xex>degree</xex> with the
ordinal; thus, <mathex><it>a<exp>2</exp>b<exp>2</exp>c</it></mathex> is
a term of five <xex>dimensions</xex>, or of the fifth degree.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <pluf>pl.</pluf> <fld>(Phys.)</fld> <def>The manifoldness
with which the fundamental units of time, length, and mass are involved
in determining the units of other physical quantities.</def> <note>Thus,
since the unit of velocity varies directly as the unit of length and
inversely as the unit of time, the <ex>dimensions</ex> of velocity are
said to be <mathex>length <divide/ time</mathex>; the
<ex>dimensions</ex> of work are <mathex>mass <times/
(length)<exp>2</exp> <divide/ (time)<exp>2</exp></mathex>; the
<ex>dimensions</ex> of density are <mathex>mass <divide/
(length)<exp>3</exp></mathex>.</note></p>

<p><cs><mcol><col><b>Dimensional lumber</b></col>, <col><b>Dimension
lumber</b></col>, <col><b>Dimension scantling</b></col>, <it>or</it>
<col><b>Dimension stock</b></col></mcol> <fld>(Carp.)</fld>, <cd>lumber
for building, etc., cut to the sizes usually in demand, or to special
sizes as ordered.</cd> -- <col><b>Dimension stone</b></col>, <cd>stone
delivered from the quarry rough, but brought to such sizes as are
requisite for cutting to dimensions given.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dimensional</ent><br/
<hw>Di*men"sion*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to
dimension.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dimensioned</ent><br/
<hw>Di*men"sioned</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having
dimensions.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dimensionless</ent><br/
<hw>Di*men"sion*less</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Without
dimensions; having no appreciable or noteworthy extent.</def>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dimensity</ent><br/
<hw>Di*men"si*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Dimension.</def>
<mark>[R.]</mark> <rj><au>Howell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dimensive</ent><br/
<hw>Di*men"sive</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Without
dimensions; marking dimensions or the limits.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Who can draw the soul's <qex>dimensive</qex> lines?</q>
<rj><qau>Sir J. Davies.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dimera</ent><br/
\'d8<hw>Dim"e*ra</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL., fr. Gr.
<grk>di-</grk> = <grk>di`s-</grk> twice + <?/ part.]</ety>
<fld>(Zool.)</fld> <sd>(a)</sd> <def>A division of Coleoptera, having
two joints to the tarsi.</def> <sd>(b)</sd> <def>A division of the
Hemiptera, including the aphids.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dimeran</ent><br/
<hw>Dim"er*an</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>One of the Dimera.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dimerous</ent><br/
<hw>Dim"er*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <grk>di-</grk>
= <grk>di`s-</grk> twice + <?/ part.]</ety> <def>Composed of, or having,
two parts of each kind.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ A <xex>dimerous</xex> flower has two sepals, two petals,
two stamens, and two pistils.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dimeter</ent><br/
<hw>Dim"e*ter</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>dimeter</ets>, Gr. <?/; <grk>di-</grk> = <grk>di`s-</grk> twice +
<?/ measure.]</ety> <def>Having two poetical measures or meters.</def>
-- <def2><pos>n.</pos> <def>A verse of two meters.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dimethyl</ent><br/
<hw>Di*meth"yl</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>di-</ets> + <ets>methyl</ets>.]</ety> <fld>(Chem.)</fld>
<def>Ethane; -- sometimes so called because regarded as consisting of
two methyl radicals. See <er>Ethane</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dimetric</ent><br/
<hw>Di*met"ric</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Dimeter</er>, <pos>a.</pos>]</ety> <fld>(Crystallog.)</fld>
<def>Same as <er>Tetragonal</er>.</def> <rj><au>Dana.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dimication</ent><br/
<hw>Dim`i*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>dimicatio</ets>, fr. <ets>dimicare</ets> to fight.]</ety> <def>A
fight; contest.</def> <mark>[Obs.]</mark> <rj><au>Bp.
Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dimidiate</ent><br/
<hw>Di*mid"i*ate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>dimidiatus</ets>, p. p. of <ets>dimidiare</ets> to halve, fr.
<ets>dimidius</ets> half. See <er>Demi-</er>.]</ety> <sn>1.</sn>
<def>Divided into two equal parts; reduced to half in shape or
form.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Biol.)</fld> <sd>(a)</sd> <def>Consisting of only
one half of what the normal condition requires; having the appearance of
lacking one half; <as>as, a <ex>dimidiate</ex> leaf, which has only one
side developed</as>.</def> <sd>(b)</sd> <def>Having the organs of one
side, or half, different in function from the corresponding organs on
the other side; <as>as, <ex>dimidiate</ex>
hermaphroditism</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dimidiate</ent><br/
<hw>Di*mid"i*ate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Dimidiated</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Dimidiating</conjf>.]</vmorph> <sn>1.</sn> <def>To divide into
two equal parts.</def> <mark>[Obs.]</mark>
<rj><au>Cockeram.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Her.)</fld> <def>To represent the half of; to
halve.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dimidiation</ent><br/
<hw>Di*mid`i*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>dimidiatio</ets>.]</ety> <def>The act of dimidiating or halving;
the state of being dimidiate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diminish</ent><br/
<hw>Di*min"ish</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Diminished</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Diminishing</conjf>.]</vmorph> <ety>[Pref.
<ets>di-</ets> (= L. <ets>dis-</ets>) + <ets>minish</ets>: cf. L.
<ets>diminuere</ets>, F. <ets>diminuer</ets>, OE. <ets>diminuen</ets>.
See <er>Dis-</er>, and <er>Minish</er>.]</ety> <sn>1.</sn> <def>To make
smaller in any manner; to reduce in bulk or amount; to lessen; --
opposed to <ant>augment</ant> or <ant>increase</ant>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Not <qex>diminish</qex>, but rather increase, the debt.</q>
<rj><qau>Barrow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To lessen the authority or dignity of; to put down;
to degrade; to abase; to weaken.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This doth nothing <qex>diminish</qex> their opinion.</q>
<rj><qau>Robynson (More's Utopia).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I will <qex>diminish</qex> them, that they shall no more rule over
the nations.</q> <rj><qau>Ezek. xxix. 15.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>O thou . . . at whose sight all the stars<br/
Hide their <qex>diminished</qex> heads.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Mus.)</fld> <def>To make smaller by a half step; to
make (an interval) less than minor; <as>as, a <ex>diminished</ex>
seventh</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To take away; to subtract.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Neither shall ye <qex>diminish</qex> aught from it.</q>
<rj><qau>Deut. iv. 2.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Diminished column</b></col>, <cd>one whose upper diameter
is less than the lower.</cd> -- <mcol><col><b>Diminished
scale</b></col>, <it>or</it> <col><b>Diminishing scale</b></col></mcol>,
<cd>a scale of gradation used in finding the different points for
drawing the spiral curve of the volute.</cd> <au>Gwilt.</au> --
<col><b>Diminishing rule</b></col> <fld>(Arch.)</fld>, <cd>a board cut
with a concave edge, for fixing the entasis and curvature of a
shaft.</cd> -- <col><b>Diminishing stile</b></col> <fld>(Arch.)</fld>,
<cd>a stile which is narrower in one part than in another, as in many
glazed doors.</cd></cs></p>

<p><syn><b>Syn.</b> -- To decrease; lessen; abate; reduce; contract;
curtail; impair; degrade. See <er>Decrease</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diminish</ent><br/
<hw>Di*min"ish</hw>, <pos>v. i.</pos> <def>To become or appear less or
smaller; to lessen; <as>as, the apparent size of an object
<ex>diminishes</ex> as we recede from it</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diminishable</ent><br/
<hw>Di*min"ish*a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of
being diminished or lessened.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diminisher</ent><br/
<hw>Di*min"ish*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, diminishes anything.</def> <rj><au>Clerke (1637).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diminishingly</ent><br/
<hw>Di*min"ish*ing*ly</hw>, <pos>adv.</pos> <def>In a manner to
diminish.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diminishment</ent><br/
<hw>Di*min"ish*ment</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Diminution.</def> <mark>[R.]</mark> <rj><au>Cheke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diminuendo</ent><br/
<hw>Di*min`u*en"do</hw> <pr>(?)</pr>, <pos>adv.</pos> <ety>[It., p. pr.
of <ets>diminuere</ets> to diminish.]</ety> <fld>(Mus.)</fld> <def>In a
gradually diminishing manner; with abatement of tone; decrescendo; --
expressed on the staff by <xex>Dim</xex>., or <xex>Dimin</xex>., or the
sign.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diminuent</ent><br/
<hw>Di*min"u*ent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>diminuens</ets>, p. pr. of <ets>diminuere</ets>. See
<er>Diminish</er>.]</ety> <def>Lessening.</def> <rj><au>Bp.
Sanderson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diminutal</ent><br/
<hw>Dim`i*nu"tal</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Indicating or
causing diminution.</def> <rj><au>Earle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diminute</ent><br/
<hw>Dim"i*nute</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Small; diminished;
diminutive.</def> <mark>[Obs.]</mark> <rj><au>Jer. Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diminutely</ent><br/
<hw>Dim"i*nute*ly</hw>, <pos>adv.</pos> <def>Diminutively.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diminution</ent><br/
<hw>Dim`i*nu"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>diminutio</ets>, or perh. rather <ets>deminutio</ets>: cf. F.
<ets>diminution</ets>. See <er>Diminish</er>.]</ety> <sn>1.</sn>
<def>The act of diminishing, or of making or becoming less; state of
being diminished; reduction in size, quantity, or degree; -- opposed to
<ant>augmentation</ant> or <ant>increase</ant>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The act of lessening dignity or consideration, or
the state of being deprived of dignity; a lowering in estimation;
degradation; abasement.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The world's opinion or <qex>diminution</qex> of me.</q>
<rj><qau>Eikon Basilike.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Nor thinks it <qex>diminution</qex> to be ranked<br/
In military honor next.</q> <rj><qau>Philips.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 414 --></p>

<p><sn>3.</sn> <fld>(Law)</fld> <def>Omission, inaccuracy, or defect in
a record.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Mus.)</fld> <def>In counterpoint, the imitation of,
or reply to, a subject, in notes of half the length or value of those
the subject itself.</def></p>

<p><syn><b>Syn.</b> -- Decrease; decay; abatement; reduction; deduction;
decrement.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diminutival</ent><br/
<hw>Di*min`u*ti"val</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Indicating
diminution; diminutive.</def> <ldquo/<xex>Diminutival</xex> forms<rdquo/
[of words]. <au>Earle.</au> -- <def2><pos>n.</pos> <def>A
diminutive.</def> <au>Earle.</au></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diminutive</ent><br/
<hw>Di*min"u*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. L.
<ets>deminutivus</ets>, F. <ets>diminutif</ets>.]</ety> <sn>1.</sn>
<def>Below the average size; very small; little.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Expressing diminution; <as>as, a <ex>diminutive</ex>
word</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Tending to diminish.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Diminutive</qex> of liberty.</q>
<rj><qau>Shaftesbury.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diminutive</ent><br/
<hw>Di*min"u*tive</hw>, <pos>n.</pos> <sn>1.</sn> <def>Something of very
small size or value; an insignificant thing.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Such water flies, <qex>diminutives</qex> of nature.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Gram.)</fld> <def>A derivative from a noun,
denoting a small or a young object of the same kind with that denoted by
the primitive; <as>as, <ex>gosling</ex>, <ex>eaglet</ex>,
<ex>lambkin</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Babyisms and dear <qex>diminutives</qex>.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The word sometimes denotes a derivative verb which
expresses a diminutive or petty form of the action, as
<xex>scribble</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diminutively</ent><br/
<hw>Di*min"u*tive*ly</hw>, <pos>adv.</pos> <def>In a diminutive
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diminutiveness</ent><br/
<hw>Di*min"u*tive*ness</hw>, <pos>n.</pos> <def>The quality of being
diminutive; smallness; littleness; minuteness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dimish</ent><br/
<hw>Dim"ish</hw> <pr>(?)</pr>, <pos>a.</pos> <def>See
<er>Dimmish</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dimission</ent><br/
<hw>Di*mis"sion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>dimissio</ets>. See <er>Dimit</er>, and cf.
<er>Dismission</er>.]</ety> <def>Leave to depart; a dismissing.</def>
<mark>[Obs.]</mark> <rj><au>Barrow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dimissory</ent><br/
<hw>Dim"is*so*ry</hw> <pr>(?; 277)</pr>, <pos>a.</pos> <ety>[L.
<ets>dimissorius</ets>: cf. F. <ets>dimissoire</ets>. See
<er>Dimit</er>.]</ety> <def>Sending away; dismissing to another
jurisdiction; granting leave to depart.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Letters dimissory</b></col> <fld>(Eccl.)</fld>,
<cd>letters given by a bishop dismissing a person who is removing into
another diocese, and recommending him for reception there.</cd>
<rj><au>Hook.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dimit</ent><br/
<hw>Di*mit"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>dimittere</ets> to send away, le<?/ go; <ets>di- = dis-</ets> +
<ets>mittere</ets> to send. See <er>Dismiss</er>.]</ety> <def>To
dismiss, let go, or release.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dimity</ent><br/
<hw>Dim"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Prob. fr. Gr. <?/ of
double thread, dimity; <grk>di-</grk> = <grk>di`s-</grk> twice + <?/ a
thread of the warp; prob. through D. <ets>diemet</ets>, of F.
<ets>dimite</ets>, <ets>d<eacute/mitte</ets>. Cf.
<er>Samite</er>.]</ety> <def>A cotton fabric employed for hangings and
furniture coverings, and formerly used for women's under-garments. It is
of many patterns, both plain and twilled, and occasionally is printed in
colors.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dimly</ent><br/
<hw>Dim"ly</hw>, <pos>adv.</pos> <def>In a dim or obscure manner; not
brightly or clearly; with imperfect sight.</def></p>

<p><ent>Dimmy</ent><br/
<ent>Dimmish</ent><br/
<mhw>{ <hw>Dim"mish</hw> <pr>(?)</pr>, <hw>Dim"my</hw> <pr>(?)</pr>,
}</mhw> <pos>a.</pos> <def>Somewhat dim; <as>as, <ex>dimmish</ex>
eyes</as>.</def> <ldquo/<xex>Dimmy</xex> clouds.<rdquo/ <rj><au>Sir P.
Sidney.</au></rj></p>

<p><ent>Dimness</ent><br/

<hw>Dim"ness</hw>, <pos>n.</pos> <ety>[AS. <ets>dimness</ets>.]</ety>
<sn>1.</sn> <def>The state or quality <?/ being dim; lack of brightness,
clearness, or distinctness; dullness; obscurity.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Dullness, or want of clearness, of vision or of
intellectual perception.</def> <rj><au>Dr. H. More.</au></rj></p>

<p><syn><b>Syn.</b> -- Darkness; obscurity; gloom. See
<er>Darkness</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dimorph</ent><br/
<hw>Di"morph`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ two-formed;
<grk>di`s-</grk> twice (see <er>Di-</er>) + <grk>morfh`</grk>
form.]</ety> <fld>(Crystallog.)</fld> <def>Either one of the two forms
of a dimorphous substance; <as>as, calcite and aragonite are
<ex>dimorphs</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dimorphic</ent><br/
<hw>Di*mor"phic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having the
property of dimorphism; dimorphous.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dimorphism</ent><br/
<hw>Di*mor"phism</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>dimorphisme</ets>.]</ety> <sn>1.</sn> <fld>(Biol.)</fld>
<def>Difference of form between members of the same species, as when a
plant has two kinds of flowers, both hermaphrodite (as in the partridge
berry), or when there are two forms of one or both sexes of the same
species of butterfly.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Dimorphism</qex> is the condition of the appearance of the
same species under two dissimilar forms.</q>
<rj><qau>Darwin.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Crystallog.)</fld> <def>Crystallization in two
independent forms of the same chemical compound, as of calcium carbonate
as calcite and aragonite.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dimorphous</ent><br/
<hw>Di*mor"phous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>dimorphe</ets>.]</ety> <sn>1.</sn> <fld>(Biol.)</fld>
<def>Characterized by dimorphism; occurring under two distinct forms,
not dependent on sex; dimorphic.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Crystallog.)</fld> <def>Crystallizing under two
forms fundamentally different, while having the same chemical
composition.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dimple</ent><br/
<hw>Dim"ple</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Prob. a nasalized
dim. of <ets>dip</ets>. See <er>Dip</er>, and cf.
<er>Dimble</er>.]</ety> <sn>1.</sn> <def>A slight natural depression or
indentation on the surface of some part of the body, esp. on the cheek
or chin.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>dimple</qex> of her chin.</q>
<rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A slight indentation on any surface.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The garden pool's dark surface . . . <br/
Breaks into <qex>dimples</qex> small and bright.</q>
<rj><qau>Wordsworth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dimple</ent><br/
<hw>Dim"ple</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Dimpled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Dimpling</conjf> <pr>(?)</pr>.]</vmorph> <def>To form dimples; to
sink into depressions or little inequalities.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And smiling eddies <qex>dimpled</qex> on the main.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dimple</ent><br/
<hw>Dim"ple</hw>, <pos>v. t.</pos> <def>To mark with dimples or
dimplelike depressions.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dimplement</ent><br/
<hw>Dim"ple*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state of
being dimpled, or marked with gentle depressions.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The ground's most gentle <qex>dimplement</qex>.</q> <rj><qau>Mrs.
Browning.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dimply</ent><br/
<hw>Dim"ply</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Full of dimples, or
small depressions; dimpled; <as>as, the <ex>dimply</ex> pool</as>.</def>
<rj><au>Thomson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dim-sighted</ent><br/
<hw>Dim"-sight`ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having dim
sight; lacking perception.</def> --
<wordforms><wf>Dim"-sight`ed*ness</wf>, <pos>n.</pos></wordforms></p>

<p><ent>dim-witted</ent><br/
<hw>dim-witted</hw> <pos>adj.</pos> <def>mentally retarded; relatively
slow in mental function.</def><br/
<syn><b>Syn. --</b> half-witted, simple, simple-minded.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Dimyaria</ent><br/
<ent>Dimya</ent><br/
<mhw>\'d8<hw>Dim"y*a</hw> <pr>(?)</pr>, <hw>Dim`y*a"ri*a</hw>
<pr>(<?/)</pr></mhw>, <pos>n. pl.</pos> <ety>[NL., fr. Gr. <?/ = <?/ +
<?/ to close.]</ety> <fld>(Zool.)</fld> <def>An order of
lamellibranchiate mollusks having an anterior and posterior adductor
muscle, as the common clam. See <er>Bivalve</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dimyarian</ent><br/
<hw>Dim`y*a"ri*an</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Like or pertaining to the Dimya.</def> -- <def2><pos>n.</pos>
<def>One of the Dimya.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dimyary</ent><br/
<hw>Dim"y*a*ry</hw> <pr>(?)</pr>, <pos>a. & n.</pos> <fld>(Zool.)</fld>
<def>Same as <er>Dimyarian</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Din</ent><br/
<hw>Din</hw> <pr>(d<icr/n)</pr>, <pos>n.</pos> <ety>[AS.
<ets>dyne</ets>, <ets>dyn</ets>; akin to Icel. <ets>dynr</ets>, and to
AS. <ets>dynian</ets> to resound, Icel. <ets>dynja</ets> to pour down
like hail or rain; cf. Skr. <ets>dhuni</ets> roaring, a torrent,
<ets>dhvan</ets> to sound. Cf. <er>Dun</er> to ask payment.]</ety>
<def>Loud, confused, harsh noise; a loud, continuous, rattling or
clanging sound; clamor; roar.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Think you a little <qex>din</qex> can daunt mine ears?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He knew the battle's <qex>din</qex> afar.</q> <rj><qau>Sir W.
Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The dust and <qex>din</qex> and steam of town.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Din</ent><br/
<hw>Din</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Dinned</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Dinning</conjf>.]</vmorph> <ety>[AS. <ets>dynian</ets>. See
<er>Din</er>, <pos>n.</pos>]</ety> <sn>1.</sn> <def>To strike with
confused or clanging sound; to stun with loud and continued noise; to
harass with clamor; <as>as, to <ex>din</ex> the ears with
cries</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To utter with a din; to repeat noisily; to
ding.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This hath been often <qex>dinned</qex> in my ears.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To din into</b></col>, <cd>to fix in the mind of another
by frequent and noisy repetitions.</cd> <rj><au>Sir W.
Scott.</au></rj></cs><-- = to drum into? --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Din</ent><br/
<hw>Din</hw>, <pos>v. i.</pos> <def>To sound with a din; a
ding.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The gay viol <qex>dinning</qex> in the dale.</q> <rj><qau>A.
Seward.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dinaphthyl</ent><br/
<hw>Di*naph"thyl</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>di-</ets> + <ets>naphthyl</ets>ene.]</ety> <fld>(Chem.)</fld>
<def>A colorless, crystalline hydrocarbon, <chform>C20H14</chform>,
obtained from naphthylene, and consisting of a doubled naphthylene
radical.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dinar</ent><br/
<hw>Di"nar</hw> <pr>(d<imac/"n<etil/r <it>or</it> d<esl/*n<aum/r")</pr>,
<pos>n.</pos> <ety>[Ar. <ets>d<imac/n<amac/r</ets>, from Gr.
<grk>dhna`rion</grk>, fr. L. <ets>denarius</ets>. See
<er>Denier</er>.]</ety> <sn>1.</sn> <def>A petty money of accounts of
Persia; 100 <ex>dinars</ex> constituted a
<partof>rial</partof>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An ancient gold coin of the East, issued by various
Islamic countries.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>the unit of currency of Yugoslavia. One dinar equals
100 paras. Abbreviated <abbr>Din.</abbr></def><br/
[<source>PJC</source>]</p>

<p><ent>Dinarchy</ent><br/
<hw>Di"nar*chy</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Diarchy</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dine</ent><br/
<hw>Dine</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Dined</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Dining</conjf>.]</vmorph> <ety>[F. <ets>d<icir/ner</ets>, OF.
<ets>disner</ets>, LL. <ets>disnare</ets>, contr. fr. an assumed
<ets>disjunare</ets>; <ets>dis-</ets> + an assumed <ets>junare</ets>
(OF. <ets>juner</ets>) to fast, for L. <ets>jejunare</ets>, fr.
<ets>jejunus</ets> fasting. See <er>Jejune</er>, and cf.
<er>Dinner</er>, <er>D<eacute/jeuner</er>.]</ety> <def>To eat the
principal regular meal of the day; to take dinner.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Now can I break my fast, <qex>dine</qex>, sup, and sleep.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To dine with Duke Humphrey</b></col>, <cd>to go without
dinner; -- a phrase common in Elizabethan literature, said to be from
the practice of the poor gentry, who beguiled the dinner hour by a
promenade near the tomb of Humphrey, Duke of Gloucester, in Old Saint
Paul's.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dine</ent><br/
<hw>Dine</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To give a dinner to; to
furnish with the chief meal; to feed; <as>as, to <ex>dine</ex> a hundred
men</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A table massive enough to have <qex>dined</qex> Johnnie Armstrong
and his merry men.</q> <rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To dine upon; to have to eat.</def>
<mark>[Obs.]</mark> <ldquo/What will ye <xex>dine</xex>.<rdquo/
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diner</ent><br/
<hw>Din"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
dines.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diner-out</ent><br/
<hw>Din"er-out`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who often
takes his dinner away from home, or in company.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A brilliant <qex>diner-out</qex>, though but a curate.</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dinetical</ent><br/
<hw>Di*net"ic*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/ to whirl
round.]</ety> <def>Revolving on an axis.</def> <mark>[Obs.]</mark>
<rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ding</ent><br/
<hw>Ding</hw> <pr>(d<icr/ng)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Dinged</conjf> <pr>(?)</pr>, <conjf>Dang</conjf>
(<mark>Obs</mark>.), or <conjf>Dung</conjf> (<mark>Obs</mark>.); <pos>p.
pr. & vb. n.</pos> <conjf>Dinging</conjf>.]</vmorph> <ety>[OE.
<ets>dingen</ets>, <ets>dengen</ets>; akin to AS. <ets>dencgan</ets> to
knock, Icel. <ets>dengja</ets> to beat, hammer, Sw.
<ets>d<aum/nga</ets>, G. <ets>dengeln</ets>.]</ety> <sn>1.</sn> <def>To
dash; to throw violently.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>ding</qex> the book a coit's distance from him.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To cause to sound or ring.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To ding (anything) in one's ears</b></col>, <cd>to
impress one by noisy repetition, as if by hammering.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ding</ent><br/
<hw>Ding</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To strike; to thump; to
pound.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Diken, or delven, or <qex>dingen</qex> upon sheaves.</q>
<rj><qau>Piers Plowman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To sound, as a bell; to ring; to clang.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The fretful tinkling of the convent bell evermore
<qex>dinging</qex> among the mountain echoes.</q> <rj><qau>W.
Irving.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To talk with vehemence, importunity, or reiteration;
to bluster.</def> <mark>[Low]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ding</ent><br/
<hw>Ding</hw>, <pos>n.</pos> <def>A thump or stroke, especially of a
bell.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>ding-a-ling</ent><br/
<hw>ding"-a-ling</hw> <def>a stupid or foolish person; -- used in a
deprecatory or contemptuous sense.</def> <mark>[slang]</mark><br/
<syn><b>Syn. --</b> dingdong, doofus.</syn>
[<source>PJC</source>]</p>

<p><ent>ding-dong</ent><br/
<ent>dingdong</ent><br/
<mhw><hw>ding"dong`</hw>, <hw>ding-dong</hw></mhw> <pr>(?)</pr>,
<pos>n.</pos> <ety>[See <er>Ding</er>.]</ety> <sn>1.</sn> <def>The sound
of, or as of, repeated strokes on a metallic body, as a bell; a repeated
and monotonous sound.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Horol.)</fld> <def>An attachment to a clock by
which the quarter hours are struck upon bells of different
tones.</def></p>

<p><sn>3.</sn> <def>a stupid or foolish person; -- used in a deprecatory
or contemptuous sense.</def> <mark>[slang]</mark><br/
<syn><b>Syn. --</b> ding-a-ling, doofus.</syn>
[<source>PJC</source>]</p>

<p><ent>Dingdong theory</ent><br/
<hw>Ding"dong` the"o*ry</hw>. <fld>(Philol.)</fld> <def>The theory which
maintains that the primitive elements of language are reflex expressions
induced by sensory impressions; that is, as stated by <person>Max
M<uum/ller</person>, the creative faculty gave to each general
conception as it thrilled for the first time through the brain a
phonetic expression; -- jocosely so called from the analogy of the sound
of a bell induced by the stroke of the clapper.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Dinghy</ent><br/
<ent>Dingy</ent><br/
<ent>Dingey</ent><br/
<mhw>{ <hw>Din"gey</hw> <pr>(?)</pr>, <hw>Din"gy</hw>, <hw>Din"ghy</hw>
}</mhw>, <pos>n.</pos> <ety>[Bengalee <ets>dingi</ets>.]</ety>
<sn>1.</sn> <def>a small boat propelled by oars or sails, used in the
East Indies, in sheltered waters.</def> <altsp>[Written also
<asp>dinghey</asp>.]</altsp> <rj><au>Malcom.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>a small boat intended to be used as a tender or
lifeboat, carried or towed by a ship. It may be propelled by oars, sail,
or a motor.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>a small boat of shallow draft with cross thwarts for
seats and rowlocks for oars with which it is propelled.</def><br/
<syn><b>Syn. --</b> dory, rowboat.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dingily</ent><br/
<hw>Din"gi*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a dingy
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dinginess</ent><br/
<hw>Din"gi*ness</hw>, <pos>n.</pos> <def>Quality of being dingy; a dusky
hue.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dingle</ent><br/
<hw>Din"gle</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Of uncertain origin:
cf. AS. <ets>ding</ets> prison; or perh. akin to
<ets>dimble</ets>.]</ety> <def>A narrow dale; a small dell; a small,
secluded, and embowered valley.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dingle-dangle</ent><br/
<hw>Din"gle-dan`gle</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a
dangling manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dingo</ent><br/
<hw>Din"go</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>A
wild dog found in Australia, but supposed to have introduced at a very
early period. It has a wolflike face, bushy tail, and a reddish brown
color.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dingthrift</ent><br/
<hw>Ding"thrift`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A
spendthrift.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Wilt thou, therefore, a drunkard be,<br/
A <qex>dingthrift</qex> and a knave?</q> <rj><qau>Drant.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dingy</ent><br/
<hw>Din"gy</hw> <pr>(d<icr/n"j<ycr/)</pr>, <pos>a.</pos>
<amorph>[<pos>Compar.</pos> <adjf>Dingier</adjf> <pr>(?)</pr>;
<pos>superl.</pos> <adjf>Dingiest</adjf>.]</amorph> <ety>[Prob. fr.
<ets>dung</ets>. Cf. <er>Dungy</er>.]</ety> <def>Soiled; sullied; of a
dark or dusky color; dark brown; dirty.</def> <ldquo/Scraps of
<xex>dingy</xex> paper.<rdquo/ <rj><au>Macaulay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dinichthys</ent><br/
\'d8<hw>Di*nich"thys</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<?/ terrible + <?/ fish.]</ety> <fld>(Paleon.)</fld> <def>A genus of
large extinct Devonian ganoid fishes. In some parts of Ohio remains of
the Dinichthys are abundant, indicating animals twenty feet in
length.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dining</ent><br/
<hw>Din"ing</hw> <pr>(?)</pr>, <pos>n. & a.</pos> <def>from
<er>Dine</er>, <pos>a.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Used either adjectively or as the first part of a
compound; as, <xex>dining</xex> hall or <xex>dining</xex>-hall,
<xex>dining</xex> room, <xex>dining</xex> table, etc.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>dining hall</ent><br/
<ent>dining-hall</ent><br/
<ent>dininghall</ent><br/
<mhw><hw>dininghall</hw>, <hw>dining-hall</hw>, <hw>dining
hall</hw></mhw> <pos>n.</pos> <def>a large room at a college or
university, used especially for dining.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>dining room</ent><br/
<ent>diningroom</ent><br/
<mhw><hw>diningroom</hw>, <hw>dining room</hw></mhw> <pos>n.</pos>
<def>a room used for dining. In a residence, it usually contains a
dining table and some furniture, such as a buffet or sideboard, for
storing tableware and dining utensils.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dink</ent><br/
<hw>Dink</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Etymol.
uncertain.]</ety> <def>Trim; neat.</def> <mark>[Scot.]</mark>
<au>Burns.</au> -- <wordforms><wf>Dink"ly</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>dink</ent><br/
<hw>dink</hw>, <pos>v. t.</pos> <def>To deck; -- often with
<ptcl>out</ptcl> or <ptcl>up</ptcl>.</def> <mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>dink</ent><br/
<hw>dink</hw>, <pos>n.</pos> <ety>[ca. 1985, acronym from
<ets>d</ets>ouble <ets>i</ets>ncome <ets>n</ets>o
<ets>k</ets>ids.]</ety> <def>either of a married couple who both are
employed and have no children. The term is often used as the prototype
of middle-class persons with higher-than-average disposable
income.</def><br/
[<source>PJC</source>]</p>

<p><ent>dink</ent><br/
<hw>dink</hw>, <pos>n.</pos> <fld>(Tennis)</fld> <def>a ball hit softly
that falls to the ground just beyond the net.</def><br/
[<source>PJC</source>]</p>

<p><ent>dink</ent><br/
<hw>dink</hw>, <pos>n.</pos> <def>an Asian person, especially a
Vietnamese; -- used contemptuously, considered disparaging and
offensive.</def> <mark>[U.S. slang]</mark><br/
<syn><b>Syn. --</b> slant, slope.</syn>
[<source>PJC</source>]</p>

<p><ent>Dinka</ent><br/
<hw>Dinka</hw> <pos>prop. n.</pos> <def>a Nilotic language.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>dinky</ent><br/
<hw>dinky</hw> <pos>adj.</pos> <sn>1.</sn> <def>small and insignificant;
shabby or unimpressive; <as>as, he drove to work in a <ex>dinky</ex> old
Volkswagen; we stayed in a <ex>dinky</ex> little hotel</as>.</def>
<mark>[informal]</mark><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>pretty and neat; fashionable or well-dressed;
<as>as, what a <ex>dinky</ex> little hat</as>.</def> <mark>[British
informal]</mark><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dinmont</ent><br/
<hw>Din"mont</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>A
wether sheep between one and two years old.</def>
<mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>dinner</ent><br/
<hw>din"ner</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>d<icir/ner</ets>, fr. <ets>d<icir/ner</ets> to dine. See
<er>Dine</er>.]</ety> <sn>1.</sn> <def>The principal meal of the day,
eaten in some countries about midday, but in others (especially in the
U. S. and in large cities) at a later hour.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An entertainment; a feast.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A grand political <qex>dinner</qex>.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <ex>Dinner</ex> is much used, in an obvious sense,
either adjectively or as the first part of a compound; as,
<ex>dinner</ex> time, or <ex>dinner</ex>-time, <ex>dinner</ex> bell,
<ex>dinner</ex> hour, etc.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dinnerless</ent><br/
<hw>Din"ner*less</hw>, <pos>a.</pos> <def>Having no dinner; <as>as, the
naughty child was sent to bed <ex>dinnerless</ex></as>.</def>
<rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dinnerly</ent><br/
<hw>Din"ner*ly</hw>, <pos>a.</pos> <def>Of or pertaining to
dinner.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>dinnerly</qex> officer.</q>
<rj><qau>Copley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>dinnertime</ent><br/
<hw>dinnertime</hw> <pos>n.</pos> <def>the time when people eat dinner,
usually the time for the evening meal.</def><br/
<syn><b>Syn. --</b> suppertime.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dinoceras</ent><br/
\'d8<hw>Di*noc"e*ras</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<?/ terrible + <?/, <?/, horn.]</ety> <fld>(Paleon.)</fld> <def>A genus
of large extinct Eocene mammals from Wyoming; -- called also
<altname><gen>Uintatherium</gen></altname>. See <xex>Illustration</xex>
in Appendix.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ They were herbivorous, and remarkable for three pairs of
hornlike protuberances on the skull. The males were armed with a pair of
powerful canine tusks.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dinocerata</ent><br/
<hw>Dinocerata</hw> <pos>n.</pos> <def>a small order of primitive
ungulates of the Paleocene and Eocene.</def><br/
<syn><b>Syn. --</b> order <ord>Dinocerata</ord>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dinoflagellata</ent><br/
<hw>Dinoflagellata</hw> <pos>n.</pos> <def>and order of plankton, in
some classifications it is considered a phylum of the kingdom Protista;
in others it is included in the plant phylum
<phylum>Pyrrophyta</phylum>. Its members usually have two flagella, one
of which extends from its center.</def><br/
<syn><b>Syn. --</b> order <ord>Dinoflagellata</ord>, Cilioflagellata,
order <ord>Cilioflagellata</ord>.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>dinoflagellate</ent><br/
<hw>dinoflagellate</hw> <pos>n.</pos> <def>a member of the
<ord>Dinoflagellata</ord>, chiefly marine protozoa having two flagella.
The dinoflagellates form a chief constituent of plankton.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dinornis</ent><br/
\'d8<hw>Di*nor"nis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<?/ terrible + <?/ bird.]</ety> <fld>(Paleon.)</fld> <def>A genus of
extinct, ostrichlike birds of gigantic size, which formerly inhabited
New Zealand. See <er>Moa</er>.</def> <altsp>[Written also
<asp>Deinornis</asp>.]</altsp></p>

<p><ent>Dinosaurian</ent><br/
<ent>Dinosaur</ent><br/
<mhw>{ <hw>Di"no*saur</hw> <pr>(?)</pr>, <hw>Di`no*sau"ri*an</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[Gr. <?/ terrible + <?/
lizard.]</ety> <fld>(Paleon.)</fld> <def>One of the Dinosauria.</def>
<altsp>[Written also <asp>deinosaur</asp>, and
<asp>deinosaurian</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dinosauria</ent><br/
\'d8<hw>Di`no*sau"ri*a</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
fr. Gr. <?/ terrible + <?/ lizard.]</ety> <fld>(Paleon.)</fld> <def>An
order of extinct mesozoic reptiles, mostly of large size (whence the
name). Notwithstanding their size, they present birdlike characters in
the skeleton, esp. in the pelvis and hind limbs. Some walked on their
three-toed hind feet, thus producing the large <ldquo/bird
tracks,<rdquo/ so-called, of mesozoic sandstones; others were five-toed
and quadrupedal. See <xex>Illust.</xex> of <er>Compsognathus</er>, also
<xex>Illustration</xex> of <xex>Dinosaur</xex> in Appendix.</def></p>

<p><ent>Dinotherium</ent><br/
<ent>Dinothere</ent><br/
<mhw>{ <hw>Di"no*there</hw> <pr>(?)</pr>, \'d8<hw>Di`no*the"ri*um</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[NL. <ets>dinotherium</ets>,
fr. Gr. <grk>deino`s</grk> terrible + <grk>qhri`on</grk> beast.]</ety>
<fld>(Paleon.)</fld> <def>A large extinct proboscidean mammal from the
miocene beds of Europe and Asia. It is remarkable for a pair of tusks
directed downward from the decurved apex of the lower jaw.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dinoxide</ent><br/
<hw>Din*ox"ide</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>Same as <er>Dioxide</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dinsome</ent><br/
<hw>Din"some</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Full of din.</def>
<mark>[Scot.]</mark> <rj><au>Burns.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dint</ent><br/
<hw>Dint</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>dint</ets>,
<ets>dent</ets>, <ets>dunt</ets>, a blow, AS. <ets>dynt</ets>; akin to
Icel. <ets>dyntr</ets> a dint, <ets>dynta</ets> to dint, and perh. to L.
<ets>fendere</ets> (in composition). Cf. 1st <er>Dent</er>,
<er>Defend</er>.]</ety> <sn>1.</sn> <def>A blow; a stroke.</def>
<mark>[Obs.]</mark> <ldquo/Mortal <xex>dint</xex>.<rdquo/
<au>Milton.</au> <ldquo/Like thunder's <xex>dint</xex>.<rdquo/
<rj><au>Fairfax.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The mark left by a blow; an indentation or
impression made by violence; a dent.</def> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Every <qex>dint</qex> a sword had beaten in it [the shield].</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Force; power; -- esp. in the phrase <xex>by dint
of</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Now you weep; and, I perceive, you feel<br/
The <qex>dint</qex> of pity.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>It was by <qex>dint</qex> of passing strength<br/
That he moved the massy stone at length.</q> <rj><qau>Sir W.
Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dint</ent><br/
<hw>Dint</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Dinted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Dinting</conjf>.]</vmorph> <def>To make a mark or cavity on or
in, by a blow or by pressure; to dent.</def> <rj><au>Donne.
Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dinumeration</ent><br/
<hw>Di*nu`mer*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>dinumeratio</ets>; <ets>di- = dis-</ets> + <ets>numerare</ets> to
count, fr. <ets>numerus</ets> number.]</ety> <def>Enumeration.</def>
<mark>[Obs.]</mark> <rj><au>Bullokar.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diocesan</ent><br/
<hw>Di*oc"e*san</hw> <pr>(?; 277)</pr>, <pos>a.</pos> <ety>[LL.
<ets>dioecesanus</ets>: cf. F. <ets>dioc<eacute/sain</ets>.]</ety>
<def>Of or pertaining to a diocese; <as>as, <ex>diocesan</ex>
missions</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diocesan</ent><br/
<hw>Di*oc"e*san</hw>, <pos>n.</pos> <sn>1.</sn> <def>A bishop, viewed in
relation to his diocese; <as>as, the <ex>diocesan</ex> of New
York</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <pluf>pl.</pluf> <def>The clergy or the people of a
diocese.</def> <rj><au>Strype.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diocese</ent><br/
<hw>Di"o*cese</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Dioceses</plw> <pr>(#)</pr>.</plu> <ety>[OE. <ets>diocise</ets>,
OF. <ets>diocise</ets>, F. <ets>dioc<eacute/se</ets>, L.
<ets>dioecesis</ets>, fr. Gr. <?/ housekeeping, administration, a
province, a diocese, fr. <?/ to keep house, manage; <grk>dia`</grk>
through + <?/ to manage a household, <?/ a house. See
<er>Economy</er>.]</ety> <fld>(Eccl.)</fld> <def>The circuit or extent
of a bishop's jurisdiction; the district in which a bishop exercises his
ecclesiastical authority.</def> <altsp>[Frequently, but improperly,
spelt <asp>diocess</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diocesener</ent><br/
<hw>Di`o*ce"se*ner</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who belongs
to a diocese.</def> <mark>[Obs.]</mark> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diodon</ent><br/
<hw>Di"o*don</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <grk>di-</grk> =
<grk>di`s-</grk> twice + <grk>'odoy`s</grk>, <grk>'odo`ntos</grk>, a
tooth: cf. F. <ets>diodon</ets>.]</ety> <sn>1.</sn> <fld>(Zool.)</fld>
<def>A genus of spinose, plectognath fishes, having the teeth of each
jaw united into a single beaklike plate. They are able to inflate the
body by taking in air or water, and, hence, are called
<altname>globefishes</altname>, <altname>swellfishes</altname>, etc.
Called also <altname>porcupine fishes</altname>, and <altname>sea
hedgehogs</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>A genus of whales.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diodont</ent><br/
<hw>Di"o*dont</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Like or pertaining to the genus Diodon.</def> --
<def2><pos>n.</pos> <def>A fish of the genus Diodon, or an allied
genus.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 415 --></p>

<p><ent>Dioecia</ent><br/
\'d8<hw>Di*<oe/"ci*a</hw> <pr>(d<isl/*<emac/"sh<icr/*<adot/)</pr>,
<pos>n. pl.</pos> <ety>[NL., fr. Gr. <grk>di</grk> = <grk>di`s</grk>
twice + <grk>o'i^kos</grk> a house.]</ety> <sn>1.</sn> <fld>(Bot.)</fld>
<def>A Linn<ae/an class of plants having the stamens and pistils on
different plants.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>A subclass of gastropod mollusks
in which the sexes are separate. It includes most of the large marine
species, like the conchs, cones, and cowries.</def></p>

<p><ent>Dioecious</ent><br/
<ent>Dioecian</ent><br/
<mhw>{ <hw>Di*<oe/"cian</hw> <pr>(?)</pr>, <hw>Di*<oe/"cious</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <fld>(Biol.)</fld> <def>Having the
sexes in two separate individuals; -- applied to plants in which the
female flowers occur on one individual and the male flowers on another
of the same species, and to animals in which the ovum is produced by one
individual and the sperm cell by another; -- opposed to
<contr>mon<oe/cious</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dioeciously</ent><br/
<hw>Di*<oe/"cious*ly</hw>, <pos>adv.</pos> <fld>(Biol.)</fld> <def>In a
di<oe/cious manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Di<oe/ciously hermaphrodite</b></col> <fld>(Bot.)</fld>,
<cd>having flowers structurally perfect, but practically di<oe/cious, --
those on one plant producing no pollen, and those on another no
ovules.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dioeciousness</ent><br/
<hw>Di*<oe/"cious*ness</hw>, <pos>n.</pos> <fld>(Biol.)</fld> <def>The
state or quality of being di<oe/cious.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dioecism</ent><br/
<hw>Di*<oe/"cism</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Biol.)</fld>
<def>The condition of being di<oe/cious.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>dioestrual</ent><br/
<ent>dioestrous</ent><br/
<mhw><hw>dioestrous</hw> <hw>dioestrual</hw></mhw> <pos>adj.</pos>
<def>in a period of sexual inactivity; -- of animals that have several
estrous cycles in one breeding season.</def><br/
<syn><b>Syn. --</b> diestrous, diestrual.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Diogenes</ent><br/
<hw>Di*og"e*nes</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A Greek Cynic
philosopher (412?-323 <sc>B. C.</sc>) who lived much in Athens and was
distinguished for contempt of the common aims and conditions of life,
and for sharp, caustic sayings.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Diogenes' crab</b></col> <fld>(Zool.)</fld>, <cd>a
species of terrestrial hermit crabs (<spn>Cenobita Diogenes</spn>),
abundant in the West Indies and often destructive to crops.</cd> --
<col><b>Diogenes' tub</b></col>, <cd>the tub which the philosopher
Diogenes is said to have carried about with him as his house, in which
he lived.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dioicous</ent><br/
<hw>Di*oi"cous</hw> <pr>(?)</pr>, <pos>a.</pos> <def>See
<er>Di<oe/cious</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diomedea</ent><br/
\'d8<hw>Di*om`e*de"a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL.]</ety>
<fld>(Zool.)</fld> <def>A genus of large sea birds, including the
albatross. See <er>Albatross</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dionaea</ent><br/
\'d8<hw>Di`o*n<ae/"a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<?/ a name of Aphrodite.]</ety> <fld>(Bot.)</fld> <def>An insectivorous
plant. See <er>Venus's flytrap</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dionysia</ent><br/
\'d8<hw>Di`o*ny"si*a</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[L., fr.
Gr. <?/.]</ety> <fld>(Class. Antiq.)</fld> <def>Any of the festivals
held in honor of the Olympian god Dionysus. They correspond to the Roman
Bacchanalia; the greater Dionysia were held at Athens in March or April,
and were celebrated with elaborate performances of both tragedies and
comedies.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Dionysiac</ent><br/
<hw>Di`o*ny"si*ac</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or pertaining
to Dionysus or to the Dionysia; Bacchic; <as>as, a <ex>Dionysiac</ex>
festival; the <ex>Dionysiac</ex> theater at Athens</as>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Dionysian</ent><br/
<hw>Di`o*ny"sian</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Relating to
Dionysius, a monk of the 6th century; <as>as, the <ex>Dionysian</ex>, or
Christian, era</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dionysian period</b></col>, <cd>a period of 532 years,
depending on the cycle of the sun, or 28 years, and the cycle of the
moon, or 19 years; -- sometimes called the <altname>Greek paschal
cycle</altname>, or <altname>Victorian period</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diophantine</ent><br/
<hw>Di`o*phan"tine</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Originated or
taught by Diophantus, the Greek writer on algebra.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Diophantine analysis</b></col> <fld>(Alg.)</fld>,
<cd>that branch of indeterminate analysis which has for its object the
discovery of rational values that satisfy given equations containing
squares or cubes; as, for example, to find values of <xex>x</xex> and
<xex>y</xex> which make <mathex>x<exp>2</exp> + y<exp>2</exp></mathex>
an exact square.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diopside</ent><br/
<hw>Di*op"side</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <grk>di-</grk>
= <grk>di`s-</grk> twice + <?/ a sight, fr. the root of <?/ I shall see:
cf. F. <ets>diopside</ets>.]</ety> <fld>(Min.)</fld> <def>A crystallized
variety of pyroxene, of a clear, grayish green color; mussite.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dioptase</ent><br/
<hw>Di*op"tase</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ =
<grk>dia`</grk> through + <?/ to see: cf. F. <ets>dioptase</ets>.]</ety>
<fld>(Min.)</fld> <def>A hydrous silicate of copper, occurring in
emerald-green crystals.</def></p>

<p><ent>Dioptra</ent><br/
<ent>Diopter</ent><br/
<mhw>{ <hw>Di*op"ter</hw> <pr>(?)</pr>, \'d8<hw>Di*op"tra</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[L. <ets>dioptra</ets>, fr. Gr.
<?/. See 2d <er>Dioptric</er>.]</ety> <def>An optical instrument,
invented by Hipparchus, for taking altitudes, leveling, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dioptre</ent><br/
\'d8<hw>Di*op"tre</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. See 2d
<er>Dioptric</er>.]</ety> <fld>(Optics)</fld> <def>A unit employed by
oculists in numbering glasses according to the metric system; a
refractive power equal to that of a glass whose principal focal distance
is one meter.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dioptric</ent><br/
<hw>Di*op"tric</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Optics)</fld>
<def>Of or pertaining to the dioptre, or to the metric system of
numbering glasses.</def> -- <def2><pos>n.</pos> <def>A dioptre. See
<er>Dioptre</er>.</def></def2></p>

<p><ent>Dioptrical</ent><br/
<ent>Dioptric</ent><br/
<mhw>{ <hw>Di*op"tric</hw> <pr>(?)</pr>, <hw>Di*op"tric*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[Gr. <?/ belonging to the use
of the <?/; <?/ = <grk>dia`</grk> through + the root of <?/ I shall see:
cf. F. <ets>dioptrique</ets>.]</ety> <def>Of or pertaining to dioptrics;
assisting vision by means of the refraction of light; refractive;
<as>as, the <ex>dioptric</ex> system; a <ex>dioptric</ex> glass or
telescope.</as></def> <ldquo/<xex>Dioptrical</xex> principles.<rdquo/
<rj><au>Nichol.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dioptric curve</b></col> <fld>(Geom.)</fld>, <cd>a
Cartesian oval. See under <er>Cartesian</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dioptrics</ent><br/
<hw>Di*op"trics</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ <?/: cf.
F. <ets>dioptrique</ets>.]</ety> <fld>(Optics)</fld> <def>The science of
the refraction of light; that part of geometrical optics which treats of
the laws of the refraction of light in passing from one medium into
another, or through different mediums, as air, water, or glass, and esp.
through different lenses; -- distinguished from <xex>catoptrics</xex>,
which refers to <xex>reflected</xex> light.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dioptry</ent><br/
<hw>Di*op"try</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Optics)</fld>
<def>A dioptre.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diorama</ent><br/
<hw>Di`o*ra"ma</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ to see
through; <?/ = <grk>dia`</grk> through + <?/ to see; cf. <?/ that which
is seen, a sight: cf. F. <ets>diorama</ets>. Cf.
<er>Panorama</er>.]</ety> <sn>1.</sn> <def>A mode of scenic
representation, invented by Daguerre and Bouton, in which a painting is
seen from a distance through a large opening. By a combination of
transparent and opaque painting, and of transmitted and reflected light,
and by contrivances such as screens and shutters, much diversity of
scenic effect is produced.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A building used for such an exhibition.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dioramic</ent><br/
<hw>Di`o*ram"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to a
diorama.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diorism</ent><br/
<hw>Di"o*rism</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/, fr. <?/ to
distinguish; <?/ = <grk>dia`</grk> through + <?/ to divide from, fr. <?/
a boundary.]</ety> <def>Definition; logical direction.</def>
<mark>[Obs.]</mark> <rj><au>Dr. H. More.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dioristic</ent><br/
<hw>Di`o*ris"tic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/.]</ety>
<def>Distinguishing; distinctive; defining.</def> <mark>[R.]</mark> --
<wordforms><wf>Di`o*ris"tic*al*ly</wf> <pr>(#)</pr>, <pos>adv.</pos>
<mark>[R.]</mark></wordforms> <rj><au>Dr. H. More.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diorite</ent><br/
<hw>Di"o*rite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>diorite</ets>. See <er>Diorism</er>.]</ety> <fld>(Min.)</fld>
<def>An igneous, crystalline in structure, consisting essentially of a
triclinic feldspar and hornblende. It includes part of what was called
greenstone.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dioritic</ent><br/
<hw>Di`o*rit"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Containing
diorite.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diorthotic</ent><br/
<hw>Di`or*thot"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/; <?/ =
<?/ + <?/ to set straight.]</ety> <def>Relating to the correcting or
straightening out of something; corrective.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dioscorea</ent><br/
\'d8<hw>Di`os*co"re*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. Named
after <person><etsep>Dioscorides</etsep></person> the Greek
physician.]</ety> <fld>(Bot.)</fld> <def>A genus of plants, the roots of
which are eaten as <prod>yams</prod>. See <er>Yam</er>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Dioscoreaceae</ent><br/
<hw>Dioscoreaceae</hw> <pos>n.</pos> <sn>1.</sn> <def>a natural family
of tuberous plants including the yams.</def><br/
<syn><b>Syn. --</b> family <fam>Dioscoreaceae</fam>, yam
family.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Diota</ent><br/
\'d8<hw>Di*o"ta</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., fr. Gr. <?/
two-handled; <grk>di-</grk> = <grk>di`s-</grk> twice + <?/, <?/, ear,
handle.]</ety> <fld>(Rom. Antiq.)</fld> <def>A vase or drinking cup
having two handles or ears.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dioxide</ent><br/
<hw>Di*ox"ide</hw> <pr>(?; 104)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>di-</ets> + <ets>oxide</ets>.]</ety> <fld>(Chem.)</fld>
<sd>(a)</sd> <def>An oxide containing two atoms of oxygen in each
molecule; binoxide.</def> <sd>(b)</sd> <def>An oxide containing but one
atom or equivalent of oxygen to two of a metal; a suboxide.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Carbon dioxide</b></col>. <cd>See <cref>Carbonic
acid</cref>, under <er>Carbonic</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dioxindol</ent><br/
<hw>Di`ox*in"dol</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>di-</ets> + <ets>ox</ets>ygen + <ets>indol</ets>.]</ety>
<fld>(Chem.)</fld> <def>A white, crystalline, nitrogenous substance
obtained by the reduction of isatin. It is a member of the indol series;
-- hence its name.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dip</ent><br/
<hw>Dip</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Dipped</conjf> <pr>(?)</pr> or <conjf>Dipt</conjf>
(<?/); <pos>p. pr. & vb. n.</pos> <conjf>Dipping</conjf>.]</vmorph>
<ety>[OE. <ets>dippen</ets>, <ets>duppen</ets>, AS. <ets>dyppan</ets>;
akin to Dan. <ets>dyppe</ets>, Sw. <ets>doppa</ets>, and to AS.
<ets>d<?/pan</ets> to baptize, OS. <ets>d<?/pian</ets>, D.
<ets>doopen</ets>, G. <ets>taufen</ets>, Sw. <ets>d<oum/pa</ets>, Goth.
<ets>daupjan</ets>, Lith. <ets>dubus</ets> deep, hollow, OSlav.
<ets>dupl<?/</ets> hollow, and to E. <ets>dive</ets>. Cf. <er>Deep</er>,
<er>Dive</er>.]</ety> <sn>1.</sn> <def>To plunge or immerse; especially,
to put for a moment into a liquid; to insert into a fluid and withdraw
again.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The priest shall <qex>dip</qex> his finger in the blood.</q>
<rj><qau>Lev. iv. 6.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>[Wat'ry fowl] now <qex>dip</qex> their pinions in the briny
deep.</q> <rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>While the prime swallow <qex>dips</qex> his wing.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To immerse for baptism; to baptize by
immersion.</def> <rj><au>Book of Common Prayer. Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To wet, as if by immersing; to moisten.</def>
<mark>[Poetic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>A cold shuddering dew<br/
<qex>Dips</qex> me all o'er.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To plunge or engage thoroughly in any
affair.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He was . . . <qex>dipt</qex> in the rebellion of the Commons.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To take out, by dipping a dipper, ladle, or other
receptacle, into a fluid and removing a part; -- often with
<xex>out</xex>; <as>as, to <ex>dip</ex> water from a boiler; to
<ex>dip</ex> out water.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To engage as a pledge; to mortgage.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Live on the use and never <qex>dip</qex> thy lands.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dipped candle</b></col>, <cd>a candle made by repeatedly
dipping a wick in melted tallow.</cd> -- <col><b>To dip snuff</b></col>,
<cd>to take snuff by rubbing it on the gums and teeth.</cd>
<mark>[Southern U. S.]</mark> -- <col><b>To dip the colors</b></col>
<fld>(Naut.)</fld>, <cd>to lower the colors and return them to place; --
a form of naval salute.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dip</ent><br/
<hw>Dip</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To immerse one's self;
to become plunged in a liquid; to sink.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The sun's rim <qex>dips</qex>; the stars rush out.</q>
<rj><qau>Coleridge.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To perform the action of plunging some receptacle,
as a dipper, ladle. etc.; into a liquid or a soft substance and removing
a part.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Whoever <qex>dips</qex> too deep will find death in the pot.</q>
<rj><qau>L'Estrange.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To pierce; to penetrate; -- followed by
<xex>in</xex> or <xex>into</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>When I <qex>dipt</qex> into the future.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To enter slightly or cursorily; to engage one's self
desultorily or by the way; to partake limitedly; -- followed by
<xex>in</xex> or <xex>into</xex>.</def> <ldquo/<xex>Dipped</xex> into a
multitude of books.<rdquo/ <rj><au>Macaulay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To incline downward from the plane of the horizon;
<as>as, strata of rock <ex>dip</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To dip snuff.</def> <mark>[Southern U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dip</ent><br/
<hw>Dip</hw>, <pos>n.</pos> <sn>1.</sn> <def>The action of dipping or
plunging for a moment into a liquid.</def> <ldquo/The <xex>dip</xex> of
oars in unison.<rdquo/ <rj><au>Glover.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Inclination downward; direction below a horizontal
line; slope; pitch.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>a hollow or depression in a surface, especially in
the ground.</def><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <def>A liquid, as a sauce or gravy, served at table with
a ladle or spoon.</def> <mark>[Local, U.S.]</mark>
<rj><au>Bartlett.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A dipped candle.</def> <mark>[Colloq.]</mark>
<rj><au>Marryat.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>A gymnastic exercise on the parallel bars in which
the performer, resting on his hands, lets his arms bend and his body
sink until his chin is level with the bars, and then raises himself by
straightening his arms.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>7.</sn> <def>In the turpentine industry, the viscid exudation,
which is dipped out from incisions in the trees; <as>as, virgin
<ex>dip</ex> (the runnings of the first year), yellow <ex>dip</ex> (the
runnings of subsequent years)</as>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>8.</sn> <fld>(A<eum/ronautics)</fld> <def>A sudden drop followed
by a climb, usually to avoid obstacles or as the result of getting into
an airhole.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>9.</sn> <def>a liquid, in which objects are soaked by dipping;
e.g., a parasiticide or insecticide solution into which animals are
dipped (see <er>sheep-dip</er>).</def><br/
[<source>PJC</source>]</p>

<p><sn>10.</sn> <def>a sauce into which foods are dipped to enhance the
flavor; e. g., an <stype>onion dip</stype> made from sour cream and
dried onions, into which potato chips are dipped.</def><br/
[<source>PJC</source>]</p>

<p><sn>11.</sn> <def>a <er>pickpocket</er>.</def> <mark>[slang]</mark>
<br/
[<source>PJC</source>]</p>

<p><cs><col><b>Dip of the horizon</b></col> <fld>(Astron.)</fld>,
<cd>the angular depression of the seen or visible horizon below the true
or natural horizon; the angle at the eye of an observer between a
horizontal line and a tangent drawn from the eye to the surface of the
ocean.</cd> -- <mcol><col><b>Dip of the needle</b></col>, <it>or</it>
<col><b>Magnetic dip</b></col></mcol>, <cd>the angle formed, in a
vertical plane, by a freely suspended magnetic needle, or the line of
magnetic force, with a horizontal line; -- called also
<altname>inclination</altname>.</cd> -- <col><b>Dip of a
stratum</b></col> <fld>(Geol.)</fld>, <cd>its greatest angle of
inclination to the horizon, or that of a line perpendicular to its
direction or strike; -- called also the
<altname>pitch</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dipaschal</ent><br/
<hw>Di*pas"chal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>di-</ets> + <ets>paschal</ets>.]</ety> <def>Including two
passovers.</def> <rj><au>Carpenter.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dipchick</ent><br/
<hw>Dip"chick`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>See <er>Dabchick</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dipetalous</ent><br/
<hw>Di*pet"al*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>di-</ets> + <ets>petalous</ets>.]</ety> <fld>(Bot.)</fld>
<def>Having two petals; two-petaled.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diphenyl</ent><br/
<hw>Di*phe"nyl</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>di-</ets> + <ets>phenyl</ets>.]</ety> <fld>(Chem.)</fld> <def>A
white crystalline substance, <chform>C6H5.C6H5</chform>, obtained by
leading benzene through a heated iron tube. It consists of two benzene
or phenyl radicals united.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diphtheria</ent><br/
<hw>Diph*the"ri*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<?/ leather (hence taken in the sense of <ets>membrane</ets>): cf. <?/
to make soft, L. <ets>depsere</ets> to knead.]</ety> <fld>(Med.)</fld>
<def>A very dangerous contagious disease in which the air passages, and
especially the throat, become coated with a false membrane, produced by
the solidification of an inflammatory exudation. Cf.
<er>Group</er>.</def></p>

<p><ent>Diphtheric</ent><br/
<ent>Diphtherial</ent><br/
<mhw>{ <hw>Diph*the"ri*al</hw> <pr>(?)</pr>, <hw>Diph*ther"ic</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <def>Relating to diphtheria;
diphtheritic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diphtheritic</ent><br/
<hw>Diph`the*rit"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Med.)</fld>
<sn>1.</sn> <def>Pertaining to, or connected with, diphtheria.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Having characteristics resembling those of
diphtheria; <as>as, <ex>diphtheritic</ex> inflammation of the
bladder</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diphthong</ent><br/
<hw>Diph"thong</hw> <pr>(?; 115, 277)</pr>, <pos>n.</pos> <ety>[L.
<ets>diphthongus</ets>, Gr. <?/; <grk>di-</grk> = <grk>di`s-</grk> twice
+ <?/ voice, sound, fr. <?/ to utter a sound: cf. F.
<ets>diphthongue</ets>.]</ety> <fld>(Ortho<eum/py)</fld> <sd>(a)</sd>
<def>A coalition or union of two vowel sounds pronounced in one
syllable; as, <xex>ou</xex> in <xex>out</xex>, <xex>oi</xex> in
<xex>noise</xex>; -- called a <stype>proper diphthong</stype>.</def>
<sd>(b)</sd> <def>A vowel digraph; a union of two vowels in the same
syllable, only one of them being sounded; as, <xex>ai</xex> in
<xex>rain</xex>, <xex>eo</xex> in <xex>people</xex>; -- called an
<stype>improper diphthong</stype>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diphthong</ent><br/
<hw>Diph"thong</hw>, <pos>v. t.</pos> <def>To form or pronounce as a
diphthong; diphthongize.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diphthongal</ent><br/
<hw>Diph*thon"gal</hw> <pr>(?; 115)</pr>, <pos>a.</pos> <def>Relating or
belonging to a diphthong; having the nature of a diphthong.</def> --
<wordforms><wf>Diph*thon"gal*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diphthongalize</ent><br/
<hw>Diph*thon"gal*ize</hw> <pr>(?; 115)</pr>, <pos>v. t.</pos> <def>To
make into a diphthong; to pronounce as a diphthong.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diphthongation</ent><br/
<hw>Diph`thon*ga"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Diphthongization</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diphthongic</ent><br/
<hw>Diph*thong"ic</hw> <pr>(?; 115)</pr>, <pos>a.</pos> <def>Of the
nature of diphthong; diphthongal.</def> <rj><au>H. Sweet.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diphthongization</ent><br/
<hw>Diph`thong*i*za"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act
of changing into a diphthong.</def> <rj><au>H. Sweet.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diphthongize</ent><br/
<hw>Diph"thong*ize</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <def>To
change into a diphthong, as by affixing another vowel to a simple
vowel.</def> <ldquo/The <xex>diphthongized</xex> long vowels.<rdquo/
<rj><au>H. Sweet.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diphycercal</ent><br/
<hw>Diph`y*cer"cal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>difyh`s</grk> double (<grk>di-</grk> = <grk>di`s-</grk> twice +
<grk>fy`ein</grk> to produce) + <grk>ke`rkos</grk> tail.]</ety>
<fld>(Anat.)</fld> <def>Having the tail fin divided into two equal parts
by the notochord, or end of the vertebral column; protocercal. See
<er>Protocercal</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diphygenic</ent><br/
<hw>Diph`y*gen"ic</hw> <pr>(-j<ecr/n"<icr/k)</pr>, <pos>a.</pos>
<ety>[Gr. <grk>difyh`s</grk> of double form + <ets>-genic</ets>.]</ety>
<fld>(Zool.)</fld> <def>Having two modes of embryonic
development.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diphyllous</ent><br/
<hw>Diph"yl*lous</hw> <pr>(d<icr/f"<icr/l*l<ucr/s <it>or</it>
d<isl/*f<icr/l"-)</pr>, <pos>a.</pos> <ety>[Gr. <grk>di-</grk> =
<grk>di`s-</grk> twice + <grk>fy`llon</grk> leaf: cf. F.
<ets>diphylle</ets>.]</ety> <fld>(Bot.)</fld> <def>Having two leaves, as
a calyx, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diphyodont</ent><br/
<hw>Diph"y*o*dont</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/ double
(<grk>di-</grk> = <grk>di`s-</grk> twice + <?/ to produce) +
<grk>'odoy`s</grk>, <grk>'odo`ntos</grk>, tooth.]</ety>
<fld>(Anat.)</fld> <def>Having two successive sets of teeth (deciduous
and permanent), one succeeding the other; <as>as, a <ex>diphyodont</ex>
mammal; <ex>diphyodont</ex> dentition</as>; -- opposed to
<contr>monophyodont</contr>.</def> -- <def2><pos>n.</pos> <def>An animal
having two successive sets of teeth.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diphyozooid</ent><br/
<hw>Diph`y*o*zo"oid</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ of
double from + E. <ets>zooid</ets>.]</ety> <fld>(Zool.)</fld> <def>One of
the free-swimming sexual zooids of Siphonophora.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diplanar</ent><br/
<hw>Di*pla"nar</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>di-</ets> + <ets>plane</ets>.]</ety> <fld>(Math.)</fld> <def>Of or
pertaining to two planes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dipleidoscope</ent><br/
<hw>Di*plei"do*scope</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/
double + <?/ image + <ets>-scope</ets>.]</ety> <fld>(Astron.)</fld>
<def>An instrument for determining the time of apparent noon. It
consists of two mirrors and a plane glass disposed in the form of a
prism, so that, by the reflections of the sun's rays from their
surfaces, two images are presented to the eye, moving in opposite
directions, and coinciding at the instant the sun's center is on the
meridian.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diplex</ent><br/
<hw>Di"plex</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref. <ets>di-</ets>
+ <ets>-plex</ets>, as in du<ets>plex</ets>.]</ety> <fld>(Teleg.)</fld>
<def>Pertaining to the sending of two messages in the same direction at
the same time. <ex>Diplex</ex> and <contr>contraplex</contr> are the two
varieties of <isa>duplex</isa>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Diploblastic</ent><br/
<hw>Dip`lo*blas"tic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/
doublet + <ets>-blast</ets> + <ets>-ic</ets>.]</ety> <fld>(Biol.)</fld>
<def>Characterizing the ovum when it has two primary germinal
layers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diplocardiac</ent><br/
<hw>Dip`lo*car"di*ac</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/
double + E. <ets>cardiac</ets>.]</ety> <fld>(Anat.)</fld> <def>Having
the heart completely divided or double, one side systemic, the other
pulmonary.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diplococcus</ent><br/
\'d8<hw>Dip`lo*coc"cus</hw> <pr>(?)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Diplococci</plw> <pr>(#)</pr>.</plu> <ety>[NL.,
fr. Gr. <grk>diplo`os</grk> twofold + <grk>ko`kkos</grk> grain,
seed.]</ety> <fld>(Biol.)</fld> <def>A form of micrococcus in which
cocci are united in a binary manner. See <er>Micrococcus</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diploe</ent><br/
\'d8<hw>Dip"lo*<eum/</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<?/ fold, fr. <?/ twofold, double.]</ety> <fld>(Anat.)</fld> <def>The
soft, spongy, or cancellated substance between the plates of the
skull.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diploetic</ent><br/
<hw>Dip`lo*et"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Anat.)</fld>
<def>Diploic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diplogenic</ent><br/
<hw>Dip`lo*gen"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/ double
+ the root of <?/ to produce.]</ety> <def>Partaking of the nature of two
bodies; producing two substances.</def> <rj><au>Wright.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diplograph</ent><br/
<hw>Dip"lo*graph</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ double +
<ets>-graph</ets>.]</ety> <def>An instrument used for double writing, as
one for producing embossed writing for the blind and ordinary writing at
the same time.</def> -- <wordforms><wf>Dip`lo*graph"ic*al</wf>
<pr>(#)</pr>, <pos>a.</pos> -- <wf>Dip*log"ra*phy</wf> <pr>(#)</pr>,
<pos>n.</pos></wordforms><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Diploic</ent><br/
<hw>Di*plo"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Anat.)</fld>
<def>Of or pertaining to the diplo<eum/.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>diploid</ent><br/
<hw>dip"loid</hw> <pr>(d<icr/p"loid)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>diplo`os</grk> twofold + <ets>-oid</ets>.]</ety> <sn>1.</sn>
<fld>(Crystallog.)</fld> <def>A solid bounded by twenty-four similar
quadrilateral faces. It is a hemihedral form of the
hexoctahedron.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Biol.)</fld> <def>a cell or organism having a
number of chromosomes corresponding to two copies of each chromosome; a
diploid cell or organism.</def><br/
[<source>PJC</source>]</p>

<p><q>A: I'm not interested in diploids.<br/
B: Oh, how I wish your parents had felt the same way!</q></p>

<p><ent>diploid</ent><br/
<hw>dip"loid</hw> <pr>(d<icr/p"loid)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>diplo`os</grk> twofold + <ets>-oid</ets>.]</ety> <fld>(Biol.)</fld>
<def>having a number of chromosomes corresponding to two copies of each
chromosome; having double the basic number of chromosomes, as seen in a
haploid cell. Contrasted to <contr>haploid</contr> and
<contr>polyploid</contr>.</def> <note>in diploid cells, although the
number of chromosomes is double that in haploid cells, it is not always
true that there are two copies of every chromosome, since the two sex
chromosomes in males will differ from each other. In females, and for
other chromosomes, however, there are generally two copies of each,
giving rise to the classical hereditary and sorting patterns of
Mendelian genetics.</note><br/
[<source>PJC</source>]</p>

<p><ent>Diploma</ent><br/
<hw>Di*plo"ma</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Diplomas</plw> <pr>(#)</pr>.</plu> <ety>[L., fr. Gr. <?/, fr. <?/
to double, fr. <grk>diplo`os</grk> twofold. See <er>Double</er>.]</ety>
<def>A letter or writing, usually under seal, conferring some privilege,
honor, or power; a document bearing record of a degree conferred by a
literary society or educational institution.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diplomacy</ent><br/
<hw>Di*plo"ma*cy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>diplomatie</ets>. This word, like <ets>supremacy</ets>, retains the
accent of its original. See <er>Diploma</er>.]</ety> <sn>1.</sn>
<def>The art and practice of conducting negotiations between nations
(particularly in securing treaties), including the methods and forms
usually employed.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Dexterity or skill in securing advantages;
tact.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The body of ministers or envoys resident at a court;
the diplomatic body.</def> <mark>[R.]</mark>
<rj><au>Burke.</au></rj></p>

<p><ent>Diplomate</ent><br/
<ent>Diplomat</ent><br/
<mhw>{ <hw>Dip"lo*mat</hw> <pr>(?)</pr>, <hw>Dip"lo*mate</hw>
<pr>(?)</pr> }</mhw>, <pos>n.</pos> <ety>[F.
<ets>diplomate</ets>.]</ety> <def>A diplomatist.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diplomate</ent><br/
<hw>Dip"lo*mate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To invest with
a title or privilege by diploma.</def> <mark>[R.]</mark>
<rj><au>Wood.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diplomatial</ent><br/
<hw>Dip`lo*ma"tial</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Diplomatic.</def> <mark>[R.]</mark></p>

<p><ent>Diplomatical</ent><br/
<ent>Diplomatic</ent><br/
<mhw>{ <hw>Dip`lo*mat"ic</hw> <pr>(?)</pr>, <hw>Dip`lo*mat"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[Cf.
<ets>diplomatique</ets>.]</ety> <sn>1.</sn> <def>Pertaining to
diplomacy; relating to the foreign ministers at a court, who are called
the <xex>diplomatic body</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Characterized by tact and shrewdness; dexterous;
artful; <as>as, <ex>diplomatic</ex> management</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Pertaining to diplomatics; paleographic.</def>
<rj><au>Astle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diplomatic</ent><br/
<hw>Dip`lo*mat"ic</hw>, <pos>n.</pos> <def>A minister, official agent,
or envoy to a foreign court; a diplomatist.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diplomatically</ent><br/
<hw>Dip`lo*mat"ic*al*ly</hw>, <pos>adv.</pos> <def>According to the
rules of diplomacy; in the manner of a diplomatist; artfully.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diplomatics</ent><br/
<hw>Dip`lo*mat"ics</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The science of
diplomas, or the art of deciphering ancient writings, and determining
their age, authenticity, etc.; paleography.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diplomatism</ent><br/
<hw>Di*plo"ma*tism</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Diplomacy.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diplomatist</ent><br/
<hw>Di*plo"ma*tist</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>diplomatiste</ets> a student of diplomatics.]</ety> <def>A person
employed in, or skilled in, diplomacy; a diplomat.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In ability, Avaux had no superior among the numerous able
<qex>diplomatists</qex> whom his country then possessed.</q>
<rj><qau>Macaulay.</qau></rj></p>

<p><ent>Diplopy</ent><br/
<ent>Diplopia</ent><br/
<mhw>{ \'d8<hw>Di*plo"pi*a</hw> <pr>(?)</pr>, <hw>Dip"lo*py</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[NL. <ets>diplopia</ets>, from
Gr. <?/ double + the root of <?/ sight: cf. F.
<ets>diplopie</ets>.]</ety> <fld>(Med.)</fld> <def>The act or state of
seeing double.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In <xex>crossed</xex> or <xex>heteronymous
diplopia</xex> the image seen by the right eye is upon the left hand,
and that seen by the left eye is upon the right hand. In <xex>homonymous
diplopia</xex> the image seen by the right eye is on the right side,
that by the left eye on the left side. In <xex>vertical diplopia</xex>
one image stands above the other.</note><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 416 --></p>

<p><ent>Diplopod</ent><br/
<hw>Dip"lo*pod</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>One of the Diplopoda.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diplopoda</ent><br/
\'d8<hw>Di*plop"o*da</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[Gr. <?/
double + <ets>-poda</ets>.]</ety> <fld>(Zool.)</fld> <def>An order of
myriapods having two pairs of legs on each segment; the
Chilognatha.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diplostemonous</ent><br/
<hw>Dip`lo*stem"o*nous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/
double + <?/ the warp, a thread.]</ety> <fld>(Bot.)</fld> <def>Having
twice as many stamens as petals, as the geranium.</def> <rj><au>R.
Brown.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diplostemony</ent><br/
<hw>Dip`lo*stem"o*ny</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>The condition of being diplostemonous.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>diplotene</ent><br/
<hw>diplotene</hw> <pos>n.</pos> <fld>(Cell biol.)</fld> <def>the fourth
stage of the prophase of meiosis, when the paired chromosomes being to
separate. This stage follows the <contr>pachytene</contr>.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Dipneumona</ent><br/
\'d8<hw>Dip*neu"mo*na</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
fr. Gr. <?/ = <?/ lung.]</ety> <fld>(Zool.)</fld> <def>A group of
spiders having only two lunglike organs.</def> <altsp>[Written also
<asp>Dipneumones</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dipnoi</ent><br/
\'d8<hw>Dip"no*i</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL., fr. Gr.
<?/ <?/ with two breathing apertures; <grk>di-</grk> = <grk>di`s-</grk>
twice + <?/ breath.]</ety> <fld>(Zool.)</fld> <def>A group of ganoid
fishes, including the living genera <gen>Ceratodus</gen> and
<gen>Lepidosiren</gen>, which present the closest approximation to the
Amphibia. The air bladder acts as a lung, and the nostrils open inside
the mouth. See <er>Ceratodus</er>, and <xex>Illustration</xex> in
Appendix.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dipodomys</ent><br/
<hw>Dipodomys</hw> <pos>n.</pos> <def>a genus of rodents of the family
<fam>Heteromyidae</fam>, comprising the genus of kangaroo rats which
live in arid regions of Mexico and the western U. S.</def> <note>An
Australian rodent of the genus <gen>Notomys</gen> is also referred to as
a <er>kangaroo rat</er>, as is the potoroo. See <er>kangaroo
rat</er></note><br/
<syn><b>Syn. --</b> genus <gen>Dipodomys</gen>.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Dipogon</ent><br/
<hw>Dipogon</hw> <pos>n.</pos> <def>a genus of plants consisting of one
species, the Australian pea.</def><br/
<syn><b>Syn. --</b> genus <gen>Dipogon</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dipody</ent><br/
<hw>Dip"o*dy</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Dipodies</plw> <pr>(#)</pr>.</plu> <ety>[Gr. <?/, fr. <?/
two-footed; <grk>di-</grk> = <grk>di`s-</grk> twice + <?/, <?/,
foot.]</ety> <fld>(Pros.)</fld> <def>Two metrical feet taken together,
or included in one measure.</def> <rj><au>Hadley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Trochaic, iambic, and anapestic verses . . . are measured by
<qex>dipodies</qex>.</q> <rj><qau>W. W. Goodwin.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dipolar</ent><br/
<hw>Di*po"lar</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pre. <ets>di-</ets>
+ <ets>polar</ets>. Cf. <er>Bipolar</er>.]</ety> <def>Having two poles,
as a magnetic bar.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>dipped</ent><br/
<hw>dipped</hw> <pos>adj.</pos> <def>having an abnormal sagging of the
spine, especially in horses.</def><br/
<syn><b>Syn. --</b> sway-backed.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dippel's oil</ent><br/
<hw>Dip"pel's oil`</hw> <pr>(?)</pr>. <fld>(Chem.)</fld> <ety>[From the
name of the inventor.]</ety> <def>See <cref>Bone oil</cref>, under
<er>Bone</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dipper</ent><br/
<hw>Dip"per</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who,
or that which, dips; especially, a vessel used to dip water or other
liquid; a ladle.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <sd>(a)</sd> <def>A small grebe; the
dabchick.</def> <sd>(b)</sd> <def>The buffel duck.</def> <sd>(c)</sd>
<def>The water ouzel (<spn>Cinolus aquaticus</spn>) of Europe.</def>
<sd>(d)</sd> <def>The American dipper or ouzel (<spn>Cinclus
Mexicanus</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>The Dipper</b></col> <fld>(Astron.)</fld>, <cd>the seven
principal stars in the constellation of the Great Bear; popularly so
called from their arrangement in the form of a dipper; -- called also
<altname>Charles's Wain</altname>. See <cref>Ursa Major</cref>, under
<er>Ursa</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dipping</ent><br/
<hw>Dip"ping</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act or process of
immersing.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The act of inclining downward.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The act of lifting or moving a liquid with a dipper,
ladle, or the like.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The process of cleaning or brightening sheet metal
or metalware, esp. brass, by dipping it in acids, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>The practice of taking snuff by rubbing the teeth or
gums with a stick or brush dipped in snuff.</def>
<mark>[U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dipping needle</b></col>, <cd>a magnetic needle suspended
at its center of gravity, and moving freely in a vertical plane, so as
to indicate on a graduated circle the magnetic dip or
inclination.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diprismatic</ent><br/
<hw>Di`pris*mat"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Prefix
<ets>di-</ets> + <ets>prismatic</ets>.]</ety> <def>Doubly
prismatic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dipropargyl</ent><br/
<hw>Di`pro*par"gyl</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Prefix
<ets>di-</ets> + <ets>propargyl</ets>.]</ety> <fld>(Chem.)</fld> <def>A
pungent, mobile, volatile liquid, <chform>C6H6</chform>, produced
artificially from certain allyl derivatives. Though isomeric with
benzine, it is very different in its chemical relations. Called also
<altname>dipropinyl</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dipropyl</ent><br/
<hw>Di*pro"pyl</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>di-</ets> + <ets>propyl</ets>.]</ety> <fld>(Chem.)</fld> <def>One
of the hexane paraffins, found in petroleum, consisting of two propyl
radicals. See <er>Hexane</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diprotodon</ent><br/
\'d8<hw>Di*pro"to*don</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>di-</grk> = <grk>di`s-</grk> twice + <?/ first +
<grk>'odoy`s</grk>, <grk>'odo`ntos</grk>, tooth.]</ety>
<fld>(Paleon.)</fld> <def>An extinct Quaternary marsupial from
Australia, about as large as the hippopotamus; -- so named because of
its two large front teeth. See <xex>Illustration</xex> in
Appendix.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dipsas</ent><br/
<hw>Dip"sas</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., fr. Gr. <?/, fr.
<?/ thirst.]</ety> <sn>1.</sn> <def>A serpent whose bite was fabled to
produce intense thirst.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>A genus of harmless colubrine
snakes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dipsetic</ent><br/
<hw>Dip*set"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/.]</ety>
<def>Tending to produce thirst.</def> <rj><au>Wright.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dipsy</ent><br/
<ent>Dipsie</ent><br/
<ent>Dipsey</ent><br/
<mhw>{ <hw>Dip"sey</hw>, <hw>Dip"sie</hw>, <hw>Dip"sy</hw> }</mhw>
<pr>(?)</pr>, <pos>a.</pos> <def>Deep-sea; <as>as, a <ex>dipsey</ex>
line; a <ex>dipsy</ex> lead</as>.</def> <mark>[Sailor's Cant]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Dipsy</ent><br/
<ent>Dipsie</ent><br/
<ent>Dipsey</ent><br/
<mhw>{ <hw>Dip"sey</hw>, <hw>Dip"sie</hw>, <hw>Dip"sy</hw> }</mhw>,
<pos>n.</pos> <sn>1.</sn> <def>A sinker attached to a fishing line;
also, a line having several branches, each with such a sinker, used in
deep-sea fishing.</def> <mark>[Local, U. S.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <fld>(Naut.)</fld> <def>A deep-sea lead.</def>
<mark>[Rare]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Dipsomania</ent><br/
<hw>Dip`so*ma"ni*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<?/ thirst + <?/ mania.]</ety> <fld>(Med.)</fld> <def>A morbid an
uncontrollable craving (often periodic) for drink, esp. for alcoholic
liquors; also improperly used to denote acute and chronic
alcoholism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dipsomaniac</ent><br/
<hw>Dip`so*ma"ni*ac</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who has an
irrepressible desire for alcoholic drinks.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dipsomaniacal</ent><br/
<hw>Dip`so*ma*ni"a*cal</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or
pertaining to dipsomania.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dipsosis</ent><br/
\'d8<hw>Dip*so"sis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<?/ thirst.]</ety> <fld>(Med.)</fld> <def>Excessive thirst produced by
disease.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>dipstick</ent><br/
<hw>dipstick</hw> <pos>n.</pos> <def>a graduated rod dipped into a
container to indicate the fluid level; <as>as, to check the oil level in
a car with a <ex>dipstick</ex></as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Diptera</ent><br/
\'d8<hw>Dip"te*ra</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL., fr.
Gr. <?/ with two wings, <grk>di-</grk> = <grk>di`s-</grk> twice + <?/
feather, wing: cf. F. <ets>dipt<egrave/re</ets>.]</ety>
<fld>(Zool.)</fld> <def>An extensive order of insects having only two
functional wings and two balancers, as the house fly, mosquito, etc.
They have a suctorial proboscis, often including two pairs of sharp
organs (mandibles and maxill<ae/) with which they pierce the skin of
animals. They undergo a complete metamorphosis, their larv<ae/ (called
maggots) being usually without feet.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dipteral</ent><br/
<hw>Dip"ter*al</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<fld>(Zool.)</fld> <def>Having two wings only; belonging to the order
Diptera.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Anc. Arch.)</fld> <def>Having a double row of
columns on each on the flanks, as well as in front and rear; -- said of
a temple.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dipteran</ent><br/
<hw>Dip"ter*an</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>An insect of the order Diptera.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dipterocarpus</ent><br/
\'d8<hw>Dip`te*ro*car"pus</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL.,
fr. Gr. <?/ with two wings + <?/ fruit.]</ety> <fld>(Bot.)</fld> <def>A
genus of trees found in the East Indies, some species of which produce a
fragrant resin, other species wood oil. The fruit has two long
wings.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dipterous</ent><br/
<hw>Dip"ter*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<fld>(Zool.)</fld> <def>Having two wings, as certain insects; belonging
to the order Diptera.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>Having two wings;
two-winged.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dipterygian</ent><br/
<hw>Dip`ter*yg"i*an</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>di-</grk> = <grk>di`s-</grk> twice + <?/ a fin, dim. of <?/
wing.]</ety> <fld>(Zool.)</fld> <def>Having two dorsal fins; -- said of
certain fishes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dipteryx</ent><br/
<hw>Dipteryx</hw> <pos>n.</pos> <def>a genus of tropical American trees
which produce a black seed called the <prod>tonka bean</prod>.</def><br/
<syn><b>Syn. --</b> Coumarouna, genus <gen>Coumarouna</gen>, genus
<gen>Dipteryx</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Diptote</ent><br/
<hw>Dip"tote</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/;
<grk>di-</grk> = <grk>di`s-</grk> twice + <?/ falling, fr. <?/ to fall:
cf. F. <ets>diptote</ets>.]</ety> <fld>(Gram.)</fld> <def>A noun which
has only two cases.</def> <rj><au>Andrews.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diptych</ent><br/
<hw>Dip"tych</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>diptycha</ets>, pl., fr. Gr. <?/ folded, doubled; <grk>di-</grk> =
<grk>di`s-</grk> twice + <?/ to fold, double up.]</ety> <sn>1.</sn>
<def>Anything consisting of two leaves.</def> Especially: <sd>(a)</sd>
<fld>(Roman Antiq.)</fld> <def>A writing tablet consisting of two leaves
of rigid material connected by hinges and shutting together so as to
protect the writing within.</def> <sd>(b)</sd> <def>A picture or series
of pictures painted on two tablets connected by hinges. See
<er>Triptych</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A double catalogue, containing in one part the names
of living, and in the other of deceased, ecclesiastics and benefactors
of the church; a catalogue of saints.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dipyre</ent><br/
<hw>Di*pyre"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <grk>di-</grk> =
<grk>di`s-</grk> twice fire.]</ety> <fld>(Min.)</fld> <def>A mineral of
the scapolite group; -- so called from the double effect of fire upon
it, in fusing it, and rendering it phosphorescent.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dipyrenous</ent><br/
<hw>Di`py*re"nous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>di-</ets> + <ets>pyrene</ets>.]</ety> <fld>(Bot.)</fld>
<def>Containing two stones or nutlets.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dipyridine</ent><br/
<hw>Di*pyr"i*dine</hw> <pr>(?; 104)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>di-</ets> + <ets>pyridine</ets>.]</ety> <fld>(Geom.)</fld> <def>A
polymeric form of pyridine, <chform>C10H10N2</chform>, obtained as a
colorless oil by the action of sodium on pyridine.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dipyridyl</ent><br/
<hw>Di*pyr"i*dyl</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>di-</ets> + <ets>pyrid</ets>ine + <ets>-yl</ets>.]</ety>
<fld>(Chem.)</fld> <def>A crystalline nitrogenous base,
<chform>C10H8N2</chform>, obtained by the reduction of
pyridine.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diradiation</ent><br/
<hw>Di*ra`di*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>di-</ets> + <ets>radiation</ets>.]</ety> <def>The emission and
diffusion of rays of light.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dire</ent><br/
<hw>Dire</hw> <pr>(d<imac/r)</pr>, <pos>a.</pos>
<amorph>[<pos>Compar.</pos> <adjf>Direr</adjf>
<pr>(d<imac/r"<etil/r)</pr>; <pos>superl.</pos>
<adjf>Direst</adjf>.]</amorph> <ety>[L. <ets>dirus</ets>; of uncertain
origin.]</ety> <sn>1.</sn> <def>Ill-boding; portentous; <as>as,
<ex>dire</ex> omens</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Evil in great degree; dreadful; dismal; horrible;
terrible; lamentable.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Dire</qex> was the tossing, deep the groans.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Gorgons and hydras and chimeras <qex>dire</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Direct</ent><br/
<hw>Di*rect"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>directus</ets>, p. p. of <ets>dirigere</ets> to direct: cf. F.
<ets>direct</ets>. See <er>Dress</er>, and cf. <er>Dirge</er>.]</ety>
<sn>1.</sn> <def>Straight; not crooked, oblique, or circuitous; leading
by the short or shortest way to a point or end; <as>as, a
<ex>direct</ex> line; <ex>direct</ex> means.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>What is <qex>direct</qex> to, what slides by, the question.</q>
<rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Straightforward; not of crooked ways, or swerving
from truth and openness; sincere; outspoken.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Be even and <qex>direct</qex> with me.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Immediate; express; plain; unambiguous.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He nowhere, that I know, says it in <qex>direct</qex> words.</q>
<rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>direct</qex> and avowed interference with elections.</q>
<rj><qau>Hallam.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>In the line of descent; not collateral; <as>as, a
descendant in the <ex>direct</ex> line</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Astron.)</fld> <def>In the direction of the general
planetary motion, or from west to east; in the order of the signs; not
<ant>retrograde</ant>; -- said of the motion of a celestial
body.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Political Science)</fld> <def>Pertaining to, or
effected immediately by, action of the people through their votes
instead of through one or more representatives or delegates; <as>as,
<ex>direct</ex> nomination, <ex>direct</ex> legislation</as>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><cs><col><b>Direct action</b></col>. <sd>(a)</sd> <fld>(Mach.)</fld>
<cd>See <er>Direct-acting</er>.</cd> <sd>(b)</sd> <fld>(Trade
unions)</fld> <def>See <er>Syndicalism</er>, below.</def>
[<source>Webster 1913 Suppl.</source>] -- <col><b>Direct
discourse</b></col> <fld>(Gram.)</fld>, <cd>the language of any one
quoted without change in its form; as, he said <ldquo/I can not
come;<rdquo/ -- correlative to <contr>indirect discourse</contr>, in
which there is change of form; as, he said that he could not come. They
are often called respectively by their Latin names, <altname>oratio
directa</altname>, and <contr>oratio obliqua</contr>.</cd> --
<col><b>Direct evidence</b></col> <fld>(Law)</fld>, <cd>evidence which
is positive or not inferential; -- opposed to <contr>circumstantial
evidence</contr>, or <contr>indirect evidence</contr>. -- This
distinction, however, is merely formal, since there is no direct
evidence that is not circumstantial, or dependent on circumstances for
its credibility.</cd> <au>Wharton.</au> -- <col><b>Direct
examination</b></col> <fld>(Law)</fld>, <cd>the first examination of a
witness in the orderly course, upon the merits.</cd> <au>Abbott.</au> --
<col><b>Direct fire</b></col> <fld>(Mil.)</fld>, <cd>fire, the direction
of which is perpendicular to the line of troops or to the parapet aimed
at.</cd> -- <col><b>Direct process</b></col> <fld>(Metal.)</fld>,
<cd>one which yields metal in working condition by a single process from
the ore.</cd> <au>Knight.</au> -- <col><b>Direct tax</b></col>, <cd>a
tax assessed directly on lands, etc., and polls, distinguished from
taxes on merchandise, or customs, and from excise.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Direct</ent><br/
<hw>Di*rect"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Directed</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Directing</conjf>.]</vmorph> <sn>1.</sn> <def>To arrange in a
direct or straight line, as against a mark, or towards a goal; to point;
to aim; <as>as, to <ex>direct</ex> an arrow or a piece of
ordnance</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To point out or show to (any one), as the direct or
right course or way; to guide, as by pointing out the way; <as>as, he
<ex>directed</ex> me to the left-hand road</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The Lord <qex>direct</qex> your into the love of God.</q>
<rj><qau>2 Thess. iii. 5.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The next points to which I will <qex>direct</qex> your
attention.</q> <rj><qau>Lubbock.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To determine the direction or course of; to cause to
go on in a particular manner; to order in the way to a certain end; to
regulate; to govern; <as>as, to <ex>direct</ex> the affairs of a nation
or the movements of an army</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I will <qex>direct</qex> their work in truth.</q> <rj><qau>Is.
lxi. 8.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To point out to with authority; to instruct as a
superior; to order; <as>as, he <ex>directed</ex> them to
go</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I 'll first <qex>direct</qex> my men what they shall do.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To put a direction or address upon; to mark with the
name and residence of the person to whom anything is sent; to
superscribe; <as>as, to <ex>direct</ex> a letter</as>.</def></p>

<p><syn><b>Syn.</b> -- To guide; lead; conduct; dispose; manage;
regulate; order; instruct; command.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Direct</ent><br/
<hw>Di*rect"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To give direction;
to point out a course; to act as guide.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Wisdom is profitable to <qex>direct</qex>.</q> <rj><qau>Eccl. x.
10.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Direct</ent><br/
<hw>Di*rect"</hw>, <pos>n.</pos> <fld>(Mus.)</fld> <def>A character,
thus [<?/], placed at the end of a staff on the line or space of the
first note of the next staff, to apprise the performer of its
situation.</def> <rj><au>Moore (Encyc. of Music).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Direct-acting</ent><br/
<hw>Di*rect"-act`ing</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Mach.)</fld>
<def>Acting directly, as one part upon another, without the intervention
of other working parts.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Direct-acting steam engine</b></col>, <cd>one in which
motion is transmitted to the crank without the intervention of a beam or
lever; -- also called <altname>direct-action steam
engine</altname>.</cd> -- <col><b>Direct-acting steam pump</b></col>,
<cd>one in which the steam piston rod is directly connected with the
pump rod; -- also called <altname>direct-action steam
pump</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Direct-coupled</ent><br/
<hw>Di*rect"-cou"pled</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Coupled
without intermediate connections, as an engine and a dynamo.</def></p>

<p><cs><col><b>Direct-coupled antenna</b></col> <fld>(Wireless
Teleg.)</fld>, <cd>an antenna connected electrically with one point of a
closed oscillation circuit in syntony with it and earthed.</cd></cs><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Direct current</ent><br/
<hw>Direct current</hw>. <fld>(Elec.)</fld> <sd>(a)</sd> <def>A current
flowing in one direction only; -- distinguished from <contr>alternating
current</contr>. When steady and not pulsating a direct current is often
called a <stype>continuous current</stype>.</def> <sd>(b)</sd>
<def><col><b>A direct induced current</b></col>, or momentary current of
the same direction as the inducing current, produced by stopping or
removing the latter; also, a similar current produced by removal of a
magnet.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>directed</ent><br/
<hw>directed</hw> <pos>adj.</pos> <sn>1.</sn> <def>having a specified
direction; often used in combination; <as>as,
goal-<ex>directed</ex></as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>marked with a destination; -- of mail or parcels;
<as>as, I throw away all mail <ex>directed</ex> to `resident'</as>.
Opposite of <ant>unaddressed</ant>.</def><br/
<syn><b>Syn. --</b> addressed.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Directer</ent><br/
<hw>Di*rect"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who directs; a
director.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Directer plane</b></col> <fld>(Geom.)</fld>, <cd>the
plane to which all right-lined elements in a warped surface are
parallel.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Direction</ent><br/
<hw>Di*rec"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>directio</ets>: cf. F. <ets>direction</ets>.]</ety> <sn>1.</sn>
<def>The act of directing, of aiming, regulating, guiding, or ordering;
guidance; management; superintendence; administration; <as>as, the
<ex>direction</ex> o<?/ public affairs or of a bank</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I do commit his youth<br/
To your <qex>direction</qex>.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>All nature is but art, unknown to thee;<br/
ll chance, <qex>direction</qex>, which thou canst not see.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is imposed by directing; a guiding or
authoritative instruction; prescription; order; command; <as>as, he
grave <ex>directions</ex> to the servants</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The princes digged the well . . . by the <qex>direction</qex> of
the law giver.</q> <rj><qau>Numb. xxi. 18.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The name and residence of a person to whom any thing
is sent, written upon the thing sent; superscription; address; <as>as,
the <ex>direction</ex> of a letter</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The line or course upon which anything is moving or
aimed to move, or in which anything is lying or pointing; aim; line or
point of tendency; direct line or course; <as>as, the ship sailed in a
southeasterly <ex>direction</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>The body of managers of a corporation or enterprise;
board of directors.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Gun.)</fld> <def>The pointing of a piece with
reference to an imaginary vertical axis; -- distinguished from
<xex>elevation</xex>. The <xex>direction</xex> is given when the plane
of sight passes through the object.</def> <rj><au>Wilhelm.</au></rj></p>

<p><syn><b>Syn.</b> -- Administration; guidance; management;
superintendence; oversight; government; order; command; guide;
clew.</syn> <usage><er>Direction</er>, <er>Control</er>,
<er>Command</er>, <er>Order</er>. These words, as here compared, have
reference to the exercise of power over the actions of others.
<xex>Control</xex> is negative, denoting power to restrain;
<xex>command</xex> is positive, implying a right to enforce obedience;
<xex>directions</xex> are commands containing instructions how to act.
<xex>Order</xex> conveys more prominently the idea of authority than the
word <xex>direction</xex>. A shipmaster has the <xex>command</xex> of
his vessel; he gives <xex>orders</xex> or <xex>directions</xex> to the
seamen as to the mode of sailing it; and exercises a due
<xex>control</xex> over the passengers.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>directional</ent><br/
<hw>directional</hw> <pos>adj.</pos> <sn>1.</sn> <def>of or pertaining
to direction (definition 2).</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>serving to indicate direction.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <fld>(Radio)</fld> <def>transmitting radio signals in a
specific direction, or receiving signals only from a narrow angle of
directions, thus serving to indicate the direction from which radio
signals are coming. Used of antennas; <as>as, a <ex>directional</ex>
antenna</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>directionality</ent><br/
<hw>directionality</hw> <pos>n.</pos> <def>the property of a microphone
or antenna of being more sensitive to signal arriving from one direction
than from another.</def><br/
<syn><b>Syn. --</b> directivity.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>directionless</ent><br/
<hw>directionless</hw> <pos>adj.</pos> <sn>1.</sn> <def>purposeless.
Opposite of <ant>purposeful</ant>.</def><br/
<syn><b>Syn. --</b> adrift(predicate), afloat(predicate), aimless,
planless, rudderless, undirected.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Directive</ent><br/
<hw>Di*rect"ive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[LL.
<ets>directivus</ets>: cf. F. <ets>directif</ets>.]</ety> <sn>1.</sn>
<def>Having power to direct; tending to direct, guide, or govern;
showing the way.</def> <rj><au>Hooker.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The precepts <qex>directive</qex> of our practice in relation to
God.</q> <rj><qau>Barrow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Able to be directed; manageable.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Swords and bows<br/
<qex>Directive</qex> by the limbs.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>directivity</ent><br/
<hw>directivity</hw> <pos>n.</pos> <def>the property of a microphone or
antenna of being more sensitive to sounds coming from one direction than
from another.</def><br/
<syn><b>Syn. --</b> directionality.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Directly</ent><br/
<hw>Di*rect"ly</hw>, <pos>adv.</pos> <sn>1.</sn> <def>In a direct
manner; in a straight line or course.</def> <ldquo/To run
<xex>directly</xex> on.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Indirectly and <qex>directly</qex> too<br/
Thou hast contrived against the very life<br/
Of the defendant.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>In a straightforward way; without anything
intervening; not by secondary, but by direct, means.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Without circumlocution or ambiguity; absolutely; in
express terms.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>No man hath hitherto been so impious as plainly and
<qex>directly</qex> to condemn prayer.</q>
<rj><qau>Hooker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Exactly; just.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Stand you <qex>directly</qex> in Antonius' way.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Straightforwardly; honestly.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I have dealt most <qex>directly</qex> in thy affair.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Manifestly; openly.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Desdemona is <qex>directly</qex> in love with him.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>Straightway; next in order; without delay;
immediately.</def> <ldquo/Will she go now to bed?'
<?/<xex>Directly</xex>.<xex>'</xex><rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>Immediately after; as soon as.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Directly</qex> he stopped, the coffin was removed.</q>
<rj><qau>Dickens.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ This use of the word is common in England, especially in
colloquial speech, but it can hardly be regarded as a well-sanctioned or
desirable use.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Directly proportional</b></col> <fld>(Math.)</fld>,
<cd>proportional in the order of the terms; increasing or decreasing
together, and with a constant ratio; -- opposed to <contr>inversely
proportional</contr>.</cd></cs></p>

<p><syn><b>Syn.</b> -- Immediately; forthwith; straightway; instantly;
instantaneously; soon; promptly; openly; expressly.</syn> <usage>--
<er>Directly</er>, <er>Immediately</er>, <er>Instantly</er>,
<er>Instantaneously</er>. <xex>Directly</xex> denotes, without any delay
or diversion of attention; <xex>immediately</xex> implies, without any
interposition of other occupation; <xex>instantly</xex> implies, without
any intervention of time. Hence, <ldquo/I will do it
<xex>directly</xex>,<rdquo/ means, <ldquo/I will go
<xex>straightway</xex> about it.<rdquo/ <ldquo/I will do it
<xex>immediately</xex>,<rdquo/ means, <ldquo/I will do it as the very
<xex>next</xex> thing.<rdquo/ <ldquo/I will do it
<xex>instantly</xex>,<rdquo/ allows not a particle of delay.
<xex>Instantaneously</xex>, like <xex>instantly</xex>, marks an interval
too small to be appreciable, but commonly relates to physical causes;
<as>as, the powder touched by fire <ex>instantaneously</ex>
exploded</as>.</usage><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 417 --></p>

<p><ent>Directness</ent><br/
<hw>Di*rect"ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The quality of
being direct; straightness; straightforwardness;
immediateness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Direct nomination</ent><br/
<hw>Direct nomination</hw>. <fld>(Political Science)</fld> <def>The
nomination or designation of candidates for public office by direct
popular vote rather than through the action of a convention or body of
elected nominating representatives or delegates. The term is applied
both to the nomination of candidates without any nominating convention,
and, loosely, to the nomination effected, as in the case of candidates
for president or senator of the United States, by the election of
nominating representatives pledged or instructed to vote for certain
candidates designated by popular vote.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Directoire style</ent><br/
<hw>Di`rec`toire" style</hw> <pr>(?)</pr>. <fld>(Dressmaking)</fld>
<def>A style of dress prevalent at the time of the French Directory,
characterized by great extravagance of design and imitating the Greek
and Roman costumes.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Director</ent><br/
<hw>Di*rect"or</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>directeur</ets>.]</ety> <sn>1.</sn> <def>One who, or that which,
directs; one who regulates, guides, or orders; a manager or
superintendent.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In all affairs thou sole <qex>director</qex>.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One of a body of persons appointed to manage the
affairs of a company or corporation; <as>as, the <ex>directors</ex> of a
bank, insurance company, or railroad company</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>What made <qex>directors</qex> cheat in South-Sea year?</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Mech.)</fld> <def>A part of a machine or instrument
which directs its motion or action.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Surg.)</fld> <def>A slender grooved instrument upon
which a knife is made to slide when it is wished to limit the extent of
motion of the latter, or prevent its injuring the parts
beneath.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Directorate</ent><br/
<hw>Di*rect"o*rate</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>directorat</ets>.]</ety> <def>The office of director; also, a body
of directors taken jointly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Directorial</ent><br/
<hw>Di*rec*to"ri*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>directorial</ets>.]</ety> <sn>1.</sn> <def>Having the quality of a
director, or authoritative guide; directive.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Pertaining to: director or directory; specifically,
relating to the Directory of France under the first republic. See
<er>Directory</er>, 3.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Whoever goes to the <qex>directorial</qex> presence under this
passport.</q> <rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Directorship</ent><br/
<hw>Di*rect"or*ship</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The condition
or office of a director; directorate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Directory</ent><br/
<hw>Di*rect"o*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>directorius</ets>.]</ety> <def>Containing directions; enjoining;
instructing; directorial.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Directory</ent><br/
<hw>Di*rect"o*ry</hw>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Directories</plw> <pr>(<?/)</pr>.</plu> <sn>1.</sn> <def>A
collection or body of directions, rules, or ordinances; esp., a book of
directions for the conduct of worship; <as>as, the <ex>Directory</ex>
used by the nonconformists instead of the Prayer Book</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A book containing the names and residences of the
inhabitants of any place, or of classes of them; an address book;
<as>as, a business <ex>directory</ex></as>.</def> <-- as, a telephone
directory. --><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <ety>[Cf. F. <ets>directoire</ets>.]</ety> <def>A body of
directors; board of management; especially, a committee which held
executive power in France under the first republic.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Direction; guide.</def> <mark>[R.]</mark>
<rj><au>Whitlock.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Direct primary</ent><br/
<hw>Direct primary</hw>. <fld>(Political Science)</fld> <def>A primary
by which direct nominations of candidates for office are made.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Directress</ent><br/
<hw>Di*rect"ress</hw>, <pos>n.</pos> <def>A woman who directs.</def>
<rj><au>Bp. Hurd.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Directrix</ent><br/
<hw>Di*rect"rix</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it> E.
<plw>Directrixes</plw> <pr>(<?/)</pr>, L. <er>Directrices</er>
<pr>(<?/)</pr>.</plu> <sn>1.</sn> <def>A directress.</def>
<mark>[R.]</mark> <rj><au>Jer. Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Geom.)</fld> <sd>(a)</sd> <def>A line along which a
point in another line moves, or which in any way governs the motion of
the point and determines the position of the curve generated by it; the
line along which the generatrix moves in generating a surface.</def>
<sd>(b)</sd> <def>A straight line so situated with respect to a conic
section that the distance of any point of the curve from it has a
constant ratio to the distance of the same point from the
focus.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Direful</ent><br/
<hw>Dire"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<ets>Dire</ets> +
<ets>-ful</ets>.]</ety> <def>Dire; dreadful; terrible; calamitous;
woeful; <as>as, a <ex>direful</ex> fiend; a <ex>direful</ex>
day.</as></def> -- <wordforms><wf>Dire"ful*ly</wf>, <pos>adv.</pos> --
<wf>Dire"ful*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Direly</ent><br/
<hw>Dire"ly</hw>, <pos>adv.</pos> <def>In a dire manner.</def>
<rj><au>Drayton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dirempt</ent><br/
<hw>Di*rempt"</hw> <pr>(?; 215)</pr>, <pos>a.</pos> <ety>[L.
<ets>diremptus</ets>, p. p. of <ets>dirimere</ets> to take apart,
separate; <ets>di- = dis-</ets> + <ets>emere</ets> to buy, orig., to
take.]</ety> <def>Divided; separated.</def> <mark>[Obs.]</mark>
<rj><au>Stow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dirempt</ent><br/
<hw>Di*rempt"</hw>, <pos>v. t.</pos> <def>To separate by force; to tear
apart.</def> <mark>[Obs.]</mark> <rj><au>Holinshed.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diremption</ent><br/
<hw>Di*remp"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>diremptio</ets>.]</ety> <def>A tearing apart; violent
separation.</def> <mark>[Obs.]</mark> <rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Direness</ent><br/
<hw>Dire"ness</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Dire-</ets> +
<ets>-ness</ets>.]</ety> <def>Terribleness; horror; woefulness.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Direption</ent><br/
<hw>Di*rep"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>direptio</ets>, fr. <ets>diripere</ets> to tear asunder, plunder;
<ets>di- = dis-</ets> + <ets>rapere</ets> to seize and carry off.]</ety>
<def>The act of plundering, despoiling, or snatching away.</def>
<mark>[R.]</mark> <rj><au>Speed.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Direptitious</ent><br/
<hw>Di*rep*ti"tious</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Characterized
by direption.</def> <mark>[R.]</mark> <rj><au>Encyc. Dict.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Direptitiously</ent><br/
<hw>Di*rep*ti"tious*ly</hw>, <pos>adv.</pos> <def>With plundering
violence; by violent injustice.</def> <mark>[R.]</mark>
<rj><au>Strype.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dirge</ent><br/
<hw>Dirge</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Contraction of Lat.
<ets>dirige</ets>, direct thou (imperative of <ets>dirigere</ets>), the
first word of a funeral hymn (Lat. transl. of Psalm v. 8) beginning,
<ldquo/<ets>Dirige</ets>, <ets>Domine</ets>, <ets>in conspectu tuo vitam
meam</ets>.<rdquo/ See <er>Direct</er>, <pos>a.</pos>, and cf.
<er>Dirige</er>.]</ety> <def>A piece of music of a mournful character,
to accompany funeral rites; a funeral hymn.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The raven croaked, and hollow shrieks of owls<br/
Sung <qex>dirges</qex> at her funeral.</q> <rj><qau>Ford.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dirgeful</ent><br/
<hw>Dirge"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Funereal;
moaning.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Soothed sadly by the <qex>dirgeful</qex> wind.</q>
<rj><qau>Coleridge.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dirige</ent><br/
<hw>Dir"i*ge</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. See
<er>Dirge</er>.]</ety> <def>A service for the dead, in the Roman
Catholic Church, being the first antiphon of Matins for the dead, of
which <xex>Dirige</xex> is the first word; a dirge.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Evensongs and placebo and <qex>dirige</qex>.</q>
<rj><qau>Wyclif.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Resort, I pray you, unto my sepulture<br/
To sing my <qex>dirige</qex> with great devotion.</q>
<rj><qau>Lamentation of Mary Magdalene.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dirigent</ent><br/
<hw>Dir"i*gent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>dirigens</ets>, p. pr. of <ets>dirigere</ets>. See <er>Direct</er>,
<pos>a.</pos>]</ety> <def>Directing.</def> <rj><au>Baxter.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dirigent</ent><br/
<hw>Dir"i*gent</hw>, <pos>n.</pos> <fld>(Geom.)</fld> <def>The line of
motion along which a describent line or surface is carried in the
genesis of any plane or solid figure; a directrix.</def>
<rj><au>Hutton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dirigible</ent><br/
<hw>Dir"i*gi*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of being
directed; steerable; <as>as, a <ex>dirigible</ex>
balloon</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>dirigisme</ent><br/
<hw>dir`i*gisme"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>dirigere</ets> to direct.]</ety> <def>The practice or inclination
to direct (activities) by a central authority; <as>as, the linguistic
<ex>dirigisme</ex> of prescriptivists clashes with the modern tendency
toward acceptance of multiculturalism</as>. See also
<er>dirigiste</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>dirigiste</ent><br/
<hw>dir`i*giste"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>dirigere</ets> to direct.]</ety> <def>Directed by a central
authority; <as>as, a <ex>dirigiste</ex> economy</as>; with respect to
economics, opposed to <ant>free-market</ant>. See also
<er>dirigisme</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Diriment</ent><br/
<hw>Dir"i*ment</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>dirimens</ets>, p. pr. of <ets>dirimere</ets>. See
<er>Dirempt</er>.]</ety> <fld>(Law)</fld> <def>Absolute.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Diriment impediment</b></col> <fld>(R. C. Ch.)</fld>,
<cd>an impediment that nullifies marriage.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dirk</ent><br/
<hw>Dirk</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Ir.
<ets>duirc</ets>.]</ety> <def>A kind of dagger or poniard; -- formerly
much used by the Scottish Highlander.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dirk knife</b></col>, <cd>a clasp knife having a large,
dirklike blade.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dirk</ent><br/
<hw>Dirk</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Dirked</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Dirking</conjf>.]</vmorph> <def>To stab with a dirk.</def>
<rj><au>Sir W. Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dirk</ent><br/
<hw>Dirk</hw>, <pos>a.</pos> <ety>[See <er>Dark</er>,
<pos>a.</pos>]</ety> <def>Dark.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dirk</ent><br/
<hw>Dirk</hw>, <pos>v. t.</pos> <def>To darken.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dirkness</ent><br/
<hw>Dirk"ness</hw>, <pos>n.</pos> <def>Darkness.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dirl</ent><br/
<hw>Dirl</hw> <pr>(?)</pr>, <pos>v. i. & t.</pos> <ety>[Cf.
<er>Drill</er>, <er>Thrill</er>.]</ety> <def>To thrill; to vibrate; to
penetrate.</def> <mark>[Prov. Eng.]</mark>
<rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dirt</ent><br/
<hw>Dirt</hw> <pr>(d<etil/rt)</pr>, <pos>n.</pos> <ety>[OE.
<ets>drit</ets>; kin to Icel. <ets>drit</ets> excrement,
<ets>dr<imac/ta</ets> to dung, OD. <ets>drijten</ets> to dung, AS.
<ets>gedr<imac/tan</ets>.]</ety> <sn>1.</sn> <def>Any foul of filthy
substance, as excrement, mud, dust, etc.; whatever, adhering to
anything, renders it foul or unclean; earth; <as>as, a wagonload of
<ex>dirt</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Whose waters cast up mire and <qex>dirt</qex>.</q> <rj><qau>Is.
lvii. 20.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Meanness; sordidness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Honors . . . thrown away upon <qex>dirt</qex> and infamy.</q>
<rj><qau>Melmoth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>In placer mining, earth, gravel, etc., before
washing.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dirt bed</b></col> <fld>(Geom.)</fld>, <cd>a layer of
clayey earth forming a stratum in a geological formation. Dirt beds are
common among the coal measures.</cd> -- <col><b>Dirt eating</b></col>.
<sd>(a)</sd> <cd>The use of certain kinds of clay for food, existing
among some tribes of Indians; geophagism.</cd> <au>Humboldt.</au>
<sd>(b)</sd> <fld>(Med.)</fld> <cd>Same as <er>Chthonophagia</er>.</cd>
-- <col><b>Dirt pie</b></col>, <cd>clay or mud molded by children in
imitation of pastry.</cd> <au>Otway (1684).</au> -- <col><b>To eat
dirt</b></col>, <cd>to submit in a meanly humble manner to insults; to
eat humble pie.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dirt</ent><br/
<hw>Dirt</hw>, <pos>v. t.</pos> <def>To make foul of filthy; to
dirty.</def> <rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>dirt-cheap</ent><br/
<hw>dirt-cheap</hw> <pos>adj.</pos> <def>costing much less than standard
price; <as>as, the store went out of business and sold their remaining
stock for <ex>dirt-cheap</ex> prices</as>.</def><br/
<syn><b>Syn. --</b> bargain-priced, cut-rate, cut-price.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Dirtily</ent><br/
<hw>Dirt"i*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a dirty manner;
foully; nastily; filthily; meanly; sordidly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dirtiness</ent><br/
<hw>Dirt"i*ness</hw>, <pos>n.</pos> <def>The state of being dirty;
filthiness; foulness; nastiness; baseness; sordidness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dirty</ent><br/
<hw>Dirt"y</hw> <pr>(?)</pr>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Dirtier</adjf> <pr>(?)</pr>; <pos>superl.</pos>
<adjf>Dirtiest</adjf>.]</amorph> <sn>1.</sn> <def>Defiled with dirt;
foul; nasty; filthy; not clean or pure; serving to defile; <as>as,
<ex>dirty</ex> hands; <ex>dirty</ex> water; a <ex>dirty</ex>
white.</as></def> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Sullied; clouded; -- applied to color.</def>
<rj><au>Locke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Sordid; base; groveling; <as>as, a <ex>dirty</ex>
fellow</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The creature's at his <qex>dirty</qex> work again.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Sleety; gusty; stormy; <as>as, <ex>dirty</ex>
weather</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Storms of wind, clouds of dust, an angry, <qex>dirty</qex>
sea.</q> <rj><qau>M. Arnold.</qau></rj></p>

<p><syn><b>Syn.</b> -- Nasty; filthy; foul. See
<er>Nasty</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dirty</ent><br/
<hw>Dirt"y</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Dirtied</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Dirtying</conjf>.]</vmorph> <sn>1.</sn> <def>To foul; to make
filthy; to soil; <as>as, to <ex>dirty</ex> the clothes or
hands</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To tarnish; to sully; to scandalize; -- said of
reputation, character, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>dirtying</ent><br/
<hw>dirtying</hw> <pos>n.</pos> <def>the act of soiling
something.</def><br/
<syn><b>Syn. --</b> soiling, soilure.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Diruption</ent><br/
<hw>Di*rup"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>diruptio</ets>, fr. <ets>dirumpere</ets>. See <er>Disrupt</er>,
<pos>a.</pos>]</ety> <def>Disruption.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>dis-</ent><br/
<hw>dis-</hw> <pr>(?; 258)</pr> <sn>1.</sn> <def>A prefix from the
Latin, whence F. <xex>d<eacute/s</xex>, or sometimes
<xex>d<eacute/-</xex>, <xex>dis-</xex>. The Latin <xex>dis-</xex>appears
as <altname>di-</altname>before <xex>b</xex>, <xex>d</xex>,
<xex>g</xex>, <xex>l</xex>, <xex>m</xex>, <xex>n</xex>, <xex>r</xex>,
<xex>v</xex>, becomes <xex>dif-</xex>before <xex>f</xex>, and either
<xex>dis-</xex>or <xex>di-</xex> before <xex>j</xex>. It is from the
same root as <xex>bis</xex> twice, and <xex>duo</xex>, E.
<xex>two</xex>. See <er>Two</er>, and cf. <er>Bi-</er>, <er>Di-</er>,
<er>Dia-</er>. <xex>Dis-</xex> denotes <sig>separation</sig>, <sig>a
parting from</sig>, as in <xex>dis</xex>tribute, <xex>dis</xex>connect;
hence it often has the force of a privative and negative, as in
<xex>dis</xex>arm, <xex>dis</xex>oblige, <xex>dis</xex>agree. Also
intensive, as in <xex>dis</xex>sever.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Walker's rule of pronouncing this prefix is, that the
<xex>s</xex> ought always to be pronounced like <xex>z</xex>, when the
next syllable is accented and begins with <ldquo/a flat mute
[<xex>b</xex>, <xex>d</xex>, <xex>v</xex>, <xex>g</xex>, <xex>z</xex>],
a liquid [<xex>l</xex>, <xex>m</xex>, <xex>n</xex>, <xex>r</xex>], or a
vowel; as, <xex>disable</xex>, <xex>disease</xex>, <xex>disorder</xex>,
<xex>disuse</xex>, <xex>disband</xex>, <xex>disdain</xex>,
<xex>disgrace</xex>, <xex>disvalue</xex>, <xex>disjoin</xex>,
<xex>dislike</xex>, <xex>dislodge</xex>, <xex>dismay</xex>,
<xex>dismember</xex>, <xex>dismiss</xex>, <xex>dismount</xex>,
<xex>disnatured</xex>, <xex>disrank</xex>, <xex>disrelish</xex>,
<xex>disrobe</xex>.<rdquo/ Dr. Webster's example in disapproving of
Walker's rule and pronouncing <xex>dis-</xex>as <xex>diz</xex> in only
one (<xex>disease</xex>) of the above words, is followed by recent
ortho<eum/pists. See <er>Disable</er>, <er>Disgrace</er>, and the other
words, beginning with <xex>dis</xex>-, in this Dictionary.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A prefix from Gr. <grk>di`s-</grk> twice. See
<er>Di-</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dis</ent><br/
\'d8<hw>Dis</hw> <pr>(?)</pr>, <pos>prop. n.</pos> <ety>[L.]</ety>
<def>The god Pluto, god of the underworld; also called <altname>Dis
Pater</altname>.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>dis</ent><br/
<hw>dis</hw> <pos>v. t.</pos> <ety>[shortened from
<ets>dis</ets>respect.]</ety> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>dissed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>dissing</conjf> <pr>(?)</pr>.]</vmorph> <def>to treat in a
disrespectful manner; to insult, disparage or belittle.</def>
<mark>[slang]</mark><br/
[<source>PJC</source>]</p>

<p><ent>disa</ent><br/
<hw>disa</hw> <pos>n.</pos> <def>any orchid of the genus
<gen>Disa</gen>, a genus of beautiful orchids with dark green leaves and
usually hooded flowers; -- they are much prized as emblematic flowers in
their native regions.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>disability</ent><br/
<hw>dis`a*bil"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Disabilities</plw> <pr>(<?/)</pr>.</plu> <sn>1.</sn> <def>State of
being disabled; deprivation or want of ability; absence of competent
physical, intellectual, or moral power, means, fitness, and the
like.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Grossest faults, or <qex>disabilities</qex> to perform what was
covenanted.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Chatham refused to see him, pleading his
<qex>disability</qex>.</q> <rj><qau>Bancroft.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Want of legal qualification to do a thing; legal
incapacity or incompetency.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>disabilities</qex> of idiocy, infancy, and coverture.</q>
<rj><qau>Abbott.</qau></rj></p>

<p><syn><b>Syn.</b> -- Weakness; inability; incompetence; impotence;
incapacity; incompetency; disqualification.</syn> <usage>--
<er>Disability</er>, <er>Inability</er>. <xex>Inability</xex> is an
inherent want of power to perform the thing in question;
<xex>disability</xex> arises from some <xex>deprivation</xex> or loss of
the needed competency. One who becomes deranged is under a
<xex>disability</xex> of holding his estate; and one who is made a
judge, of deciding in his own case. A man may decline an office on
account of his <xex>inability</xex> to discharge its duties; he may
refuse to accept a trust or employment on account of some
<xex>disability</xex> prevents him from entering into such
engagements.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disable</ent><br/
<hw>Dis*a"ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Lacking ability;
unable.</def> <mark>[Obs.]</mark> <ldquo/Our <xex>disable</xex> and
unactive force.<rdquo/ <rj><au>Daniel.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disable</ent><br/
<hw>Dis*a"ble</hw> <pr>(?; 277)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Disabled</conjf> <pr>(?)</pr>;
<pos>p. pr. & vb. n.</pos> <conjf>Disabling</conjf>
<pr>(?)</pr>.]</vmorph> <sn>1.</sn> <def>To render unable or incapable;
to destroy the force, vigor, or power of action of; to deprive of
competent physical or intellectual power; to incapacitate; to
disqualify; to make incompetent or unfit for service; to
impair.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A Christian's life is a perpetual exercise, a wrestling and
warfare, for which sensual pleasure <qex>disables</qex> him.</q>
<rj><qau>Jer. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And had performed it, if my known offense<br/
Had not <qex>disabled</qex> me.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I have <qex>disabled</qex> mine estate.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>To deprive of legal right or
qualification; to render legally incapable.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>An attainder of the ancestor corrupts the blood, and
<qex>disables</qex> his children to inherit.</q>
<rj><qau>Blackstone.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To deprive of that which gives value or estimation;
to declare lacking in competency; to disparage; to undervalue.</def>
<mark>[Obs.]</mark> <ldquo/He <xex>disabled</xex> my judgment.<rdquo/
<rj><au>Shak.</au></rj></p>

<p><syn><b>Syn.</b> -- To weaken; unfit; disqualify;
incapacitate.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>disabled</ent><br/
<hw>disabled</hw> <pos>adj.</pos> <sn>1.</sn> <def>injured so as to be
unable to function; <as>as, <ex>disabled</ex> veterans</as>.</def><br/
<syn><b>Syn. --</b> hors de combat, out of action.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>unable to function at normal capacity.</def><br/
<syn><b>Syn. --</b> handicapped, incapacitated.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Disablement</ent><br/
<hw>Dis*a"ble*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Deprivation of
ability; incapacity.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>disabling</ent><br/
<hw>disabling</hw> <pos>adj.</pos> <sn>1.</sn> <def>causing or having
caused disability; rendering disabled; <as>as, <ex>disabling</ex>
injury</as>.</def><br/
<syn><b>Syn. --</b> crippling, incapacitating.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>depriving of legal right; rendering legally
disqualified; <as>as, certain <ex>disabling</ex> restrictions
disqualified him for citizenship</as>.</def> <ant>enabling</ant><br/
<syn><b>Syn. --</b> disqualifying.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>disabuse</ent><br/
<hw>dis`a*buse"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Disabused</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Disabusing</conjf>.]</vmorph> <ety>[Pref.
<ets>dis-</ets> + <ets>abuse</ets>; cf. F.
<ets>d<eacute/sabuser</ets>.]</ety> <def>To set free from mistakes; to
undeceive; to disengage from fallacy or deception; to set right; --
often used with <ptcl>of</ptcl>; <as>as, to <ex>disabuse</ex> one of his
illusions</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To undeceive and <qex>disabuse</qex> the people.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>If men are now sufficiently enlightened to <qex>disabuse</qex>
themselves or artifice, hypocrisy, and superstition, they will consider
this event as an era in their history.</q> <rj><qau>J.
Adams.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>disaccommodate</ent><br/
<hw>dis`ac*com"mo*date</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>dis-</ets> + <ets>accommodate</ets>.]</ety> <def>To put to
inconvenience; to incommode.</def> <mark>[R.]</mark> <rj><au>Bp.
Warburton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disaccommodation</ent><br/
<hw>Dis`ac*com`mo*da"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A state
of being unaccommodated or unsuited.</def> <mark>[R.]</mark> <rj><au>Sir
M. Hale.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disaccord</ent><br/
<hw>Dis`ac*cord"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[Cf. F.
<ets>d<eacute/saccorder</ets> to cause discord.]</ety> <def>To refuse to
assent.</def> <mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disaccord</ent><br/
<hw>Dis`ac*cord"</hw>, <pos>n.</pos> <def>Disagreement.</def>
<rj><au>Pop. Sci. Monthly.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disaccordant</ent><br/
<hw>Dis`ac*cord"ant</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Not
accordant.</def> <rj><au>Fabyan.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disaccustom</ent><br/
<hw>Dis`ac*cus"tom</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Cf. F.
<ets>d<eacute/saccoutumer</ets>.]</ety> <def>To destroy the force of
habit in; to wean from a custom.</def> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disacidify</ent><br/
<hw>Dis`a*cid"i*fy</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To free from
acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disacknowledge</ent><br/
<hw>Dis`ac*knowl"edge</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Disacknowledged</conjf>
<pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Disacknowledging</conjf>.]</vmorph> <def>To refuse to
acknowledge; to deny; to disown.</def> <mark>[Obs.]</mark>
<rj><au>South.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disacquaint</ent><br/
<hw>Dis`ac*quaint"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>dis-</ets> + <ets>acquaint</ets>: cf. OF.
<ets>desacointier</ets>.]</ety> <def>To render unacquainted; to make
unfamiliar.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>While my sick heart<br/
With dismal smart<br/
Is <qex>disacquainted</qex> never.</q> <rj><qau>Herrick.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disacquaintance</ent><br/
<hw>Dis`ac*quaint"ance</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Neglect of
disuse of familiarity, or familiar acquaintance.</def>
<mark>[Obs.]</mark> <rj><au>South.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disacryl</ent><br/
<hw>Dis*ac"ryl</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>dis-</ets> (Gr. <grk>di`s-</grk> twice) + <ets>acr</ets>olein +
<ets>-yl</ets>.]</ety> <fld>(Chem.)</fld> <def>A white amorphous
substance obtained as a polymeric modification of acrolein.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disadorn</ent><br/
<hw>Dis`a*dorn"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To deprive of
ornaments.</def> <rj><au>Congreve.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disadvance</ent><br/
<hw>Dis`ad*vance"</hw> <pr>(?; 61)</pr>, <pos>v. t. & i.</pos>
<ety>[Pref. <ets>dis-</ets> + <ets>advance</ets>: cf. OF.
<ets>desavancier</ets>.]</ety> <def>To draw back, or cause to draw
back.</def> <mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disadvantage</ent><br/
<hw>Dis`ad*van"tage</hw> <pr>(?; 48, 61)</pr>, <pos>n.</pos> <ety>[Cf.
F. <ets>d<eacute/savantage</ets>.]</ety> <sn>1.</sn> <def>Deprivation of
advantage; unfavorable or prejudicial quality, condition, circumstance,
or the like; that which hinders success, or causes loss or
injury.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I was brought here under the <qex>disadvantage</qex> of being
unknown by sight to any of you.</q> <rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Abandoned by their great patron, the faction henceforward acted at
<qex>disadvantage</qex>.</q> <rj><qau>Palfrey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Loss; detriment; hindrance; prejudice to interest,
fame, credit, profit, or other good.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They would throw a construction on his conduct, to his
<qex>disadvantage</qex> before the public.</q>
<rj><qau>Bancroft.</qau></rj></p>

<p><syn><b>Syn.</b> -- Detriment; injury; hurt; loss; damage.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disadvantage</ent><br/
<hw>Dis`ad*van"tage</hw>, <pos>v. t.</pos> <ety>[Cf. F.
<ets>d<eacute/savantager</ets>.]</ety> <def>To injure the interest of;
to be detrimental to.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disadvantageable</ent><br/
<hw>Dis`ad*van"tage*a*ble</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Injurious; disadvantageous.</def> <mark>[Obs.]</mark>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disadvantageous</ent><br/
<hw>Dis*ad`van*ta"geous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>d<eacute/savantageux</ets>.]</ety> <def>Attended with disadvantage;
unfavorable to success or prosperity; inconvenient; prejudicial; --
opposed to <ant>advantageous</ant>; <as>as, the situation of an army is
<ex>disadvantageous</ex> for attack or defense</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Even in the <qex>disadvantageous</qex> position in which he had
been placed, he gave clear indications of future excellence.</q>
<rj><qau>Prescott.</qau></rj></p>

<p>-- <wordforms><wf>Dis*ad`van*ta"geous*ly</wf>, <pos>adv.</pos> --
<wf>Dis*ad`van*ta"geous*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disadventure</ent><br/
<hw>Dis`ad*ven"ture</hw> <pr>(?; 135)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>dis-</ets> + <ets>adventure</ets>: cf. OF.
<ets>desaventure</ets>.]</ety> <def>Misfortune; mishap.</def>
<mark>[Obs.]</mark> <rj><au>Sir W. Raleigh.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disadventurous</ent><br/
<hw>Dis`ad*ven"tur*ous</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Unprosperous; unfortunate.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disadvise</ent><br/
<hw>Dis`ad*vise"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To advise
against; to dissuade from.</def> <mark>[R.]</mark>
<rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disaffect</ent><br/
<hw>Dis`af*fect"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Disaffected</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Disaffecting</conjf>.]</vmorph> <sn>1.</sn> <def>To alienate or
diminish the affection of; to make unfriendly or less friendly; to fill
with discontent and unfriendliness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They had attempted to <qex>disaffect</qex> and discontent his
majesty's late army.</q> <rj><qau>Clarendon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To disturb the functions of; to disorder.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It <qex>disaffects</qex> the bowels.</q>
<rj><qau>Hammond.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To lack affection for; to be alienated from, or
indisposed toward; to dislike.</def> <mark>[Obs.]</mark> <rj><au>Bp.
Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disaffected</ent><br/
<hw>Dis`af*fect"ed</hw>, <pos>a.</pos> <def>Alienated in feeling; not
wholly loyal.</def> <au>J. H. Newman.</au> --
<wordforms><wf>Dis`af*fect"ed*ly</wf>, <pos>adv.</pos> --
<wf>Dis`af*fect"ed*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disaffection</ent><br/
<hw>Dis`af*fec"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>State of being disaffected; alienation or want of affection or good
will, esp. toward those in authority; unfriendliness; dislike.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In the making laws, princes must have regard to . . . the
affections and <qex>disaffections</qex> of the people.</q> <rj><qau>Jer.
Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Disorder; bad constitution.</def> <mark>[R.]</mark>
<rj><au>Wiseman.</au></rj></p>

<p><syn><b>Syn.</b> -- Dislike; disgust; discontent; unfriendliness;
alienation; disloyalty; hostility.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disaffectionate</ent><br/
<hw>Dis`af*fec"tion*ate</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Not
disposed to affection; unfriendly; disaffected.</def> <mark>[R.]</mark>
<rj><au>Blount.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disaffirm</ent><br/
<hw>Dis`af*firm"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <sn>1.</sn> <def>To
assert the contrary of; to contradict; to deny; -- said of that which
has been asserted.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>To refuse to confirm; to annul, as
a judicial decision, by a contrary judgment of a superior
tribunal.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disaffirmance</ent><br/
<hw>Dis`af*firm"ance</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>The act of disaffirming; denial; negation.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>Overthrow or annulment by the
decision of a superior tribunal; <as>as, <ex>disaffirmance</ex> of
judgment</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disaffirmation</ent><br/
<hw>Dis*af`fir*ma"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
disaffirming; negation; refutation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disafforest</ent><br/
<hw>Dis`af*for"est</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Disafforested</conjf>; <pos>p.
pr. & vb. n.</pos> <conjf>Disafforesting</conjf>.]</vmorph> <ety>[Pref.
<ets>dis-</ets> + <ets>afforest</ets>: cf. OF.
<ets>desaforester</ets>.]</ety> <fld>(Eng. Law)</fld> <def>To reduce
from the privileges of a forest to the state of common ground; to exempt
from forest laws.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>By charter 9 Henry III. many forests were
<qex>disafforested</qex>.</q> <rj><qau>Blackstone.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 418 --></p>

<p><ent>Disaggregate</ent><br/
<hw>Dis*ag"gre*gate</hw> <pr>(d<icr/s*<acr/g"gr<esl/*g<amac/t)</pr>,
<pos>v. t.</pos> <def>To destroy the aggregation of; to separate into
component parts, as an aggregate mass.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disaggregation</ent><br/
<hw>Dis*ag`gre*ga"tion</hw>
<pr>(d<icr/s*<acr/g`gr<esl/*g<amac/"sh<ucr/n)</pr>, <pos>n.</pos>
<ety>[Cf. F. <ets>d<eacute/sagr<eacute/gation</ets>.]</ety> <def>The
separation of an aggregate body into its component parts.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disagree</ent><br/
<hw>Dis`a*gree"</hw> <pr>(d<icr/s`<adot/*gr<emac/")</pr>, <pos>v.
i.</pos> <vmorph>[<pos>imp. & p. p.</pos> <conjf>Disagreed</conjf>
<pr>(d<icr/s`<adot/*gr<emac/d")</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Disagreeing</conjf>.]</vmorph> <ety>[Pref. <ets>dis-</ets> +
<ets>agree</ets>: cf. F. <ets>d<eacute/sagr<eacute/er</ets> to
displease.]</ety> <sn>1.</sn> <def>To fail to accord; not to agree; to
lack harmony; to differ; to be unlike; to be at variance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They reject the plainest sense of Scripture, because it seems to
<qex>disagree</qex> with what they call reason.</q>
<rj><qau>Atterbury.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To differ in opinion; to hold discordant views; to
be at controversy; to quarrel.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Who shall decide, when doctors <qex>disagree</qex>?</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To be unsuited; to have unfitness; <as>as,
<ex>medicine</ex> sometimes <ex>disagrees</ex> with the patient; food
often <ex>disagrees</ex> with the stomach or the taste.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Usually followed by <xex>with</xex>, sometimes by
<xex>to</xex>, rarely by <xex>from</xex>; as, I <xex>disagree</xex> to
your proposal.</note></p>

<p><syn><b>Syn.</b> -- To differ; vary; dissent.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disagreeable</ent><br/
<hw>Dis`a*gree"a*ble</hw> <pr>(d<icr/s`<adot/*gr<emac/"<adot/*b'l)</pr>,
<pos>a.</pos> <ety>[Cf. F. <ets>d<eacute/sagr<eacute/able</ets>.]</ety>
<sn>1.</sn> <def>Not agreeable, conformable, or congruous; contrary;
unsuitable.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Preach you truly the doctrine which you have received, and each
nothing that is <qex>disagreeable</qex> thereunto.</q>
<rj><qau>Udall.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Exciting repugnance; offensive to the feelings or
senses; displeasing; unpleasant.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That which is <qex>disagreeable</qex> to one is many times
agreeable to another, or <qex>disagreeable</qex> in a less degree.</q>
<rj><qau>Wollaston.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disagreeableness</ent><br/
<hw>Dis`a*gree"a*ble*ness</hw>, <pos>n.</pos> <def>The state or quality
of being; disagreeable; unpleasantness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disagreeably</ent><br/
<hw>Dis`a*gree"a*bly</hw>, <pos>adv.</pos> <def>In a disagreeable
manner; unsuitably; offensively.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disagreeance</ent><br/
<hw>Dis`a*gree"ance</hw> <pr>(d<icr/s`<adot/*gr<emac/"<ait/ns)</pr>,
<pos>n.</pos> <def>Disagreement.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disagreement</ent><br/
<hw>Dis`a*gree"ment</hw> <pr>(d<icr/s`<adot/*gr<emac/"m<eit/nt)</pr>,
<pos>n.</pos> <ety>[Cf. F. <ets>d<eacute/sagr<eacute/ment</ets>
disagreeable circumstance, disagreeableness.]</ety> <sn>1.</sn> <def>The
state of disagreeing; a being at variance; dissimilitude;
diversity.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Unsuitableness; unadaptedness.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Difference of opinion or sentiment.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A falling out, or controversy; difference.</def></p>

<p><syn><b>Syn.</b> -- Difference; diversity; dissimilitude; unlikeness;
discrepancy; variance; dissent; misunderstanding; dissension; division;
dispute; jar; wrangle; discord.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disagreer</ent><br/
<hw>Dis`a*gre"er</hw> <pr>(d<icr/s`<adot/*gr<emac/"<etil/r)</pr>,
<pos>n.</pos> <def>One who disagrees.</def>
<rj><au>Hammond.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disalliege</ent><br/
<hw>Dis`al*liege"</hw> <pr>(d<icr/s`<acr/l*l<emac/j")</pr>, <pos>v.
t.</pos> <def>To alienate from allegiance.</def> <mark>[Obs. &
R.]</mark> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disallow</ent><br/
<hw>Dis`al*low"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Disallowed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Disallowing</conjf>.]</vmorph> <ety>[Pref.
<ets>dis-</ets> + <ets>allow</ets>: cf. OF. <ets>desalouer</ets>,
<ets>desloer</ets>, to blame, dissuade.]</ety> <def>To refuse to allow;
to deny the force or validity of; to disown and reject; <as>as, the
judge <ex>disallowed</ex> the executor's charge</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To whom coming, as unto a living stone, <qex>disallowed</qex>
indeed of men, but chosen of God.</q> <rj><qau>1 Pet. ii.
4.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>That the edicts of C<ae/sar we may at all times
<qex>disallow</qex>, but the statutes of God for no reason we may
reject.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ This verb was sometimes followed by <xex>of</xex>; as,
<ldquo/What follows, if we <xex>disallow of</xex> this?<rdquo/
<au>Shak.</au> See <er>Allow</er>.</note></p>

<p><syn><b>Syn.</b> -- To disapprove; prohibit; censure;
reject.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disallowable</ent><br/
<hw>Dis`al*low"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Not
allowable; not to be suffered.</def> <au>Raleigh.</au> --
<wordforms><wf>Dis`al*low"a*ble*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disallowance</ent><br/
<hw>Dis`al*low"ance</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
disallowing; refusal to admit or permit; rejection.</def></p>

<p><syn><b>Syn.</b> -- Disapprobation; prohibition; condemnation;
censure; rejection.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disally</ent><br/
<hw>Dis`al*ly"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>dis-</ets> + <ets>ally</ets>: cf. F.
<ets>d<eacute/saltier</ets>.]</ety> <def>To part, as an alliance; to
sunder.</def> <mark>[R.]</mark> <ldquo/<xex>Disallied</xex> their
nuptials.<rdquo/ <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disanchor</ent><br/
<hw>Dis*an"chor</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <ety>[Pref.
<ets>dis-</ets> + <ets>anchor</ets>: cf. F.
<ets>d<eacute/sancrer</ets>.]</ety> <def>To raise the anchor of, as a
ship; to weigh anchor.</def> <mark>[Obs.]</mark>
<rj><au>Heywood.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disangelical</ent><br/
<hw>Dis`an*gel"ic*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Not
angelical.</def> <mark>[R.]</mark> <ldquo/<xex>Disangelical</xex>
nature.<rdquo/ <rj><au>Coventry.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disanimate</ent><br/
<hw>Dis*an"i*mate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Disanimated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Disanimating</conjf> <pr>(?)</pr>.]</vmorph> <sn>1.</sn>
<def>To deprive of life.</def> <mark>[R.]</mark>
<rj><au>Cudworth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To deprive of spirit; to dishearten.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disanimation</ent><br/
<hw>Dis*an`i*ma"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>Privation of life.</def> <mark>[R.]</mark> <rj><au>Sir T.
Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The state of being disanimated or discouraged;
depression of spirits.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disannex</ent><br/
<hw>Dis`an*nex"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To disunite; to
undo or repeal the annexation of.</def> <rj><au>State Trials
(1608).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disannul</ent><br/
<hw>Dis`an*nul"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To annul
completely; to render void or of no effect.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>For the Lord of hosts hath purposed, and who shall
<qex>disannul</qex> it?</q> <rj><qau>Isaiah xiv. 27.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The prefix in this word an its derivatives is intensive,
and not negative.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disannuller</ent><br/
<hw>Dis`an*nul"ler</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
disannuls.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disannulment</ent><br/
<hw>Dis`an*nul"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Complete
annulment.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disanoint</ent><br/
<hw>Dis`a*noint"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To invalidate
the consecration of; <as>as, to <ex>disanoint</ex> a king</as>.</def>
<mark>[Obs.]</mark> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disapparel</ent><br/
<hw>Dis`ap*par"el</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[See
<er>Apparel</er>, <pos>v. t.</pos>]</ety> <ety>[Pref. <ets>dis-</ets> +
<ets>apparel</ets>: cf. OF. <ets>desapareiller</ets>.]</ety> <def>To
disrobe; to strip of apparel; to make naked.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Drink <qex>disapparels</qex> the soul.</q> <rj><qau>Junius
(1635).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disappear</ent><br/
<hw>Dis`ap*pear"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Disappeared</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Disappearing</conjf>.]</vmorph> <sn>1.</sn> <def>To
cease to appear or to be perceived; to pass from view, gradually or
suddenly; to vanish; to be no longer seen; <as>as, darkness
<ex>disappears</ex> at the approach of light; a ship <ex>disappears</ex>
as she sails from port.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To cease to be or exist; <as>as, the epidemic has
<ex>disappeared</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disappearance</ent><br/
<hw>Dis`ap*pear"ance</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
disappearing; cessation of appearance; removal from sight;
vanishing.</def> <rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disappearing</ent><br/
<hw>Dis`ap*pear"ing</hw>, <def><pos>p. pr. & vb. n.</pos> of
<er>Disappear</er>.</def></p>

<p><cs><col><b>Disappearing carriage</b></col> <fld>(Ordnance)</fld>,
<cd>a carriage for heavy coast guns on which the gun is raised above the
parapet for firing and upon discharge is lowered behind the parapet for
protection. The standard type of disappearing carriage in the coast
artillery of the United States army is the
<styp><ecol><b>Buffington-Crozier carriage</b></ecol></styp>, in which
the gun trunnions are secured at the upper and after ends of a pair of
heavy levers, at the lower ends of which is attached a counterweight of
lead. The levers are pivoted at their middle points, which are, with the
top carriage, permitted restrained motion along the slightly inclined
chassis rails. The counterweight is held in place by a pawl and ratchet.
When the gun is loaded the pawl is released and the counterweight sinks,
raising the gun to the firing position above the parapet. The recoil
following the discharge returns the gun to the loading position, the
counterweight rising until the pawl engages the ratchet.</cd></cs><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Disappendency</ent><br/
<hw>Dis`ap*pend"en*cy</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A detachment
or separation from a former connection.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disappendent</ent><br/
<hw>Dis`ap*pend"ent</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Freed from a
former connection or dependence; disconnected.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disappoint</ent><br/
<hw>Dis`ap*point"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Disapointed</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Disappointing</conjf>.]</vmorph> <ety>[OF.
<ets>desapointier</ets>, F. <ets>d<eacute/sappointer</ets>; pref.
<ets>des-</ets> (L. <ets>dis-</ets>) + <ets>apointier</ets>, F.
<ets>appointier</ets>, to appoint. See <er>Appoint</er>.]</ety>
<sn>1.</sn> <def>To defeat of expectation or hope; to hinder from the
attainment of that which was expected, hoped, or desired; to balk;
<as>as, a man is <ex>disappointed</ex> of his hopes or expectations, or
his hopes, desires, intentions, expectations, or plans are
<ex>disappointed</ex>; a bad season <ex>disappoints</ex> the farmer of
his crops; a defeat <ex>disappoints</ex> an enemy of his
spoil.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>I was <qex>disappointed</qex>, but very agreeably.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Disappointed of</xex> a thing not obtained;
<xex>disappointed in</xex> a thing obtained.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To frustrate; to fail; to hinder of
result.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His retiring foe<br/
Shrinks from the wound, and <qex>disappoints</qex> the blow.</q>
<rj><qau>Addison.</qau></rj></p>

<p><syn><b>Syn.</b> -- To tantalize; fail; frustrate; balk; baffle;
delude; foil; defeat. See <er>Tantalize</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disappointed</ent><br/
<hw>Dis`ap*point"ed</hw>, <pos>a.</pos> <sn>1.</sn> <def>Defeated of
expectation or hope; balked; <as>as, a <ex>disappointed</ex> person or
hope</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Unprepared; unequipped.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Cut off even in the blossoms of my sin,<br/
Unhouseled, <qex>disappointed</qex>, unaneled.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>disappointing</ent><br/
<hw>disappointing</hw> <pos>a.</pos> <def>defeating one's expectations
or hopes; failing to fulfill one's expectations or hopes; <as>as, a
<ex>disappointing</ex> result; a <ex>disappointing</ex> crop
yield</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>disappointing</ent><br/
<hw>disappointing</hw> <pos>n.</pos> <def>the act of disappointing
someone.</def><br/
<syn><b>Syn. --</b> disappointment, dashing hopes.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Disappointment</ent><br/
<hw>Dis`ap*point"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>d<eacute/sappointement</ets>.]</ety> <sn>1.</sn> <def>The act of
disappointing, or the state of being disappointed; defeat or failure of
expectation or hope; miscarriage of design or plan;
frustration.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If we hope for things of which we have not thoroughly considered
the value, our <qex>disappointment</qex> will be greater than our
pleasure in the fruition of them.</q> <rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>In <qex>disappointment</qex> thou canst bless.</q>
<rj><qau>Keble.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which disappoints.</def></p>

<p><syn><b>Syn.</b> -- Miscarriage; frustration; balk.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disappreciate</ent><br/
<hw>Dis`ap*pre"ci*ate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[See
<er>Appreciate</er>.]</ety> <def>To undervalue; not to esteem.</def> --
<wordforms><wf>Dis`ap*pre`ci*a"tion</wf> <pr>(#)</pr>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disapprobation</ent><br/
<hw>Dis*ap`pro*ba"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>dis-</ets> + <ets>approbation</ets>: cf. F.
<ets>d<eacute/sapprobation</ets>. Cf. <er>Disapprove</er>.]</ety>
<def>The act of disapproving; mental condemnation of what is judged
wrong, unsuitable, or inexpedient; feeling of censure.</def>

<q>We have ever expressed the most unqualified <qex>disapprobation</qex>
of all the steps.</q> <rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disapprobatory</ent><br/
<hw>Dis*ap"pro*ba`to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Containing
disapprobation; serving to disapprove.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disappropriate</ent><br/
<hw>Dis`ap*pro"pri*ate</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Law)</fld>
<def>Severed from the appropriation or possession of a spiritual
corporation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The appropriation may be severed, and the church become
<qex>disappropriate</qex>, two ways.</q>
<rj><qau>Blackstone.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disappropriate</ent><br/
<hw>Dis`ap*pro"pri*ate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <sn>1.</sn>
<def>To release from individual ownership or possession.</def>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>To sever from appropriation or
possession a spiritual corporation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Appropriations of the several parsonages . . . would heave been,
by the rules of the common law, <qex>disappropriated</qex>.</q>
<rj><qau>Blackstone.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disappropriation</ent><br/
<hw>Dis`ap*pro`pri*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act
of disappropriating.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disapproval</ent><br/
<hw>Dis`ap*prov"al</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Disapprobation;
dislike; censure; adverse judgment.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disapprove</ent><br/
<hw>Dis`ap*prove</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Disapproved</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Disapproving</conjf>.]</vmorph> <ety>[Pref.
<ets>dis-</ets> + <ets>approve</ets>: cf. F.
<ets>d<eacute/approuver</ets>. Cf. <er>Disapprobation</er>.]</ety>
<sn>1.</sn> <def>To pass unfavorable judgment upon; to condemn by an act
of the judgment; to regard as wrong, unsuitable, or inexpedient; to
censure; <as>as, to <ex>disapprove</ex> the conduct of
others</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To refuse official approbation to; to disallow; to
decline to sanction; <as>as, the sentence of the court-martial was
<ex>disapproved</ex> by the commander in chief</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ This verb is often followed by <xex>of</xex>; as, to
<xex>disapprove</xex> of an opinion, of such conduct. See
<er>Approve</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disapprover</ent><br/
<hw>Dis`ap*prov"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
disapproves.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>disapproving</ent><br/
<hw>disapproving</hw> <pos>adj.</pos> <def>expressing
disapproval.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Disapprovingly</ent><br/
<hw>Dis`ap*prov"ing*ly</hw>, <pos>adv.</pos> <def>In a disapproving
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disard</ent><br/
<hw>Dis"ard</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Dizzard</er>.</def> <mark>[Obs.]</mark>
<rj><au>Burton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disarm</ent><br/
<hw>Dis*arm"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Disarming</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Disarming</conjf>.]</vmorph> <ety>[OE.
<ets>desarmen</ets>, F. <ets>d<eacute/sarmer</ets>; pref.
<ets>d<eacute/s-</ets> (L. <ets>dis-</ets>) + <ets>armer</ets> to arm.
See <er>Arm</er>.]</ety> <sn>1.</sn> <def>To deprive of arms; to take
away the weapons of; to deprive of the means of attack or defense; to
render defenseless.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Security <qex>disarms</qex> the best-appointed army.</q>
<rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The proud was half <qex>disarmed</qex> of pride.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To deprive of the means or the disposition to harm;
to render harmless or innocuous; <as>as, to <ex>disarm</ex> a man's
wrath</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disarmament</ent><br/
<hw>Dis*arm"a*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>d<eacute/sarmement</ets>.]</ety> <def>The act of
disarming.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disarmature</ent><br/
<hw>Dis*ar"ma*ture</hw> <pr>(?; 135)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>dis-</ets> + <ets>armature</ets>.]</ety> <def>The act of divesting
of armature.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disarmed</ent><br/
<hw>Dis*armed"</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Deprived of arms.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Her.)</fld> <def>Deprived of claws, and teeth or
beaks.</def> <rj><au>Cussans.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disarmer</ent><br/
<hw>Dis*arm"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
disarms.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>disarming</ent><br/
<hw>disarming</hw> <pos>adj.</pos> <sn>1.</sn> <def>capable of allaying
suspicion or hostility and inspiring confidence; <as>as, a
<ex>disarming</ex> smile</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>capable of allaying hostility.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>disarming</ent><br/
<hw>disarming</hw> <pos>n.</pos> <def>act of reducing or depriving of
weapons.</def><br/
<syn><b>Syn. --</b> disarmament.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Disarrange</ent><br/
<hw>Dis`ar*range"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Disarranged</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Disarranging</conjf>.]</vmorph> <ety>[Pref.
<ets>dis-</ets> + <ets>arrange</ets>: cf. F.
<ets>d<eacute/sarranger</ets>.]</ety> <def>To unsettle or disturb the
order or due arrangement of; to throw out of order.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>disarranged</ent><br/
<hw>disarranged</hw> <pos>adj.</pos> <def>having the arrangement
disturbed; not put in order; <as>as, her <ex>disarranged</ex> hair</as>.
Opposite of <ant>arranged</ant>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Disarrangement</ent><br/
<hw>Dis`ar*range"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
disarranging, or the state of being disarranged; confusion;
disorder.</def> <rj><au>Cowper.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disarray</ent><br/
<hw>Dis`ar*ray"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Disarrayed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Disarraying</conjf>.]</vmorph> <ety>[Pref.
<ets>dis-</ets> + <ets>array</ets>, v.: cf. OF. <ets>desarroyer</ets>,
<ets>desarreier</ets>.]</ety> <sn>1.</sn> <def>To throw into disorder;
to break the array of.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Who with fiery steeds<br/
Oft <qex>disarrayed</qex> the foes in battle ranged.</q>
<rj><qau>Fenton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To take off the dress of; to unrobe.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>So, as she bade, the witch they <qex>disarrayed</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disarray</ent><br/
<hw>Dis`ar*ray"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>d<eacute/sarroi</ets>.]</ety> <sn>1.</sn> <def>Want of array or
regular order; disorder; confusion.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Disrank the troops, set all in <qex>disarray</qex>.</q>
<rj><qau>Daniel.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Confused attire; undress.</def>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disarrayment</ent><br/
<hw>Dis`ar*ray"ment</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Disorder.</def> <mark>[R.]</mark> <rj><au>Feltham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disarticulate</ent><br/
<hw>Dis`ar*tic"u*late</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To
sunder; to separate, as joints.</def> --
<wordforms><wf>Dis`ar*tic`u*la"tion</wf> <pr>(#)</pr>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disarticulator</ent><br/
<hw>Dis`ar*tic"u*la`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
disarticulates and prepares skeletons.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>disassemble</ent><br/
<hw>dis`as*sem"ble</hw> <pos>v. t.</pos> <sn>1.</sn> <def>to take apart;
to disconnect the parts of; to convert a whole into its constituent
pieces.</def><br/
<syn><b>Syn. --</b> dismantle, take apart, break apart, break up.</syn>
[<source>PJC</source>]</p>

<p><sn>2.</sn> <fld>(Computers)</fld> <def>to convert a computer program
in machine language into an equivalent assembly-language file.</def><br/
[<source>PJC</source>]</p>

<p><ent>disassemble</ent><br/
<hw>dis`as*sem"ble</hw> <pos>v. i.</pos> <def>to be able to come apart
easily; to be converted into constituent parts; <as>as, the rifle
<ex>disassembles</ex> into small pieces for concealment</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>disassembler</ent><br/
<hw>dis`as*sem"bler</hw> <pos>n.</pos> <fld>(Computers)</fld> <def>a
computer program that takes as input a computer program in machine
language and produces an equivalent assembly-language file.</def><br/
[<source>PJC</source>]</p>

<p><ent>Disassent</ent><br/
<hw>Dis`as*sent"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To
dissent.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disassent</ent><br/
<hw>Dis`as*sent"</hw>, <pos>n.</pos> <def>Dissent.</def>
<mark>[Obs.]</mark> <rj><au>E. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disassenter</ent><br/
<hw>Dis`as*sent"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
disassents; a dissenter.</def> <mark>[Obs.]</mark> <rj><au>State Trials
(1634).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disassiduity</ent><br/
<hw>Dis*as`si*du"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Want of
assiduity or care.</def> <mark>[R.]</mark> <rj><au>Sir H.
Wotton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disassimilate</ent><br/
<hw>Dis`as*sim"i*late</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<fld>(Physiol.)</fld> <def>To subject to disassimilation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disassimilation</ent><br/
<hw>Dis`as*sim`i*la"tion</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Physics)</fld> <def>The decomposition of complex substances,
within the organism, into simpler ones suitable only for excretion, with
evolution of energy, -- a normal nutritional process the reverse of
assimilation; downward metabolism; -- now more commonly called
<altname>catabolism</altname>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><q>The breaking down of already existing chemical compounds into
simpler ones, sometimes called <qex>disassimilation</qex>.</q>
<rj><qau>Martin.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disassimilative</ent><br/
<hw>Dis`as*sim"i*la*tive</hw> <pr>(?)</pr>, <pos>a.</pos>
<fld>(Physiol.)</fld> <def>Having power to disassimilate; of the nature
of disassimilation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Disassimilative</qex> processes constitute a marked feature
in the life of animal cells.</q> <rj><qau>McKendrick.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disassociate</ent><br/
<hw>Dis`as*so"ci*ate</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Disassociated</conjf>
<pr>(?)</pr>; <pos>p. pr. & vb. n.</pos> <conjf>Disassociating</conjf>
<pr>(?)</pr>.]</vmorph> <def>To disconnect from things associated; to
disunite; to dissociate.</def> <rj><au>Florio.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disaster</ent><br/
<hw>Dis*as"ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>d<eacute/sastre</ets>; pref. <ets>d<eacute/s-</ets> (L.
<ets>dis-</ets>) + <ets>astre</ets> star, fr. L. <ets>astrum</ets>; a
word of astrological origin. See <er>Aster</er>, <er>Astral</er>,
<er>Star</er>.]</ety> <sn>1.</sn> <def>An unpropitious or baleful aspect
of a planet or star; malevolent influence of a heavenly body; hence, an
ill portent.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Disasters</qex> in the sun.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An adverse or unfortunate event, esp. a sudden and
extraordinary misfortune; a calamity; a serious mishap.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>But noble souls, through dust and heat,<br/
Rise from <qex>disaster</qex> and defeat<br/
The stronger.</q> <rj><qau>Longfellow.</qau></rj></p>

<p><syn><b>Syn.</b> -- Calamity; misfortune; mishap; mischance;
visitation; misadventure; ill luck. See <er>Calamity</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disaster</ent><br/
<hw>Dis*as"ter</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To blast by the
influence of a baleful star.</def> <mark>[Obs.]</mark> <rj><au>Sir P.
Sidney.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To bring harm upon; to injure.</def>
<mark>[R.]</mark> <rj><au>Thomson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disasterly</ent><br/
<hw>Dis*as"ter*ly</hw>, <pos>adv.</pos> <def>Disastrously.</def>
<mark>[Obs.]</mark> <rj><au>Drayton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disastrous</ent><br/
<hw>Dis*as"trous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>d<eacute/sastreux</ets>. See <er>Disaster</er>.]</ety> <sn>1.</sn>
<def>Full of unpropitious stellar influences; unpropitious;
ill-boding.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The moon<br/
In dim eclipse, <qex>disastrous</qex> twilight sheds.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Attended with suffering or disaster; very
unfortunate; calamitous; ill-fated; ending in utter failure or ruin;
<as>as, a <ex>disastrous</ex> day; a <ex>disastrous</ex> termination of
an undertaking.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Wherein I spake of most <qex>disastrous</qex> chances.</q>
<rj><qau>Shak.</qau></rj></p>

<p>-- <wordforms><wf>Dis*as"trous*ly</wf>, <pos>adv.</pos> --
<wf>Dis*as"trous*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disattire</ent><br/
<hw>Dis`at*tire"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>dis-</ets> + <ets>attire</ets>: cf. OF.
<ets>desatirier</ets>.]</ety> <def>To unrobe; to undress.</def>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disaugment</ent><br/
<hw>Dis`aug*ment"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To
diminish.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disauthorize</ent><br/
<hw>Dis*au"thor*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To deprive
of credit or authority; to discredit.</def> <mark>[R.]</mark> <rj><au>W.
Wotton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disavaunce</ent><br/
<hw>Dis`a*vaunce"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Cf.
<er>Disadvance</er>.]</ety> <def>To retard; to repel; to do damage
to.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disaventure</ent><br/
<hw>Dis`a*ven"ture</hw> <pr>(?; 135)</pr>, <pos>n.</pos> <ety>[See
<er>Disadventure</er>, <er>Adventure</er>.]</ety> <def>Misfortune.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disaventurous</ent><br/
<hw>Dis`a*ven"tur*ous</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Misadventurous; unfortunate.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disavouch</ent><br/
<hw>Dis`a*vouch"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>dis-</ets> + <ets>avouch</ets>. Cf. <er>Disavow</er>.]</ety>
<def>To disavow.</def> <mark>[R.]</mark> <rj><au>Daniel.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disavow</ent><br/
<hw>Dis`a*vow"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Disavowed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Disavowing</conjf>.]</vmorph> <ety>[F.
<ets>d<eacute/savouer</ets>; pref. <ets>d<eacute/s-</ets> (L.
<ets>dis</ets>-) + <ets>avouer</ets> to avow. See <er>Avow</er>, and cf.
<er>Disavouch</er>.]</ety> <sn>1.</sn> <def>To refuse strongly and
solemnly to own or acknowledge; to deny responsibility for, approbation
of, and the like; to disclaim; to disown; <as>as, he was charged with
embezzlement, but he <ex>disavows</ex> the crime</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A solemn promise made and <qex>disavowed</qex>.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To deny; to show the contrary of; to
disprove.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Yet can they never<br/
Toss into air the freedom of my birth,<br/
Or <qex>disavow</qex> my blood Plantagenet's.</q>
<rj><qau>Ford.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>disavowable</ent><br/
<hw>disavowable</hw> <pos>adj.</pos> <def>able to be
disavowed.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Disavowal</ent><br/
<hw>Dis`a*vow"al</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
disavowing, disclaiming, or disowning; rejection and denial.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>An earnest <qex>disavowal</qex> of fear often proceeds from
fear.</q> <rj><qau>Richardson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disavowance</ent><br/
<hw>Dis`a*vow"ance</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Disavowal.</def> <mark>[Obs.]</mark> <rj><au>South.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disavower</ent><br/
<hw>Dis`a*vow"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
disavows.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disavowment</ent><br/
<hw>Dis`a*vow"ment</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Disavowal.</def> <mark>[R.]</mark> <rj><au>Wotton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disband</ent><br/
<hw>Dis*band"</hw> <pr>(?; see <er>Dis-</er>)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Disbanded</conjf>; <pos>p. pr. &
vb. n.</pos> <conjf>Disbanding</conjf>.]</vmorph> <ety>[Pref.
<ets>dis-</ets> + <ets>band</ets>: cf. OF. <ets>desbander</ets>, F.
<ets>d<eacute/bander</ets>, to unbind, unbend. See <er>Band</er>, and
cf. <er>Disbend</er>, <er>Disbind</er>.]</ety> <sn>1.</sn> <def>To loose
the bands of; to set free; to disunite; to scatter; to disperse; to
break up the organization of; especially, to dismiss from military
service; <as>as, to <ex>disband</ex> an army</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They <qex>disbanded</qex> themselves and returned, every man to
his own dwelling.</q> <rj><qau>Knolles.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To divorce.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>And therefore . . . she ought to be <qex>disbanded</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disband</ent><br/
<hw>Dis*band"</hw>, <pos>v. i.</pos> <def>To become separated, broken
up, dissolved, or scattered; especially, to quit military service by
breaking up organization.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 419 --></p>

<p><q>When both rocks and all things shall <qex>disband</qex>.</q>
<rj><qau>Herbert.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Human society would in a short space <qex>disband</qex>.</q>
<rj><qau>Tillotson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disbandment</ent><br/
<hw>Dis*band"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
disbanding.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disbar</ent><br/
<hw>Dis*bar"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Disbarred</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Disbarring</conjf>.]</vmorph> <fld>(Law)</fld> <def>To
expel from the bar, or the legal profession; to deprive (an attorney,
barrister, or counselor) of his status and privileges as such.</def>
<rj><au>Abbott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disbark</ent><br/
<hw>Dis*bark"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>dis-</ets> + <ets>bark</ets> a small ship: cf. OF.
<ets>desbarquer</ets>, F. <ets>d<eacute/barquer</ets>. Cf.
<er>Debark</er>, <er>Disembark</er>.]</ety> <def>To disembark.</def>
<rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disbark</ent><br/
<hw>Dis*bark"</hw>, <pos>v. t.</pos> <ety>[Pref. <ets>dis-</ets> +
<ets>bark</ets> rind.]</ety> <def>To strip of bark; to bark.</def>
<mark>[R.]</mark> <rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disbarment</ent><br/
<hw>Dis*bar"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Act of
disbarring.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disbase</ent><br/
<hw>Dis*base"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Cf.
<er>Debase</er>.]</ety> <def>To debase or degrade.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Nor you nor your house were so much as spoken of before I
<qex>disbased</qex> myself.</q> <rj><qau>B. Jonson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disbecome</ent><br/
<hw>Dis`be*come"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To
misbecome.</def> <mark>[Obs.]</mark> <rj><au>Massinger.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disbelief</ent><br/
<hw>Dis*be*lief"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
disbelieving;; a state of the mind in which one is fully persuaded that
an opinion, assertion, or doctrine is not true; refusal of assent,
credit, or credence; denial of belief.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Our belief or <qex>disbelief</qex> of a thing does not alter the
nature of the thing.</q> <rj><qau>Tillotson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>No sadder proof can be given by a man of his own littleness that
<qex>disbelief</qex> in great men.</q> <rj><qau>Carlyle.</qau></rj></p>

<p><syn><b>Syn.</b> -- Distrust; unbelief; incredulity; doubt;
skepticism. -- <er>Disbelief</er>, <er>Unbelief</er>.
<xex>Unbelief</xex> is a mere failure to admit; <xex>disbelief</xex> is
a positive rejection. One may be an <xex>unbeliever</xex> in
Christianity from ignorance or want of inquiry; a <xex>unbeliever</xex>
has the proofs before him, and incurs the guilt of setting them aside.
<xex>Unbelief</xex> is usually open to conviction; <xex>disbelief</xex>
is already convinced as to the falsity of that which it rejects. Men
often tell a story in such a manner that we regard everything they say
with <xex>unbelief</xex>. Familiarity with the worst parts of human
nature often leads us into a <xex>disbelief</xex> in many good qualities
which really exist among men.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disbelieve</ent><br/
<hw>Dis`be*lieve"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Disbelieved</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Disbelieving</conjf>.]</vmorph> <def>Not to believe; to
refuse belief or credence to; to hold not to be true or
actual.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Assertions for which there is abundant positive evidence are often
<qex>disbelieved</qex>, on account of what is called their improbability
or impossibility.</q> <rj><qau>J. S. Mill.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disbeliever</ent><br/
<hw>Dis`be*liev"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
disbelieves, or refuses belief; an unbeliever. Specifically, one who
does not believe the Christian religion.</def> <rj><au>I.
Watts.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disbench</ent><br/
<hw>Dis*bench"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <sn>1.</sn> <def>To
drive from a bench or seat.</def> <mark>[R.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Eng. Law)</fld> <def>To deprive (a bencher) of his
privileges.</def> <rj><au>Mozley & W.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disbend</ent><br/
<hw>Dis*bend</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To unbend.</def>
<mark>[Obs.]</mark> <rj><au>Stirling.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disbind</ent><br/
<hw>Dis*bind"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Cf.
<er>Disband</er>.]</ety> <def>To unbind; to loosen.</def>
<mark>[Obs.]</mark> <rj><au>Mede.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disblame</ent><br/
<hw>Dis*blame"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[OE.
<ets>desblamen</ets>, OF. <ets>desblasmer</ets>; pref. <ets>des-</ets>
(L. <ets>dis-</ets>) + <ets>blasmer</ets>, F. <ets>bl<acir/mer</ets>, to
blame.]</ety> <def>To clear from blame.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disbodied</ent><br/
<hw>Dis*bod"ied</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Disembodied.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disboscation</ent><br/
<hw>Dis`bos*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>dis-</ets> + F. <ets>bosquet</ets> grove.]</ety> <def>Converting
forest land into cleared or arable land; removal of a forest.</def>
<rj><au>Sir W. Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disbowel</ent><br/
<hw>Dis*bow"el</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[See
<er>Bowel</er>, <pos>v. t.</pos>]</ety> <def>To disembowel.</def>
<mark>[R.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disbranch</ent><br/
<hw>Dis*branch"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[See
<er>Branch</er>, <pos>v.</pos>]</ety> <def>To divest of a branch or
branches; to tear off.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disbud</ent><br/
<hw>Dis*bud"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[See <er>Bud</er>,
<pos>v.</pos>]</ety> <fld>(Hort.)</fld> <def>To deprive of buds or
shoots, as for training, or economizing the vital strength of a
tree.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disburden</ent><br/
<hw>Dis*bur"den</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[See
<er>Burden</er>, <pos>v. t.</pos>]</ety> <ety>[Cf.
<er>Disburthen</er>.]</ety> <def>To rid of a burden; to free from a load
borne or from something oppressive; to unload; to disencumber; to
relieve.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He did it to <qex>disburden</qex> a conscience.</q>
<rj><qau>Feltham.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>My mediations . . . will, I hope, be more calm, being thus
<qex>disburdened</qex>.</q> <rj><qau>Hammond.</qau></rj></p>

<p><syn><b>Syn.</b> -- To unload; unburden; discharge; free.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disburden</ent><br/
<hw>Dis*bur"den</hw>, <pos>v. i.</pos> <def>To relieve one's self of a
burden; to ease the mind.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disburgeon</ent><br/
<hw>Dis*bur"geon</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To strip of
burgeons or buds; to disbud.</def> <mark>[R.]</mark>
<rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disburse</ent><br/
<hw>Dis*burse"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Disbursed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Disbursing</conjf>.]</vmorph> <ety>[OF.
<ets>desbourser</ets>, F. <ets>d<eacute/bourser</ets>; pref.
<ets>des-</ets> (L. <ets>dis-</ets>) + <ets>bourse</ets> purse. See
<er>Burse</er>, and cf. <er>Dispurse</er>.]</ety> <def>To pay out; to
expend; -- usually from a public fund or treasury.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The duty of collecting and <qex>disbursing</qex> his revenues.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Disbursing officer</b></col>, <cd>an officer in any
department of the public service who is charged with the duty of paying
out public money.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disbursement</ent><br/
<hw>Dis*burse"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>d<eacute/boursement</ets>.]</ety> <sn>1.</sn> <def>The act of
disbursing or paying out.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>disbursement</qex> of the public moneys.</q> <rj><qau>U.
S. Statutes.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is disbursed or paid out; <as>as, the
annual <ex>disbursements</ex> exceed the income</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disburser</ent><br/
<hw>Dis*burs"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who disburses
money.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disburthen</ent><br/
<hw>Dis*bur"then</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Disburthened</conjf> <pr>(?)</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>Disburthening</conjf>.]</vmorph> <ety>[Cf.
<er>Disburden</er>.]</ety> <def>To disburden; to relieve of a
load.</def> <mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disc</ent><br/
<hw>Disc</hw> <pr>(d<icr/sk)</pr>, <pos>n.</pos> <ety>[See
<er>Disk</er>, <er>Dish</er>.]</ety> <def>A flat round plate</def>;
<fld>(Biol.)</fld> <def>A circular structure either in plants or
animals; <as>as, a blood <ex>disc</ex>, a germinal <ex>disc</ex>,
etc.</as> Same as <er>Disk</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discage</ent><br/
<hw>Dis*cage"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To uncage.</def>
<mark>[R.]</mark> <rj><au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discal</ent><br/
<hw>Disc"al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to, or
resembling, a disk; <as>as, <ex>discal</ex> cells</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discalceate</ent><br/
<hw>Dis*cal"ce*ate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>discalceatus</ets> unshod; <ets>dis-</ets> + <ets>calceus</ets>
shoe.]</ety> <def>To pull off shoes or sandals from.</def>
<mark>[Obs.]</mark> <rj><au>Cockeram.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discalceated</ent><br/
<hw>Dis*cal"ce*at`ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Deprived off
shoes or sandals; unshod; discalced.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discalceation</ent><br/
<hw>Dis*cal`ce*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
pulling off the shoes or sandals.</def> <mark>[Obs.]</mark> <rj><au>Sir
T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discalced</ent><br/
<hw>Dis*calced"</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Unshod;
barefooted; -- in distinction from <xex>calced</xex>.</def> <ldquo/The
foundation of houses of <xex>discalced</xex> friars.<rdquo/
<rj><au>Cardinal Manning's St. Teresa.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discamp</ent><br/
<hw>Dis*camp"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[See
<er>Decamp</er>.]</ety> <def>To drive from a camp.</def>
<mark>[Obs.]</mark> <rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discandy</ent><br/
<hw>Dis*can"dy</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To melt; to
dissolve; to thaw.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discant</ent><br/
<hw>Dis"cant</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See <er>Descant</er>,
<pos>n.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discapacitate</ent><br/
<hw>Dis*ca*pac"i*tate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To
deprive of capacity; to incapacitate.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discard</ent><br/
<hw>Dis*card"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Discarded</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Discarding</conjf>.]</vmorph> <sn>1.</sn> <fld>(Card
Playing)</fld> <def>To throw out of one's hand, as superfluous cards; to
lay aside (a card or cards).</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To cast off as useless or as no longer of service;
to dismiss from employment, confidence, or favor; to discharge; to turn
away.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They blame the favorites, and think it nothing extraordinary that
the queen should . . . resolve to <qex>discard</qex> them.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To put or thrust away; to reject.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A man <qex>discards</qex> the follies of boyhood.</q> <rj><qau>I.
Taylor.</qau></rj></p>

<p><syn><b>Syn.</b> -- To dismiss; displace; discharge;
cashier.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discard</ent><br/
<hw>Dis*card"</hw>, <pos>v. i.</pos> <fld>(Card Playing)</fld> <def>To
make a discard.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discard</ent><br/
<hw>Dis*card"</hw>, <pos>n.</pos> <fld>(Card Playing)</fld> <def>The act
of discarding; also, the card or cards discarded.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discardure</ent><br/
<hw>Dis*car"dure</hw> <pr>(?; 135)</pr>, <pos>n.</pos> <def>Rejection;
dismissal.</def> <mark>[R.]</mark> <rj><au>Hayter.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discarnate</ent><br/
<hw>Dis*car"nate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>dis-</ets> + <ets>carnatus</ets> fleshy, fr. <ets>caro</ets>,
<ets>carnis</ets>, flesh.]</ety> <def>Stripped of flesh.</def>
<mark>[Obs.]</mark> <ldquo/<xex>Discarnate</xex> bones.<rdquo/
<rj><au>Glanvill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discase</ent><br/
<hw>Dis*case"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To strip; to
undress.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discede</ent><br/
<hw>Dis*cede"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[L.
<ets>discedere</ets>; <ets>dis-</ets> + <ets>cedere</ets> to
yield.]</ety> <def>To yield or give up; to depart.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I dare not <qex>discede</qex> from my copy a tittle.</q>
<rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discept</ent><br/
<hw>Dis*cept"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[L.
<ets>disceptare</ets>.]</ety> <def>To debate; to discuss.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>One dissertates, he is candid;<br/
Two must <qex>discept</qex>, -- has distinguished.</q> <rj><qau>R.
Browning.</qau></rj><-- ??sic. --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disceptation</ent><br/
<hw>Dis`cep*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>disceptatio</ets>.]</ety> <def>Controversy; disputation;
discussion.</def> <mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Verbose janglings and endless <qex>disceptations</qex>.</q>
<rj><qau>Strype.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disceptator</ent><br/
<hw>Dis`cep*ta"tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.]</ety>
<def>One who arbitrates or decides.</def> <mark>[R.]</mark>
<rj><au>Cowley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discern</ent><br/
<hw>Dis*cern"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Discerned</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Discerning</conjf>.]</vmorph> <ety>[F.
<ets>discerner</ets>, L. <ets>discernere</ets>, <ets>discretum</ets>;
<ets>dis-</ets> + <ets>cernere</ets> to separate, distinguish. See
<er>Certain</er>, and cf. <er>Discreet</er>.]</ety> <sn>1.</sn> <def>To
see and identify by noting a difference or differences; to note the
distinctive character of; to discriminate; to distinguish.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>discern</qex> such buds as are fit to produce
blossoms.</q> <rj><qau>Boyle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A counterfeit stone which thine eye can not <qex>discern</qex>
from a right stone.</q> <rj><qau>Robynson (More's
Utopia).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To see by the eye or by the understanding; to
perceive and recognize; <as>as, to <ex>discern</ex> a
difference</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And [I] beheld among the simple ones, I <qex>discerned</qex> among
the youths, a young man void of understanding.</q> <rj><qau>Prov. vii.
7.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Our unassisted sight . . . is not acute enough to
<qex>discern</qex> the minute texture of visible objects.</q>
<rj><qau>Beattie.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I wake, and I <qex>discern</qex> the truth.</q>
<rj><qau>Tennyson.</qau></rj></p>

<p><syn><b>Syn.</b> -- To perceive; distinguish; discover; penetrate;
discriminate; espy; descry; detect. See <er>Perceive</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discern</ent><br/
<hw>Dis*cern"</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To see or
understand the difference; to make distinction; <as>as, to
<ex>discern</ex> between good and evil, truth and
falsehood</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>More than sixscore thousand that cannot <qex>discern</qex> between
their right hand their left.</q> <rj><qau>Jonah iv. 11.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To make cognizance.</def> <mark>[Obs.]</mark>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discernance</ent><br/
<hw>Dis*cern"ance</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Discernment.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discerner</ent><br/
<hw>Dis*cern"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, discerns, distinguishes, perceives, or judges; <as>as, a
<ex>discerner</ex> of truth, of right and wrong</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A great observer and <qex>discerner</qex> of men's natures.</q>
<rj><qau>Clarendon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discernible</ent><br/
<hw>Dis*cern"i*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>discernibilis</ets>.]</ety> <def>Capable of being discerned by the
eye or the understanding; <as>as, a star is <ex>discernible</ex> by the
eye; the identity of difference of ideas is <ex>discernible</ex> by the
understanding.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>The effect of the privations and sufferings . . . was
<qex>discernible</qex> to the last in his temper and deportment.</q>
<rj><qau>Macaulay.</qau></rj></p>

<p><syn><b>Syn.</b> -- Perceptible; distinguishable; apparent; visible;
evident; manifest.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discernibleness</ent><br/
<hw>Dis*cern"i*ble*ness</hw>, <pos>n.</pos> <def>The quality of being
discernible.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discernibly</ent><br/
<hw>Dis*cern"i*bly</hw>, <pos>adv.</pos> <def>In a manner to be
discerned; perceptibly; visibly.</def> <rj><au>Hammond.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discerning</ent><br/
<hw>Dis*cern"ing</hw>, <pos>a.</pos> <def>Acute; shrewd; sagacious;
sharp-sighted.</def> <rj><au>Macaulay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discerningly</ent><br/
<hw>Dis*cern"ing*ly</hw>, <pos>adv.</pos> <def>In a discerning manner;
with judgment; judiciously; acutely.</def> <rj><au>Garth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discernment</ent><br/
<hw>Dis*cern"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>discernement</ets>.]</ety> <sn>1.</sn> <def>The act of
discerning.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The power or faculty of the mind by which it
distinguishes one thing from another; power of viewing differences in
objects, and their relations and tendencies; penetrative and
discriminate mental vision; acuteness; sagacity; insight; <as>as, the
errors of youth often proceed from the want of
<ex>discernment</ex></as>.</def></p>

<p><syn><b>Syn.</b> -- Judgment; acuteness; discrimination; penetration;
sagacity; insight. -- <er>Discernment</er>, <er>Penetration</er>,
<er>Discrimination</er>. <xex>Discernment</xex> is keenness and accuracy
of mental vision; <xex>penetration</xex> is the power of seeing deeply
into a subject in spite of everything that intercepts the view;
<xex>discrimination</xex> is a capacity of tracing out minute
distinctions and the nicest shades of thought. A <xex>discerning</xex>
man is not easily misled; one of a <xex>penetrating</xex> mind sees a
multitude of things which escape others; a <xex>discriminating</xex>
judgment detects the slightest differences.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discerp</ent><br/
<hw>Dis*cerp"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>discerpere</ets>, <ets>discerptum</ets>; <ets>dis-</ets> +
<ets>carpere</ets> to pluck.]</ety> <sn>1.</sn> <def>To tear in pieces;
to rend.</def> <mark>[R.]</mark> <rj><au>Stukeley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To separate; to disunite.</def> <mark>[R.]</mark>
<rj><au>Bp. Hurd.</au></rj></p>

<p><ent>Discerptibility</ent><br/
<ent>Discerpibility</ent><br/
<mhw>{ <hw>Dis*cerp`i*bil"i*ty</hw> <pr>(?)</pr>,
<hw>Dis*cerp`ti*bil"i*ty</hw> <pr>(?)</pr> }</mhw>, <pos>n.</pos>
<def>Capability or liableness to be discerped.</def> <mark>[R.]</mark>
<rj><au>Wollaston.</au></rj></p>

<p><ent>Discerptible</ent><br/
<ent>Discerpible</ent><br/
<mhw>{ <hw>Dis*cerp"i*ble</hw> <pr>(?)</pr>, <hw>Dis*cerp"ti*ble</hw>
<pr>(?)</pr> }</mhw>, <pos>a.</pos> <ety>[See <er>Discerp</er>.]</ety>
<def>Capable of being discerped.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discerption</ent><br/
<hw>Dis*cerp"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>discerptio</ets>.]</ety> <def>The act of pulling to pieces, or of
separating the parts.</def> <rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discerptive</ent><br/
<hw>Dis*cerp"tive</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Tending to
separate or disunite parts.</def> <rj><au>Encys. Dict.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discession</ent><br/
<hw>Dis*ces"sion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>discessio</ets>, fr. <ets>discedere</ets>, <ets>discessum</ets>.
See <er>Discede</er>.]</ety> <def>Departure.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discharge</ent><br/
<hw>Dis*charge"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Discharged</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Discharging</conjf>.]</vmorph> <ety>[OE.
<ets>deschargen</ets>, <ets>dischargen</ets>, OF.
<ets>deschargier</ets>, F. <ets>d<eacute/charger</ets>; pref.
<ets>des-</ets> (L. <ets>dis</ets>) + <ets>chargier</ets>, F.
<ets>charger</ets>. See <er>Charge</er>.]</ety> <sn>1.</sn> <def>To
relieve of a charge, load, or burden; to empty of a load or cargo; to
unburden; to unload; <as>as, to <ex>discharge</ex> a
vessel</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To free of the missile with which anything is
charged or loaded; to let go the charge of; <as>as, to
<ex>discharge</ex> a bow, catapult, etc.</as>; especially, said of
firearms, -- to fire off; to shoot off; also, to relieve from a state of
tension, as a Leyden jar.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The galleys also did oftentimes, out of their prows,
<qex>discharge</qex> their great pieces against the city.</q>
<rj><qau>Knolles.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Feeling in other cases <qex>discharges</qex> itself in indirect
muscular actions.</q> <rj><qau>H. Spencer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To of something weighing upon or impeding over one,
as a debt, claim, obligation, responsibility, accusation, etc.; to
absolve; to acquit; to clear.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Discharged</qex> of business, void of strife.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>In one man's fault <qex>discharge</qex> another man of his
duty.</q> <rj><qau>L'Estrange.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To relieve of an office or employment; to send away
from service; to dismiss.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Discharge</qex> the common sort<br/
With pay and thanks.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Grindal . . . was <qex>discharged</qex> the government of his
see.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To release legally from confinement; to set at
liberty; <as>as, to <ex>discharge</ex> a prisoner</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To put forth, or remove, as a charge or burden; to
take out, as that with which anything is loaded or filled; <as>as, to
<ex>discharge</ex> a cargo</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>To let fly, as a missile; to shoot.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They do <qex>discharge</qex> their shot of courtesy.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>To set aside; to annul; to dismiss.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We say such an order was <ldquo/<qex>discharged</qex> on
appeal.<rdquo/</q> <rj><qau>Mozley & W.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The order for Daly's attendance was <qex>discharged</qex>.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>To throw off the obligation of, as a duty or debt;
to relieve one's self of, by fulfilling conditions, performing duty,
trust, and the like; hence, to perform or execute, as an office, or
part.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Had I a hundred tongues, a wit so large<br/
As could their hundred offices <qex>discharge</qex>.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <def>To send away (a creditor) satisfied by payment; to
pay one's debt or obligation to.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>If he had<br/
The present money to <qex>discharge</qex> the Jew.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>11.</sn> <def>To give forth; to emit or send out; <as>as, a pipe
<ex>discharges</ex> water</as>; to let fly; to give expression to; to
utter; <as>as, to <ex>discharge</ex> a horrible oath</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>12.</sn> <def>To prohibit; to forbid.</def> <mark>[Scot.
Obs.]</mark> <rj><au>Sir W. Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>13.</sn> <fld>(Textile Dyeing & Printing)</fld> <def>To bleach
out or to remove or efface, as by a chemical process; <as>as, to
<ex>discharge</ex> the color from a dyed fabric in order to form light
figures on a dark ground</as>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><cs><col><b>Discharging arch</b></col> <fld>(Arch.)</fld>, <cd>an
arch over a door, window, or other opening, to distribute the pressure
of the wall above. See <xex>Illust.</xex> of <er>Lintel</er>.</cd> --
<mcol><col><b>Discharging piece</b></col>, <col><b>Discharging
strut</b></col></mcol> <fld>(Arch.)</fld>, <cd>a piece set to carry
thrust or weight to a solid point of support.</cd> --
<col><b>Discharging rod</b></col> <fld>(Elec.)</fld>, <cd>a bent wire,
with knobs at both ends, and insulated by a glass handle. It is employed
for discharging a Leyden jar or an electrical battery. See
<er>Discharger</er>.</cd></cs></p>

<p><syn><b>Syn.</b> -- See <er>Deliver</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discharge</ent><br/
<hw>Dis*charge"</hw>, <pos>v. i.</pos> <def>To throw off or deliver a
load, charge, or burden; to unload; to emit or give vent to fluid or
other contents; <as>as, the water pipe <ex>discharges</ex>
freely</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The cloud, if it were oily or fatty, would not
<qex>discharge</qex>.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discharge</ent><br/
<hw>Dis*charge"</hw>, <pos>n.</pos> <ety>[Cf. F.
<ets>d<eacute/charge</ets>. See <er>Discharge</er>, <pos>v.
t.</pos>]</ety> <sn>1.</sn> <def>The act of discharging; the act of
relieving of a charge or load; removal of a load or burden; unloading;
<as>as, the <ex>discharge</ex> of a ship; <ex>discharge</ex> of a
cargo.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Firing off; explosive removal of a charge;
explosion; letting off; <as>as, a <ex>discharge</ex> of arrows, of
artillery</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Act of relieving of something which oppresses or
weighs upon one, as an obligation, liability, debt, accusation, etc.;
acquittance; <as>as, the <ex>discharge</ex> of a debtor</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Act of removing, or getting rid of, an obligation,
liability, etc.; fulfillment, as by the payment of a debt, or the
performance of a trust or duty.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Indefatigable in the <qex>discharge</qex> of
<qex>business</qex>.</q> <rj><qau>Motley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Nothing can absolve us from the <qex>discharge</qex> of those
duties.</q> <rj><qau>L'Estrange.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Release or dismissal from an office, employment,
etc.; dismission; <as>as, the <ex>discharge</ex> of a workman by his
employer</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Legal release from confinement; liberation; <as>as,
the <ex>discharge</ex> of a prisoner</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>The state of being discharged or relieved of a debt,
obligation, office, and the like; acquittal.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Too secure of our <qex>discharge</qex><br/
From penalty.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>That which discharges or releases from an
obligation, liability, penalty, etc., as a price of ransom, a legal
document.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Death, who sets all free,<br/
Hath paid his ransom now and full <qex>discharge</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>A flowing or issuing out; emission; vent;
evacuation; also, that which is discharged or emitted; <as>as, a rapid
<ex>discharge</ex> of water from the pipe</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The hemorrhage being stopped, the next occurrence is a thin serous
<qex>discharge</qex>.</q> <rj><qau>S. Sharp.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 420 --></p>

<p><sn>10.</sn> <fld>(Elec.)</fld> <def>The equalization of a difference
of electric potential between two points. The character of the discharge
is mostly determined by the nature of the medium through which it takes
place, the amount of the difference of potential, and the form of the
terminal conductors on which the difference exists. The discharge may be
alternating, continuous, brush, connective, disruptive, glow,
oscillatory, stratified, etc.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><cs><col><b>Charge and discharge</b></col>. <fld>(Equity
Practice)</fld> <cd>See under <er>Charge</er>, <pos>n.</pos></cd> --
<col><b>Paralytic discharge</b></col> <fld>(Physiol.)</fld>, <cd>the
increased secretion from a gland resulting from the cutting of all of
its nerves.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discharger</ent><br/
<hw>Dis*char"ger</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, discharges. Specifically, in electricity, an instrument for
discharging a Leyden jar, or electrical battery, by making a connection
between the two surfaces; a discharging rod.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dischevele</ent><br/
<hw>Dis*chev"ele</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Disheveled.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dischurch</ent><br/
<hw>Dis*church"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To deprive of
status as a church, or of membership in a church.</def> <rj><au>Bp.
Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discide</ent><br/
<hw>Dis*cide"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>discidere</ets>; <ets>dis-</ets> + <ets>caedere</ets> to
cut.]</ety> <def>To divide; to cleave in two.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disciferous</ent><br/
<hw>Dis*cif"er*ous</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Disc-</ets> + <ets>-ferous</ets>.]</ety> <def>Bearing
disks.</def></p>

<p><ent>Disciflorous</ent><br/
<ent>Discifloral</ent><br/
<mhw>{ <hw>Dis`ci*flo"ral</hw> <pr>(?)</pr>, <hw>Dis`ci*flo"rous</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[See <er>Disk</er>, and
<er>Floral</er>.]</ety> <fld>(Bot.)</fld> <def>Bearing the stamens on a
discoid outgrowth of the receptacle; -- said of a subclass of plants.
Cf. <er>Calycifloral</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disciform</ent><br/
<hw>Dis"ci*form</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Discoid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discina</ent><br/
\'d8<hw>Dis*ci"na</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. L.
<ets>discus</ets> disk, Gr. <?/.]</ety> <fld>(Zool.)</fld> <def>A genus
of Branchiopoda, having a disklike shell, attached by one valve, which
is perforated by the peduncle.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discinct</ent><br/
<hw>Dis*cinct</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>discinctus</ets>, p. p. of <ets>discingere</ets> to ungird;
<ets>dis-</ets> + <ets>cingere</ets> to gird.]</ety> <def>Ungirded;
loosely dressed.</def> <mark>[R.]</mark> <rj><au>Sir W.
Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discind</ent><br/
<hw>Dis*cind"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>discindere</ets>; <ets>dis-</ets> + <ets>scindere</ets> to cut,
split.]</ety> <def>To part; to divide.</def> <mark>[Obs.]</mark>
<rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disciple</ent><br/
<hw>Dis*ci"ple</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>disciple</ets>, <ets>deciple</ets>, OF. <ets>disciple</ets>, fr. L.
<ets>discipulus</ets>, fr. <ets>discere</ets> to learn (akin to
<ets>docere</ets> to teach; see <er>Docile</er>) + prob. a root meaning
<ets>to turn</ets> or <ets>drive</ets>, as in L. <ets>pellere</ets> to
drive (see <er>Pulse</er>).]</ety> <def>One who receives instruction
from another; a scholar; a learner; especially, a follower who has
learned to believe in the truth of the doctrine of his teacher; an
adherent in doctrine; <as>as, the <ex>disciples</ex> of Plato; the
<ex>disciples</ex> of our Savior.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>The disciples</b></col>, <it>or</it> <col><b>The
twelve disciples</b></col></mcol>, <cd>the twelve selected companions of
Jesus; -- also called <altname>the apostles</altname>.</cd> --
<col><b>Disciples of Christ</b></col>. <cd>See <er>Christian</er>,
<pos>n.</pos>, 3, and <er>Campbellite</er>.</cd></cs></p>

<p><syn><b>Syn.</b> -- Learner; scholar; pupil; follower;
adherent.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disciple</ent><br/
<hw>Dis*ci"ple</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Discipled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Discipling</conjf>.]</vmorph> <sn>1.</sn> <def>To teach; to
train.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>That better were in virtues <qex>discipled</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To punish; to discipline.</def> <mark>[Obs.]</mark>
<rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To make disciples of; to convert to doctrines or
principles.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Sending missionaries to <qex>disciple</qex> all nations.</q>
<rj><qau>E. D. Griffin.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discipleship</ent><br/
<hw>Dis*ci"ple*ship</hw>, <pos>n.</pos> <def>The state of being a
disciple or follower in doctrines and precepts.</def> <rj><au>Jer.
Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discipless</ent><br/
<hw>Dis*ci"pless</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A female
disciple.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disciplinable</ent><br/
<hw>Dis"ci*plin*a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>disciplinable</ets>. See <er>Discipline</er>.]</ety> <sn>1.</sn>
<def>Capable of being disciplined or improved by instruction and
training.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Liable or deserving to be disciplined; subject to
disciplinary punishment; <as>as, a <ex>disciplinable</ex>
offense</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disciplinableness</ent><br/
<hw>Dis"ci*plin*a*ble*ness</hw>, <pos>n.</pos> <def>The quality of being
improvable by discipline.</def> <rj><au>Sir M. Hale.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disciplinal</ent><br/
<hw>Dis"ci*plin*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Relating to
discipline.</def> <rj><au>Latham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disciplinant</ent><br/
<hw>Dis"ci*plin*ant</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Discipline</er>.]</ety> <fld>(Eccl. Hist.)</fld> <def>A flagellant.
See <er>Flagellant</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disciplinarian</ent><br/
<hw>Dis`ci*plin*a"ri*an</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining
to discipline.</def> <ldquo/<xex>Displinarian</xex> system.<rdquo/
<rj><au>Milman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disciplinarian</ent><br/
<hw>Dis`ci*plin*a"ri*an</hw>, <pos>n.</pos> <sn>1.</sn> <def>One who
disciplines; one who excels in training, especially with training,
especially with regard to order and obedience; one who enforces rigid
discipline; a stickler for the observance of rules and methods of
training; <as>as, he is a better <ex>disciplinarian</ex> than
scholar</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A Puritan or Presbyterian; -- because of rigid
adherence to religious or church discipline.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disciplinary</ent><br/
<hw>Dis"ci*plin*a*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[LL.
<ets>disciplinarius</ets> flogging: cf. F.
<ets>disciplinaire</ets>.]</ety> <def>Pertaining to discipline; intended
for discipline; corrective; belonging to a course of training.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Those canons . . . were only <qex>disciplinary</qex>.</q>
<rj><qau>Bp. Ferne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The evils of the . . . are <qex>disciplinary</qex> and
remedial.</q> <rj><qau>Buckminster.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discipline</ent><br/
<hw>Dis`ci*pline</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>discipline</ets>, L. <ets>disciplina</ets>, from
<ets>discipulus</ets>. See <er>Disciple</er>.]</ety> <sn>1.</sn>
<def>The treatment suited to a disciple or learner; education;
development of the faculties by instruction and exercise; training,
whether physical, mental, or moral.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Wife and children are a kind of <qex>discipline</qex> of
humanity.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Discipline</qex> aims at the removal of bad habits and the
substitution of good ones, especially those of order, regularity, and
obedience.</q> <rj><qau>C. J. Smith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Training to act in accordance with established
rules; accustoming to systematic and regular action; drill.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Their wildness lose, and, quitting nature's part,<br/
Obey the rules and <qex>discipline</qex> of art.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Subjection to rule; submissiveness to order and
control; habit of obedience.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The most perfect, who have their passions in the best
<qex>discipline</qex>, are yet obliged to be constantly on their
guard.</q> <rj><qau>Rogers.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Severe training, corrective of faults; instruction
by means of misfortune, suffering, punishment, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A sharp <qex>discipline</qex> of half a century had sufficed to
educate us.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Correction; chastisement; punishment inflicted by
way of correction and training.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Giving her the <qex>discipline</qex> of the strap.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>The subject matter of instruction; a branch of
knowledge.</def> <rj><au>Bp. Wilkins.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Eccl.)</fld> <def>The enforcement of methods of
correction against one guilty of ecclesiastical offenses; reformatory or
penal action toward a church member.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <fld>(R. C. Ch.)</fld> <def>Self-inflicted and voluntary
corporal punishment, as penance, or otherwise; specifically, a
penitential scourge.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <fld>(Eccl.)</fld> <def>A system of essential rules and
duties; <as>as, the Romish or Anglican
<ex>discipline</ex></as>.</def></p>

<p><syn><b>Syn.</b> -- Education; instruction; training; culture;
correction; chastisement; punishment.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discipline</ent><br/
<hw>Dis"ci*pline</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Disciplined</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Disciplining</conjf>.]</vmorph> <ety>[Cf. LL.
<ets>disciplinarian</ets> to flog, fr. L. <ets>disciplina</ets>
discipline, and F. <ets>discipliner</ets> to discipline.]</ety>
<sn>1.</sn> <def>To educate; to develop by instruction and exercise; to
train.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To accustom to regular and systematic action; to
bring under control so as to act systematically; to train to act
together under orders; to teach subordination to; to form a habit of
obedience in; to drill.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Ill armed, and worse <qex>disciplined</qex>.</q>
<rj><qau>Clarendon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>His mind . . . imperfectly <qex>disciplined</qex> by nature.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To improve by corrective and penal methods; to
chastise; to correct.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Has he <qex>disciplined</qex> Aufidius soundly?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To inflict ecclesiastical censures and penalties
upon.</def></p>

<p><syn><b>Syn.</b> -- To train; form; teach; instruct; bring up;
regulate; correct; chasten; chastise; punish.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discipliner</ent><br/
<hw>Dis"ci*plin*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
disciplines.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>disc jockey</ent><br/
<hw>disc" jock`ey</hw> <pr>(d<icr/sk" j<ocr/k`<ycr/)</pr>, <pos>n.</pos>
<def>a person who plays records or compact disks of recorded
music;</def> <specif>especially,</specif> <def>a person who selects and
plays recorded music for broadcast over the radio, often making comments
about the music or other topics and also announcing commercial
advertising messages; also, one who plays recorded music at a dance or
social gathering, especially as a profession.</def> <altsp>[Also spelled
<asp>disk jockey</asp>.]</altsp><br/
<syn><b>Syn. --</b> DJ.</syn>
[<source>PJC</source>]</p>

<p><ent>Disclaim</ent><br/
<hw>Dis*claim"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Disclaimed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Disclaiming</conjf>.]</vmorph> <sn>1.</sn> <def>To
renounce all claim to deny; ownership of, or responsibility for; to
disown; to disavow; to reject.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He calls the gods to witness their offense;<br/
<qex>Disclaims</qex> the war, asserts his innocence.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He <qex>disclaims</qex> the authority of Jesus.</q>
<rj><qau>Farmer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To deny, as a claim; to refuse.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The payment was irregularly made, if not
<qex>disclaimed</qex>.</q> <rj><qau>Milman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Law)</fld> <def>To relinquish or deny having a
claim; to disavow another's claim; to decline accepting, as an estate,
interest, or office.</def> <rj><au>Burrill.</au></rj></p>

<p><syn><b>Syn.</b> -- To disown; disavow; renounce;
repudiate.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disclaim</ent><br/
<hw>Dis*claim"</hw>, <pos>v. t.</pos> <def>To disavow or renounce all
part, claim, or share.</def> <rj><au>Blackstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Disclaim in</b></col>, <col><b>Disclaim
from</b></col></mcol>, <cd>to disown; to disavow.</cd>
<mark>[Obs.]</mark> <ldquo/Nature <xex>disclaims in</xex> thee.<rdquo/
<rj><au>Shak.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disclaimer</ent><br/
<hw>Dis*claim"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One
who disclaims, disowns, or renounces.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>A denial, disavowal, or
renunciation, as of a title, claim, interest, estate, or trust;
relinquishment or waiver of an interest or estate.</def>
<rj><au>Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A public disavowal, as of pretensions, claims,
opinions, and the like.</def> <rj><au>Burke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disclamation</ent><br/
<hw>Dis`cla*ma"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A disavowing
or disowning.</def> <rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disclame</ent><br/
<hw>Dis*clame"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To disclaim; to
expel.</def> <mark>[Obs.]</mark> <ldquo/Money did love
<xex>disclame</xex>.<rdquo/ <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disclaunder</ent><br/
<hw>Dis*claun"der</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[From OE.
<ets>disclaundre</ets>, <ets>n.</ets>, for <ets>sclandre</ets>,
<ets>esclandre</ets>, OF. <ets>esclandre</ets>. See <er>Sclaundre</er>,
<er>Slander</er>.]</ety> <def>To injure one's good name; to
slander.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discloak</ent><br/
<hw>Dis*cloak"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To take off a
cloak from; to uncloak.</def> <mark>[Obs.]</mark> <rj><au>B.
Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disclose</ent><br/
<hw>Dis*close"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Disclosed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Disclosing</conjf>.]</vmorph> <ety>[OE.
<ets>desclosen</ets>, <ets>disclosen</ets>, fr. <ets>disclos</ets>,
<ets>desclos</ets>, not shut in, open, OF. <ets>desclos</ets>, p. p. of
<ets>desclore</ets> to open, F. <ets>d<eacute/clore</ets>; pref.
<ets>des-</ets> (L. <ets>dis-</ets>) + <ets>clore</ets> to shut, fr. L.
<ets>claudere</ets> to shut. See <er>Close</er>, and cf.
<er>Disclusion</er>.]</ety> <sn>1.</sn> <def>To unclose; to open; --
applied esp. to eggs in the sense of <xex>to hatch</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The ostrich layeth her eggs under sand, where the heat of the
<qex>discloseth</qex> them.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To remove a cover or envelope from;; to set free
from inclosure; to uncover.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The shells being broken, . . . the stone included in them is
thereby <qex>disclosed</qex> and set at liberty.</q>
<rj><qau>Woodward.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To lay open or expose to view; to cause to appear;
to bring to light; to reveal.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>How softly on the Spanish shore she plays,<br/
<qex>Disclosing</qex> rock, and slope, and forest brown!</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Her lively looks a sprightly mind <qex>disclose</qex>.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To make known, as that which has been kept secret or
hidden; to reveal; to expose; <as>as, events have <ex>disclosed</ex> his
designs</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If I <qex>disclose</qex> my passion,<br/
Our friendship 's an end.</q> <rj><qau>Addison.</qau></rj></p>

<p><syn><b>Syn.</b> -- To uncover; open; unveil; discover; reveal;
divulge; tell; utter.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disclose</ent><br/
<hw>Dis*close"</hw>, <pos>n.</pos> <def>Disclosure.</def>
<mark>[Obs.]</mark> <rj><au>Shak. Young.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disclosed</ent><br/
<hw>Dis*closed"</hw> <pr>(?)</pr>, <pos>p. a.</pos> <fld>(Her.)</fld>
<def>Represented with wings expanded; -- applied to doves and other
birds not of prey.</def> <rj><au>Cussans.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discloser</ent><br/
<hw>Dis*clos"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
discloses.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disclosure</ent><br/
<hw>Dis*clo"sure</hw> <pr>(?; 135)</pr>, <pos>n.</pos> <ety>[See
<er>Disclose</er>, <pos>v. t.</pos>, and cf. <er>Closure</er>.]</ety>
<sn>1.</sn> <def>The act of disclosing, uncovering, or revealing;
bringing to light; exposure.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He feels it [his secret] beating at his heart, rising to his
throat, and demanding <qex>disclosure</qex>.</q> <rj><qau>D.
Webster.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is disclosed or revealed.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Were the <qex>disclosures</qex> of 1695 forgotten?</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discloud</ent><br/
<hw>Dis*cloud"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To clear from
clouds.</def> <mark>[Archaic]</mark> <rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disclout</ent><br/
<hw>Dis*clout"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To divest of a
clout.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disclusion</ent><br/
<hw>Dis*clu"sion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>disclusio</ets>, fr. <ets>discludere</ets>, <ets>disclusum</ets>,
to separate. See <er>Disclose</er>.]</ety> <def>A shutting off;
exclusion.</def> <mark>[Obs.]</mark> <rj><au>Dr. H. More.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discoast</ent><br/
<hw>Dis*coast"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[Pref.
<ets>dis-</ets> + <ets>coast</ets>: cf. It.
<ets>discostare</ets>.]</ety> <def>To depart; to quit the coast (that
is, the side or border) of anything; to be separated.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>As far as heaven and earth <qex>discoasted</qex> lie.</q>
<rj><qau>G. Fletcher.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>discoast</qex> from the plain and simple way of
speech.</q> <rj><qau>Barrow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discoblastic</ent><br/
<hw>Dis`co*blas"tic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/ disk
+ <?/ to grow.]</ety> <fld>(Biol.)</fld> <def>Applied to a form of egg
cleavage seen in osseous fishes, which occurs only in a small disk that
separates from the rest of the egg.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discobolus</ent><br/
\'d8<hw>Dis*cob"o*lus</hw> <pr>(?)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Discoboli</plw> <pr>(#)</pr>.</plu> <ety>[L., fr.
Gr. <?/; <?/ a discu + <?/ to throw.]</ety> <fld>(Fine Arts)</fld>
<sd>(a)</sd> <def>A thrower of the discus.</def> <sd>(b)</sd> <def>A
statue of an athlete holding the discus, or about to throw it.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The <xex>Discobolus</xex> of Myron was a famous statue
of antiquity, and several copies or imitations of it have been
preserved.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discodactyl</ent><br/
<hw>Dis`co*dac"tyl</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Discodactylia</er>.]</ety> <fld>(Zool.)</fld> <def>One of the tree
frogs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discodactylia</ent><br/
\'d8<hw>Dis`co*dac*tyl"i*a</hw> <pr>(?)</pr>, <pos>n. pl.</pos>
<ety>[NL., fr. Gr. <?/ disk + <?/ finger.]</ety> <fld>(Zool.)</fld>
<def>A division of amphibians having suctorial disks on the toes, as the
tree frogs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discodactylous</ent><br/
<hw>Dis`co*dac"tyl*ous</hw> <pr>(?)</pr>, <pos>a.</pos>
<fld>(Zool.)</fld> <def>Having sucking disks on the toes, as the tree
frogs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discoherent</ent><br/
<hw>Dis`co*her"ent</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Incoherent.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discoid</ent><br/
<hw>Dis"coid</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/
quoit-shaped, <?/ a round plate, quoit + <grk>e'i^dos</grk> form, shape:
cf. F. <ets>disco<ium/de</ets>. See <er>Disk</er>.]</ety> <def>Having
the form of a disk, as those univalve shells which have the whorls in
one plane, so as to form a disk, as the pearly nautilus.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Discoid flower</b></col> <fld>(Bot.)</fld>, <cd>a
compound flower, consisting of tubular florets only, as a tansy, lacking
the rays which are seen in the daisy and sunflower.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discoid</ent><br/
<hw>Dis"coid</hw>, <pos>n.</pos> <def>Anything having the form of a
discus or disk; particularly, a discoid shell.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discoidal</ent><br/
<hw>Dis*coid"al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>disco<ium/dal</ets>.]</ety> <def>Disk-shaped; discoid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discolith</ent><br/
<hw>Dis"co*lith</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ a round
plate + <ets>-lith</ets>.]</ety> <fld>(Biol.)</fld> <def>One of a
species of coccoliths, having an oval discoidal body, with a thick
strongly refracting rim, and a thinner central portion. One of them
measures about <frac1x50000/ of an inch in its longest
diameter.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discolor</ent><br/
<hw>Dis*col"or</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Discolored</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Discoloring</conjf>.]</vmorph> <ety>[OE.
<ets>descolouren</ets>, OF. <ets>descolorer</ets>, F.
<ets>d<eacute/colorer</ets>, fr. L. <ets>dis-</ets> +
<ets>cololare</ets>, <ets>coloratum</ets>, to color, <ets>color</ets>
color. See <er>Color</er>.]</ety> <altsp>[Written also
<asp>discolour</asp>.]</altsp> <sn>1.</sn> <def>To alter the natural hue
or color of; to change to a different color; to stain; to tinge; <as>as,
a drop of wine will <ex>discolor</ex> water; silver is
<ex>discolored</ex> by sea water.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To alter the true complexion or appearance of; to
put a false hue upon.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>discolor</qex> all your ideas.</q>
<rj><qau>Watts.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discolorate</ent><br/
<hw>Dis*col"or*ate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To
discolor.</def> <mark>[R.]</mark> <rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discoloration</ent><br/
<hw>Dis*col`or*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>decoloration</ets>.]</ety> <sn>1.</sn> <def>The act of discoloring,
or the state of being discolored; alteration of hue or appearance.</def>
<rj><au>Darwin.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A discolored spot; a stain.</def>
<rj><au>Arbuthnot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>discolored</ent><br/
<hw>dis*col"ored</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Altered in color; stained; spotted or streaked with foreign
matter.</def><br/
<syn><b>Syn. --</b> discoloured.</syn>
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Variegated; of divers colors.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>That ever wore <qex>discolored</qex> arms.</q>
<rj><qau>Chapman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>discolour</ent><br/
<hw>discolour</hw> <pos>v.</pos> <def>same as <er>discolor</er>.</def>
<mark>[Brit.]</mark><br/
<syn><b>Syn. --</b> discolor, colour, change color.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>discoloured</ent><br/
<hw>discoloured</hw> <pos>adj.</pos> <def>same as <er>discolored</er>;
<as>as, <ex>discoloured</ex> paneling</as>.</def>
<mark>[Brit.]</mark><br/
<syn><b>Syn. --</b> discolored.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>discombobulate</ent><br/
<hw>discombobulate</hw> <pos>v.</pos> <def>to cause to be confused;
confuse emotionally.</def><br/
<syn><b>Syn. --</b> confuse, flurry, consternate, disconcert, put off,
bewilder, bemuse, throw.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>discombobulated</ent><br/
<hw>discombobulated</hw> <pos>adj.</pos> <def>confused; upset; <as>as,
the hecklers pelted the <ex>discombobulated</ex> speaker with anything
that came to hand</as>.</def><br/
<syn><b>Syn. --</b> discomfited, discomfitted, disconcerted.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Discomfit</ent><br/
<hw>Dis*com"fit</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Discomfited</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Discomfiting</conjf>.]</vmorph> <ety>[OF. <ets>desconfit</ets>,
p. p. of <ets>desconfire</ets>, F. <ets>d<eacute/confire</ets>; fr. L.
<ets>dis-</ets> + <ets>conficere</ets> to make ready, prepare, bring
about. See <er>Comfit</er>, <er>Fact</er>.]</ety> <sn>1.</sn> <def>To
scatter in fight; to put to rout; to defeat.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And his proud foes <qex>discomfit</qex> in victorious field.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To break up and frustrate the plans of; to balk<?/
to throw into perplexity and dejection; to disconcert.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Well, go with me and be not so <qex>discomfited</qex>.</q>
<rj><qau>Shak.</qau></rj></p>

<p><syn><b>Syn.</b> -- To defeat; overthrow; overpower; vanquish;
conquer; baffle; frustrate; confound; discourage.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discomfit</ent><br/
<hw>Dis*com"fit</hw>, <pos>a.</pos> <def>Discomfited; overthrown.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discomfit</ent><br/
<hw>Dis*com"fit</hw>, <pos>n.</pos> <def>Rout; overthrow;
discomfiture.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Such a <qex>discomfit</qex> as shall quite despoil him.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>discomfitted</ent><br/
<ent>discomfited</ent><br/
<mhw><hw>discomfited</hw> <hw>discomfitted</hw></mhw> <pos>adj.</pos>
<sn>1.</sn> <def>thwarted; -- used especially of feelings of defeat and
discouragement.</def><br/
<syn><b>Syn. --</b> baffled, balked, discouraged, frustrated,
disconcerted.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>same as <er>discombobulated</er>.</def><br/
<syn><b>Syn. --</b> discombobulated.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>discomfited</ent><br/
<hw>discomfited</hw> <pos>n. pl.</pos> <def>people who are
defeated.</def><br/
<syn><b>Syn. --</b> defeated.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Discomfiture</ent><br/
<hw>Dis*com"fi*ture</hw> <pr>(?; 135)</pr>, <pos>n.</pos> <ety>[OF.
<ets>desconfiture</ets>, F. <ets>d<eacute/confiture</ets>. See
<er>Discomfort</er>, <pos>v. t.</pos>, and cf.
<er>Comfiture</er>.]</ety> <def>The act of discomfiting, or the state of
being discomfited; rout; overthrow; defeat; frustration; confusion and
dejection.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Every man's sword was against his fellow, and there was a very
great <qex>discomfiture</qex>.</q> <rj><qau>1 Sam. xiv.
20.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A hope destined to end . . . in <qex>discomfiture</qex> and
disgrace.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discomfort</ent><br/
<hw>Dis*com"fort</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Discomforted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Discomforting</conjf>.]</vmorph> <ety>[OF.
<ets>desconforter</ets>, F. <ets>d<eacute/conforter</ets>, to
discourage; pref. <ets>des-</ets> (L <ets>dis-</ets>) +
<ets>conforter</ets>. See <er>Comfort</er>.]</ety> <sn>1.</sn> <def>To
discourage; to deject.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His funeral shall not be in our camp,<br/
Lest it <qex>discomfort</qex> us.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To destroy or disturb the comfort of; to deprive of
quiet enjoyment; to make uneasy; to pain; <as>as, a smoky chimney
<ex>discomforts</ex> a family</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discomfort</ent><br/
<hw>Dis*com"fort</hw>, <pos>n.</pos> <ety>[OF. <ets>desconfort</ets>, F.
<ets>d<eacute/confort</ets>. See <er>Discomfort</er>, <pos>v.
t.</pos>]</ety> <sn>1.</sn> <def>Discouragement.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Want of comfort; uneasiness, mental or physical;
disturbance of peace; inquietude; pain; distress; sorrow.</def>
<ldquo/An age of spiritual <xex>discomfort</xex>.<rdquo/ <rj><au>M.
Arnold.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Strive against all the <qex>discomforts</qex> of thy
sufferings.</q> <rj><qau>Bp. Hall.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discomfortable</ent><br/
<hw>Dis*com"fort*a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. OF.
<ets>desconfortable</ets>.]</ety> <sn>1.</sn> <def>Causing discomfort;
occasioning uneasiness; making sad.</def> <mark>[Obs.]</mark>
<rj><au>Sir P. Sidney.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Destitute of comfort; uncomfortable.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>A labyrinth of little <qex>discomfortable</qex> garrets.</q>
<rj><qau>Thackeray.</qau></rj></p>

<p>-- <wordforms><wf>Dis*com"fort*a*ble*ness</wf>, <pos>n.</pos>
<mark>[Obs.]</mark></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discommend</ent><br/
<hw>Dis`com*mend"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <sn>1.</sn>
<def>To mention with disapprobation; to blame; to disapprove.</def>
<mark>[R.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>By commending something in him that is good, and
<qex>discommending</qex> the same fault in others.</q> <rj><qau>Jer.
Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 421 --></p>

<p><sn>2.</sn> <def>To expose to censure or ill favor; to put out of the
good graces of any one.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A compliance will <qex>discommend</qex> me to Mr. Coventry.</q>
<rj><qau>Pepys.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discommendable</ent><br/
<hw>Dis`com*mend"a*ble</hw>
<pr>(d<icr/s`k<ocr/m*m<ecr/nd"<adot/*b'l)</pr>, <pos>a.</pos>
<def>Deserving, disapprobation or blame.</def> --
<wordforms><wf>Dis`com*mend"a*ble*ness</wf>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discommendation</ent><br/
<hw>Dis*com`men*da"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Blame;
censure; reproach.</def> <mark>[R.]</mark>
<rj><au>Ayliffe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discommender</ent><br/
<hw>Dis`com*mend"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
discommends; a dispraiser.</def> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discommission</ent><br/
<hw>Dis`com*mis"sion</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To deprive
of a commission or trust.</def> <mark>[R.]</mark>
<rj><au>Laud.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discommodate</ent><br/
<hw>Dis*com"mo*date</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>dis-</ets> + <ets>commodatus</ets>, p. p. of <ets>commodare</ets>
to make fit or suitable, fr. <ets>commodus</ets> fit, commodious. See
<er>Commodious</er>, and cf. <er>Discommode</er>.]</ety> <def>To
discommode.</def> <mark>[Obs.]</mark> <rj><au>Howell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discommode</ent><br/
<hw>Dis`com*mode"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Discommoded</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Discommoding</conjf>.]</vmorph> <ety>[See
<er>Discommodate</er>.]</ety> <def>To put inconvenience; to incommode;
to trouble.</def> <mark>[R.]</mark></p>

<p><syn><b>Syn.</b> -- To incommode; annoy; inconvenience.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discommodious</ent><br/
<hw>Dis`com*mo"di*ous</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Inconvenient; troublesome; incommodious.</def> <mark>[R.]</mark>
<rj><au>Spenser.</au></rj></p>

<p>-- <wordforms><wf>Dis`com*mo"di*ous*ly</wf>, <pos>adv.</pos> --
<wf>Dis`com*mo"di*ous*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discommodity</ent><br/
<hw>Dis`com*mod"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Disadvantage;
inconvenience.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discommon</ent><br/
<hw>Dis*com"mon</hw> <pr>(?)</pr>, <pos>v. t.</pos> <sn>1.</sn> <def>To
deprive of the right of common.</def> <mark>[R.]</mark> <rj><au>Bp.
Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To deprive of privileges.</def> <mark>[R.]</mark>
<rj><au>T. Warton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Law)</fld> <def>To deprive of commonable quality,
as lands, by inclosing or appropriating.</def>
<rj><au>Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discommunity</ent><br/
<hw>Dis`com*mu"ni*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A lack of
common possessions, properties, or relationship.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Community of embryonic structure reveals community of descent; but
dissimilarity of embryonic development does not prove
<qex>discommunity</qex> of descent.</q> <rj><qau>Darwin.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discompany</ent><br/
<hw>Dis*com"pa*ny</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To free from
company; to dissociate.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>It she be alone now, and <qex>discompanied</qex>.</q> <rj><qau>B.
Jonson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discomplexion</ent><br/
<hw>Dis`com*plex"ion</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To change
the complexion or hue of.</def> <mark>[Obs.]</mark> <rj><au>Beau. &
Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discompliance</ent><br/
<hw>Dis`com*pli"ance</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Failure or
refusal to comply; noncompliance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A compliance will discommend me to Mr. Coventry, and a
<qex>discompliance</qex> to my lord chancellor.</q>
<rj><qau>Pepys.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discompose</ent><br/
<hw>Dis`com*pose"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Discomposed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Discomposing</conjf>.]</vmorph> <ety>[Pref.
<ets>dis-</ets> + <ets>compose</ets>: cf. OF. <ets>decomposer</ets>, F.
<ets>d<eacute/composer</ets>.]</ety> <sn>1.</sn> <def>To disarrange; to
interfere with; to disturb; to disorder; to unsettle; to break
up.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Or <qex>discomposed</qex> the headdress of a prude.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To throw into disorder; to ruffle; to destroy the
composure or equanimity; to agitate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Opposition . . . <qex>discomposeth</qex> the mind's serenity.</q>
<rj><qau>Glanvill.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To put out of place or service; to discharge; to
displace.</def> <mark>[Obs.]</mark> <rj><au>Bacon.</au></rj></p>

<p><syn><b>Syn.</b> -- To disorder; derange; unsettle; disturb;
disconcert; agitate; ruffle; fret; vex.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discomposed</ent><br/
<hw>Dis`com*posed"</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Disordered;
disturbed; disquieted.</def> -- <wordforms><wf>Dis`com*pos"ed*ly</wf>
<pr>(#)</pr>, <pos>adv.</pos> -- <wf>Dis`com*pos"ed*ness</wf>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discomposition</ent><br/
<hw>Dis*com`po*si"tion</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Inconsistency; discordance.</def> <mark>[Obs.]</mark>
<rj><au>Donne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discomposure</ent><br/
<hw>Dis`com*po"sure</hw> <pr>(?; 135)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>The state of being discomposed; disturbance; disorder; agitation;
perturbation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>No <qex>discomposure</qex> stirred her features.</q>
<rj><qau>Akenside.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Discordance; disagreement of parts.</def>
<mark>[Obs.]</mark> <rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discompt</ent><br/
<hw>Dis*compt"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[See
<er>Discount</er>.]</ety> <def>To discount. See <er>Discount</er>.</def>
<rj><au>Hudibras.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disconcert</ent><br/
<hw>Dis`con*cert"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Disconcerted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Disconcerting</conjf>.]</vmorph> <ety>[Pref. <ets>dis-</ets> +
<ets>concert</ets>: cf. OF. <ets>desconcerter</ets>, F.
<ets>d<eacute/concerter</ets>.]</ety> <sn>1.</sn> <def>To break up the
harmonious progress of; to throw into disorder or confusion; <as>as, the
emperor <ex>disconcerted</ex> the plans of his enemy</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To confuse the faculties of; to disturb the
composure of; to discompose; to abash.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The embrace <qex>disconcerted</qex> the daughter-in-law somewhat,
as the caresses of old gentlemen unshorn and perfumed with tobacco might
well do.</q> <rj><qau>Thackeray.</qau></rj></p>

<p><syn><b>Syn.</b> -- To discompose; derange; ruffle; confuse; disturb;
defeat; frustrate.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disconcert</ent><br/
<hw>Dis`con*cert"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Want of concert;
disagreement.</def> <rj><au>Sir W. Temple.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>disconcerting</ent><br/
<hw>disconcerting</hw> <pos>adj.</pos> <def>hard to deal with; causing
uncertainty or confusion about how to act or react.</def><br/
<syn><b>Syn. --</b> awkward, embarrassing, off-putting, sticky, tight,
unenviable.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Disconcertion</ent><br/
<hw>Dis`con*cer"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
disconcerting, or state of being disconcerted; discomposure;
perturbation.</def> <mark>[R.]</mark> <rj><au>State Trials
(1794).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disconducive</ent><br/
<hw>Dis`con*du"cive</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Not
conductive; impeding; disadvantageous.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disconformable</ent><br/
<hw>Dis`con*form"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Not
conformable.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Disconformable</qex> in religion from us.</q> <rj><qau>Stow
(1603).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disconformity</ent><br/
<hw>Dis`con*form"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Want of
conformity or correspondence; inconsistency; disagreement.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Those . . . in some <qex>disconformity</qex> to ourselves.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Disagreement and <qex>disconformity</qex> betwixt the speech and
the conception of the mind.</q> <rj><qau>Hakewill.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discongruity</ent><br/
<hw>Dis`con*gru"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Incongruity;
disagreement; unsuitableness.</def> <rj><au>Sir M. Hale.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disconnect</ent><br/
<hw>Dis`con*nect"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Disconnected</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Disconnecting</conjf>.]</vmorph> <def>To dissolve the union or
connection of; to disunite; to sever; to separate; to
disperse.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The commonwealth itself would . . . be <qex>disconnected</qex>
into the dust and powder of individuality.</q>
<rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>This restriction <qex>disconnects</qex> bank paper and the
precious metals.</q> <rj><qau>Walsh.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>disconnected</ent><br/
<hw>disconnected</hw> <pos>adj.</pos> <sn>1.</sn> <def>marked by or
composed of disconnected parts or sounds.</def> [Narrower terms:
<stype>staccato (vs. legato)</stype>]<br/
<syn><b>Syn. --</b> abrupt, broken off(predicate).</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>not switched on or not connected to a power source;
-- of electrical equipment.</def> [Narrower terms: <stype>off-line (vs.
on-line), offline, off line(predicate)</stype>;
<stype>unplugged</stype>]<br/
<syn><b>Syn. --</b> not ready, off.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><sn>3.</sn> <def>noncontinuous; not continuing in time or space.
Opposite of <ant>continuous</ant>.</def><br/
<syn><b>Syn. --</b> disrupted, discontinuous.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><sn>4.</sn> <def>unconnected, detached. Opposite of
<ant>connected</ant>.</def><br/
<syn><b>Syn. --</b> disjoined, separate.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>5.</sn> <def>lacking orderly continuity; illogical or seemingly
irrational; <as>as, <ex>disconnected</ex> fragments of a
story</as>.</def><br/
<syn><b>Syn. --</b> confused, disjointed, disordered, disorganized,
desultory, garbled, illogical, rambling, scattered,
unconnected.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>disconnectedness</ent><br/
<hw>disconnectedness</hw> <pos>n.</pos> <def>the state of being
disconnected.</def><br/
<syn><b>Syn. --</b> disjunction, disjuncture, disconnection.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Disconnection</ent><br/
<hw>Dis`con*nec"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
disconnecting, or state of being disconnected; separation; want of
union.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Nothing was therefore to be left in all the subordinate members
but weakness, <qex>disconnection</qex>, and confusion.</q>
<rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disconsecrate</ent><br/
<hw>Dis*con"se*crate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To deprive
of consecration or sacredness.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disconsent</ent><br/
<hw>Dis`con*sent"</hw> <pr>(d<icr/s`k<ocr/n*s<ecr/nt")</pr>, <pos>v.
i.</pos> <def>To differ; to disagree; to dissent.</def>
<mark>[Obs.]</mark> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disconsolacy</ent><br/
<hw>Dis*con"so*la`cy</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state of
being disconsolate.</def> <mark>[Obs.]</mark>
<rj><au>Barrow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disconsolate</ent><br/
<hw>Dis*con"so*late</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Disconsolateness.</def> <mark>[Obs.]</mark>
<rj><au>Barrow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disconsolate</ent><br/
<hw>Dis*con"so*late</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[LL.
<ets>disconsolatus</ets>; L. <ets>dis-</ets> + <ets>consolatus</ets>, p.
p. of <ets>consolari</ets> to console. See <er>Console</er>, <pos>v.
t.</pos>]</ety> <sn>1.</sn> <def>Destitute of consolation; deeply
dejected and dispirited; hopelessly sad; comfortless; filled with grief;
<as>as, a bereaved and <ex>disconsolate</ex> parent</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>One morn a Peri at the gate<br/
Of Eden stood <qex>disconsolate</qex>.</q>
<rj><qau>Moore.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The ladies and the knights, no shelter nigh,<br/
Were dropping wet, <qex>disconsolate</qex> and wan.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Inspiring dejection; saddening; cheerless; <as>as,
the <ex>disconsolate</ex> darkness of the winter nights</as>.</def>
<rj><au>Ray.</au></rj></p>

<p><syn><b>Syn.</b> -- Forlorn; melancholy; sorrowful; desolate; woeful;
hopeless; gloomy.</syn></p>

<p>-- <wordforms><wf>Dis*con"so*late*ly</wf>, <pos>adv.</pos> --
<wf>Dis*con"so*late*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disconsolated</ent><br/
<hw>Dis*con"so*la`ted</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Disconsolate.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>A poor, <qex>disconsolated</qex>, drooping creature.</q>
<rj><qau>Sterne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disconsolation</ent><br/
<hw>Dis*con`so*la"tion</hw> <pr>(<?/)</pr>, <pos>n.</pos>
<def>Dejection; grief.</def> <mark>[R.]</mark> <rj><au>Bp.
Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discontent</ent><br/
<hw>Dis`con*tent"</hw> <pr>(d<icr/s`k<ocr/n*t<ecr/nt")</pr>,
<pos>a.</pos> <def>Not content; discontented; dissatisfied.</def>
<rj><au>Jer. Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Passion seemed to be much <qex>discontent</qex>, but Patience was
very quiet.</q> <rj><qau>Bunyan.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discontent</ent><br/
<hw>Dis`con*tent"</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Discontented</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Discontenting</conjf>.]</vmorph> <def>To deprive of content; to
make uneasy; to dissatisfy.</def> <rj><au>Suckling.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discontent</ent><br/
<hw>Dis`con*tent"</hw>, <pos>n.</pos> <sn>1.</sn> <def>Want of content;
uneasiness and inquietude of mind; dissatisfaction; disquiet.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Now is the winter of our <qex>discontent</qex><br/
Made glorious summer by this sun of York.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The rapacity of his father's administration had excited such
universal <qex>discontent</qex>.</q> <rj><qau>Hallam</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A discontented person; a malcontent.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Thus was the Scotch nation full of <qex>discontents</qex>.</q>
<rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discontentation</ent><br/
<hw>Dis*con`ten*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Discontent.</def> <mark>[Obs.]</mark> <rj><au>Ascham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discontented</ent><br/
<hw>Dis`con*tent"ed</hw> <pr>(?)</pr>, <pos>p. p. & a.</pos>
<def>Dissatisfied; uneasy in mind; malcontent.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And every one that was in distress, and every one that was in
debt, and every one that was <qex>discontented</qex>, gathered
themselves unto him.</q> <rj><qau>1 Sam. xxii. 2.</qau></rj></p>

<p>-- <wordforms><wf>Dis`con*tent"ed*ly</wf>, <pos>adv.</pos> --
<wf>Dis`con*tent"ed*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discontentful</ent><br/
<hw>Dis`con*tent"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Full of
discontent.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discontenting</ent><br/
<hw>Dis`con*tent"ing</hw>, <pos>a.</pos> <sn>1.</sn>
<def>Discontented.</def> <mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Causing discontent; dissatisfying.</def>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discontentive</ent><br/
<hw>Dis`con*tent"ive</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Relating or
tending to discontent.</def> <mark>[R.]</mark> <ldquo/Pride is ever
<xex>discontentive</xex>.<rdquo/ <rj><au>Feltham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discontentment</ent><br/
<hw>Dis`con*tent"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state of
being discontented; uneasiness; inquietude.</def>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discontinuable</ent><br/
<hw>Dis`con*tin"u*a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Admitting
of being discontinued.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discontinuance</ent><br/
<hw>Dis`con*tin"u*ance</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>The act of discontinuing, or the state of being discontinued; want
of continued connection or continuity; breaking off; cessation;
interruption; <as>as, a <ex>discontinuance</ex> of conversation or
intercourse; <ex>discontinuance</ex> of a highway or of
travel.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <sd>(a)</sd> <def>A breaking off or
interruption of an estate, which happened when an alienation was made by
a tenant in tail, or other tenant, seized in right of another, of a
larger estate than the tenant was entitled to, whereby the party ousted
or injured was driven to his real action, and could not enter. This
effect of such alienation is now obviated by statute in both England and
the United States.</def> <sd>(b)</sd> <def>The termination of an action
in practice by the voluntary act of the plaintiff; an entry on the
record that the plaintiff discontinues his action.</def> <sd>(c)</sd>
<def>That technical interruption of the proceedings in pleading in an
action, which follows where a defendant does not answer the whole of the
plaintiff's declaration, and the plaintiff omits to take judgment for
the part unanswered.</def> <rj><au>Wharton's Law Dict.
Burrill.</au></rj></p>

<p><syn><b>Syn.</b> -- Cessation; intermission; discontinuation;
separation; disunion; disjunction; disruption; break.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discontinuation</ent><br/
<hw>Dis`con*tin`u*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>discontinuation</ets>.]</ety> <def>Breach or interruption of
continuity; separation of parts in a connected series;
discontinuance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Upon any <qex>discontinuation</qex> of parts, made either by
bubbles or by shaking the glass, the whole mercury falls.</q>
<rj><qau>Sir I. Newton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discontinue</ent><br/
<hw>Dis`con*tin"ue</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Discontinued</conjf>
<pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Discontinuing</conjf>.]</vmorph> <ety>[Cf. F.
<ets>discontinuer</ets>.]</ety> <def>To interrupt the continuance of; to
intermit, as a practice or habit; to put an end to; to cause to cease;
to cease using, to stop; to leave off.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Set up their conventicles again, which had been
<qex>discontinued</qex>.</q> <rj><qau>Bp. Burnet.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I have <qex>discontinued</qex> school<br/
Above a twelvemonth.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Taught the Greek tongue, <qex>discontinued</qex> before in these
parts the space of seven hundred years.</q>
<rj><qau>Daniel.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>They modify and discriminate the voice, without appearing to
<qex>discontinue</qex> it.</q> <rj><qau>Holder.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discontinue</ent><br/
<hw>Dis`con*tin"ue</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To lose
continuity or cohesion of parts; to be disrupted or broken off.</def>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To be separated or severed; to part.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thyself shalt <qex>discontinue</qex> from thine heritage.</q>
<rj><qau>Jer. xvii. 4.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discontinuee</ent><br/
<hw>Dis`con*tin`u*ee"</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Law)</fld>
<def>One whose possession of an estate is broken off, or discontinued;
one whose estate is subject to discontinuance.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discontinuer</ent><br/
<hw>Dis`con*tin"u*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
discontinues, or breaks off or away from; an absentee.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He was no gadder abroad, not <qex>discontinuer</qex> from his
convent for a long time.</q> <rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discontinuity</ent><br/
<hw>Dis*con`ti*nu"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Want of
continuity or cohesion; disunion of parts.</def>
<ldquo/<xex>Discontinuity</xex> of surface.<rdquo/
<rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discontinuor</ent><br/
<hw>Dis`con*tin"u*or</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Law)</fld>
<def>One who deprives another of the possession of an estate by
discontinuance. See <er>Discontinuance</er>, 2.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discontinuous</ent><br/
<hw>Dis`con*tin"u*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Not continuous; interrupted; broken off.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A path that is zigzag, <qex>discontinuous</qex>, and intersected
at every turn by human negligence.</q> <rj><qau>De
Quincey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Exhibiting a dissolution of continuity;
gaping.</def> <ldquo/<xex>Discontinuous</xex> wound.<rdquo/
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Discontinuous function</b></col> <fld>(Math.)</fld>,
<cd>a function which for certain values or between certain values of the
variable does not vary continuously as the variable increases. The
discontinuity may, for example, consist of an abrupt change in the value
of the function, or an abrupt change in its law of variation, or the
function may become imaginary.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disconvenience</ent><br/
<hw>Dis`con*ven"ience</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Unsuitableness; incongruity.</def> <mark>[Obs.]</mark>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disconvenient</ent><br/
<hw>Dis`con*ven"ient</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Not
convenient or congruous; unsuitable; ill-adapted.</def>
<mark>[Obs.]</mark> <rj><au>Bp. Reynolds.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discophora</ent><br/
\'d8<hw>Dis*coph"o*ra</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
fr. Gr. <?/ disk + <ets><?/</ets> to bear.]</ety> <fld>(Zool.)</fld>
<def>A division of acalephs or jellyfishes, including most of the large
disklike species.</def> -- <wordforms><wf>Dis*coph"o*rous</wf>
<pr>(#)</pr>, <pos>a.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discord</ent><br/
<hw>Dis"cord`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>discord</ets>, <ets>descord</ets>, OF. <ets>discorde</ets>,
<ets>descorde</ets>, F. <ets>discorde</ets>, from L.
<ets>discordia</ets>, fr. <ets>discors</ets>, <ets>-cordis</ets>,
discordant, disagreeable; <ets>dis-</ets> + <ets>cor</ets>,
<ets>cordis</ets>, heart; cf. F. <ets>discord</ets>, <ets>n.</ets>, and
OF. <ets>descorder</ets>, <ets>discorder</ets>, F. <ets>discorder</ets>,
to discord, L. <ets>discordare</ets>, from <ets>discors</ets>. See
<er>Heart</er>, and cf. <er>Discord</er>, <pos>v. i.</pos>]</ety>
<sn>1.</sn> <def>Want of concord or agreement; absence of unity or
harmony in sentiment or action; variance leading to contention and
strife; disagreement; -- applied to persons or to things, and to
thoughts, feelings, or purposes.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A false witness that speaketh lies, and he that soweth
<qex>discord</qex> among brethren.</q> <rj><qau>Prov. vi.
19.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Peace to arise out of universal <qex>discord</qex> fomented in all
parts of the empire.</q> <rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mus.)</fld> <def>Union of musical sounds which
strikes the ear harshly or disagreeably, owing to the incommensurability
of the vibrations which they produce; want of musical concord or
harmony; a chord demanding resolution into a concord.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>For a <qex>discord</qex> itself is but a harshness of divers
sounds meeting.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Apple of discord</b></col>. <cd>See under
<er>Apple</er>.</cd></cs></p>

<p><syn><b>Syn.</b> -- Variance; difference; opposition; contrariety;
clashing; dissension; contention; strife; disagreement;
dissonance.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discord</ent><br/
<hw>Dis*cord"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[OE.
<ets>discorden</ets>, <ets>descorden</ets>, from the French. See
<er>Discord</er>, <pos>n.</pos>]</ety> <def>To disagree; to be
discordant; to jar; to clash; not to suit.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The one <qex>discording</qex> with the other.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discordable</ent><br/
<hw>Dis*cord"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. OF.
<ets>descordable</ets>.]</ety> <def>That may produce discord;
disagreeing; discordant.</def> <mark>[R.]</mark>
<rj><au>Halliwell.</au></rj></p>

<p><ent>Discordancy</ent><br/
<ent>Discordance</ent><br/
<mhw>{ <hw>Dis*cord"ance</hw> <pr>(?)</pr>, <hw>Dis*cord"an*cy</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[Cf. F.
<ets>discordance</ets>.]</ety> <def>State or quality of being
discordant; disagreement; inconsistency.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There will arise a thousand <qex>discordances</qex> of
opinion.</q> <rj><qau>I. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discordant</ent><br/
<hw>Dis*cord"ant</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OE.
<ets>discordant</ets>, <ets>descordaunt</ets>, OF.
<ets>descordant</ets>, <ets>discordant</ets>, F. <ets>discordant</ets>,
p. pr. of <ets>discorder</ets>, OF. also, <ets>descorder</ets>. See
<er>Discord</er>, <pos>n.</pos>]</ety> <sn>1.</sn> <def>Disagreeing;
incongruous; being at variance; clashing; opposing; not
harmonious.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>discordant</qex> elements out of which the emperor had
compounded his realm did not coalesce.</q>
<rj><qau>Motley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <ety>[See <er>Discord</er>, <pos>n.</pos>,
<sn>2.</sn>]</ety> <fld>(Mus.)</fld> <def>Dissonant; not in harmony or
musical concord; harsh; jarring; <as>as, <ex>discordant</ex> notes or
sounds</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>For still their music seemed to start<br/
<qex>Discordant</qex> echoes in each heart.</q>
<rj><qau>Longfellow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Geol.)</fld> <def>Said of strata which lack
conformity in direction of bedding, either as in unconformability, or as
caused by a fault.</def></p>

<p><syn><b>Syn.</b> -- Disagreeing; incongruous; contradictory;
repugnant; opposite; contrary; inconsistent; dissonant; harsh; jarring;
irreconcilable.</syn></p>

<p>-- <wordforms><wf>Dis*cord"ant*ly</wf>, <pos>adv.</pos> --
<wf>Dis*cord"ant*ness</wf>, <pos>n.</pos>
<mark>[R.]</mark></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discordful</ent><br/
<hw>Dis*cord"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Full of discord;
contentious.</def> <mark>[Obs.]</mark> <ldquo/His <xex>discordful</xex>
dame.<rdquo/ <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discordous</ent><br/
<hw>Dis*cord"ous</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Full of
discord.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discorporate</ent><br/
<hw>Dis*cor"po*rate</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Deprived of
the privileges or form of a body corporate.</def> <mark>[Obs.]</mark>
<rj><au>Jas. II.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discorrespondent</ent><br/
<hw>Dis*cor`re*spond"ent</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Incongruous.</def> <rj><au>W. Montagu.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discost</ent><br/
<hw>Dis*cost"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>Same as
<er>Discoast</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discounsel</ent><br/
<hw>Dis*coun"sel</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>dis-</ets> + <ets>counsel</ets>: cf. OF.
<ets>desconseiller</ets>.]</ety> <def>To dissuade.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discount</ent><br/
<hw>Dis"count`</hw> <pr>(?; 277)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Discounted</conjf>; <pos>p. pr.
& vb. n.</pos> <conjf>Discounting</conjf>.]</vmorph> <ety>[OF.
<ets>desconter</ets>, <ets>descompter</ets>, to deduct, F.
<ets>d<eacute/compter</ets> to discount; pref. <ets>des-</ets> (L.
<ets>dis-</ets>) + <ets>conter</ets>, <ets>compter</ets>. See
<er>Count</er>, <pos>v.</pos>]</ety> <sn>1.</sn> <def>To deduct from an
account, debt, charge, and the like; to make an abatement of; <as>as,
merchants sometimes <ex>discount</ex> five or six per cent for prompt
payment of bills</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To lend money upon, deducting the discount or
allowance for interest; <as>as, the banks <ex>discount</ex> notes and
bills of exchange</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Discount</qex> only unexceptionable paper.</q>
<rj><qau>Walsh.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To take into consideration beforehand; to anticipate
and form conclusions concerning (an event).</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To leave out of account; to take no notice of.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Of the three opinions (I <qex>discount</qex> Brown's).</q>
<rj><qau>Sir W. Hamilton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 422 --></p>

<p><ent>Discount</ent><br/
<hw>Dis"count`</hw> <pr>(?; 277)</pr>, <pos>v. i.</pos> <def>To lend, or
make a practice of lending, money, abating the discount; <as>as, the
<ex>discount</ex> for sixty or ninety days</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discount</ent><br/
<hw>Dis"count`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>d<eacute/compte</ets>. See <er>Discount</er>, <pos>v.
t.</pos>]</ety> <sn>1.</sn> <def>A counting off or deduction made from a
gross sum on any account whatever; an allowance upon an account, debt,
demand, price asked, and the like; something taken or
deducted.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A deduction made for interest, in advancing money
upon, or purchasing, a bill or note not due; payment in advance of
interest upon money.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The rate of interest charged in
discounting.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>At a discount</b></col>, <cd>below par, or below the
nominal value; hence, colloquially, out of favor; poorly esteemed;
depreciated.</cd> -- <col><b>Bank discount</b></col>, <cd>a sum equal to
the interest at a given rate on the principal (face) of a bill or note
from the time of discounting until it become due.</cd> --
<col><b>Discount broker</b></col>, <cd>one who makes a business of
discounting commercial paper; a bill broker.</cd> -- <col><b>Discount
day</b></col>, <cd>a particular day of the week when a bank discounts
bills.</cd> -- <col><b>True discount</b></col>, <cd>the interest which,
added to a principal, will equal the face of a note when it becomes due.
The principal yielding this interest is the <xex>present value</xex> of
the note.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discountable</ent><br/
<hw>Dis*count"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of
being, or suitable to be, discounted; <as>as, certain forms are
necessary to render notes <ex>discountable</ex> at a
bank</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discountenance</ent><br/
<hw>Dis*coun"te*nance</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Discountenanced</conjf>
<pr>(?)</pr>; <pos>p. pr. & vb. n.</pos> <conjf>Discountenancing</conjf>
<pr>(?)</pr>.]</vmorph> <ety>[Pref. <ets>dis-</ets> +
<ets>countenance</ets>: cf. OF. <ets>descontenancer</ets>, F.
<ets>d<eacute/contenancer</ets>.]</ety> <sn>1.</sn> <def>To ruffle or
discompose the countenance of; to put of countenance; to put to shame;
to abash.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>How would one look from his majestic brow . . . <br/
<qex>Discountenance</qex> her despised!</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The hermit was somewhat <qex>discountenanced</qex> by this
observation.</q> <rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To refuse to countenance, or give the support of
one's approval to; to give one's influence against; to restrain by cold
treatment; to discourage.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A town meeting was convened to <qex>discountenance</qex> riot.</q>
<rj><qau>Bancroft.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discountenance</ent><br/
<hw>Dis*coun"te*nance</hw>, <pos>n.</pos> <def>Unfavorable aspect;
unfriendly regard; cold treatment; disapprobation; whatever tends to
check or discourage.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He thought a little <qex>discountenance</qex> on those persons
would suppress that spirit.</q> <rj><qau>Clarendon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discountenancer</ent><br/
<hw>Dis*coun"te*nan*cer</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
discountenances; one who disfavors.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discounter</ent><br/
<hw>Dis"count`er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
discounts; a discount broker.</def> <rj><au>Burke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discourage</ent><br/
<hw>Dis*cour"age</hw> <pr>(?; 48)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Discouraged</conjf>
<pr>(?)</pr>; <pos>p. pr. & vb. n.</pos> <conjf>Discouraging</conjf>
<pr>(?)</pr>.]</vmorph> <ety>[Pref. <ets>dis-</ets> +
<ets>courage</ets>: cf. OF. <ets>descoragier</ets>, F.
<ets>d<eacute/courager</ets>: pref. <ets>des-</ets> (L. <ets>dis-</ets>)
+ <ets>corage</ets>, F. <ets>courage</ets>. See <er>Courage</er>.]</ety>
<sn>1.</sn> <def>To extinguish the courage of; to dishearten; to depress
the spirits of; to deprive of confidence; to deject; -- the opposite of
<xex>encourage</xex>; <as>as, he was <ex>discouraged</ex> in his
undertaking; he need not be <ex>discouraged</ex> from a like
attempt.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Fathers, provoke not your children to anger, lest they be
<qex>discouraged</qex>.</q> <rj><qau>Col. iii. 21.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To dishearten one with respect to; to
discountenance; to seek to check by disfavoring; to deter one from;
<as>as, they <ex>discouraged</ex> his efforts</as>.</def></p>

<p><syn><b>Syn.</b> -- To dishearten; dispirit; depress; deject;
dissuade; disfavor.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discourage</ent><br/
<hw>Dis*cour"age</hw>, <pos>n.</pos> <def>Lack of courage;
cowardliness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discourageable</ent><br/
<hw>Dis*cour"age*a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of
being discouraged; easily disheartened.</def> <rj><au>Bp.
Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discouragement</ent><br/
<hw>Dis*cour"age*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. OF.
<ets>descouragement</ets>, F. <ets>d<eacute/couragement</ets>.]</ety>
<sn>1.</sn> <def>The act of discouraging, or the state of being
discouraged; depression or weakening of confidence; dejection.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which discourages; that which deters, or tends
to deter, from an undertaking, or from the prosecution of anything; a
determent; <as>as, the revolution was commenced under every possible
<ex>discouragement</ex></as>.</def> <ldquo/<xex>Discouragements</xex>
from vice.<rdquo/ <rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discourager</ent><br/
<hw>Dis*cour"a*ger</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
discourages.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The promoter of truth and the <qex>discourager</qex> of error.</q>
<rj><qau>Sir G. C. Lewis.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discouraging</ent><br/
<hw>Dis*cour"a*ging</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Causing or
indicating discouragement.</def> --
<wordforms><wf>Dis*cour"a*ging*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discoure</ent><br/
<hw>Dis*coure"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To
discover.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>That none might her <qex>discoure</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discourse</ent><br/
<hw>Dis*course"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>discursus</ets> a running to and fro, discourse, fr.
<ets>discurrere</ets>, <ets>discursum</ets>, to run to and fro, to
discourse; <ets>dis-</ets> + <ets>currere</ets> to run: cf. F.
<ets>discours</ets>. See <er>Course</er>.]</ety> <sn>1.</sn> <def>The
power of the mind to reason or infer by running, as it were, from one
fact or reason to another, and deriving a conclusion; an exercise or act
of this power; reasoning; range of reasoning faculty.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Difficult, strange, and harsh to the <qex>discourses</qex> of
natural reason.</q> <rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Sure he that made us with such large <qex>discourse</qex>,<br/
Looking before and after, gave us not<br/
That capability and godlike reason<br/
To fust in us unused.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Conversation; talk.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In their <qex>discourses</qex> after supper.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Filling the head with variety of thoughts, and the mouth with
copious <qex>discourse</qex>.</q> <rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The art and manner of speaking and
conversing.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Of excellent breeding, admirable <qex>discourse</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Consecutive speech, either written or unwritten, on
a given line of thought; speech; treatise; dissertation; sermon, etc.;
<as>as, the preacher gave us a long <ex>discourse</ex> on
duty</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Dealing; transaction.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Good Captain Bessus, tell us the <qex>discourse</qex><br/
Betwixt Tigranes and our king, and how<br/
We got the victory.</q> <rj><qau>Beau. & Fl.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discourse</ent><br/
<hw>Dis*course"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Discoursed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Discoursing</conjf>.]</vmorph> <sn>1.</sn> <def>To
exercise reason; to employ the mind in judging and inferring; to
reason.</def> <mark>[Obs.]</mark> <ldquo/Have sense or can
<xex>discourse</xex>.<rdquo/ <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To express one's self in oral discourse; to expose
one's views; to talk in a continuous or formal manner; to hold forth; to
speak; to converse.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Bid me <qex>discourse</qex>, I will enchant thine ear.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To relate something; to tell.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To treat of something in writing and
formally.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discourse</ent><br/
<hw>Dis*course"</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To treat of; to
expose or set forth in language.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The life of William Tyndale . . . is sufficiently and at large
<qex>discoursed</qex> in the book.</q> <rj><qau>Foxe.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To utter or give forth; to speak.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It will <qex>discourse</qex> most eloquent music.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To talk to; to confer with.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I have spoken to my brother, who is the patron, to
<qex>discourse</qex> the minister about it.</q>
<rj><qau>Evelyn.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discourser</ent><br/
<hw>Dis*cours"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One
who discourse; a narrator; a speaker; an haranguer.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In his conversation he was the most clear
<qex>discourser</qex>.</q> <rj><qau>Milward.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The writer of a treatise or dissertation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Philologers and critical <qex>discoursers</qex>.</q> <rj><qau>Sir
T. Browne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discoursive</ent><br/
<hw>Dis*cours"ive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Discursive</er>.]</ety> <sn>1.</sn> <def>Reasoning; characterized by
reasoning; passing from premises to consequences; discursive.</def>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Containing dialogue or conversation;
interlocutory.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The epic is everywhere interlaced with dialogue or
<qex>discoursive</qex> scenes.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Inclined to converse; conversable; communicative;
<as>as, a <ex>discoursive</ex> man</as>.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discoursive</ent><br/
<hw>Dis*cours"ive</hw>, <pos>n.</pos> <def>The state or quality of being
discoursive or able to reason.</def> <mark>[R.]</mark>
<rj><au>Feltham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discourteous</ent><br/
<hw>Dis*cour"te*ous</hw> <pr>(?; see <er>Courteous</er>, 277)</pr>,
<pos>a.</pos> <ety>[Pref. <ets>dis-</ets> + <ets>courteous</ets>: cf.
OF. <ets>discortois</ets>.]</ety> <def>Uncivil; rude; wanting in
courtesy or good manners; uncourteous.</def> --
<wordforms><wf>Dis*cour"te*ous*ly</wf>, <pos>adv.</pos> --
<wf>Dis*cour"te*ous*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discourtesy</ent><br/
<hw>Dis*cour"te*sy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>dis-</ets> + <ets>courtesy</ets>: cf. OF.
<ets>descourtoisie</ets>.]</ety> <def>Rudeness of behavior or language;
ill manners; manifestation of disrespect; incivility.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Be calm in arguing; for fierceness makes<br/
Error a fault, and truth <qex>discourtesy</qex>.</q>
<rj><qau>Herbert.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discourtship</ent><br/
<hw>Dis*court"ship</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Want of
courtesy.</def> <mark>[Obs.]</mark> <rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discous</ent><br/
<hw>Disc"ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>discus</ets>
disk. See <er>Disk</er>.]</ety> <def>Disklike; discoid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discovenant</ent><br/
<hw>Dis*cov"e*nant</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To dissolve
covenant with.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discover</ent><br/
<hw>Dis*cov"er</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Discovered</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Discovering</conjf>.]</vmorph> <ety>[OE.
<ets>discoveren</ets>, <ets>discuren</ets>, <ets>descuren</ets>, OF.
<ets>descovrir</ets>, <ets>descouvrir</ets>, F.
<ets>d<eacute/couvrir</ets>; <ets>des-</ets> (L. <ets>dis-</ets>) +
<ets>couvrir</ets> to cover. See <er>Cover</er>.]</ety> <sn>1.</sn>
<def>To uncover.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Whether any man hath pulled down or <qex>discovered</qex> any
church.</q> <rj><qau>Abp. Grindal.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To disclose; to lay open to view; to make visible;
to reveal; to make known; to show (what has been secret, unseen, or
unknown).</def> <mark>[Archaic]</mark> <br/
[<source>1913 Webster</source>]</p>

<p><q>Go, draw aside the curtains, and <qex>discover</qex><br/
The several caskets to this noble prince.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Prosperity doth best <qex>discover</qex> vice; but adversity doth
best <qex>discover</qex> virtue.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>We will <qex>discover</qex> ourselves unto them.</q> <rj><qau>1
Sam. xiv. 8.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Discover</qex> not a secret to another.</q> <rj><qau>Prov.
xxv. 9.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To obtain for the first time sight or knowledge of,
as of a thing existing already, but not perceived or known; to find; to
ascertain; to espy; to detect.</def>
<wns>[wns=1,2,3,4,5,6,7,8]</wns><br/
[<source>1913 Webster</source>]</p>
<-- all 8 senses in WordNet seem to fit under this category. -->

<p><q>Some to <qex>discover</qex> islands far away.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To manifest without design; to show.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The youth <qex>discovered</qex> a taste for sculpture.</q> <rj><qau>C. J. Smith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To explore; to examine.</def> <mark>[Obs.]</mark></p>

<p><syn><b>Syn.</b> -- To disclose; bring out; exhibit; show; manifest; reveal; communicate; impart; tell; espy; find; out; detect. -- To <er>Discover</er>, <er>Invent</er>. We <xex>discover</xex> what existed before, but remained unknown; we <xex>invent</xex> by forming combinations which are either entirely new, or which attain their end by means unknown before. Columbus <xex>discovered</xex> America; Newton <xex>discovered</xex> the law of gravitation; Whitney <xex>invented</xex> the cotton gin; Galileo <xex>invented</xex> the telescope.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discover</ent><br/
<hw>Dis*cov"er</hw>, <pos>v. i.</pos> <def>To discover or show one's self.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>This done, they <qex>discover</qex>.</q> <rj><qau>Decker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Nor was this the first time that they <qex>discovered</qex> to be followers of this world.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discoverability</ent><br/
<hw>Dis*cov`er*a*bil"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The quality of being discoverable.</def> <mark>[R.]</mark>  <rj><au>Carlyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discoverable</ent><br/
<hw>Dis*cov"er*a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of being discovered, found out, or perceived; <as>as, many minute animals are <ex>discoverable</ex> only by the help of the microscope; truths <ex>discoverable</ex> by human industry.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discoverer</ent><br/
<hw>Dis*cov"er*er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who discovers; one who first comes to the knowledge of something; one who discovers an unknown country, or a new principle, truth, or fact.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>discoverers</qex> and searchers of the land.</q> <rj><qau>Sir W. Raleigh.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A scout; an explorer.</def>  <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discoverment</ent><br/
<hw>Dis*cov"er*ment</hw>, <pos>n.</pos> <def>Discovery.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discovert</ent><br/
<hw>Dis*cov"ert</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F. <ets>d<eacute/couvert</ets> uncovered, OF. <ets>descovert</ets>. See <er>Discover</er>, <er>Covert</er>.]</ety> <fld>(Law)</fld> <def>Not covert; not within the bonds of matrimony; unmarried; -- applied either to a woman who has never married or to a widow.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discovert</ent><br/
<hw>Dis*cov"ert</hw>, <pos>n.</pos> <def>An uncovered place or part.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>At discovert</b></col>, <cd>uncovered.</cd> <mark>[Obs.]</mark>  <rj><au>Chaucer.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discoverture</ent><br/
<hw>Dis*cov"er*ture</hw> <pr>(?; 135)</pr>, <pos>n.</pos> <ety>[Pref. <ets>dis-</ets> + <ets>coverture</ets>: cf. OF. <ets>descoverture</ets>.]</ety> <sn>1.</sn> <def>Discovery.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>A state of being released from coverture; freedom of a woman from the coverture of a husband.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discovery</ent><br/
<hw>Dis*cov"er*y</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it> <plw>Discoveries</plw> <pr>(<?/)</pr>.</plu> <sn>1.</sn> <def>The action of discovering; exposure to view; laying open; showing; <as>as, the <ex>discovery</ex> of a plot</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A making known; revelation; disclosure; <as>as, a bankrupt is bound to make a full <ex>discovery</ex> of his assets</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In the clear <qex>discoveries</qex> of the next [world].</q> <rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Finding out or ascertaining something previously unknown or unrecognized; <as>as, Harvey's <ex>discovery</ex> of the circulation of the blood</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A brilliant career of <qex>discovery</qex> and conquest.</q> <rj><qau>Prescott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>We speak of the <ldquo/invention<rdquo/ of printing, the <qex>discovery</qex> of America.</q> <rj><qau>Trench.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>That which is discovered; a thing found out, or for the first time ascertained or recognized; <as>as, the properties of the magnet were an important <ex>discovery</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Exploration; examination.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discovery Day</ent><br/
<hw>Dis*cov"er*y Day</hw>. <def>same as <er>Columbus Day</er>, above.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Discradle</ent><br/
<hw>Dis*cra"dle</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To take from a cradle.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>This airy apparition first <qex>discradled</qex><br/
From Tournay into Portugal.</q> <rj><qau>Ford.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discredit</ent><br/
<hw>Dis*cred"it</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F. <ets>discr<eacute/dit</ets>.]</ety> <sn>1.</sn> <def>The act of discrediting or disbelieving, or the state of being discredited or disbelieved; <as>as, later accounts have brought the story into <ex>discredit</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence, some degree of dishonor or disesteem; ill repute; reproach; -- applied to persons or things.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It is the duty of every Christian to be concerned for the reputation or <qex>discredit</qex> his life may bring on his profession.</q> <rj><qau>Rogers.</qau></rj></p>

<p><syn><b>Syn.</b> -- Disesteem; disrepute; dishonor; disgrace; ignominy; scandal; disbelief; distrust.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discredit</ent><br/
<hw>Dis*cred"it</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos> <conjf>Discredited</conjf>; <pos>p. pr. & vb. n.</pos> <conjf>Discrediting</conjf>.]</vmorph> <ety>[Cf. F. <ets>discr<eacute/diter</ets>.]</ety> <sn>1.</sn> <def>To refuse credence to; not to accept as true; to disbelieve; <as>as, the report is <ex>discredited</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To deprive of credibility; to destroy confidence or trust in; to cause disbelief in the accuracy or authority of.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>An occasion might be given to the . . . papists of <qex>discrediting</qex> our common English Bible.</q> <rj><qau>Strype.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To deprive of credit or good repute; to bring reproach upon; to make less reputable; to disgrace.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He. . . least <qex>discredits</qex> his travels who returns the same man he went.</q> <rj><qau>Sir H. Wotton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>discreditable</ent><br/
<hw>dis*cred"it*a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Not creditable; injurious to reputation; disgraceful; disreputable.</def> -- <wordforms><wf>Dis*cred"it*a*bly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>discredited</ent><br/
<hw>discredited</hw> <pos>adj.</pos> <sn>1.</sn> <def>being brought into disrepute; <as>as, a <ex>discredited</ex> politician</as>.</def><br/
<syn><b>Syn. --</b> damaged.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>suffering shame.</def><br/
<syn><b>Syn. --</b> disgraced, dishonored, shamed.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>3.</sn> <def>having been shown to be incorrect; <as>as, a <ex>discredited</ex> theory or policy</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>discreditor</ent><br/
<hw>dis*cred"it*or</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who discredits.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discreet</ent><br/
<hw>Dis*creet"</hw> <pr>(?)</pr>, <pos>a.</pos> <amorph>[<pos>Compar.</pos> <adjf>Discreeter</adjf> <pr>(?)</pr>; <pos>superl.</pos> <adjf>Discreetest</adjf>.]</amorph> <ety>[F. <ets>discret</ets>, L. <ets>discretus</ets> separated (whence the meaning <ets>reserved</ets>, <ets>prudent</ets>), p. p. of <ets>discernere</ets>. See <er>Discern</er>, and cf. <er>Discrete</er>.]</ety> <sn>1.</sn> <def>Possessed of discernment, especially in avoiding error or evil, and in the adaptation of means to ends; prudent; sagacious; judicious; not rash or heedless; cautious.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It is the <qex>discreet</qex> man, not the witty, nor the learned, nor the brave, who guides the conversation, and gives measures to society.</q> <rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Satire 's my weapon, but I 'm too <qex>discreet</qex><br/
To run amuck, and tilt at all I meet.</q> <rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The sea is silent, the sea is <qex>discreet</qex>.</q> <rj><qau>Longfellow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Differing; distinct.</def> <mark>[Obs.]</mark>  <rj><au>Spenser.</au></rj></p>

<p>-- <wordforms><wf>Dis*creet"ly</wf>, <pos>adv.</pos> -- <wf>Dis*creet"ness</wf>, <pos>n.</pos></wordforms></p>

<p><ent>Discrepancy</ent><br/
<ent>Discrepance</ent><br/
<mhw>{ <hw>Dis*crep"ance</hw> <pr>(?; 277)</pr>, <hw>Dis*crep"an*cy</hw> <pr>(?)</pr>, }</mhw> <pos>n.</pos>; <plu><it>pl.</it> <plw>-ances</plw> <pr>(#)</pr>, <plw>-ancies</plw> <pr>(#)</pr>.</plu> <ety>[L. <ets>disrepantia</ets>: cf. OF. <ets>discrepance</ets>. See <er>Discrepant</er>.]</ety> <def>The state or quality of being discrepant; disagreement; variance; discordance; dissimilarity; contrariety.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There hath been ever a <qex>discrepance</qex> of vesture of youth and age, men and women.</q> <rj><qau>Sir T. Elyot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>There is no real <qex>discrepancy</qex> between these two genealogies.</q> <rj><qau>G. S. Faber.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discrepant</ent><br/
<hw>Dis*crep"ant</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>discrepans</ets>, <ets>-antis</ets>, p. pr. of <ets>discrepare</ets> to sound differently or discordantly; <ets>dis-</ets> + <ets>crepare</ets> to rattle, creak: cf. OF. <ets>discrepant</ets>. See <er>Crepitate</er>.]</ety> <def>Discordant; at variance; disagreeing; contrary; different.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The Egyptians were . . . the most oddly <qex>discrepant</qex> from the rest in their manner of worship.</q> <rj><qau>Cudworth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discrepant</ent><br/
<hw>Dis*crep"ant</hw>, <pos>n.</pos> <def>A dissident.</def>  <rj><au>J. Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discrete</ent><br/
<hw>Dis*crete"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>discretus</ets>, p. p. of <ets>discernere</ets>. See <er>Discreet</er>.]</ety> <sn>1.</sn> <def>Separate; distinct; disjunct.</def>  <rj><au>Sir M. Hale.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Disjunctive; containing a disjunctive or discretive clause; <as>as, <ldquo/I resign my life, but not my honor,<rdquo/ is a <ex>discrete</ex> proposition</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Bot.)</fld> <def>Separate; not coalescent; -- said of things usually coalescent.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Discrete movement</b></col>. <cd>See <cref>Concrete movement of the voice</cref>, under <er>Concrete</er>, <pos>a.</pos></cd> -- <col><b>Discrete proportion</b></col>, <cd>proportion where the ratio of the <xex>means</xex> is different from that of either couplet; as, 3:6::8:16, 3 bearing the same proportion to 6 as 8 does to 16. But 3 is not to 6 as 6 to 8. It is thus opposed to <xex>continued</xex> or <contr>continual proportion</contr>; as, 3:6::12:24.</cd> -- <col><b>Discrete quantity</b></col>, <cd>that which must be divided into units, as number, and is opposed to <contr>continued quantity</contr>, as duration, or extension.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discrete</ent><br/
<hw>Dis*crete"</hw>, <pos>v. t.</pos> <def>To separate.</def> <mark>[Obs.]</mark>  <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discretely</ent><br/
<hw>Dis*crete"ly</hw>, <pos>adv.</pos> <def>Separately; disjunctively.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discretion</ent><br/
<hw>Dis*cre"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>discr<eacute/tion</ets>, L. <ets>discretio</ets> separation, difference, discernment, fr. <ets>discernere</ets>, <ets>discretum</ets>. See <er>Discreet</er>, <er>Discern</er>.]</ety> <sn>1.</sn> <def>Disjunction; separation.</def> <mark>[Obs.]</mark>  <rj><au>Mede.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The quality of being discreet; wise conduct and management; cautious discernment, especially as to matters of propriety and self-control; prudence; circumspection; wariness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The better part of valor is <qex>discretion</qex>.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The greatest parts without <qex>discretion</qex> may be fatal to their owner.</q> <rj><qau>Hume.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Discrimination.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Well spoken, with good accent and good <qex>discretion</qex>.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Freedom to act according to one's own judgment; unrestrained exercise of choice or will.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>At discretion</b></col>, <cd>without conditions or stipulations.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 423 --></p>

<p><ent>Discretionary</ent><br/
<ent>Discretional</ent><br/
<mhw>{ <hw>Dis*cre"tion*al</hw> <pr>(?)</pr>, <hw>Dis*cre"tion*a*ry</hw>
<pr>(?)</pr>, }</mhw><ety>[Cf. F.
<ets>discr<eacute/tionnaire</ets>.]</ety> <def>Left to discretion;
unrestrained except by discretion or judgment; <as>as, an ambassador
with <ex>discretionary</ex> powers</as>.</def></p>

<p><ent>Discretionarily</ent><br/
<ent>Discretionally</ent><br/
<mhw>{ <hw>Dis*cre"tion*al*ly</hw> <pr>(?)</pr>,
<hw>Dis*cre"tion*a*ri*ly</hw> <pr>(?)</pr>, }</mhw> <pos>adv.</pos>
<def>At discretion; according to one's discretion or judgment.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discretive</ent><br/
<hw>Dis*cre"tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>discretivus</ets>. See <er>Discrete</er>.]</ety> <def>Marking
distinction or separation; disjunctive.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Discretive proposition</b></col> <fld>(Logic &
Gram.)</fld>, <cd>one that expresses distinction, opposition, or
variety, by means of <xex>discretive</xex> particles, as <xex>but</xex>,
<xex>though</xex>, <xex>yet</xex>, etc.; as, travelers change their
climate, <xex>but</xex> not their temper.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discretively</ent><br/
<hw>Dis*cre"tive*ly</hw>, <pos>adv.</pos> <def>In a discretive
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discriminable</ent><br/
<hw>Dis*crim"i*na*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of
being discriminated.</def> <mark>[Obs.]</mark>
<rj><au>Bailey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discriminal</ent><br/
<hw>Dis*crim"i*nal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>discriminalis</ets> serving to divide.]</ety> <def>In palmistry,
applied to the line which marks the separation between the hand and the
arm.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discriminant</ent><br/
<hw>Dis*crim"i*nant</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>discriminans</ets>, p. pr. of <ets>discriminare</ets>.]</ety>
<fld>(Math.)</fld> <def>The eliminant of the <xex>n</xex> partial
differentials of any homogeneous function of <xex>n</xex> variables. See
<er>Eliminant</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discriminate</ent><br/
<hw>Dis*crim"i*nate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>discriminatus</ets>, p. p. of <ets>discriminare</ets> to divide,
separate, fr. <ets>discrimen</ets> division, distinction, decision, fr.
<ets>discernere</ets>. See <er>Discern</er>, and cf.
<er>Criminate</er>.]</ety> <def>Having the difference marked;
distinguished by certain tokens.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discriminate</ent><br/
<hw>Dis*crim"i*nate</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Discriminated</conjf>
<pr>(?)</pr>; <pos>p. pr. & vb. n.</pos> <conjf>Discriminating</conjf>
<pr>(?)</pr>.]</vmorph> <def>To set apart as being different; to mark as
different; to separate from another by discerning differences; to
distinguish.</def> <rj><au>Cowper.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>discriminate</qex> the goats from the sheep.</q>
<rj><qau>Barrow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discriminate</ent><br/
<hw>Dis*crim"i*nate</hw> <pr>(?)</pr>, <pos>v. i.</pos> <sn>1.</sn>
<def>To make a difference or distinction; to distinguish accurately;
<as>as, in judging of evidence, we should be careful to
<ex>discriminate</ex> between probability and slight
presumption</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <sd>(a)</sd> <def>To treat unequally.</def> <sd>(b)</sd>
<fld>(Railroads)</fld> <def>To impose unequal tariffs for substantially
the same service.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discriminately</ent><br/
<hw>Dis*crim"i*nate*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a
discriminating manner; distinctly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discriminateness</ent><br/
<hw>Dis*crim"i*nate*ness</hw>, <pos>n.</pos> <def>The state of being
discriminated; distinctness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discriminating</ent><br/
<hw>Dis*crim"i*na`ting</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Marking a difference; distinguishing.</def> --
<wordforms><wf>Dis*crim"i*na`ting*ly</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><q>And finds with keen <qex>discriminating</qex> sight,<br/
Black's not so black; -- nor white so very white.</q>
<rj><qau>Canning.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>making careful or fine distinctions, especially as
to quality or accuracy; <as>as, a <ex>discriminating</ex>
observer</as>.</def><br/
<syn><b>Syn. --</b> discerning, perspicacious.</syn>
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>having a refined taste or excellent judgment;
<as>as, a <ex>discriminating</ex> taste</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Discrimination</ent><br/
<hw>Dis*crim`i*na"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>discriminatio</ets> the contrasting of opposite thoughts.]</ety>
<sn>1.</sn> <def>The act of discriminating, distinguishing, or noting
and marking differences.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To make an anxious <qex>discrimination</qex> between the miracle
absolute and providential.</q> <rj><qau>Trench.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The state of being discriminated, distinguished, or
set apart.</def> <rj><au>Sir J. Reynolds.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Railroads)</fld> <def>The arbitrary imposition of
unequal tariffs for substantially the same service.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A difference in rates, not based upon any corresponding difference
in cost, constitutes a case of <qex>discrimination</qex>.</q>
<rj><qau>A. T. Hadley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The quality of being discriminating; faculty of
nicely distinguishing; acute discernment; <as>as, to show great
<ex>discrimination</ex> in the choice of means</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>That which discriminates; mark of
distinction.</def></p>

<p><syn><b>Syn.</b> -- Discernment; penetration; clearness; acuteness;
judgment; distinction. See <er>Discernment</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discriminative</ent><br/
<hw>Dis*crim"i*na*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Marking a difference; distinguishing; distinctive;
characteristic.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That peculiar and <qex>discriminative</qex> form of life.</q>
<rj><qau>Johnson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Observing distinctions; making differences;
discriminating.</def> <ldquo/<xex>Discriminative</xex> censure.<rdquo/
<au>J. Foster.</au> <ldquo/<xex>Discriminative</xex> Providence.<rdquo/
<rj><au>Dr. H. More.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discriminatively</ent><br/
<hw>Dis*crim"i*na*tive*ly</hw>, <pos>adv.</pos> <def>With discrimination
or distinction.</def> <rj><au>J. Foster.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discriminator</ent><br/
<hw>Dis*crim"i*na`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL.]</ety>
<def>One who discriminates.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discriminatory</ent><br/
<hw>Dis*crim"i*na*to*ry</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Discriminative.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discriminous</ent><br/
<hw>Dis*crim"i*nous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[LL.
<ets>discriminosus</ets>, fr. L. <ets>discrimen</ets> the dangerous,
decisive moment. See <er>Discriminate</er>, <pos>a.</pos>]</ety>
<def>Hazardous; dangerous.</def> <mark>[Obs.]</mark>
<rj><au>Harvey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discrive</ent><br/
<hw>Dis*crive"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[OF.
<ets>descrivre</ets>. See <er>Describe</er>.]</ety> <def>To
describe.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discrown</ent><br/
<hw>Dis*crown"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Discrowned</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Discrowning</conjf>.]</vmorph> <def>To deprive of a
crown.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The end had crowned the work; it not unreasonably
<qex>discrowned</qex> the workman.</q> <rj><qau>Motley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discruciate</ent><br/
<hw>Dis*cru"ci*ate</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Discruciated</conjf>; <pos>p.
pr. & vb. n.</pos> <conjf>Discruciating</conjf>.]</vmorph> <ety>[L.
<ets>discruciatus</ets>, p. p. of <ets>discruciare</ets>. See
<er>Cruciate</er>.]</ety> <def>To torture; to excruciate.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Discruciate</qex> a man in deep distress.</q>
<rj><qau>Herrick.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discubitory</ent><br/
<hw>Dis*cu"bi*to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>discumbere</ets>, <ets>discubitum</ets>, to lie down, recline at
table; <ets>dis-</ets> + <ets>cumbere</ets> (in comp.) to lie
down.]</ety> <def>Leaning; fitted for a reclining posture.</def>
<mark>[Obs.]</mark> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disculpate</ent><br/
<hw>Dis*cul"pate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Disculpated</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Disculpating</conjf>.]</vmorph> <ety>[LL. <ets>disculpatus</ets>,
p. p. of <ets>disculpare</ets> to disculpate; <ets>dis-</ets> + L.
<ets>culpare</ets> to blame, <ets>culpa</ets> fault.]</ety> <def>To free
from blame or the imputation of a fault; to exculpate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I almost fear you think I begged it, but I can
<qex>disculpate</qex> myself.</q> <rj><qau>Walpole.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disculpation</ent><br/
<hw>Dis`cul*pa"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>disculpation</ets>.]</ety> <def>Exculpation.</def>
<rj><au>Burke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disculpatory</ent><br/
<hw>Dis*cul"pa*to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Tending to
exculpate; exculpatory.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discumbency</ent><br/
<hw>Dis*cum"ben*cy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From L.
<ets>discumbens</ets>, p. pr. of <ets>discumbere</ets>. See
<er>Discubitory</er>.]</ety> <def>The act of reclining at table
according to the manner of the ancients at their meals.</def>
<rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discumber</ent><br/
<hw>Dis*cum"ber</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>dis-</ets> + <ets>cumber</ets>: cf. OF.
<ets>descombrer</ets>.]</ety> <def>To free from that which cumbers or
impedes; to disencumber.</def> <mark>[Archaic]</mark>
<rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discure</ent><br/
<hw>Dis*cure"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[See
<er>Discover</er>.]</ety> <def>To discover; to reveal; to
discoure.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I will, if please you it <qex>discure</qex>, assay<br/
To ease you of that ill, so wisely as I may.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discurrent</ent><br/
<hw>Dis*cur"rent</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Not current or
free to circulate; not in use.</def> <mark>[Obs.]</mark> <rj><au>Sir E.
Sandys.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discursion</ent><br/
<hw>Dis*cur"sion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL.
<ets>discursio</ets> a running different ways. See
<er>Discourse</er>.]</ety> <def>The act of discoursing or reasoning;
range, as from thought to thought.</def>
<rj><au>Coleridge.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discursist</ent><br/
<hw>Dis*cur"sist</hw>, <pos>n.</pos> <def>A discourser.</def>
<mark>[Obs.]</mark> <rj><au>L. Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discursive</ent><br/
<hw>Dis*cur"sive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>discursif</ets>. See <er>Discourse</er>, and cf.
<er>Discoursive</er>.]</ety> <sn>1.</sn> <def>Passing from one thing to
another; ranging over a wide field; roving; digressive; desultory.</def>
<ldquo/<xex>Discursive</xex> notices.<rdquo/ <rj><au>De
Quincey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The power he [Shakespeare] delights to show is not intense, but
<qex>discursive</qex>.</q> <rj><qau>Hazlitt.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A man rather tacit than <qex>discursive</qex>.</q>
<rj><qau>Carlyle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Reasoning; proceeding from one ground to another, as
in reasoning; argumentative.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Reason is her being,<br/
<qex>Discursive</qex> or intuitive.</q> <rj><qau>Milton.</qau></rj></p>

<p>-- <wordforms><wf>Dis*cur"sive*ly</wf>, <pos>adv.</pos> --
<wf>Dis*cur"sive*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discursory</ent><br/
<hw>Dis*cur`so*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Argumentative;
discursive; reasoning.</def> <mark>[R.]</mark> <rj><au>Bp.
Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discursus</ent><br/
<hw>Dis*cur"sus</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.]</ety>
<fld>(Logic)</fld> <def>Argumentation; ratiocination; discursive
reasoning.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discus</ent><br/
<hw>Dis"cus</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it> E.
<plw>Discuses</plw> <pr>(#)</pr>, L. <plw>Disci</plw>
<pr>(#)</pr>.</plu> <ety>[L. See <er>Disk</er>.]</ety> <sn>1.</sn>
<sd>(a)</sd> <def>A quoit; a circular plate of some heavy material
intended to be pitched or hurled as a trial of strength and skill.</def>
<sd>(b)</sd> <def>The exercise with the discus.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ This among the Greeks was one of the chief gymnastic
exercises and was included in the Pentathlon (the contest of the five
exercises). The chief contest was that of throwing the discus to the
greatest possible distance.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A disk. See <er>Disk</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discuss</ent><br/
<hw>Dis*cuss"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Discussed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Discussing</conjf>.]</vmorph> <ety>[L.
<ets>discussus</ets>, p. p. of <ets>discutere</ets> to strike asunder
(hence came the sense <ets>to separate mentally</ets>,
<ets>distinguish</ets>); <ets>dis-</ets> + <ets>quatere</ets> to shake,
strike. See <er>Quash</er>.]</ety> <sn>1.</sn> <def>To break to pieces;
to shatter.</def> <mark>[Obs.]</mark> <rj><au>Sir T.
Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To break up; to disperse; to scatter; to dissipate;
to drive away; -- said especially of tumors.</def>
<mark>[archaic]</mark> <note>This usage is preserved only in the word
<er>discussive</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><q>Many arts were used to <qex>discuss</qex> the beginnings of new
affection.</q> <rj><qau>Sir H. Wotton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A pomade . . . of virtue to <qex>discuss</qex> pimples.</q>
<rj><qau>Rambler.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To shake; to put away; to finish.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>All regard of shame she had <qex>discussed</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To examine in detail or by disputation; to reason
upon by presenting favorable and adverse considerations; to debate; to
sift; to investigate; to ventilate.</def> <ldquo/We sat and . . .
<xex>discussed</xex> the farm . . . and the price of grain.<rdquo/
<au>Tennyson.</au> <ldquo/To <xex>discuss</xex> questions of
taste.<rdquo/ <rj><au>Macaulay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To deal with, in eating or drinking.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>We sat quietly down and <qex>discussed</qex> a cold fowl that we
had brought with us.</q> <rj><qau>Sir S. Baker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Law)</fld> <def>To examine or search thoroughly; to
exhaust a remedy against, as against a principal debtor before
proceeding against the surety.</def> <rj><au>Burrill.</au></rj></p>

<p><syn><b>Syn.</b> -- To <er>Discuss</er>, <er>Examine</er>,
<er>Debate</er>. We speak of <xex>examining</xex> a subject when we
ponder it with care, in order to discover its real state, or the truth
respecting it. We speak of <xex>discussing</xex> a topic when we examine
it thoroughly in its distinct parts. The word is very commonly applied
to matters of opinion. We may <xex>discuss</xex> a subject without
giving in an adhesion to any conclusion. We speak of <xex>debating</xex>
a point when we examine it in mutual argumentation between opposing
parties. In <xex>debate</xex> we contend for or against some conclusion
or view.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>discussant</ent><br/
<hw>discussant</hw> <pos>n.</pos> <def>a participant in a discussion,
especially a member of a panel.</def><br/
<syn><b>Syn. --</b> panelist.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Discusser</ent><br/
<hw>Dis*cuss"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who discusses;
one who sifts or examines.</def> <rj><au>Wood.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discussion</ent><br/
<hw>Dis*cus"sion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>discussio</ets> a shaking, examination, discussion: cf. F.
<ets>discussion</ets>.]</ety> <sn>1.</sn> <def>The act or process of
discussing by breaking up, or dispersing, as a tumor, or the like.</def>
<mark>[archaic]</mark> <br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The act of discussing or exchanging reasons;
examination by argument; debate; disputation; agitation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The liberty of <qex>discussion</qex> is the great safeguard of all
other liberties.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Discussion of a problem</b></col> <it>or</it>
<col><b>Discussion of an equation</b></col></mcol> <fld>(Math.)</fld>,
<cd>the operation of assigning different reasonable values to the
arbitrary quantities and interpreting the result.</cd> <rj><au>Math.
Dict.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discussional</ent><br/
<hw>Dis*cus"sion*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to
discussion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>discussive</ent><br/
<hw>dis*cuss"ive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>discussif</ets>.]</ety> <sn>1.</sn> <fld>(Med.)</fld> <def>Able or
tending to discuss or disperse tumors or coagulated matter;
discutient.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Doubt-dispelling; decisive.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>A kind of peremptory and <qex>discussive</qex> voice.</q>
<rj><qau>Hopkins.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discussive</ent><br/
<hw>Dis*cuss"ive</hw>, <pos>n.</pos> <fld>(Med.)</fld> <def>A medicine
that discusses or disperses morbid humors; a discutient.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Discutient</ent><br/
<hw>Dis*cu"tient</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>discutiens</ets>, p. pr. of <ets>discutere</ets>. See
<er>Discuss</er>.]</ety> <fld>(Med.)</fld> <def>Serving to disperse
morbid matter; discussive; <as>as, a <ex>discutient</ex>
application</as>.</def> -- <def2><pos>n.</pos> <def>An agent (as a
medicinal application) which serves to disperse morbid matter.</def>
<ldquo/Foment with <xex>discutiens</xex>.<rdquo/</def2>
<rj><au>Wiseman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disdain</ent><br/
<hw>Dis*dain"</hw> <pr>(?; 277)</pr>, <pos>n.</pos> <ety>[OE.
<ets>desdain</ets>, <ets>disdein</ets>, OF. <ets>desdein</ets>,
<ets>desdaing</ets>, F. <ets>d<eacute/dain</ets>, fr. the verb. See
<er>Disdain</er>, <pos>v. t.</pos>]</ety> <sn>1.</sn> <def>A feeling of
contempt and aversion; the regarding anything as unworthy of or beneath
one; scorn.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>How my soul is moved with just <qex>disdain</qex>!</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note>Often implying an idea of haughtiness.</note><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Disdain</qex> and scorn ride sparkling in her eyes.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is worthy to be disdained or regarded
with contempt and aversion.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Most loathsome, filthy, foul, and full of vile
<qex>disdain</qex>.</q> <rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The state of being despised; shame.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj></p>

<p><syn><b>Syn.</b> -- Haughtiness; scorn; contempt; arrogance; pride.
See <er>Haughtiness</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disdain</ent><br/
<hw>Dis*dain"</hw> <pr>(?; 277)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Disdained</conjf> <pr>(?)</pr>;
<pos>p. pr. & vb. n.</pos> <conjf>Disdaining</conjf>.]</vmorph>
<ety>[OE. <ets>disdainen</ets>, <ets>desdainen</ets>, OF.
<ets>desdeigner</ets>, <ets>desdaigner</ets>, F.
<ets>d<eacute/daigner</ets>; <ets>des-</ets> (L. <ets>dis-</ets>) +
<ets>daigner</ets> to deign, fr. L. <ets>dignari</ets> to deem worthy.
See <er>Deign</er>.]</ety> <sn>1.</sn> <def>To think unworthy; to deem
unsuitable or unbecoming; <as>as, to <ex>disdain</ex> to do a mean
act</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Disdaining</qex> . . . that any should bear the armor of the
best knight living.</q> <rj><qau>Sir P. Sidney.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To reject as unworthy of one's self, or as not
deserving one's notice; to look with scorn upon; to scorn, as base acts,
character, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>When the Philistine . . . saw David, he <qex>disdained</qex> him;
for he was but a youth.</q> <rj><qau>1 Sam. xvii. 42.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>'T is great, 't is manly to <qex>disdain</qex> disguise.</q>
<rj><qau>Young.</qau></rj></p>

<p><syn><b>Syn.</b> -- To contemn; despise; scorn. See
<er>Contemn</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disdain</ent><br/
<hw>Dis*dain"</hw>, <pos>v. i.</pos> <def>To be filled with scorn; to
feel contemptuous anger; to be haughty.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And when the chief priests and scribes saw the marvels that he did
. . . they <qex>disdained</qex>.</q> <rj><qau>Genevan Testament (Matt.
xxi. 15).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disdained</ent><br/
<hw>Dis*dained"</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Disdainful.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Revenge the jeering and <qex>disdained</qex> contempt<br/
Of this proud king.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disdainful</ent><br/
<hw>Dis*dain"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Full of disdain;
expressing disdain; scornful; contemptuous; haughty.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>From these<br/
Turning <qex>disdainful</qex> to an equal good.</q>
<rj><qau>Akenside.</qau></rj></p>

<p>-- <wordforms><wf>Dis*dain"ful*ly</wf>, <pos>adv.</pos> --
<wf>Dis*dain"ful*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disdainishly</ent><br/
<hw>Dis*dain"ish*ly</hw>, <pos>adv.</pos> <def>Disdainfully.</def>
<mark>[Obs.]</mark> <rj><au>Vives.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disdainous</ent><br/
<hw>Dis*dain"ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OF.
<ets>desdeignos</ets>, <ets>desdaigneux</ets>, F.
<ets>d<eacute/daigneux</ets>.]</ety> <def>Disdainful.</def>
<mark>[Obs.]</mark> <rj><au>Rom. of R.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disdainously</ent><br/
<hw>Dis*dain"ous*ly</hw>, <pos>adv.</pos> <def>Disdainfully.</def>
<mark>[Obs.]</mark> <rj><au>Bale.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disdeify</ent><br/
<hw>Dis*de"i*fy</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To divest or
deprive of deity or of a deific rank or condition.</def>
<rj><au>Feltham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disdeign</ent><br/
<hw>Dis*deign"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To
disdain.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Guyon much <qex>disdeigned</qex> so loathly sight.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disdiaclast</ent><br/
<hw>Dis*di"a*clast</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>di`s-</grk> twice + <grk>diakla^n</grk> to break in twain;
<grk>dia`</grk> through + <grk>kla^n</grk> to break.]</ety>
<fld>(Physiol.)</fld> <def>One of the dark particles forming the doubly
refracting disks of muscle fibers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disdiapason</ent><br/
<hw>Dis*di`a*pa"son</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>dis-</ets> (Gr. <?/) + <ets>diapason</ets>.]</ety> <fld>(Anc.
Mus.)</fld> <def>An interval of two octaves, or a fifteenth; -- called
also <altname>bisdiapason</altname>. Compare
<er>diapason{1}</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disease</ent><br/
<hw>Dis*ease"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>disese</ets>, OF. <ets>desaise</ets>; <ets>des-</ets> (L.
<ets>dis-</ets>) + <ets>aise</ets> ease. See <er>Ease</er>.]</ety>
<sn>1.</sn> <def>Lack of ease; uneasiness; trouble; vexation;
disquiet.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>So all that night they passed in great <qex>disease</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To shield thee from <qex>diseases</qex> of the world.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An alteration in the state of the body or of some of
its organs, interrupting or disturbing the performance of the vital
functions, and causing or threatening pain and weakness; malady;
affection; illness; sickness; disorder; -- applied figuratively to the
mind, to the moral character and habits, to institutions, the state,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Diseases</qex> desperate grown,<br/
By desperate appliances are relieved.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The instability, injustice, and confusion introduced into the
public counsels have, in truth, been the mortal <qex>diseases</qex>
under which popular governments have every where perished.</q>
<rj><qau>Madison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Disease germ</b></col>. <cd>See under
<er>Germ</er>.</cd></cs></p>

<p><syn><b>Syn.</b> -- Distemper; ailing; ailment; malady; disorder;
sickness; illness; complaint; indisposition; affection. --
<er>Disease</er>, <er>Disorder</er>, <er>Distemper</er>,
<er>Malady</er>, <er>Affection</er>. <xex>Disease</xex> is the leading
medical term. <xex>Disorder</xex> mean<?/ much the same, with perhaps
some slight reference to an <xex>irregularity</xex> of the system.
<xex>Distemper</xex> is now used by physicians only of the diseases of
animals. <xex>Malady</xex> is not a medical term, and is less used than
formerly in literature. <xex>Affection</xex> has special reference to
the part, organ, or function disturbed; <as>as, his <ex>disease</ex> is
an <ex>affection</ex> of the lungs</as>. A <xex>disease</xex> is usually
deep-seated and permanent, or at least prolonged; a <xex>disorder</xex>
is often slight, partial, and temporary; <xex>malady</xex> has less of a
technical sense than the other terms, and refers more especially to the
suffering endured. In a figurative sense we speak of a
<xex>disease</xex> mind, of <xex>disordered</xex> faculties, and of
mental <xex>maladies</xex>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disease</ent><br/
<hw>Dis*ease"</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Diseased</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Diseasing</conjf>.]</vmorph> <sn>1.</sn> <def>To deprive of ease;
to disquiet; to trouble; to distress.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>His double burden did him sore <qex>disease</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To derange the vital functions of; to afflict with
disease or sickness; to disorder; -- used almost exclusively in the
participle <xex>diseased</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He was <qex>diseased</qex> in body and mind.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diseased</ent><br/
<hw>Dis*eased"</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Afflicted with
disease.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It is my own <qex>diseased</qex> imagination that torments me.</q>
<rj><qau>W. Irving.</qau></rj></p>

<p><syn><b>Syn.</b> -- See <er>Morbid</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diseasedness</ent><br/
<hw>Dis*eas"ed*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state of
being diseased; a morbid state; sickness.</def> <mark>[R.]</mark>
<rj><au>T. Burnet.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diseaseful</ent><br/
<hw>Dis*ease"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Causing uneasiness.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Disgraceful to the king and <qex>diseaseful</qex> to the
people.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Abounding with disease; producing diseases; <as>as,
a <ex>diseaseful</ex> climate</as>.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diseasefulness</ent><br/
<hw>Dis*ease"ful*ness</hw>, <pos>n.</pos> <def>The quality of being
diseaseful; trouble; trial.</def> <mark>[R.]</mark> <rj><au>Sir P.
Sidney.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diseasement</ent><br/
<hw>Dis*ease"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Uneasiness;
inconvenience.</def> <mark>[Obs.]</mark> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disedge</ent><br/
<hw>Dis*edge"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To deprive of an
edge; to blunt; to dull.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Served a little to <qex>disedge</qex><br/
The sharpness of that pain about her heart.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disedify</ent><br/
<hw>Dis*ed"i*fy</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To fail of
edifying; to injure.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diselder</ent><br/
<hw>Dis*eld"er</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To deprive of an
elder or elders, or of the office of an elder.</def> <mark>[Obs.]</mark>
<rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diselenide</ent><br/
<hw>Di*sel"e*nide</hw> <pr>(?; 104)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>di-</ets> + <ets>selenide</ets>.]</ety> <fld>(Chem.)</fld> <def>A
selenide containing two atoms of selenium in each molecule.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disembark</ent><br/
<hw>Dis`em*bark"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Disembarked</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Disembarking</conjf>.]</vmorph> <ety>[Pref.
<ets>dis-</ets> + <ets>embark</ets>: cf. F.
<ets>d<eacute/sembarquer</ets>.]</ety> <def>To remove from on board a
vessel; to put on shore; to land; to debark; <as>as, the general
<ex>disembarked</ex> the troops</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 424 --></p>

<p><q>Go to the bay, and <qex>disembark</qex> my coffers.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disembark</ent><br/
<hw>Dis`em*bark"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To go ashore
out of a ship or boat; to leave a ship; to debark.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And, making fast their moorings, <qex>disembarked</qex>.</q>
<rj><qau>Cowper.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disembarkation</ent><br/
<hw>Dis*em`bar*ka"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
disembarking.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disembarkment</ent><br/
<hw>Dis`em*bark"ment</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Disembarkation.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disembarrass</ent><br/
<hw>Dis`em*bar"rass</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Disembarrassed</conjf>
<pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Disembarrassing</conjf>.]</vmorph> <ety>[Pref. <ets>dis-</ets> +
<ets>embarrass</ets>: cf. F. <ets>d<eacute/sembarasser</ets>.]</ety>
<def>To free from embarrassment, or perplexity; to clear; to
extricate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>disembarrass</qex> himself of his companion.</q>
<rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disembarrassment</ent><br/
<hw>Dis`em*bar"rass*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Freedom
or relief from impediment or perplexity.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disembay</ent><br/
<hw>Dis`em*bay"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Disembayed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Disembaying</conjf>.]</vmorph> <ety>[Pref.
<ets>dis-</ets> + <ets>embay</ets>.]</ety> <def>To clear from a
bay.</def> <rj><au>Sherburne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disembellish</ent><br/
<hw>Dis`em*bel"lish</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>dis-</ets> + <ets>embellish</ets>: cf. F.
<ets>d<eacute/sembellir</ets>.]</ety> <def>To deprive of embellishment;
to disadorn.</def> <rj><au>Carlyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disembitter</ent><br/
<hw>Dis`em*bit"ter</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To free
from</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disembodied</ent><br/
<hw>Dis`em*bod"ied</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Divested of a
body; ceased to be corporal; incorporeal.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>disembodied</qex> spirits of the dead.</q>
<rj><qau>Bryant.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disembodiment</ent><br/
<hw>Dis`em*bod"i*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
disembodying, or the state of being disembodied.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disembody</ent><br/
<hw>Dis`em*bod"y</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Disembodied</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Disembodying</conjf>.]</vmorph> <sn>1.</sn> <def>To
divest of the body or corporeal existence.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Devils embodied and <qex>disembodied</qex>.</q> <rj><qau>Sir W.
Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mil.)</fld> <def>To disarm and disband, as a body
of soldiers.</def> <rj><au>Wilhelm.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disembogue</ent><br/
<hw>Dis`em*bogue"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Disembogued</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Disemboguing</conjf>.]</vmorph> <ety>[Sp.
<ets>desembocar</ets>; pref. <ets>des-</ets> (L. <ets>dis-</ets>) +
<ets>embocar</ets> to put into the mouth, fr. <ets>en</ets> (L.
<ets>in</ets>) + <ets>boca</ets> mouth, fr. L. <ets>bucca</ets> cheek.
Cf. <er>Debouch</er>, <er>Embogue</er>.]</ety> <sn>1.</sn> <def>To pour
out or discharge at the mouth, as a stream; to vent; to discharge into
an ocean, a lake, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Rolling down, the steep Timavus raves,<br/
And through nine channels <qex>disembogues</qex> his waves.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To eject; to cast forth.</def> <mark>[R.]</mark>
<rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disembogue</ent><br/
<hw>Dis`em*bogue"</hw>, <pos>v. i.</pos> <def>To become discharged; to
flow out; to find vent; to pour out contents.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Volcanos bellow ere they <qex>disembogue</qex>.</q>
<rj><qau>Young.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disemboguement</ent><br/
<hw>Dis`em*bogue"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
disemboguing; discharge.</def> <rj><au>Mease.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disembossom</ent><br/
<hw>Dis`em*bos"som</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To separate
from the bosom.</def> <mark>[R.]</mark> <rj><au>Young.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disembowel</ent><br/
<hw>Dis`em*bow"el</hw> <pr>(d<icr/s`<ecr/m*bou"<ecr/l)</pr>, <pos>v.
t.</pos> <ety>[See <er>Embowel</er>.]</ety> <sn>1.</sn> <def>To take or
let out the bowels or interior parts of; to eviscerate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Soon after their death, they are <qex>disemboweled</qex>.</q>
<rj><qau>Cook.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Roaring floods and cataracts that sweep<br/
From <qex>disemboweled</qex> earth the virgin gold.</q>
<rj><qau>Thomson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To take or draw from the body, as the web of a
spider.</def> <mark>[R.]</mark> <ldquo/Her <xex>disemboweled</xex>
web.<rdquo/ <rj><au>J. Philips.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disembowelment</ent><br/
<hw>Dis`em*bow"el*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
disemboweling, or state of being disemboweled; evisceration.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disembowered</ent><br/
<hw>Dis`em*bow"ered</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Deprived of,
or removed from, a bower.</def> <mark>[Poetic]</mark>
<rj><au>Bryant.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disembrangle</ent><br/
<hw>Dis`em*bran"gle</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>dis-</ets> + <ets>em</ets> = <ets>en</ets> (L. <ets>in</ets>) +
<ets>brangle</ets>.]</ety> <def>To free from wrangling or
litigation.</def> <mark>[Obs.]</mark> <rj><au>Berkeley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disembroil</ent><br/
<hw>Dis`em*broil"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Disembroiled</conjf> <pr>(?)</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>Disembroiling</conjf>.]</vmorph> <ety>[Pref.
<ets>dis-</ets> + <ets>embroil</ets>.]</ety> <def>To disentangle; to
free from perplexity; to extricate from confusion.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Vaillant has <qex>disembroiled</qex> a history that was lost to
the world before his time.</q> <rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disemploy</ent><br/
<hw>Dis`em*ploy"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To throw out
of employment.</def> <mark>[Obs.]</mark> <rj><au>Jer.
Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disemployment</ent><br/
<hw>Dis`em*ploy"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state of
being disemployed, or deprived of employment.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This glut of leisure and <qex>disemployment</qex>.</q>
<rj><qau>Jer. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disempower</ent><br/
<hw>Dis`em*pow"er</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To deprive of
power; to divest of strength.</def> <rj><au>H. Bushnell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disenable</ent><br/
<hw>Dis`en*a"ble</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>dis-</ets> + <ets>enable</ets>.]</ety> <def>To disable; to
disqualify.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The sight of it might damp me and <qex>disenable</qex> me to
speak.</q> <rj><qau>State Trials (1640).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disenamor</ent><br/
<hw>Dis`en*am"or</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To free from
the captivity of love.</def> <rj><au>Shelton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disenchained</ent><br/
<hw>Dis`en*chained"</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Freed from
restraint; unrestrained.</def> <mark>[Archaic]</mark> <rj><au>E. A.
Poe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disenchant</ent><br/
<hw>Dis`en*chant"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Disenchanted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Disenchanting</conjf>.]</vmorph> <ety>[Pref. <ets>dis-</ets> +
<ets>enchant</ets>: cf. F. <ets>d<eacute/senchanter</ets>.]</ety>
<sn>1.</sn> <def>To free from enchantment; to deliver from the power of
charms or spells.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Haste to thy work; a noble stroke or two<br/
Ends all the charms, and <qex>disenchants</qex> the grove.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>to free (a person) from fascination or delusion; to
destroy the false hopes or overoptimistic expectations of (a person); to
disillusion; -- used with people or events as the agent (subject);
<as>as, the candidate was <ex>disenchanted</ex> by the low turnout at
the rally</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Disenchanter</ent><br/
<hw>Dis`en*chant"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or
that which, disenchants.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>disenchanting</ent><br/
<hw>disenchanting</hw> <pos>adj.</pos> <def>freeing from illusion,
credulity, overoptimism, or false belief.</def><br/
<syn><b>Syn. --</b> disillusioning.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Disenchantment</ent><br/
<hw>Dis`en*chant"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>dis-</ets> + <ets>enchantment</ets>: cf. F.
<ets>d<eacute/senchantement</ets>.]</ety> <def>The act of disenchanting,
or state of being disenchanted.</def> <rj><au>Shelton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disencharm</ent><br/
<hw>Dis`en*charm"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>dis-</ets> + <ets>en</ets> (L. <ets>in</ets>) +
<ets>charm</ets>.]</ety> <def>To free from the influence of a charm or
spell; to disenchant.</def> <mark>[R.]</mark> <rj><au>Jer.
Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disenclose</ent><br/
<hw>Dis`en*close</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>See
<er>Disinclose</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disencouragement</ent><br/
<hw>Dis`en*cour"age*ment</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Discouragement.</def> <mark>[Obs.]</mark>
<rj><au>Spectator.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disencrese</ent><br/
<hw>Dis`en*crese"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[Pref.
<ets>dis-</ets> + OE. <ets>encrese</ets>, E. <ets>increase</ets>.]</ety>
<def>To decrease.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disencrese</ent><br/
<hw>Dis`en*crese"</hw>, <pos>n.</pos> <def>Decrease.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disencumber</ent><br/
<hw>Dis`en*cum"ber</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Disencumbered</conjf>
<pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Disencumbering</conjf>.]</vmorph> <ety>[Pref. <ets>dis-</ets> +
<ets>encumber</ets>: cf. F. <ets>d<eacute/sencombrer</ets>.]</ety>
<def>To free from encumbrance, or from anything which clogs, impedes, or
obstructs; to disburden.</def> <rj><au>Owen.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I have <qex>disencumbered</qex> myself from rhyme.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disencumbrance</ent><br/
<hw>Dis`en*cum"brance</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Freedom or
deliverance from encumbrance, or anything burdensome or
troublesome.</def> <rj><au>Spectator.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disendow</ent><br/
<hw>Dis`en*dow"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To deprive of
an endowment, as a church.</def> <rj><au>Gladstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disendowment</ent><br/
<hw>Dis`en*dow"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
depriving of an endowment or endowments.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>[The] <qex>disendowment</qex> of the Irish Church.</q> <rj><qau>G.
B. Smith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disenfranchise</ent><br/
<hw>Dis`en*fran"chise</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To
disfranchise; to deprive of the rights of a citizen.</def> --
<wordforms><wf>Dis`en*fran"chise*ment</wf> <pr>(#)</pr>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>disenfranchised</ent><br/
<hw>disenfranchised</hw> <pos>adj.</pos> <def>deprived of the rights of
citizenship, especially the right to vote. Opposite of
<ant>enfranchised</ant>.</def><br/
<syn><b>Syn. --</b> disfranchised, voteless.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Disengage</ent><br/
<hw>Dis`en*gage"</hw> <pr>(<?/)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Disengaged</conjf> <pr>(#)</pr>;
<pos>p. pr. & vb. n.</pos> <conjf>Disengaging</conjf>.]</vmorph>
<ety>[Pref. <ets>dis-</ets> + <ets>engage</ets>: cf. F.
<ets>d<eacute/sengager</ets>.]</ety> <def>To release from that with
which anything is engaged, engrossed, involved, or entangled; to
extricate; to detach; to set free; to liberate; to clear; <as>as, to
<ex>disengage</ex> one from a party, from broils and controversies, from
an oath, promise, or occupation; to <ex>disengage</ex> the affections a
favorite pursuit, the mind from study.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>disengage</qex> him and the kingdom, great sums were to be
borrowed.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Caloric and light must be <qex>disengaged</qex> during the
process.</q> <rj><qau>Transl. of Lavoisier.</qau></rj></p>

<p><syn><b>Syn.</b> -- To liberate; free; loose; extricate; clear;
disentangle; detach; withdraw; wean.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disengage</ent><br/
<hw>Dis`en*gage"</hw>, <pos>v. i.</pos> <def>To release one's self; to
become detached; to free one's self.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>From a friends's grave how soon we <qex>disengage</qex>!</q>
<rj><qau>Young.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disengaged</ent><br/
<hw>Dis`en*gaged"</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Not engaged;
free from engagement; at leisure; free from occupation or care;
vacant.</def> -- <wordforms><wf>Dis`en*ga"ged*ness</wf> <pr>(#)</pr>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disengagement</ent><br/
<hw>Dis`en*gage"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>dis-</ets> + <ets>engagement</ets>: cf. F.
<ets>d<eacute/sengagement</ets>.]</ety> <sn>1.</sn> <def>The act of
disengaging or setting free, or the state of being disengaged.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It is easy to render this <qex>disengagement</qex> of caloric and
light evident to the senses.</q> <rj><qau>Transl. of
Lavoisier.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>disengagement</qex> from earthly trammels.</q> <rj><qau>Sir
W. Jones.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Freedom from engrossing occupation;
leisure.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Disengagement</qex> is absolutely necessary to enjoyment.</q>
<rj><qau>Bp. Butler.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disengaging</ent><br/
<hw>Dis`en*ga"ging</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Loosing;
setting free; detaching.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Disengaging machinery</b></col>. <cd>See under
<er>Engaging</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disennoble</ent><br/
<hw>Dis`en*no"ble</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To deprive of
that which ennobles; to degrade.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>An unworthy behavior degrades and <qex>disennobles</qex> a
man.</q> <rj><qau>Guardian.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disenroll</ent><br/
<hw>Dis`en*roll"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Disenrolled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Disenrolling</conjf>.]</vmorph> <def>To erase from a
roll or list.</def> <altsp>[Written also <asp>disenrol</asp>.]</altsp>
<rj><au>Donne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disensanity</ent><br/
<hw>Dis`en*san"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>dis-</ets> + <ets>en</ets> (L. <ets>in</ets>) +
<ets>sanity</ets>.]</ety> <def>Insanity; folly.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>What tediosity and <qex>disensanity</qex><br/
Is here among!</q> <rj><qau>Beau. & Fl.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disenshrouded</ent><br/
<hw>Dis`en*shroud"ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Freed from a
shroudlike covering; unveiled.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>disenshrouded</qex> statue.</q> <rj><qau>R.
Browning.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disenslave</ent><br/
<hw>Dis`en*slave"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To free from
bondage or slavery; to disenthrall.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He shall <qex>disenslave</qex> and redeem his soul.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disentail</ent><br/
<hw>Dis`en*tail"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <fld>(Law)</fld>
<def>To free from entailment.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>disentangle</ent><br/
<hw>dis`en*tan"gle</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Disentangled</conjf>
<pr>(?)</pr>; <pos>p. pr. & vb. n.</pos> <conjf>Disentangling</conjf>
<pr>(?)</pr>.]</vmorph> <sn>1.</sn> <def>To free from entanglement; to
release from a condition of being intricately and confusedly involved or
interlaced; to reduce to orderly arrangement; to straighten out; <as>as,
to <ex>disentangle</ex> a skein of yarn</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To extricate from complication and perplexity;
disengage from embarrassing connection or intermixture; to disembroil;
to set free; to separate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>disentangle</qex> truth from error.</q>
<rj><qau>Stewart.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To extricate and <qex>disentangle</qex> themselves out of this
labyrinth.</q> <rj><qau>Clarendon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A mind free and <qex>disentangled</qex> from all corporeal
mixtures.</q> <rj><qau>Bp. Stillingfleet.</qau></rj></p>

<p><syn><b>Syn.</b> -- To loose; extricate; disembarrass; disembroil;
clear; evolve; disengage; separate; detach.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>disentangled</ent><br/
<hw>disentangled</hw> <pos>adj.</pos> <sn>1.</sn> <def>freed from an
entanglement; -- of people or agents.</def><br/
<syn><b>Syn. --</b> extricated, freed.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>straightened out.</def><br/
<syn><b>Syn. --</b> loosened, unsnarled.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Disentanglement</ent><br/
<hw>Dis`en*tan"gle*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
disentangling or clearing from difficulties.</def>
<rj><au>Warton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disenter</ent><br/
<hw>Dis`en*ter"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>See
<er>Disinter</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disenthrall</ent><br/
<hw>Dis`en*thrall"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[See
<er>Enthrall</er>.]</ety> <def>To release from thralldom or slavery; to
give freedom to; to disinthrall.</def> <altsp>[Written also
<asp>disenthral</asp>.]</altsp> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disenthrallment</ent><br/
<hw>Dis`en*thrall"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Liberation
from bondage; emancipation; disinthrallment.</def> <altsp>[Written also
<asp>disenthralment</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disenthrone</ent><br/
<hw>Dis`en*throne"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To dethrone;
to depose from sovereign authority.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disentitle</ent><br/
<hw>Dis`en*ti"tle</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To deprive of
title or claim.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Every ordinary offense does not <qex>disentitle</qex> a son to the
love of his father.</q> <rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disentomb</ent><br/
<hw>Dis`en*tomb"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To take out
from a tomb; a disinter.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disentrail</ent><br/
<hw>Dis`en*trail"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To
disembowel; to let out or draw forth, as the entrails.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>As if he thought her soul to <qex>disentrail</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disentrance</ent><br/
<hw>Dis`en*trance"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To awaken
from a trance or an enchantment.</def> <rj><au>Hudibras.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disentwine</ent><br/
<hw>Dis`en*twine"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To free from
being entwined or twisted.</def> <rj><au>Shelley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disepalous</ent><br/
<hw>Di*sep"al*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>di-</ets> + <ets>sepalous</ets>.]</ety> <fld>(Bot.)</fld>
<def>Having two sepals; two-sepaled.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disert</ent><br/
<hw>Dis*ert"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>disertus</ets>, for <ets>dissertus</ets>, p. p.: cf. F.
<ets>disert</ets>. See <er>Dissert</er>.]</ety> <def>Eloquent.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disertitude</ent><br/
<hw>Dis*er"ti*tude</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>disertitud</ets><?/.]</ety> <def>Eloquence.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diserty</ent><br/
<hw>Dis*ert"y</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>Expressly;
clearly; eloquently.</def> <mark>[Obs.]</mark>
<rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disespouse</ent><br/
<hw>Dis`es*pouse"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To release
from espousal or plighted faith.</def> <mark>[Poetic]</mark>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disestablish</ent><br/
<hw>Dis`es*tab"lish</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To
unsettle; to break up (anything established); to deprive, as a church,
of its connection with the state.</def> <rj><au>M. Arnold.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disestablishment</ent><br/
<hw>Dis`es*tab"lish*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>The act or process of unsettling or breaking up that which has been
established; specifically, the withdrawal of the support of the state
from an established church; <as>as, the <ex>disestablishment</ex> and
disendowment of the Irish Church by Act of Parliament</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The condition of being disestablished.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>disestablishmentarianism</ent><br/
<hw>dis`es*tab`lish*men*ta"ri*an*ism</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>The doctrine or political position that advocates abrogating the
establishment of a church as the official state religion.</def>.<br/
[<source>PJC</source>]</p>

<p><q>Prior to the Puritans, very few earlier believers contended for
any form of <qex>disestablishmentarianism</qex>.</q> <rj><qau>David. W.
Hall (Savior or Servant? Putting Government in Its Place: The Covenant
Foundation, 1996)</qau></rj></p>

<p><ent>Disesteem</ent><br/
<hw>Dis`es*teem"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Want of esteem;
low estimation, inclining to dislike; disfavor; disrepute.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Disesteem</qex> and contempt of the public affairs.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disesteem</ent><br/
<hw>Dis`es*teem"</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Disesteemed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Disesteeming</conjf>.]</vmorph> <sn>1.</sn> <def>To feel an
absence of esteem for; to regard with disfavor or slight contempt; to
slight.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>But if this sacred gift you <qex>disesteem</qex>.</q>
<rj><qau>Denham.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Qualities which society does not <qex>disesteem</qex>.</q>
<rj><qau>Ld. Lytton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To deprive of esteem; to bring into disrepute; to
cause to be regarded with disfavor.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>What fables have you vexed, what truth redeemed,<br/
Antiquities searched, opinions <qex>disesteemed</qex>?</q> <rj><qau>B.
Jonson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disesteemer</ent><br/
<hw>Dis`es*teem"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
disesteems.</def> <rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disestimation</ent><br/
<hw>Dis*es`ti*ma"tion</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Disesteem.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disexercise</ent><br/
<hw>Dis*ex"er*cise</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To deprive
of exercise; to leave untrained.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>By <qex>disexercising</qex> and blunting our abilities.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disfame</ent><br/
<hw>Dis*fame"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Disrepute.</def>
<mark>[R.]</mark> <rj><au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disfancy</ent><br/
<hw>Dis*fan"cy</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To
dislike.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disfashion</ent><br/
<hw>Dis*fash"ion</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>dis-</ets> + <ets>fashion</ets>. See <er>Fashion</er>, and cf.
<er>Defeat</er>.]</ety> <def>To disfigure.</def> <mark>[Obs.]</mark>
<rj><au>Sir T. More.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disfavor</ent><br/
<hw>Dis*fa"vor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>dis-</ets> + <ets>favor</ets>: cf. OF. <ets>disfaveur</ets>, F.
<ets>d<eacute/faveur</ets>.]</ety> <altsp>[Written also
<asp>disfavour</asp>.]</altsp> <sn>1.</sn> <def>Want of favor of
favorable regard; disesteem; disregard.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The people that deserved my <qex>disfavor</qex>.</q> <rj><qau>Is.
x. 6 (1551).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Sentiment of <qex>disfavor</qex> against its ally.</q>
<rj><qau>Gladstone.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The state of not being in favor; a being under the
displeasure of some one; state of unacceptableness; <as>as, to be in
<ex>disfavor</ex> at court</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>An unkindness; a disobliging act.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He might dispense favors and <qex>disfavors</qex>.</q>
<rj><qau>Clarendon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disfavor</ent><br/
<hw>Dis*fa"vor</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Disfavored</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Disfavoring</conjf>.]</vmorph> <sn>1.</sn> <def>To withhold or
withdraw favor from; to regard with disesteem; to show disapprobation
of; to discountenance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Countenanced or <qex>disfavored</qex> according as they obey.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To injure the form or looks of.</def>
<mark>[R.]</mark> <rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disfavorable</ent><br/
<hw>Dis*fa"vor*a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>d<eacute/favorable</ets>.]</ety> <def>Unfavorable.</def>
<mark>[Obs.]</mark> <rj><au>Stow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disfavorably</ent><br/
<hw>Dis*fa"vor*a*bly</hw>, <pos>adv.</pos> <def>Unpropitiously.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disfavorer</ent><br/
<hw>Dis*fa"vor*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
disfavors.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disfeature</ent><br/
<hw>Dis*fea"ture</hw> <pr>(?; 135)</pr>, <pos>v. t.</pos> <ety>[Cf.
<er>Defeature</er>.]</ety> <def>To deprive of features; to mar the
features of.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disfellowship</ent><br/
<hw>Dis*fel"low*ship</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[See
<er>Fellowship</er>, <pos>v. t.</pos>]</ety> <def>To exclude from
fellowship; to refuse intercourse with, as an associate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>An attempt to <qex>disfellowship</qex> an evil, but to fellowship
the evildoer.</q> <rj><qau>Freewill Bapt. Quart.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disfiguration</ent><br/
<hw>Dis*fig`u*ra"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Disfigure</er>, and cf. <er>Defiguration</er>.]</ety> <def>The act
of disfiguring, or the state of being disfigured; defacement; deformity;
disfigurement.</def> <rj><au>Gauden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disfigure</ent><br/
<hw>Dis*fig"ure</hw> <pr>(?; 135)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Disfigured</conjf> <pr>(?)</pr>;
<pos>p. pr. & vb. n.</pos> <conjf>Disfiguring</conjf>.]</vmorph>
<ety>[OF. <ets>desfigurer</ets>, F. <ets>d<eacute/figurer</ets>; pref.
<ets>des-</ets> (L. <ets>dis-</ets>) + <ets>figurer</ets> to fashion,
shape, fr. L. <ets>figurare</ets>, fr. <ets>figura</ets> figure. See
<er>Figure</er>, and cf. <er>Defiguration</er>.]</ety> <def>To mar the
figure of; to render less complete, perfect, or beautiful in appearance;
to deface; to deform.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Disfiguring</qex> not God's likeness, but their own.</q>
<rj><qau>Milton.</qau></rj></p>

<p><syn><b>Syn.</b> -- To deface; deform; mar; injure.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disfigure</ent><br/
<hw>Dis*fig"ure</hw>, <pos>n.</pos> <def>Disfigurement; deformity.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>disfigured</ent><br/
<hw>disfigured</hw> <pos>adj.</pos> <def>having the appearance spoiled;
<as>as, a <ex>disfigured</ex> face; strip mining left a
<ex>disfigured</ex> landscape</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Disfigurement</ent><br/
<hw>Dis*fig"ure*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>Act of disfiguring, or state of being disfigured; deformity.</def>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which disfigures; a defacement; a
blot.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Uncommon expressions . . . are a <qex>disfigurement</qex> rather
than any embellishment of discourse.</q> <rj><qau>Hume.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disfigurer</ent><br/
<hw>Dis*fig"ur*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
disfigures.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disflesh</ent><br/
<hw>Dis*flesh"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To reduce the
flesh or obesity of.</def> <mark>[Obs.]</mark>
<rj><au>Shelton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disforest</ent><br/
<hw>Dis*for"est</hw> <pr>(?)</pr>, <pos>v. t.</pos> <sn>1.</sn> <def>To
disafforest.</def> <rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To clear or deprive of forests or trees.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disforestation</ent><br/
<hw>Dis*for`es*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
clearing land of forests.</def> <rj><au>Daniel.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disformity</ent><br/
<hw>Dis*form"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf.
<er>Deformity</er>.]</ety> <def>Discordance or diversity of form;
unlikeness in form.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Uniformity or <qex>disformity</qex> in comparing together the
respective figures of bodies.</q> <rj><qau>S. Clarke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disfranchise</ent><br/
<hw>Dis*fran"chise</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Disfranchised</conjf>
<pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Disfranchising</conjf>.]</vmorph> <ety>[Cf.
<er>Diffranchise</er>.]</ety> <def>To deprive of a franchise or
chartered right; to dispossess of the rights of a citizen, or of a
particular privilege, as of voting, holding office, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Sir William Fitzwilliam was <qex>disfranchised</qex>.</q>
<rj><qau>Fabyan (1509).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He was partially <qex>disfranchised</qex> so as to be made
incapable of taking part in public affairs.</q>
<rj><qau>Thirlwall.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>disfranchised</ent><br/
<hw>disfranchised</hw> <pos>adj.</pos> <def>deprived of the rights of
citizenship especially the right to vote. Opposite of
<ant>enfranchised</ant>.</def><br/
<syn><b>Syn. --</b> disenfranchised, voteless.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Disfranchisement</ent><br/
<hw>Dis*fran"chise*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
disfranchising, or the state of being disfranchised; deprivation of
privileges of citizenship or of chartered immunities.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Sentenced first to dismission from the court, and then to
<qex>disfranchisement</qex> and expulsion from the colony.</q>
<rj><qau>Palfrey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 425 --></p>

<p><ent>Disfriar</ent><br/
<hw>Dis*fri"ar</hw> <pr>(d<icr/s*fr<imac/"<etil/r)</pr>, <pos>v.
t.</pos> <def>To depose or withdraw from the condition of a friar.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Many did quickly unnun and <qex>disfriar</qex> themselves.</q>
<rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disfrock</ent><br/
<hw>Dis*frock"</hw> <pr>(d<icr/s*fr<ocr/k")</pr>, <pos>v. t.</pos>
<def>To unfrock.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disfurnish</ent><br/
<hw>Dis*fur"nish</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Disfurnished</conjf> <pr>(?)</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>Disfurnishing</conjf>.]</vmorph> <ety>[Pref.
<ets>dis-</ets> + <ets>furnish</ets>.]</ety> <def>To deprive of that
with which anything is furnished (furniture, equipments, etc.); to
strip; to render destitute; to divest.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I am a thing obscure, <qex>disfurnished</qex> of<br/
All merit, that can raise me higher.</q>
<rj><qau>Massinger.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disfurnishment</ent><br/
<hw>Dis*fur"nish*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
disfurnishing, or the state of being disfurnished.</def>
<rj><au>Daniel.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disfurniture</ent><br/
<hw>Dis*fur"ni*ture</hw> <pr>(?; 135)</pr>, <pos>n.</pos> <def>The act
of disfurnishing, or the state of being disfurnished.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disfurniture</ent><br/
<hw>Dis*fur"ni*ture</hw>, <pos>v. t.</pos> <def>To disfurnish.</def>
<mark>[R.]</mark> <rj><au>East.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disgage</ent><br/
<hw>Dis*gage"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To free from a
gage or pledge; to disengage.</def> <mark>[Obs.]</mark>
<rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disgallant</ent><br/
<hw>Dis*gal"lant</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To deprive of
gallantry.</def> <mark>[Obs.]</mark> <rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disgarland</ent><br/
<hw>Dis*gar"land</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To strip of a
garland.</def> <mark>[Poetic]</mark> <ldquo/Thy locks
<xex>disgarland</xex>.<rdquo/ <rj><au>Drummond.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disgarnish</ent><br/
<hw>Dis*gar"nish</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>dis-</ets> + <ets>garnish</ets>. See <er>Degarnish</er>.]</ety>
<def>To divest of garniture; to disfurnish; to dismantle.</def>
<rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disgarrison</ent><br/
<hw>Dis*gar"ri*son</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To deprive
of a garrison.</def> <rj><au>Hewyt.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disgavel</ent><br/
<hw>Dis*gav"el</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Disgaveled</conjf> <pr>(?)</pr> or
<conjf>Disgaveled</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Disgaveling</conjf>.]</vmorph> <ety>[See
<er>Gavelkind</er>.]</ety> <fld>(Eng. Law)</fld> <def>To deprive of that
principal quality of gavelkind tenure by which lands descend equally
among all the sons of the tenant; -- said of lands.</def>
<rj><au>Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disgest</ent><br/
<hw>Dis*gest"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To digest.</def>
<mark>[Obs.]</mark> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disgestion</ent><br/
<hw>Dis*ges"tion</hw> <pr>(?; 106)</pr>, <pos>n.</pos>
<def>Digestion.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disglorify</ent><br/
<hw>Dis*glo"ri*fy</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Disglorified</conjf> <pr>(?)</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>Disglorifying</conjf>.]</vmorph> <def>To deprive of
glory; to treat with indignity.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Disglorified</qex>, blasphemed, and had in scorn.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disglory</ent><br/
<hw>Dis*glo"ry</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Dishonor.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>To the <qex>disglory</qex> of God's name.</q>
<rj><qau>Northbrooke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disgorge</ent><br/
<hw>Dis*gorge"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Disgorged</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Disgorging</conjf>.]</vmorph> <ety>[F.
<ets>d<eacute/gorger</ets>, earlier <ets>desgorger</ets>; pref.
<ets>d<eacute/-</ets>, <ets>des-</ets> (L. <ets>dis-</ets>) +
<ets>gorge</ets>. See <er>Gorge</er>.]</ety> <sn>1.</sn> <def>To eject
or discharge by the throat and mouth; to vomit; to pour forth or throw
out with violence, as if from the mouth; to discharge violently or in
great quantities from a confined place.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This mountain when it rageth, . . . casteth forth huge stones,
<qex>disgorgeth</qex> brimstone.</q> <rj><qau>Hakluyt.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>They loudly laughed<br/
To see his heaving breast <qex>disgorge</qex> the briny draught.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To give up unwillingly as what one has wrongfully
seized and appropriated; to make restitution of; to surrender; <as>as,
he was compelled to <ex>disgorge</ex> his ill-gotten
gains</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disgorge</ent><br/
<hw>Dis*gorge"</hw>, <pos>v. i.</pos> <def>To vomit forth what anything
contains; to discharge; to make restitution.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>See where it flows, <qex>disgorging</qex> at seven mouths<br/
Into the sea.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disgorgement</ent><br/
<hw>Dis*gorge"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>d<eacute/gorgement</ets>.]</ety> <def>The act of disgorging; a
vomiting; that which is disgorged.</def> <rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disgospel</ent><br/
<hw>Dis*gos"pel</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To be
inconsistent with, or act contrary to, the precepts of the gospel; to
pervert the gospel.</def> <mark>[Obs.]</mark>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disgrace</ent><br/
<hw>Dis*grace"</hw> <pr>(?; 277)</pr>, <pos>n.</pos> <ety>[F.
<ets>disgr<acir/ce</ets>; pref. <ets>dis-</ets> (L. <ets>dis-</ets>) +
<ets>gr<acir/ce</ets>. See <er>Grace</er>.]</ety> <sn>1.</sn> <def>The
condition of being out of favor; loss of favor, regard, or
respect.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Macduff lives in <qex>disgrace</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The state of being dishonored, or covered with
shame; dishonor; shame; ignominy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To tumble down thy husband and thyself<br/
From top of honor to <qex>disgrace's</qex> feet?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which brings dishonor; cause of shame or
reproach; great discredit; <as>as, vice is a <ex>disgrace</ex> to a
rational being</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>An act of unkindness; a disfavor.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The interchange continually of favors and
<qex>disgraces</qex>.</q> <rj><qau>Bacon.</qau></rj></p>

<p><syn><b>Syn.</b> -- Disfavor; disesteem; opprobrium; reproach;
discredit; disparagement; dishonor; shame; infamy; ignominy;
humiliation.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disgrace</ent><br/
<hw>Dis*grace"</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Disgraced</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Disgracing</conjf> <pr>(?)</pr>.]</vmorph> <ety>[Cf. F.
<ets>disgracier</ets>. See <er>Disgrace</er>, <pos>n.</pos>]</ety>
<sn>1.</sn> <def>To put out of favor; to dismiss with
dishonor.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Flatterers of the <qex>disgraced</qex> minister.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Pitt had been <qex>disgraced</qex> and the old Duke of Newcastle
dismissed.</q> <rj><qau>J. Morley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To do disfavor to; to bring reproach or shame upon;
to dishonor; to treat or cover with ignominy; to lower in
estimation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Shall heap with honors him they now <qex>disgrace</qex>.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>His ignorance <qex>disgraced</qex> him.</q>
<rj><qau>Johnson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To treat discourteously; to upbraid; to
revile.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The goddess wroth gan foully her <qex>disgrace</qex>.</q>
<rj><qau>Spenser.</qau></rj></p>

<p><syn><b>Syn.</b> -- To degrade; humble; humiliate; abase; disparage;
defame; dishonor; debase.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>disgraced</ent><br/
<hw>disgraced</hw> <pos>adj.</pos> <def>suffering shame or
dishonor.</def><br/
<syn><b>Syn. --</b> discredited, dishonored, shamed.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Disgraceful</ent><br/
<hw>Dis*grace"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Bringing
disgrace; causing shame; shameful; dishonorable; unbecoming; <as>as,
profaneness is <ex>disgraceful</ex> to a man</as>.</def> --
<wordforms><wf>Dis*grace"ful*ly</wf>, <pos>adv.</pos> --
<wf>Dis*grace"ful*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><q>The Senate have cast you forth <qex>disgracefully</qex>.</q>
<rj><qau>B. Jonson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disgracer</ent><br/
<hw>Dis*gra"cer</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
disgraces.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disgracious</ent><br/
<hw>Dis*gra"cious</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>disgracieux</ets>.]</ety> <def>Wanting grace; unpleasing;
disagreeable.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disgracive</ent><br/
<hw>Dis*gra"cive</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Disgracing.</def>
<mark>[Obs.]</mark> <rj><au>Feltham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disgradation</ent><br/
<hw>Dis`gra*da"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Scots
Law)</fld> <def>Degradation; a stripping of titles and honors.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disgrade</ent><br/
<hw>Dis*grade"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To
degrade.</def> <mark>[Obs.]</mark> <rj><au>Foxe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disgraduate</ent><br/
<hw>Dis*grad"u*ate</hw> <pr>(?; 135)</pr>, <pos>v. t.</pos> <def>To
degrade; to reduce in rank.</def> <mark>[Obs.]</mark>
<rj><au>Tyndale.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disgregate</ent><br/
<hw>Dis"gre*gate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>disgregare</ets>; <ets>dis-</ets> + <ets>gregare</ets> to collect,
fr. <ets>grex</ets>, <ets>gregis</ets>, flock or herd.]</ety> <def>To
disperse; to scatter; -- opposite of <xex>congregate</xex>.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disgregation</ent><br/
<hw>Dis`gre*ga"tion</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Physiol.)</fld> <def>The process of separation, or the condition
of being separate, as of the molecules of a body.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disgruntle</ent><br/
<hw>Dis*grun"tle</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To dissatisfy;
to disaffect; to anger.</def> <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disguise</ent><br/
<hw>Dis*guise"</hw> <pr>(?; 232)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Disguised</conjf> <pr>(?)</pr>;
<pos>p. pr. & vb. n.</pos> <conjf>Disguising</conjf>.]</vmorph>
<ety>[OE. <ets>desguisen</ets>, <ets>disgisen</ets>, <ets>degisen</ets>,
OF. <ets>desguisier</ets>, F. <ets>d<eacute/guiser</ets>; pref.
<ets>des-</ets> (L. <ets>dis-</ets>) + <ets>guise</ets>. See
<er>Guise</er>.]</ety> <sn>1.</sn> <def>To change the guise or
appearance of; especially, to conceal by an unusual dress, or one
intended to mislead or deceive.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Bunyan was forced to <qex>disguise</qex> himself as a wagoner.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To hide by a counterfeit appearance; to cloak by a
false show; to mask; <as>as, to <ex>disguise</ex> anger; to
<ex>disguise</ex> one's sentiments, character, or
intentions.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>All God's angels come to us <qex>disguised</qex>.</q>
<rj><qau>Lowell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To affect or change by liquor; to
intoxicate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I have just left the right worshipful, and his myrmidons, about a
sneaker of five gallons; the whole magistracy was pretty well
<qex>disguised</qex> before I gave them the ship.</q>
<rj><qau>Spectator.</qau></rj></p>

<p><syn><b>Syn.</b> -- To conceal; hide; mask; dissemble; dissimulate;
feign; pretend; secrete. See <er>Conceal</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disguise</ent><br/
<hw>Dis*guise"</hw>, <pos>n.</pos> <sn>1.</sn> <def>A dress or exterior
put on for purposes of concealment or of deception; <as>as, persons
doing unlawful acts in <ex>disguise</ex> are subject to heavy
penalties</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There is no passion which steals into the heart more imperceptibly
and covers itself under more <qex>disguises</qex>, than pride.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Artificial language or manner assumed for deception;
false appearance; counterfeit semblance or show.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That eye which glances through all <qex>disguises</qex>.</q>
<rj><qau>D. Webster.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Change of manner by drink; intoxication.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A masque or masquerade.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Disguise</qex> was the old English word for a masque.</q>
<rj><qau>B. Jonson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disguisedly</ent><br/
<hw>Dis*guis"ed*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In
disguise.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disguisedness</ent><br/
<hw>Dis*guis"ed*ness</hw>, <pos>n.</pos> <def>The state of being
disguised.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disguisement</ent><br/
<hw>Dis*guise"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Disguise.</def>
<mark>[R.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disguiser</ent><br/
<hw>Dis*guis"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One
who, or that which, disguises.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who wears a disguise; an actor in a masquerade;
a masker.</def> <mark>[Obs.]</mark> <rj><au>E. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disguising</ent><br/
<hw>Dis*guis"ing</hw>, <pos>n.</pos> <def>A masque or masquerade.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disgust</ent><br/
<hw>Dis*gust"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Disgusted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Disgusting</conjf>.]</vmorph> <ety>[OF. <ets>desgouster</ets>, F.
<ets>d<eacute/go<ucir/ter</ets>; pref. <ets>des-</ets> (L.
<ets>dis-</ets>) + <ets>gouster</ets> to taste, F.
<ets>go<ucir/ter</ets>, fr. L. <ets>gustare</ets>, fr. <ets>gustus</ets>
taste. See <er>Gust</er> to taste.]</ety> <def>To provoke disgust or
strong distaste in; to cause (any one) loathing, as of the stomach; to
excite aversion in; to offend the moral taste of; -- often with
<xex>at</xex>, <xex>with</xex>, or <xex>by</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>disgust</qex> him with the world and its vanities.</q>
<rj><qau>Prescott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><AE/rius is expressly declared . . . to have been
<qex>disgusted</qex> at failing.</q> <rj><qau>J. H.
Newman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Alarmed and <qex>disgusted</qex> by the proceedings of the
convention.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disgust</ent><br/
<hw>Dis*gust"</hw>, <pos>n.</pos> <ety>[Cf. OF. <ets>desgoust</ets>, F.
<ets>d<eacute/go<ucir/t</ets>. See <er>Disgust</er>, <pos>v.
t.</pos>]</ety> <def>Repugnance to what is offensive; aversion or
displeasure produced by something loathsome; loathing; strong distaste;
-- said primarily of the sickening opposition felt for anything which
offends the physical organs of taste; now rather of the analogous
repugnance excited by anything extremely unpleasant to the moral taste
or higher sensibilities of our nature; <as>as, an act of cruelty may
excite <ex>disgust</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The manner of doing is more consequence than the thing done, and
upon that depends the satisfaction or <qex>disgust</qex> wherewith it is
received.</q> <rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>In a vulgar hack writer such oddities would have excited only
<qex>disgust</qex>.</q> <rj><qau>Macaulay.</qau></rj></p>

<p><syn><b>Syn.</b> -- Nausea; loathing; aversion; distaste; dislike;
disinclination; abomination. See <er>Dislike</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>disgusted</ent><br/
<hw>disgusted</hw> <pos>adj.</pos> <def>having a strong distaste from
surfeit.</def><br/
<syn><b>Syn. --</b> fed up(predicate), sick of(predicate), tired
of(predicate).</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Disgustful</ent><br/
<hw>Dis*gust"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Provoking
disgust; offensive to the taste; exciting aversion;
disgusting.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That horrible and <qex>disgustful</qex> situation.</q>
<rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disgustfulness</ent><br/
<hw>Dis*gust"ful*ness</hw>, <pos>n.</pos> <def>The state of being
disgustful.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disgusting</ent><br/
<hw>Dis*gust"ing</hw>, <pos>a.</pos> <def>That causes disgust;
sickening; offensive; revolting.</def> --
<wordforms><wf>Dis*gust"ing*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dish</ent><br/
<hw>Dish</hw> <pr>(d<icr/sh)</pr>, <pos>n.</pos> <ety>[AS.
<ets>disc</ets>, L. <ets>discus</ets> dish, disc, quoit, fr. Gr.
<grk>di`skos</grk> quoit, fr. <grk>dikei^n</grk> to throw. Cf.
<er>Dais</er>, <er>Desk</er>, <er>Disc</er>, <er>Discus</er>.]</ety>
<sn>1.</sn> <def>A vessel, as a platter, a plate, a bowl, used for
serving up food at the table.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>She brought forth butter in a lordly <qex>dish</qex>.</q>
<rj><qau>Judg. v. 25.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The food served in a dish; hence, any particular
kind of food, especially prepared food; <as>as, a cold <ex>dish</ex>; a
warm <ex>dish</ex>; a delicious <ex>dish</ex>. <ldquo/A <ex>dish</ex>
fit for the gods.<rdquo/</as></def> <rj><au>Shak.</au></rj></p>

<p><q>Home-home <qex>dishes</qex> that drive one from home.</q>
<rj><qau>Hood.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The state of being concave, or like a dish, or the
degree of such concavity; <as>as, the <ex>dish</ex> of a
wheel</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A hollow place, as in a field.</def>
<rj><au>Ogilvie.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Mining)</fld> <sd>(a)</sd> <def>A trough about 28
inches long, 4 deep, and 6 wide, in which ore is measured.</def>
<sd>(b)</sd> <def>That portion of the produce of a mine which is paid to
the land owner or proprietor.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>anything with a discoid and concave shape, like that
of a dish.</def><br/
[<source>PJC</source>]</p>

<p><sn>7.</sn> <def>an electronic device with a concave reflecting
surface which focuses reflected radio waves to or from a point, used as
a receiving or transmitting antenna; also called <altname><ecol><b>dish
antenna</b></ecol></altname>. The dish is often shaped as a paraboloid
so as to achieve a high sensitivity and enable reception of weak signals
when used as a receiving antenna, or to focus transmitted signals into a
narrow beam when used as a transmitting antenna.</def><br/
<syn><b>Syn. --</b> dish aerial, dish antenna, saucer.</syn>
[<source>PJC</source>]</p>

<p><sn>8.</sn> <def>a very attractive woman or young lady, especially
one sexually attractive; -- sometimes considered offensive and sexist;
<as>as, the departmental secretary is quite a <ex>dish</ex></as>.</def>
<mark>[slang]</mark><br/
<syn><b>Syn. --</b> smasher, stunner, knockout, beauty, sweetheart,
peach, lulu, looker, mantrap, dish.</syn>
[<source>WordNet 1.5</source> + <source>PJC</source>]</p>

<p><sn>9.</sn> <def>a favorite activity, or an activity at which one
excels.</def> <mark>[slang]</mark> <br/
<syn><b>Syn. --</b> cup of tea, bag.</syn>
[<source>WordNet 1.5</source> + <source>PJC</source>]</p>

<p><sn>10.</sn> <def>the quantity that a dish will hold, or a dish
filled with some material.</def><br/
<syn><b>Syn. --</b> dishful.</syn>
[<source>WordNet 1.5</source> + <source>PJC</source>]</p>

<p><cs><col><b>satellite dish</b></col> <cd>a <isa>dish antenna</isa>
used to receive signals from or to transmit signals to a satellite which
transmits or receives radio signals. In most common usage, it refers to
small dish antennas used to receive television programs broadcast from
geostationary satellites.</cd></cs><br/
[<source>PJC</source>]</p>

<p><ent>Dish</ent><br/
<hw>Dish</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Dished</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Dishing</conjf>.]</vmorph> <sn>1.</sn> <def>To put in a dish,
ready for the table.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To make concave, or depress in the middle, like a
dish; <as>as, to <ex>dish</ex> a wheel by inclining the
spokes</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To frustrate; to beat; to ruin.</def>
<mark>[Low]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>to talk about (a person) in a disparaging manner; to
gossip about (a person); <as>as, the secretaries spent their break time
<ex>dishing</ex> the newest employee</as>.</def>
<mark>[slang]</mark><br/
[<source>PJC</source>]</p>

<p><cs><col><b>To dish out</b></col>. <sn>1.</sn> <cd>To serve out of a
dish; to distribute in portions at table.</cd> <sn>2.</sn>
<fld>(Arch.)</fld> <cd>To hollow out, as a gutter in stone or wood.</cd>
<sn>2.</sn> <cd>to dispense freely; -- also used figuratively; <as>as,
to <ex>dish out</ex> punishment; to <ex>dish out</ex> abuse or
insult</as>.</cd> -- <col><b>To dish up</b></col>, <cd>to take (food)
from the oven, pots, etc., and put in dishes to be served at
table.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dishabilitate</ent><br/
<hw>Dis`ha*bil"i*tate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Cf.
<er>Disability</er>.]</ety> <def>To disqualify.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dishabille</ent><br/
<hw>Dis`ha*bille"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Deshabille</er>.]</ety> <def>An undress; a loose, negligent dress;
deshabille.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They breakfast in <qex>dishabille</qex>.</q>
<rj><qau>Smollett.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dishabit</ent><br/
<hw>Dis*hab"it</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>dis-</ets> + <ets>habit</ets> to inhabit.]</ety> <def>To
dislodge.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Those sleeping stones . . . from their fixed beds of lime<br/
Had been <qex>dishabited</qex>.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dishabited</ent><br/
<hw>Dis*hab"it*ed</hw>, <pos>p. a.</pos> <def>Rendered
uninhabited.</def> <ldquo/<xex>Dishabited</xex> towns.<rdquo/ <rj><au>R.
Carew.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dishabituate</ent><br/
<hw>Dis`ha*bit"u*ate</hw> <pr>(?; 135)</pr>, <pos>v. t.</pos> <def>To
render unaccustomed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dishable</ent><br/
<hw>Dis*ha"ble</hw> <pr>(?)</pr>, <pos>v. t.</pos> <sn>1.</sn> <def>To
disable.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To disparage.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>She oft him blamed . . . and him <qex>dishabled</qex> quite.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dishallow</ent><br/
<hw>Dis*hal"low</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To make unholy;
to profane.</def> <rj><au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Nor can the unholiness of the priest <qex>dishallow</qex> the
altar.</q> <rj><qau>T. Adams.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disharmonious</ent><br/
<hw>Dis`har*mo"ni*ous</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Unharmonious; discordant.</def> <mark>[Obs.]</mark>
<rj><au>Hallywell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disharmony</ent><br/
<hw>Dis*har"mo*ny</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Want of harmony;
discord; incongruity.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>disharmony</qex> in the different impulses that constitute
it [our nature].</q> <rj><qau>Coleridge.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dishaunt</ent><br/
<hw>Dis*haunt"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To leave; to
quit; to cease to haunt.</def> <rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dishcloth</ent><br/
<hw>Dish"cloth`</hw> <pr>(?; 115)</pr>, <pos>n.</pos> <def>A cloth used
for washing dishes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dishclout</ent><br/
<hw>Dish"clout`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A dishcloth.</def>
<mark>[Obsolescent]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disheart</ent><br/
<hw>Dis*heart"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To
dishearten.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dishearten</ent><br/
<hw>Dis*heart"en</hw> <pr>(d<icr/s*h<aum/rt"'n)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Disheartened</conjf>
<pr>(d<icr/s*h<aum/rt"'nd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Disheartening</conjf>.]</vmorph> <ety>[Pref. <ets>dis-</ets> +
<ets>hearten</ets>.]</ety> <def>To discourage; to deprive of courage and
hope; to depress the spirits of; to deject.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Regiments . . . utterly disorganized and
<qex>disheartened</qex>.</q> <rj><qau>Macaulay.</qau></rj></p>

<p><syn><b>Syn.</b> -- To dispirit; discourage; depress; deject; deter;
terrify.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>disheartened</ent><br/
<hw>dis*heart"ened</hw> <pr>(d<icr/s*h<aum/rt"'nd)</pr>, <pos>adj.</pos>
<def>made less hopeful or enthusiastic; <as>as, their lack of interest
<ex>disheartened</ex> the instructor</as>.</def> [Narrower terms:
<hascons>pessimistic</hascons> (vs. optimistic)]<br/
<syn><b>Syn. --</b> demoralized, discouraged.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>disheartening</ent><br/
<hw>disheartening</hw> <pos>adj.</pos> <def>Causing loss of hope or
enthusiasm.</def><br/
<syn><b>Syn. --</b> demoralizing, demoralising, dispiriting.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>disheartenment</ent><br/
<hw>dis*heart"en*ment</hw> <pr>(d<icr/s*h<aum/rt"'n*m<eit/nt)</pr>,
<pos>n.</pos> <def>Discouragement; dejection; depression of
spirits.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>disheir</ent><br/
<hw>dis*heir"</hw> <pr>(d<icr/z*<acir/r")</pr>, <pos>v. t.</pos>
<ety>[Cf. <er>Disherit</er>.]</ety> <def>To disinherit.</def>
<mark>[Obs.]</mark> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>dishelm</ent><br/
<hw>dis*helm"</hw> <pr>(d<icr/s*h<ecr/lm")</pr>, <pos>v. t.</pos>
<ety>[Pref. <ets>dis-</ets> + <ets>helm</ets> helmet.]</ety> <def>To
deprive of the helmet.</def> <mark>[Poetic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Lying stark,<br/
<qex>Dishelmed</qex> and mute, and motionlessly pale.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>disherison</ent><br/
<hw>dis*her"i*son</hw> <pr>(d<icr/s*h<ecr/r"<icr/z'n)</pr>,
<pos>n.</pos> <ety>[See <er>Disherit</er>.]</ety> <def>The act of
disheriting, or debarring from inheritance; disinherison.</def>
<rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>disherit</ent><br/
<hw>dis*her"it</hw> <pr>(d<icr/s*h<ecr/r"<icr/t)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Disherited</conjf>; <pos>p. pr.
& vb. n.</pos> <conjf>Disheriting</conjf>.]</vmorph> <ety>[F.
<ets>d<eacute/sh<eacute/riter</ets>; pref. <ets>d<eacute/s-</ets> (L.
<ets>dis-</ets>) + <ets>h<eacute/riter</ets> to inherit. See
<er>Inherit</er>, and cf. <er>Dusheir</er>, <er>Disinherit</er>.]</ety>
<def>To disinherit; to cut off, or detain, from the possession or
enjoyment of an inheritance.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disheritance</ent><br/
<hw>Dis*her"it*ance</hw> <pr>(d<icr/s*h<ecr/r"<icr/t*<ait/ns)</pr>,
<pos>n.</pos> <ety>[Cf. OF. <ets>desheritance</ets>.]</ety> <def>The act
of disinheriting or state of being disinherited; disinheritance.</def>
<mark>[Obs.]</mark> <rj><au>Beau. & Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disheritor</ent><br/
<hw>Dis*her"it*or</hw> <pr>(d<icr/s*h<ecr/r"<icr/t*<etil/r)</pr>,
<pos>n.</pos> <fld>(Law)</fld> <def>One who puts another out of his
inheritance.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dishevel</ent><br/
<hw>Di*shev"el</hw> <pr>(d<icr/*sh<ecr/v"'l <it>or</it> -<ecr/l)</pr>,
<pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Disheveled</conjf> <pr>(?)</pr> or <conjf>Dishevelled</conjf>;
<pos>p. pr. & vb. n.</pos> <conjf>Disheveling</conjf> or
<conjf>Dishevelling</conjf>.]</vmorph> <ety>[OF. <ets>descheveler</ets>,
F. <ets>d<eacute/cheveler</ets>, LL. <ets>discapillare</ets>;
<ets>dis-</ets> + L. <ets>capillus</ets> the hair of the head. See
<er>Capillary</er>.]</ety> <sn>1.</sn> <def>To suffer (the hair) to hang
loosely or disorderly; to spread or throw (the hair) in disorder; --
used chiefly in the passive participle.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With garments rent and hair <qex>disheveled</qex>,<br/
Wringing her hands and making piteous moan.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To spread loosely or disorderly.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Like the fair flower <qex>disheveled</qex> in the wind.</q>
<rj><qau>Cowper.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dishevel</ent><br/
<hw>Di*shev"el</hw>, <pos>v. i.</pos> <def>To be spread in disorder or
hang negligently, as the hair.</def> <mark>[R.]</mark> <rj><au>Sir T.
Herbert.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dishevele</ent><br/
<hw>Di*shev"ele</hw> <pr>(?)</pr>, <pos>p. p. & a.</pos>
<def>Disheveled.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Dishevele</qex>, save his cap, he rode all bare.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p> <pos>adj.</pos> <sn>1.</sn> <def>; .</def><br/
<syn><b>Syn. --</b> disheveled, ungroomed.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>dishevelled</ent><br/
<ent>disheveled</ent><br/
<mhw><hw>di*shev"eled</hw>, <hw>di*shev"elled</hw></mhw> <pr>(?)</pr>,
<pos>a.</pos> <sn>1.</sn> <def>Hanging in loose disorder; disarranged;
in disarray; not made neat; -- used especially of hair or clothing;
<as>as, <ex>disheveled</ex> hair</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Having the hair in loose disorder.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The dancing maidens are <qex>disheveled</qex> M<ae/nads.</q>
<rj><qau>J. A. Symonds.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dishful</ent><br/
<hw>Dish"ful</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Dishfuls</plw> <pr>(<?/)</pr>.</plu> <def>As much as a dish holds
when full.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dishing</ent><br/
<hw>Dish"ing</hw>, <pos>a.</pos> <def>Dish-shaped; concave.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dishonest</ent><br/
<hw>Dis*hon"est</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>dis-</ets> + <ets>honest</ets>: cf. F.
<ets>d<eacute/shonn<ecir/te</ets>, OF. <ets>deshoneste</ets>.]</ety>
<sn>1.</sn> <def>Dishonorable; shameful; indecent; unchaste; lewd.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Inglorious triumphs and <qex>dishonest</qex> scars.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Speak no foul or <qex>dishonest</qex> words before them [the
women].</q> <rj><qau>Sir T. North.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Dishonored; disgraced; disfigured.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Dishonest</qex> with lopped arms the youth appears,<br/
Spoiled of his nose and shortened of his ears.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Wanting in honesty; void of integrity; faithless;
disposed to cheat or defraud; not trustworthy; <as>as, a
<ex>dishonest</ex> man</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Characterized by fraud; indicating a want of
probity; knavish; fraudulent; unjust.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To get <qex>dishonest</qex> gain.</q> <rj><qau>Ezek. xxii.
27.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>dishonest</qex> profits of men in office.</q>
<rj><qau>Bancroft.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dishonest</ent><br/
<hw>Dis*hon"est</hw>, <pos>v. t.</pos> <ety>[Cf. OF.
<ets>deshonester</ets>.]</ety> <def>To disgrace; to dishonor; <as>as, to
<ex>dishonest</ex> a maid</as>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I will no longer <qex>dishonest</qex> my house.</q>
<rj><qau>Chapman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dishonestly</ent><br/
<hw>Dis*hon"est*ly</hw>, <pos>adv.</pos> <def>In a dishonest
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dishonesty</ent><br/
<hw>Dis*hon"es*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. OF.
<ets>deshonest<eacute/</ets>, F.
<ets>d<eacute/shonn<ecir/tet<eacute/</ets>.]</ety> <sn>1.</sn>
<def>Dishonor; dishonorableness; shame.</def> <mark>[Obs.]</mark>
<ldquo/The hidden things of <xex>dishonesty</xex>.<rdquo/ <rj><au>2 Cor.
iv. 2.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Want of honesty, probity, or integrity in principle;
want of fairness and straightforwardness; a disposition to defraud,
deceive, or betray; faithlessness.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Violation of trust or of justice; fraud; any
deviation from probity; a dishonest act.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Lewdness; unchastity.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 426 --></p>

<p><ent>dishpan</ent><br/
<hw>dishpan</hw> <pos>n.</pos> <sn>1.</sn> <def>large pan for washing
dishes.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dishonor</ent><br/
<hw>Dis*hon"or</hw> <pr>(d<icr/s*<ocr/n"<etil/r <it>or</it>
d<icr/z*<ocr/n"<etil/r)</pr>, <pos>n.</pos> <ety>[OE.
<ets>deshonour</ets>, <ets>dishonour</ets>, OF. <ets>deshonor</ets>,
<ets>deshonur</ets>, F. <ets>d<eacute/shonneur</ets>; pref.
<ets>des-</ets> (L. <ets>dis-</ets>) + <ets>honor</ets>,
<ets>honur</ets>, F. <ets>honneur</ets>, fr. L. <ets>honor</ets>. See
<er>Honor</er>.]</ety> <altsp>[Written also
<asp>dishonour</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Lack of honor; disgrace; ignominy; shame;
reproach.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It was not meet for us to see the king's <qex>dishonor</qex>.</q>
<rj><qau>Ezra iv. 14.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>His honor rooted in <qex>dishonor</qex> stood.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>The nonpayment or nonacceptance of
commercial paper by the party on whom it is drawn.</def></p>

<p><syn><b>Syn.</b> -- Disgrace; ignominy; shame; censure; reproach;
opprobrium.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dishonor</ent><br/
<hw>Dis*hon"or</hw> <pr>(d<icr/s*<ocr/n"<etil/r <it>or</it>
d<icr/z*<ocr/n"<etil/r)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Dishonored</conjf> <pr>(d<icr/s*<ocr/n"<etil/rd
<it>or</it> d<icr/z*<ocr/n"<etil/rd)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Dishonoring</conjf>.]</vmorph> <ety>[OE. <ets>deshonouren</ets>,
F. <ets>d<eacute/shonorer</ets>; pref. <ets>d<eacute/s-</ets> (L.
<ets>dis-</ets>) + <ets>honorer</ets> to honor, fr. L.
<ets>honorare</ets>. See <er>Honor</er>, <pos>v. t.</pos>]</ety>
<altsp>[Written also <asp>dishonour</asp>.]</altsp> <sn>1.</sn> <def>To
deprive of honor; to disgrace; to bring reproach or shame on; to treat
with indignity, or as unworthy in the sight of others; to stain the
character of; to lessen the reputation of; <as>as, the duelist
<ex>dishonors</ex> himself to maintain his honor</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Nothing . . . that may <qex>dishonor</qex><br/
Our law, or stain my vow of Nazarite.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To violate the chastity of; to debauch.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To refuse or decline to accept or pay; -- said of a
bill, check, note, or draft which is due or presented; <as>as, to
<ex>dishonor</ex> a bill exchange</as>.</def></p>

<p><syn><b>Syn.</b> -- To disgrace; shame; debase; degrade; lower;
humble; humiliate; debauch; pollute.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dishonorable</ent><br/
<hw>Dis*hon"or*a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>d<eacute/shonorable</ets>.]</ety> <sn>1.</sn> <def>Wanting in
honor; not honorable; bringing or deserving dishonor; staining the
character, and lessening the reputation; shameful; disgraceful;
base.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Wanting in honor or esteem; disesteemed.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He that is <qex>dishonorable</qex> in riches, how much more in
poverty!</q> <rj><qau>Ecclus. x. 31.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To find ourselves <qex>dishonorable</qex> graves.</q>
<rj><qau>Shak.</qau></rj></p>

<p>-- <wordforms><wf>Dis*hon"or*a*ble*ness</wf>, <pos>n.</pos> --
<wf>Dis*hon"or*a*bly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dishonorary</ent><br/
<hw>Dis*hon"or*a*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Bringing
dishonor on; tending to disgrace; lessening reputation.</def>
<rj><au>Holmes.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dishonorer</ent><br/
<hw>Dis*hon"or*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
dishonors or disgraces; one who treats another indignity.</def>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dishorn</ent><br/
<hw>Dis*horn"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To deprive of
horns; <as>as, to <ex>dishorn</ex> cattle</as>.</def>
<ldquo/<xex>Dishorn</xex> the spirit.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dishorse</ent><br/
<hw>Dis*horse"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To dismount; to
knock (a person) from a horse.</def> <rj><au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dishouse</ent><br/
<hw>Dis*house"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To deprive of
house or home.</def> <ldquo/<xex>Dishoused</xex> villagers.<rdquo/
<rj><au>James White.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>dishpan</ent><br/
<hw>dishpan</hw> <pos>n.</pos> <def>a large pan for washing
dishes.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>dishrag</ent><br/
<hw>dishrag</hw> <pos>n.</pos> <def>a cloth for washing
dishes.</def><br/
<syn><b>Syn. --</b> dishcloth.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dishumor</ent><br/
<hw>Dis*hu"mor</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Ill humor.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dishumor</ent><br/
<hw>Dis*hu"mor</hw>, <pos>v. t.</pos> <def>To deprive of humor or
desire; to put out of humor.</def> <mark>[Obs.]</mark> <rj><au>B.
Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>dishware</ent><br/
<hw>dishware</hw> <pos>n.</pos> <def>eating and serving dishes
collectively.</def><br/
<syn><b>Syn. --</b> crockery.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dishwasher</ent><br/
<hw>Dish"wash`er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One
who, or that which, washes dishes.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>A European bird; the
wagtail.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>an electrical appliance{4} which washes tableware
automatically by directing powerful streams of hot soapy water at the
items from multiple jets.</def><br/
[<source>PJC</source>]</p>

<p><ent>Dishwater</ent><br/
<hw>Dish"wa`ter</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Water in which
dishes have been washed.</def> <ldquo/Suds and
<xex>dishwater</xex>.<rdquo/ <rj><au>Beau. & Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>dishy</ent><br/
<hw>dishy</hw> <pos>adj.</pos> <def>good-looking; -- used of
persons.</def> <mark>[British informal]</mark><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Disillusion</ent><br/
<hw>Dis`il*lu"sion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act or
process of freeing from an illusion, or the state of being freed
therefrom.</def> <rj><au>Lowell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disillusion</ent><br/
<hw>Dis`il*lu"sion</hw>, <pos>v. t.</pos> <def>To free from an illusion;
to disillusionize.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>disillusioning</ent><br/
<hw>disillusioning</hw> <pos>adj.</pos> <def>freeing from illusion or
false belief.</def><br/
<syn><b>Syn. --</b> disenchanting.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Disillusionize</ent><br/
<hw>Dis`il*lu"sion*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To
disenchant; to free from illusion.</def> <ldquo/The bitter
<xex>disillusionizing</xex> experience of postnuptial life.<rdquo/
<rj><au>W. Black.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disillusionment</ent><br/
<hw>Dis`il*lu"sion*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
freeing from an illusion, or the state of being freed
therefrom.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disimbitter</ent><br/
<hw>Dis`im*bit"ter</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>dis-</ets> + <ets>imbitter</ets>. Cf. <er>Disembitter</er>.]</ety>
<def>To free from bitterness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disimpark</ent><br/
<hw>Dis`im*park"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To free from
the barriers or restrictions of a park.</def> <mark>[R.]</mark>
<rj><au>Spectator.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disimpassioned</ent><br/
<hw>Dis`im*pas"sioned</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Free from
warmth of passion or feeling.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disimprove</ent><br/
<hw>Dis`im*prove"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To make
worse; -- the opposite of <xex>improve</xex>.</def> <mark>[R.]</mark>
<rj><au>Jer. Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disimprove</ent><br/
<hw>Dis`im*prove"</hw>, <pos>v. i.</pos> <def>To grow worse; to
deteriorate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disimprovement</ent><br/
<hw>Dis`im*prove"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Reduction
from a better to a worse state; <as>as, <ex>disimprovement</ex> of the
earth;</as> specific features which are worse than former features;
<as><ex>disimprovements</ex> in the new Windows operating
system</as>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Disincarcerate</ent><br/
<hw>Dis`in*car"cer*ate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To
liberate from prison.</def> <mark>[R.]</mark>
<rj><au>Harvey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disinclination</ent><br/
<hw>Dis*in`cli*na"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state
of being disinclined; want of propensity, desire, or affection; slight
aversion or dislike; indisposition.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Disappointment gave him a <qex>disinclination</qex> to the fair
sex.</q> <rj><qau>Arbuthnot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Having a <qex>disinclination</qex> to books or business.</q>
<rj><qau>Guardian.</qau></rj></p>

<p><syn><b>Syn.</b> -- Unwillingness; disaffection; alienation; dislike;
indisposition; distaste; aversion; repugnance.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disincline</ent><br/
<hw>Dis`in*cline"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Disinclined</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Disinclining</conjf>.]</vmorph> <def>To incline away the
affections of; to excite a slight aversion in; to indispose; to make
unwilling; to alienate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Careful . . . to <qex>disincline</qex> them from any reverence or
affection to the Queen.</q> <rj><qau>Clarendon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To social scenes by nature <qex>disinclined</qex>.</q>
<rj><qau>Cowper.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disinclose</ent><br/
<hw>Dis`in*close"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Cf.
<er>Disenclose</er>.]</ety> <def>To free from being inclosed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disincorporate</ent><br/
<hw>Dis`in*cor"po*rate</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Disincorporated</conjf>
<pr>(?)</pr>; <pos>p. pr. & vb. n.</pos> <conjf>Disincorporating</conjf>
<pr>(?)</pr>.]</vmorph> <sn>1.</sn> <def>To deprive of corporate powers,
rights, or privileges; to divest of the condition of a corporate
body.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To detach or separate from a corporation.</def>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disincorporate</ent><br/
<hw>Dis`in*cor"po*rate</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Separated
from, or not included in, a corporation; disincorporated.</def>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disincorporation</ent><br/
<hw>Dis`in*cor`po*ra"tion</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Deprivation of the rights and privileges of a corporation.</def>
<rj><au>T. Warton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disinfect</ent><br/
<hw>Dis`in*fect"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Disinfected</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Disinfecting</conjf>.]</vmorph> <def>To free from infectious or
contagious matter; to destroy putrefaction; to purify; to make
innocuous.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>When the infectious matter and the infectious matter and the
odoriferous matter are one . . . then to deodorize is to
<qex>disinfect</qex>.</q> <rj><qau>Ure.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>disinfectant</ent><br/
<hw>dis`in*fect"ant</hw> <pr>(?)</pr>, <pos>n.</pos> <def>That which
disinfects, especially an agent for killing or removing the
microorganisms which cause infection. Commonly used disinfectants are
<examp>chlorine</examp>, <examp>sodium hypochlorite solution</examp>,
<examp>hydrogen peroxide</examp>, and <examp>alcohol</examp>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>disinfection</ent><br/
<hw>dis`in*fec"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
disinfecting; purification from infecting matter.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>disinfector</ent><br/
<hw>dis`in*fect"or</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or
that which, disinfects; an apparatus for applying
disinfectants.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disinflame</ent><br/
<hw>Dis`in*flame"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To divest of
flame or ardor.</def> <rj><au>Chapman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>disinflation</ent><br/
<hw>disinflation</hw> <pos>n.</pos> <sn>1.</sn> <def>a reduction in the
rate of price increases; a lessening of inflationary pressure.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>a reduction of the value of a currency in
international exchange markets caused by a government; -- usually done
as a means to improve the country's international balance of
payments.</def><br/
[<source>PJC</source>]</p>

<p><ent>Disingenuity</ent><br/
<hw>Dis*in`ge*nu"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Disingenuousness.</def> <mark>[Obs.]</mark>
<rj><au>Clarendon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disingenuous</ent><br/
<hw>Dis`in*gen"u*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Not noble; unbecoming true honor or dignity; mean; unworthy;
<as>as, <ex>disingenuous</ex> conduct or schemes</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Not ingenuous; wanting in noble candor or frankness;
not frank or open; uncandid; unworthily or meanly artful.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>So <qex>disingenuous</qex> as not to confess them [faults].</q>
<rj><qau>Pope.</qau></rj></p>

<p>-- <wordforms><wf>Dis`in*gen"u*ous*ly</wf>, <pos>adv.</pos> <au>T.
Warton.</au> -- <wf>Dis`in*gen"u*ous*ness</wf>,
<pos>n.</pos></wordforms> <rj><au>Macaulay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disinhabited</ent><br/
<hw>Dis`in*hab"it*ed</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Uninhabited.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disinherison</ent><br/
<hw>Dis`in*her"i*son</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Disinherit</er>, <pos>v. t.</pos>, and cf.
<er>Disherison</er>.]</ety> <def>Same as <er>Disherison</er>.</def>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disinherit</ent><br/
<hw>Dis`in*her"it</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Disinherited</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Disinheriting</conjf>.]</vmorph> <ety>[Cf. <er>Disherit</er>,
<er>Disheir</er>.]</ety> <sn>1.</sn> <def>To cut off from an inheritance
or from hereditary succession; to prevent, as an heir, from coming into
possession of any property or right, which, by law or custom, would
devolve on him in the course of descent.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Of how fair a portion Adam <qex>disinherited</qex> his whole
posterity!</q> <rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To deprive of heritage; to dispossess.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And <qex>disinherit</qex> Chaos, that reigns here.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disinheritance</ent><br/
<hw>Dis`in*her"it*ance</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
disinheriting, or the condition of being; disinherited;
disherison.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disinhume</ent><br/
<hw>Dis`in*hume"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To
disinter.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disinsure</ent><br/
<hw>Dis`in*sure"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To render
insecure; to put in danger.</def> <mark>[Obs.]</mark>
<rj><au>Fanshawe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disintegrable</ent><br/
<hw>Dis*in"te*gra*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of
being disintegrated, or reduced to fragments or powder.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Argillo-calcite is readily <qex>disintegrable</qex> by
exposure.</q> <rj><qau>Kirwan.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disintegrate</ent><br/
<hw>Dis*in"te*grate</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Disintegrated</conjf>; <pos>p.
pr. & vb. n.</pos> <conjf>Disintegrating</conjf>.]</vmorph> <ety>[L.
<ets>dis-</ets> + <ets>integratus</ets>, p. p. of <ets>integrare</ets>
to renew, repair, fr. <ets>integer</ets> entire, whole. See
<er>Integer</er>.]</ety> <def>To separate into integrant parts; to
reduce to fragments or to powder; to break up, or cause to fall to
pieces, as a rock, by blows of a hammer, frost, rain, and other
mechanical or atmospheric influences.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Marlites are not <qex>disintegrated</qex> by exposure to the
atmosphere, at least in six years.</q> <rj><qau>Kirwan.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disintegrate</ent><br/
<hw>Dis*in"te*grate</hw>, <pos>v. i.</pos> <def>To decompose into
integrant parts; <as>as, chalk rapidly
<ex>disintegrates</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disintegration</ent><br/
<hw>Dis*in`te*gra"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <sd>(a)</sd>
<def>The process by which anything is disintegrated; the condition of
anything which is disintegrated.</def> Specifically <sd>(b)</sd>
<fld>(Geol.)</fld> <def>The wearing away or falling to pieces of rocks
or strata, produced by atmospheric action, frost, ice, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Society had need of further <qex>disintegration</qex> before it
could begin to reconstruct itself locally.</q>
<rj><qau>Motley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disintegrator</ent><br/
<hw>Dis*in"te*gra`tor</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Mech.)</fld> <def>A machine for grinding or pulverizing by
percussion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disinter</ent><br/
<hw>Dis`in*ter"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Disinterred</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Disinterring</conjf>.]</vmorph> <sn>1.</sn> <def>To take
out of the grave or tomb; to unbury; to exhume; to dig up.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To bring out, as from a grave or hiding place; to
bring from obscurity into view.</def> <rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disinteress</ent><br/
<hw>Dis*in"ter*ess</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[F.
<ets>d<eacute/sint<eacute/resser</ets> to deprive of interest in; pref.
<ets>d<eacute/s-</ets> (L. <ets>dis-</ets>) +
<ets>int<eacute/resser</ets> to interest, fr. L. <ets>interesse</ets> to
import, concern. See <er>Interest</er>, and cf.
<er>Disinterest</er>.]</ety> <def>To deprive or rid of interest in, or
regard for; to disengage.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disinteressment</ent><br/
<hw>Dis*in"ter*ess*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>d<eacute/sint<eacute/ressement</ets>.]</ety>
<def>Disinterestedness; impartiality; fairness.</def>
<mark>[Obs.]</mark> <rj><au>Prior.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disinterest</ent><br/
<hw>Dis*in"ter*est</hw> <pr>(?)</pr>, <pos>p. a.</pos>
<def>Disinterested.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The measures they shall walk by shall be <qex>disinterest</qex>
and even.</q> <rj><qau>Jer. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disinterest</ent><br/
<hw>Dis*in"ter*est</hw>, <pos>n.</pos> <sn>1.</sn> <def>What is contrary
to interest or advantage; disadvantage.</def> <mark>[Obs.]</mark>
<rj><au>Glanvill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Indifference to profit; want of regard to private
advantage; disinterestedness.</def> <mark>[Obs.]</mark>
<rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disinterest</ent><br/
<hw>Dis*in"ter*est</hw>, <pos>v. t.</pos> <def>To divest of interest or
interested motives.</def> <mark>[Obs.]</mark>
<rj><au>Feltham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disinterested</ent><br/
<hw>Dis*in"ter*est*ed</hw>, <pos>a.</pos> <ety>[Cf.
<er>Disinteressed</er>.]</ety> <def>Not influenced by regard to personal
interest or advantage; free from selfish motive; having no relation of
interest or feeling; not biased or prejudiced; <as>as, a
<ex>disinterested</ex> decision or judge</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The happiness of <qex>disinterested</qex> sacrifices.</q>
<rj><qau>Channing.</qau></rj></p>

<p><syn><b>Syn.</b> -- Unbiased; impartial; uninterested;
indifferent.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disinterestedly</ent><br/
<hw>Dis*in"ter*est*ed*ly</hw>, <pos>adv.</pos> <def>In a disinterested
manner; without bias or prejudice.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disinterestedness</ent><br/
<hw>Dis*in"ter*est*ed*ness</hw>, <pos>n.</pos> <def>The state or quality
of being disinterested; impartiality.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That perfect <qex>disinterestedness</qex> and self-devotion of
which man seems to be incapable, but which is sometimes found in
woman.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disinteresting</ent><br/
<hw>Dis*in"ter*est*ing</hw>, <pos>a.</pos> <def>Uninteresting.</def>
<mark>[Obs.]</mark> <ldquo/<xex>Disinteresting</xex> passages.<rdquo/
<rj><au>Bp. Warburton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disinterment</ent><br/
<hw>Dis`in*ter"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
disinterring, or taking out of the earth; exhumation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disinthrall</ent><br/
<hw>Dis`in*thrall"</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Disinthralled</conjf>
<pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Disinthralling</conjf>.]</vmorph> <ety>[Pref. <ets>dis-</ets> +
<ets>inthrall</ets>. Cf. <er>Disenthrall</er>.]</ety> <def>To free from
thralldom; to disenthrall.</def> <altsp>[Written also
<asp>disinthral</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disinthrallment</ent><br/
<hw>Dis`in*thrall"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A releasing
from thralldom or slavery; disenthrallment.</def> <altsp>[Written also
<asp>disinthralment</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disintricate</ent><br/
<hw>Dis*in"tri*cate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To
disentangle.</def> <mark>[R.]</mark> <ldquo/To <xex>disintricate</xex>
the question.<rdquo/ <rj><au>Sir W. Hamilton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disinure</ent><br/
<hw>Dis`in*ure"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Disinured</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Disinuring</conjf>.]</vmorph> <ety>[Pref.
<ets>dis-</ets> + <ets>inure</ets>.]</ety> <def>To render unaccustomed
or unfamiliar.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We are hindered and <qex>disinured</qex> . . . towards the true
knowledge.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disinvestiture</ent><br/
<hw>Dis`in*ves"ti*ture</hw> <pr>(?; 135)</pr>, <pos>n.</pos> <def>The
act of depriving of investiture.</def> <mark>[Obs.]</mark>
<rj><au>Ogilvie.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disinvigorate</ent><br/
<hw>Dis`in*vig"or*ate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To
enervate; to weaken.</def> <mark>[R.]</mark> <rj><au>Sydney
Smith.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disinvolve</ent><br/
<hw>Dis`in*volve"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To uncover;
to unfold or unroll; to disentangle.</def> <mark>[R.]</mark> <rj><au>Dr.
H. More.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disjection</ent><br/
<hw>Dis*jec"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>disjicere</ets>, <ets>disjectum</ets>, to throw asunder, disperse;
<ets>dis-</ets> + <ets>jacere</ets> to throw.]</ety> <def>Destruction;
dispersion.</def> <rj><au>Bp. Horsley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>disk jockey</ent><br/
<hw>disk jockey</hw> <pos>n.</pos> <def>same as <er>disc
jockey</er>.</def><br/
<syn><b>Syn. --</b> DJ.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>diskjockey</ent><br/
<hw>diskjockey</hw> <pos>v. i.</pos> <def>to comment on music to be
played.</def><br/
<syn><b>Syn. --</b> DJ.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Disjoin</ent><br/
<hw>Dis*join"</hw> <pr>(d<icr/s*join")</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Disjoined</conjf>
<pr>(d<icr/s*joind")</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Disjoining</conjf>.]</vmorph> <ety>[OF. <ets>desjoindre</ets>, F.
<ets>disjoindre</ets>, <ets>d<eacute/joindre</ets>, fr. L.
<ets>disjungere</ets>; <ets>dis-</ets> + <ets>jungere</ets> to join. See
<er>Join</er>, and cf. <er>Disjoint</er>, <er>Disjunct</er>.]</ety>
<def>To part; to disunite; to separate; to sunder.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That marriage, therefore, God himself <qex>disjoins</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Never let us lay down our arms against France, till we have
utterly <qex>disjoined</qex> her from the Spanish monarchy.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Windmill Street consisted of <qex>disjoined</qex> houses.</q>
<rj><qau>Pennant.</qau></rj></p>

<p><syn><b>Syn.</b> -- To disunite; separate; detach; sever; dissever;
sunder; disconnect.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disjoin</ent><br/
<hw>Dis*join"</hw>, <pos>v. i.</pos> <def>To become separated; to
part.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>disjoined</ent><br/
<hw>disjoined</hw> <pos>adj.</pos> <def>unconnected, detached.</def>
<ant>joined</ant><br/
<syn><b>Syn. --</b> disconnected, separate.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Disjoint</ent><br/
<hw>Dis*joint"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OF.
<ets>desjoint</ets>, p. p. of <ets>desjoindre</ets>. See
<er>Disjoin</er>.]</ety> <def>Disjointed; unconnected; -- opposed to
<ant>conjoint</ant>.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disjoint</ent><br/
<hw>Dis*joint"</hw>, <pos>n.</pos> <ety>[From OF. <ets>desjoint</ets>,
p. p. of <ets>desjoindre</ets>. See <er>Disjoint</er>, <pos>v.
t.</pos>]</ety> <def>Difficult situation; dilemma; strait.</def>
<mark>[Obs.]</mark> <ldquo/I stand in such <xex>disjoint</xex>.<rdquo/
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disjoint</ent><br/
<hw>Dis*joint"</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Disjointed</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Disjointing</conjf>.]</vmorph> <sn>1.</sn> <def>To separate the
joints of; to separate, as parts united by joints; to put out of joint;
to force out of its socket; to dislocate; <as>as, to <ex>disjoint</ex>
limbs; to <ex>disjoint</ex> bones; to <ex>disjoint</ex> a fowl in
carving.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Yet what could swords or poisons, racks or flame,<br/
But mangle and <qex>disjoint</qex> the brittle frame?</q>
<rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To separate at junctures or joints; to break where
parts are united; to break in pieces; <as>as, <ex>disjointed</ex>
columns; to <ex>disjoint</ex> an edifice.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Some half-ruined wall<br/
<qex>Disjointed</qex> and about to fall.</q>
<rj><qau>Longfellow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To break the natural order and relations of; to make
incoherent; <as>as, a <ex>disjointed</ex> speech</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disjoint</ent><br/
<hw>Dis*joint"</hw>, <pos>v. i.</pos> <def>To fall in pieces.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disjointed</ent><br/
<hw>Dis*joint"ed</hw>, <pos>a.</pos> <def>Separated at the joints;
disconnected; incoherent.</def> -- <wordforms><wf>Dis*joint"ed*ly</wf>,
<pos>adv.</pos> -- <wf>Dis*joint"ed*ness</wf>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disjointly</ent><br/
<hw>Dis*joint"ly</hw>, <pos>adv.</pos> <def>In a disjointed state.</def>
<rj><au>Sandys.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disjudication</ent><br/
<hw>Dis*ju`di*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Judgment;
discrimination. See <er>Dijudication</er>.</def> <mark>[Obs.]</mark>
<rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disjunct</ent><br/
<hw>Dis*junct"</hw> <pr>(d<icr/s*j<ucr/<nsm/kt")</pr>, <pos>a.</pos>
<ety>[L. <ets>disjunctus</ets>, p. p. of <ets>disjungere</ets> to
disjoin. See <er>Disjoin</er>, and cf. <er>Disjoint</er>.]</ety>
<sn>1.</sn> <def>Disjoined; separated.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>Having the head, thorax, and
abdomen separated by a deep constriction.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Disjunct tetrachords</b></col> <fld>(Mus.)</fld>,
<cd>tetrachords so disposed to each other that the gravest note of the
upper is one note higher than the acutest note of the
other.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disjunction</ent><br/
<hw>Dis*junc"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>disjunctio</ets>.]</ety> <sn>1.</sn> <def>The act of disjoining;
disunion; separation; a parting; <as>as, the <ex>disjunction</ex> of
soul and body</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A disjunctive proposition.</def>
<rj><au>Coleridge.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disjunctive</ent><br/
<hw>Dis*junc"tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>disjunctivus</ets>: cf. F. <ets>disjonctif</ets>.]</ety>
<sn>1.</sn> <def>Tending to disjoin; separating; disjoining.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mus.)</fld> <def>Pertaining to disjunct
tetrachords.</def> <ldquo/<xex>Disjunctive</xex> notes.<rdquo/
<rj><au>Moore (Encyc. of Music).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Disjunctive conjunction</b></col> <fld>(Gram.)</fld>,
<cd>one connecting grammatically two words or clauses, expressing at the
same time an opposition or separation inherent in the notions or
thoughts; as, <xex>either</xex>, <xex>or</xex>, <xex>neither</xex>,
<xex>nor</xex>, <xex>but</xex>, <xex>although</xex>, <xex>except</xex>,
<xex>lest</xex>, etc.</cd> -- <col><b>Disjunctive proposition</b></col>,
<cd>a proposition in which the parts are connected by disjunctive
conjunctions, specifying that one of two or more propositions may hold,
but that no two propositions may hold at the same time; as it is
<xex>either</xex> day <xex>or</xex> night.</cd> -- <col><b>Disjunctive
syllogism</b></col> <fld>(Logic)</fld>, <cd>one in which the major
proposition is <xex>disjunctive</xex>; as, the earth moves in a circle
or an ellipse; but in does not move in a circle, therefore it moves in
an ellipse.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disjunctive</ent><br/
<hw>Dis*junc"tive</hw>, <pos>n.</pos> <sd>(a)</sd> <fld>(Gram.)</fld>
<def>A disjunctive conjunction.</def> <sd>(b)</sd> <fld>(Logic)</fld>
<def>A disjunctive proposition.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disjunctively</ent><br/
<hw>Dis*junc"tive*ly</hw>, <pos>adv.</pos> <def>In a disjunctive manner;
separately.</def> <rj><au>Dr. H. More.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disjuncture</ent><br/
<hw>Dis*junc"ture</hw> <pr>(?; 135)</pr>, <pos>n.</pos> <def>The act of
disjoining, or state of being disjoined; separation.</def>
<rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disk</ent><br/
<hw>Disk</hw> <pr>(d<icr/sk)</pr>, <pos>n.</pos> <ety>[L.
<ets>discus</ets>, Gr. <grk>di`skos</grk>. See <er>Dish</er>.]</ety>
<altsp>[Written also <asp>disc</asp>.]</altsp> <sn>1.</sn> <def>A
discus; a quoit.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Some whirl the <qex>disk</qex>, and some the javelin dart.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A flat, circular plate; <as>as, a <ex>disk</ex> of
metal or paper</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Astron.)</fld> <def>The circular figure of a
celestial body, as seen projected of the heavens.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Biol.)</fld> <def>A circular structure either in
plants or animals; <as>as, a blood <ex>disk</ex>; germinal
<ex>disk</ex>, etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Bot.)</fld> <sd>(a)</sd> <def>The whole surface of
a leaf.</def> <sd>(b)</sd> <def>The central part of a radiate compound
flower, as in sunflower.</def> <sd>(c)</sd> <def>A part of the
receptacle enlarged or expanded under, or around, or even on top of, the
pistil.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Zool.)</fld> <sd>(a)</sd> <def>The anterior surface
or oral area of c<oe/lenterate animals, as of sea anemones.</def>
<sd>(b)</sd> <def>The lower side of the body of some invertebrates,
especially when used for locomotion, when it is often called a
<xex>creeping disk</xex>.</def> <sd>(c)</sd> <def>In owls, the space
around the eyes.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Disk engine</b></col>, <cd>a form of rotary steam
engine.</cd> -- <col><b>Disk shell</b></col> <fld>(Zool.)</fld>, <cd>any
species of Discina.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disk clutch</ent><br/
<hw>Disk clutch</hw>. <fld>(Engin.)</fld> <def>A friction clutch in
which the gripping surfaces are disks or more or less resemble
disks.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>diskette</ent><br/
<hw>diskette</hw> <pos>n.</pos> <fld>(Computers)</fld> <def>a
data-storage medium consisting of a small plastic disk coated with a
thin layer of magnetizable material on one or both sides, enclosed in a
stiff envelope with a radial slit. It is used in a specially designed
<usedby>disk drive</usedby>, in which the disk is rotated at high speed,
and which stores data on the disk by causing changes in the direction of
magnetization of the magnetic layer as the disk spins and as sequential
locations on the disk pass under the read-write head of the drive.
Reading of the data occurs in the reverse process, by detection of the
patterns of magnetization of the disk. Such disks are used to store data
or programs for a microcomputer.</def><br/
<syn><b>Syn. --</b> floppy, floppy disk.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>diskindness</ent><br/
<hw>dis*kind"ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Unkindness;
disservice.</def> <mark>[R.]</mark> <rj><au>A. Tucker.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diskless</ent><br/
<hw>Disk"less</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having no disk;
appearing as a point and not expanded into a disk, as the image of a
faint star in a telescope.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>disklike</ent><br/
<hw>disklike</hw> <pos>adj.</pos> <def>resembling a disk in shape;
circular and having a height considerably smaller than the
diameter.</def><br/
<syn><b>Syn. --</b> discoid, discoidal.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Dislade</ent><br/
<hw>Dis*lade"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To unlade.</def>
<mark>[Obs.]</mark> <rj><au>Heywood.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disleal</ent><br/
<hw>Dis*leal"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Disloyal</er>, <er>Leal</er>.]</ety> <def>Disloyal;
perfidious.</def> <mark>[Obs.]</mark> <ldquo/<xex>Disleal</xex>
knight.<rdquo/ <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 427 --></p>

<p><ent>Disleave</ent><br/
<hw>Dis*leave"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To deprive of
leaves.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The cankerworms that annually that <qex>disleaved</qex> the
elms.</q> <rj><qau>Lowell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dislike</ent><br/
<hw>Dis*like"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Disliked</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Disliking</conjf>.]</vmorph> <sn>1.</sn> <def>To regard
with dislike or aversion; to disapprove; to disrelish.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Every nation <qex>dislikes</qex> an impost.</q>
<rj><qau>Johnson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To awaken dislike in; to displease.</def>
<ldquo/<xex>Disliking</xex> countenance.<rdquo/ <au>Marston.</au>
<ldquo/It <xex>dislikes</xex> me.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>dislike</ent><br/
<hw>dis*like"</hw>, <pos>n.</pos> <sn>1.</sn> <def>A feeling of positive
and usually permanent aversion to something unpleasant, uncongenial, or
offensive; disapprobation; repugnance; displeasure; disfavor; -- the
opposite of <xex>liking</xex> or <xex>fondness</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>God's grace . . . gives him continual <qex>dislike</qex> to
sin.</q> <rj><qau>Hammond.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The hint malevolent, the look oblique,<br/
The obvious satire, or implied <qex>dislike</qex>.</q> <rj><qau>Hannah
More.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>We have spoken of the <qex>dislike</qex> of these excellent women
for Sheridan and Fox.</q> <rj><qau>J. Morley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>His <qex>dislike</qex> of a particular kind of sensational
stories.</q> <rj><qau>A. W. Ward.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Discord; dissension.</def> <mark>[Obs.]</mark>
<rj><au>Fairfax.</au></rj></p>

<p><syn><b>Syn.</b> -- Distaste; disinclination; disapprobation;
disfavor; disaffection; displeasure; disrelish; aversion; reluctance;
repugnance; disgust; antipathy. -- <er>Dislike</er>, <er>Aversion</er>,
<er>Reluctance</er>, <er>Repugnance</er>, <er>Disgust</er>,
<er>Antipathy</er>. <xex>Dislike</xex> is the more general term,
applicable to both persons and things and arising either from feeling or
judgment. It may mean little more than want of positive liking; but
<xex>antipathy</xex>, <xex>repugnance</xex>, <xex>disgust</xex>, and
<xex>aversion</xex> are more intense phases of <xex>dislike</xex>.
<xex>Aversion</xex> denotes a fixed and habitual dislike; <as>as, an
<ex>aversion</ex> to or for business</as>. <xex>Reluctance</xex> and
<xex>repugnance</xex> denote a mental strife or hostility something
proposed (<xex>repugnance</xex> being the stronger); <as>as, a
<ex>reluctance</ex> to make the necessary sacrifices, and a
<ex>repugnance</ex> to the submission required</as>. <xex>Disgust</xex>
is repugnance either of taste or moral feeling; <as>as, a
<ex>disgust</ex> at gross exhibitions of selfishness</as>.
<xex>Antipathy</xex> is primarily an instinctive feeling of dislike of a
thing, such as most persons feel for a snake. When used figuratively, it
denotes a correspondent dislike for certain persons, modes of acting,
etc. Men have an <xex>aversion</xex> to what breaks in upon their
habits; a <xex>reluctance</xex> and <xex>repugnance</xex> to what
crosses their will; a <xex>disgust</xex> at what offends their
sensibilities; and are often governed by <xex>antipathies</xex> for
which they can give no good reason.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>dislikeful</ent><br/
<hw>dis*like"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Full of dislike;
disaffected; malign; disagreeable.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>dislikelihood</ent><br/
<hw>dis*like"li*hood</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The want of
likelihood; improbability.</def> <rj><au>Sir W. Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disliken</ent><br/
<hw>Dis*lik"en</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To make unlike;
to disguise.</def> <mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dislikeness</ent><br/
<hw>Dis*like"ness</hw>, <pos>n.</pos> <def>Unlikeness.</def>
<mark>[R.]</mark> <rj><au>Locke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disliker</ent><br/
<hw>Dis*lik"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who dislikes or
disrelishes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dislimb</ent><br/
<hw>Dis*limb"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To tear limb from
limb; to dismember.</def> <mark>[Obs.]</mark>
<rj><au>Bailey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dislimn</ent><br/
<hw>Dis*limn"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>dis-</ets> + <ets>limn</ets>.]</ety> <def>To efface, as a
picture.</def> <mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dislink</ent><br/
<hw>Dis*link"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To unlink; to
disunite; to separate.</def> <mark>[R.]</mark>
<rj><au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dislive</ent><br/
<hw>Dis*live"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To deprive of
life.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Telemachus <qex>dislived</qex> Amphimedon.</q>
<rj><qau>Chapman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dislocate</ent><br/
<hw>Dis"lo*cate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Dislocated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Dislocating</conjf> <pr>(?)</pr>.]</vmorph> <ety>[LL.
<ets>dislocatus</ets>, p. p. of <ets>dislocare</ets>; <ets>dis-</ets> +
<ets>locare</ets> to place, fr. <ets>locus</ets> place. See
<er>Locus</er>.]</ety> <def>To displace; to put out of its proper place.
Especially, of a bone: To remove from its normal connections with a
neighboring bone; to put out of joint; to move from its socket; to
disjoint; <as>as, to <ex>dislocate</ex> your bones</as>.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>After some time the strata on all sides of the globe were
<qex>dislocated</qex>.</q> <rj><qau>Woodward.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And thus the archbishop's see, <qex>dislocated</qex> or out of
joint for a time, was by the hands of his holiness set right again.</q>
<rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dislocate</ent><br/
<hw>Dis"lo*cate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[LL.
<ets>dislocatus</ets>, p. p.]</ety> <def>Dislocated.</def>
<rj><au>Montgomery.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>dislocated</ent><br/
<hw>dislocated</hw> <pos>adj.</pos> <def>separated at the joint; -- used
especially of limbs; <as>as, a <ex>dislocated</ex> knee</as>.</def><br/
<syn><b>Syn. --</b> disjointed, separated.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dislocation</ent><br/
<hw>Dis`lo*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>dislocation</ets>.]</ety> <sn>1.</sn> <def>The act of displacing,
or the state of being displaced.</def> <rj><au>T. Burnet.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Geol.)</fld> <def>The displacement of parts of
rocks or portions of strata from the situation which they originally
occupied. Slips, faults, and the like, are
<xex>dislocations</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Surg.)</fld> <def>The act of dislocating, or
putting out of joint; also, the condition of being thus
displaced.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dislodge</ent><br/
<hw>Dis*lodge"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Dislodged</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Dislodging</conjf>.]</vmorph> <ety>[OF.
<ets>deslogier</ets>, F. <ets>d<eacute/loger</ets>; pref.
<ets>des-</ets> (L. <ets>dis-</ets>) + OF. <ets>logier</ets>, F.
<ets>loger</ets>. See <er>Lodge</er>.]</ety> <sn>1.</sn> <def>To drive
from a lodge or place of rest; to remove from a place of quiet or
repose; <as>as, shells resting in the sea at a considerate depth are not
<ex>dislodged</ex> by storms</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To drive out from a place of hiding or defense;
<as>as, to <ex>dislodge</ex> a deer, or an enemy</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The Volscians are <qex>dislodg'd</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dislodge</ent><br/
<hw>Dis*lodge"</hw>, <pos>v. i.</pos> <def>To go from a place of
rest.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Where Light and Darkness in perpetual round<br/
Lodge and <qex>dislodge</qex> by turns.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dislodge</ent><br/
<hw>Dis*lodge"</hw>, <pos>n.</pos> <def>Dwelling apart;
separation.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>dislodgement</ent><br/
<hw>dislodgement</hw> <pos>n.</pos> <sn>1.</sn> <def>forced removal from
a position of advantage.</def><br/
<syn><b>Syn. --</b> dislodgment.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>dislodgment.</def><br/
[<source>PJC</source>]</p>

<p><ent>Dislodgment</ent><br/
<hw>Dis*lodg"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>d<eacute/logement</ets>, OF. <ets>deslogement</ets>.]</ety>
<def>The act or process of dislodging, or the state of being
dislodged.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disloign</ent><br/
<hw>Dis*loign"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[OF.
<ets>desloignier</ets>. See <er>Eloign</er>.]</ety> <def>To put at a
distance; to remove.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Low-looking dales, <qex>disloigned</qex> from common gaze.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disloyal</ent><br/
<hw>Dis*loy"al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>dis-</ets> + <ets>loyal</ets>: cf. OF. <ets>desloial</ets>,
<ets>desleal</ets>, F. <ets>d<eacute/loyal</ets>. See
<er>Loyal</er>.]</ety> <def>Not loyal; not true to a sovereign or lawful
superior, or to the government under which one lives; false where
allegiance is due; faithless; <as>as, a subject <ex>disloyal</ex> to the
king; a husband <ex>disloyal</ex> to his wife.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Without a thought <qex>disloyal</qex>.</q> <rj><qau>Mrs.
Browning.</qau></rj></p>

<p><syn><b>Syn.</b> -- Disobedient; faithless; untrue; treacherous;
perfidious; dishonest; inconstant; disaffected.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disloyally</ent><br/
<hw>Dis*loy"al*ly</hw>, <pos>adv.</pos> <def>In a disloyal
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disloyalty</ent><br/
<hw>Dis*loy"al*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>dis-</ets> + <ets>loyalty</ets>: cf. OF.
<ets>desloiaut<eacute/</ets>, <ets>deslealt<eacute/</ets>, F.
<ets>d<eacute/loyaut<eacute/</ets>.]</ety> <def>Want of loyalty; lack of
fidelity; violation of allegiance.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dismail</ent><br/
<hw>Dis*mail"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>dis-</ets> + <ets>mail</ets>: cf. OF.
<ets>desmaillier</ets>.]</ety> <def>To divest of coat of mail.</def>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dismal</ent><br/
<hw>Dis"mal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Formerly a noun;
<it>e. g.</it>, <ldquo/I trow it was in the <ets>dismalle</ets>.<rdquo/
<ets>Chaucer</ets>. Of uncertain origin; but perh. (as suggested by
Skeat) from OF. <ets>disme</ets>, F. <ets>d<icir/me</ets>, tithe, the
phrase <ets>dismal day</ets> properly meaning, the day when tithes must
be paid. See <er>Dime</er>.]</ety> <sn>1.</sn> <def>Fatal; ill-omened;
unlucky.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>An ugly fiend more foul than <qex>dismal</qex> day.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Gloomy to the eye or ear; sorrowful and depressing
to the feelings; foreboding; cheerless; dull; dreary; <as>as, a
<ex>dismal</ex> outlook; <ex>dismal</ex> stories; a <ex>dismal</ex>
place.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Full well the busy whisper, circling round,<br/
Convey'd the <qex>dismal</qex> tidings when he frowned.</q>
<rj><qau>Goldsmith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>dismal</qex> description of an English November.</q>
<rj><qau>Southey.</qau></rj></p>

<p><syn><b>Syn.</b> -- Dreary; lonesome; gloomy; dark; ominous;
ill-boding; fatal; doleful; lugubrious; funereal; dolorous; calamitous;
sorrowful; sad; joyless; melancholy; unfortunate; unhappy.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dismally</ent><br/
<hw>Dis"mal*ly</hw>, <pos>adv.</pos> <def>In a dismal manner; gloomily;
sorrowfully; uncomfortably.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dismalness</ent><br/
<hw>Dis"mal*ness</hw>, <pos>n.</pos> <def>The quality of being dismal;
gloominess.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disman</ent><br/
<hw>Dis*man"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To unman.</def>
<mark>[Obs.]</mark> <rj><au>Feltham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dismantle</ent><br/
<hw>Dis*man"tle</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Dismantled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Dismantling</conjf> <pr>(?)</pr>.]</vmorph> <ety>[F.
<ets>d<eacute/manteler</ets>, OF. <ets>desmanteler</ets>; pref:
<ets>des-</ets> (L. <ets>dis-</ets>) + <ets>manteler</ets> to cover with
a cloak, defend, fr. <ets>mantel</ets>, F. <ets>manteau</ets>, cloak.
See <er>Mantle</er>.]</ety> <sn>1.</sn> <def>To strip or deprive of
dress; to divest.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To strip of furniture and equipments, guns, etc.; to
unrig; to strip of walls or outworks; to break down; <as>as, to
<ex>dismantle</ex> a fort, a town, or a ship</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>dismantled</qex> house, without windows or shutters to keep
out the rain.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To disable; to render useless.</def>
<rj><au>Comber.</au></rj></p>

<p><syn><b>Syn.</b> -- To demolish; raze. See
<er>Demolish</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dismarch</ent><br/
<hw>Dis*march"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To march
away.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dismarry</ent><br/
<hw>Dis*mar"ry</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>dis-</ets> + <ets>marry</ets>: cf. OF. <ets>desmarier</ets>, F.
<ets>d<eacute/marier</ets>.]</ety> <def>To free from the bonds of
marriage; to divorce.</def> <mark>[Obs.]</mark> <rj><au>Ld.
Berners.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dismarshal</ent><br/
<hw>Dis*mar"shal</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To disarrange;
to derange; to put in disorder.</def> <mark>[R.]</mark>
<rj><au>Drummond.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dismask</ent><br/
<hw>Dis*mask"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>dis-</ets> + <ets>mask</ets>: cf. F.
<ets>d<eacute/masquer</ets>.]</ety> <def>To divest of a mask.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dismast</ent><br/
<hw>Dis*mast"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Dismasted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Dismasting</conjf>.]</vmorph> <ety>[Pref. <ets>dis-</ets> +
<ets>mast</ets>: cf. F. <ets>d<eacute/m<acir/ter</ets>.]</ety> <def>To
deprive of a mast of masts; to break and carry away the masts from;
<as>as, a storm <ex>dismasted</ex> the ship</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dismastment</ent><br/
<hw>Dis*mast"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
dismasting; the state of being dismasted.</def> <mark>[R.]</mark>
<rj><au>Marshall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dismaw</ent><br/
<hw>Dis*maw"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To eject from the
maw; to disgorge.</def> <mark>[R.]</mark> <rj><au>Shelton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dismay</ent><br/
<hw>Dis*may"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Dismayed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Dismaying</conjf>.]</vmorph> <ety>[OE.
<ets>desmaien</ets>, <ets>dismaien</ets>, OF. <ets>esmaier</ets>; pref.
<ets>es-</ets> (L. <ets>ex</ets>) + OHG. <ets>magan</ets> to be strong
or able; akin to E. <ets>may</ets>. In English the pref. <ets>es-</ets>
was changed to <ets>dis-</ets> (L. <ets>dis-</ets>). See <er>May</er>,
<pos>v. i.</pos>]</ety> <sn>1.</sn> <def>To disable with alarm or
apprehensions; to depress the spirits or courage of; to deprive or
firmness and energy through fear; to daunt; to appall; to
terrify.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Be not afraid, neither be thou <qex>dismayed</qex>.</q>
<rj><qau>Josh. i. 9.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>What words be these? What fears do you <qex>dismay</qex>?</q>
<rj><qau>Fairfax.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To render lifeless; to subdue; to disquiet.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Do not <qex>dismay</qex> yourself for this.</q>
<rj><qau>Spenser.</qau></rj></p>

<p><syn><b>Syn.</b> -- To terrify; fright; affright; frighten; appall;
daunt; dishearthen; dispirit; discourage; deject; depress. -- To
<er>Dismay</er>, <er>Daunt</er>, <er>Appall</er>. <xex>Dismay</xex>
denotes a state of deep and gloomy apprehension. To <xex>daunt</xex>
supposes something more sudden and startling. To <xex>appall</xex> is
the strongest term, implying a sense of terror which overwhelms the
faculties.</syn><br/
[<source>1913 Webster</source>]</p>

<p><q>So flies a herd of beeves, that hear, <qex>dismayed</qex>,<br/
The lions roaring through the midnight shade.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Jove got such heroes as my sire, whose soul<br/
No fear could <qex>daunt</qex>, nor earth nor hell control.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Now the last ruin the whole host <qex>appalls</qex>;<br/
Now Greece has trembled in her wooden walls.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dismay</ent><br/
<hw>Dis*may"</hw>, <pos>v. i.</pos> <def>To take dismay or fright; to be
filled with dismay.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dismay</ent><br/
<hw>Dis*may"</hw>, <pos>n.</pos> <ety>[Cf. OF. <ets>esmai</ets>, F.
<ets><eacute/moi</ets>. See <er>Dismay</er>, <pos>v. t.</pos>]</ety>
<sn>1.</sn> <def>Loss of courage and firmness through fear; overwhelming
and disabling terror; a sinking of the spirits; consternation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I . . . can not think of such a battle without
<qex>dismay</qex>.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou with a tiger spring dost leap upon thy prey,<br/
And tear his helpless breast, o'erwhelmed with wild
<qex>dismay</qex>.</q> <rj><qau>Mrs. Barbauld.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Condition fitted to dismay; ruin.</def>
<rj><au>Spenser.</au></rj></p>

<p><syn><b>Syn.</b> -- Dejection; discouragement; depression; fear;
fright; terror; apprehension; alarm; affright.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dismayedness</ent><br/
<hw>Dis*may"ed*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A state of
being dismayed; dejection of courage; dispiritedness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dismayful</ent><br/
<hw>Dis*may"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Terrifying.</def>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disme</ent><br/
\'d8<hw>Disme</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF. See
<er>Dime</er>.]</ety> <def>A tenth; a tenth part; a tithe.</def>
<rj><au>Ayliffe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dismember</ent><br/
<hw>Dis*mem"ber</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Dismembered</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Dismembering</conjf>.]</vmorph> <ety>[OF.
<ets>desmembrer</ets>, F. <ets>d<eacute/membrer</ets>; pref.
<ets>des-</ets> (L. <ets>dis</ets>) + OF. & F. <ets>membre</ets> limb.
See <er>Member</er>.]</ety> <sn>1.</sn> <def>To tear limb from limb; to
dilacerate; to disjoin member from member; to tear or cut in pieces; to
break up.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Fowls obscene <qex>dismembered</qex> his remains.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A society lacerated and <qex>dismembered</qex>.</q>
<rj><qau>Gladstone.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>By whose hands the blow should be struck which would
<qex>dismember</qex> that once mighty empire.</q>
<rj><qau>Buckle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To deprive of membership.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>They were <qex>dismembered</qex> by vote of the house.</q>
<rj><qau>R. North.</qau></rj></p>

<p><syn><b>Syn.</b> -- To disjoint; dislocate; dilacerate; mutilate;
divide; sever.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dismemberment</ent><br/
<hw>Dis*mem"ber*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. OF.
<ets>desmembrement</ets>, F. <ets>d<eacute/membrement</ets>.]</ety>
<def>The act of dismembering, or the state of being dismembered; cutting
in piece; mutilation; division; separation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The Castilians would doubtless have resented the
<qex>dismemberment</qex> of the unwieldy body of which they formed the
head.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dismettled</ent><br/
<hw>Dis*met"tled</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Destitute of
mettle, that is, or fire or spirit.</def> <mark>[R.]</mark>
<rj><au>Llewellyn.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dismiss</ent><br/
<hw>Dis*miss"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Dismissed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Dismissing</conjf>.]</vmorph> <ety>[L. <ets>dis-</ets> +
<ets>missus</ets>, p. p. of <ets>mittere</ets> to send: cf.
<ets>dimittere</ets>, OF. <ets>desmetre</ets>, F.
<ets>d<eacute/mettre</ets>. See <er>Demise</er>, and cf.
<er>Dimit</er>.]</ety> <sn>1.</sn> <def>To send away; to give leave of
departure; to cause or permit to go; to put away.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He <qex>dismissed</qex> the assembly.</q> <rj><qau>Acts xix.
41.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Dismiss</qex> their cares when they <qex>dismiss</qex> their
flock.</q> <rj><qau>Cowper.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Though he soon <qex>dismissed</qex> himself from state
affairs.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To discard; to remove or discharge from office,
service, or employment; <as>as, the king <ex>dismisses</ex> his
ministers; the matter <ex>dismisses</ex> his servant.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To lay aside or reject as unworthy of attentions or
regard, as a petition or motion in court.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dismiss</ent><br/
<hw>Dis*miss"</hw>, <pos>n.</pos> <def>Dismission.</def>
<mark>[Obs.]</mark> <rj><au>Sir T. Herbert.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dismissal</ent><br/
<hw>Dis*miss"al</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Dismission;
discharge.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Officeholders were commanded faithfully to enforce it, upon pain
of immediate <qex>dismissal</qex>.</q> <rj><qau>Motley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>dismissible</ent><br/
<hw>dismissible</hw> <pos>adj.</pos> <def>subject to
dismissal.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dismission</ent><br/
<hw>Dis*mis"sion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. L.
<ets>dimissio</ets>.]</ety> <sn>1.</sn> <def>The act dismissing or
sending away; permission to leave; leave to depart; dismissal; <as>as,
the <ex>dismission</ex> of the grand jury</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Removal from office or employment; discharge, either
with honor or with disgrace.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Rejection; a setting aside as trivial, invalid, or
unworthy of consideration.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dismissive</ent><br/
<hw>Dis*miss"ive</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Giving
dismission.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dismortgage</ent><br/
<hw>Dis*mort"gage</hw> <pr>(?; 48)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Dismortaged</conjf>; <pos>p. pr.
& vb. n.</pos> <conjf>Dismortgaging</conjf> <pr>(?)</pr>.]</vmorph>
<def>To redeem from mortgage.</def> <mark>[Obs.]</mark>
<rj><au>Howell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dismount</ent><br/
<hw>Dis*mount"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Dismounted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Dismounting</conjf>.]</vmorph> <ety>[Pref. <ets>dis-</ets> +
<ets>mount</ets>: cf. OF. <ets>desmonter</ets>, F.
<ets>d<eacute/monter</ets>.]</ety> <sn>1.</sn> <def>To come down; to
descend.</def> <mark>[Poetic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>But now the bright sun ginneth to <qex>dismount</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To alight from a horse; to descend or get off, as a
rider from his beast; <as>as, the troops
<ex>dismounted</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dismount</ent><br/
<hw>Dis*mount"</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To throw or bring
down from an elevation, place of honor and authority, or the
like.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Dismounted</qex> from his authority.</q>
<rj><qau>Barrow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To throw or remove from a horse; to unhorse; <as>as,
the soldier <ex>dismounted</ex> his adversary</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Mech.)</fld> <def>To take down, or apart, as a
machine.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To throw or remove from the carriage, or from that
on which a thing is mounted; to break the carriage or wheels of, and
render useless; to deprive of equipments or mountings; -- said esp. of
artillery.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disnaturalize</ent><br/
<hw>Dis*nat"u*ral*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To make
alien; to deprive of the privileges of birth.</def>
<rj><au>Locke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disnatured</ent><br/
<hw>Dis*na"tured</hw> <pr>(?; 135)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>dis-</ets> + <ets>nature</ets>: cf. OF.
<ets>desnatur<eacute/</ets>, F.
<ets>d<eacute/natur<eacute/</ets>.]</ety> <def>Deprived or destitute of
natural feelings; unnatural.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disobedience</ent><br/
<hw>Dis`o*be"di*ence</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Neglect or
refusal to obey; violation of a command or prohibition.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He is undutiful to him other actions, and lives in open
<qex>disobedience</qex>.</q> <rj><qau>Tillotson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disobediency</ent><br/
<hw>Dis`o*be"di*en*cy</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Disobedience.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disobedient</ent><br/
<hw>Dis`o*be"di*ent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>dis-</ets> + <ets>obedient</ets>. See <er>Disobey</er>,
<er>Obedient</er>.]</ety> <sn>1.</sn> <def>Neglecting or refusing to
obey; omitting to do what is commanded, or doing what is prohibited;
refractory; not observant of duty or rules prescribed by authority; --
applied to persons and acts.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This <qex>disobedient</qex> spirit in the colonies.</q>
<rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Disobedient</qex> unto the word of the Lord.</q> <rj><qau>1
Kings xiii. 26.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Not yielding.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Medicines used unnecessarily contribute to shorten life, by sooner
rendering peculiar parts of the system <qex>disobedient</qex> to
stimuli.</q> <rj><qau>E. Darwin.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disobediently</ent><br/
<hw>Dis`o*be"di*ent*ly</hw>, <pos>adv.</pos> <def>In a disobedient
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disobeisance</ent><br/
<hw>Dis`o*bei"sance</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>d<eacute/sob<eacute/issance</ets>.]</ety> <def>Disobedience.</def>
<mark>[Obs.]</mark> <rj><au>E. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disobeisant</ent><br/
<hw>Dis`o*bei"sant</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F.
<ets>d<eacute/sob<eacute/issant</ets>.]</ety> <def>Disobedient.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disobey</ent><br/
<hw>Dis`o*bey"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Disobeyed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Disobeying</conjf>.]</vmorph> <ety>[F.
<ets>d<eacute/sob<eacute/ir</ets>; pref. <ets>d<eacute/s-</ets> (L.
<ets>dis-</ets>) + <ets>ob<eacute/ir</ets>. See <er>Obey</er>, and cf.
<er>Disobedient</er>.]</ety> <def>Not to obey; to neglect or refuse to
obey (a superior or his commands, the laws, etc.); to transgress the
commands of (one in authority); to violate, as an order; <as>as,
refractory children <ex>disobey</ex> their parents; men <ex>disobey</ex>
their Maker and the laws.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Not to <qex>disobey</qex> her lord's behest.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disobey</ent><br/
<hw>Dis`o*bey"</hw>, <pos>v. i.</pos> <def>To refuse or neglect to obey;
to violate commands; to be disobedient.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He durst not know how to <qex>disobey</qex>.</q> <rj><qau>Sir P.
Sidney.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disobeyer</ent><br/
<hw>Dis`o*bey"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
disobeys.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disobligation</ent><br/
<hw>Dis*ob`li*ga"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>The act of disobliging.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A disobliging act; an offense.</def>
<mark>[Obs.]</mark> <rj><au>Clarendon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Release from obligation.</def> <rj><au>Jer.
Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disobligatory</ent><br/
<hw>Dis*ob"li*ga*to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Releasing
from obligation.</def> <ldquo/<xex>Disobligatory</xex> power.<rdquo/
<rj><au>Charles I.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disoblige</ent><br/
<hw>Dis`o*blige"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Disobliged</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Disobliging</conjf>.]</vmorph> <ety>[Pref.
<ets>dis-</ets> + <ets>oblige</ets>: cf. F.
<ets>d<eacute/sobliger</ets>.]</ety> <sn>1.</sn> <def>To do an act which
contravenes the will or desires of; to offend by an act of unkindness or
incivility; to displease; to refrain from obliging; to be
unaccommodating to.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Those . . . who slight and <qex>disoblige</qex> their friends,
shall infallibly come to know the value of them by having none when they
shall most need them.</q> <rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>My plan has given offense to some gentlemen, whom it would not be
very safe to <qex>disoblige</qex>.</q> <rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 428 --></p>

<p><sn>2.</sn> <def>To release from obligation.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Absolving and <qex>disobliging</qex> from a more general command
for some just and reasonable cause.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disobligement</ent><br/
<hw>Dis`o*blige"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Release from
obligation.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disobliger</ent><br/
<hw>Dis`o*bli"ger</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
disobliges.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disobliging</ent><br/
<hw>Dis`o*bli"ging</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Not
obliging; not disposed to do a favor; unaccommodating; <as>as, a
<ex>disobliging</ex> person or act</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Displeasing; offensive.</def> <mark>[Obs.]</mark>
<rj><au>Cov. of Tongue.</au></rj></p>

<p>-- <wordforms><wf>Dis`o*bli"ging*ly</wf>, <pos>adv.</pos> --
<wf>Dis`o*bli"ging*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disoccident</ent><br/
<hw>Dis*oc"ci*dent</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To turn away
from the west; to throw out of reckoning as to longitude.</def>
<mark>[Obs.]</mark> <rj><au>Marvell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disoccupation</ent><br/
<hw>Dis*oc`cu*pa"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state of
being unemployed; want of occupation.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disopinion</ent><br/
<hw>Dis`o*pin"ion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Want or
difference of belief; disbelief.</def> <mark>[Obs.]</mark> <rj><au>Bp.
Reynolds.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disoppilate</ent><br/
<hw>Dis*op"pi*late</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>dis-</ets> + <ets>oppilatus</ets>, p. p. of <ets>oppilare</ets> to
shut up.]</ety> <def>To open.</def> <mark>[Obs.]</mark>
<rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disorb</ent><br/
<hw>Dis*orb"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>dis-</ets> + <ets>orb</ets>.]</ety> <def>To throw out of the proper
orbit; to unsphere.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disord</ent><br/
<hw>Dis*ord"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Disorder.</def>
<mark>[Obs.]</mark> <rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disordeined</ent><br/
<hw>Dis`or*deined"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Ordain</er>.]</ety> <def>Inordinate; irregular; vicious.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disorder</ent><br/
<hw>Dis*or"der</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>dis-</ets> + <ets>order</ets>: cf. F.
<ets>d<eacute/sordre</ets>.]</ety> <sn>1.</sn> <def>Want of order or
regular disposition; lack of arrangement; confusion; disarray; <as>as,
the troops were thrown into <ex>disorder</ex>; the papers are in
<ex>disorder</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Neglect of order or system; irregularity.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>From vulgar bounds with brave <qex>disorder</qex> part,<br/
And snatch a grace beyond the reach of art.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Breach of public order; disturbance of the peace of
society; tumult.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Disturbance of the functions of the animal economy
or of the soul; sickness; derangement.</def> <ldquo/<xex>Disorder</xex>
in the body.<rdquo/ <rj><au>Locke.</au></rj></p>

<p><syn><b>Syn.</b> -- Irregularity; disarrangement; confusion; tumult;
bustle; disturbance; disease; illness; indisposition; sickness; ailment;
malady; distemper. See <er>Disease</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disorder</ent><br/
<hw>Dis*or"der</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Disordered</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Disordering</conjf>.]</vmorph> <sn>1.</sn> <def>To disturb the
order of; to derange or disarrange; to throw into confusion; to
confuse.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Disordering</qex> the whole frame or jurisprudence.</q>
<rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The burden . . . <qex>disordered</qex> the aids and auxiliary
rafters into a common ruin.</q> <rj><qau>Jer. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To disturb or interrupt the regular and natural
functions of (either body or mind); to produce sickness or indisposition
in; to discompose; to derange; <as>as, to <ex>disorder</ex> the head or
stomach</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A man whose judgment was so much <qex>disordered</qex> by party
spirit.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To depose from holy orders.</def>
<mark>[Obs.]</mark> <rj><au>Dryden.</au></rj></p>

<p><syn><b>Syn.</b> -- To disarrange; derange; confuse;
discompose.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disordered</ent><br/
<hw>Dis*or"dered</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Thrown into disorder; deranged; <as>as, a <ex>disordered</ex>
house, judgment</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Disorderly.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj></p>

<p>-- <wordforms><wf>Dis*or"dered*ly</wf>, <pos>adv.</pos> --
<wf>Dis*or"dered*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disorderliness</ent><br/
<hw>Dis*or"der*li*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state
of being disorderly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disorderly</ent><br/
<hw>Dis*or"der*ly</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Not
in order; marked by disorder; disarranged; immethodical; <as>as, the
books and papers are in a <ex>disorderly</ex> state</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Not acting in an orderly way, as the functions of
the body or mind.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Not complying with the restraints of order and law;
tumultuous; unruly; lawless; turbulent; <as>as, <ex>disorderly</ex>
people; <ex>disorderly</ex> assemblies.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Law)</fld> <def>Offensive to good morals and public
decency; notoriously offensive; <as>as, a <ex>disorderly</ex>
house</as>.</def></p>

<p><syn><b>Syn.</b> -- Irregular; immethodical; confused; tumultuous;
inordinate; intemperate; unruly; lawless; vicious.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disorderly</ent><br/
<hw>Dis*or"der*ly</hw>, <pos>adv.</pos> <def>In a disorderly manner;
without law or order; irregularly; confusedly.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Withdraw yourselves from every brother that walketh
<qex>disorderly</qex>.</q> <rj><qau>2 Thess. iii. 6.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Savages fighting <qex>disorderly</qex> with stones.</q>
<rj><qau>Sir W. Raleigh.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disordinance</ent><br/
<hw>Dis*or"di*nance</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Disarrangement; disturbance.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disordinate</ent><br/
<hw>Dis*or"di*nate</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Inordinate;
disorderly.</def> <mark>[Obs.]</mark> <ldquo/With <xex>disordinate</xex>
gestures.<rdquo/ <rj><au>Prynne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disordinately</ent><br/
<hw>Dis*or"di*nate*ly</hw>, <pos>adv.</pos> <def>Inordinately.</def>
<mark>[Obs.]</mark> <rj><au>E. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disordination</ent><br/
<hw>Dis*or`di*na"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state of
being in disorder; derangement; confusion.</def> <mark>[Obs.]</mark>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disorganization</ent><br/
<hw>Dis*or`gan*i*za"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>d<eacute/sorganisation</ets>. See <er>Disorganize</er>, <pos>v.
t.</pos>]</ety> <sn>1.</sn> <def>The act of disorganizing; destruction
of system.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The state of being disorganized; <as>as, the
<ex>disorganization</ex> of the body, or of government</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The magazine of a pawnbroker in such total
<qex>disorganization</qex>, that the owner can never lay his hands upon
any one article at the moment he has occasion for it.</q> <rj><qau>Sir
W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disorganize</ent><br/
<hw>Dis*or"gan*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Disorganized</conjf>
<pr>(?)</pr>; <pos>p. pr. & vb. n.</pos> <conjf>Disorganizing</conjf>
<pr>(?)</pr>.]</vmorph> <ety>[Pref. <ets>dis-</ets> +
<ets>organize</ets>: cf. F. <ets>d<eacute/sorganiser</ets>.]</ety>
<def>To destroy the organic structure or regular system of (a
government, a society, a party, etc.); to break up (what is organized);
to throw into utter disorder; to disarrange.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Lyford . . . attempted to <qex>disorganize</qex> the church.</q>
<rj><qau>Eliot (1809).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disorganizer</ent><br/
<hw>Dis*or"gan*i`zer</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
disorganizes or causes disorder and confusion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disorient</ent><br/
<hw>Dis*o"ri*ent</hw> <pr>(?)</pr>, <pos>v. t.</pos> <sn>1.</sn> <def>To
turn away from the east; to confuse as to which way is east; to cause to
lose one's bearings.</def> <mark>[R.]</mark> <rj><au>Bp.
Warburton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>to cause (a person) to lose one's sense of
direction; to cause to lose one's bearings or way; <as>as, the tourist
was <ex>disoriented</ex> by the winding and narrow
streets</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <fld>(Psychiatry)</fld> <def>to cause one to lose one's
sense of time or place, or of one's own personal identity.</def><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <def>to confuse (a person) by changing or removing
something which has served as a standard or guide to action; <as>as,
workers were rendered unemployed and <ex>disoriented</ex> by the rapid
changes in the markets</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Disorientate</ent><br/
<hw>Dis*o"ri*en*tate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To turn
away from the east, or (figuratively) from the right or the truth.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>disoriented</ent><br/
<hw>disoriented</hw> <pos>adj.</pos> <sn>1.</sn> <def>having lost one's
bearings physically or mentally.</def> <illu>I frequently find myself
<ex>disoriented</ex> when I come up out of the subway</illu>;<illu>the
anesthetic left her completely <ex>disoriented</ex></illu><br/
<syn><b>Syn. --</b> confused, lost.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>socially disoriented; withdrawn from social
interactions.</def><br/
<syn><b>Syn. --</b> alienated, anomic.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>disorienting</ent><br/
<hw>disorienting</hw> <pos>adj.</pos> <sn>1.</sn> <def>causing
disorientation: causing confusion of directions.</def> <see>Also See:
<er>unoriented</er>.</see> Antonym: <ant>orienting</ant><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Disown</ent><br/
<hw>Dis*own"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Disowned</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Disowning</conjf>.]</vmorph> <sn>1.</sn> <def>To refuse
to own or acknowledge as belonging to one's self; to disavow or deny, as
connected with one's self personally; <as>as, a parent can hardly
<ex>disown</ex> his child; an author will sometimes <ex>disown</ex> his
writings.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To refuse to acknowledge or allow; to
deny.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Then they, who brother's better claim <qex>disown</qex>,<br/
Expel their parents, and usurp the throne.</q>
<rj><qau>Dryden.</qau></rj></p>

<p><syn><b>Syn.</b> -- To disavow; disclaim; deny; abnegate; renounce;
disallow.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>disowned</ent><br/
<hw>disowned</hw> <pos>adj.</pos> <def>having social connections
repudiated.</def><br/
<syn><b>Syn. --</b> repudiated.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>disowning</ent><br/
<hw>disowning</hw> <pos>n.</pos> <def>the refusal to acknowledge
(something or somebody) as one's own.</def><br/
<syn><b>Syn. --</b> disownment.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Disownment</ent><br/
<hw>Dis*own"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Act of
disowning.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disoxidate</ent><br/
<hw>Dis*ox"i*date</hw> <pr>(?)</pr>, <pos>v. t.</pos> <fld>(Chem.)</fld>
<def>To deoxidate; to deoxidize.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disoxidation</ent><br/
<hw>Dis*ox`i*da"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>Deoxidation.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disoxygenate</ent><br/
<hw>Dis*ox"y*gen*ate</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<fld>(Chem.)</fld> <def>To deprive of oxygen; to deoxidize.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disoxygenation</ent><br/
<hw>Dis*ox`y*gen*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Chem.)</fld> <def>Deoxidation.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispace</ent><br/
<hw>Dis*pace"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[Pref.
<ets>dis-</ets> asunder, different ways, to and fro +
<ets>pace</ets>.]</ety> <def>To roam.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>In this fair plot <qex>dispacing</qex> to and fro.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispair</ent><br/
<hw>Dis*pair"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To separate (a
pair).</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I have . . . <qex>dispaired</qex> two doves.</q> <rj><qau>Beau. &
Fl.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispand</ent><br/
<hw>Dis*pand"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>dispandere</ets> to spread out; pref. <ets>dis-</ets> +
<ets>pandere</ets>, <ets>pansum</ets>, to spread out.]</ety> <def>To
spread out; to expand.</def> <mark>[Obs.]</mark>
<rj><au>Bailey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispansion</ent><br/
<hw>Dis*pan"sion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Dispand</er>.]</ety> <def>Act of dispanding, or state of being
dispanded.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disparadised</ent><br/
<hw>Dis*par"a*dised</hw>, <pos>a.</pos> <def>Removed from
paradise.</def> <mark>[R.]</mark> <rj><au>Cockeram.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disparage</ent><br/
<hw>Dis*par"age</hw> <pr>(?; 48)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Disparaged</conjf> <pr>(?)</pr>;
<pos>p. pr. & vb. n.</pos> <conjf>Disparaging</conjf>
<pr>(?)</pr>.]</vmorph> <ety>[OF. <ets>desparagier</ets>, F.
<ets>d<eacute/parager</ets>, to marry unequally; pref. <ets>des-</ets>
(L. <ets>dis-</ets>) + F. <ets>parage</ets> extraction, lineage, from L.
<ets>par</ets> equal, peer. See <er>Peer</er>.]</ety> <sn>1.</sn>
<def>To match unequally; to degrade or dishonor by an unequal
marriage.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Alas! that any of my nation<br/
Should ever so foul <qex>disparaged</qex> be.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To dishonor by a comparison with what is inferior;
to lower in rank or estimation by actions or words; to speak slightingly
of; to depreciate; to undervalue.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Those forbidding appearances which sometimes <qex>disparage</qex>
the actions of men sincerely pious.</q> <rj><qau>Bp.
Atterbury.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou durst not thus <qex>disparage</qex> glorious arms.</q>
<rj><qau>Milton.</qau></rj></p>

<p><syn><b>Syn.</b> -- To decry; depreciate; undervalue; underrate;
cheapen; vilify; reproach; detract from; derogate from; degrade; debase.
See <er>Decry</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disparage</ent><br/
<hw>Dis"pa*rage`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Inequality in
marriage; marriage with an inferior.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Dissuaded her from such a <qex>disparage</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disparagement</ent><br/
<hw>Dis*par"age*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. OF.
<ets>desparagement</ets>.]</ety> <sn>1.</sn> <def>Matching any one in
marriage under his or her degree; injurious union with something of
inferior excellence; a lowering in rank or estimation.</def>
<mark>[Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>And thought that match a foul <qex>disparagement</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Injurious comparison with an inferior; a
depreciating or dishonoring opinion or insinuation; diminution of value;
dishonor; indignity; reproach; disgrace; detraction; -- commonly with
<xex>to</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It ought to be no <qex>disparagement</qex> to a star that it is
not the sun.</q> <rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Imitation is a <qex>disparagement</qex> and a degradation in a
Christian minister.</q> <rj><qau>I. Taylor.</qau></rj></p>

<p><syn><b>Syn.</b> -- Indignity; derogation; detraction; reproach;
dishonor; debasement; degradation; disgrace.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>disparager</ent><br/
<hw>dis*par"a*ger</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
disparages or dishonors; one who vilifies or disgraces.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>disparaging</ent><br/
<hw>disparaging</hw> <pos>adj.</pos> <def>expressing a low opinion of;
same as <er>derogatory</er>; <as>as, <ex>disparaging</ex> remarks about
the new house</as>.</def><br/
<syn><b>Syn. --</b> belittling, depreciative, deprecatory, depreciatory,
derogative, derogatory, detractive, detracting, slighting, pejorative,
denigratory.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>disparagingly</ent><br/
<hw>dis*par"a*ging*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a
manner to disparage or dishonor; slightingly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disparate</ent><br/
<hw>Dis"pa*rate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>disparatus</ets>, p. p. of <ets>disparare</ets> to part, separate;
<ets>dis-</ets> + <ets>parare</ets> to make ready, prepare.]</ety>
<sn>1.</sn> <def>Unequal; dissimilar; separate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Connecting <qex>disparate</qex> thoughts, purely by means of
resemblances in the words expressing them.</q>
<rj><qau>Coleridge.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Logic)</fld> <def>Pertaining to two coordinate
species or divisions.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disparates</ent><br/
<hw>Dis"pa*rates</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <def>Things so
unequal or unlike that they can not be compared with each
other.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disparition</ent><br/
<hw>Dis`pa*ri"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>disparition</ets>.]</ety> <def>Act of disappearing;
disappearance.</def> <mark>[Obs.]</mark> <rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disparity</ent><br/
<hw>Dis*par"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Disparities</plw> <pr>(#)</pr>.</plu> <ety>[LL.
<ets>disparitas</ets>, fr. L. <ets>dispar</ets> unlike, unequal;
<ets>dis-</ets> + <ets>par</ets> equal: cf. F.
<ets>disparit<eacute/</ets>. See <er>Par</er>, <er>Peer</er>.]</ety>
<def>Inequality; difference in age, rank, condition, or excellence;
dissimilitude; -- followed by <xex>between</xex>, <xex>in</xex>,
<xex>of</xex>, <xex>as to</xex>, etc.; <as>as, <ex>disparity</ex> in, or
of, years; a <ex>disparity</ex> as to color.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>disparity</qex> between God and his intelligent
creatures.</q> <rj><qau>I. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>disparity</qex> of numbers was not such as ought to cause
any uneasiness.</q> <rj><qau>Macaulay.</qau></rj></p>

<p><syn><b>Syn.</b> -- Inequality; unlikeness; dissimilitude;
disproportion; difference.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispark</ent><br/
<hw>Dis*park"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <sn>1.</sn> <def>To
throw (a park or inclosure); to treat (a private park) as a
common.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The Gentiles were made to be God's people when the Jews' inclosure
was <qex>disparked</qex>.</q> <rj><qau>Jer. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To set at large; to release from
inclosure.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Till his free muse threw down the pale,<br/
And did at once <qex>dispark</qex> them all.</q>
<rj><qau>Waller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disparkle</ent><br/
<hw>Dis*par"kle</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[OF.
<ets>desparpeillier</ets>.]</ety> <def>To scatter abroad.</def>
<mark>[Obs.]</mark> <rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispart</ent><br/
<hw>Dis*part"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Disparted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Disparting</conjf>.]</vmorph> <ety>[Pref. <ets>dis-</ets> +
<ets>part</ets>: cf. OF. <ets>despartir</ets>.]</ety> <def>To part
asunder; to divide; to separate; to sever; to rend; to rive or split;
<as>as, <ex>disparted</ex> air; <ex>disparted</ex> towers.</as></def>
<mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Them in twelve troops their captain did <qex>dispart</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The world will be whole, and refuses to be
<qex>disparted</qex>.</q> <rj><qau>Emerson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispart</ent><br/
<hw>Dis*part"</hw>, <pos>v. i.</pos> <def>To separate, to open; to
cleave.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispart</ent><br/
<hw>Dis*part"</hw>, <pos>n.</pos> <sn>1.</sn> <fld>(Gun.)</fld> <def>The
difference between the thickness of the metal at the mouth and at the
breech of a piece of ordnance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>On account of the <qex>dispart</qex>, the line of aim or line of
metal, which is in a plane passing through the axis of the gun, always
makes a small angle with the axis.</q> <rj><qau>Eng. Cys.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Gun.)</fld> <def>A piece of metal placed on the
muzzle, or near the trunnions, on the top of a piece of ordnance, to
make the line of sight parallel to the axis of the bore; -- called also
<altname>dispart sight</altname>, and <altname>muzzle
sight</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispart</ent><br/
<hw>Dis*part"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <sn>1.</sn>
<fld>(Gun.)</fld> <def>To make allowance for the dispart in (a gun),
when taking aim.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Every gunner, before he shoots, must truly <qex>dispart</qex> his
piece.</q> <rj><qau>Lucar.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Gun.)</fld> <def>To furnish with a dispart
sight.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispassion</ent><br/
<hw>Dis*pas"sion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Freedom from
passion; an undisturbed state; apathy.</def> <rj><au>Sir W.
Temple.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispassionate</ent><br/
<hw>Dis*pas"sion*ate</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Free from passion; not warped, prejudiced, swerved, or carried away
by passion or feeling; judicial; calm; composed.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Wise and <qex>dispassionate</qex> men.</q>
<rj><qau>Clarendon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Not dictated by passion; not proceeding from temper
or bias; impartial; <as>as, <ex>dispassionate</ex> proceedings; a
<ex>dispassionate</ex> view.</as></def></p>

<p><syn><b>Syn.</b> -- Calm; cool; composed serene; unimpassioned;
temperate; moderate; impartial; unruffled.</syn></p>

<p>-- <wordforms><wf>Dis*pas"sion*ate*ly</wf>, <pos>adv.</pos> --
<wf>Dis*pas"sion*ate*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispassioned</ent><br/
<hw>Dis*pas"sioned</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Free from
passion; dispassionate.</def> <mark>[R.]</mark>
<ldquo/<xex>Dispassioned</xex> men.<rdquo/ <rj><au>Donne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispatch</ent><br/
<hw>Dis*patch"</hw> <pr>(?; 224)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Dispatched</conjf> <pr>(?)</pr>;
<pos>p. pr. & vb. n.</pos> <conjf>Dispatching</conjf>.]</vmorph>
<ety>[OF. <ets>despeechier</ets>, F. <ets>d<eacute/p<ecir/cher</ets>;
prob. from pref. <ets>des-</ets> (L. <ets>dis-</ets>) + (assumed) LL.
<ets>pedicare</ets> to place obstacles in the way, fr. L.
<ets>pedica</ets> fetter, fr. <ets>pes</ets>, <ets>pedis</ets>, foot.
See <er>Foot</er>, and cf. <er>Impeach</er>, <er>Despatch</er>.]</ety>
<altsp>[Written also <asp>despatch</asp>.]</altsp> <sn>1.</sn> <def>To
dispose of speedily, as business; to execute quickly; to make a speedy
end of; to finish; to perform.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Ere we put ourselves in arms, <qex>dispatch</qex> we<br/
The business we have talked of.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>[The] harvest men . . . almost in one fair day
<qex>dispatcheth</qex> all the harvest work.</q> <rj><qau>Robynson
(More's Utopia).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To rid; to free.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I had clean <qex>dispatched</qex> myself of this great charge.</q>
<rj><qau>Udall.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To get rid of by sending off; to send away
hastily.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Unless <qex>dispatched</qex> to the mansion house in the country .
. . they perish among the lumber of garrets.</q>
<rj><qau>Walpole.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To send off or away; -- particularly applied to
sending off messengers, messages, letters, etc., on special business,
and implying haste.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Even with the speediest expedition<br/
I will <qex>dispatch</qex> him to the emperor's cou<?/<?/.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To send out of the world; to put to death.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The company shall stone them with stones, and <qex>dispatch</qex>
them with their swords.</q> <rj><qau>Ezek. xxiii. 47.</qau></rj></p>

<p><syn><b>Syn.</b> -- To expedite; hasten; speed; accelerate; perform;
conclude; finish; slay; kill.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispatch</ent><br/
<hw>Dis*patch"</hw>, <pos>v. i.</pos> <def>To make haste; to conclude an
affair; to finish a matter of business.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They have <qex>dispatched</qex> with Pompey.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispatch</ent><br/
<hw>Dis*patch"</hw>, <pos>n.</pos> <ety>[Cf. OF. <ets>despeche</ets>, F.
<ets>d<eacute/p<ecir/che</ets>. See <er>Dispatch</er>, <pos>v.
t.</pos>]</ety> <altsp>[Written also <asp>despatch</asp>.]</altsp>
<sn>1.</sn> <def>The act of sending a message or messenger in haste or
on important business.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Any sending away; dismissal; riddance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To the utter <qex>dispatch</qex> of all their most beloved
comforts.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The finishing up of a business; speedy performance,
as of business; prompt execution; diligence; haste.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Serious business, craving quick <qex>dispatch</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To carry his scythe . . . with a sufficient <qex>dispatch</qex>
through a sufficient space.</q> <rj><qau>Paley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A message dispatched or sent with speed; especially,
an important official letter sent from one public officer to another; --
often used in the plural; <as>as, a messenger has arrived with
<ex>dispatches</ex> for the American minister; naval or military
<ex>dispatches</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A message transmitted by telegraph.</def>
<mark>[Modern]</mark><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dispatch boat</b></col>, <cd>a swift vessel for conveying
dispatches; an advice boat.</cd> -- <col><b>Dispatch box</b></col>,
<cd>a box for carrying dispatches; a box for papers and other
conveniences when traveling.</cd></cs></p>

<p><syn><b>Syn.</b> -- Haste; hurry; promptness; celerity; speed. See
<er>Haste</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispatcher</ent><br/
<hw>Dis*patch"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
dispatches.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispatchful</ent><br/
<hw>Dis*patch"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Bent on haste;
intent on speedy execution of business or any task; indicating haste;
quick; <as>as, <ex>dispatchful</ex> looks</as>.</def>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispatchment</ent><br/
<hw>Dis*patch"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. OF.
<ets>despechement</ets>.]</ety> <def>The act of dispatching.</def>
<mark>[Obs.]</mark> <rj><au>State Trials (1529).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispathy</ent><br/
<hw>Dis"pa*thy</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Dispathies</plw> <pr>(#)</pr>.</plu> <ety>[Pref. <ets>dis-</ets> +
Gr. <?/ passion. See <er>Pathos</er>.]</ety> <def>Lack of sympathy; want
of passion; apathy.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Many discrepancies and some <qex>dispathies</qex> between us.</q>
<rj><qau>Southey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispauper</ent><br/
<hw>Dis*pau"per</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To deprive of
the claim of a pauper to public support; to deprive of the privilege of
suing <xex>in forma pauperis</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispauperize</ent><br/
<hw>Dis*pau"per*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To free a
state of pauperism, or from paupers.</def> <rj><au>J. S.
Mill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispeed</ent><br/
<hw>Dis*peed"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>dis-</ets> + <ets>speed</ets>.]</ety> <def>To send off with speed;
to dispatch.</def> <mark>[Obs.]</mark> <rj><au>Knolles.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Then they <qex>dispeeded</qex> themselves of the Cid and of their
mother-in-law, Do<ntil/a Ximena.</q> <rj><qau>Southey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispel</ent><br/
<hw>Dis*pel"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Dispelled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Dispelling</conjf>.]</vmorph> <ety>[L.
<ets>dispellere</ets>; <ets>dis-</ets> + <ets>pellere</ets> to push,
drive. See <er>Pulse</er> a beating.]</ety> <def>To drive away by
scattering, or so to cause to vanish; to clear away; to banish; to
dissipate; <as>as, to <ex>dispel</ex> a cloud, vapors, cares, doubts,
illusions</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>[Satan] gently raised<br/
their fainting courage, and <qex>dispelled</qex> their fears.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I saw myself the lambent easy light<br/
Gild the brown horror, and <qex>dispel</qex> the night.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispence</ent><br/
<hw>Dis*pence"</hw> <pr>(?)</pr>, <pos>v. i. & n.</pos> <def>See
<er>Dispense</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 429 --></p>

<p><ent>Dispend</ent><br/
<hw>Dis*pend"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[OF.
<ets>despendre</ets>, L. <ets>dispendere</ets> to weigh out, dispense;
<ets>dis-</ets> + <ets>pendere</ets> to weigh. See <er>Pension</er>,
<er>Spend</er>, and cf. <er>Dispense</er>.]</ety> <def>To spend; to lay
out; to expend.</def> <mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Able to <qex>dispend</qex> yearly twenty pounds and above.</q>
<rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispender</ent><br/
<hw>Dis*pend"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who dispends
or expends; a steward.</def> <mark>[Obs.]</mark> <rj><au>Wyclif (1 Cor.
iv. 1).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispensable</ent><br/
<hw>Dis*pen"sa*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[LL.
<ets>dispensabilis</ets>. See <er>Dispense</er>.]</ety> <sn>1.</sn>
<def>Capable of being dispensed or administered.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Capable of being dispensed with.</def>
<rj><au>Coleridge.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispensableness</ent><br/
<hw>Dis*pen"sa*ble*ness</hw>, <pos>n.</pos> <def>Quality of being
dispensable.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispensary</ent><br/
<hw>Dis*pen"sa*ry</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Dispensaries</plw> <pr>(#)</pr>.</plu> <ety>[Cf. F.
<ets>dispensaire</ets>.]</ety> <sn>1.</sn> <def>A place where medicines
are prepared and dispensed; esp., a place where the poor can obtain
medical advice and medicines gratuitously or at a nominal
price.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A dispensatory.</def> <rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispensation</ent><br/
<hw>Dis`pen*sa"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>dispensation</ets>, L. <ets>dispensatio</ets>.]</ety> <sn>1.</sn>
<def>The act of dispensing or dealing out; distribution; often used of
the distribution of good and evil by God to man, or more generically, of
the acts and modes of his administration.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To respect the <qex>dispensations</qex> of Providence.</q>
<rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is dispensed, dealt out, or appointed;
that which is enjoined or bestowed</def>; especially
<fld>(Theol.)</fld>, <def>A system of principles, promises, and rules
ordained and administered; scheme; economy; <as>as, the Patriarchal,
Mosaic, and Christian <ex>dispensations</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Neither are God's methods or intentions different in his
<qex>dispensations</qex> to each private man.</q>
<rj><qau>Rogers.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The relaxation of a law in a particular case;
permission to do something forbidden, or to omit doing something
enjoined; specifically, in the Roman Catholic Church, exemption from
some ecclesiastical law or obligation to God which a man has incurred of
his own free will (oaths, vows, etc.).</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>dispensation</qex> was obtained to enable Dr. Barrow to
marry.</q> <rj><qau>Ward.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispensative</ent><br/
<hw>Dis*pen"sa*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>dispensatif</ets>.]</ety> <def>Granting dispensation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispensatively</ent><br/
<hw>Dis*pen"sa*tive*ly</hw>, <pos>adv.</pos> <def>By dispensation.</def>
<rj><au>Wotton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispensator</ent><br/
<hw>Dis"pen*sa`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.]</ety>
<def>A distributer; a dispenser.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispensatorily</ent><br/
<hw>Dis*pen"sa*to*ri*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In the
way of dispensation; dispensatively.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispensatory</ent><br/
<hw>Dis*pen"sa*to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>dispensatorius</ets> relating to management. See <er>Dispense</er>,
<pos>v. t.</pos>]</ety> <def>Granting, or authorized to grant,
dispensations.</def> <ldquo/<xex>Dispensatory</xex> power.<rdquo/
<rj><au>Bp. Rainbow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispensatory</ent><br/
<hw>Dis*pen"sa*to*ry</hw>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Dispensatories</plw> <pr>(<?/)</pr>.</plu> <def>A book or medicinal
formulary containing a systematic description of drugs, and of
preparations made from them. It is usually, but not always,
distinguished from a pharmacop<oe/ia in that it issued by private
parties, and not by an official body or by government.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispense</ent><br/
<hw>Dis*pense"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Dispensed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Dispensing</conjf>.]</vmorph> <ety>[F.
<ets>dispenser</ets>, L. <ets>dispensare</ets>, intens. of
<ets>dispendere</ets>. See <er>Dispend</er>.]</ety> <sn>1.</sn> <def>To
deal out in portions; to distribute; to give; <as>as, the steward
<ex>dispenses</ex> provisions according directions; Nature
<ex>dispenses</ex> her bounties; to <ex>dispense</ex>
medicines.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>He is delighted to <qex>dispense</qex> a share of it to all the
company.</q> <rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To apply, as laws to particular cases; to
administer; to execute; to manage; to direct.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>While you <qex>dispense</qex> the laws, and guide the state.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To pay for; to atone for.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>His sin was <qex>dispensed</qex><br/
With gold, whereof it was compensed.</q> <rj><qau>Gower.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To exempt; to excuse; to absolve; -- with
<xex>from</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It was resolved that all members of the House who held
commissions, should be <qex>dispensed</qex> from parliamentary
attendance.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He appeared to think himself born to be supported by others, and
<qex>dispensed</qex> from all necessity of providing for himself.</q>
<rj><qau>Johnson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispense</ent><br/
<hw>Dis*pense"</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To compensate; to
make up; to make amends.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>One loving hour<br/
For many years of sorrow can <qex>dispense</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To give dispensation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He [the pope] can also <qex>dispense</qex> in all matters of
ecclesiastical law.</q> <rj><qau>Addis & Arnold (Cath. Dict.
)</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To dispense with</b></col>. <sd>(a)</sd> <cd>To permit
the neglect or omission of, as a form, a ceremony, an oath; to suspend
the operation of, as a law; to give up, release, or do without, as
services, attention, etc.; to forego; to part with</cd>. <sd>(b)</sd>
<cd>To allow by dispensation; to excuse; to exempt; to grant
dispensation to or for.</cd> <mark>[Obs.]</mark> <ldquo/Conniving and
<xex>dispensing with</xex> open and common adultery.<rdquo/
<au>Milton.</au> <sd>(c)</sd> <cd>To break or go back from, as one's
word.</cd> <mark>[Obs.]</mark> <rj><au>Richardson.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispense</ent><br/
<hw>Dis*pense"</hw>, <pos>n.</pos> <ety>[Cf. F. <ets>dispense</ets>
dispensation. See <er>Dispense</er>, <pos>v. t.</pos>]</ety>
<def>Dispensation; exemption.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispense</ent><br/
<hw>Dis*pense"</hw>, <pos>n.</pos> <ety>[OF. <ets>despense</ets>, F.
<ets>d<eacute/pense</ets>.]</ety> <def>Expense; profusion; outlay.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>It was a vault built for great <qex>dispense</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>dispensed</ent><br/
<hw>dispensed</hw> <pos>adj.</pos> <def>distributed or weighed out in
carefully determined portions; <as>as, medicines <ex>dispensed</ex> to
the sick</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dispenser</ent><br/
<hw>Dis*pens"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, dispenses; a distributer; <as>as, a <ex>dispenser</ex> of
favors</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispeople</ent><br/
<hw>Dis*peo"ple</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Dispeopled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Dispeopling</conjf> <pr>(?)</pr>.]</vmorph> <ety>[Pref.
<ets>dis-</ets> + <ets>people</ets>: cf. F.
<ets>d<eacute/peupler</ets>.]</ety> <def>To deprive of inhabitants; to
depopulate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Leave the land <qex>dispeopled</qex> and desolate.</q>
<rj><qau>Sir T. More.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A certain island long before <qex>dispeopled</qex> . . . by sea
rivers.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispeopler</ent><br/
<hw>Dis*peo"pler</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, dispeoples; a depopulator.</def> <rj><au>Gay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disperge</ent><br/
<hw>Dis*perge"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>dispergere</ets>. See <er>Disperse</er>.]</ety> <def>To
sprinkle.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispermous</ent><br/
<hw>Di*sper"mous</hw> <pr>(d<isl/*sp<etil/r"m<ucr/s)</pr>, <pos>a.</pos>
<ety>[Gr. <grk>di-</grk> = <grk>dis</grk> + <grk>spe`rma</grk> seed, fr.
<grk>spei`rein</grk> to sow: cf. F. <ets>disperme</ets>.]</ety>
<fld>(Bot.)</fld> <def>Containing only two seeds; two-seeded.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disperple</ent><br/
<hw>Dis*per"ple</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[OF.
<ets>desparpeulier</ets>.]</ety> <def>To scatter; to sprinkle.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Odorous water was<br/
<qex>Disperpled</qex> lightly on my head and neck.</q>
<rj><qau>Chapman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispersal</ent><br/
<hw>Dis*per"sal</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act or result
of dispersing or scattering; dispersion.</def>
<rj><au>Darwin.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disperse</ent><br/
<hw>Dis*perse"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Dispersed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Dispersing</conjf>.]</vmorph> <ety>[L.
<ets>dispersus</ets>, p. p. of <ets>dispergere</ets> to strew, scatter.
See <er>Sparse</er>.]</ety> <sn>1.</sn> <def>To scatter abroad; to drive
to different parts; to distribute; to diffuse; to spread; <as>as, the
Jews are <ex>dispersed</ex> among all nations</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The lips of the wise <qex>disperse</qex> knowledge.</q>
<rj><qau>Prov. xv. 7.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Two lions, in the still, dark night,<br/
A herd of beeves <qex>disperse</qex>.</q>
<rj><qau>Cowper.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To scatter, so as to cause to vanish; to dissipate;
<as>as, to <ex>disperse</ex> vapors</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Dispersed</qex> are the glories.</q>
<rj><qau>Shak.</qau></rj></p>

<p><syn><b>Syn.</b> -- To scatter; dissipate; dispel; spread; diffuse;
distribute; deal out; disseminate.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disperse</ent><br/
<hw>Dis*perse"</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To separate; to
go or move into different parts; to vanish; <as>as, the company
<ex>dispersed</ex> at ten o'clock; the clouds
<ex>disperse</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To distribute wealth; to share one's abundance with
others.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He hath <qex>dispersed</qex>, he hath given to the poor.</q>
<rj><qau>Ps. cxii. 9.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispersed</ent><br/
<hw>Dis*persed"</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Scattered.</def>
-- <wordforms><wf>Dis*pers"ed*ly</wf> <pr>(#)</pr>, <pos>adv.</pos> --
<wf>Dis*pers"ed*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dispersed harmony</b></col> <fld>(Mus.)</fld>,
<cd>harmony in which the tones composing the chord are widely separated,
as by an octave or more.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disperseness</ent><br/
<hw>Dis*perse"ness</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Dispersedness.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disperser</ent><br/
<hw>Dis*pers"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One that
disperses.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispersion</ent><br/
<hw>Dis*per"sion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[CF. F.
<ets>dispersion</ets>.]</ety> <sn>1.</sn> <def>The act or process of
scattering or dispersing, or the state of being scattered or separated;
<as>as, the Jews in their <ex>dispersion</ex> retained their rites and
ceremonies; a great <ex>dispersion</ex> of the human family took place
at the building of Babel.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>The days of your slaughter and of your <qex>dispersions</qex> are
accomplished.</q> <rj><qau>Jer. xxv. 34.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Opt.)</fld> <def>The separation of light into its
different colored rays, arising from their different
refrangibilities.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dispersion of the optic axes</b></col>
<fld>(Crystallog.)</fld>, <cd>the separation of the optic axes in
biaxial crystals, due to the fact that the axial angle has different
values for the different colors of the spectrum.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispersive</ent><br/
<hw>Dis*pers"ive</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Tending to
disperse.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dispersive power</b></col> <fld>(Opt.)</fld>, <cd>the
relative effect of a material in separating the different rays of light
by refraction, as when the substance is formed into a
prism.</cd></cs></p>

<p>-- <wordforms><wf>Dis*pers"ive*ness</wf>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disperson'ate</ent><br/
<hw>Dis*per"son'*ate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To deprive
of personality or individuality.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>We multiply; we <qex>dispersonate</qex> ourselves.</q>
<rj><qau>Hare.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispirit</ent><br/
<hw>Dis*pir"it</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Dispirited</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Dispiriting</conjf>.]</vmorph> <ety>[Pref. <ets>dis-</ets> +
<ets>spirit</ets>.]</ety> <sn>1.</sn> <def>To deprive of cheerful
spirits; to depress the spirits of; to dishearten; to
discourage.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Not <qex>dispirited</qex> with my afflictions.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He has <qex>dispirited</qex> himself by a debauch.</q>
<rj><qau>Collier.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To distill or infuse the spirit of.</def>
<mark>[Obs. or R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>This makes a man master of his learning, and <qex>dispirits</qex>
the book into the scholar.</q> <rj><qau>Fuller.</qau></rj></p>

<p><syn><b>Syn.</b> -- To dishearten; discourage; deject; damp; depress;
cast down; intimidate; daunt; cow.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>dispirited</ent><br/
<hw>dis*pir"it*ed</hw>, <pos>a.</pos> <def>Depressed in spirits;
deprived of cheer or enthusiasm; disheartened; discouraged;
daunted.</def><br/
<syn><b>Syn. --</b> depressed, down(predicate), downcast, downhearted,
low, low-spirited, disheartened, discouraged, demoralized.</syn><br/
[<source>1913 Webster</source>]</p>

<p><wordforms>-- <wf>Dis*pir"it*ed*ly</wf>, <pos>adv.</pos> --
<wf>Dis*pir"it*ed</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>dispiriting</ent><br/
<hw>dispiriting</hw> <pos>adj.</pos> <def>causing dejection;
discouraging. Opposite of <ant>encouraging</ant>.</def><br/
<syn><b>Syn. --</b> demoralizing, demoralising, disheartening.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>causing dejection or depression.</def><br/
<syn><b>Syn. --</b> black, dark, depressing, grim.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dispiritment</ent><br/
<hw>Dis*pir"it*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Depression of
spirits; discouragement.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Procter, in evident distress and <qex>dispiritment</qex>, was
waiting the slow conclusion of this.</q>
<rj><qau>Carlyle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispiteous</ent><br/
<hw>Dis*pit"e*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>dis-</ets> + <ets>piteous</ets>. Cf. <er>Despiteous</er>.]</ety>
<def>Full of despite; cruel; spiteful; pitiless.</def> <au>Spenser.</au>
-- <wordforms><wf>Dis*pit"e*ous*ly</wf>, <pos>adv.</pos>
<mark>[Obs.]</mark></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Displace</ent><br/
<hw>Dis*place"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Displaced</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Displacing</conjf>.]</vmorph> <ety>[Pref.
<ets>dis-</ets> + <ets>place</ets>: cf. F.
<ets>d<eacute/placer</ets>.]</ety> <sn>1.</sn> <def>To change the place
of; to remove from the usual or proper place; to put out of place; to
place in another situation; <as>as, the books in the library are all
<ex>displaced</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To crowd out; to take the place of.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Holland <qex>displaced</qex> Portugal as the mistress of those
seas.</q> <rj><qau>London Times.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To remove from a state, office, dignity, or
employment; to discharge; to depose; <as>as, to <ex>displace</ex> an
officer of the revenue</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To dislodge; to drive away; to banish.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>You have <qex>displaced</qex> the mirth.</q>
<rj><qau>Shak.</qau></rj></p>

<p><syn><b>Syn.</b> -- To disarrange; derange; dismiss;
discard.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Displaceable</ent><br/
<hw>Dis*place"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of
being displaced.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Displacement</ent><br/
<hw>Dis*place"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>d<eacute/placement</ets>.]</ety> <sn>1.</sn> <def>The act of
displacing, or the state of being displaced; a putting out of
place.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Unnecessary <qex>displacement</qex> of funds.</q> <rj><qau>A.
Hamilton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>displacement</qex> of the sun by parallax.</q>
<rj><qau>Whewell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The quantity of anything, as water, displaced by a
floating body, as by a ship, the weight of the displaced liquid being
equal to that of the displacing body.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Chem.)</fld> <def>The process of extracting soluble
substances from organic material and the like, whereby a quantity of
saturated solvent is <xex>displaced</xex>, or removed, for another
quantity of the solvent.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Piston displacement</b></col> <fld>(Mech.)</fld>, <cd>the
volume of the space swept through, or weight of steam, water, etc.,
displaced, in a given time, by the piston of a steam engine or
pump.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Displacency</ent><br/
<hw>Dis*pla"cen*cy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL.
<ets>displacentia</ets>, for L. <ets>displicentia</ets>, fr.
<ets>displicere</ets> to displease; <ets>dis-</ets> + <ets>placere</ets>
to please. See <er>Displease</er>, and cf. <er>Displeasance</er>.]</ety>
<def>Want of complacency or gratification; envious displeasure;
dislike.</def> <mark>[Obs.]</mark> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Displacer</ent><br/
<hw>Dis*pla"cer</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One
that displaces.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Chem.)</fld> <def>The funnel part of the apparatus
for solution by displacement.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Displant</ent><br/
<hw>Dis*plant"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Displanted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Displanting</conjf>.]</vmorph> <ety>[Pref. <ets>dis-</ets> +
<ets>plant</ets>: cf. OF. <ets>desplanter</ets>, F.
<ets>d<eacute/planter</ets>.]</ety> <sn>1.</sn> <def>To remove (what is
planted or fixed); to unsettle and take away; to displace; to root out;
<as>as, to <ex>displant</ex> inhabitants</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I did not think a look,<br/
Or a poor word or two, could have <qex>displanted</qex><br/
Such a fixed constancy.</q> <rj><qau>Beau. & Fl.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To strip of what is planted or settled; <as>as, to
<ex>displant</ex> a country of inhabitants</as>.</def>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Displantation</ent><br/
<hw>Dis`plan*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
displanting; removal; displacement.</def> <rj><au>Sir W.
Raleigh.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Displat</ent><br/
<hw>Dis*plat"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To untwist; to
uncurl; to unplat.</def> <mark>[Obs.]</mark>
<rj><au>Hakewill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Display</ent><br/
<hw>Dis*play"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Displayed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Displaying</conjf>.]</vmorph> <ety>[OE.
<ets>displaien</ets>, <ets>desplaien</ets>, OF. <ets>despleier</ets>,
<ets>desploier</ets>, F. <ets>d<eacute/ployer</ets>; pref.
<ets>des-</ets> (L. <ets>dis-</ets>) + <ets>pleier</ets>,
<ets>ploier</ets>, <ets>plier</ets>, F. <ets>ployer</ets>,
<ets>plier</ets>, to fold, bend, L. <ets>plicare</ets>. See
<er>Ply</er>, and cf. <er>Deploy</er>, <er>Splay</er>.]</ety>
<sn>1.</sn> <def>To unfold; to spread wide; to expand; to stretch out;
to spread.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The northern wind his wings did broad <qex>display</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mil.)</fld> <def>To extend the front of (a column),
bringing it into line.</def> <rj><au>Farrow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To spread before the view; to show; to exhibit to
the sight, or to the mind; to make manifest.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His statement . . . <qex>displays</qex> very clearly the actual
condition of the army.</q> <rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To make an exhibition of; to set in view
conspicuously or ostentatiously; to exhibit for the sake of publicity;
to parade.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Proudly <qex>displaying</qex> the insignia of their order.</q>
<rj><qau>Prescott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Print.)</fld> <def>To make conspicuous by large or
prominent type.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To discover; to descry.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>And from his seat took pleasure to <qex>display</qex><br/
The city so adorned with towers.</q> <rj><qau>Chapman.</qau></rj></p>

<p><sn>7.</sn> <fld>(Computers)</fld> <def>To output (results or data)
in a visible manner on the screen of a monitor, CRT, or other
device.</def><br/
[<source>PJC</source>]</p>

<p><syn><b>Syn.</b> -- To exhibit; show; manifest; spread out; parade;
expand; flaunt.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Display</ent><br/
<hw>Dis*play"</hw>, <pos>v. i.</pos> <def>To make a display; to act as
one making a show or demonstration.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Display</ent><br/
<hw>Dis*play"</hw>, <pos>n.</pos> <sn>1.</sn> <def>An opening or
unfolding; exhibition; manifestation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Having witnessed <qex>displays</qex> of his power and grace.</q>
<rj><qau>Trench.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Ostentatious show; exhibition for effect;
parade.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He died, as erring man should die,<br/
Without <qex>display</qex>, without parade.</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Electronics)</fld> <def>An electronic device on
which the output signal of another electronic device may be presented in
a visual form; -- also called <altname>display device</altname>.
Typically the display device it is the screen of a cathode-ray tube, as
in a computer monitor, but other forms of visual display such as LED or
liquid crystal devices are also used. The printed output from a computer
or other device is not considered as a <ex>display</ex>.</def><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <fld>(Computers)</fld> <def>The output signal from a
computer program, displayed on a display device. The displayed signal
may consist of letters, numbers, or any graphical image.</def><br/
[<source>PJC</source>]</p>

<p><sn>5.</sn> <fld>(Biology)</fld> <def>a pattern of behavior, such as
showing a body part to another animal, by which one animal conveys
information to another, as for mating or defense.</def><br/
[<source>PJC</source>]</p>

<p><ent>Displayed</ent><br/
<hw>Dis*played"</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Unfolded; expanded; exhibited conspicuously or
ostentatiously.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Her.)</fld> <def>With wings expanded; -- said of a
bird of prey, esp. an eagle.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Print.)</fld> <def>Set with lines of prominent type
interspersed, to catch the eye.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Displayer</ent><br/
<hw>Dis*play"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, displays.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disple</ent><br/
<hw>Dis"ple</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To discipline; to
correct.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>And bitter Penance, with an iron whip,<br/
Was wont him once to <qex>disple</qex> every day.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Displeasance</ent><br/
<hw>Dis*pleas"ance</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>desplaisance</ets>, F. <ets>d<eacute/plaisance</ets>. Cf.
<er>Displacency</er>.]</ety> <def>Displeasure; discontent;
annoyance.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Displeasant</ent><br/
<hw>Dis*pleas"ant</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OF.
<ets>desplaisant</ets>, F. <ets>d<eacute/plaisant</ets>. See
<er>Displease</er>.]</ety> <def>Unpleasing; offensive; unpleasant.</def>
<mark>[Obs.]</mark> <au>Speed.</au> --
<wordforms><wf>Dis*pleas"ant*ly</wf>, <pos>adv.</pos>
<mark>[Obs.]</mark> <au>Strype.</au> -- <wf>Dis*pleas"ant*ness</wf>,
<pos>n.</pos> <mark>[Obs.]</mark></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Displease</ent><br/
<hw>Dis*please"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Displeased</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Displeasing</conjf>.]</vmorph> <ety>[OF.
<ets>desplaisir</ets>, whence F. <ets>d<eacute/plaisir</ets>
displeasure; pref. <ets>des-</ets> (L. <ets>dis-</ets>) +
<ets>plaisir</ets> to please. See <er>Please</er>, and cf.
<er>Displeasure</er>.]</ety> <sn>1.</sn> <def>To make not pleased; to
excite a feeling of disapprobation or dislike in; to be disagreeable to;
to offend; to vex; -- often followed by <xex>with</xex> or
<xex>at</xex>. It usually expresses less than to <xex>anger</xex>,
<xex>vex</xex>, <xex>irritate</xex>, or <xex>provoke</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>God was <qex>displeased</qex> with this thing.</q> <rj><qau>1
Chron. xxi. 7.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Wilt thou be <qex>displeased</qex> at us forever?</q>
<rj><qau>Psalms lxxxv. 5 (Bk. of Com. Prayer).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>This virtuous plaster will <qex>displease</qex><br/
Your tender sides.</q> <rj><qau>J. Fletcher.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Adversity is so wholesome . . . why should we be
<qex>displeased</qex> therewith?</q> <rj><qau>Barrow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To fail to satisfy; to miss of.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I shall <qex>displease</qex> my ends else.</q> <rj><qau>Beau. &
Fl.</qau></rj></p>

<p><syn><b>Syn.</b> -- To offend; disgust; vex; annoy; dissatisfy;
chafe; anger; provoke; affront.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Displease</ent><br/
<hw>Dis*please"</hw>, <pos>v. i.</pos> <def>To give displeasure or
offense.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Displeasedly</ent><br/
<hw>Dis*pleas"ed*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>With
displeasure.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Displeasedness</ent><br/
<hw>Dis*pleas"ed*ness</hw>, <pos>n.</pos> <def>Displeasure.</def>
<mark>[R.]</mark> <rj><au>South.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Displeaser</ent><br/
<hw>Dis*pleas"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
displeases.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Displeasing</ent><br/
<hw>Dis*pleas"ing</hw>, <pos>a.</pos> <def>Causing displeasure or
dissatisfaction; offensive; disagreeable.</def> --
<wordforms><wf>Dis*pleas"ing*ly</wf>, <pos>adv.</pos> --
<wf>Dis*pleas"ing*ness</wf>, <pos>n.</pos>
<au>Locke.</au></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Displeasure</ent><br/
<hw>Dis*pleas"ure</hw> <pr>(?; 135)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>dis-</ets> + <ets>pleasure</ets>: cf. OF. <ets>desplaisir</ets>, F.
<ets>d<eacute/plaisir</ets>. Cf. <er>Displease</er>.]</ety> <sn>1.</sn>
<def>The feeling of one who is displeased; irritation or uneasiness of
the mind, occasioned by anything that counteracts desire or command, or
which opposes justice or a sense of propriety; disapprobation; dislike;
dissatisfaction; disfavor; indignation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>O Lord, rebuke me not in thine anger, neither chasten me in thy
hot <qex>displeasure</qex>.</q> <rj><qau>Ps. vi. 1.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Undoubtedly he will relent, and turn<br/
From his <qex>displeasure</qex>.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which displeases; cause of irritation or
annoyance; offense; injury.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Hast thou delight to see a wretched man<br/
Do outrage and <qex>displeasure</qex> to himself?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 430 --></p>

<p><sn>3.</sn> <def>State of disgrace or disfavor; disfavor.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He went into Poland, being in <qex>displeasure</qex> with the pope
for overmuch familiarity.</q> <rj><qau>Peacham.</qau></rj></p>

<p><syn><b>Syn.</b> -- Dissatisfaction; disapprobation; disfavor;
distaste; dislike; anger; hate; aversion; indignation;
offense.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Displeasure</ent><br/
<hw>Dis*pleas"ure</hw> <pr>(?; 135)</pr>, <pos>v. t.</pos> <def>To
displease.</def> <mark>[Obs.]</mark> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Displenish</ent><br/
<hw>Dis*plen"ish</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To deprive or
strip, as a house of furniture, or a barn of stock.</def>
<mark>[Scot.]</mark></p>

<p><ent>Displicency</ent><br/
<ent>Displicence</ent><br/
<mhw>{ <hw>Dis"pli*cence</hw> <pr>(?)</pr>, <hw>Dis"pli*cen*cy</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[L. <ets>displicentia</ets>.
See <er>Displacency</er>.]</ety> <def>Dislike; dissatisfaction;
discontent.</def> <mark>[Obs.]</mark> <rj><au>W. Montagu.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Displode</ent><br/
<hw>Dis*plode"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Disploded</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Disploding</conjf>.]</vmorph> <ety>[L. <ets>displodere</ets>,
<ets>displosum</ets>; <ets>dis-</ets> + <ets>plodere</ets>,
<ets>plaudere</ets>, to clap, strike, beat.]</ety> <def>To discharge; to
explode.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In posture to <qex>displode</qex> their second tire<br/
Of thunder.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Displode</ent><br/
<hw>Dis*plode"</hw>, <pos>v. i.</pos> <def>To burst with a loud report;
to explode.</def> <ldquo/<xex>Disploding</xex> engines.<rdquo/
<rj><au>Young.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Displosion</ent><br/
<hw>Dis*plo"sion</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Explosion.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The vast <qex>displosion</qex> dissipates the clouds.</q>
<rj><qau>Young.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Displosive</ent><br/
<hw>Dis*plo"sive</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Explosive.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Displume</ent><br/
<hw>Dis*plume"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Displumed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Displuming</conjf>.]</vmorph> <ety>[Pref.
<ets>dis-</ets> + <ets>plume</ets>: cf. OF. <ets>desplumer</ets>, F.
<ets>d<eacute/plumer</ets>.]</ety> <def>To strip of, or as of, a plume,
or plumes; to deprive of decoration; to dishonor; to degrade.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Displumed</qex>, degraded, and metamorphosed.</q>
<rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispoline</ent><br/
<hw>Dis"po*line</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>One of several isomeric organic bases of the quinoline series of
alkaloids.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispond</ent><br/
<hw>Dis*pond"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Despond</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispondee</ent><br/
<hw>Di*spon"dee</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>dispondeus</ets>, Gr. <?/; <grk>di-</grk> = <grk>di`s-</grk> twice
+ <?/ spondee.]</ety> <fld>(Gr. <?/ Lat. Pros.)</fld> <def>A double
spondee; a foot consisting of four long syllables.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispone</ent><br/
<hw>Dis*pone"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>disponere</ets>. See <er>Disposition</er>.]</ety> <sn>1.</sn>
<fld>(Her.)</fld> <def>To dispose.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To dispose of.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Scots Law)</fld> <def>To make over, or convey,
legally.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He has <qex>disponed</qex> . . . the whole estate.</q>
<rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disponee</ent><br/
<hw>Dis`po*nee"</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Scots Law)</fld>
<def>The person to whom any property is legally conveyed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disponer</ent><br/
<hw>Dis*pon"er</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Scots Law)</fld>
<def>One who legally transfers property from himself to
another.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disponge</ent><br/
<hw>Dis*ponge"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>dis-</ets> + <ets>sponge</ets>.]</ety> <def>To sprinkle, as with
water from a sponge.</def> <mark>[Poetic & Rare]</mark> <altsp>[Written
also <asp>dispunge</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><q>O sovereign mistress of true melancholy,<br/
The poisonous damp of night <qex>disponge</qex> upon me</q>.
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispope</ent><br/
<hw>Dis*pope"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To refuse to
consider as pope; to depose from the popedom.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>One whom they <qex>dispoped</qex>.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disporous</ent><br/
<hw>Di*spor"ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>di-</ets> + <ets>sporous</ets>.]</ety> <fld>(Biol.)</fld>
<def>Having two spores.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disport</ent><br/
<hw>Dis*port"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>desport</ets>, <ets>deport</ets>. See <er>Disport</er>, <pos>v.
i.</pos>, and cf. <er>Sport</er>.]</ety> <def>Play; sport; pastime;
diversion; playfulness.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disport</ent><br/
<hw>Dis*port"</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Disported</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Disporting</conjf>.]</vmorph> <ety>[OF. <ets>se desporter</ets>;
pref. <ets>des-</ets> (L. <ets>dis-</ets>) + F. <ets>porter</ets> to
carry; orig. therefore, to carry one's self away from work, to go to
amuse one's self. See <er>Port</er> demeanor, and cf.
<er>Sport</er>.]</ety> <def>To play; to wanton; to move in gayety; to
move lightly and without restraint; to amuse one's self.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Where light <qex>disports</qex> in ever mingling dyes.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Childe Harold basked him in the noontide sun,<br/
<qex>Disporting</qex> there like any other fly.</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disport</ent><br/
<hw>Dis*port"</hw>, <pos>v. t.</pos> <ety>[OF. <ets>desporter</ets>. See
<er>Disport</er>, <pos>v. i.</pos>]</ety> <sn>1.</sn> <def>To divert or
amuse; to make merry.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They could <qex>disport</qex> themselves.</q>
<rj><qau>Buckle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To remove from a port; to carry away.</def>
<rj><au>Prynne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disportment</ent><br/
<hw>Dis*port"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Act of
disporting; diversion; play.</def> <mark>[Obs.]</mark> <rj><au>Dr. H.
More.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disposable</ent><br/
<hw>Dis*pos"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From
<er>Dispose</er>.]</ety> <def>Subject to disposal; free to be used or
employed as occasion may require; not assigned to any service or
use.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The great of this kingdom . . . has easily afforded a
<qex>disposable</qex> surplus.</q> <rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>designed to be disposed of after use; -- of articles
of commerce. The term implies that it is less expensive to manufacture a
new one than to clean and recycle the used item to make it fit for use
again; <as>as, <ex>disposable</ex> dishes</as>; <ex>disposable</ex>
diapers; <ex>disposable</ex> gloves. Opposite of
<ant>reusable</ant>.</def><br/
<syn><b>Syn. --</b> throwaway(predicate), non-reusable.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>disposable income</ent><br/
<hw>dis*pos"a*ble in"come</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Economics)</fld> <def>that portion of income which is available
for spending on discretionary purchases; for individuals, it is usually
calculated as total income less taxes. <ecol><b>National disposable
income</b></ecol>, which is the disposable income of all individuals and
businesses, is calculated as total national income minus taxes plus
transfer payments.</def> <au>Dornbusch and Fischer
(Macroeconomics)</au><br/
[<source>PJC</source>]</p>

<p><ent>Disposal</ent><br/
<hw>Dis*pos"al</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<er>Dispose</er>.]</ety> <sn>1.</sn> <def>The act of disposing, or
disposing of, anything; arrangement; orderly distribution; a putting in
order; <as>as, the <ex>disposal</ex> of the troops in two
lines</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Ordering; regulation; adjustment; management;
government; direction.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The execution leave to high <qex>disposal</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Regulation of the fate, condition, application,
etc., of anything; the transference of anything into new hands, a new
place, condition, etc.; alienation, or parting; <as>as, a
<ex>disposal</ex> of property</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A domestic affair of great importance, which is no less than the
<qex>disposal</qex> of my sister Jenny for life.</q>
<rj><qau>Tatler.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Power or authority to dispose of, determine the
condition of, control, etc., especially in the phrase <xex>at</xex>, or
<xex>in</xex>, the <xex>disposal</xex> of.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The sole and absolute <qex>disposal</qex> of him an his
concerns.</q> <rj><qau>South.</qau></rj></p>

<p><syn><b>Syn.</b> -- Disposition; dispensation; management; conduct;
government; distribution; arrangement; regulation; control.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispose</ent><br/
<hw>Dis*pose"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Disposed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Disposing</conjf>.]</vmorph> <ety>[F.
<ets>disposer</ets>; pref. <ets>dis-</ets> + <ets>poser</ets> to place.
See <er>Pose</er>.]</ety> <sn>1.</sn> <def>To distribute and put in
place; to arrange; to set in order; <as>as, to <ex>dispose</ex> the
ships in the form of a crescent</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Who hath <qex>disposed</qex> the whole world?</q> <rj><qau>Job
xxxiv. 13.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>All ranged in order and <qex>disposed</qex> with grace.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The rest themselves in troops did else <qex>dispose</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To regulate; to adjust; to settle; to
determine.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The knightly forms of combat to <qex>dispose</qex>.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To deal out; to assign to a use; to bestow for an
object or purpose; to apply; to employ; to dispose of.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Importuned him that what he designed to bestow on her funeral, he
would rather <qex>dispose</qex> among the poor.</q>
<rj><qau>Evelyn.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To give a tendency or inclination to; to adapt; to
cause to turn; especially, to incline the mind of; to give a bent or
propension to; to incline; to make inclined; -- usually followed by
<xex>to</xex>, sometimes by <xex>for</xex> before the indirect
object.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Endure and conquer; Jove will soon <qex>dispose</qex><br/
To future good our past and present woes.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Suspicions <qex>dispose</qex> kings to tyranny, husbands to
jealousy, and wise men to irresolution and melancholy.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<cs><p><col><b>To dispose of</b></col>. <sd>(a)</sd> <cd>To determine
the fate of; to exercise the power of control over; to fix the
condition, application, employment, etc. of; to direct or assign for a
use.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>Freedom to order their actions and <qex>dispose of</qex> their
possessions and persons.</q> <rj><qau>Locke.</qau></rj></p>

<p><sd>(b)</sd> <def>To exercise finally one's power of control over; to
pass over into the control of some one else, as by selling; to alienate;
to part with; to relinquish; to get rid of; as, to <xex>dispose of</xex>
a house; to <xex>dispose of</xex> one's time.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>More water . . . than can be <qex>disposed of</qex>.</q>
<rj><qau>T. Burnet.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I have <qex>disposed of</qex> her to a man of business.</q>
<rj><qau>Tatler.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A rural judge <qex>disposed of</qex> beauty's prize.</q>
<rj><qau>Waller.</qau></rj></p></cs>

<p><syn><b>Syn.</b> -- To set; arrange; order; distribute; adjust;
regulate; adapt; fit; incline; bestow; give.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispose</ent><br/
<hw>Dis*pose"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To bargain; to
make terms.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>She had <qex>disposed</qex> with C<ae/sar.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispose</ent><br/
<hw>Dis*pose"</hw>, <pos>n.</pos> <sn>1.</sn> <def>Disposal; ordering;
management; power or right of control.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>But such is the <qex>dispose</qex> of the sole Disposer of
empires.</q> <rj><qau>Speed.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Cast of mind; disposition; inclination; behavior;
demeanor.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He hath a person, and a smooth <qex>dispose</qex><br/
To be suspected.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disposed</ent><br/
<hw>Dis*posed"</hw> <pr>(?)</pr>, <pos>p. a.</pos> <sn>1.</sn>
<def>Inclined; minded.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>When he was <qex>disposed</qex> to pass into Achaia.</q>
<rj><qau>Acts xviii. 27.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Inclined to mirth; jolly.</def> <mark>[Obs.]</mark>
<rj><au>Beau. & Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Well disposed</b></col>, <cd>in good condition; in good
health.</cd> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disposedness</ent><br/
<hw>Dis*pos"ed*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state of
being disposed or inclined; inclination; propensity.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disposement</ent><br/
<hw>Dis*pose"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Disposal.</def>
<mark>[Obs.]</mark> <rj><au>Goodwin.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disposer</ent><br/
<hw>Dis*pos"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, disposes; a regulator; a director; a bestower.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Absolute lord and <qex>disposer</qex> of all things.</q>
<rj><qau>Barrow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disposingly</ent><br/
<hw>Dis*pos"ing*ly</hw>, <pos>adv.</pos> <def>In a manner to
dispose.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disposited</ent><br/
<hw>Dis*pos"it*ed</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Disposition</er>.]</ety> <def>Disposed.</def> <mark>[Obs.]</mark>
<rj><au>Glanvill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disposition</ent><br/
<hw>Dis`po*si"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>disposition</ets>, <ets>dispositio</ets>, fr. <ets>disponere</ets>
to dispose; <ets>dis-</ets> + <ets>ponere</ets> to place. See
<er>Position</er>, and cf. <er>Dispone</er>.]</ety> <sn>1.</sn> <def>The
act of disposing, arranging, ordering, regulating, or transferring;
application; disposal; <as>as, the <ex>disposition</ex> of a man's
property by will</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Who have received the law by the <qex>disposition</qex> of
angels.</q> <rj><qau>Acts vii. 53.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>disposition</qex> of the work, to put all things in a
beautiful order and harmony, that the whole may be of a piece.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The state or the manner of being disposed or
arranged; distribution; arrangement; order; <as>as, the
<ex>disposition</ex> of the trees in an orchard; the
<ex>disposition</ex> of the several parts of an edifice.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Tendency to any action or state resulting from
natural constitution; nature; quality; <as>as, a <ex>disposition</ex> in
plants to grow in a direction upward; a <ex>disposition</ex> in bodies
to putrefaction.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Conscious inclination; propension or
propensity.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>How stands your <qex>disposition</qex> to be married?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Natural or prevailing spirit, or temperament of
mind, especially as shown in intercourse with one's fellow-men; temper
of mind.</def> <ldquo/A man of turbulent <xex>disposition</xex>.<rdquo/
<au>Hallam.</au> <ldquo/He is of a very melancholy
<xex>disposition</xex>.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>His <qex>disposition</qex> led him to do things agreeable to his
quality and condition wherein God had placed him.</q>
<rj><qau>Strype.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Mood; humor.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>As I perchance hereafter shall think meet<br/
To put an antic <qex>disposition</qex> on.</q>
<rj><qau>Shak.</qau></rj></p>

<p><syn><b>Syn.</b> -- Disposal; adjustment; regulation; arrangement;
distribution; order; method; adaptation; inclination; propensity;
bestowment; alienation; character; temper; mood. --
<er>Disposition</er>, <er>Character</er>, <er>Temper</er>.
<xex>Disposition</xex> is the natural humor of a person, the
predominating quality of his character, the constitutional habit of his
mind. <xex>Character</xex> is this disposition influenced by motive,
training, and will. <xex>Temper</xex> is a quality of the fiber of
character, and is displayed chiefly when the emotions, especially the
passions, are aroused.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispositional</ent><br/
<hw>Dis`po*si"tion*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining
to disposition.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispositioned</ent><br/
<hw>Dis`po*si"tioned</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having (such)
a disposition; -- used in compounds; <as>as,
well-<ex>dispositioned</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispositive</ent><br/
<hw>Dis*pos"i*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>dispositif</ets>.]</ety> <sn>1.</sn> <def>Disposing; tending to
regulate; decretive.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>His <qex>dispositive</qex> wisdom and power.</q>
<rj><qau>Bates.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Belonging to disposition or natural, tendency.</def>
<mark>[Obs.]</mark> <ldquo/<xex>Dispositive</xex> holiness.<rdquo/
<rj><au>Jer. Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispositively</ent><br/
<hw>Dis*pos"i*tive*ly</hw>, <pos>adv.</pos> <def>In a dispositive
manner; by natural or moral disposition.</def> <mark>[Obs.]</mark>
<rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Do <qex>dispositively</qex> what Moses is recorded to have done
literally, . . . break all the ten commandments at once.</q>
<rj><qau>Boyle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispositor</ent><br/
<hw>Dis*pos"it*or</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. See
<er>Disposition</er>.]</ety> <sn>1.</sn> <def>A disposer.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Astrol.)</fld> <def>The planet which is lord of the
sign where another planet is.</def> <mark>[Obs.]</mark>
<rj><au>Crabb.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispossess</ent><br/
<hw>Dis`pos*sess"</hw> <pr>(?; see <er>Possess</er>)</pr>, <pos>v.
t.</pos> <vmorph>[<pos>imp. & p. p.</pos> <conjf>Dispossessed</conjf>
<pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Dispossessing</conjf>.]</vmorph> <ety>[Pref. <ets>dis-</ets> +
<ets>possess</ets>: cf. F. <ets>d<eacute/poss<eacute/der</ets>.]</ety>
<def>To put out of possession; to deprive of the actual occupancy of,
particularly of land or real estate; to disseize; to eject; -- usually
followed by <xex>of</xex> before the thing taken away; <as>as, to
<ex>dispossess</ex> a king of his crown</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Usurp the land, and <qex>dispossess</qex> the swain.</q>
<rj><qau>Goldsmith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>dispossessed</ent><br/
<hw>dispossessed</hw> <pos>adj.</pos> <def>physically or spiritually
homeless or deprived of security.</def><br/
<syn><b>Syn. --</b> homeless, roofless.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><q>made a living out of shepherding <ex>dispossessed</ex> people from
one country to another</q> <qau>James Stern</qau></p>

<p><ent>Dispossession</ent><br/
<hw>Dis`pos*ses"sion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>d<eacute/possession</ets>.]</ety> <sn>1.</sn> <def>The act of
putting out of possession; the state of being dispossessed.</def>
<rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>The putting out of possession,
wrongfully or otherwise, of one who is in possession of a freehold, no
matter in what title; -- called also
<altname>ouster</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispossessor</ent><br/
<hw>Dis`pos*sess"or</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
dispossesses.</def> <rj><au>Cowley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispost</ent><br/
<hw>Dis*post"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To eject from a
post; to displace.</def> <mark>[R.]</mark> <rj><au>Davies (Holy
Roode).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disposure</ent><br/
<hw>Dis*po"sure</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<er>Dispose</er>.]</ety> <sn>1.</sn> <def>The act of disposing; power to
dispose of; disposal; direction.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Give up<br/
My estate to his <qex>disposure</qex>.</q>
<rj><qau>Massinger.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Disposition; arrangement; position; posture.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>In a kind of warlike <qex>disposure</qex>.</q> <rj><qau>Sir H.
Wotton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispraisable</ent><br/
<hw>Dis*prais"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Blamable.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispraise</ent><br/
<hw>Dis*praise"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Dispraised</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Dispraising</conjf>.]</vmorph> <ety>[OE.
<ets>dispreisen</ets>, OF. <ets>desprisier</ets>,
<ets>despreisier</ets>, F. <ets>d<eacute/priser</ets>; pref.
<ets>des-</ets> (L. <ets>dis-</ets>) + <ets>prisier</ets>, F.
<ets>priser</ets>, to prize, praise. See <er>Praise</er>, and cf.
<er>Disprize</er>, <er>Depreciate</er>.]</ety> <def>To withdraw praise
from; to notice with disapprobation or some degree of censure; to
disparage; to blame.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Dispraising</qex> the power of his adversaries.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I <qex>dispraised</qex> him before the wicked, that the wicked
might not fall in love with him.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispraise</ent><br/
<hw>Dis*praise"</hw>, <pos>n.</pos> <ety>[Cf. OF. <ets>despris</ets>.
See <er>Dispraise</er>, <pos>v. t.</pos>]</ety> <def>The act of
dispraising; detraction; blame censure; reproach; disparagement.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>In praise and in <qex>dispraise</qex> the same.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispraiser</ent><br/
<hw>Dis*prais"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who blames or
dispraises.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispraisingly</ent><br/
<hw>Dis*praising*ly</hw>, <pos>adv.</pos> <def>By way of
dispraise.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispread</ent><br/
<hw>Dis*pread"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>dis-</ets> + <ets>spread</ets>.]</ety> <def>To spread abroad, or
different ways; to spread apart; to open; <as>as, the sun
<ex>dispreads</ex> his beams</as>.</def> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispread</ent><br/
<hw>Dis*pread"</hw>, <pos>v. i.</pos> <def>To extend or expand
itself.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>While tyrant Heat, <qex>dispreading</qex> through the sky.</q>
<rj><qau>Thomson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispreader</ent><br/
<hw>Dis*pread"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who spreads
abroad.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Dispreaders</qex> both of vice and error.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disprejudice</ent><br/
<hw>Dis*prej"u*dice</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To free
from prejudice.</def> <mark>[Obs.]</mark> <rj><au>W.
Montagu.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disprepare</ent><br/
<hw>Dis`pre*pare"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To render
unprepared.</def> <mark>[Obs.]</mark> <rj><au>Hobbes.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disprince</ent><br/
<hw>Dis*prince"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To make unlike
a prince.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>For I was drench'd with ooze, and torn with briers, . . . <br/
And, all one rag, <qex>disprinced</qex> from head to heel.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disprison</ent><br/
<hw>Dis*pris"on</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To let loose
from prison, to set at liberty.</def> <mark>[R.]</mark>
<rj><au>Bulwer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disprivilege</ent><br/
<hw>Dis*priv"i*lege</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To deprive
of a privilege or privileges.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disprize</ent><br/
<hw>Dis*prize"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Cf.
<er>Dispraise</er>.]</ety> <def>To depreciate.</def> <mark>[R.]</mark>
<rj><au>Cotton (Ode to Lydia).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disprofess</ent><br/
<hw>Dis`pro*fess"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To renounce
the profession or pursuit of.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His arms, which he had vowed to <qex>disprofess</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disprofit</ent><br/
<hw>Dis*prof"it</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Loss;
damage.</def> <rj><au>Foxe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disprofit</ent><br/
<hw>Dis*prof"it</hw>, <pos>v. i. & i.</pos> <def>To be, or to cause to
be, without profit or benefit.</def> <mark>[Obs. or Archaic]</mark>
<rj><au>Bale.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disprofitable</ent><br/
<hw>Dis*prof"it*a*ble</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Unprofitable.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disproof</ent><br/
<hw>Dis*proof"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>dis-</ets> + <ets>proof</ets>. Cf. <er>Disprove</er>.]</ety> <def>A
proving to be false or erroneous; confutation; refutation; <as>as, to
offer evidence in <ex>disproof</ex> of a statement</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I need not offer anything farther in support of one, or in
<qex>disproof</qex> of the other.</q> <rj><qau>Rogers.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disproperty</ent><br/
<hw>Dis*prop"er*ty</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To cause to
be no longer property; to dispossess of.</def> <mark>[R.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disproportion</ent><br/
<hw>Dis`pro*por"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>dis-</ets> + <ets>proportion</ets>: cf. F.
<ets>disproportion</ets>.]</ety> <sn>1.</sn> <def>Want of proportion in
form or quantity; lack of symmetry; <as>as, the arm may be in
<ex>disproportion</ex> to the body; the <ex>disproportion</ex> of the
length of a building to its height.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Want of suitableness, adequacy, or due proportion to
an end or use; unsuitableness; disparity; <as>as, the
<ex>disproportion</ex> of strength or means to an object</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disproportion</ent><br/
<hw>Dis`pro*por"tion</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Disproportioned</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Disproportioning</conjf>.]</vmorph> <def>To make
unsuitable in quantity, form, or fitness to an end; to violate symmetry
in; to mismatch; to join unfitly.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To shape my legs of an unequal size;<br/
To <qex>disproportion</qex> me in every part.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A degree of strength altogether <qex>disproportioned</qex> to the
extent of its territory.</q> <rj><qau>Prescott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disproportionable</ent><br/
<hw>Dis`pro*por"tion*a*ble</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Disproportional; unsuitable in form, size, quantity, or adaptation;
disproportionate; inadequate.</def> --
<wordforms><wf>Dis`pro*por"tion*a*ble*ness</wf>, <pos>n.</pos>
<au>Hammond.</au> -- <wf>Dis`pro*por"tion*a*bly</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disproportional</ent><br/
<hw>Dis`pro*por"tion*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Not having
due proportion to something else; not having proportion or symmetry of
parts; unsuitable in form, quantity or value; inadequate; unequal;
<as>as, a <ex>disproportional</ex> limb constitutes deformity in the
body; the studies of youth should not be <ex>disproportional</ex> to
their understanding.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disproportionality</ent><br/
<hw>Dis`pro*por`tion*al"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The
state of being disproportional.</def> <rj><au>Dr. H. More.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disproportionally</ent><br/
<hw>Dis`pro*por"tion*al*ly</hw>, <pos>adv.</pos> <def>In a
disproportional manner; unsuitably in form, quantity, or value;
unequally.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disproportionate</ent><br/
<hw>Dis`pro*por"tion*ate</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Not
proportioned; unsymmetrical; unsuitable to something else in bulk, form,
value, or extent; out of proportion; inadequate; <as>as, in a perfect
body none of the limbs are <ex>disproportionate</ex>; it is wisdom not
to undertake a work <ex>disproportionate</ex> means.</as></def> --
<wordforms><wf>Dis`pro*por"tion*ate*ly</wf>, <pos>adv.</pos> --
<wf>Dis`pro*por"tion*ate*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispropriate</ent><br/
<hw>Dis*pro"pri*ate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>dis-</ets> + <ets>propriare</ets> to appropriate, fr.
<ets>proprius</ets> one's own, proper.]</ety> <def>To cancel the
appropriation of; to disappropriate.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disprovable</ent><br/
<hw>Dis*prov"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of
being disproved or refuted.</def> <rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disproval</ent><br/
<hw>Dis*prov"al</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Act of disproving;
disproof.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 431 --></p>

<p><ent>Disprove</ent><br/
<hw>Dis*prove"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Disproved</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Disproving</conjf>.]</vmorph> <ety>[Pref.
<ets>dis-</ets> + <ets>prove</ets>: cf. OF. <ets>desprover</ets>.]</ety>
<sn>1.</sn> <def>To prove to be false or erroneous; to confute; to
refute.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That false supposition I advanced in order to <qex>disprove</qex>
it.</q> <rj><qau>Atterbury.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To disallow; to disapprove of.</def>
<mark>[Obs.]</mark> <rj><au>Stirling.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disprover</ent><br/
<hw>Dis*prov"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who disproves
or confutes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disprovide</ent><br/
<hw>Dis`pro*vide"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>Not to
provide; to fail to provide.</def> <mark>[Obs.]</mark>
<rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispunct</ent><br/
<hw>Dis*punct"</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Wanting in
punctilious respect; discourteous.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>That were <qex>dispunct</qex> to the ladies.</q> <rj><qau>B.
Jonson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispunct</ent><br/
<hw>Dis*punct"</hw>, <pos>v. t.</pos> <ety>[See 1st
<er>Dispunge</er>.]</ety> <def>To expunge.</def> <mark>[Obs.]</mark>
<rj><au>Foxe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispunge</ent><br/
<hw>Dis*punge"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>dispungere</ets> to prick apart, <it>i. e.</it>, check off the
debts and credits of an account; <ets>dis-</ets> + <ets>pungere</ets> to
prick.]</ety> <def>To expunge; to erase.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispunge</ent><br/
<hw>Dis*punge"</hw>, <pos>v. t.</pos> <def>See <er>Disponge</er>.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispunishable</ent><br/
<hw>Dis*pun"ish*a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Without
penal restraint; not punishable.</def> <mark>[R.]</mark>
<rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispurpose</ent><br/
<hw>Dis*pur"pose</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To dissuade;
to frustrate; <as>as, to <ex>dispurpose</ex> plots</as>.</def>
<mark>[R.]</mark> <rj><au>A. Brewer.</au></rj></p>

<p><ent>Dispurse</ent><br/

<hw>Dis*purse"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To
disburse.</def> <mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispurvey</ent><br/
<hw>Dis`pur*vey"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>dis-</ets> + <ets>purvey</ets>: cf. OF. <ets>desporveoir</ets>, F.
<ets>d<eacute/pourvoir</ets>.]</ety> <def>To disfurnish; to strip.</def>
<mark>[Obs.]</mark> <rj><au>Heywood.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispurveyance</ent><br/
<hw>Dis`pur*vey"ance</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Want of
provisions; lack of food.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disputable</ent><br/
<hw>Dis`pu*ta*ble</hw> <pr>(?; 277)</pr>, <pos>a.</pos> <ety>[L.
<ets>disputabilis</ets>: cf. F. <ets>disputable</ets>. See
<er>Dispute</er>, <pos>v. i.</pos>]</ety> <sn>1.</sn> <def>Capable of
being disputed; liable to be called in question, controverted, or
contested; or doubtful certainty or propriety; controvertible; <as>as,
<ex>disputable</ex> opinions, propositions, points, or
questions</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Actions, every one of which is very <qex>disputable</qex>.</q>
<rj><qau>Jer. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Disputatious; contentious.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disputableness</ent><br/
<hw>Dis`pu*ta*ble*ness</hw>, <pos>n.</pos> <def>State of being
disputable.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disputacity</ent><br/
<hw>Dis`pu*tac"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Dispute</er>, <pos>v. i.</pos>]</ety> <def>Proneness to
dispute.</def> <mark>[Obs.]</mark> <rj><au>Bp. Ward.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>disputant</ent><br/
<hw>dis"pu*tant</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>disputants</ets>, p. pr. of <ets>disputare</ets>: cf. F.
<ets>disputant</ets>. See <er>Dispute</er>, <pos>v. i.</pos>]</ety>
<def>Disputing; engaged in controversy.</def>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>disputant</ent><br/
<hw>dis"pu*tant</hw>, <pos>n.</pos> <def>One who disputes; one who
argues in opposition to another; one appointed to dispute; a
controvertist; a reasoner in opposition.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A singularly eager, acute, and pertinacious
<qex>disputant</qex>.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disputation</ent><br/
<hw>Dis`pu*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>desputeson</ets>, <ets>disputacion</ets>, OF.
<ets>desputeison</ets>, F. <ets>disputation</ets>, fr. L.
<ets>disputatio</ets>. See <er>Dispute</er>, <pos>v. i.</pos>]</ety>
<sn>1.</sn> <def>The act of disputing; a reasoning or argumentation in
opposition to something, or on opposite sides; controversy in words;
verbal contest respecting the truth of some fact, opinion, proposition,
or argument.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A rhetorical exercise in which parties reason in
opposition to each other on some question proposed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disputatious</ent><br/
<hw>Dis`pu*ta"tious</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Inclined to
dispute; apt to civil or controvert; characterized by dispute; <as>as, a
<ex>disputatious</ex> person or temper</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The Christian doctrine of a future life was no recommendation of
the new religion to the wits and philosophers of that
<qex>disputations</qex> period.</q> <rj><qau>Buckminster.</qau></rj></p>

<p>-- <wordforms><wf>Dis`pu*ta"tious*ly</wf>, <pos>adv.</pos> --
<wf>Dis`pu*ta"tious*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disputative</ent><br/
<hw>Dis*put"a*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>disputativus</ets>.]</ety> <def>Disposed to dispute; inclined to
cavil or to reason in opposition; <as>as, a <ex>disputative</ex>
temper</as>.</def> <rj><au>I. Watts.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispute</ent><br/
<hw>Dis*pute"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Disputed</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Disputing</conjf>.]</vmorph> <ety>[OE. <ets>desputen</ets>,
<ets>disputen</ets>, OF. <ets>desputer</ets>, <ets>disputer</ets>, F.
<ets>disputer</ets>, from L. <ets>disputare</ets>,
<ets>disputatum</ets>; <ets>dis-</ets> + <ets>putare</ets> to clean;
hence, fig., to clear up, set in order, reckon, think. See
<er>Putative</er>, <er>Pure</er>.]</ety> <def>To contend in argument; to
argue against something maintained, upheld, or claimed, by another; to
discuss; to reason; to debate; to altercate; to wrangle.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Therefore <qex>disputed</qex> [reasoned, <au>Rev. Ver.</au>] he in
synagogue with the Jews.</q> <rj><qau>Acts xvii. 17.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispute</ent><br/
<hw>Dis*pute"</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To make a subject
of disputation; to argue pro and con; to discuss.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The rest I reserve it be <qex>disputed</qex> how the magistrate is
to do herein.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To oppose by argument or assertion; to attempt to
overthrow; to controvert; to express dissent or opposition to; to call
in question; to deny the truth or validity of; <as>as, to
<ex>dispute</ex> assertions or arguments</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To seize goods under the <qex>disputed</qex> authority of writs of
assistance.</q> <rj><qau>Bancroft.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To strive or contend about; to contest.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>dispute</qex> the possession of the ground with the
Spaniards.</q> <rj><qau>Prescott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To struggle against; to resist.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Dispute</qex> it [grief] like a man.</q>
<rj><qau>Shak.</qau></rj></p>

<p><syn><b>Syn.</b> -- To controvert; contest; gainsay; doubt; question;
argue; debate; discuss; impugn. See <er>Argue</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dispute</ent><br/
<hw>Dis*pute"</hw>, <pos>n.</pos> <ety>[Cf. F. <ets>dispute</ets>. See
<er>Dispute</er>, <pos>v. i.</pos>]</ety> <sn>1.</sn> <def>Verbal
controversy; contest by opposing argument or expression of opposing
views or claims; controversial discussion; altercation;
debate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Addicted more<br/
To contemplation and profound <qex>dispute</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Contest; struggle; quarrel.</def> <rj><au>De
Foe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Beyond dispute</b></col>, <col><b>Without
dispute</b></col></mcol>, <cd>indisputably;
incontrovertibly.</cd></cs></p>

<p><syn><b>Syn.</b> -- Altercation; controversy; argumentation; debate;
discussion; quarrel; disagreement; difference; contention; wrangling.
See <er>Altercation</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disputeless</ent><br/
<hw>Dis*pute"less</hw>, <pos>a.</pos> <def>Admitting no dispute;
incontrovertible.</def> <rj><au>Bailey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disputer</ent><br/
<hw>Dis*put"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who disputes,
or who is given to disputes; a controvertist.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Where is the <qex>disputer</qex> of this world?</q> <rj><qau>1
Cor. i. 20.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disputison</ent><br/
<hw>Dis*pu"ti*son</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Disputation</er>.]</ety> <def>Dispute; discussion.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disqualification</ent><br/
<hw>Dis*qual`i*fi*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>The act of disqualifying, or state of being disqualified; want of
qualification; incompetency; disability; <as>as, the
<ex>disqualification</ex> of men for holding certain
offices</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which disqualifies; that which incapacitates or
makes unfit; <as>as, conviction of crime is a <ex>disqualification</ex>
of a person for office; sickness is a <ex>disqualification</ex> for
labor.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>I must still retain the consciousness of those
<qex>disqualifications</qex> which you have been pleased to
overlook.</q> <rj><qau>Sir J. Shore.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>disqualified</ent><br/
<hw>dis*qual"i*fied</hw> <pr>(d<icr/s*kw<ocr/l"<icr/*f<imac/d)</pr>,
<pos>adj.</pos> <sn>1.</sn> <def>rendered ineligible by law or rule or
provision; <as>as, <ex>disqualified</ex> from voting</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <fld>(Sports)</fld> <def>barred from competition for
violation of rules; <as>as, a <ex>disqualified</ex>
player</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>disqualify</ent><br/
<hw>dis*qual"i*fy</hw> <pr>(d<icr/s*kw<ocr/l"<icr/*f<imac/)</pr>,
<pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Disqualified</conjf> <pr>(d<icr/s*kw<ocr/l"<icr/*f<imac/d)</pr>;
<pos>p. pr. & vb. n.</pos> <conjf>Disqualifying</conjf>.]</vmorph>
<sn>1.</sn> <def>To deprive of the qualities or properties necessary for
any purpose; to render unfit; to incapacitate; -- with <xex>for</xex> or
<xex>from</xex> before the purpose, state, or act.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>My common illness <qex>disqualifies</qex> me for all conversation;
I mean my deafness.</q> <rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Me are not <qex>disqualified</qex> by their engagements in trade
from being received in high society.</q>
<rj><qau>Southey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To deprive of some power, right, or privilege, by
positive restriction; to disable; to debar legally; <as>as, a conviction
of perjury <ex>disqualifies</ex> a man to be a witness</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disquantity</ent><br/
<hw>Dis*quan"ti*ty</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To diminish
the quantity of; to lessen.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disquiet</ent><br/
<hw>Dis*qui"et</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Deprived of quiet;
impatient; restless; uneasy.</def> <mark>[R.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disquiet</ent><br/
<hw>Dis*qui"et</hw>, <pos>n.</pos> <def>Want of quiet; want of
tranquility in body or mind; uneasiness; restlessness; disturbance;
anxiety.</def> <rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disquiet</ent><br/
<hw>Dis*qui"et</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Disquieted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Disquieting</conjf>.]</vmorph> <def>To render unquiet; to deprive
of peace, rest, or tranquility; to make uneasy or restless; to
disturb.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Why art thou cast down, O my soul, and why art thou
<qex>disquieted</qex> within me?</q> <rj><qau>Ps. xlii.
11.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>As quiet as these <qex>disquieted</qex> times will permit.</q>
<rj><qau>Sir W. Scott.</qau></rj></p>

<p><syn><b>Syn.</b> -- To harass; disturb; vex; fret; excite;
agitate.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disquietal</ent><br/
<hw>Dis*qui"et*al</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
disquieting; a state of disquiet.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>[It] roars and strives 'gainst its <qex>disquietal</qex>.</q>
<rj><qau>Dr. H. More.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disquieter</ent><br/
<hw>Dis*qui"et*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, disquiets, or makes uneasy; a disturber.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disquietful</ent><br/
<hw>Dis*qui"et*ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Producing
inquietude or uneasiness.</def> <mark>[R.]</mark>
<rj><au>Barrow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disquietive</ent><br/
<hw>Dis*qui"et*ive</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Tending to
disquiet.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disquietly</ent><br/
<hw>Dis*qui"et*ly</hw>, <pos>adv.</pos> <def>In a disquiet manner;
uneasily; <as>as, he rested <ex>disquietly</ex> that night</as>.</def>
<mark>[R.]</mark> <rj><au>Wiseman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disquietment</ent><br/
<hw>Dis*qui"et*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>State of being
disquieted; uneasiness; harassment.</def> <mark>[R.]</mark>
<rj><au>Hopkins.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disquietness</ent><br/
<hw>Dis*qui"et*ness</hw>, <pos>n.</pos> <def>Disturbance of quiet in
body or mind; restlessness; uneasiness.</def>
<rj><au>Hooker.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disquietous</ent><br/
<hw>Dis*qui"et*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Causing
uneasiness.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>So distasteful and <qex>disquietous</qex> to a number of men.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disquiettude</ent><br/
<hw>Dis*qui"et*tude</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Want of peace
or tranquility; uneasiness; disturbance; agitation; anxiety.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Fears and <qex>disquietude</qex>, and unavoidable anxieties of
mind.</q> <rj><qau>Abp. Sharp.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disquisition</ent><br/
<hw>Dis`qui*si"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>disquisitio</ets>, fr. <ets>disquirere</ets> to inquire diligently,
investigate; <ets>dis-</ets> + <ets>quaerere</ets> to seek. See
<er>Quest</er>.]</ety> <def>A formal or systematic inquiry into, or
discussion of, any subject; a full examination or investigation of a
matter, with the arguments and facts bearing upon it; elaborate essay;
dissertation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>For accurate research or grave <qex>disquisition</qex> he was not
well qualified.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disquisitional</ent><br/
<hw>Dis`qui*si"tion*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining
to disquisition; of the nature of disquisition.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disquisitionary</ent><br/
<hw>Dis`qui*si"tion*a*ry</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Pertaining to disquisition; disquisitional.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disquisitive</ent><br/
<hw>Dis*quis"i*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Relating to
disquisition; fond of discussion or investigation; examining;
inquisitive.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disquisitorial</ent><br/
<hw>Dis*quis`i*to"ri*al</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Disquisitory.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disquisitory</ent><br/
<hw>Dis*quis"i*to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or
pertaining to disquisition; disquisitive.</def> <rj><au>Ed.
Rev.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disrange</ent><br/
<hw>Dis*range"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>dis-</ets> + <ets>range</ets>: cf. OF. <ets>desrengier</ets>, F.
<ets>d<eacute/rangier</ets>. See <er>Derange</er>,
<er>Disrank</er>.]</ety> <def>To disarrange.</def> <mark>[Obs.]</mark>
<rj><au>Wood.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disrank</ent><br/
<hw>Dis*rank"</hw> <pr>(?; see <er>Dis-</er>)</pr>, <pos>v. t.</pos>
<ety>[Cf. <er>Derange</er>.]</ety> <sn>1.</sn> <def>To degrade from
rank.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To throw out of rank or into confusion.</def>
<rj><au>Decker.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>disrate</ent><br/
<hw>dis*rate"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To reduce to a
lower rating or rank; to degrade.</def> <rj><au>Marryat.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>disray</ent><br/
<hw>dis*ray"</hw> <pr>(?)</pr>, <def><er>Disarray</er>; -- an obsolete
variant.</def> <mark>[Obs.]</mark> <rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>disrealize</ent><br/
<hw>dis*re"al*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To divest of
reality; to make uncertain.</def> <mark>[Obs.]</mark>
<rj><au>Udall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>disregard</ent><br/
<hw>dis`re*gard"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>disregarded</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>disregarding</conjf>.]</vmorph> <def>Not to regard; to pay no
heed to; to omit to take notice of; to neglect to observe; to slight as
unworthy of regard or notice; <as>as, to <ex>disregard</ex> the
admonitions of conscience</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Studious of good, man <qex>disregarded</qex> fame.</q>
<rj><qau>Blackmore.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disregard</ent><br/
<hw>Dis`re*gard"</hw>, <pos>n.</pos> <def>The act of disregarding, or
the state of being disregarded; intentional neglect; omission of notice;
want of attention; slight.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>disregard</qex> of experience.</q>
<rj><qau>Whewell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disregarder</ent><br/
<hw>Dis`re*gard"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
disregards.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disregardful</ent><br/
<hw>Dis`re*gard"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Neglect;
negligent; heedless; regardless.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disregardfully</ent><br/
<hw>Dis`re*gard"ful*ly</hw>, <pos>adv.</pos> <def>Negligently;
heedlessly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disrelish</ent><br/
<hw>Dis*rel"ish</hw> <pr>(?; see <er>Dis-</er>)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>Want of relish; dislike (of the palate or of the mind);
distaste; a slight degree of disgust; <as>as, a <ex>disrelish</ex> for
some kinds of food</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Men love to hear of their power, but have an extreme
<qex>disrelish</qex> to be told of their duty.</q>
<rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Absence of relishing or palatable quality; bad
taste; nauseousness.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disrelish</ent><br/
<hw>Dis*rel"ish</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Disrelished</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Disrelishing</conjf>.]</vmorph> <sn>1.</sn> <def>Not to relish;
to regard as unpalatable or offensive; to feel a degree of disgust
at.</def> <rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To deprive of relish; to make nauseous or disgusting
in a slight degree.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disremember</ent><br/
<hw>Dis`re*mem"ber</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To fail to
remember; to forget.</def> <mark>[Obs. or Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disrepair</ent><br/
<hw>Dis`re*pair"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A state of being
in bad condition, and needing repair.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The fortifications were ancient and in <qex>disrepair</qex>.</q>
<rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disreputability</ent><br/
<hw>Dis*rep`u*ta*bil"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The
state of being disreputable.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disreputable</ent><br/
<hw>Dis*rep"u*ta*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Not
reputable; of bad repute; not in esteem; dishonorable; disgracing the
reputation; tending to bring into disesteem; <as>as, it is
<ex>disreputable</ex> to associate familiarly with the mean, the lewd,
and the profane</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Why should you think that conduct <qex>disreputable</qex> in
priests which you probably consider as laudable in yourself?</q>
<rj><qau>Bp. Watson.</qau></rj></p>

<p><syn><b>Syn.</b> -- Dishonorable; discreditable; low; mean;
disgraceful; shameful.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disreputably</ent><br/
<hw>Dis*rep"u*ta*bly</hw>, <pos>adv.</pos> <def>In a disreputable
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disreputation</ent><br/
<hw>Dis*rep`u*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Loss or want
of reputation or good name; dishonor; disrepute; disesteem.</def>
<ldquo/A <xex>disreputation</xex> of piety.<rdquo/ <rj><au>Jer.
Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disrepute</ent><br/
<hw>Dis`re*pute"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Loss or want of
reputation; ill character; disesteem; discredit.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>At the beginning of the eighteenth century astrology fell into
general <qex>disrepute</qex>.</q> <rj><qau>Sir W. Scott.</qau></rj></p>

<p><syn><b>Syn.</b> -- Disesteem; discredit; dishonor;
disgrace.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disrepute</ent><br/
<hw>Dis`re*pute"</hw>, <pos>v. t.</pos> <def>To bring into
disreputation; to hold in dishonor.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>More inclined to love them than to <qex>disrepute</qex> them.</q>
<rj><qau>Jer. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disrespect</ent><br/
<hw>Dis`re*spect"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Want of respect
or reverence; disesteem; incivility; discourtesy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Impatience of bearing the least affront or
<qex>disrespect</qex>.</q> <rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disrespect</ent><br/
<hw>Dis`re*spect"</hw>, <pos>v. t.</pos> <def>To show disrespect
to.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We have <qex>disrespected</qex> and slighted God.</q>
<rj><qau>Comber.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disrespectability</ent><br/
<hw>Dis`re*spect`a*bil"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Lack
of respectability.</def> <rj><au>Thackeray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disrespectable</ent><br/
<hw>Dis`re*spect"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Not
respectable; disreputable.</def> <rj><au>M. Arnold.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disrespecter</ent><br/
<hw>Dis`re*spect"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
disrespects.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disrespectful</ent><br/
<hw>Dis`re*spect"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Wanting in
respect; manifesting disesteem or lack of respect; uncivil; <as>as,
<ex>disrespectful</ex> behavior</as>.</def> --
<wordforms><wf>Dis`re*spect"ful*ly</wf>, <pos>adv.</pos> --
<wf>Dis`re*spect"ful*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disrespective</ent><br/
<hw>Dis`re*spect"ive</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Showing lack
of respect; disrespectful.</def> <mark>[Obs.]</mark> <rj><au>Bp.
Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disreverence</ent><br/
<hw>Dis*rev"er*ence</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To treat
irreverently or with disrespect.</def> <mark>[Obs.]</mark> <rj><au>Sir
T. More.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disrobe</ent><br/
<hw>Dis*robe"</hw> <pr>(?; see <er>Dis-</er>)</pr>, <pos>v. t. &
i.</pos> <vmorph>[<pos>imp. & p. p.</pos> <conjf>Disrobed</conjf>
<pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Disrobing</conjf>.]</vmorph> <def>To divest of a robe; to
undress; figuratively, to strip of covering; to divest of that which
clothes or decorates; <as>as, autumn <ex>disrobes</ex> the fields of
verdure</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Two great peers were <qex>disrobed</qex> of their glory.</q>
<rj><qau>Sir H. Wotton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disrober</ent><br/
<hw>Dis*rob"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, disrobes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disroof</ent><br/
<hw>Dis*roof"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To unroof.</def>
<mark>[R.]</mark> <rj><au>Carlyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disroot</ent><br/
<hw>Dis*root"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Disrooted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Disrooting</conjf>.]</vmorph> <def>To tear up the roots of, or by
the roots; hence, to tear from a foundation; to uproot.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A piece of ground <qex>disrooted</qex> from its situation by
subterraneous inundations.</q> <rj><qau>Goldsmith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disrout</ent><br/
<hw>Dis*rout"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[Cf. OF.
<ets>desrouter</ets>, F. <ets>d<eacute/router</ets>.]</ety> <def>To put
to rout.</def> <rj><au>Taylor (1630).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disrudder</ent><br/
<hw>Dis*rud"der</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To deprive of
the rudder, as a ship.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disrulily</ent><br/
<hw>Dis*ru"li*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a disorderly
manner.</def> <mark>[Obs.]</mark> <rj><au>Rom. of R.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disruly</ent><br/
<hw>Dis*ru"ly</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Unruly;
disorderly.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disrupt</ent><br/
<hw>Dis*rupt"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>disruptus</ets>, <ets>diruptus</ets>, p. p. of
<ets>disrumpere</ets>, to break or burst asunder; <ets>dis-</ets> +
<ets>rumpere</ets> to break, burst. See <er>Rupture</er>.]</ety>
<def>Rent off; torn asunder; severed; disrupted.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>disrupt</ent><br/
<hw>dis*rupt"</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Disrupted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Disrupting</conjf>.]</vmorph> <sn>1.</sn> <def>To break asunder;
to rend.</def> <rj><au>Thomson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>to destroy the continuity of, usually temporarily;
<as>as, electrical power was <ex>disrupted</ex> by the
hurricane</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>To interfere with or halt, especially by causing a
lack of order; <as>as, the shouting of the demonstrators
<ex>disrupted</ex> the meeting</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>disrupted</ent><br/
<hw>disrupted</hw> <pos>adj.</pos> <def>Not continuous in time or space.
Opposite of <ant>continuous</ant>.</def><br/
<syn><b>Syn. --</b> disconnected, discontinuous,
noncontinuous.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Disruption</ent><br/
<hw>Dis*rup"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>disruptio</ets>, <ets>diruptio</ets>.]</ety> <def>The act or
rending asunder, or the state of being rent asunder or broken in pieces;
breach; rent; dilaceration; rupture; <as>as, the <ex>disruption</ex> of
rocks in an earthquake; <ex>disruption</ex> of a state.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disruptive</ent><br/
<hw>Dis*rupt"ive</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Causing, or
tending to cause, disruption; caused by disruption; breaking through;
bursting; <as>as, the <ex>disruptive</ex> discharge of an electrical
battery</as>.</def> <rj><au>Nichol.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disrupture</ent><br/
<hw>Dis*rup"ture</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Disruption.</def>
<mark>[R.]</mark> <rj><au>Jefferson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissatisfaction</ent><br/
<hw>Dis*sat`is*fac"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state
of being dissatisfied, unsatisfied, or discontented; uneasiness
proceeding from the want of gratification, or from disappointed wishes
and expectations.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The ambitious man has little happiness, but is subject to much
uneasiness and <qex>dissatisfaction</qex>.</q>
<rj><qau>Addison.</qau></rj></p>

<p><syn><b>Syn.</b> -- Discontent; discontentment; displeasure;
disapprobation; distaste; dislike.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissatisfactory</ent><br/
<hw>Dis*sat`is*fac"to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Causing
dissatisfaction; unable to give content; unsatisfactory;
displeasing.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To have reduced the different qualifications in the different
States to one uniform rule, would probably have been as
<qex>dissatisfactory</qex> to some of the States, as difficult for the
Convention.</q> <rj><qau>A. Hamilton.</qau></rj></p>

<p>-- <wordforms><wf>Dis*sat`is*fac"to*ri*ness</wf> <pr>(#)</pr>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>dissatisfied</ent><br/
<hw>dissatisfied</hw> <pos>adj.</pos> <def>in a state of sulky
dissatisfaction.</def><br/
<syn><b>Syn. --</b> disgruntled.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dissatisfy</ent><br/
<hw>Dis*sat"is*fy</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Dissatisfied</conjf> <pr>(?)</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>Dissatisfying</conjf>.]</vmorph> <def>To render
unsatisfied or discontented; to excite uneasiness in by frustrating
wishes or expectations; to displease by the want of something requisite;
<as>as, to be <ex>dissatisfied</ex> with one's fortune</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>dissatisfied</qex> factions of the autocracy.</q>
<rj><qau>Bancroft.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disseat</ent><br/
<hw>Dis*seat"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To unseat.</def>
<mark>[R.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissect</ent><br/
<hw>Dis*sect"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Dissected</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Dissecting</conjf>.]</vmorph> <ety>[L. <ets>dissectus</ets>, p.
p. of <ets>dissecare</ets>; <ets>dis-</ets> + <ets>secare</ets> to cut.
See <er>Section</er>.]</ety> <sn>1.</sn> <fld>(Anat.)</fld> <def>To
divide into separate parts; to cut in pieces; to separate and expose the
parts of, as an animal or a plant, for examination and to show their
structure and relations; to anatomize.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 432 --></p>

<p><sn>2.</sn> <def>To analyze, for the purposes of science or
criticism; to divide and examine minutely.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This paragraph . . . I have <qex>dissected</qex> for a sample.</q>
<rj><qau>Atterbury.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissected</ent><br/
<hw>Dis*sect"ed</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Cut
into several parts; divided into sections; <as>as, a <ex>dissected</ex>
map</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>Cut deeply into many lobes or
divisions; <as>as, a <ex>dissected</ex> leaf</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissectible</ent><br/
<hw>Dis*sect"i*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of
being dissected, or separated by dissection.</def>
<rj><au>Paley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissecting</ent><br/
<hw>Dis*sect"ing</hw>, <pos>a.</pos> <sn>1.</sn> <def>Dividing or
separating the parts of an animal or vegetable body; <as>as, a
<ex>dissecting</ex> aneurism, one which makes its way between or within
the coats of an artery</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of or pertaining to, or received during, a
dissection; <as>as, a <ex>dissecting</ex> wound</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Used for or in dissecting; <as>as, a
<ex>dissecting</ex> knife; a <ex>dissecting</ex>
microscope.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissection</ent><br/
<hw>Dis*sec"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>dissection</ets>.]</ety> <sn>1.</sn> <def>The act of dissecting an
animal or plant; <as>as, <ex>dissection</ex> of the human body was held
sacrilege till the time of Francis I</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Fig.: The act of separating or dividing for the
purpose of critical examination.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Anything dissected; especially, some part, or the
whole, of an animal or plant dissected so as to exhibit the structure;
an anatomical so prepared.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dissection wound</b></col>, <cd>a poisoned wound incurred
during the dissection of a dead body.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissector</ent><br/
<hw>Dis*sect"or</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>dissecteur</ets>.]</ety> <def>One who dissects; an
anatomist.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disseize</ent><br/
<hw>Dis*seize"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Disseized</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Disseizing</conjf>.]</vmorph> <ety>[Pref.
<ets>dis-</ets> + <ets>seize</ets>: cf. F. <ets>dessaisir</ets>.]</ety>
<fld>(Law)</fld> <def>To deprive of seizin or possession; to dispossess
or oust wrongfully (one in freehold possession of land); -- followed by
<xex>of</xex>; <as>as, to <ex>disseize</ex> a tenant of his
freehold</as>.</def> <altsp>[Written also
<asp>disseise</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><q>Which savage beasts strive as eagerly to keep and hold those
golden mines, as the Arimaspians to <qex>disseize</qex> them
thereof.</q> <rj><qau>Holland.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disseizee</ent><br/
<hw>Dis`sei*zee"</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Law)</fld>
<def>A person disseized, or put out of possession of an estate
unlawfully; -- correlative to <xex>disseizor</xex>.</def>
<altsp>[Written also <asp>disseisee</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disseizin</ent><br/
<hw>Dis*sei"zin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>dessaisine</ets>.]</ety> <fld>(Law)</fld> <def>The act of
disseizing; an unlawful dispossessing and ouster of a person actually
seized of the freehold.</def> <altsp>[Written also
<asp>disseisin</asp>.]</altsp> <rj><au>Blackstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disseizor</ent><br/
<hw>Dis*sei"zor</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Law)</fld>
<def>One who wrongfully disseizes, or puts another out of possession of
a freehold.</def> <altsp>[Written also <asp>disseisor</asp>.]</altsp>
<rj><au>Blackstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disseizoress</ent><br/
<hw>Dis*sei"zor*ess</hw>, <pos>n.</pos> <fld>(Law)</fld> <def>A woman
disseizes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disseizure</ent><br/
<hw>Dis*sei"zure</hw> <pr>(?; 135)</pr>, <pos>n.</pos>
<def>Disseizin.</def> <rj><au>Speed.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissemblance</ent><br/
<hw>Dis*sem"blance</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>dissemblance</ets>. See <er>Dissemble</er>.]</ety> <def>Want of
resemblance; dissimilitude.</def> <mark>[R.]</mark>
<rj><au>Osborne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissemblance</ent><br/
<hw>Dis*sem"blance</hw>, <pos>n.</pos> <ety>[<ets>Dissemble</ets> +
<ets>-ance</ets>.]</ety> <def>The act or art of dissembling;
dissimulation.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissemble</ent><br/
<hw>Dis*sem"ble</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Dissembled</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Dissembling</conjf> <pr>(?)</pr>.]</vmorph> <ety>[OF.
<ets>dissembler</ets> to be dissimilar; pref. <ets>dis-</ets> (L.
<ets>dis-</ets>) + F. <ets>sembler</ets> to seem, L. <ets>simulare</ets>
to simulate; cf. L. <ets>dissimulare</ets> to dissemble. See
<er>Simulate</er>, and cf. <er>Dissimulate</er>.]</ety> <sn>1.</sn>
<def>To hide under a false semblance or seeming; to feign (something)
not to be what it really is; to put an untrue appearance upon; to
disguise; to mask.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Dissemble</qex> all your griefs and discontents.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Perhaps it was right to <qex>dissemble</qex> your love,<br/
But -- why did you kick me down stairs?</q> <rj><qau>J. P.
Kemble.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To put on the semblance of; to make pretense of; to
simulate; to feign.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He soon <qex>dissembled</qex> a sleep.</q>
<rj><qau>Tatler.</qau></rj></p>

<p><syn><b>Syn.</b> -- To conceal; disguise; cloak; cover; equivocate.
See <er>Conceal</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissemble</ent><br/
<hw>Dis*sem"ble</hw>, <pos>v. i.</pos> <def>To conceal the real fact,
motives, intention, or sentiments, under some pretense; to assume a
false appearance; to act the hypocrite.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He that hateth <qex>dissembleth</qex> with his lips.</q>
<rj><qau>Prov. xxvi. 24.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He [an enemy] <qex>dissembles</qex> when he assumes an air of
friendship.</q> <rj><qau>C. J. Smith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissembler</ent><br/
<hw>Dis*sem"bler</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
dissembles; one who conceals his opinions or dispositions under a false
appearance; a hypocrite.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It is the weakest sort of politicians that are the greatest
<qex>dissemblers</qex>.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Priests, princes, women, no <qex>dissemblers</qex> here.</q>
<rj><qau>Pope.</qau></rj></p>

<p><syn><b>Syn.</b> -- <er>Dissembler</er>, <er>Hypocrite</er>.</syn>
<usage>A person is called a <xex>dissembler</xex> with reference to his
concealment of his real character, and a <xex>hypocrite</xex> with
reference to his assumption of a false character. But
<xex>hypocrite</xex> is the stronger word, being commonly used to
characterize a person who is habitually insincere and false, especially
one who makes professions of goodness when his aims are selfish and his
life corrupt.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissembling</ent><br/
<hw>Dis*sem"bling</hw> <pr>(?)</pr>, <pos>a.</pos> <def>That dissembles;
hypocritical; false.</def> -- <wordforms><wf>Dis*sem"bling*ly</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disseminate</ent><br/
<hw>Dis*sem"i*nate</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Disseminated</conjf>; <pos>p.
pr. & vb. n.</pos> <conjf>Disseminating</conjf>.]</vmorph> <ety>[L.
<ets>disseminatus</ets>, p. p. of <ets>disseminare</ets> to disseminate;
<ets>dis-</ets> + <ets>seminare</ets> to sow, <ets>semen</ets> seed. See
<er>Seminary</er>.]</ety> <sn>1.</sn> <def>to spread around widely; to
sow broadcast or as seed; to scatter for growth and propagation, like
seed; to spread abroad; to diffuse; <as>as, principles, ideas, opinions,
and errors are <ex>disseminated</ex> when they are spread abroad for
propagation</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To spread or extend by dispersion.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A nearly uniform and constant fire or heat <qex>disseminated</qex>
throughout the body of the earth.</q> <rj><qau>Woodward.</qau></rj></p>

<p><syn><b>Syn.</b> -- To spread; diffuse; propagate; circulate;
disperse; scatter.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>disseminated</ent><br/
<hw>dis*sem"i*na`ted</hw> <pr>(?)</pr>, <pos>p. a.</pos>
<fld>(Min.)</fld> <def>Occurring in small portions scattered through
some other substance; scattered widely.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>disseminating</ent><br/
<hw>disseminating</hw> <pos>adj.</pos> <def>serving to diffuse,
disseminate, or disperse.</def><br/
<syn><b>Syn. --</b> diffusing(prenominal), diffusive, dispersive,
disseminative, scattering, spreading.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>dissemination</ent><br/
<hw>dis*sem`i*na"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>disseminatio</ets>: cf. F. <ets>diss<eacute/mination</ets>.]</ety>
<def>The act of disseminating, or the state of being disseminated;
diffusion for propagation and permanence; a scattering or spreading
abroad, as of ideas, beliefs, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The universal <qex>dissemination</qex> of those writings.</q>
<rj><qau>Wayland.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>disseminative</ent><br/
<hw>dis*sem"i*na*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Tending to
disseminate, or to become disseminated.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The effect of heresy is, like the plague, infectious and
<qex>disseminative</qex>.</q> <rj><qau>Jer. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disseminator</ent><br/
<hw>Dis*sem"i*na`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.]</ety>
<def>One who, or that which, disseminates, spreads, or propagates;
<as>as, <ex>disseminators</ex> of disease</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissension</ent><br/
<hw>Dis*sen"sion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>dissensio</ets>: cf. F. <ets>dissension</ets>. See
<er>Dissent</er>.]</ety> <def>Disagreement in opinion, usually of a
violent character, producing warm debates or angry words; contention in
words; partisan and contentious divisions; breach of friendship and
union; strife; discord; quarrel.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Paul and Barnabas had no small <qex>dissension</qex> and
disputation with them.</q> <rj><qau>Acts xv. 2.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Debates, <qex>dissension</qex>, uproars are thy joy.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A seditious person and raiser-up of <qex>dissension</qex> among
the people.</q> <rj><qau>Robynson (More's Utopia).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissensious</ent><br/
<hw>Dis*sen"sious</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Disposed to
discord; contentious; dissentious.</def> <mark>[R.]</mark>
<au>Ascham.</au> -- <wordforms><wf>Dis*sen"sious*ly</wf>,
<pos>adv.</pos></wordforms> <rj><au>Chapman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissent</ent><br/
<hw>Dis*sent"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Dissented</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Dissenting</conjf>.]</vmorph> <ety>[L. <ets>dissentire</ets>,
<ets>dissentum</ets>; <ets>dis-</ets> + <ets>sentire</ets> to feel,
think. See <er>Sense</er>.]</ety> <sn>1.</sn> <def>To differ in opinion;
to be of unlike or contrary sentiment; to disagree; -- followed by
<xex>from</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The bill passed . . . without a <qex>dissenting</qex> voice.</q>
<rj><qau>Hallam.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Opinions in which multitudes of men <qex>dissent</qex> from
us.</q> <rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Eccl.)</fld> <def>To differ from an established
church in regard to doctrines, rites, or government.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To differ; to be of a contrary nature.</def>
<rj><au>Hooker.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissent</ent><br/
<hw>Dis*sent"</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act of
dissenting; difference of opinion; refusal to adopt something proposed;
nonagreement, nonconcurrence, or disagreement.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>dissent</qex> of no small number [of peers] is frequently
recorded.</q> <rj><qau>Hallam.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Eccl.)</fld> <def>Separation from an established
church, especially that of England; nonconformity.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It is the dissidence of <qex>dissent</qex> and the protestantism
of the Protestant religion.</q> <rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Contrariety of nature; diversity in quality.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>dissent</qex> of the metals.</q>
<rj><qau>Bacon.</qau></rj></p>

<p><syn><b>Syn.</b> -- Disagreement; variance; difference;
nonconcurrence; nonconformity.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissentaneous</ent><br/
<hw>Dis`sen*ta"ne*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>dissentaneus</ets>.]</ety> <def>Disagreeing; contrary; differing;
-- opposed to <ant>consentaneous</ant>.</def> <mark>[R.]</mark>
<rj><au>Barrow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissentany</ent><br/
<hw>Dis"sen*ta*ny</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Dissentaneous;
inconsistent.</def> <mark>[Obs.]</mark> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissentation</ent><br/
<hw>Dis`sen*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Dissension.</def> <mark>[Obs.]</mark> <rj><au>W.
Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissenter</ent><br/
<hw>Dis*sent"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One
who dissents; one who differs in opinion, or declares his
disagreement.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Eccl.)</fld> <def>One who separates from the
service and worship of an established church; especially, one who
disputes the authority or tenets of the Church of England; a
nonconformist.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Dissenters</qex> from the establishment of their several
countries.</q> <rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Robert Brown is said to have the first formal
<qex>dissenter</qex>.</q> <rj><qau>Shipley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <ldquo/The word is commonly applied only to Protestants.
The Roman Catholics are generally referred to as a distinct
class.<rdquo/</note> <rj><au>Brande & C.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissenterism</ent><br/
<hw>Dis*sent"er*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The spirit or
principles of dissenters.</def> <rj><au>Ed. Rev.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissentiate</ent><br/
<hw>Dis*sen"ti*ate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To throw
into a state of dissent.</def> <mark>[R.]</mark>
<rj><au>Feltham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissentient</ent><br/
<hw>Dis*sen"tient</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>dissentiens</ets>, p. pr. of <ets>dissentire</ets>. See
<er>Dissent</er>, <pos>v. i.</pos>]</ety> <def>Disagreeing; declaring
dissent; dissenting.</def> -- <def2><pos>n.</pos> <def>One who
dissents.</def></def2> <rj><au>Macaulay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>dissenting</ent><br/
<hw>dissenting</hw> <pos>adj.</pos> <def>disagreeing, especially with a
majority.</def><br/
<syn><b>Syn. --</b> dissentient, dissident.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dissentious</ent><br/
<hw>Dis*sen"tious</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Marked by
dissensions; apt to breed discord; quarrelsome; contentious;
factious.</def> -- <wordforms><wf>Dis*sen"tious*ly</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissentive</ent><br/
<hw>Dis*sent"ive</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Disagreeing;
inconsistent.</def> <mark>[Obs.]</mark> <rj><au>Feltham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissepiment</ent><br/
<hw>Dis*sep"i*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>dissaepimentum</ets>, fr. <ets>dissaepire</ets>; <ets>dis-</ets> +
<ets>saepire</ets> to hedge in, inclose.]</ety> <sn>1.</sn> <def>A
separating tissue; a partition; a septum.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>One of the partitions which divide
a compound ovary into cells.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <def>One of the transverse, calcareous
partitions between the radiating septa of a coral.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissert</ent><br/
<hw>Dis*sert"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[L.
<ets>dissertus</ets>, p. p. of <ets>disserere</ets>; <ets>dis-</ets> +
<ets>serere</ets> to join, connect: cf. F. <ets>disserter</ets>. See
<er>Series</er>.]</ety> <def>To discourse or dispute; to discuss.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>We have <qex>disserted</qex> upon it a little longer than was
necessary.</q> <rj><qau>Jeffrey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissertate</ent><br/
<hw>Dis"ser*tate</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[L.
<ets>dissertatus</ets>, p. p. of <ets>dissertare</ets> to discuss,
intents, fr. <ets>disserere</ets>. See <er>Dissert</er>.]</ety> <def>To
deal in dissertation; to write dissertations; to discourse.</def>
<mark>[R.]</mark> <rj><au>J. Foster.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissertation</ent><br/
<hw>Dis`ser*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>dissertatio</ets>: cf. F. <ets>dissertation</ets>.]</ety> <def>A
formal or elaborate argumentative discourse, oral or written; a
disquisition; an essay; a discussion; <as>as, <ex>Dissertations</ex> on
the Prophecies</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissertational</ent><br/
<hw>Dis`ser*ta"tion*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Relating to
dissertations; resembling a dissertation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissertationist</ent><br/
<hw>Dis`ser*ta"tion*ist</hw>, <pos>n.</pos> <def>A writer of
dissertations.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissertator</ent><br/
<hw>Dis"ser*ta`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.: cf. F.
<ets>dissertateur</ets>.]</ety> <def>One who writers a dissertation; one
who discourses.</def> <rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissertly</ent><br/
<hw>Dis*sert"ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>See
<er>Disertly</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disserve</ent><br/
<hw>Dis*serve"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Disserved</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Disserving</conjf>.]</vmorph> <ety>[Pref.
<ets>dis-</ets> + <ets>serve</ets>: cf. F. <ets>desservir</ets>.]</ety>
<def>To fail to serve; to do injury or mischief to; to damage; to hurt;
to harm.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Have neither served nor <qex>disserved</qex> the interests of any
party.</q> <rj><qau>Jer. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disservice</ent><br/
<hw>Dis*serv"ice</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>dis-</ets> + <ets>service</ets>: cf. F.
<ets>desservice</ets>.]</ety> <def>Injury; mischief.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We shall rather perform good offices unto truth than any
<qex>disservice</qex> unto their relators.</q> <rj><qau>Sir T.
Browne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disserviceable</ent><br/
<hw>Dis*serv"ice*a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Calculated
to do disservice or harm; not serviceable; injurious; harmful;
unserviceable.</def> <au>Shaftesbury.</au> --
<wordforms><wf>Dis*serv"ice*a*ble*ness</wf>, <pos>n.</pos>
<au>Norris.</au> -- <wf>Dis*serv"ice*a*bly</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissettle</ent><br/
<hw>Dis*set"tle</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To
unsettle.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissettlement</ent><br/
<hw>Dis*set"tle*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
unsettling, or the state of being unsettled.</def>
<rj><au>Marvell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissever</ent><br/
<hw>Dis*sev"er</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Dissevered</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Dissevering</conjf>.]</vmorph> <ety>[OE.
<ets>dessevrer</ets>; pref. <ets>des-</ets> (L. <ets>dis-</ets>) +
<ets>sevrer</ets> to sever, F. <ets>sevrer</ets> to wean, L.
<ets>separate</ets> to separate. In this word the prefix is intensive.
See <er>Dis-</er>, and <er>Sever</er>.]</ety> <def>To part in two; to
sever thoroughly; to sunder; to disunite; to separate; to
disperse.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The storm so <qex>dissevered</qex> the company . . . that most of
therm never met again.</q> <rj><qau>Sir P. Sidney.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>States <qex>disserved</qex>, discordant, belligerent.</q>
<rj><qau>D. Webster.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissever</ent><br/
<hw>Dis*sev"er</hw>, <pos>v. i.</pos> <def>To part; to separate.</def>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disseverance</ent><br/
<hw>Dis*sev"er*ance</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>dessevrance</ets>.]</ety> <def>The act of disserving;
separation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disseveration</ent><br/
<hw>Dis*sev`er*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
disserving; disseverance.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disseverment</ent><br/
<hw>Dis*sev"er*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. OF.
<ets>dessevrement</ets>.]</ety> <def>Disseverance.</def> <rj><au>Sir W.
Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disshadow</ent><br/
<hw>Dis*shad"ow</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To free from
shadow or shade.</def> <mark>[Obs.]</mark> <rj><au>G.
Fletcher.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissheathe</ent><br/
<hw>Dis*sheathe"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To become
unsheathed.</def> <mark>[Obs.]</mark> <rj><au>Sir W.
Raleigh.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disship</ent><br/
<hw>Dis*ship"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To dismiss from
service on board ship.</def> <mark>[Obs.]</mark>
<rj><au>Hakluyt.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disshiver</ent><br/
<hw>Dis*shiv"er</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <def>To shiver
or break in pieces.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissidence</ent><br/
<hw>Dis"si*dence</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>dissidentia</ets>: cf. F. <ets>dissidence</ets>. See
<er>Dissident</er>, <pos>a.</pos>]</ety> <def>Disagreement; dissent;
separation from the established religion.</def> <rj><au>I.
Taylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>It is the <qex>dissidence</qex> of dissent.</q>
<rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissident</ent><br/
<hw>Dis"si*dent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>dissidens</ets>, <ets>-entis</ets>, p. pr. of <ets>dissidere</ets>
to sit apart, to disagree; <ets>dis-</ets> + <ets>sedere</ets> to sit:
cf. F. <ets>dissident</ets>. See <er>Sit</er>.]</ety> <def>No agreeing;
dissenting; discordant; different.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Our life and manners be <qex>dissident</qex> from theirs.</q>
<rj><qau>Robynson (More's Utopia).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissident</ent><br/
<hw>Dis"si*dent</hw>, <pos>n.</pos> <fld>(Eccl.)</fld> <def>One who
disagrees or dissents; one who separates from the established
religion.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>dissident</qex>, habituated and taught to think of his
dissidenc<?/ as a laudable and necessary opposition to ecclesiastical
usurpation.</q> <rj><qau>I. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissidently</ent><br/
<hw>Dis"si*dent*ly</hw>, <pos>adv.</pos> <def>In a dissident
manner.</def></p>

<p><ent>Dissiliency</ent><br/
<ent>Dissilience</ent><br/
<mhw>{ <hw>Dis*sil"i*ence</hw> <pr>(?; 106)</pr>,
<hw>Dis*sil"i*en*cy</hw> <pr>(?)</pr>, }</mhw> <pos>n.</pos> <def>The
act of leaping or starting asunder.</def> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissilient</ent><br/
<hw>Dis*sil"i*ent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>dissiliens</ets>, <ets>-entis</ets>, p. pr. of <ets>dissilire</ets>
to leap asunder: <ets>dis-</ets> + <ets>salire</ets> to leap.]</ety>
<def>Starting asunder; bursting and opening with an elastic force;
dehiscing explosively; <as>as, a <ex>dissilient</ex>
pericarp</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissilition</ent><br/
<hw>Dis`si*li"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
bursting or springing apart.</def> <mark>[R.]</mark>
<rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissimilar</ent><br/
<hw>Dis*sim"i*lar</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>dis-</ets> + <ets>similar</ets>: cf. F.
<ets>dissimilaire</ets>.]</ety> <def>Not similar; unlike; heterogeneous;
<as>as, the tempers of men are as <ex>dissimilar</ex> as their
features</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This part very <qex>dissimilar</qex> to any other.</q>
<rj><qau>Boyle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissimilarity</ent><br/
<hw>Dis*sim`i*lar"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Want of
resemblance; unlikeness; dissimilitude; variety; <as>as, the
<ex>dissimilarity</ex> of human faces and forms</as>.</def> <rj><au>Sir
W. Jones.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissimilarly</ent><br/
<hw>Dis*sim"i*lar*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a
dissimilar manner; in a varied style.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With verdant shrubs <qex>dissimilarly</qex> gay.</q> <rj><qau>C.
Smart.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissimilate</ent><br/
<hw>Dis*sim"i*late</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To render
dissimilar.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissimilation</ent><br/
<hw>Dis*sim`i*la"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
making dissimilar.</def> <rj><au>H. Sweet.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissimile</ent><br/
<hw>Dis*sim"i*le</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>dissimile</ets>, neut. of <ets>dissimilis</ets> unlike.]</ety>
<fld>(Rhet.)</fld> <def>Comparison or illustration by
contraries.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissimilitude</ent><br/
<hw>Dis`si*mil"i*tude</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>dissimilitudo</ets>, fr. <ets>dissimilis</ets>: cf. F.
<ets>dissimilitude</ets>.]</ety> <sn>1.</sn> <def>Want of resemblance;
unlikeness; dissimilarity.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Dissimilitude</qex> between the Divinity and images.</q>
<rj><qau>Stillingfleet.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Rhet.)</fld> <def>A comparison by contrast; a
dissimile.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissimulate</ent><br/
<hw>Dis*sim"u*late</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>dissimulatus</ets>, p. p. of <ets>dissimulare</ets>. See
<er>Dissemble</er>.]</ety> <def>Feigning; simulating; pretending.</def>
<mark>[Obs.]</mark> <rj><au>Henryson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>dissimulate</ent><br/
<hw>dis*sim"u*late</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To
dissemble; to feign; to pretend.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>dissimulating</ent><br/
<hw>dissimulating</hw> <pos>adj.</pos> <def>concealing under a false
appearance with the intent to deceive.</def><br/
<syn><b>Syn. --</b> dissembling, dissimulative.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>dissimulation</ent><br/
<hw>dis*sim`u*la"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>dissimulatio</ets>: cf. F. <ets>dissimulation</ets>.]</ety>
<def>The act of dissembling; a hiding under a false appearance;
concealment by feigning; false pretension; hypocrisy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Let love be without <qex>dissimulation</qex>.</q> <rj><qau>Rom.
xii. 9.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Dissimulation</qex> . . . when a man lets fall signs and
arguments that he is not that he is.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Simulation is a pretense of what is not, and
<qex>dissimulation</qex> a concealment of what is.</q>
<rj><qau>Tatler.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissimulator</ent><br/
<hw>Dis*sim"u*la`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.]</ety>
<def>One who dissimulates; a dissembler.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissimule</ent><br/
<hw>Dis*sim"ule</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <ety>[F.
<ets>dissimuler</ets>. See <er>Dissimulate</er>.]</ety> <def>To
dissemble.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissimuler</ent><br/
<hw>Dis*sim"u*ler</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A
dissembler.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissimulour</ent><br/
<hw>Dis*sim"u*lour</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>dissimuleur</ets>.]</ety> <def>A dissembler.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissipable</ent><br/
<hw>Dis"si*pa*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>dissipabilis</ets>.]</ety> <def>Capable of being scattered or
dissipated.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The heat of those plants is very <qex>dissipable</qex>.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 433 --></p>

<p><ent>dissipate</ent><br/
<hw>dis"si*pate</hw> <pr>(d<icr/s"s<icr/*p<amac/t)</pr>, <pos>v.
t.</pos> <vmorph>[<pos>imp. & p. p.</pos> <conjf>Dissipated</conjf>;
<pos>p. pr. & vb. n.</pos> <conjf>Dissipating</conjf>.]</vmorph>
<ety>[L. <ets>dissipatus</ets>, p. p. of <ets>dissipare</ets>;
<ets>dis-</ets> + an obsolete verb <ets>sipare</ets>, <ets>supare</ets>.
to throw.]</ety> <sn>1.</sn> <def>To scatter completely; to disperse and
cause to disappear; -- used esp. of the dispersion of things that can
never again be collected or restored.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Dissipated</qex> those foggy mists of error.</q>
<rj><qau>Selden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I soon <qex>dissipated</qex> his fears.</q>
<rj><qau>Cook.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The extreme tendency of civilization is to <qex>dissipate</qex>
all intellectual energy.</q> <rj><qau>Hazlitt.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To destroy by wasteful extravagance or lavish use;
to squander.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The vast wealth . . . was in three years
<qex>dissipated</qex>.</q> <rj><qau>Bp. Burnet.</qau></rj></p>

<p><syn><b>Syn.</b> -- To disperse; scatter; dispel; spend; squander;
waste; consume; lavish.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissipate</ent><br/
<hw>Dis"si*pate</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To separate into
parts and disappear; to waste away; to scatter; to disperse; to vanish;
<as>as, a fog or cloud gradually <ex>dissipates</ex> before the rays or
heat of the sun; the heat of a body <ex>dissipates</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To be extravagant, wasteful, or dissolute in the
pursuit of pleasure; to engage in dissipation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissipated</ent><br/
<hw>Dis"si*pa`ted</hw> <pr>(d<icr/s"s<icr/*p<amac/`t<ecr/d)</pr>,
<pos>a.</pos> <sn>1.</sn> <def>Squandered; scattered.</def>
<ldquo/<xex>Dissipated</xex> wealth.<rdquo/
<rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Wasteful of health, money, etc., in the pursuit of
pleasure; dissolute; intemperate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A life irregular and <qex>dissipated</qex>.</q>
<rj><qau>Johnson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissipation</ent><br/
<hw>Dis`si*pa"tion</hw> <pr>(d<icr/s`s<icr/*p<amac/"sh<ucr/n)</pr>,
<pos>n.</pos> <ety>[L. <ets>dissipatio</ets>: cf. F.
<ets>dissipation</ets>.]</ety> <sn>1.</sn> <def>The act of dissipating
or dispersing; a state of dispersion or separation; dispersion;
waste.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Without loss or <qex>dissipation</qex> of the matter.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The famous <qex>dissipation</qex> of mankind.</q> <rj><qau>Sir M.
Hale.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A dissolute course of life, in which health, money,
etc., are squandered in pursuit of pleasure; profuseness in vicious
indulgence, as late hours, riotous living, etc.;
dissoluteness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To reclaim the spendthrift from his <qex>dissipation</qex> and
extravagance.</q> <rj><qau>P. Henry.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A trifle which wastes time or distracts
attention.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Prevented from finishing them [the letters] a thousand avocations
and <qex>dissipations</qex>.</q> <rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dissipation of energy</b></col>. <cd>Same as
<cref>Degradation of energy</cref>, under
<er>Degradation</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>dissipative</ent><br/
<hw>dis"si*pa*tive</hw> <pr>(d<icr/s"s<icr/*p<asl/*t<icr/v)</pr>,
<pos>a.</pos> <def>Tending to dissipate.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dissipative system</b></col> <fld>(Mech.)</fld>, <cd>an
assumed system of matter and motions in which forces of friction and
resistances of other kinds are introduced without regard to the heat or
other molecular actions which they generate; -- opposed to
<contr>conservative system</contr>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissipativity</ent><br/
<hw>Dis`si*pa*tiv"i*ty</hw>
<pr>(d<icr/s`s<icr/*p<adot/*t<icr/v"<icr/*t<ycr/)</pr>, <pos>n.</pos>
<def>The rate at which palpable energy is dissipated away into other
forms of energy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissite</ent><br/
<hw>Dis"site</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>dissitus</ets>.]</ety> <def>Lying apart.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Lands far <qex>dissite</qex> and remote asunder.</q>
<rj><qau>Holland.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disslander</ent><br/
<hw>Dis*slan"der</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>dis-</ets> (intens.) + <ets>slander</ets>.]</ety> <def>To
slander.</def> <mark>[Obs.]</mark> <rj><au>Legend of Dido.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disslander</ent><br/
<hw>Dis*slan"der</hw>, <pos>n.</pos> <def>Slander.</def>
<mark>[Obs.]</mark> <rj><au>E. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disslanderous</ent><br/
<hw>Dis*slan"der*ous</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Slanderous.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissociability</ent><br/
<hw>Dis*so`cia*bil"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Want of
sociability; unsociableness.</def> <rj><au>Bp. Warburton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissociable</ent><br/
<hw>Dis*so"cia*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>dissociabilis</ets>, fr. <ets>dissociare</ets>: cf. F.
<ets>dissociable</ets>. See <er>Dissociate</er>.]</ety> <sn>1.</sn>
<def>Not well associated or assorted; incongruous.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They came in two and two, though matched in the most
<qex>dissociable</qex> manner.</q> <rj><qau>Spectator.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Having a tendency to dissolve social connections;
unsuitable to society; unsociable.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissocial</ent><br/
<hw>Dis*so"cial</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>dis-</ets> + <ets>social</ets>: cf. L. <ets>dissocialis</ets>. See
<er>Dissociate</er>, <pos>v. t.</pos>]</ety> <def>Unfriendly to society;
contracted; selfish; <as>as, <ex>dissocial</ex> feelings</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissocialize</ent><br/
<hw>Dis*so"cial*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To render
unsocial.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>dissociate</ent><br/
<hw>dis*so"ci*ate</hw> <pr>(d<icr/s*s<omac/"sh<icr/*<amac/t)</pr>,
<pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Dissociated</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Dissociating</conjf>.]</vmorph> <ety>[L. <ets>dissociatus</ets>,
p. p. of <ets>dissociare</ets> to dissociate; <ets>dis-</ets> +
<ets>sociare</ets> to unite, associate, <ets>socius</ets> companion. See
<er>Social</er>.]</ety> <def>To separate from fellowship or union; to
disunite; to disjoin; <as>as, to <ex>dissociate</ex> the particles of a
concrete substance</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Before Wyclif's death in 1384, John of Gaunt had openly
<qex>dissociated</qex> himself from the reformer.</q> <rj><qau>A. W.
Ward.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>dissociated</ent><br/
<hw>dissociated</hw> <pos>adj.</pos> <sn>1.</sn> <def>not connected or
associated.</def><br/
<syn><b>Syn. --</b> unconnected.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <fld>(Chem.)</fld> <def>diffusing independently in a
fluid; -- said of ions or molecules which may form relatively stable
associated structures; <as>as, the products become rapidly
<ex>dissociated</ex> from the active site of the enzyme</as>. Opposite
of <ant>associated</ant>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Dissociation</ent><br/
<hw>Dis*so`ci*a"tion</hw> <pr>(?; 106)</pr>, <pos>n.</pos> <ety>[L.
<ets>dissociatio</ets>: cf. F. <ets>dissociation</ets>.]</ety>
<sn>1.</sn> <def>The act of dissociating or disuniting; a state of
separation; disunion.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It will add infinitely <qex>dissociation</qex>, distraction, and
confusion of these confederate republics.</q>
<rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Chem.)</fld> <def>The process by which a compound
body breaks up into simpler constituents; -- said particularly of the
action of heat on gaseous or volatile substances; <as>as, the
<ex>dissociation</ex> of the sulphur molecules; the
<ex>dissociation</ex> of ammonium chloride into hydrochloric acid and
ammonia.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissociative</ent><br/
<hw>Dis*so"ci*a*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Tending or
leading to dissociation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissolubility</ent><br/
<hw>Dis`so*lu*bil"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The quality
of being dissoluble; capacity of being dissoluble; capacity of being
dissolved by heat or moisture, and converted into a fluid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissoluble</ent><br/
<hw>Dis"so*lu*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>dissolubilis</ets>: cf. F. <ets>dissoluble</ets>. See
<er>Dissolve</er>, and cf. <er>Dissolvable</er>.]</ety> <sn>1.</sn>
<def>Capable of being dissolved; having its parts separable by heat or
moisture; convertible into a fluid.</def>
<rj><au>Woodward.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Capable of being disunited.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissolubleness</ent><br/
<hw>Dis"so*lu*ble*ness</hw>, <pos>n.</pos> <def>The quality of being
dissoluble; dissolubility.</def> <rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissolute</ent><br/
<hw>Dis"so*lute</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>dissolutus</ets>, p. p. of <ets>dissolvere</ets>: cf. F.
<ets>dissolu</ets>. See <er>Dissolve</er>.]</ety> <sn>1.</sn> <def>With
nerves unstrung; weak.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Loosed from restraint; recklessly abandoned to
sensual pleasures; esp., loose in morals and conduct; profligate;
wanton; lewd; debauched.</def> <ldquo/A wild and <xex>dissolute</xex>
soldier.<rdquo/ <rj><au>Motley.</au></rj></p>

<p><sn>3.</sn> <specif>Specifically:</specif> <def>Engaging in excessive
drinking, or promiscuous sexual activity.</def><br/
[<source>PJC</source>]</p>

<p><syn><b>Syn.</b> -- Uncurbed; unbridled; disorderly; unrestrained;
reckless; wild; wanton; vicious; lax; licentious; lewd; rakish;
debauched; profligate.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissolutely</ent><br/
<hw>Dis"so*lute*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a
dissolute manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissoluteness</ent><br/
<hw>Dis"so*lute*ness</hw>, <pos>n.</pos> <def>State or quality of being
dissolute; looseness of morals and manners; addictedness to sinful
pleasures; debauchery; dissipation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Chivalry had the vices of <qex>dissoluteness</qex>.</q>
<rj><qau>Bancroft.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissolution</ent><br/
<hw>Dis`so*lu"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>dissolucioun</ets> dissoluteness, F. <ets>dissolution</ets>, fr. L.
<ets>dissolutio</ets>, fr. <ets>dissolvere</ets>. See
<er>Dissolve</er>.]</ety> <sn>1.</sn> <def>The act of dissolving,
sundering, or separating into component parts; separation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Dissolutions</qex> of ancient amities.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Change from a solid to a fluid state; solution by
heat or moisture; liquefaction; melting.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Change of form by chemical agency; decomposition;
resolution.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>dissolution</qex> of the compound.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The dispersion of an assembly by terminating its
sessions; the breaking up of a partnership.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Dissolution</qex> is the civil death of Parliament.</q>
<rj><qau>Blackstone.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>The extinction of life in the human body; separation
of the soul from the body; death.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We expected<br/
Immediate <qex>dissolution</qex>.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>The state of being dissolved, or of undergoing
liquefaction.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A man of continual <qex>dissolution</qex> and thaw.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>The new product formed by dissolving a body; a
solution.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>Destruction of anything by the separation of its
parts; ruin.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To make a present <qex>dissolution</qex> of the world.</q>
<rj><qau>Hooker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>Corruption of morals; dissipation;
dissoluteness.</def> <mark>[Obs. or R.]</mark>
<rj><au>Atterbury.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissolvability</ent><br/
<hw>Dis*solv`a*bil"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Capacity
of being dissolved; solubility.</def> <rj><au>Richardson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissolvable</ent><br/
<hw>Dis*solv"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From
<er>Dissolve</er>, cf. <er>Dissoluble</er>.]</ety> <def>Capable of being
dissolved, or separated into component parts; capable of being
liquefied; soluble.</def> -- <wordforms><wf>Dis*solv"a*ble*ness</wf>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><q>Though everything which is compacted be in its own nature
<qex>dissolvable</qex>.</q> <rj><qau>Cudworth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Such things as are not <qex>dissolvable</qex> by the moisture of
the tongue.</q> <rj><qau>Sir I. Newton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissolvative</ent><br/
<hw>Dis*solv"a*tive</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Having the
power to dissolve anything; solvent.</def> <mark>[Obs.]</mark>
<rj><au>Frampton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissolve</ent><br/
<hw>Dis*solve"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Dissolved</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Dissolving</conjf>.]</vmorph> <ety>[L.
<ets>dissolvere</ets>, <ets>dissolutum</ets>; <ets>dis-</ets> +
<ets>solvere</ets> to loose, free. See <er>Solve</er>, and cf.
<er>Dissolute</er>.]</ety> <sn>1.</sn> <def>To separate into competent
parts; to disorganize; to break up; hence, to bring to an end by
separating the parts, sundering a relation, etc.; to terminate; to
destroy; to deprive of force; <as>as, to <ex>dissolve</ex> a
partnership; to <ex>dissolve</ex> Parliament.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Lest his ungoverned rage <qex>dissolve</qex> the life.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To break the continuity of; to disconnect; to
disunite; to sunder; to loosen; to undo; to separate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Nothing can <qex>dissolve</qex> us.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Down fell the duke, his joints <qex>dissolved</qex> asunder.</q>
<rj><qau>Fairfax.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>For one people to <qex>dissolve</qex> the political bands which
have connected them with another.</q> <rj><qau>The Declaration of
Independence.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To convert into a liquid by means of heat, moisture,
etc.,; to melt; to liquefy; to soften.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>As if the world were all <qex>dissolved</qex> to tears.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To solve; to clear up; to resolve.</def>
<ldquo/<xex>Dissolved</xex> the mystery.<rdquo/
<rj><au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Make interpretations and <qex>dissolve</qex> doubts.</q>
<rj><qau>Dan. v. 16.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To relax by pleasure; to make powerless.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Angels <qex>dissolved</qex> in hallelujahs lie.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Law)</fld> <def>To annul; to rescind; to discharge
or release; <as>as, to <ex>dissolve</ex> an injunction</as>.</def></p>

<p><syn><b>Syn.</b> -- See <er>Adjourn</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissolve</ent><br/
<hw>Dis*solve"</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To waste away; to
be dissipated; to be decomposed or broken up.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To become fluid; to be melted; to be
liquefied.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A figure<br/
Trenched in ice, which with an hour's heat<br/
<qex>Dissolves</qex> to water, and doth lose his form.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To fade away; to fall to nothing; to lose
power.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The charm <qex>dissolves</qex> apace.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>dissolved</ent><br/
<hw>dissolved</hw> <pos>adj.</pos> <sn>1.</sn> <def>changed from a solid
to a liquid state by increase of temperature; melted. Opposite of
<ant>unmelted</ant>.</def><br/
<syn><b>Syn. --</b> liquefied, liquified, melted.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>sundered by divorce, separation, or desertion; -- of
social bonds and relations.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>3.</sn> <def>diffused into a liquid of differing chemical
composition, forming a stable solution; -- said of chemical
substances.</def><br/
[<source>PJC</source>]</p>

<p><ent>dissolvent</ent><br/
<hw>dis*solv"ent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>dissolvens</ets>, <ets>-entis</ets>, p. pr. of
<ets>dissolvere</ets>.]</ety> <def>Having power to dissolve power to
dissolve a solid body; <as>as, the <ex>dissolvent</ex> juices of the
stomach</as>.</def> <rj><au>Ray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissolvent</ent><br/
<hw>Dis*solv"ent</hw>, <pos>n.</pos> <sn>1.</sn> <def>That which has the
power of dissolving or melting other substances, esp. by mixture with
them; a menstruum; a solvent.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Melted in the crucible <qex>dissolvents</qex>.</q> <rj><qau>A.
Smith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The secret treaty of December acted as an immediate
<qex>dissolvent</qex> to the truce.</q> <rj><qau>Mothley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Med.)</fld> <def>A remedy supposed capable of
dissolving concretions in the body, such as calculi, tubercles,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissolver</ent><br/
<hw>Dis*solv"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, has power to dissolve or dissipate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou kind <qex>dissolver</qex> of encroaching care.</q>
<rj><qau>Otway.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissolving</ent><br/
<hw>Dis*solv"ing</hw>, <pos>a.</pos> <def>Melting; breaking up;
vanishing.</def> -- <wordforms><wf>Dis*solv"ing*ly</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dissolving view</b></col>, <cd>a picture which grows dim
and is gradually replaced by another on the same field; -- an effect
produced by magic lanterns.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissonance</ent><br/
<hw>Dis"so*nance</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>dissonantia</ets>: cf. F. <ets>dissonance</ets>.]</ety> <sn>1.</sn>
<def>A mingling of discordant sounds; an inharmonious combination of
sounds; discord.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Filled the air with barbarous <qex>dissonance</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Want of agreement; incongruity.</def>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissonancy</ent><br/
<hw>Dis"so*nan*cy</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Discord;
dissonance.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissonant</ent><br/
<hw>Dis"so*nant</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>dissonans</ets>, <ets>-antis</ets>, p. pr. of <ets>dissonare</ets>
to disagree in sound, be discordant; <ets>dis-</ets> + <ets>sonare</ets>
to sound: cf. F. <ets>dissonant</ets>. See <er>Sonant</er>.]</ety>
<sn>1.</sn> <def>Sounding harshly; discordant; unharmonious.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With clamor of voices <qex>dissonant</qex> and loud.</q>
<rj><qau>Longfellow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Disagreeing; incongruous; discrepant, -- with
<xex>from</xex> or <xex>to</xex>.</def> <ldquo/Anything
<xex>dissonant</xex> to truth.<rdquo/ <rj><au>South.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>What can be <qex>dissonant</qex> from reason and nature than that
a man, naturally inclined to clemency, should show himself unkind and
inhuman?</q> <rj><qau>Hakewill.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disspirit</ent><br/
<hw>Dis*spir"it</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>See
<er>Dispirit</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissuade</ent><br/
<hw>Dis*suade"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Dissuaded</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Dissuading</conjf>.]</vmorph> <ety>[L. <ets>dissuadere</ets>,
<ets>dissuasum</ets>; <ets>dis-</ets> + <ets>suadere</ets> to advise,
persuade: cf. F. <ets>dissuader</ets>. See <er>Suasion</er>.]</ety>
<sn>1.</sn> <def>To advise or exhort against; to try to persuade (one
from a course).</def> <mark>[Obsolescent]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Mr. Burchell, on the contrary, <qex>dissuaded</qex> her with great
ardor: and I stood neuter.</q> <rj><qau>Goldsmith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>War, therefore, open or concealed, alike<br/
My voice <qex>dissuades</qex>.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To divert by persuasion; to turn from a purpose by
reasons or motives; -- with <xex>from</xex>; <as>as, I could not
<ex>dissuade</ex> him from his purpose</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I have tried what is possible to <qex>dissuade</qex> him.</q>
<rj><qau>Mad. D' Arblay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissuader</ent><br/
<hw>Dis*suad"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who dissuades;
a dehorter.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissuasion</ent><br/
<hw>Dis*sua"sion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>dissuasio</ets>: cf. F. <ets>dissuasion</ets>. See
<er>Dissuade</er>.]</ety> <sn>1.</sn> <def>The act of dissuading;
exhortation against a thing; dehortation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In spite of all the <qex>dissuasions</qex> of his friends.</q>
<rj><qau>Boyle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A motive or consideration tending to dissuade; a
dissuasive.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissuasive</ent><br/
<hw>Dis*sua"sive</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Tending to
dissuade or divert from a measure or purpose; dehortatory; <as>as,
<ex>dissuasive</ex> advice</as>.</def> -- <def2><pos>n.</pos> <def>A
dissuasive argument or counsel; dissuasion; dehortation.</def>
<au>Prynne.</au></def2> -- <wordforms><wf>Dis*sua"sive*ly</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissuasory</ent><br/
<hw>Dis*sua"so*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A
dissuasive.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>This virtuous and reasonable person, however, has ill luck in all
his <qex>dissuasories</qex>.</q> <rj><qau>Jeffrey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissunder</ent><br/
<hw>Dis*sun"der</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Dissundered</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Dissundering</conjf>.]</vmorph> <ety>[Pref.
<ets>dis-</ets> (intens) + <ets>sunder</ets>.]</ety> <def>To separate;
to sunder; to destroy.</def> <mark>[R.]</mark>
<rj><au>Chapman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissweeten</ent><br/
<hw>Dis*sweet"en</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To deprive of
sweetness.</def> <mark>[R.]</mark> <rj><au>Bp. Richardson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissyllabic</ent><br/
<hw>Dis`syl*lab"ic</hw> <pr>(d<icr/s`s<icr/l*l<acr/b"<icr/k)</pr>,
<pos>a.</pos> <ety>[Cf. F. <ets>dissyllabique</ets>. See
<er>Dissylable</er>.]</ety> <def>Consisting of two syllables only;
<as>as, a <ex>dissyllabic</ex> foot in poetry</as>.</def> <rj><au>B.
Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissyllabification</ent><br/
<hw>Dis`syl*lab`i*fi*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A
forming into two syllables.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissyllabify</ent><br/
<hw>Dis`syl*lab"i*fy</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<ety>[<ets>Dissyllable</ets> + <ets>-fly</ets>.]</ety> <def>To form into
two syllables.</def> <rj><au>Ogilvie.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissyllabize</ent><br/
<hw>Dis*syl"la*bize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To form
into two syllables; to dissyllabify.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissyllable</ent><br/
<hw>Dis*syl"la*ble</hw> <pr>(?; 277)</pr>, <pos>n.</pos> <ety>[F.
<ets>dissyllabe</ets>, L. <ets>disyllabus</ets>, adj., of two syllables,
fr. Gr. <?/; <grk>di-</grk> = <grk>di`s-</grk> twice + <?/ syllable. See
<er>Syllable</er>.]</ety> <def>A word of two syllables; as,
<xex>pa-per</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissymmetrical</ent><br/
<hw>Dis`sym*met"ric*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Not having
symmetry; asymmetrical; unsymmetrical.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissymmetry</ent><br/
<hw>Dis*sym"me*try</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>dis-</ets> + <ets>symmetry</ets>.]</ety> <def>Absence or defect of
symmetry; asymmetry.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dissympathy</ent><br/
<hw>Dis*sym"pa*thy</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Lack of
sympathy; want of interest; indifference.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distad</ent><br/
<hw>Dis"tad</hw> <pr>(?)</pr>, <pos>adv.</pos> <ety>[<ets>Dist</ets>al +
L. <ets>ad</ets> toward.]</ety> <fld>(Anat.)</fld> <def>Toward a distal
part; on the distal side of; distally.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distaff</ent><br/
<hw>Dis"taff</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Distaffs</plw> <pr>(#)</pr>, <xex>rarely</xex> <plw>Distaves</plw>
<pr>(#)</pr>.</plu> <ety>[OE. <ets>distaf</ets>, <ets>dysestafe</ets>,
AS. <ets>distaef</ets>; cf. LG. <ets>diesse</ets> the bunch of flax on a
distaff, and E. <ets>dizen</ets>. See <er>Staff</er>.]</ety> <sn>1.</sn>
<def>The staff for holding a bunch of flax, tow, or wool, from which the
thread is drawn in spinning by hand.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I will the <qex>distaff</qex> hold; come thou and spin.</q>
<rj><qau>Fairfax.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Used as a symbol of the holder of a distaff; hence,
a woman; women, collectively.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His crown usurped, a <qex>distaff</qex> on the throne.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Some say the crozier, some say the <qex>distaff</qex> was too
busy.</q> <rj><qau>Howell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The plural is regular, but <xex>Distaves</xex> occurs in
Beaumont & Fletcher.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Descent by distaff</b></col>, <cd>descent on the mother's
side.</cd> -- <mcol><col><b>Distaff Day</b></col>, <it>or</it>
<col><b>Distaff's Day</b></col></mcol>, <cd>the morrow of the Epiphany,
that is, January 7, because working at the distaff was then resumed,
after the Christmas festival; -- called also <altname>Rock
Day</altname>, a distaff being called a <xex>rock</xex>.</cd>
<rj><au>Shipley.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distain</ent><br/
<hw>Dis*tain"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Distained</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Distaining</conjf>.]</vmorph> <ety>[OE.
<ets>desteinen</ets>, OF. <ets>desteindre</ets> to take away the color,
F. <ets>d<eacute/teindre</ets>; pref. <ets>des-</ets> (L.
<ets>dis-</ets>) + F. <ets>teindre</ets> to tinge, dye, L.
<ets>tingere</ets>. See <er>Tinge</er>, and cf. <er>Stain</er>.]</ety>
<def>To tinge with a different color from the natural or proper one; to
stain; to discolor; to sully; to tarnish; to defile; -- used chiefly in
poetry.</def> <ldquo/<xex>Distained</xex> with dirt and blood.<rdquo/
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>[She] hath . . . <qex>distained</qex> her honorable blood.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The worthiness of praise <qex>distains</qex> his worth.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distal</ent><br/
<hw>Dis"tal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From
<er>Distant</er>.]</ety> <fld>(Physiol.)</fld> <sd>(a)</sd> <def>Remote
from the point of attachment or origin; <as>as, the <ex>distal</ex> end
of a bone or muscle</as></def>; -- opposed to <ant>proximal</ant>.
<sd>(b)</sd> <def>Pertaining to that which is distal; <as>as, the
<ex>distal</ex> tuberosities of a bone</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distally</ent><br/
<hw>Dis"tal*ly</hw>, <pos>adv.</pos> <fld>(Anat.)</fld> <def>Toward a
distal part.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distance</ent><br/
<hw>Dis"tance</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>distance</ets>, L. <ets>distantia</ets>.]</ety> <sn>1.</sn>
<def>The space between two objects; the length of a line, especially the
shortest line joining two points or things that are separate; measure of
separation in place.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Every particle attracts every other with a force . . . inversely
proportioned to the square of the <qex>distance</qex>.</q> <rj><qau>Sir
I. Newton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Remoteness of place; a remote place.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Easily managed from a <qex>distance</qex>.</q> <rj><qau>W.
Irving.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>'T is <qex>distance</qex> lends enchantment to the view.</q>
<rj><qau>T. Campbell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>[He] waits at <qex>distance</qex> till he hears from Cato.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 434 --></p>

<p><sn>3.</sn> <fld>(Racing)</fld> <def>A space marked out in the last
part of a race course.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The horse that ran the whole field out of <qex>distance</qex>.</q>
<rj><qau>L'Estrange.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In trotting matches under the rules of the American
Association, the <xex>distance</xex> varies with the conditions of the
race, being 80 yards in races of mile heats, best two in three, and 150
yards in races of two-mile heats. At that distance from the winning post
is placed the <xex>distance post</xex>. If any horse has not reached
this distance post before the first horse in that heat has reached the
winning post, such horse is <xex>distanced</xex>, and disqualified for
running again during that race.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Mil.)</fld> <def>Relative space, between troops in
ranks, measured from front to rear; -- contrasted with
<contr>interval</contr>, which is measured from right to left.</def>
<ldquo/<xex>Distance</xex> between companies in close column is twelve
yards.<rdquo/ <rj><au>Farrow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Space between two antagonists in fencing.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Painting)</fld> <def>The part of a picture which
contains the representation of those objects which are the farthest
away, esp. in a landscape.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In a picture, the <col><b>Middle distance</b></col> is
the central portion between the <xex>foreground</xex> and the
<xex>distance</xex> or the <xex>extreme distance</xex>. In a perspective
drawing, the <col><b>Point of distance</b></col> is the point where the
visual rays meet.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>Ideal disjunction; discrepancy; contrariety.</def>
<rj><au>Locke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>Length or interval of time; period, past or future,
between two eras or events.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Ten years' <qex>distance</qex> between one and the other.</q>
<rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The writings of Euclid at the <qex>distance</qex> of two thousand
years.</q> <rj><qau>Playfair.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>The remoteness or reserve which respect requires;
hence, respect; ceremoniousness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I hope your modesty<br/
Will know what <qex>distance</qex> to the crown is due.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>'T is by respect and <qex>distance</qex> that authority is
upheld.</q> <rj><qau>Atterbury.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <def>A withholding of intimacy; alienation; coldness;
disagreement; variance; restraint; reserve.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Setting them [factions] at <qex>distance</qex>, or at least
distrust amongst themselves.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>On the part of Heaven,<br/
Now alienated, <qex>distance</qex> and distaste.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>11.</sn> <def>Remoteness in succession or relation; <as>as, the
<ex>distance</ex> between a descendant and his ancestor</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>12.</sn> <fld>(Mus.)</fld> <def>The interval between two notes;
<as>as, the <ex>distance</ex> of a fourth or seventh</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Angular distance</b></col>, <cd>the distance made at the
eye by lines drawn from the eye to two objects.</cd> -- <col><b>Lunar
distance</b></col>. <cd>See under <er>Lunar</er>.</cd> -- <col><b>North
polar distance</b></col> <fld>(Astron.)</fld>, <cd>the distance on the
heavens of a heavenly body from the north pole. It is the complement of
the declination.</cd> -- <col><b>Zenith distance</b></col>
<fld>(Astron.)</fld>, <cd>the arc on the heavens from a heavenly body to
the zenith of the observer. It is the complement of the altitude.</cd>
-- <col><b>To keep one's distance</b></col>, <cd>to stand aloof; to
refrain from familiarity.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><q>If a man makes me <qex>keep my distance</qex>, the comfort is he
keeps his at the same time.</q> <rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distance</ent><br/
<hw>Dis"tance</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Distanced</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Distancing</conjf> <pr>(?)</pr>.]</vmorph> <sn>1.</sn>
<def>To place at a distance or remotely.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I heard nothing thereof at Oxford, being then miles
<qex>distanced</qex> thence.</q> <rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To cause to appear as if at a distance; to make seem
remote.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His peculiar art of <qex>distancing</qex> an object to aggrandize
his space.</q> <rj><qau>H. Miller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To outstrip by as much as a distance (see
<er>Distance</er>, <pos>n.</pos>, 3); to leave far behind; to surpass
greatly.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He <qex>distanced</qex> the most skillful of his
contemporaries.</q> <rj><qau>Milner.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distancy</ent><br/
<hw>Dis"tan*cy</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Distance.</def>
<mark>[Obs.]</mark> <rj><au>Dr. H. More.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distant</ent><br/
<hw>Dis"tant</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F., fr. L.
<ets>distans</ets>, <ets>-antis</ets>, p. pr. of <ets>distare</ets> to
stand apart, be separate or distant; <ets>dis-</ets> + <ets>stare</ets>
to stand. See <er>Stand</er>.]</ety> <sn>1.</sn> <def>Separated; having
an intervening space; at a distance; away.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>One board had two tenons, equally <qex>distant</qex>.</q>
<rj><qau>Ex. xxxvi. 22.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Diana's temple is not <qex>distant</qex> far.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Far separated; far off; not near; remote; -- in
place, time, consanguinity, or connection; <as>as, <ex>distant</ex>
times; <ex>distant</ex> relatives.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>The success of these <qex>distant</qex> enterprises.</q>
<rj><qau>Prescott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Reserved or repelling in manners; cold; not cordial;
somewhat haughty; <as>as, a <ex>distant</ex> manner</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He passed me with a <qex>distant</qex> bow.</q>
<rj><qau>Goldsmith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Indistinct; faint; obscure, as from
distance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Some <qex>distant</qex> knowledge.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>distant</qex> glimpse.</q> <rj><qau>W.
Irving.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Not conformable; discrepant; repugnant; <as>as, a
practice so widely <ex>distant</ex> from Christianity</as>.</def></p>

<p><syn><b>Syn.</b> -- Separate; far; remote; aloof; apart; asunder;
slight; faint; indirect; indistinct.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distantial</ent><br/
<hw>Dis*tan"tial</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Distant.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>More <qex>distantial</qex> from the eye.</q> <rj><qau>W.
Montagu.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distantly</ent><br/
<hw>Dis"tant*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>At a distance;
remotely; with reserve.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distaste</ent><br/
<hw>Dis*taste"</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>Aversion of the taste; dislike, as of food or drink;
disrelish.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Discomfort; uneasiness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Prosperity is not without many fears and <qex>distastes</qex>, and
adversity is not without comforts and hopes.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Alienation of affection; displeasure;
anger.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>On the part of Heaven,<br/
Now alienated, distance and <qex>distaste</qex>.</q>
<rj><qau>Milton.</qau></rj></p>

<p><syn><b>Syn.</b> -- Disrelish; disinclination; dislike; aversion;
displeasure; dissatisfaction; disgust.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distaste</ent><br/
<hw>Dis*taste"</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Distasted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Distasting</conjf>.]</vmorph> <sn>1.</sn> <def>Not to have relish
or taste for; to disrelish; to loathe; to dislike.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Although my will <qex>distaste</qex> what it elected.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To offend; to disgust; to displease.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He thought in no policy to <qex>distaste</qex> the English or
Irish by a course of reformation, but sought to please them.</q>
<rj><qau>Sir J. Davies.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To deprive of taste or relish; to make unsavory or
distasteful.</def> <rj><au>Drayton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distaste</ent><br/
<hw>Dis*taste"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To be
distasteful; to taste ill or disagreeable.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Dangerous conceits are, in their natures, poisons,<br/
Which at the are scarce found to <qex>distaste</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distasteful</ent><br/
<hw>Dis*taste"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Unpleasant or disgusting to the taste; nauseous;
loathsome.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Offensive; displeasing to the feelings;
disagreeable; <as>as, a <ex>distasteful</ex> truth</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Distasteful</qex> answer, and sometimes unfriendly
actions.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Manifesting distaste or dislike; repulsive.</def>
<ldquo/<xex>Distasteful</xex> looks.<rdquo/ <rj><au>Shak.</au></rj></p>

<p><syn><b>Syn.</b> -- Nauseous; unsavory; unpalatable; offensive;
displeasing; dissatisfactory; disgusting.</syn></p>

<p>- <wordforms><wf>Dis*taste"ful*ly</wf>, <pos>adv.</pos> --
<wf>Dis*taste"ful*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distasteive</ent><br/
<hw>Dis*taste"ive</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Tending to
excite distaste.</def> <mark>[Obs.]</mark> -- <def2><pos>n.</pos>
<def>That which excites distaste or aversion.</def></def2>
<mark>[Obs.]</mark> <rj><au>Whitlock.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distasture</ent><br/
<hw>Dis*tas"ture</hw> <pr>(?; 135)</pr>, <pos>n.</pos> <def>Something
which excites distaste or disgust.</def> <mark>[Obs.]</mark>
<rj><au>Speed.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distemper</ent><br/
<hw>Dis*tem"per</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Distempered</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Distempering</conjf>.]</vmorph> <ety>[OF.
<ets>destemprer</ets>, <ets>destremper</ets>, to distemper, F.
<ets>d<eacute/tremper</ets> to soak, soften, slake (lime); pref.
<ets>des-</ets> (L. <ets>dis-</ets>) + OF. <ets>temprer</ets>,
<ets>tremper</ets>, F. <ets>tremper</ets>, L. <ets>temperare</ets> to
mingle in due proportion. See <er>Temper</er>, and cf.
<er>Destemprer</er>.]</ety> <sn>1.</sn> <def>To temper or mix unduly; to
make disproportionate; to change the due proportions of.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>When . . . the humors in his body ben <qex>distempered</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To derange the functions of, whether bodily, mental,
or spiritual; to disorder; to disease.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The imagination, when completely <qex>distempered</qex>, is the
most incurable of all disordered faculties.</q>
<rj><qau>Buckminster.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To deprive of temper or moderation; to disturb; to
ruffle; to make disaffected, ill-humored, or malignant.</def>
<ldquo/<xex>Distempered</xex> spirits.<rdquo/
<rj><au>Coleridge.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To intoxicate.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The courtiers reeling,<br/
And the duke himself, I dare not say <qex>distempered</qex>,<br/
But kind, and in his tottering chair carousing.</q>
<rj><qau>Massinger.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Paint.)</fld> <def>To mix (colors) in the way of
distemper; <as>as, to <ex>distemper</ex> colors with size</as>.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distemper</ent><br/
<hw>Dis*tem"per</hw>, <pos>n.</pos> <ety>[See <er>Distemper</er>,
<pos>v. t.</pos>, and cf. <er>Destemprer</er>.]</ety> <sn>1.</sn>
<def>An undue or unnatural temper, or disproportionate mixture of
parts.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ This meaning and most of the following are to be
referred to the Galenical doctrine of the four <ldquo/humors<rdquo/ in
man. See <er>Humor</er>. According to the old physicians, these humors,
when unduly tempered, produce a disordered state of body and
mind.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Severity of climate; extreme weather, whether hot or
cold.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Those countries . . . under the tropic, were of a
<qex>distemper</qex> uninhabitable.</q> <rj><qau>Sir W.
Raleigh.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A morbid state of the animal system; indisposition;
malady; disorder; -- at present chiefly applied to diseases of brutes;
<as>as, a <ex>distemper</ex> in dogs; the horse <ex>distemper</ex>; the
horn <ex>distemper</ex> in cattle.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>They heighten <qex>distempers</qex> to diseases.</q>
<rj><qau>Suckling.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Morbid temper of the mind; undue predominance of a
passion or appetite; mental derangement; bad temper; ill humor.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Little faults proceeding on <qex>distemper</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Some frenzy <qex>distemper</qex> had got into his head.</q>
<rj><qau>Bunyan.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Political disorder; tumult.</def>
<rj><au>Waller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Paint.)</fld> <sd>(a)</sd> <def>A preparation of
opaque or body colors, in which the pigments are tempered or diluted
with weak glue or size (cf. <er>Tempera</er>) instead of oil, usually
for scene painting, or for walls and ceilings of rooms.</def>
<sd>(b)</sd> <def>A painting done with this preparation.</def></p>

<p><syn><b>Syn.</b> -- Disease; disorder; sickness; illness; malady;
indisposition; ailment. See <er>Disease</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distemperance</ent><br/
<hw>Dis*tem"per*ance</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Distemperature.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distemperate</ent><br/
<hw>Dis*tem"per*ate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[LL.
<ets>distemperatus</ets>, p. p.]</ety> <sn>1.</sn>
<def>Immoderate.</def> <mark>[Obs.]</mark> <rj><au>Sir W.
Raleigh.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Diseased; disordered.</def> <mark>[Obs.]</mark>
<rj><au>Wodroephe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distemperately</ent><br/
<hw>Dis*tem"per*ate*ly</hw>, <pos>adv.</pos> <def>Unduly.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distemperature</ent><br/
<hw>Dis*tem"per*a*ture</hw> <pr>(?; 135)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>Bad temperature; intemperateness; excess of heat or cold, or of
other qualities; <as>as, the <ex>distemperature</ex> of the
air</as>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Disorder; confusion.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Disorder of body; slight illness;
distemper.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A huge infectious troop<br/
Of pale <qex>distemperatures</qex> and foes to life.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Perturbation of mind; mental uneasiness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Sprinkled a little patience on the heat of his
<qex>distemperature</qex>.</q> <rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distemperment</ent><br/
<hw>Dis*tem"per*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Distempered
state; distemperature.</def> <mark>[Obs.]</mark>
<rj><au>Feltham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distend</ent><br/
<hw>Dis*tend"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Distended</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Distending</conjf>.]</vmorph> <ety>[L. <ets>distendere</ets>,
<ets>distentum</ets>, <ets>distensum</ets>; <ets>dis-</ets> +
<ets>tendere</ets> to stretch, stretch out: cf. F. <ets>distendre</ets>
to distend, <ets>d<eacute/tendre</ets> to unbend. See <er>Tend</er>, and
cf. <er>Detent</er>.]</ety> <sn>1.</sn> <def>To extend in some one
direction; to lengthen out; to stretch.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>But say, what mean those colored streaks in heaven<br/
<qex>Distended</qex> as the brow of God appeased?</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To stretch out or extend in all directions; to
dilate; to enlarge, as by elasticity of parts; to inflate so as to
produce tension; to cause to swell; <as>as, to <ex>distend</ex> a
bladder, the stomach, etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>The warmth <qex>distends</qex> the chinks.</q>
<rj><qau>Dryden.</qau></rj></p>

<p><syn><b>Syn.</b> -- To dilate; expand; enlarge; swell;
inflate.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distend</ent><br/
<hw>Dis*tend"</hw>, <pos>v. i.</pos> <def>To become expanded or
inflated; to swell.</def> <ldquo/His heart <xex>distends</xex> with
pride.<rdquo/ <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distensibility</ent><br/
<hw>Dis*ten`si*bil"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The
quality or capacity of being distensible.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distensible</ent><br/
<hw>Dis*ten"si*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of
being distended or dilated.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distension</ent><br/
<hw>Dis*ten"sion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Distention</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distensive</ent><br/
<hw>Dis*ten"sive</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Distending, or
capable of being distended.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distent</ent><br/
<hw>Dis*tent"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>distentus</ets>, p. p. See <er>Distend</er>.]</ety>
<def>Distended.</def> <mark>[Poetic]</mark>
<rj><au>Thomson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distent</ent><br/
<hw>Dis*tent"</hw>, <pos>n.</pos> <def>Breadth.</def>
<mark>[Obs.]</mark> <rj><au>Sir H. Wotton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distention</ent><br/
<hw>Dis*ten"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>distentio</ets>: cf. F. <ets>distension</ets>.]</ety> <sn>1.</sn>
<def>The act of distending; the act of stretching in breadth or in all
directions; the state of being Distended; <as>as, the
<ex>distention</ex> of the lungs</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Breadth; extent or space occupied by the thing
distended.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dister</ent><br/
<hw>Dis*ter"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>dis-</ets> + <ets>terra</ets> earth, country; cf. Sp. & Pg.
<ets>desterrar</ets>.]</ety> <def>To banish or drive from a
country.</def> <mark>[Obs.]</mark> <rj><au>Howell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disterminate</ent><br/
<hw>Dis*ter"mi*nate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>disterminatus</ets>, p. p. of <ets>disterminare</ets> to limit. See
<er>Terminate</er>.]</ety> <def>Separated by bounds.</def>
<mark>[Obs.]</mark> <rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distermination</ent><br/
<hw>Dis*ter`mi*na"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>disterminatio</ets>.]</ety> <def>Separation by bounds.</def>
<mark>[Obs.]</mark> <rj><au>Hammond.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disthene</ent><br/
<hw>Dis"thene</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <grk>di-</grk>
= <grk>di`s-</grk> twice + <?/ force: cf. F.
<ets>disth<egrave/ne</ets>.]</ety> <fld>(Min.)</fld> <def>Cyanite or
kyanite; -- so called in allusion to its unequal hardness in two
different directions. See <er>Cyanite</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disthrone</ent><br/
<hw>Dis*throne"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>dis-</ets> + <ets>throne</ets>: cf. OF. <ets>desthroner</ets>, F.
<ets>d<eacute/troner</ets>.]</ety> <def>To dethrone.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disthronize</ent><br/
<hw>Dis*thron"ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To
dethrone.</def> <mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distich</ent><br/
<hw>Dis"tich</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>distichon</ets>, Gr. <?/, neut. of <?/ with two rows, of two
verses; <grk>di-</grk> = <grk>di`s-</grk> twice + <?/ row, verse, fr.
<?/ to ascend; akin to AS. <ets>st<imac/gan</ets> to ascend: cf. F.
<ets>distique</ets>. See <er>Stirrup</er>.]</ety> <fld>(Pros.)</fld>
<def>A couple of verses or poetic lines making complete sense; an
epigram of two verses.</def></p>

<p><ent>Distichous</ent><br/
<ent>Distich</ent><br/
<mhw>{ <hw>Dis"tich</hw> <pr>(?)</pr>, <hw>Dis"tich*ous</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[Gr. <?/. See <er>Distich</er>,
<pos>n.</pos>]</ety> <def>Disposed in two vertical rows;
two-ranked.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distichously</ent><br/
<hw>Dis"tich*ous*ly</hw>, <pos>adv.</pos> <def>In a distichous
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distil</ent><br/
<hw>Dis*til"</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <def>See
<er>Distill</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distill</ent><br/
<hw>Dis*till"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Distilled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Distilling</conjf>.]</vmorph> <ety>[F.
<ets>distiller</ets>, from L. <ets>destillare</ets>,
<ets>destillatum</ets>; <ets>de</ets> + <ets>stillare</ets> to drop,
<ets>stilla</ets> a drop, prob. fr. <ets>stiria</ets> frozen drop,
icicle; prob. akin to <ets>stare</ets>, E. <ets>stand</ets>. Cf.
<er>Still</er>, <pos>n. & v.</pos>, <er>Instill</er>.]</ety>
<altsp>[Written also <asp>distil</asp>.]</altsp> <sn>1.</sn> <def>To
drop; to fall in drops; to trickle.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Soft showers <qex>distilled</qex>, and suns grew warm in vain.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To flow gently, or in a small stream.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The Euphrates <qex>distilleth</qex> out of the mountains of
Armenia.</q> <rj><qau>Sir W. Raleigh.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To practice the art of distillation.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distill</ent><br/
<hw>Dis*till"</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To let fall or
send down in drops.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Or o'er the glebe <qex>distill</qex> the kindly rain.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The dew which on the tender grass<br/
The evening had <qex>distilled</qex>.</q>
<rj><qau>Drayton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To obtain by distillation; to subject to a process
of evaporation and subsequent condensation; to extract by distillation,
as spirits, essential oil, etc.; to rectify; <as>as, to <ex>distill</ex>
brandy from wine; to <ex>distill</ex> alcoholic spirits from grain; to
<ex>distill</ex> essential oils from flowers, etc.; to <ex>distill</ex>
fresh water from sea water.</as></def> <ldquo/<xex>Distilling</xex>
odors on me.<rdquo/ <rj><au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To subject to distillation; <as>as, to
<ex>distill</ex> molasses in making rum; to <ex>distill</ex> barley,
rye, corn, etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To dissolve or melt.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Swords by the lightning's subtle force <qex>distilled</qex>.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>to extract out and present the essence of; to
shorten and refine; to present the essential elements of; -- of ideas or
texts.</def><br/
[<source>PJC</source>]</p>

<p><ent>Distillable</ent><br/
<hw>Dis*till"a*ble</hw> <pr>(d<icr/s*t<icr/l"<adot/*b'l)</pr>,
<pos>a.</pos> <fld>(Chem.)</fld> <def>Capable of being distilled;
especially, capable of being distilled without chemical change or
decomposition; <as>as, alcohol is <ex>distillable</ex>; olive oil is not
<ex>distillable</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distillate</ent><br/
<hw>Dis"till*ate</hw> <pr>(d<icr/s"t<icr/l*<asl/t <it>or</it>
d<icr/s*t<icr/l"<asl/t)</pr>, <pos>n.</pos> <fld>(Chem.)</fld> <def>The
product of distillation; <as>as, the <ex>distillate</ex> from
molasses</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distillation</ent><br/
<hw>Dis`til*la"tion</hw> <pr>(d<icr/s`t<icr/l*l<amac/"sh<ucr/n)</pr>,
<pos>n.</pos> <ety>[F. <ets>distillation</ets>, L.
<ets>destillatio</ets>.]</ety> <sn>1.</sn> <def>The act of falling in
drops, or the act of pouring out in drops.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which falls in drops.</def> <mark>[R.]</mark>
<rj><au>Johnson</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Chem.)</fld> <def>The separation of the volatile
parts of a substance from the more fixed; specifically, the operation of
driving off gas or vapor from volatile liquids or solids, by heat in a
retort or still, and the condensation of the products as far as possible
by a cool receiver, alembic, or condenser; rectification; vaporization;
condensation; <as>as, the <ex>distillation</ex> of illuminating gas and
coal, of alcohol from sour mash, or of boric acid in
steam</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The evaporation of water, its condensation into clouds,
and its precipitation as rain, dew, frost, snow, or hail, is an
illustration of natural <xex>distillation</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The substance extracted by distilling.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Destructive distillation</b></col> <fld>(Chem.)</fld>,
<cd>the distillation, especially of complex solid substances, so that
the ultimate constituents are separated or evolved in new compounds, --
usually requiring a high degree of heat; <as>as, the <ex>destructive
distillation</ex> of soft coal or of wood</as>.</cd> -- <col><b>Dry
distillation</b></col>, <cd>the distillation of substances by
themselves, or without the addition of water or of other volatile
solvent; <as>as, the <ex>dry distillation</ex> of citric acid</as>.</cd>
-- <col><b>Fractional distillation</b></col>. <fld>(Chem.)</fld> <cd>See
under <er>Fractional</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distillatory</ent><br/
<hw>Dis*til"la*to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>distillatoire</ets>.]</ety> <def>Belonging to, or used in,
distilling; <as>as, <ex>distillatory</ex> vessels</as>.</def> --
<def2><pos>n.</pos> <def>A distillatory apparatus; a
still.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distiller</ent><br/
<hw>Dis*till"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One
who distills; esp., one who extracts alcoholic liquors by
distillation.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The condenser of a distilling apparatus.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distillery</ent><br/
<hw>Dis*till"er*y</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Distilleries</plw> <pr>(#)</pr>.</plu> <ety>[F.
<ets>distillerie</ets>.]</ety> <sn>1.</sn> <def>The building and works
where distilling, esp. of alcoholic liquors, is carried on.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The act of distilling spirits.</def>
<mark>[R.]</mark> <rj><au>Todd.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distillment</ent><br/
<hw>Dis*till"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Distillation;
the substance obtained by distillation.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distinct</ent><br/
<hw>Dis*tinct"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>distinctus</ets>, p. p. of <ets>distinguere</ets>: cf. F.
<ets>distinct</ets>. See <er>Distinguish</er>.]</ety> <sn>1.</sn>
<def>Distinguished; having the difference marked; separated by a visible
sign; marked out; specified.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Wherever thus created -- for no place<br/
Is yet <qex>distinct</qex> by name.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Marked; variegated.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The which [place] was dight<br/
With divers flowers <qex>distinct</qex> with rare delight.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 435 --></p>

<p><sn>3.</sn> <def>Separate in place; not conjunct; not united by
growth or otherwise; -- with <xex>from</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The intention was that the two armies which marched out together
should afterward be <qex>distinct</qex>.</q>
<rj><qau>Clarendon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Not identical; different; individual.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To offend, and judge, are <qex>distinct</qex> offices.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>So separated as not to be confounded with any other
thing; not liable to be misunderstood; not confused; well-defined;
clear; <as>as, we have a <ex>distinct</ex> or indistinct view of a
prospect</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Relation more particular and <qex>distinct</qex>.</q>
<rj><qau>Milton.</qau></rj></p>

<p><syn><b>Syn.</b> -- Separate; unconnected; disjoined; different;
clear; plain; conspicuous; obvious.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distinct</ent><br/
<hw>Dis*tinct"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To
distinguish.</def> <mark>[Obs.]</mark> <rj><au>Rom. of R.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distinction</ent><br/
<hw>Dis*tinc"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>distinctio</ets>: cf. F. <ets>distinction</ets>.]</ety> <sn>1.</sn>
<def>A marking off by visible signs; separation into parts;
division.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>distinction</qex> of tragedy into acts was not known.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The act of distinguishing or denoting the
differences between objects, or the qualities by which one is known from
others; exercise of discernment; discrimination.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To take away therefore that error, which confusion breedeth,
<qex>distinction</qex> is requisite.</q> <rj><qau>Hooker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which distinguishes one thing from another;
distinguishing quality; sharply defined difference; <as>as, the
<ex>distinction</ex> between real and apparent good</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>distinction</qex> betwixt the animal kingdom and the
inferior parts of matter.</q> <rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Estimation of difference; regard to differences or
distinguishing circumstance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Maids, women, wives, without <qex>distinction</qex>, fall.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Conspicuous station; eminence; superiority;
honorable estimation; <as>as, a man of
<ex>distinction</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Your country's own means of <qex>distinction</qex> and
defense.</q> <rj><qau>D. Webster.</qau></rj></p>

<p><syn><b>Syn.</b> -- Difference; variation, variety; contrast;
diversity; contrariety; disagreement; discrimination; preference;
superiority; rank; note; eminence.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distinctive</ent><br/
<hw>Dis*tinc"tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>distinctif</ets>.]</ety> <sn>1.</sn> <def>Marking or expressing
distinction or difference; distinguishing; characteristic;
peculiar.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>distinctive</qex> character and institutions of New
England.</q> <rj><qau>Bancroft.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Having the power to distinguish and discern;
discriminating.</def> <mark>[Obs.]</mark> <rj><au>Sir T.
Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distinctively</ent><br/
<hw>Dis*tinc"tive*ly</hw>, <pos>adv.</pos> <def>With distinction;
plainly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distinctiveness</ent><br/
<hw>Dis*tinc"tive*ness</hw>, <pos>n.</pos> <def>State of being
distinctive.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distinctly</ent><br/
<hw>Dis*tinct"ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <sn>1.</sn>
<def>With distinctness; not confusedly; without the blending of one part
or thing another; clearly; plainly; <as>as, to see
<ex>distinctly</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>With meaning; significantly.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou dost snore <qex>distinctly</qex>;<br/
There's meaning in thy snores.</q> <rj><qau>Shak.</qau></rj></p>

<p><syn><b>Syn.</b> -- Separately; clearly; plainly;
obviously.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distinctness</ent><br/
<hw>Dis*tinct"ness</hw>, <pos>n.</pos> <sn>1.</sn> <def>The quality or
state of being distinct; a separation or difference that prevents
confusion of parts or things.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The soul's . . . <qex>distinctness</qex> from the body.</q>
<rj><qau>Cudworth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Nice discrimination; hence, clearness; precision;
<as>as, he stated his arguments with great
<ex>distinctness</ex></as>.</def></p>

<p><syn><b>Syn.</b> -- Plainness; clearness; precision;
perspicuity.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distincture</ent><br/
<hw>Dis*tinc"ture</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Distinctness.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distinguish</ent><br/
<hw>Dis*tin"guish</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Distinguished</conjf> <pr>(?)</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>Distinguishing</conjf>.]</vmorph> <ety>[F.
<ets>distinguer</ets>, L. <ets>distinguere</ets>, <ets>distinctum</ets>;
<ets>di-</ets> = <ets>dis-</ets> + <ets>stinguere</ets> to quench,
extinguish; prob. orig., to prick, and so akin to G. <ets>stechen</ets>,
E. <ets>stick</ets>, and perh. <ets>sting</ets>. Cf.
<er>Extinguish</er>.]</ety> <sn>1.</sn> <def>Not set apart from others
by visible marks; to make distinctive or discernible by exhibiting
differences; to mark off by some characteristic.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Not more <qex>distinguished</qex> by her purple vest,<br/
Than by the charming features of her face.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Milton has <qex>distinguished</qex> the sweetbrier and the
eglantine.</q> <rj><qau>Nares.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To separate by definition of terms or logical
division of a subject with regard to difference; <as>as, to
<ex>distinguish</ex> sounds into high and low</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Moses <qex>distinguished</qex> the causes of the flood into those
that belong to the heavens, and those that belong to the earth.</q>
<rj><qau>T. Burnet.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To recognize or discern by marks, signs, or
characteristic quality or qualities; to know and discriminate (anything)
from other things with which it might be confounded; <as>as, to
<ex>distinguish</ex> the sound of a drum</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We are enabled to <qex>distinguish</qex> good from evil, as well
as truth from falsehood.</q> <rj><qau>Watts.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Nor more can you <qex>distinguish</qex> of a man,<br/
Than of his outward show.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To constitute a difference; to make to
differ.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Who <qex>distinguisheth</qex> thee?</q> <rj><qau>1 Cor. iv. 7.
(Douay version).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To separate from others by a mark of honor; to make
eminent or known; to confer distinction upon; -- with <xex>by</xex> or
<xex>for</xex>.</def><ldquo/To <xex>distinguish</xex> themselves by
means never tried before.<rdquo/ <rj><au>Johnson.</au></rj></p>

<p><syn><b>Syn.</b> -- To mark; discriminate; differentiate;
characterize; discern; perceive; signalize; honor; glorify.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distinguish</ent><br/
<hw>Dis*tin"guish</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To make
distinctions; to perceive the difference; to exercise discrimination; --
with <xex>between</xex>; <as>as, a judge <ex>distinguishes</ex> between
cases apparently similar, but differing in principle</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To become distinguished or distinctive; to make
one's self or itself discernible.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The little embryo . . . first <qex>distinguishes</qex> into a
little knot.</q> <rj><qau>Jer. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distinguishable</ent><br/
<hw>Dis*tin"guish*a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Capable of being distinguished; separable; divisible; discernible;
capable of recognition; <as>as, a tree at a distance is
<ex>distinguishable</ex> from a shrub</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A simple idea being in itself uncompounded . . . is not
<qex>distinguishable</qex> into different ideas.</q>
<rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Worthy of note or special regard.</def>
<rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distinguishableness</ent><br/
<hw>Dis*tin"guish*a*ble*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The
quality of being distinguishable.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distinguishably</ent><br/
<hw>Dis*tin"guish*a*bly</hw>, <pos>adv.</pos> <def>So as to be
distinguished.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distinguished</ent><br/
<hw>Dis*tin"guished</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Marked; special.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The most <qex>distinguished</qex> politeness.</q> <rj><qau>Mad. D'
Arblay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Separated from others by distinct difference;
having, or indicating, superiority; eminent or known; illustrious; --
applied to persons and deeds.</def></p>

<p><syn><b>Syn.</b> -- Marked; noted; famous; conspicuous; celebrated;
transcendent; eminent; illustrious; extraordinary; prominent. --
<er>Distinguished</er>, <er>Eminent</er>, <er>Conspicuous</er>,
<er>Celebrated</er>, <er>Illustrious</er>. A man is <xex>eminent</xex>,
when he stands high as compared with those around him;
<xex>conspicuous</xex>, when he is so elevated as to be seen and
observed; <xex>distinguished</xex>, when he has something which makes
him stand apart from others in the public view; <xex>celebrated</xex>,
when he is widely spoken of with honor and respect;
<xex>illustrious</xex>, when a splendor is thrown around him which
confers the highest dignity.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distinguishedly</ent><br/
<hw>Dis*tin"guish*ed*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a
distinguished manner.</def> <mark>[R.]</mark>
<rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distinguisher</ent><br/
<hw>Dis*tin"guish*er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>One who, or that which, distinguishes or separates one thing from
another by marks of diversity.</def> <rj><au>Sir T.
Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who discerns accurately the difference of
things; a nice or judicious observer.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distinguishing</ent><br/
<hw>Dis*tin"guish*ing</hw>, <pos>a.</pos> <def>Constituting difference,
or distinction from everything else; distinctive; peculiar;
characteristic.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>distinguishing</qex> doctrines of our holy religion.</q>
<rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Distinguishing pennant</b></col> <fld>(Naut.)</fld>,
<cd>a special pennant by which any particular vessel in a fleet is
recognized and signaled.</cd> <rj><au>Simmonds.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distinguishingly</ent><br/
<hw>Dis*tin"guish*ing*ly</hw>, <pos>adv.</pos> <def>With distinction;
with some mark of preference.</def> <rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distinguishment</ent><br/
<hw>Dis*tin"guish*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Observation
of difference; distinction.</def> <rj><au>Graunt.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distitle</ent><br/
<hw>Dis*ti"tle</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To deprive of
title or right.</def> <mark>[R.]</mark> <rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distoma</ent><br/
\'d8<hw>Dis"to*ma</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<grk>di-</grk> = <grk>di`s-</grk> twice + <grk>sto`ma</grk>
mouth.]</ety> <fld>(Zool.)</fld> <def>A genus of parasitic, trematode
worms, having two suckers for attaching themselves to the part they
infest. See 1st <er>Fluke</er>, 2.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distort</ent><br/
<hw>Dis*tort"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>distortus</ets>, p. p. of <ets>distorquere</ets> to twist, distort;
<ets>dis-</ets> + <ets>torquere</ets> to twist. See
<er>Torsion</er>.]</ety> <def>Distorted; misshapen.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Her face was ugly and her mouth <qex>distort</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distort</ent><br/
<hw>Dis*tort"</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Distorted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Distorting</conjf>.]</vmorph> <sn>1.</sn> <def>To twist of
natural or regular shape; to twist aside physically; <as>as, to
<ex>distort</ex> the limbs, or the body</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Whose face was <qex>distorted</qex> with pain.</q>
<rj><qau>Thackeray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To force or put out of the true posture or
direction; to twist aside mentally or morally.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Wrath and malice, envy and revenge, do darken and
<qex>distort</qex> the understandings of men.</q>
<rj><qau>Tillotson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To wrest from the true meaning; to pervert; <as>as,
to <ex>distort</ex> passages of Scripture, or their
meaning</as>.</def></p>

<p><syn><b>Syn.</b> -- To twist; wrest; deform; pervert.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distorter</ent><br/
<hw>Dis*tort"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, distorts.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distortion</ent><br/
<hw>Dis*tor"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>distortio</ets>: cf. F. <ets>distortion</ets>.]</ety> <sn>1.</sn>
<def>The act of distorting, or twisting out of natural or regular shape;
a twisting or writhing motion; <as>as, the <ex>distortions</ex> of the
face or body</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A wresting from the true meaning.</def> <rj><au>Bp.
Wren.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The state of being distorted, or twisted out of
shape or out of true position; crookedness; perversion.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Med.)</fld> <def>An unnatural deviation of shape or
position of any part of the body producing visible deformity.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distortive</ent><br/
<hw>Dis*tort"ive</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Causing
distortion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distract</ent><br/
<hw>Dis*tract"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>distractus</ets>, p. p. of <ets>distrahere</ets> to draw asunder;
<ets>dis-</ets> + <ets>trahere</ets> to draw. See <er>Trace</er>, and
cf. <er>Distraught</er>.]</ety> <sn>1.</sn> <def>Separated; drawn
asunder.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Insane; mad.</def> <mark>[Obs.]</mark>
<rj><au>Drayton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distract</ent><br/
<hw>Dis*tract"</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Distracted</conjf>, old <pos>p. p.</pos>
<conjf>Distraught</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Distracting</conjf>.]</vmorph> <sn>1.</sn> <def>To draw apart or
away; to divide; to disjoin.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A city . . . <qex>distracted</qex> from itself.</q>
<rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To draw (the sight, mind, or attention) in different
directions; to perplex; to confuse; <as>as, to <ex>distract</ex> the
eye; to <ex>distract</ex> the attention.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Mixed metaphors . . . <qex>distract</qex> the imagination.</q>
<rj><qau>Goldsmith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To agitate by conflicting passions, or by a variety
of motives or of cares; to confound; to harass.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Horror and doubt <qex>distract</qex><br/
His troubled thoughts.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To unsettle the reason of; to render insane; to
craze; to madden; -- most frequently used in the participle,
<xex>distracted</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A poor mad soul; . . . poverty hath <qex>distracted</qex> her.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distracted</ent><br/
<hw>Dis*tract"ed</hw>, <pos>a.</pos> <def>Mentally disordered;
unsettled; mad.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>My <qex>distracted</qex> mind.</q> <rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distractedly</ent><br/
<hw>Dis*tract"ed*ly</hw>, <pos>adv.</pos> <def>Disjointedly;
madly.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distractedness</ent><br/
<hw>Dis*tract"ed*ness</hw>, <pos>n.</pos> <def>A state of being
distracted; distraction.</def> <rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distracter</ent><br/
<hw>Dis*tract"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, distracts away.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distractful</ent><br/
<hw>Dis*tract"ful</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Distracting.</def> <mark>[R.]</mark> <rj><au>Heywood.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distractible</ent><br/
<hw>Dis*tract"i*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of
being drawn aside or distracted.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distractile</ent><br/
<hw>Dis*tract"ile</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Bot.)</fld>
<def>Tending or serving to draw apart.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distracting</ent><br/
<hw>Dis*tract"ing</hw>, <pos>a.</pos> <def>Tending or serving to
distract.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distraction</ent><br/
<hw>Dis*trac"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>distractio</ets>: cf. F. <ets>distraction</ets>.]</ety> <sn>1.</sn>
<def>The act of distracting; a drawing apart; separation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To create <qex>distractions</qex> among us.</q> <rj><qau>Bp.
Burnet.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which diverts attention; a diversion.</def>
<ldquo/Domestic <xex>distractions</xex>.<rdquo/ <rj><au>G.
Eliot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A diversity of direction; detachment.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>His power went out in such <qex>distractions</qex> as<br/
Beguiled all species.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>State in which the attention is called in different
ways; confusion; perplexity.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That ye may attend upon the Lord without
<qex>distraction</qex>.</q> <rj><qau>1 Cor. vii. 35.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Confusion of affairs; tumult; disorder; <as>as,
political <ex>distractions</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Never was known a night of such <qex>distraction</qex>.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Agitation from violent emotions; perturbation of
mind; despair.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>distraction</qex> of the children, who saw both their
parents together, would have melted the hardest heart.</q>
<rj><qau>Tatler.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>Derangement of the mind; madness.</def>
<rj><au>Atterbury.</au></rj></p>

<p><syn><b>Syn.</b> -- Perplexity; confusion; disturbance; disorder;
dissension; tumult; derangement; madness; raving; franticness;
furiousness.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distractious</ent><br/
<hw>Dis*trac"tious</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Distractive.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distractive</ent><br/
<hw>Dis*trac"tive</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Causing
perplexity; distracting.</def> <ldquo/<xex>Distractive</xex>
thoughts.<rdquo/ <rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distrain</ent><br/
<hw>Dis*train"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Distrained</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Distraining</conjf>.]</vmorph> <ety>[OE.
<ets>destreinen</ets> to force, OF. <ets>destreindre</ets> to press,
oppress, force, fr. L. <ets>distringere</ets>, <ets>districtum</ets>, to
draw asunder, hinder, molest, LL., to punish severely; <ets>di-</ets> =
<ets>stringere</ets> to draw tight, press together. See <er>Strain</er>,
and cf. <er>Distress</er>, <er>District</er>, <er>Distraint</er>.]</ety>
<sn>1.</sn> <def>To press heavily upon; to bear down upon with violence;
hence, to constrain or compel; to bind; to distress, torment, or
afflict.</def> <mark>[Obs.]</mark> <ldquo/<xex>Distrained</xex> with
chains.<rdquo/ <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To rend; to tear.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Neither guile nor force might it [a net] <qex>distrain</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Law)</fld> <sd>(a)</sd> <def>To seize, as a pledge
or indemnification; to take possession of as security for nonpayment of
rent, the reparation of an injury done, etc.; to take by distress;
<as>as, to <ex>distrain</ex> goods for rent, or of an
amercement</as>.</def> <sd>(b)</sd> <def>To subject to distress; to
coerce; <as>as, to <ex>distrain</ex> a person by his goods and
chattels</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distrain</ent><br/
<hw>Dis*train"</hw>, <pos>v. i.</pos> <def>To levy a distress.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Upon whom I can <qex>distrain</qex> for debt.</q>
<rj><qau>Camden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distrainable</ent><br/
<hw>Dis*train"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of
being, or liable to be, distrained.</def>
<rj><au>Blackstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distrainer</ent><br/
<hw>Dis*train"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Distrainor</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distrainor</ent><br/
<hw>Dis*train"or</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Law)</fld>
<def>One who distrains; the party distraining goods or chattels.</def>
<rj><au>Blackstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distraint</ent><br/
<hw>Dis*traint"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>destrainte</ets> distress, force.]</ety> <fld>(Law)</fld> <def>The
act or proceeding of seizing personal property by distress.</def>
<rj><au>Abbott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distrait</ent><br/
\'d8<hw>Dis`trait"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F. See
<er>Distract</er>.]</ety> <def>Absent-minded; lost in thought;
abstracted.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distraught</ent><br/
<hw>Dis*traught"</hw> <pr>(?)</pr>, <pos>p. p. & a.</pos> <ety>[OE.
<ets>distract</ets>, <ets>distrauht</ets>. See <er>Distract</er>,
<pos>a.</pos>]</ety> <sn>1.</sn> <def>Torn asunder; separated.</def>
<mark>[Obs.]</mark> <ldquo/His greedy throat . . .
<xex>distraught</xex>.<rdquo/ <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Distracted; perplexed.</def>
<ldquo/<xex>Distraught</xex> twixt fear and pity.<rdquo/
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>As if thou wert <qex>distraught</qex> and mad with terror.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To doubt betwixt our senses and our souls<br/
Which are the most <qex>distraught</qex> and full of pain.</q>
<rj><qau>Mrs. Browning.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distraughted</ent><br/
<hw>Dis*traught"ed</hw>, <pos>a.</pos> <def>Distracted.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distream</ent><br/
<hw>Dis*tream"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[Pref.
<ets>dis-</ets> (intens.) + <ets>stream</ets>.]</ety> <def>To
flow.</def> <mark>[Poetic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Yet o'er that virtuous blush <qex>distreams</qex> a tear.</q>
<rj><qau>Shenstone.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distress</ent><br/
<hw>Dis*tress"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>destresse</ets>, <ets>distresse</ets>, OF. <ets>destresse</ets>,
<ets>destrece</ets>, F. <ets>d<eacute/tresse</ets>, OF.
<ets>destrecier</ets> to distress, (assumed) LL.
<ets>districtiare</ets>, fr. L. <ets>districtus</ets>, p. p. of
<ets>distringere</ets>. See <er>Distrain</er>, and cf.
<er>Stress</er>.]</ety> <sn>1.</sn> <def>Extreme pain or suffering;
anguish of body or mind; <as>as, to suffer <ex>distress</ex> from the
gout, or from the loss of friends</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Not fearing death nor shrinking for <qex>distress</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which occasions suffering; painful situation;
misfortune; affliction; misery.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Affliction's sons are brothers in <qex>distress</qex>.</q>
<rj><qau>Burns.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A state of danger or necessity; <as>as, a ship in
<ex>distress</ex>, from leaking, loss of spars, want of provisions or
water, etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Law)</fld> <sd>(a)</sd> <def>The act of
distraining; the taking of a personal chattel out of the possession of a
wrongdoer, by way of pledge for redress of an injury, or for the
performance of a duty, as for nonpayment of rent or taxes, or for injury
done by cattle, etc.</def> <sd>(b)</sd> <def>The thing taken by
distraining; that which is seized to procure satisfaction.</def>
<rj><au>Bouvier.</au> <au>Kent.</au> <au>Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>If he were not paid, he would straight go and take a
<qex>distress</qex> of goods and cattle.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>distress</qex> thus taken must be proportioned to the
thing distrained for.</q> <rj><qau>Blackstone.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Abuse of distress</b></col>. <fld>(Law)</fld> <cd>See
under <er>Abuse</er>.</cd></cs></p>

<p><syn><b>Syn.</b> -- Affliction; suffering; pain; agony; misery;
torment; anguish; grief; sorrow; calamity; misfortune; trouble;
adversity. See <er>Affliction</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distress</ent><br/
<hw>Dis*tress"</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Distressed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Distressing</conjf>.]</vmorph> <ety>[Cf. OF.
<ets>destrecier</ets>. See <er>Distress</er>, <pos>n.</pos>]</ety>
<sn>1.</sn> <def>To cause pain or anguish to; to pain; to oppress with
calamity; to afflict; to harass; to make miserable.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We are troubled on every side, yet not <qex>distressed</qex>.</q>
<rj><qau>2 Cor. iv. 8.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To compel by pain or suffering.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Men who can neither be <qex>distressed</qex> nor won into a
sacrifice of duty.</q> <rj><qau>A. Hamilton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Law)</fld> <def>To seize for debt; to
distrain.</def></p>

<p><syn><b>Syn.</b> -- To pain; grieve; harass; trouble; perplex;
afflict; worry; annoy.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>distressed</ent><br/
<hw>distressed</hw> <pos>adj.</pos> <sn>1.</sn> <def>facing or
experiencing financial trouble or difficulty; <as>as,
<ex>distressed</ex> companies need loans and technical
advice</as>.</def><br/
<syn><b>Syn. --</b> hard-pressed, hard put, in a bad way(predicate), in
trouble(predicate).</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>experiencing a generalized feeling of
distress.</def> <see>Also See: <er>dejected</er>, <er>unhappy</er>,
<er>sad</er>.</see> Antonym: <ant>euphoric</ant>.<br/
<syn><b>Syn. --</b> dysphoric, unhappy.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>3.</sn> <def>suffering severe physical strain or discomfort;
<as>as, he dropped out of the race, clearly <ex>distressed</ex> and
having difficulty breathing</as>.</def><br/
<syn><b>Syn. --</b> stressed, in a bad way(predicate).</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>4.</sn> <def>emotionally upset.</def><br/
<syn><b>Syn. --</b> unstrung.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Distressedness</ent><br/
<hw>Dis*tress"ed*ness</hw>, <pos>n.</pos> <def>A state of being
distressed or greatly pained.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distressful</ent><br/
<hw>Dis*tress"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Full of
distress; causing, indicating, or attended with, distress; <as>as, a
<ex>distressful</ex> situation</as>.</def> <ldquo/Some
<xex>distressful</xex> stroke.<rdquo/ <au>Shak.</au>
<ldquo/<xex>Distressful</xex> cries.<rdquo/ <au>Pope.</au><br/
<syn><b>Syn. --</b> distressing.</syn><br/
[<source>1913 Webster</source>]</p>

<p><wordforms> -- <wf>Dis*tress"ful*ly</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>distressfulness</ent><br/
<hw>distressfulness</hw> <pos>n.</pos> <def>the quality of causing
mental anguish.</def><br/
<syn><b>Syn. --</b> seriousness.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><-- p. 436 --></p>

<p><ent>distressing</ent><br/
<hw>dis*tress"ing</hw> <pr>(d<icr/s*tr<ecr/s"<icr/ng)</pr>,
<pos>a.</pos> <def>Causing distress; painful; unpleasant.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distressing</ent><br/
<hw>Dis*tress"ing</hw>, <pos>adv.</pos> <def>In a distressing
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distributable</ent><br/
<hw>Dis*trib"u*ta*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of
being distributed.</def> <rj><au>Sir W. Jones.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distributary</ent><br/
<hw>Dis*trib"u*ta*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Tending to
distribute or be distributed; that distributes; distributive.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distribute</ent><br/
<hw>Dis*trib"ute</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Distributed</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Distributing</conjf>.]</vmorph> <ety>[L. <ets>distributus</ets>,
p. p. of <ets>distribuere</ets> to divide, distribute; <ets>dis-</ets> +
<ets>tribuere</ets> to assign, give, allot. See <er>Tribute</er>.]</ety>
<sn>1.</sn> <def>To divide among several or many; to deal out; to
apportion; to allot.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>She did <qex>distribute</qex> her goods to all them that were
nearest of kindred.</q> <rj><qau>Judith xvi. 24.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To dispense; to administer; <as>as, to
<ex>distribute</ex> justice</as>.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To divide or separate, as into classes, orders,
kinds, or species; to classify; to assort, as specimens, letters,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Printing)</fld> <sd>(a)</sd> <def>To separate (type
which has been used) and return it to the proper boxes in the
cases.</def> <sd>(b)</sd> <def>To spread (ink) evenly, as upon a roller
or a table.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Logic)</fld> <def>To employ (a term) in its whole
extent; to take as universal in one premise.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A term is said to be <qex>distributed</qex> when it is taken
universal, so as to stand for everything it is capable of being applied
to.</q> <rj><qau>Whately.</qau></rj></p>

<p><syn><b>Syn.</b> -- To dispense; deal out; apportion; allot; share;
assign; divide.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distribute</ent><br/
<hw>Dis*trib"ute</hw>, <pos>v. i.</pos> <def>To make
distribution.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>distributed</ent><br/
<hw>distributed</hw> <pos>adj.</pos> <sn>1.</sn> <def>spread from a
central location to multiple points or recipients. Opposite of
<ant>concentrated</ant>.</def> [Narrower terms: <stype>apportioned,
dealt out, doled out, meted out, parceled out</stype>; <stype>diffuse,
diffused</stype>; <stype>dispensed</stype>; <stype>dispersed,
spread</stype>; <stype>divided, divided up, shared, shared out on the
basis of a plan or purpose)</stype>; <stype>encyclical</stype>;
<stype>rationed</stype>; <stype>scattered, widespread</stype>;
<stype>sparse, thin</stype>; <stype>unfocused, unfocussed</stype>]
<see>Also See: <er>distributive</er>.</see><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>spread among a variety of securities; -- of
investments.</def><br/
<syn><b>Syn. --</b> diversified.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><q><qex>Distributing</qex> to the necessity of saints.</q>
<rj><qau>Rom. xii. 13.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distributer</ent><br/
<hw>Dis*trib"u*ter</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or
that which, distributes or deals out anything; a dispenser.</def>
<rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distributing</ent><br/
<hw>Dis*trib"u*ting</hw>, <pos>a.</pos> <def>That distributes; dealing
out.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Distributing past office</b></col>, <cd>an office where
the mails for a large district are collected to be assorted according to
their destination and forwarded.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distribution</ent><br/
<hw>Dis`tri*bu"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>distributio</ets>: cf. F. <ets>distribution</ets>.]</ety>
<sn>1.</sn> <def>The act of distributing or dispensing; the act of
dividing or apportioning among several or many; apportionment; <as>as,
the <ex>distribution</ex> of an estate among heirs or
children</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The phenomena of geological <qex>distribution</qex> are exactly
analogous to those of geography.</q> <rj><qau>A. R.
Wallace.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Separation into parts or classes; arrangement of
anything into parts; disposition; classification.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which is distributed.</def> <ldquo/Our
charitable <xex>distributions</xex>.<rdquo/
<rj><au>Atterbury.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Logic)</fld> <def>A resolving a whole into its
parts.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Print.)</fld> <def>The sorting of types and placing
them in their proper boxes in the cases.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Steam Engine)</fld> <def>The steps or operations by
which steam is supplied to and withdrawn from the cylinder at each
stroke of the piston; viz., admission, suppression or cutting off,
release or exhaust, and compression of exhaust steam prior to the next
admission.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Geographical distribution</b></col>, <cd>the natural
arrangements of animals and plants in particular regions or
districts.</cd></cs></p>

<p><syn><b>Syn.</b> -- Apportionments; allotment; dispensation;
disposal; dispersion; classification; arrangement.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distributional</ent><br/
<hw>Dis`tri*bu"tion*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or
pertaining to distribution.</def> <rj><au>Huxley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distributionist</ent><br/
<hw>Dis`tri*bu"tion*ist</hw>, <pos>n.</pos> <def>A distributer.</def>
<mark>[R.]</mark> <rj><au>Dickens.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distributive</ent><br/
<hw>Dis*trib"u*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>distributif</ets>.]</ety> <sn>1.</sn> <def>Tending to distribute;
serving to divide and assign in portions; dealing to each his proper
share.</def> <ldquo/<xex>Distributive</xex> justice.<rdquo/
<rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Logic)</fld> <def>Assigning the species of a
general term.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Gram.)</fld> <def>Expressing separation; denoting a
taking singly, not collectively; <as>as, a <ex>distributive</ex>
adjective or pronoun, such as <xex>each</xex>, <xex>either</xex>,
<xex>every</xex>; a <ex>distributive</ex> numeral, as (Latin)
<xex>bini</xex> (two by two)</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Distributive operation</b></col> <fld>(Math.)</fld>,
<cd>any operation which either consists of two or more parts, or works
upon two or more things, and which is such that the result of the total
operation is the same as the aggregated result of the two or more
partial operations. Ordinary multiplication is <ex>distributive</ex>,
since <mathex>a <times/ (b + c) = ab + ac</mathex>, and <mathex>(a + b)
<times/ c = ac + bc</mathex>.</cd> -- <col><b>Distributive
proportion</b></col>. <fld>(Math.)</fld> <cd>See
<er>Fellowship</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distributive</ent><br/
<hw>Dis*trib"u*tive</hw>, <pos>n.</pos> <fld>(Gram.)</fld> <def>A
distributive adjective or pronoun; also, a distributive
numeral.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distributively</ent><br/
<hw>Dis*trib"u*tive*ly</hw>, <pos>adv.</pos> <def>By distribution;
singly; not collectively; in a distributive manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distributiveness</ent><br/
<hw>Dis*trib"u*tive*ness</hw>, <pos>n.</pos> <def>Quality of being
distributive.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distributor</ent><br/
<hw>Dis*trib"u*tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.]</ety>
<def>One that distributes; a distributer;</def>
<specif>specif.</specif>: <sd>(a)</sd> <def>A machine for distributing
type.</def> <sd>(b)</sd> <def>An appliance, as a roller, in a printing
press, for distributing ink.</def> <sd>(c)</sd> <def>An apparatus for
distributing an electric current, either to various points in rotation,
as in some motors, or along two or more lines in parallel, as in a
distributing system.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>District</ent><br/
<hw>Dis"trict</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>districtus</ets>, p. p.]</ety> <def>Rigorous; stringent;
harsh.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Punishing with the rod of <qex>district</qex> severity.</q>
<rj><qau>Foxe.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>District</ent><br/
<hw>Dis"trict</hw>, <pos>n.</pos> <ety>[LL. <ets>districtus</ets>
district, fr. L. <ets>districtus</ets>, p. p. of <ets>distringere</ets>:
cf. F. <ets>district</ets>. See <er>Distrain</er>.]</ety> <sn>1.</sn>
<fld>(Feudal Law)</fld> <def>The territory within which the lord has the
power of coercing and punishing.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A division of territory; a defined portion of a
state, town, or city, etc., made for administrative, electoral, or other
purposes; <as>as, a congressional <ex>district</ex>, judicial
<ex>district</ex>, land <ex>district</ex>, school <ex>district</ex>,
etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>To exercise exclusive legislation . . . over such
<qex>district</qex> not exceeding ten miles square.</q> <rj><qau>The
Constitution of the United States.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Any portion of territory of undefined extent; a
region; a country; a tract.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>These <qex>districts</qex> which between the tropics lie.</q>
<rj><qau>Blackstone.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Congressional district</b></col>. <cd>See under
<er>Congressional</er>.</cd> -- <col><b>District attorney</b></col>,
<cd>the prosecuting officer of a district or district court.</cd> --
<col><b>District court</b></col>, <cd>a subordinate municipal, state, or
United States tribunal, having jurisdiction in certain cases within a
judicial district.</cd> -- <col><b>District judge</b></col>, <cd>one who
presides over a district court.</cd> -- <col><b>District
school</b></col>, <cd>a public school for the children within a school
district.</cd> <mark>[U.S.]</mark></cs></p>

<p><syn><b>Syn.</b> -- Division; circuit; quarter; province; tract;
region; country.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>District</ent><br/
<hw>Dis"trict</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Districted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Districting</conjf>.]</vmorph> <def>To divide into districts or
limited portions of territory; <as>as, legislatures <ex>district</ex>
States for the choice of representatives</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distriction</ent><br/
<hw>Dis*tric"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>districtio</ets> a stretching out.]</ety> <def>Sudden display;
flash; glitter.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>A smile . . . breaks out with the brightest
<qex>distriction</qex>.</q> <rj><qau>Collier.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Districtly</ent><br/
<hw>Dis"trict*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>Strictly.</def>
<mark>[Obs.]</mark> <rj><au>Foxe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distringas</ent><br/
\'d8<hw>Dis*trin"gas</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., that you
distrain, fr. <ets>distringere</ets>. See <er>Distrain</er>.]</ety>
<fld>(Law)</fld> <def>A writ commanding the sheriff to distrain a person
by his goods or chattels, to compel a compliance with something required
of him.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distrouble</ent><br/
<hw>Dis*trou"ble</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>dis-</ets> (intens.) + <ets>trouble</ets>.]</ety> <def>To
trouble.</def> <mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>distrust</ent><br/
<hw>dis*trust"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Distrusted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Distrusting</conjf>.]</vmorph> <ety>[Cf.
<er>Mistrust</er>.]</ety> <def>To feel absence of trust in; not to
confide in or rely upon; to deem of questionable sufficiency or reality;
to doubt; to be suspicious of; to mistrust.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Not <qex>distrusting</qex> my health.</q> <rj><qau>2 Mac. ix.
22.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>distrust</qex> the justice of your cause.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He that requireth the oath doth <qex>distrust</qex> that
other.</q> <rj><qau>Udall.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Of all afraid,<br/
<qex>Distrusting</qex> all, a wise, suspicious maid.</q>
<rj><qau>Collins.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Mistrust</xex> has been almost wholly driven out by
<xex>distrust</xex>.</note> <rj><au>T. L. K. Oliphant.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>distrust</ent><br/
<hw>dis*trust"</hw>, <pos>n.</pos> <sn>1.</sn> <def>Doubt of
sufficiency, reality, or sincerity; lack of confidence, faith, or
reliance; <as>as, <ex>distrust</ex> of one's power, authority, will,
purposes, schemes, etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Suspicion of evil designs.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Alienation and <qex>distrust</qex> . . . are the growth of false
principles.</q> <rj><qau>D. Webster.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>State of being suspected; loss of trust.</def>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distruster</ent><br/
<hw>Dis*trust"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
distrusts.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distrustful</ent><br/
<hw>Dis*trust"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Not
confident; diffident; wanting confidence or thrust; modest; <as>as,
<ex>distrustful</ex> of ourselves, of one's powers</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Distrustful</qex> sense with modest caution speaks.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Apt to distrust; suspicious; mistrustful.</def>
<rj><au>Boyle.</au></rj></p>

<p>-- <wordforms><wf>Dis*trust"ful*ly</wf>, <pos>adv.</pos> --
<wf>Dis*trust"ful*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distrusting</ent><br/
<hw>Dis*trust"ing</hw>, <pos>a.</pos> <def>That distrusts; suspicious;
lacking confidence in.</def> -- <wordforms><wf>Dis*trust"ing*ly</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distrustless</ent><br/
<hw>Dis*trust"less</hw>, <pos>a.</pos> <def>Free from distrust.</def>
<rj><au>Shenstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distune</ent><br/
<hw>Dis*tune"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To put out of
tune.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disturb</ent><br/
<hw>Dis*turb"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Disturbed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Disturbing</conjf>.]</vmorph> <ety>[OE.
<ets>desturben</ets>, <ets>destourben</ets>, OF. <ets>destorber</ets>,
<ets>desturber</ets>, <ets>destourber</ets>, fr. L.
<ets>disturbare</ets>, <ets>disturbatum</ets>; <ets>dis-</ets> +
<ets>turbare</ets> to disturb, trouble, <ets>turba</ets> disorder,
tumult, crowd. See <er>Turbid</er>.]</ety> <sn>1.</sn> <def>To throw
into disorder or confusion; to derange; to interrupt the settled state
of; to excite from a state of rest.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Preparing to <qex>disturb</qex><br/
With all-cofounding war the realms above.</q>
<rj><qau>Cowper.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The bellow's noise <qex>disturbed</qex> his quiet rest.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The utmost which the discontented colonies could do, was to
<qex>disturb</qex> authority.</q> <rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To agitate the mind of; to deprive of tranquillity;
to disquiet; to render uneasy; <as>as, a person is <ex>disturbed</ex> by
receiving an insult, or his mind is <ex>disturbed</ex> by
envy</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To turn from a regular or designed course.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>And <qex>disturb</qex><br/
His inmost counsels from their destined aim.</q>
<rj><qau>Milton.</qau></rj></p>

<p><syn><b>Syn.</b> -- To disorder; disquiet; agitate; discompose;
molest; perplex; trouble; incommode; ruffle.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disturb</ent><br/
<hw>Dis*turb"</hw>, <pos>n.</pos> <def>Disturbance.</def>
<mark>[Obs.]</mark> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disturbance</ent><br/
<hw>Dis*turb"ance</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>destorbance</ets>.]</ety> <sn>1.</sn> <def>An interruption of a
state of peace or quiet; derangement of the regular course of things;
disquiet; disorder; <as>as, a <ex>disturbance</ex> of religious
exercises; a <ex>disturbance</ex> of the galvanic
current.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Confusion of the mind; agitation of the feelings;
perplexity; uneasiness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Any man . . . in a state of <qex>disturbance</qex> and
irritation.</q> <rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Violent agitation in the body politic; public
commotion; tumult.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>disturbance</qex> was made to support a general
accusation against the province.</q> <rj><qau>Bancroft.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Law)</fld> <def>The hindering or disquieting of a
person in the lawful and peaceable enjoyment of his right; the
interruption of a right; <as>as, the <ex>disturbance</ex> of a
franchise, of common, of ways, and the like</as>.</def>
<rj><au>Blackstone.</au></rj></p>

<p><syn><b>Syn.</b> -- Tumult; brawl; commotion; turmoil; uproar;
hubbub; disorder; derangement; confusion; agitation; perturbation;
annoyance.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disturbation</ent><br/
<hw>Dis`tur*ba"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>disturbatio</ets>.]</ety> <def>Act of disturbing;
disturbance.</def> <mark>[Obs.]</mark> <rj><au>Daniel.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disturber</ent><br/
<hw>Dis*turb"er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. OF.
<ets>destorbeor</ets>.]</ety> <sn>1.</sn> <def>One who, or that which,
disturbs of disquiets; a violator of peace; a troubler.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A needless <qex>disturber</qex> of the peace of God's church and
an author of dissension.</q> <rj><qau>Hooker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>One who interrupts or incommodes
another in the peaceable enjoyment of his right.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disturn</ent><br/
<hw>Dis*turn"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[OF.
<ets>destourner</ets>, F. <ets>d<eacute/tourner</ets>. See
<er>Detour</er>.]</ety> <def>To turn aside.</def> <mark>[Obs.]</mark>
<rj><au>Daniel.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Distyle</ent><br/
<hw>Dis"tyle</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <grk>di-</grk> =
<grk>di`s-</grk> twice + <?/ pillar: cf. F. <ets>distyle</ets>.]</ety>
<fld>(Arch.)</fld> <def>Having two columns in front; -- said of a
temple, portico, or the like.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Distyle in antis</b></col>, <cd>having columns between
two ant<ae/. See <er>Anta</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disulphate</ent><br/
<hw>Di*sul"phate</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>di-</ets> + <ets>sulphate</ets>.]</ety> <fld>(Chem.)</fld>
<sd>(a)</sd> <def>A salt of disulphuric or pyrosulphuric acid; a
pyrosulphate.</def> <sd>(b)</sd> <def>An acid salt of sulphuric acid,
having only one equivalent of base to two of the acid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disulphide</ent><br/
<hw>Di*sul"phide</hw> <pr>(?; 104)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>di-</ets> + <ets>sulphide</ets>.]</ety> <fld>(Chem.)</fld> <def>A
binary compound of sulphur containing two atoms of sulphur in each
molecule; -- formerly called <xex>disulphuret</xex>. Cf.
<er>Bisulphide</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disulphuret</ent><br/
<hw>Di*sul"phu*ret</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>di-</ets> + <ets>sulphuret</ets>.]</ety> <fld>(Chem.)</fld>
<def>See <er>Disulphide</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disulphuric</ent><br/
<hw>Di`sul*phu"ric</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>di-</ets> + <ets>sulphuric</ets>.]</ety> <fld>(Chem.)</fld>
<def>Applied to an acid having in each molecule two atoms of sulphur in
the higher state of oxidation.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Disulphuric acid</b></col>, <cd>a thick oily liquid,
<chform>H2S2O7</chform>, called also <altname>Nordhausen acid</altname>
(from <ets>Nordhausen</ets> in the Harts, where it was originally
manufactured), <altname>fuming sulphuric acid</altname>, and especially
<altname>pyrosulphuric acid</altname>. See under
<er>Pyrosulphuric</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disuniform</ent><br/
<hw>Dis*u"ni*form</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Not
uniform.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disunion</ent><br/
<hw>Dis*un"ion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>dis-</ets> + <ets>union</ets>: cf. F.
<ets>d<eacute/sunion</ets>.]</ety> <sn>1.</sn> <def>The termination of
union; separation; disjunction; <as>as, the <ex>disunion</ex> of the
body and the soul</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A breach of concord and its effect;
alienation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Such a <qex>disunion</qex> between the two houses as might much
clou<?/ the happiness of this kingdom.</q>
<rj><qau>Clarendon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The termination or disruption of the union of the
States forming the United States.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I have not accustomed myself to hang over the precipice of
<qex>disunion</qex>.</q> <rj><qau>D. Webster.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disunionist</ent><br/
<hw>Dis*un"ion*ist</hw>, <pos>n.</pos> <def>An advocate of disunion,
specifically, of disunion of the United States.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disunite</ent><br/
<hw>Dis`u*nite"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Disunited</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Disuniting</conjf>.]</vmorph> <sn>1.</sn> <def>To destroy the
union of; to divide; to part; to sever; to disjoin; to sunder; to
separate; <as>as, to <ex>disunite</ex> particles of
matter</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To alienate in spirit; to break the concord
of.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Go on both in hand, O nations, never be <qex>disunited</qex>, be
the praise . . . of all posterity!</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disunite</ent><br/
<hw>Dis`u*nite"</hw>, <pos>v. i.</pos> <def>To part; to fall asunder; to
become separated.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The joints of the body politic do separate and
<qex>disunite</qex>.</q> <rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disuniter</ent><br/
<hw>Dis`u*nit"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, disjoins or causes disunion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disunity</ent><br/
<hw>Dis*u"ni*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A state of
separation or disunion; want of unity.</def> <rj><au>Dr. H.
More.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disusage</ent><br/
<hw>Dis*us"age</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Gradual cessation
of use or custom; neglect of use; disuse.</def> <mark>[R.]</mark>
<rj><au>Hooker.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disuse</ent><br/
<hw>Dis*use"</hw> <pr>(?; see <er>Dis-</er>)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Disused</conjf> <pr>(?)</pr>;
<pos>p. pr. & vb. n.</pos> <conjf>Disusing</conjf>.]</vmorph>
<sn>1.</sn> <def>To cease to use; to discontinue the practice
of.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To disaccustom; -- with <xex>to</xex> or
<xex>from</xex>; <as>as, <ex>disused</ex> to toil</as>.</def>
<ldquo/<xex>Disuse</xex> me from . . . pain.<rdquo/
<rj><au>Donne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disuse</ent><br/
<hw>Dis*use"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Cessation of use,
practice, or exercise; inusitation; desuetude; <as>as, the limbs lose
their strength by <ex>disuse</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>disuse</qex> of the tongue in the only . . . remedy.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Church discipline then fell into <qex>disuse</qex>.</q>
<rj><qau>Southey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disutilize</ent><br/
<hw>Dis*u"til*ize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To deprive of
utility; to render useless.</def> <mark>[R.]</mark> <rj><au>Mrs.
Browning.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disvaluation</ent><br/
<hw>Dis*val`u*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Disesteem;
depreciation; disrepute.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disvalue</ent><br/
<hw>Dis*val"ue</hw> <pr>(?; see <er>Dis-</er>)</pr>, <pos>v. t.</pos>
<def>To undervalue; to depreciate.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disvalue</ent><br/
<hw>Dis*val"ue</hw>, <pos>n.</pos> <def>Disesteem; disregard.</def>
<rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disvantageous</ent><br/
<hw>Dis`van*ta"geous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>dis-</ets> + <ets>vantage</ets>.]</ety> <def>Disadvantageous.</def>
<mark>[Obs.]</mark> <ldquo/<xex>Disadvantageous</xex> ground.<rdquo/
<rj><au>Drayton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disvelop</ent><br/
<hw>Dis*vel"op</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To
develop.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disventure</ent><br/
<hw>Dis*ven"ture</hw> <pr>(?; 135)</pr>, <pos>n.</pos> <def>A
disadventure.</def> <mark>[Obs.]</mark> <rj><au>Shelton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disvouch</ent><br/
<hw>Dis*vouch"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To discredit; to
contradict.</def> <mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diswarn</ent><br/
<hw>Dis*warn"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Pref.
<ets>dis-</ets> (intens.) + <ets>warn</ets>.]</ety> <def>To dissuade
from by previous warning.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diswitted</ent><br/
<hw>Dis*wit"ted</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Deprived of wits
or understanding; distracted.</def> <mark>[Obs.]</mark>
<rj><au>Drayton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diswont</ent><br/
<hw>Dis*wont"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To deprive of
wonted usage; to disaccustom.</def> <mark>[R.]</mark> <rj><au>Bp.
Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disworkmanship</ent><br/
<hw>Dis*work"man*ship</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Bad
workmanship.</def> <mark>[Obs.]</mark> <rj><au>Heywood.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disworship</ent><br/
<hw>Dis*wor"ship</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To refuse to
worship; to treat as unworthy.</def> <mark>[Obs.]</mark> <rj><au>Sir T.
More.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disworship</ent><br/
<hw>Dis*wor"ship</hw>, <pos>n.</pos> <def>A deprivation of honor; a
cause of disgrace; a discredit.</def> <mark>[Obs.]</mark>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disworth</ent><br/
<hw>Dis*worth"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To deprive of
worth; to degrade.</def> <mark>[Obs.]</mark>
<rj><au>Feltham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Disyoke</ent><br/
<hw>Dis*yoke"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To unyoke; to
free from a yoke; to disjoin.</def> <mark>[Poetic]</mark> <rj><au>R.
Browning.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dit</ent><br/
<hw>Dit</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<er>Ditty</er>.]</ety>
<sn>1.</sn> <def>A word; a decree.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A ditty; a song.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dit</ent><br/
<hw>Dit</hw>, <pos>v. t.</pos> <ety>[AS. <ets>dyttan</ets>, akin to
Icel. <ets>ditta</ets>.]</ety> <def>To close up.</def>
<mark>[Obs.]</mark> <rj><au>Dr. H. More.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ditation</ent><br/
<hw>Di*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>ditare</ets> to enrich, fr. <ets>dis</ets>, <ets>ditis</ets>, same
as <ets>dives</ets>, rich.]</ety> <def>The act of making rich;
enrichment.</def> <mark>[Obs.]</mark> <rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ditch</ent><br/
<hw>Ditch</hw> <pr>(?; 224)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Ditches</plw> <pr>(#)</pr>.</plu> <ety>[OE. <ets>dich</ets>, orig.
the same word as <ets>dik</ets>. See <er>Dike</er>.]</ety> <sn>1.</sn>
<def>A trench made in the earth by digging, particularly a trench for
draining wet land, for guarding or fencing inclosures, or for preventing
an approach to a town or fortress. In the latter sense, it is called
also a <altname>moat</altname> or a <altname>fosse</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Any long, narrow receptacle for water on the surface
of the earth.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ditch</ent><br/
<hw>Ditch</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Ditched</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Ditching</conjf>.]</vmorph> <sn>1.</sn> <def>To dig a ditch or
ditches in; to drain by a ditch or ditches; <as>as, to <ex>ditch</ex>
moist land</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To surround with a ditch.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To throw into a ditch; <as>as, the engine was
<ex>ditched</ex> and turned on its side</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ditch</ent><br/
<hw>Ditch</hw>, <pos>v. i.</pos> <def>To dig a ditch or ditches.</def>
<rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ditcher</ent><br/
<hw>Ditch"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who digs
ditches.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dite</ent><br/
<hw>Dite</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[See
<er>Dight</er>.]</ety> <def>To prepare for action or use; to make ready;
to dight.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>His hideous club aloft he <qex>dites</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diterebene</ent><br/
<hw>Di*ter"e*bene</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>di-</ets> + <ets>terebene</ets>.]</ety> <fld>(Chem.)</fld> <def>See
<er>Colophene</er>.</def></p>

<p><ent>Dithecous</ent><br/
<ent>Dithecal</ent><br/
<mhw>{ <hw>Di*the"cal</hw> <pr>(?)</pr>, <hw>Di*the"cous</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[Pref. <ets>di-</ets> +
<ets>theca</ets>.]</ety> <fld>(Bot.)</fld> <def>Having two thec<ae/,
cells, or compartments.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ditheism</ent><br/
<hw>Di"the*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>di-</ets> + <ets>theism</ets>: cf. F.
<ets>dith<eacute/isme</ets>.]</ety> <def>The doctrine of those who
maintain the existence of two gods or of two original principles (as in
Manicheism), one good and one evil; dualism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ditheist</ent><br/
<hw>Di"the*ist</hw>, <pos>n.</pos> <def>One who holds the doctrine of
ditheism; a dualist.</def> <rj><au>Cudworth.</au></rj></p>

<p><ent>Ditheistical</ent><br/
<ent>Ditheistic</ent><br/
<mhw>{ <hw>Di`the*is"tic</hw> <pr>(?)</pr>, <hw>Di`the*is"tic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <def>Pertaining to ditheism;
dualistic.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 437 --></p>

<p><ent>Dithionic</ent><br/
<hw>Di`thi*on"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>di-</ets> + <ets>-thionic</ets>.]</ety> <fld>(Chem.)</fld>
<def>Containing two equivalents of sulphur; <as>as, <ex>dithionic</ex>
acid</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dithionic acid</b></col> <fld>(Chem.)</fld>, <cd>an
unstable substance, <chform>H2S2O6</chform>, known only in its
solutions, and in certain well-defined salts.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dithyramb</ent><br/
<hw>Dith"y*ramb</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>dithyrambus</ets>, Gr. <?/ a kind of lyric poetry in honor of
Bacchus; also, a name of Bacchus; of unknown origin: cf. F.
<ets>dithyrambe</ets>.]</ety> <def>A kind of lyric poetry in honor of
Bacchus, usually sung by a band of revelers to a flute accompaniment;
hence, in general, a poem written in a wild irregular strain.</def>
<rj><au>Bentley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dithyrambic</ent><br/
<hw>Dith`y*ram"bic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>dithyrambicus</ets>, Gr. <?/: cf. F.
<ets>dithyrambique</ets>.]</ety> <def>Pertaining to, or resembling, a
dithyramb; wild and boisterous.</def> <ldquo/<xex>Dithyrambic</xex>
sallies.<rdquo/ <au>Longfellow.</au> -- <def2><pos>n.</pos> <def>A
dithyrambic poem; a dithyramb.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dithyrambus</ent><br/
<hw>Dith`y*ram"bus</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.]</ety>
<def>See <er>Dithyramb</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dition</ent><br/
<hw>Di"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>ditio</ets>,
<ets>dicio</ets>: cf. F. <ets>dition</ets>.]</ety> <def>Dominion;
rule.</def> <mark>[Obs.]</mark> <rj><au>Evelyn.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ditionary</ent><br/
<hw>Di"tion*a*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Under rule;
subject; tributary.</def> <mark>[Obs.]</mark>
<rj><au>Chapman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ditionary</ent><br/
<hw>Di"tion*a*ry</hw>, <pos>n.</pos> <def>A subject; a tributary.</def>
<mark>[Obs.]</mark> <rj><au>Eden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ditokous</ent><br/
<hw>Di"to*kous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <grk>di-</grk>
= <grk>di`s-</grk> twice + <?/ a bringing forth, offspring.]</ety>
<fld>(Zool.)</fld> <sd>(a)</sd> <def>Having two kinds of young, as
certain annelids.</def> <sd>(b)</sd> <def>Producing only two eggs for a
clutch, as certain birds do.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ditolyl</ent><br/
<hw>Di*tol"yl</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>di-</ets> + <ets>tolyl</ets>.]</ety> <fld>(Chem.)</fld> <def>A
white, crystalline, aromatic hydrocarbon, <chform>C14H14</chform>,
consisting of two radicals or residues of toluene.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ditone</ent><br/
<hw>Di"tone`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ of two
tones; <grk>di-</grk> = <grk>di`s-</grk> twice + <?/ tone.]</ety>
<fld>(Mus.)</fld> <def>The Greek major third, which comprehend two major
tones (the modern major third contains one major and one minor whole
tone).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ditrichotomous</ent><br/
<hw>Di`tri*chot"o*mous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>di-</ets> + <ets>trichotomous</ets>.]</ety> <sn>1.</sn>
<def>Divided into twos or threes.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>Dividing into double or treble
ramifications; -- said of a leaf or stem.</def> <mark>[R.]</mark>
<rj><au>Loudon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ditrochean</ent><br/
<hw>Di`tro*che"an</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Pros.)</fld>
<def>Containing two trochees.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ditrochee</ent><br/
<hw>Di*tro"chee</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>ditrochaeus</ets>, Gr. <?/; <grk>di-</grk> = <grk>di`s-</grk> twice
+ <?/ trochee.]</ety> <fld>(Pros.)</fld> <def>A double trochee; a foot
made up of two trochees.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ditroite</ent><br/
<hw>Dit"ro*ite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Named from
<ets>Ditro</ets> in Transylvania.]</ety> <fld>(Min.)</fld> <def>An
igneous rock composed of orthoclase, el<ae/olite, and
sodalite.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ditt</ent><br/
<hw>Ditt</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See <er>Dit</er>,
<pos>n.</pos>, 2.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dittander</ent><br/
<hw>Dit*tan"der</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Dittany</er>.]</ety> <fld>(Bot.)</fld> <def>A kind of peppergrass
(<spn>Lepidium latifolium</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dittany</ent><br/
<hw>Dit"ta*ny</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE.
<ets>dytane</ets>, <ets>detane</ets>, <ets>dytan</ets>, OF.
<ets>ditain</ets>, F. <ets>dictame</ets>, L. <ets>dictamnum</ets>, fr.
Gr. <grk>di`ktamnon</grk> , <grk>di`ktamnos</grk>, a plant growing in
abundance on Mount <ets>Dicte</ets> in Crete. Cf.
<er>Dittander</er>.]</ety> <fld>(Bot.)</fld> <sd>(a)</sd> <def>A plant
of the Mint family (<spn>Origanum Dictamnus</spn>), a native of
Crete.</def> <sd>(b)</sd> <def>The <spn>Dictamnus Fraxinella</spn>. See
<er>Dictamnus</er>.</def> <sd>(c)</sd> <def>In America, the <spn>Cunila
Mariana</spn>, a fragrant herb of the Mint family.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dittied</ent><br/
<hw>Dit"tied</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From
<er>Ditty</er>.]</ety> <def>Set, sung, or composed as a ditty; --
usually in composition.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Who, with his soft pipe, and smooth-<qex>dittied</qex> song.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ditto</ent><br/
<hw>Dit"to</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Dittos</plw> <pr>(<?/)</pr>.</plu> <ety>[It., <ets>detto</ets>,
<ets>ditto</ets>, fr. L. <ets>dictum</ets>. See <er>Dictum</er>.]</ety>
<def>The aforesaid thing; the same (as before). Often contracted to
<xex>do.</xex>, or to two <ldquo/turned commas<rdquo/ (<rdquo/), or
small marks. Used in bills, books of account, tables of names, etc., to
save repetition.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A spacious table in the center, and a variety of smaller
<qex>dittos</qex> in the corners.</q> <rj><qau>Dickens.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ditto</ent><br/
<hw>Dit"to</hw>, <pos>adv.</pos> <def>As before, or aforesaid; in the
same manner; also.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dittology</ent><br/
<hw>Dit*tol"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>dittologi`a</grk>. Attic form of <grk>dissologi`a</grk> repetition
of words: <?/ twofold + <?/ to speak.]</ety> <def>A double reading, or
twofold interpretation, as of a Scripture text.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ditty</ent><br/
<hw>Dit"ty</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Ditties</plw> <pr>(#)</pr>.</plu> <ety>[OE. <ets>dite</ets>, OF.
<ets>diti<eacute/</ets>, fr. L. <ets>dictatum</ets>, p. p. neut. of
<ets>dictare</ets> to say often, dictate, compose. See <er>Dictate</er>,
<pos>v. t.</pos>]</ety> <sn>1.</sn> <def>A saying or utterance;
especially, one that is short and frequently repeated; a
theme.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>O, too high <qex>ditty</qex> for my simple rhyme.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A song; a lay; a little poem intended to be
sung.</def> <ldquo/Religious, martial, or civil
<xex>ditties</xex>.<rdquo/ <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And to the warbling lute soft <qex>ditties</qex> sing.</q>
<rj><qau>Sandys.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ditty</ent><br/
<hw>Dit"ty</hw>, <pos>v. i.</pos> <def>To sing; to warble a little
tune.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Beasts fain would sing; birds <qex>ditty</qex> to their notes.</q>
<rj><qau>Herbert.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ditty-bag</ent><br/
<hw>Dit"ty-bag`</hw>, <pos>n.</pos> <def>A sailor's small bag to hold
thread, needles, tape, etc.; -- also called <altname>sailor's
housewife</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ditty-box</ent><br/
<hw>Dit"ty-box`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A small box to
hold a sailor's thread, needless, comb, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diureide</ent><br/
<hw>Di*u"re*ide</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Di-</ets> +
<ets>ureide</ets>.]</ety> <fld>(Chem.)</fld> <def>One of a series of
complex nitrogenous substances regarded as containing two molecules of
urea or their radicals, as uric acid or allantoin. Cf.
<er>Ureide</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diuresis</ent><br/
\'d8<hw>Di`u*re"sis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. See
<er>Diuretic</er>.]</ety> <fld>(Med.)</fld> <def>Free excretion of
urine.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diuretic</ent><br/
<hw>Di`u*ret"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>diureticus</ets>, Gr. <?/, fr. <?/ to make water; <?/ through + <?/
to make water, fr. <?/ urine: cf. F.
<ets>diur<eacute/tique</ets>.]</ety> <fld>(Med.)</fld> <def>Tending to
increase the secretion and discharge of urine.</def> --
<def2><pos>n.</pos> <def>A medicine with diuretic
properties.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Diuretic salt</b></col> <fld>(Med.)</fld>, <cd>potassium
acetate; -- so called because of its diuretic properties.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diuretical</ent><br/
<hw>Di`u*ret"ic*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Diuretic.</def>
<mark>[Obs.]</mark> <rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diureticalness</ent><br/
<hw>Di`u*ret"ic*al*ness</hw>, <pos>n.</pos> <def>The quality of being
diuretical; diuretic property.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diurna</ent><br/
\'d8<hw>Di*ur"na</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL., fr. L.
<ets>diurnus</ets> belonging to the day.]</ety> <fld>(Zool.)</fld>
<def>A division of Lepidoptera, including the butterflies; -- so called
because they fly only in the daytime.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diurnal</ent><br/
<hw>Di*ur"nal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>diurnalis</ets>, fr. <ets>dies</ets> day. See <er>Deity</er>, and
cf. <er>Journal</er>.]</ety> <sn>1.</sn> <def>Relating to the daytime;
belonging to the period of daylight, distinguished from the night; --
opposed to <ant>nocturnal</ant>; <as>as, <ex>diurnal</ex> heat;
<ex>diurnal</ex> hours.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Daily; recurring every day; performed in a day;
going through its changes in a day; constituting the measure of a day;
<as>as, a <ex>diurnal</ex> fever; a <ex>diurnal</ex> task;
<ex>diurnal</ex> aberration, or <ex>diurnal</ex> parallax; the
<ex>diurnal</ex> revolution of the earth.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Ere twice the horses of the sun shall bring<br/
Their fiery torcher his <qex>diurnal</qex> ring.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Bot.)</fld> <def>Opening during the day, and
closing at night; -- said of flowers or leaves.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Zool.)</fld> <def>Active by day; -- applied
especially to the eagles and hawks among raptorial birds, and to
butterflies (Diurna) among insects.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Diurnal aberration</b></col> <fld>(Anat.)</fld>, <cd>the
aberration of light arising from the effect of the earth's rotation upon
the apparent direction of motion of light.</cd> -- <col><b>Diurnal
arc</b></col>, <cd>the arc described by the sun during the daytime or
while above the horizon; hence, the arc described by the moon or a star
from rising to setting.</cd> -- <col><b>Diurnal circle</b></col>,
<cd>the apparent circle described by a celestial body in consequence of
the earth's rotation.</cd> -- <col><b>Diurnal motion of the
earth</b></col>, <cd>the motion of the earth upon its axis which is
described in twenty-four hours.</cd> -- <col><b>Diurnal motion of a
heavenly body</b></col>, <cd>that apparent motion of the heavenly body
which is due to the earth's diurnal motion.</cd> -- <col><b>Diurnal
parallax</b></col>. <cd>See under <er>Parallax</er>.</cd> --
<col><b>Diurnal revolution of a planet</b></col>, <cd>the motion of the
planet upon its own axis which constitutes one complete
revolution.</cd></cs></p>

<p><syn><b>Syn.</b> -- See <er>Daily</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diurnal</ent><br/
<hw>Di*ur"nal</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>diurnal</ets> a prayerbook. See <er>Diurnal</er>,
<pos>a.</pos>]</ety> <sn>1.</sn> <def>A daybook; a journal.</def>
<mark>[Obs.]</mark> <rj><au>Tatler.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(R. C. Ch.)</fld> <def>A small volume containing the
daily service for the <ldquo/little hours,<rdquo/ viz., prime, tierce,
sext, nones, vespers, and compline.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <def>A diurnal bird or
insect.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diurnalist</ent><br/
<hw>Di*ur"nal*ist</hw>, <pos>n.</pos> <def>A journalist.</def>
<mark>[Obs.]</mark> <rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diurnally</ent><br/
<hw>Di*ur"nal*ly</hw>, <pos>adv.</pos> <def>Daily; every day.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diurnalness</ent><br/
<hw>Di*ur"nal*ness</hw>, <pos>n.</pos> <def>The quality of being
diurnal.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diurnation</ent><br/
<hw>Di`ur*na"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>Continuance during the day.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>The condition of sleeping or
becoming dormant by day, as is the case of the bats.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diuturnal</ent><br/
<hw>Di`u*tur"nal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>diuturnus</ets>, fr. <ets>diu</ets> a long time, by day; akin to
<ets>dies</ets> day.]</ety> <def>Of long continuance; lasting.</def>
<mark>[R.]</mark> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diuturnity</ent><br/
<hw>Di`u*tur"ni*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>diuturnitas</ets>.]</ety> <def>Long duration; lastingness.</def>
<mark>[R.]</mark> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diva</ent><br/
\'d8<hw>Di"va</hw> <pr>(d<emac/"v<adot/)</pr>, <pos>n.</pos>;
<plu><it>It. pl.</it> <plw>Dive</plw> <pr>(d<emac/"v<amac/)</pr></plu>.
<ety>[It., prop. fem. of <ets>divo</ets> divine, L.
<ets>divus</ets>.]</ety> <def>A prima donna.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Divagation</ent><br/
<hw>Di`va*ga"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>divagari</ets> to wander about; <ets>di-</ets> = <ets>dis-</ets> +
<ets>vagari</ets> to stroll about: cf. F. <ets>divagation</ets>. See
<er>Vagary</er>.]</ety> <def>A wandering about or going astray;
digression.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Let us be set down at Queen's Crawley without further
<qex>divagation</qex>.</q> <rj><qau>Thackeray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divalent</ent><br/
<hw>Div"a*lent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Pref.
<ets>di-</ets> + L. <ets>valens</ets>, <ets>valentis</ets>, p. pr. See
<er>Valence</er>.]</ety> <fld>(Chem.)</fld> <def>Having two units of
combining power; bivalent. Cf. <er>Valence</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divan</ent><br/
<hw>Di*van"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Per.
<ets>d<imac/w<amac/n</ets> a book of many leaves, an account book, a
collection of books, a senate, council: cf. Ar. <ets>daiw<amac/n</ets>,
F. <ets>divan</ets>.]</ety> <sn>1.</sn> <def>A book; esp., a collection
of poems written by one author; <as>as, the <ex>divan</ex> of
Hafiz</as>.</def> <mark>[Persia]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>In Turkey and other Oriental countries: A council of
state; a royal court. Also used by the poets for a grand deliberative
council or assembly.</def> <rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A chief officer of state.</def>
<mark>[India]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A saloon or hall where a council is held, in
Oriental countries, the state reception room in places, and in the
houses of the richer citizens. Cushions on the floor or on benches are
ranged round the room.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A cushioned seat, or a large, low sofa or couch;
especially, one fixed to its place, and not movable.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>A coffee and smoking saloon.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divaricate</ent><br/
<hw>Di*var"i*cate</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Divaricated</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Divaricating</conjf>.]</vmorph> <ety>[L. <ets>divaricatus</ets>,
p. p. of <ets>divaricare</ets> to stretch apart; <ets>di-</ets> =
<ets>dis-</ets> + <ets>varicare</ets> to straddle, fr.
<ets>varicus</ets> straddling, fr. <ets>varus</ets> stretched
outwards.]</ety> <sn>1.</sn> <def>To part into two branches; to become
bifid; to fork.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To diverge; to be divaricate.</def>
<rj><au>Woodward.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divaricate</ent><br/
<hw>Di*var"i*cate</hw>, <pos>v. t.</pos> <def>To divide into two
branches; to cause to branch apart.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divaricate</ent><br/
<hw>Di*var"i*cate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>divaricatus</ets>, p. p.]</ety> <sn>1.</sn> <def>Diverging;
spreading asunder; widely diverging.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Biol.)</fld> <def>Forking and diverging; widely
diverging; as the branches of a tree, or as lines of sculpture, or color
markings on animals, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divaricately</ent><br/
<hw>Di*var"i*cate*ly</hw>, <pos>adv.</pos> <def>With
divarication.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divarication</ent><br/
<hw>Di*var`i*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>divarication</ets>.]</ety> <sn>1.</sn> <def>A separation into two
parts or branches; a forking; a divergence.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An ambiguity of meaning; a disagreement of
difference in opinion.</def> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Biol.)</fld> <def>A divergence of lines of color
sculpture, or of fibers at different angles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divaricator</ent><br/
<hw>Di*var`i*ca"tor</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>One of the muscles which open the shell of brachiopods; a cardinal
muscle. See <xex>Illust.</xex> of <er>Brachiopoda</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divast</ent><br/
<hw>Di*vast"</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Devastated; laid
waste.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dive</ent><br/
<hw>Dive</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Dived</conjf> <pr>(?)</pr>, <xex>colloq</xex>.
<conjf>Dove</conjf> <pr>(<?/)</pr>, a relic of the AS. strong forms
<xex>de<aacute/f</xex>, <xex>dofen</xex>; <pos>p. pr. & vb. n.</pos>
<conjf>Diving</conjf>.]</vmorph> <ety>[OE. <ets>diven</ets>,
<ets>duven</ets>, AS. <ets>d<?/fan</ets> to sink, v. t., fr.
<ets>d<?/fan</ets>, v. i.; akin to Icel. <ets>d<?/fa</ets>, G.
<ets>taufen</ets>, E. <ets>dip</ets>, <ets>deep</ets>, and perh. to
<ets>dove</ets>, <ets>n.</ets> Cf. <er>Dip</er>.]</ety> <sn>1.</sn>
<def>To plunge into water head foremost; to thrust the body under, or
deeply into, water or other fluid.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It is not that pearls fetch a high price because men have
<qex>dived</qex> for them.</q> <rj><qau>Whately.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The colloquial form <xex>dove</xex> is common in the
United States as an imperfect tense form.</note><br/
[<source>1913 Webster</source>]</p>

<p><q>All [the walruses] <qex>dove</qex> down with a tremendous
splash.</q> <rj><qau>Dr. Hayes.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>When closely pressed it [the loon] <qex>dove</qex> . . . and left
the young bird sitting in the water.</q> <rj><qau>J.
Burroughs.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Fig.: To plunge or to go deeply into any subject,
question, business, etc.; to penetrate; to explore.</def>
<rj><au>South.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dive</ent><br/
<hw>Dive</hw> <pr>(?)</pr>, <pos>v. t.</pos> <sn>1.</sn> <def>To plunge
(a person or thing) into water; to dip; to duck.</def>
<mark>[Obs.]</mark> <rj><au>Hooker.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To explore by diving; to plunge into.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The Curtii bravely <qex>dived</qex> the gulf of fame.</q>
<rj><qau>Denham.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He <qex>dives</qex> the hollow, climbs the steeps.</q>
<rj><qau>Emerson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dive</ent><br/
<hw>Dive</hw>, <pos>n.</pos> <sn>1.</sn> <def>A plunge headforemost into
water, the act of one who dives, literally or figuratively.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A place of low resort.</def>
<mark>[Slang]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The music halls and <qex>dives</qex> in the lower part of the
city.</q> <rj><qau>J. Hawthorne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divedapper</ent><br/
<hw>Dive"dap`per</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Dive</er>, <er>Didapper</er>.]</ety> <fld>(Zool.)</fld> <def>A water
fowl; the didapper. See <er>Dabchick</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divel</ent><br/
<hw>Di*vel"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>divellere</ets>; <ets>dit-</ets> = <ets>dis-</ets> +
<ets>vellere</ets> to pluck.]</ety> <def>To rend apart.</def>
<mark>[Obs.]</mark> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divellent</ent><br/
<hw>Di*vel"lent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>divellens</ets>, p. pr.]</ety> <def>Drawing asunder.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divellicate</ent><br/
<hw>Di*vel"li*cate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>di-</ets> = <ets>vellicatus</ets>, p. p. of <ets>vellicare</ets> to
pluck, fr. <ets>vellere</ets> to pull.]</ety> <def>To pull in
pieces.</def> <mark>[Obs. or R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diver</ent><br/
<hw>Div"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who, or
that which, dives.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Divers</qex> and fishers for pearls.</q>
<rj><qau>Woodward.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Fig.: One who goes deeply into a subject, study, or
business.</def> <ldquo/A <xex>diver</xex> into causes.<rdquo/
<rj><au>Sir H. Wotton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <def>Any bird of certain genera, as
<gen>Urinator</gen> (formerly <gen>Colymbus</gen>), or the allied genus
<gen>Colymbus</gen>, or <gen>Podiceps</gen>, remarkable for their
agility in diving.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The northern diver (<spn>Urinator imber</spn>) is the
loon; the black diver or velvet scoter (<spn>Oidemia fusca</spn>) is a
sea duck. See <er>Loon</er>, and <er>Scoter</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diverb</ent><br/
<hw>Di"verb</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>diverbium</ets> the colloquial part of a comedy, dialogue; <ets>di-
= dis-</ets> + <ets>verbum</ets> word.]</ety> <def>A saying in which two
members of the sentence are contrasted; an antithetical proverb.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Italy, a paradise for horses, a hell for women, as the
<qex>diverb</qex> goes.</q> <rj><qau>Burton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diverberate</ent><br/
<hw>Di*ver"ber*ate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>diverberatus</ets>, p. p. of <ets>diverberare</ets> to strike
asunder; <ets>di-</ets> = <ets>dis-</ets> + <ets>verberare</ets>. See
<er>Verberate</er>.]</ety> <def>To strike or sound through.</def>
<mark>[R.]</mark> <rj><au>Davies (Holy Roode).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diverberation</ent><br/
<hw>Di*ver`ber*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A sounding
through.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diverge</ent><br/
<hw>Di*verge"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Diverged</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Diverging</conjf>.]</vmorph> <ety>[L. <ets>di-</ets> =
<ets>dis-</ets> + <ets>vergere</ets> to bend, incline. See
<er>Verge</er>.]</ety> <sn>1.</sn> <def>To extend from a common point in
different directions; to tend from one point and recede from each other;
to tend to spread apart; to turn aside or deviate (as from a given
direction); -- opposed to <ant>converge</ant>; <as>as, rays of light
<ex>diverge</ex> as they proceed from the sun</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To differ from a typical form; to vary from a normal
condition; to dissent from a creed or position generally held or
taken.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divergement</ent><br/
<hw>Di*verge"ment</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Divergence.</def></p>

<p><ent>Divergency</ent><br/
<ent>Divergence</ent><br/
<mhw>{ <hw>Di*ver"gence</hw> <pr>(?)</pr>, <hw>Di*ver"gen*cy</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[Cf. F.
<ets>divergence</ets>.]</ety> <sn>1.</sn> <def>A receding from each
other in moving from a common center; the state of being divergent;
<as>as, an angle is made by the <ex>divergence</ex> of straight
lines</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Rays come to the eye in a state of <qex>divergency</qex>.</q>
<rj><qau><?/<?/<?/<?/<?/<?/.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Disagreement; difference.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Related with some <qex>divergence</qex> by other writers.</q>
<rj><qau>Sir G. C. Lewis.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divergent</ent><br/
<hw>Di*ver"gent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>divergent</ets>. See <er>Diverge</er>.]</ety> <sn>1.</sn>
<def>Receding farther and farther from each other, as lines radiating
from one point; deviating gradually from a given direction; -- opposed
to <ant>convergent</ant>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Optics)</fld> <def>Causing divergence of rays;
<as>as, a <ex>divergent</ex> lens</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Fig.: Disagreeing from something given; differing;
<as>as, a <ex>divergent</ex> statement</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Divergent series</b></col>. <fld>(Math.)</fld> <cd>See
<cref>Diverging series</cref>, under <er>Diverging</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diverging</ent><br/
<hw>Di*ver"ging</hw>, <pos>a.</pos> <def>Tending in different directions
from a common center; spreading apart; divergent.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Diverging series</b></col> <fld>(Math.)</fld>, <cd>a
series whose terms are larger as the series is extended; a series the
sum of whose terms does not approach a finite limit when the series is
extended indefinitely; -- opposed to a <contr>converging
series</contr>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divergingly</ent><br/
<hw>Di*ver"ging*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a
diverging manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divers</ent><br/
<hw>Di"vers</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F. <ets>divers</ets>,
L. <ets>diversus</ets> turned in different directions, different, p. p.
of <ets>divertere</ets>. See <er>Divert</er>, and cf.
<er>Diverse</er>.]</ety> <sn>1.</sn> <def>Different in kind or species;
diverse.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Every sect of them hath a <qex>divers</qex> posture.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou shalt not sow thy vineyard with <qex>divers</qex> seeds.</q>
<rj><qau>Deut. xxii. 9.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Several; sundry; various; more than one, but not a
great number; <as>as, <ex>divers</ex> philosophers</as>. Also used
substantively or pronominally.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Divers</qex> of Antonio's creditors.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Divers</xex> is now limited to the plural; as,
<xex>divers ways</xex> (not <xex>divers way</xex>). Besides plurality it
ordinarily implies variety of kind.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diverse</ent><br/
<hw>Di"verse</hw> <pr>(?; 277)</pr>, <pos>a.</pos> <ety>[The same word
as <ets>divers</ets>. See <er>Divers</er>.]</ety> <sn>1.</sn>
<def>Different; unlike; dissimilar; distinct; separate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The word . . . is used in a sense very <qex>diverse</qex> from its
original import.</q> <rj><qau>J. Edwards.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Our roads are <qex>diverse</qex>: farewell, love! said she.</q>
<rj><qau>R. Browning.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Capable of various forms; multiform.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Eloquence is a great and <qex>diverse</qex> thing.</q> <rj><qau>B.
Jonson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diverse</ent><br/
<hw>Di*verse"</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In different
directions; diversely.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 438 --></p>

<p><ent>Diverse</ent><br/
<hw>Di*verse"</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To turn
aside.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The redcross knight <qex>diverst</qex>, but forth rode
Britomart.</q> <rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diversely</ent><br/
<hw>Di"verse*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <sn>1.</sn> <def>In
different ways; differently; variously.</def>
<ldquo/<xex>Diversely</xex> interpreted.<rdquo/
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>How <qex>diversely</qex> love doth his pageants play.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>In different directions; to different
points.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>On life's vast ocean <qex>diversely</qex> we sail.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diverseness</ent><br/
<hw>Di*verse"ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The quality of
being diverse.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diversifiability</ent><br/
<hw>Di*ver`si*fi`a*bil"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The
quality or capacity of being diversifiable.</def>
<rj><au>Earle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diversifiable</ent><br/
<hw>Di*ver"si*fi`a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of
being diversified or varied.</def> <rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diversification</ent><br/
<hw>Di*ver`si*fi*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Diversify</er>.]</ety> <sn>1.</sn> <def>The act of making various,
or of changing form or quality.</def> <rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>State of diversity or variation; variegation;
modification; change; alternation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Infinite <qex>diversifications</qex> of tints may be produced.</q>
<rj><qau>Adventurer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diversified</ent><br/
<hw>Di*ver"si*fied</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Distinguished
by various forms, or by a variety of aspects or objects; variegated;
<as>as, <ex>diversified</ex> scenery or landscape</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diversifier</ent><br/
<hw>Di*ver"si*fi`er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or
that which, diversifies.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diversiform</ent><br/
<hw>Di*ver"si*form</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>diversus</ets> diverse + <ets>-form</ets>.]</ety> <def>Of a
different form; of varied forms.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diversify</ent><br/
<hw>Di*ver"si*fy</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Diversified</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Diversifying</conjf>.]</vmorph> <ety>[F.
<ets>diversifier</ets>, LL. <ets>diversificare</ets>, fr. L.
<ets>diversus</ets> diverse + <ets>ficare</ets> (in comp.), akin to
<ets>facere</ets> to make. See <er>Diverse</er>.]</ety> <def>To make
diverse or various in form or quality; to give variety to; to variegate;
to distinguish by numerous differences or aspects.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Separated and <qex>diversified</qex> on from another.</q>
<rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Its seven colors, that <qex>diversify</qex> all the face of
nature.</q> <rj><qau>I. Taylor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diversiloquent</ent><br/
<hw>Di`ver*sil"o*quent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>diversus</ets> diverse + <ets>loquens</ets>, p. pr. of
<ets>loqui</ets> to speak.]</ety> <def>Speaking in different ways.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diversion</ent><br/
<hw>Di*ver"sion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>diversion</ets>. See <er>Divert</er>.]</ety> <sn>1.</sn> <def>The
act of turning aside from any course, occupation, or object; <as>as, the
<ex>diversion</ex> of a stream from its channel; <ex>diversion</ex> of
the mind from business.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which diverts; that which turns or draws the
mind from care or study, and thus relaxes and amuses; sport; play;
pastime; <as>as, the <ex>diversions</ex> of youth</as>.</def>
<ldquo/Public <xex>diversions</xex>.<rdquo/ <rj><au>V.
Knox.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Such productions of wit and humor as expose vice and folly,
furnish useful <qex>diversion</qex> to readers.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Mil.)</fld> <def>The act of drawing the attention
and force of an enemy from the point where the principal attack is to be
made; the attack, alarm, or feint which diverts.</def></p>

<p><syn><b>Syn.</b> -- Amusement; entertainment; pastime; recreation;
sport; game; play; solace; merriment.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>diversionary</ent><br/
<hw>diversionary</hw> <pos>adj.</pos> <def>likely or designed to confuse
or deceive; -- of tactics.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Diversity</ent><br/
<hw>Di*ver"si*ty</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Diversities</plw> <pr>(#)</pr>.</plu> <ety>[F.
<ets>diversit<eacute/</ets>, L. <ets>diversitas</ets>, fr.
<ets>diversus</ets>. See <er>Diverse</er>.]</ety> <sn>1.</sn> <def>A
state of difference; dissimilitude; unlikeness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They will prove opposite; and not resting in a bare
<qex>diversity</qex>, rise into a contrariety.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Multiplicity of difference; multiformity;
variety.</def> <ldquo/<xex>Diversity</xex> of sounds.<rdquo/
<au>Shak.</au> <ldquo/<xex>Diversities</xex> of opinion.<rdquo/
<rj><au>Secker.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Variegation.</def> <ldquo/Bright
<xex>diversities</xex> of day.<rdquo/ <rj><au>Pope.</au></rj></p>

<p><syn><b>Syn.</b> -- See <er>Variety</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diversivolent</ent><br/
<hw>Di`ver*siv"o*lent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>diversus</ets> diverse + <ets>volens</ets>, <ets>-entis</ets>, p.
pr. of <ets>velle</ets> to wish.]</ety> <def>Desiring different
things.</def> <mark>[Obs.]</mark> <rj><au>Webster (White
Devil).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diversory</ent><br/
<hw>Di*ver"so*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Serving or
tending to divert; also, distinguishing.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diversory</ent><br/
<hw>Di*ver"so*ry</hw>, <pos>n.</pos> <ety>[L. <ets>diversorium</ets>,
<ets>deversorium</ets>, an inn or lodging.]</ety> <def>A wayside
inn.</def> <mark>[Obs. or R.]</mark> <rj><au>Chapman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divert</ent><br/
<hw>Di*vert"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Diverted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Diverting</conjf>.]</vmorph> <ety>[F. <ets>divertir</ets>, fr. L.
<ets>divertere</ets>, <ets>diversum</ets>, to go different ways, turn
aside; <ets>di- = dis-</ets> + <ets>vertere</ets> to turn. See
<er>Verse</er>, and cf. <er>Divorce</er>.]</ety> <sn>1.</sn> <def>To
turn aside; to turn off from any course or intended application; to
deflect; <as>as, to <ex>divert</ex> a river from its channel; to
<ex>divert</ex> commerce from its usual course.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>That crude apple that <qex>diverted</qex> Eve.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To turn away from any occupation, business, or
study; to cause to have lively and agreeable sensations; to amuse; to
entertain; <as>as, children are <ex>diverted</ex> with sports; men are
<ex>diverted</ex> with works of wit and humor.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>We are amused by a tale, <qex>diverted</qex> by a comedy.</q>
<rj><qau>C. J. Smith.</qau></rj></p>

<p><syn><b>Syn.</b> -- To please; gratify; amuse; entertain; exhilarate;
delight; recreate. See <er>Amuse</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divert</ent><br/
<hw>Di*vert"</hw>, <pos>v. i.</pos> <def>To turn aside; to
digress.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I <qex>diverted</qex> to see one of the prince's palaces.</q>
<rj><qau>Evelyn.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diverter</ent><br/
<hw>Di*vert"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, diverts, turns off, or pleases.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divertible</ent><br/
<hw>Di*vert"i*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of being
diverted.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diverticle</ent><br/
<hw>Di*ver"ti*cle</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>diverticulum</ets>, <ets>deverticulum</ets>, a bypath, fr.
<ets>divertere</ets> to turn away.]</ety> <sn>1.</sn> <def>A turning; a
byway; a bypath.</def> <mark>[Obs.]</mark> <rj><au>Hales.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Anat.)</fld> <def>A diverticulum.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diverticular</ent><br/
<hw>Div`er*tic"u*lar</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Anat.)</fld>
<def>Pertaining to a diverticulum.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diverticulum</ent><br/
\'d8<hw>Div`er*tic"u*lum</hw> <pr>(?)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Diverticula</plw> <pr>(#)</pr>.</plu> <ety>[L.
See <er>Diverticle</er>.]</ety> <fld>(Anat.)</fld> <def>A blind tube
branching out of a longer one.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divertimento</ent><br/
\'d8<hw>Di*ver`ti*men"to</hw> <pr>(?)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>-ti</plw> <pr>(#)</pr>.</plu> <ety>[It.]</ety>
<fld>(Mus.)</fld> <def>A light and pleasing composition.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diverting</ent><br/
<hw>Di*vert"ing</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Amusing;
entertaining.</def> -- <wordforms><wf>Di*vert"ing*ly</wf>,
<pos>adv.</pos> -- <wf>Di*vert"ing*ness</wf>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divertise</ent><br/
<hw>Di*vert"ise</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[F.
<ets>divertir</ets>, p. pr. <ets>divertissant</ets>.]</ety> <def>To
divert; to entertain.</def> <mark>[Obs.]</mark>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divertisement</ent><br/
<hw>Di*vert"ise*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. the next
word.]</ety> <def>Diversion; amusement; recreation.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divertissement</ent><br/
\'d8<hw>Di`ver`tisse`ment"</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[F.]</ety> <def>A short ballet, or other entertainment, between the
acts of a play.</def> <rj><au>Smart.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divertive</ent><br/
<hw>Di*vert"ive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From
<er>Divert</er>.]</ety> <def>Tending to divert; diverting; amusing;
interesting.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Things of a pleasant and <qex>divertive</qex> nature.</q>
<rj><qau>Rogers.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dives</ent><br/
<hw>Di"ves</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., rich.]</ety>
<def>The name popularly given to the rich man in our Lord's parable of
the <ldquo/Rich Man and Lazarus<rdquo/ (<au>Luke xvi. 19-31</au>).
Hence, a name for a rich worldling.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divest</ent><br/
<hw>Di*vest"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Divested</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Divesting</conjf>.]</vmorph> <ety>[LL. <ets>divestire</ets>
(<ets>di-</ets> = <ets>dis-</ets> + L. <ets>vestire</ets> to dress),
equiv. to L. <ets>devestire</ets>. It is the same word as
<ets>devest</ets>, but the latter is rarely used except as a technical
term in law. See <er>Devest</er>, <er>Vest</er>.]</ety> <sn>1.</sn>
<def>To unclothe; to strip, as of clothes, arms, or equipage; -- opposed
to <ant>invest</ant>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Fig.: To strip; to deprive; to dispossess; <as>as,
to <ex>divest</ex> one of his rights or privileges; to <ex>divest</ex>
one's self of prejudices, passions, etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Wretches <qex>divested</qex> of every moral feeling.</q>
<rj><qau>Goldsmith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The tendency of the language to <qex>divest</qex> itself of its
gutturals.</q> <rj><qau>Earle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Law)</fld> <def>See <er>Devest</er>.</def>
<rj><au>Mozley & W.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divestible</ent><br/
<hw>Di*vest"i*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of being
divested.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divestiture</ent><br/
<hw>Di*vest"i*ture</hw> <pr>(?; 135)</pr>, <pos>n.</pos> <def>The act of
stripping, or depriving; the state of being divested; the deprivation,
or surrender, of possession of property, rights, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divestment</ent><br/
<hw>Di*vest"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
divesting.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divesture</ent><br/
<hw>Di*ves"ture</hw> <pr>(?; 135)</pr>, <pos>n.</pos>
<def>Divestiture.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divet</ent><br/
<hw>Div"et</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Divot</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dividable</ent><br/
<hw>Di*vid"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From
<er>Divide</er>.]</ety> <sn>1.</sn> <def>Capable of being divided;
divisible.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Divided; separated; parted.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dividant</ent><br/
<hw>Di*vid"ant</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Different;
distinct.</def> <mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divide</ent><br/
<hw>Di*vide"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Divided</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Dividing</conjf>.]</vmorph> <ety>[L. <ets>dividere</ets>,
<ets>divisum</ets>; <ets>di-</ets> = <ets>dis-</ets> + root signifying
<ets>to part</ets>; cf. Skr. <ets>vyadh</ets> to pierce; perh. akin to
L. <ets>vidua</ets> widow, and E. <ets>widow</ets>. Cf. <er>Device</er>,
<er>Devise</er>.]</ety> <sn>1.</sn> <def>To part asunder (a whole); to
sever into two or more parts or pieces; to sunder; to separate into
parts.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Divide</qex> the living child in two.</q> <rj><qau>1 Kings
iii. 25.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To cause to be separate; to keep apart by a
partition, or by an imaginary line or limit; <as>as, a wall
<ex>divides</ex> two houses; a stream <ex>divides</ex> the
towns.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Let it <qex>divide</qex> the waters from the waters.</q>
<rj><qau>Gen. i. 6.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To make partition of among a number; to apportion,
as profits of stock among proprietors; to give in shares; to distribute;
to mete out; to share.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>True justice unto people to <qex>divide</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Ye shall <qex>divide</qex> the land by lot.</q> <rj><qau>Num.
xxxiii. 54.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To disunite in opinion or interest; to make
discordant or hostile; to set at variance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If a kingdom be <qex>divided</qex> against itself, that kingdom
can not stand.</q> <rj><qau>Mark iii. 24.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Every family became now <qex>divided</qex> within itself.</q>
<rj><qau>Prescott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To separate into two parts, in order to ascertain
the votes for and against a measure; <as>as, to <ex>divide</ex> a
legislative house upon a question</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Math.)</fld> <def>To subject to arithmetical
division.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Logic)</fld> <def>To separate into species; -- said
of a genus or generic term.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <fld>(Mech.)</fld> <def>To mark divisions on; to
graduate; <as>as, to <ex>divide</ex> a sextant</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <fld>(Music)</fld> <def>To play or sing in a florid
style, or with variations.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj></p>

<p><syn><b>Syn.</b> -- To sever; dissever; sunder; cleave; disjoin;
disunite; detach; disconnect; part; distribute; share.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divide</ent><br/
<hw>Di*vide"</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To be separated; to
part; to open; to go asunder.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The Indo-Germanic family <qex>divides</qex> into three groups.</q>
<rj><qau>J. Peile.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To cause separation; to disunite.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A gulf, a strait, the sea intervening between islands,
<qex>divide</qex> less than the matted forest.</q>
<rj><qau>Bancroft.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To break friendship; to fall out.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To have a share; to partake.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To vote, as in the British Parliament, by the
members separating themselves into two parties (as on opposite sides of
the hall or in opposite lobbies), that is, the <xex>ayes</xex> dividing
from the <xex>noes</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The emperors sat, voted, and <qex>divided</qex> with their
equals.</q> <rj><qau>Gibbon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divide</ent><br/
<hw>Di*vide"</hw>, <pos>n.</pos> <def>A dividing ridge of land between
the tributaries of two streams; also called <altname>watershed</altname>
and <altname>water parting</altname>. A divide on either side of which
the waters drain into two different oceans is called a
<stype>continental divide</stype>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Divided</ent><br/
<hw>Di*vid"ed</hw>, <pos>a.</pos> <sn>1.</sn> <def>Parted; disunited;
distributed.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>Cut into distinct parts, by
incisions which reach the midrib; -- said of a leaf.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dividedly</ent><br/
<hw>Di*vid"ed*ly</hw>, <pos>adv.</pos> <def>Separately; in a divided
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dividend</ent><br/
<hw>Div"i*dend</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>dividendum</ets> thing to be divided, neut. of the gerundive of
<ets>dividere</ets>: cf. F. <ets>dividende</ets>.]</ety> <sn>1.</sn>
<def>A sum of money to be divided and distributed; the share of a sum
divided that falls to each individual; a distribute sum, share, or
percentage; -- applied to the profits as appropriated among
shareholders, and to assets as apportioned among creditors; <as>as, the
<ex>dividend</ex> of a bank, a railway corporation, or a bankrupt
estate</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Math.)</fld> <def>A number or quantity which is to
be divided.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divident</ent><br/
<hw>Div"i*dent</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Dividend;
share.</def> <mark>[Obs.]</mark> <rj><au>Foxe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divider</ent><br/
<hw>Di*vid"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who,
or that which, divides; that which separates anything into
parts.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who deals out to each his share.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Who made me a judge or a <qex>divider</qex> over you?</q>
<rj><qau>Luke xii. 14.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>One who, or that which, causes division.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Hate is of all things the mightiest <qex>divider</qex>.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Money, the great <qex>divider</qex> of the world.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <pluf>pl.</pluf> <def>An instrument for dividing lines,
describing circles, etc., compasses. See <er>Compasses</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The word <xex>dividers</xex> is usually applied to the
instrument as made for the use of draughtsmen, etc.;
<xex>compasses</xex> to the coarser instrument used by
carpenters.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>a vertical structure that divides or separates (as a
wall divides one room from another).</def> <note>The structure may be a
wall with an opening in it to allow seeing one part of the room from the
other. This term is also used to designate a semitransparent curtain
formed by hanging multiple strings of various materials from a ceiling,
intended to visually partition a room without inhibiting passage between
the partitions</note><br/
<syn><b>Syn. --</b> partition, room divider.</syn><br/
[<source>WordNet 1.5</source> <source>PJC</source>]</p>

<p><ent>Dividing</ent><br/
<hw>Di*vid"ing</hw> <pr>(?)</pr>, <pos>a.</pos> <def>That divides;
separating; marking divisions; graduating.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dividing engine</b></col>, <cd>a machine for graduating
circles (as for astronomical instruments) or bars (as for scales); also,
for spacing off and cutting teeth in wheels.</cd> -- <col><b>Dividing
sinker</b></col>. <fld>(Knitting Mach.)</fld>. <cd>See under
<er>Sinker</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dividingly</ent><br/
<hw>Di*vid"ing*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>By
division.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divi-divi</ent><br/
\'d8<hw>Di"vi-di"vi</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Native
name.]</ety> <fld>(Bot.)</fld> <def>A small tree of tropical America
(<spn>C<ae/salpinia coriaria</spn>), whose legumes contain a large
proportion of tannic and gallic acid, and are used by tanners and
dyers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dividual</ent><br/
<hw>Di*vid"u*al</hw> <pr>(?; 135)</pr>, <pos>a.</pos> <ety>[See
<er>Dividuous</er>.]</ety> <def>Divided, shared, or participated in, in
common with others.</def> <mark>[R.]</mark>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dividually</ent><br/
<hw>Di*vid"u*al*ly</hw>, <pos>adv.</pos> <def>By dividing.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dividuous</ent><br/
<hw>Di*vid"u*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>dividuus</ets> divisible, divided, fr. <ets>dividere</ets>.]</ety>
<def>Divided; dividual.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He so often substantiates distinctions into <qex>dividuous</qex>,
selfsubsistent.</q> <rj><qau>Coleridge.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divination</ent><br/
<hw>Div`i*na"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>divinatio</ets>, fr. <ets>divinare</ets>, <ets>divinatum</ets>, to
foresee, foretell, fr. <ets>divinus</ets>: cf. F. <ets>divination</ets>.
See <er>Divine</er>.]</ety> <sn>1.</sn> <def>The act of divining; a
foreseeing or foretelling of future events; the pretended art
discovering secret or future by preternatural means.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There shall not be found among you any one that . . . useth
<qex>divination</qex>, or an observer of times, or an enchanter.</q>
<rj><qau>Deut. xviii. 10.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Among the ancient heathen philosophers
<xex>natural</xex> divination was supposed to be effected by a divine
afflatus; <xex>artificial</xex> divination by certain rites, omens, or
appearances, as the flight of birds, entrails of animals,
etc.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An indication of what is future or secret; augury
omen; conjectural presage; prediction.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Birds which do give a happy <qex>divination</qex> of things to
come.</q> <rj><qau>Sir T. North.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divinator</ent><br/
<hw>Div"i*na`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. See
<er>Divination</er>.]</ety> <def>One who practices or pretends to
divination; a diviner.</def> <mark>[R.]</mark>
<rj><au>Burton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divinatory</ent><br/
<hw>Di*vin"a*to*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>divinatoire</ets>.]</ety> <def>Professing, or relating to,
divination.</def> <ldquo/A natural <xex>divinatory</xex>
instinct.<rdquo/ <rj><au>Cowley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divine</ent><br/
<hw>Di*vine"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Compar.
<er>Diviner</er> <pr>(<?/)</pr>; <ets>superl</ets>.
<er>Divinest</er>.]</ety> <ety>[F. <ets>divin</ets>, L.
<ets>divinus</ets> divine, divinely inspired, fr. <ets>divus</ets>,
<ets>dius</ets>, belonging to a deity; akin to Gr. <?/, and L.
<ets>deus</ets>, God. See <er>Deity</er>.]</ety> <sn>1.</sn> <def>Of or
belonging to God; <as>as, <ex>divine</ex> perfections; the
<ex>divine</ex> will.</as></def> <ldquo/The immensity of the
<xex>divine</xex> nature.<rdquo/ <rj><au>Paley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Proceeding from God; <as>as, <ex>divine</ex>
judgments</as>.</def> <ldquo/<xex>Divine</xex> protection.<rdquo/
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Appropriated to God, or celebrating his praise;
religious; pious; holy; <as>as, <ex>divine</ex> service; <ex>divine</ex>
songs; <ex>divine</ex> worship.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Pertaining to, or proceeding from, a deity;
partaking of the nature of a god or the gods.</def> <ldquo/The
<xex>divine</xex> Apollo said.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Godlike; heavenly; excellent in the highest degree;
supremely admirable; apparently above what is human. In this
application, the word admits of comparison; <as>as, the
<ex>divinest</ex> mind</as>.</def> <au>Sir J. Davies.</au> <ldquo/The
<xex>divine</xex> Desdemona.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>divine</qex> sentence is in the lips of the king.</q>
<rj><qau>Prov. xvi. 10.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>But not to one in this benighted age<br/
Is that <qex>diviner</qex> inspiration given.</q>
<rj><qau>Gray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Presageful; foreboding; prescient.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Yet oft his heart, <qex>divine</qex> of something ill,<br/
Misgave him.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>Relating to divinity or theology.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Church history and other <qex>divine</qex> learning.</q>
<rj><qau>South.</qau></rj></p>

<p><syn><b>Syn.</b> -- Supernatural; superhuman; godlike; heavenly;
celestial; pious; holy; sacred; pre<eum/minent.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divine</ent><br/
<hw>Di*vine"</hw>, <pos>n.</pos> <ety>[L. <ets>divinus</ets> a
soothsayer, LL., a theologian. See <er>Divine</er>, <pos>a.</pos>]</ety>
<sn>1.</sn> <def>One skilled in divinity; a theologian.</def>
<ldquo/Poets were the first <xex>divines</xex>.<rdquo/
<rj><au>Denham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A minister of the gospel; a priest; a
clergyman.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The first <qex>divines</qex> of New England were surpassed by none
in extensive erudition.</q> <rj><qau>J. Woodbridge.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divine</ent><br/
<hw>Di*vine"</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Divined</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Divining</conjf>.]</vmorph> <ety>[L. <ets>divinare</ets>: cf. F.
<ets>deviner</ets>. See <er>Divination</er>.]</ety> <sn>1.</sn> <def>To
foresee or foreknow; to detect; to anticipate; to conjecture.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A sagacity which <qex>divined</qex> the evil designs.</q>
<rj><qau>Bancroft.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To foretell; to predict; to presage.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Darest thou . . . <qex>divine</qex> his downfall?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To render divine; to deify.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Living on earth like angel new <qex>divined</qex>.</q>
<rj><qau>Spenser.</qau></rj></p>

<p><syn><b>Syn.</b> -- To foretell; predict; presage; prophesy;
prognosticate; forebode; guess; conjecture; surmise.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divine</ent><br/
<hw>Di*vine"</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To use or practice
divination; to foretell by divination; to utter
prognostications.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The prophets thereof <qex>divine</qex> for money.</q>
<rj><qau>Micah iii. 11.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To have or feel a presage or foreboding.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Suggest but truth to my <qex>divining</qex> thoughts.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To conjecture or guess; <as>as, to <ex>divine</ex>
rightly</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divinely</ent><br/
<hw>Di*vine"ly</hw>, <pos>adv.</pos> <sn>1.</sn> <def>In a divine or
godlike manner; holily; admirably or excellently in a supreme
degree.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Most <qex>divinely</qex> fair.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>By the agency or influence of God.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Divinely</qex> set apart . . . to be a preacher of
righteousness.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divinement</ent><br/
<hw>Di*vine"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Divination.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divineness</ent><br/
<hw>Di*vine"ness</hw>, <pos>n.</pos> <def>The quality of being divine;
superhuman or supreme excellence.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diviner</ent><br/
<hw>Di*vin"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who
professes divination; one who pretends to predict events, or to reveal
occult things, by supernatural means.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>diviners</qex> have seen a lie, and have told false
dreams; they comfort in vain.</q> <rj><qau>Zech. x. 2.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A conjecture; a guesser; one who makes out occult
things.</def> <rj><au>Locke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divineress</ent><br/
<hw>Di*vin"er*ess</hw>, <pos>n.</pos> <def>A woman who divines.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 439 --></p>

<p><ent>Diving</ent><br/
<hw>Div"ing</hw> <pr>(?)</pr>, <pos>a.</pos> <def>That dives or is used
or diving.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Diving beetle</b></col> <fld>(Zool.)</fld>, <cd>any
beetle of the family <fam>Dytiscid<ae/</fam>, which habitually lives
under water; -- called also <altname>water tiger</altname>.</cd> --
<col><b>Diving bell</b></col>, <cd>a hollow inverted vessel, sometimes
bell-shaped, in which men may descend and work under water, respiration
being sustained by the compressed air at the top, by fresh air pumped in
through a tube from above.</cd> -- <col><b>Diving dress</b></col>.
<cd>See <cref>Submarine armor</cref>, under <er>Submarine</er>.</cd> --
<col><b>Diving stone</b></col>, <cd>a kind of jasper.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divinify</ent><br/
<hw>Di*vin"i*fy</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>divinus</ets> divine + <ets>-fy</ets>.]</ety> <def>To render
divine; to deify.</def> <mark>[Obs.]</mark> <ldquo/Blessed and
<xex>divinified</xex> soul.<rdquo/ <rj><au>Parth. Sacra
(1633).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divining</ent><br/
<hw>Di*vin"ing</hw> <pr>(?)</pr>, <pos>a.</pos> <def>That divines; for
divining.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Divining rod</b></col>, <cd>a rod, commonly of witch
hazel, with forked branches, used by those who claim to be able to
discover water or metals under ground by sensing them through such a
rod.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Diviningly</ent><br/
<hw>Di*vin"ing*ly</hw>, <pos>adv.</pos> <def>In a divining
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divinistre</ent><br/
<hw>Div`i*nis"tre</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A diviner.</def>
<mark>[Obs.]</mark> <ldquo/ I am no <xex>divinistre</xex>.<rdquo/
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divinity</ent><br/
<hw>Di*vin"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Divinities</plw> <pr>(#)</pr>.</plu> <ety>[F.
<ets>divinit<eacute/</ets>, L. <ets>divinitas</ets>. See
<er>Divine</er>, <pos>a.</pos>]</ety> <sn>1.</sn> <def>The state of
being divine; the nature or essence of God; deity; godhead.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>When he attributes <qex>divinity</qex> to other things than God,
it is only a <qex>divinity</qex> by way of participation.</q>
<rj><qau>Bp. Stillingfleet.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The Deity; the Supreme Being; God.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This the <qex>divinity</qex> that within us.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A pretended deity of pagans; a false god.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Beastly <qex>divinities</qex>, and droves of gods.</q>
<rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A celestial being, inferior to the supreme God, but
superior to man.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>God . . . employing these subservient <qex>divinities</qex>.</q>
<rj><qau>Cheyne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Something divine or superhuman; supernatural power
or virtue; something which inspires awe.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They say there is <qex>divinity</qex> in odd numbers.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>There's such <qex>divinity</qex> doth hedge a king.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>The science of divine things; the science which
treats of God, his laws and moral government, and the way of salvation;
theology.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Divinity</qex> is essentially the first of the
professions.</q> <rj><qau>Coleridge.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Case divinity</b></col>, <cd>casuistry.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divinity calf</ent><br/
<hw>Di*vin"i*ty calf`</hw> <pr>(?)</pr>. <fld>(Bookbinding)</fld>
<def>Calf stained dark brown and worked without gilding, often used for
theological books.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Divinization</ent><br/
<hw>Div`i*ni*za"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A making
divine.</def> <rj><au>M. Arnold.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divinize</ent><br/
<hw>Div"i*nize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To invest with a
divine character; to deify.</def> <mark>[R.]</mark> <rj><au>M.
Arnold.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Man had <qex>divinized</qex> all those objects of awe.</q>
<rj><qau>Milman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divisibility</ent><br/
<hw>Di*vis`i*bil"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>divisibilit<eacute/</ets>.]</ety> <def>The quality of being
divisible; the property of bodies by which their parts are capable of
separation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Divisibility</qex> . . . is a primary attribute of
matter.</q> <rj><qau>Sir W. Hamilton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divisible</ent><br/
<hw>Di*vis"i*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>divisibilis</ets>, fr. <ets>dividere</ets>: cf. F.
<ets>divisible</ets>. See <er>Divide</er>.]</ety> <def>Capable of being
divided or separated.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Extended substance . . . is <qex>divisible</qex> into parts.</q>
<rj><qau>Sir W. Hamilton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Divisible contract</b></col> <fld>(Law)</fld>, <cd>a
contract containing agreements one of which can be separated from the
other.</cd> -- <col><b>Divisible offense</b></col> <fld>(Law)</fld>,
<cd>an offense containing a lesser offense in one of a greater grade, so
that on the latter there can be an acquittal, while on the former there
can be a conviction.</cd></cs></p>

<p>-- <wordforms><wf>Di*vis"i*ble*ness</wf>, <pos>n.</pos> --
<wf>Di*vis"i*bly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divisible</ent><br/
<hw>Di*vis"i*ble</hw>, <pos>n.</pos> <def>A divisible substance.</def>
<rj><au>Glanvill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Division</ent><br/
<hw>Di*vi"sion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>division</ets>, L. <ets>divisio</ets>, from <ets>dividere</ets>.
See <er>Divide</er>.]</ety> <sn>1.</sn> <def>The act or process of
diving anything into parts, or the state of being so divided;
separation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I was overlooked in the <qex>division</qex> of the spoil.</q>
<rj><qau>Gibbon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which divides or keeps apart; a
partition.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The portion separated by the divining of a mass or
body; a distinct segment or section.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Communities and <qex>divisions</qex> of men.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Disunion; difference in opinion or feeling; discord;
variance; alienation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There was a <qex>division</qex> among the people.</q>
<rj><qau>John vii. 43.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Difference of condition; state of distinction;
distinction; contrast.</def> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I will put a <qex>division</qex> between my people and thy
people.</q> <rj><qau>Ex. viii. 23.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Separation of the members of a deliberative body,
esp. of the Houses of Parliament, to ascertain the vote.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The motion passed without a <qex>division</qex>.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Math.)</fld> <def>The process of finding how many
times one number or quantity is contained in another; the reverse of
<xex>multiplication</xex>; also, the rule by which the operation is
performed.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <fld>(Logic)</fld> <def>The separation of a genus into
its constituent species.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <fld>(Mil.)</fld> <sd>(a)</sd> <def>Two or more brigades
under the command of a general officer.</def> <sd>(b)</sd> <def>Two
companies of infantry maneuvering as one subdivision of a
battalion.</def> <sd>(c)</sd> <def>One of the larger districts into
which a country is divided for administering military affairs.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <fld>(Naut.)</fld> <def>One of the groups into which a
fleet is divided.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>11.</sn> <fld>(Mus.)</fld> <def>A course of notes so running into
each other as to form one series or chain, to be sung in one breath to
one syllable.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>12.</sn> <fld>(Rhet.)</fld> <def>The distribution of a discourse
into parts; a part so distinguished.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>13.</sn> <fld>(Biol.)</fld> <def>A grade or rank in
classification; a portion of a tribe or of a class; or, in some recent
authorities, equivalent to a subkingdom.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Cell division</b></col> <fld>(Biol.)</fld>, <cd>a method
of cell increase, in which new cells are formed by the division of the
parent cell. In this process, the cell nucleus undergoes peculiar
differentiations and changes, as shown in the figure (see also
<er>Karyokinesis</er>). At the same time the protoplasm of the cell
becomes gradually constricted by a furrow transverse to the long axis of
the nuclear spindle, followed, on the completion of the division of the
nucleus, by a separation of the cell contents into two masses, called
the <xex>daughter cells</xex>.</cd> -- <col><b>Long division</b></col>
<fld>(Math.)</fld>, <cd>the process of division when the operations are
mostly written down.</cd> -- <col><b>Short division</b></col>
<fld>(Math.)</fld>, <cd>the process of division when the operations are
mentally performed and only the results written down; -- used
principally when the divisor is not greater than ten or
twelve.</cd></cs></p>

<p><syn><b>Syn.</b> -- compartment; section; share; allotment;
distribution; separation; partition; disjunction; disconnection;
difference; variance; discord; disunion.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divisional</ent><br/
<hw>Di*vi"sion*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>That divides;
pertaining to, making, or noting, a division; <as>as, a
<ex>divisional</ex> line; a <ex>divisional</ex> general; a
<ex>divisional</ex> surgeon of police.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Divisional planes</b></col> <fld>(Geol.)</fld>,
<cd>planes of separation between rock masses. They include
joints.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divisionally</ent><br/
<hw>Di*vi"sion*al*ly</hw>, <pos>adv.</pos> <def>So as to be
divisional.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divisionary</ent><br/
<hw>Di*vi"sion*a*ry</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Divisional.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divisionor</ent><br/
<hw>Di*vi"sion*or</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who divides
or makes division.</def> <mark>[Obs.]</mark>
<rj><au>Sheldon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divisive</ent><br/
<hw>Di*vi"sive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>divisif</ets>.]</ety> <sn>1.</sn> <def>Indicating division or
distribution.</def> <rj><au>Mede.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Creating, or tending to create, division,
separation, or difference.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It [culture] is after all a dainty and <qex>divisive</qex>
quality, and can not reach to the depths of humanity.</q> <rj><qau>J. C.
Shairp.</qau></rj></p>

<p>-- <wordforms><wf>Di*vi"sive*ly</wf>, <pos>adv.</pos> --
<wf>Di*vi"sive*ness</wf>, <pos>n.</pos></wordforms>
<rj><au>Carlyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divisor</ent><br/
<hw>Di*vi"sor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., fr.
<ets>dividere</ets>. See <er>Divide</er>.]</ety> <fld>(Math.)</fld>
<def>The number by which the dividend is divided.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Common divisor</b></col>. <fld>(Math.)</fld> <cd>See
under <er>Common</er>, <pos>a.</pos></cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divorce</ent><br/
<hw>Di*vorce"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>divorce</ets>, L. <ets>divortium</ets>, fr. <ets>divortere</ets>,
<ets>divertere</ets>, to turn different ways, to separate. See
<er>Divert</er>.]</ety> <sn>1.</sn> <fld>(Law)</fld> <sd>(a)</sd> <def>A
legal dissolution of the marriage contract by a court or other body
having competent authority. This is properly a divorce, and called,
technically, divorce <it>a vinculo matrimonii</it>.</def> <ldquo/from
the bond of matrimony.<rdquo/ <sd>(b)</sd> <def>The separation of a
married woman from the bed and board of her husband -- divorce <it>a
mensa et toro</it> (or <it>a mensa et thoro</it>), <ldquo/from bed and
board<rdquo/.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The decree or writing by which marriage is
dissolved.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Separation; disunion of things closely
united.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To make <qex>divorce</qex> of their incorporate league.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>That which separates.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Bill of divorce</b></col>. <cd>See under
<er>Bill</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divorce</ent><br/
<hw>Di*vorce"</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Divorced</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Divorcing</conjf>.]</vmorph> <ety>[Cf. F. <ets>divorcer</ets>.
See <er>Divorce</er>, <pos>n.</pos>]</ety> <sn>1.</sn> <def>To dissolve
the marriage contract of, either wholly or partially; to separate by
divorce.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To separate or disunite; to sunder.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It [a word] was <qex>divorced</qex> from its old sense.</q>
<rj><qau>Earle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To make away; to put away.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Nothing but death<br/
Shall e'er <qex>divorce</qex> my dignities.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divorceable</ent><br/
<hw>Di*vorce"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of
being divorced.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>divorced</ent><br/
<hw>divorced</hw> <pos>adj.</pos> <def>having a marriage legally
terminated and having not remarried.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Divorcee</ent><br/
<hw>Di*vor`cee"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A person
divorced.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divorceless</ent><br/
<hw>Di*vorce"less</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Incapable of
being divorced or separated; free from divorce.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divorcement</ent><br/
<hw>Di*vorce"ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Dissolution of
the marriage tie; divorce; separation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Let him write her a <qex>divorcement</qex>.</q> <rj><qau>Deut.
xxiv. 1.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>divorcement</qex> of our written from our spoken
language.</q> <rj><qau>R. Morris.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divorcer</ent><br/
<hw>Di*vor"cer</hw>, <pos>n.</pos> <def>The person or cause that
produces or effects a divorce.</def> <rj><au>Drummond.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divorcible</ent><br/
<hw>Di*vor"ci*ble</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Divorceable.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divorcive</ent><br/
<hw>Di*vor"cive</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having power to
divorce; tending to divorce.</def> <ldquo/This <xex>divorcive</xex>
law.<rdquo/ <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divot</ent><br/
<hw>Div"ot</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A thin,
oblong turf used for covering cottages, and also for fuel.</def>
<mark>[Scot.]</mark> <rj><au>Simmonds.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Golf)</fld> <def>a small piece of turf gouged out
of the ground by the head of a golf club when making a stroke; <as>as,
all divots should be replaced</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Divulgate</ent><br/
<hw>Di*vul"gate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>divulgatus</ets>, p. p. of <ets>divulgare</ets>. See
<er>Divulge</er>.]</ety> <def>Published.</def> <mark>[Obs.]</mark>
<rj><au>Bale.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divulgate</ent><br/
<hw>Di*vul"gate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To
divulge.</def> <mark>[Obs.]</mark> <rj><au>Foxe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divulgater</ent><br/
<hw>Div"ul*ga`ter</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A
divulger.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divulgation</ent><br/
<hw>Div`ul*ga"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>divulgatio</ets>: cf. F. <ets>divulgation</ets>.]</ety> <def>The
act of divulging or publishing.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Secrecy hath no use than <qex>divulgation</qex>.</q> <rj><qau>Bp.
Hall.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divulge</ent><br/
<hw>Di*vulge"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Divulged</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Divulging</conjf>.]</vmorph> <ety>[F.
<ets>divulguer</ets>, L. <ets>divulgare</ets>; <ets>di- = dis-</ets> +
<ets>vulgare</ets> to spread among the people, from <ets>vulgus</ets>
the common people. See <er>Vulgar</er>.]</ety> <sn>1.</sn> <def>To make
public; to several or communicate to the public; to tell (a secret) so
that it may become generally known; to disclose; -- said of that which
had been confided as a secret, or had been before unknown; <as>as, to
<ex>divulge</ex> a secret</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Divulge not such a love as mine.</q>
<rj><qau>Cowper.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To indicate publicly; to proclaim.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>God . . . marks<br/
The just man, and <qex>divulges</qex> him through heaven.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To impart; to communicate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Which would not be</q><br/
[<source>1913 Webster</source>]</p>

<p><q>To them [animals] made common and <qex>divulged</qex>.</q>
<rj><qau>Milton.</qau></rj></p>

<p><syn><b>Syn.</b> -- To publish; disclose; discover; uncover; reveal;
communicate; impart; tell.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divulge</ent><br/
<hw>Di*vulge"</hw>, <pos>v. i.</pos> <def>To become publicly
known.</def> <mark>[R.]</mark> <ldquo/To keep it from
<xex>divulging</xex>.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Divulsive</ent><br/
<hw>Di*vul"sive</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Tending to pull
asunder, tear, or rend; distracting.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>divvy</ent><br/
<hw>divvy</hw> <pr>(d<icr/v"v<ycr/)</pr>, <pos>n.</pos> <ety>[shortened
from <ets>dividend</ets>.]</ety> <def>a dividend, especially one paid by
a cooperative society.</def> <mark>[British]</mark> <br/
[<source>WordNet 1.5</source>]</p>

<p><ent>divvy</ent><br/
<hw>div"vy</hw> <pr>(d<icr/v"v<ycr/)</pr>, <pos>v. t. & i.</pos>
<ety>[shortened from <ets>divide</ets>.]</ety> <def>divide up among a
group; distribute; -- often followed by <ptcl>up</ptcl>; <as>as,
<ex>divvy</ex> up the proceeds; <ex>divvy</ex> up the loot</as>.</def>
<mark>[Colloq.]</mark><br/
[<source>PJC</source>]</p>

<p><ent>Dixie</ent><br/
<hw>Dix"ie</hw> <pr>(d<icr/ks"<ycr/)</pr>, <pos>prop. n.</pos>
<sn>1.</sn> <def>A colloquial name for the Southern portion of the
United States, esp. during the Civil War.</def> <mark>[U.S.]</mark><br/
<syn><b>Syn. --</b> Dixieland, Dixie Land, the Confederacy, Confederate
States of America, the South.</syn><br/
<syn><b>Syn. --</b> .</syn>
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>a song popular in the Confederate states during the
American Civil War, and still played as a nostalgic anthem by those
patriotic to the American south. It was written by <person>Daniel D.
Emmett</person> in 1859.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>whistle Dixie</b></col> <cd>to talk unrealistically; to
engage in unrealistic or overoptimistic fantasies; <as>as, that ain't
just <ex>whistlin' Dixie</ex></as>.</cd></cs><br/
[<source>PJC</source>]</p>

<p><ent>Dixiecrats</ent><br/
<hw>Dixiecrats</hw> <pos>n.</pos> <def>a former political party in the
US; formed in 1948 by Southern Democrats opposed to the candidacy of
<person>Harry S. Truman</person>.</def><br/
<syn><b>Syn. --</b> States' Rights Democratic Party.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dixieland</ent><br/
<hw>Dixieland</hw> <pos>n.</pos> <def>the 11 southern states that
seceded from the <country>U. S.</country> in 1861.</def><br/
<syn><b>Syn. --</b> Confederacy, Confederate States of America, South,
Dixie.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dizen</ent><br/
<hw>Diz"en</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Dizened</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Dizening</conjf>.]</vmorph> <ety>[Perh. orig., to dress in a
foolish manner, and allied to <ets>dizzy</ets>: but cf. also OE.
<ets>dysyn</ets> (<ets>Palsgrave</ets>) to put tow or flax on a distaff,
<it>i. e.</it>, to dress it. Cf. <er>Distaff</er>.]</ety> <sn>1.</sn>
<def>To dress; to attire.</def> <mark>[Obs.]</mark> <rj><au>Beau. &
Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To dress gaudily; to overdress; to bedizen; to deck
out.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Like a tragedy queen, he has <qex>dizened</qex> her out.</q>
<rj><qau>Goldsmith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To-morrow when the masks shall fall<br/
That <qex>dizen</qex> Nature's carnival.</q>
<rj><qau>Emerson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dizz</ent><br/
<hw>Dizz</hw> <pr>(d<icr/z)</pr>, <pos>v. t.</pos> <ety>[See
<er>Dizzy</er>.]</ety> <def>To make dizzy; to astonish; to puzzle.</def>
<mark>[Obs.]</mark> <rj><au>Gayton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dizzard</ent><br/
<hw>Diz"zard</hw> <pr>(d<icr/z"z<etil/rd)</pr>, <pos>n.</pos> <ety>[See
<er>Dizzy</er>, and cf. <er>Disard</er>.]</ety> <def>A blockhead.
<mark>[Obs.]</mark> <altsp>[Written also <asp>dizard</asp>, and
<asp>disard</asp>.]</altsp></def> -- <wordforms><wf>Diz"zard*ly</wf>,
<pos>adv.</pos> <mark>[Obs.]</mark></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dizzily</ent><br/
<hw>Diz"zi*ly</hw> <pr>(d<icr/z"z<icr/*l<ycr/)</pr>, <pos>adv.</pos>
<def>In a dizzy manner or state.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dizziness</ent><br/
<hw>Diz"zi*ness</hw>, <pos>n.</pos> <ety>[AS. <ets>dysigness</ets>
folly. See <er>Dizzy</er>.]</ety> <def>Giddiness; a whirling sensation
in the head; vertigo.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dizzy</ent><br/
<hw>Diz"zy</hw> <pr>(d<icr/z"z<ycr/)</pr>, <pos>a.</pos>
<amorph>[<pos>Compar.</pos> <adjf>Dizzier</adjf>
<pr>(d<icr/z"z<icr/*<etil/r)</pr>; <pos>superl.</pos>
<adjf>Dizziest</adjf>.]</amorph> <ety>[OE. <ets>dusi</ets>,
<ets>disi</ets>, <ets>desi</ets>, foolish, AS. <ets>dysig</ets>; akin to
LG. <ets>d<uum/sig</ets> dizzy, OD. <ets>deuzig</ets>,
<ets>duyzig</ets>, OHG. <ets>tusig</ets> foolish, OFries.
<ets>dusia</ets> to be dizzy; LG. <ets>dusel</ets> dizziness,
<ets>duselig</ets>, <ets>dusselig</ets>, D. <ets>duizelig</ets>, dizzy,
Dan. <ets>d<oum/sig</ets> drowsy, slepy, <ets>d<oum/se</ets> to make
dull, drowsy, <ets>d<oum/s</ets> dullness, drowsiness, and to AS.
<ets>dw<aemac/s</ets> foolish, G. <ets>thor</ets> fool. <root/71. Cf.
<er>Daze</er>, <er>Doze</er>.]</ety> <sn>1.</sn> <def>Having in the head
a sensation of whirling, with a tendency to fall; vertiginous; giddy;
hence, confused; indistinct.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Alas! his brain was <qex>dizzy</qex>.</q>
<rj><qau>Drayton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Causing, or tending to cause, giddiness or
vertigo.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To climb from the brink of Fleet Ditch by a <qex>dizzy</qex>
ladder.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Without distinct thought; unreflecting; thoughtless;
heedless.</def> <ldquo/The <xex>dizzy</xex> multitude.<rdquo/
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dizzy</ent><br/
<hw>Diz"zy</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Dizzied</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Dizzying</conjf>.]</vmorph> <def>To make dizzy or giddy; to give
the vertigo to; to confuse.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If the jangling of thy bells had not <qex>dizzied</qex> thy
understanding.</q> <rj><qau>Sir W. Scott.</qau></rj></p>

<p><ent>DJ</ent><br/
<hw>DJ</hw> <pr>(d<emac/"j<amac/`)</pr> <pos>n.</pos> <def>same as
<er>disc jockey</er>.</def> <mark>[acronym, capitalized]</mark> <br/
[<source>PJC</source>]</p>

<p><ent>Djerrid</ent><br/
<ent>Djereed</ent><br/
<mhw>\'d8<hw>Djer*eed"</hw> <pr>(?)</pr> <it>or</it> <hw>Djer*rid"</hw>
<pr>(<?/)</pr></mhw>, <pos>n.</pos> <ety>[F. <ets>djerid</ets>, fr. Ar.
See <er>Jereed</er>.]</ety> <sd>(a)</sd> <def>A blunt javelin used in
military games in Moslem countries.</def> <sd>(b)</sd> <def>A game
played with it.</def> <altsp>[Written also <asp>jereed</asp>,
<asp>jerrid</asp>, etc.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>DJIA</ent><br/
<hw>DJIA</hw> <pr>(d<emac/"j<amac/*<imac/`<amac/)</pr>, <pos>n.</pos>
<fld>(Finance)</fld> <def>The <er>Dow Jones Industrial
Average</er>.</def> <mark>[acronym]</mark> <br/
<syn><b>Syn. --</b> DJI, DJIA, Dow, Dow Jones, Dow-Jones Average.</syn>
[<source>PJC</source>]</p>

<p><ent>Djibouti</ent><br/
<hw>Djibouti</hw> <pos>prop. n.</pos> <fld>(Geography)</fld> <def>The
capital <isa>city</isa> of <country>Djibouti</country>. Population
(2000) = 395,000.</def><br/
[<source>PJC</source>]</p>

<p><ent>Djiboutian</ent><br/
<hw>Djiboutian</hw> <pos>prop. adj.</pos> <def>Of or relating to
<country>Djibouti</country> or its people or culture; <as>as,
<ex>Djiboutian</ex> landscape; <ex>Djiboutian</ex>
merchants</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Djiboutian</ent><br/
<hw>Djiboutian</hw> <pos>n.</pos> <def>A native or inhabitant of
<country>Djibouti</country>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>djinny</ent><br/
<ent>djinni</ent><br/
<ent>djinnee</ent><br/
<mhw>\'d8<hw>djin"nee</hw> <hw>djin"ni</hw>, <hw>djin"ny</hw></mhw>
<pr>(j<icr/n"n<emac/)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>djinn</plw> <pr>(j<icr/n)</pr> or <plw>djinns</plw>
<pr>(j<icr/nz)</pr>.</plu> <def>A spirit believed by Muslims to inhabit
the earth and influence mankind by appearing in the form of humans or
animals. Same as <er>djinni</er> and <er>Jinnee</er>. See
<er>Jinnee</er>, <er>Jinn</er>.</def><br/
<syn><b>Syn. --</b> genie, jinn, jinni, jinnee, djinn, djinni.</syn><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><ent>dkg</ent><br/
<hw>dkg</hw> <pos>n.</pos> <def>ten grams.</def>
<mark>[abbr.]</mark><br/
<syn><b>Syn. --</b> dekagram, decagram, dag.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>D-layer</ent><br/
<hw>D-layer</hw> <pos>n.</pos> <def>the lowest region of the ionosphere
(35 to 50 miles up) that reflects low-frequency radio waves.</def><br/
<syn><b>Syn. --</b> D region.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>DNA</ent><br/
<hw>DNA</hw> <pr>(d<emac/"<ecr/n*<amac/`)</pr> <pos>n.</pos>
<fld>(Biochemistry, Genetics)</fld> <def>abbreviation for
<er>deoxyribonucleic acid</er>; -- more commonly used than the full
name. See also <er>RNA</er>.</def> <mark>[acronym]</mark><br/
<syn><b>Syn. --</b> deoxyribonucleic acid, desoxyribonucleic acid,
deoxyribosenucleic acid.</syn><br/
[<source>PJC</source>]</p>

<p><ent>DNA polymerase</ent><br/
<hw>DNA polymerase</hw> <pr>(d<emac/`<ecr/n*<amac/"
p<ocr/*l<icr/m"<etil/r*<amac/s)</pr> <pos>n.</pos> <fld>(Biochemistry,
Genetics)</fld> <def>an enzyme that catalyzes the formation of DNA from
deoxyribonucleoside triphosphates. Cells contain several types of DNA
polymerase, some of which are required for replication of DNA, and are
indispensable for multipliation and division of cells.</def><br/
[<source>PJC</source>]</p>

<p><ent>DNAase</ent><br/
<ent>DNase</ent><br/
<mhw><hw>DNase</hw> <pr>(d<emac/`<ecr/n*<amac/s")</pr>, <hw>DNAase</hw>
<pr>(d<emac/`<ecr/n*<amac/"<amac/s)</pr></mhw> <pos>n.</pos>
<fld>(Biochem.)</fld> <def>any of numerous enzymes that catalyze the
breakdown of DNA into oligonucleotides or mononucleotides.</def><br/
[<source>PJC</source>]</p>

<p><ent>do.</ent><br/
<hw>do.</hw> <pr>(<?/)</pr>, <pos>n.</pos> <def>An abbreviation of
<er>Ditto</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Do</ent><br/
<hw>Do</hw> <pr>(d<omac/)</pr>, <pos>n.</pos> <fld>(Mus.)</fld> <def>A
syllable attached to the first tone of the major diatonic scale for the
purpose of solmization, or solfeggio. It is the first of the seven
syllables used by the Italians as manes of musical tones, and replaced,
for the sake of euphony, the syllable <xex>Ut</xex>, applied to the note
C. In England and America the same syllables are used by many as a scale
pattern, while the tones in respect to absolute pitch are named from the
first seven letters of the alphabet.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>do</ent><br/
<hw>do</hw> <pr>(d<oomac/)</pr>, <pos>v. t. <or/ auxiliary</pos>.
<vmorph>[<pos>imp.</pos> <conjf>did</conjf> <pr>(d<icr/d)</pr>; <pos>p.
p.</pos> <conjf>done</conjf> <pr>(d<ucr/n)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Doing</conjf> <pr>(d<oomac/"<icr/ng)</pr>. This verb,
when transitive, is formed in the indicative, present tense, thus: I
<xex>do</xex>, thou <xex>doest</xex> <pr>(d<oomac/"<ecr/st)</pr> or
<xex>dost</xex> <pr>(d<ucr/st)</pr>, he <xex>does</xex>
<pr>(d<ucr/z)</pr>, <xex>doeth</xex> <pr>(d<oomac/"<ecr/th)</pr>, or
<xex>doth</xex> <pr>(d<ucr/th)</pr>; when auxiliary, the second person
is, thou <xex>dost</xex>. As an independent verb, <xex>dost</xex> is
obsolete or rare, except in poetry. <ldquo/What <xex>dost</xex> thou in
this world?<rdquo/ <au>Milton.</au> The form <xex>doeth</xex> is a verb
unlimited, <xex>doth</xex>, formerly so used, now being the auxiliary
form. The second pers, sing., imperfect tense, is <xex>didst</xex>
<pr>(d<icr/dst)</pr>, formerly <xex>didest</xex>
<pr>(d<icr/d"<ecr/st)</pr>.]</vmorph> <ety>[AS. <ets>d<omac/n</ets>;
akin to D. <ets>doen</ets>, OS. <ets>duan</ets>, OHG. <ets>tuon</ets>,
G. <ets>thun</ets>, Lith. <ets>deti</ets>, OSlav. <ets>d<emac/ti</ets>,
OIr. <ets>d<eacute/nim</ets> I do, Gr. <grk>tiqe`nai</grk> to put, Skr.
<ets>dh<amac/</ets>, and to E. suffix <ets>-dom</ets>, and prob. to L.
<ets>facere</ets> to do, E. <ets>fact</ets>, and perh. to L.
<ets>-dere</ets> in some compounds, as ad<ets>dere</ets> to add,
cre<ets>dere</ets> to trust. <root/65. Cf. <er>Deed</er>, <er>Deem</er>,
<er>Doom</er>, <er>Fact</er>, <er>Creed</er>, <er>Theme</er>.]</ety>
<sn>1.</sn> <def>To place; to put.</def> <mark>[Obs.]</mark>
<rj><au>Tale of a Usurer (about 1330).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To cause; to make; -- with an infinitive.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>My lord Abbot of Westminster <qex>did</qex> do shewe to me late
certain evidences.</q> <rj><qau>W. Caxton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I shall . . . your cloister do make.</q> <rj><qau>Piers
Plowman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A fatal plague which many <qex>did</qex> to die.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>We <qex>do</qex> you to wit [<it>i. e.</it>, We <qex>make</qex>
you to know] of the grace of God bestowed on the churches of
Macedonia.</q> <rj><qau>2 Cor. viii. 1.</qau></rj></p>

<p><note><hand/ We have lost the idiom shown by the citations
(<xex>do</xex> used like the French <xex>faire</xex> or
<xex>laisser</xex>), in which the verb in the infinitive apparently, but
not really, has a passive signification, <it>i. e.</it>, cause . . . to
be made.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To bring about; to produce, as an effect or result;
to effect; to achieve.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The neglecting it may <qex>do</qex> much danger.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He waved indifferently 'twixt <qex>doing</qex> them neither good
not harm.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To perform, as an action; to execute; to transact to
carry out in action; <as>as, to <ex>do</ex> a good or a bad act;
<ex>do</ex> our duty; to <ex>do</ex> what I can.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Six days shalt thou labor and <qex>do</qex> all thy work.</q>
<rj><qau>Ex. xx. 9.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>We did not <qex>do</qex> these things.</q> <rj><qau>Ld.
Lytton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>You can not <qex>do</qex> wrong without suffering wrong.</q>
<rj><qau>Emerson.</qau></rj></p>

<p>Hence: <xex>To do homage</xex>, <xex>honor</xex>, <xex>favor</xex>,
<xex>justice</xex>, etc., to render homage, honor, etc.<br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To bring to an end by action; to perform completely;
to finish; to accomplish; -- a sense conveyed by the construction, which
is that of the past participle <xex>done</xex>.</def> <ldquo/Ere summer
half be <xex>done</xex>.<rdquo/ <ldquo/I have <xex>done</xex>
weeping.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 440 --></p>

<p><sn>6.</sn> <def>To make ready for an object, purpose, or use, as
food by cooking; to cook completely or sufficiently; <as>as, the meat is
<ex>done</ex> on one side only</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>To put or bring into a form, state, or condition,
especially in the phrases, <xex>to do death</xex>, to put to death; to
slay; <xex>to do away</xex> (often do <xex>away with</xex>), to put
away; to remove; <xex>to do on</xex>, to put on; to don; <xex>to do
off</xex>, to take off, as dress; to doff; <xex>to do into</xex>, to put
into the form of; to translate or transform into, as a text.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Done to death</qex> by slanderous tongues.</q> <rj><qau>
Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The ground of the difficulty is <qex>done away</qex>.</q>
<rj><qau> Paley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Suspicions regarding his loyalty were entirely <qex>done
away</qex>.</q> <rj><qau>Thackeray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>do on</qex> our own harness, that we may not; but we must
<qex>do on</qex> the armor of God.</q> <rj><qau> Latimer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Then Jason rose and <qex>did on</qex> him a fair<br/
Blue woolen tunic.</q> <rj><qau> W. Morris (Jason).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Though the former legal pollution be now <qex>done off</qex>, yet
there is a spiritual contagion in idolatry as much to be shunned.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>It [<ldquo/Pilgrim's Progress<rdquo/] has been <qex>done
into</qex> verse: it has been <qex>done into</qex> modern English.</q>
<rj><qau> Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>To cheat; to gull; to overreach.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He was not be <qex>done</qex>, at his time of life, by frivolous
offers of a compromise that might have secured him seventy-five per
cent.</q> <rj><qau> De Quincey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>To see or inspect; to explore; <as>as, to
<ex>do</ex> all the points of interest</as>.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <fld>(Stock Exchange)</fld> <def>To cash or to advance
money for, as a bill or note.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>11.</sn> <def>To perform work upon, about, for, or at, by way of
caring for, looking after, preparing, cleaning, keeping in order, or the
like.</def></p>

<p><q>The sergeants seem to <qex>do</qex> themselves pretty well.</q>
<rj><qau>Harper's Mag.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>12.</sn> <def>To deal with for good and all; to finish up; to
undo; to ruin; to do for.</def> <mark>[Colloq. or Slang]</mark></p>

<p><q>Sometimes they lie in wait in these dark streets, and fracture his
skull, . . . or break his arm, or cut the sinew of his wrist; and that
they call <qex>doing</qex> him.</q> <rj><qau>Charles
Reade.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<note><p><hand/ <sd>(a)</sd> <xex>Do</xex> and <xex>did</xex> are much
employed as auxiliaries, the verb to which they are joined being an
infinitive. As an auxiliary the verb <xex>do</xex> has no participle.
<ldquo/I <xex>do</xex> set my bow in the cloud.<rdquo/ <au>Gen. ix.
13.</au> <mark>[Now archaic or rare except for emphatic
assertion.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Rarely . . . <qex>did</qex> the wrongs of individuals to the
knowledge of the public.</q> <rj><qau> Macaulay.</qau></rj></p>

<p><sd>(b)</sd> They are often used in emphatic construction. <ldquo/You
don't say so, Mr. Jobson. -- but I <xex>do</xex> say so.<rdquo/ <au>Sir
W. Scott.</au> <ldquo/I <xex>did love him</xex>, <xex>but scorn him
now</xex>.<rdquo/ <au>Latham.</au> <sd>(c)</sd> In negative and
interrogative constructions, <xex>do</xex> and <xex>did</xex> are in
common use. I <xex>do</xex> not wish to see them; what <xex>do</xex> you
think? <xex>Did</xex> C<ae/sar cross the Tiber? He <xex>did</xex> not.
<ldquo/<xex>Do</xex> you love me?<rdquo/ <au>Shak.</au> <sd>(d)</sd>
<xex>Do</xex>, as an auxiliary, is supposed to have been first used
before imperatives. It expresses entreaty or earnest request; as,
<xex>do help me</xex>. In the imperative mood, but not in the
indicative, it may be used with the verb <xex>to be</xex>; as, <xex>do
be</xex> quiet. <xex>Do</xex>, <xex>did</xex>, and <xex>done</xex> often
stand as a general substitute or representative verb, and thus save the
repetition of the principal verb. <ldquo/To live and die is all we have
to <xex>do</xex>.<rdquo/ <au>Denham.</au> In the case of <xex>do</xex>
and <xex>did</xex> as auxiliaries, the sense may be completed by the
infinitive (without <xex>to</xex>) of the verb represented. <ldquo/When
beauty lived and died as flowers <xex>do</xex> now.<rdquo/
<au>Shak.</au> <ldquo/I . . . chose my wife as she <xex>did</xex> her
wedding gown.<rdquo/ <rj><au>Goldsmith.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>My brightest hopes giving dark fears a being.<br/
As the light <qex>does</qex> the shadow.</q> <rj><qau>
Longfellow.</qau></rj></p>

<p>In unemphatic affirmative sentences <xex>do</xex> is, for the most
part, archaic or poetical; as, <ldquo/This just reproach their virtue
<xex>does</xex> excite.<rdquo/ <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p></note>

<p><cs><mcol><col><b>To do one's best</b></col>, <col><b>To do one's
diligence</b></col></mcol> (and the like), <cd>to exert one's self; to
put forth one's best or most or most diligent efforts.</cd> <ldquo/We
will . . . <xex>do our</xex> best to gain their assent.<rdquo/
<au>Jowett (Thucyd.).</au> -- <col><b>To do one's business</b></col>,
<cd>to ruin one.</cd> <mark>[Colloq.]</mark> <au>Wycherley.</au> --
<col><b>To do one shame</b></col>, <cd>to cause one shame.</cd>
<mark>[Obs.]</mark> -- <col><b>To do over</b></col>. <sd>(a)</sd> <cd>To
make over; to perform a second time.</cd> <sd>(b)</sd> <cd>To cover; to
spread; to smear.</cd> <ldquo/Boats . . . sewed together and <xex>done
over</xex> with a kind of slimy stuff like rosin.<rdquo/ <au>De
Foe.</au> -- <col><b>To do to death</b></col>, <cd>to put to death.</cd>
(See 7.) <mark>[Obs.]</mark> -- <col><b>To do up</b></col>. <sd>(a)</sd>
<cd>To put up; to raise.</cd> <mark>[Obs.]</mark> <au>Chaucer.</au>
<sd>(b)</sd> <cd>To pack together and envelop; to pack up.</cd>
<sd>(c)</sd> <cd>To accomplish thoroughly.</cd> <mark>[Colloq.]</mark>
<sd>(d)</sd> <cd>To starch and iron.</cd> <ldquo/A rich gown of velvet,
and a ruff <xex>done up</xex> with the famous yellow starch.<rdquo/
<au>Hawthorne.</au> -- <col><b>To do way</b></col>, <cd>to put away; to
lay aside.</cd> <mark>[Obs.]</mark> <au>Chaucer.</au> -- <col><b>To do
with</b></col>, <cd>to dispose of; to make use of; to employ; -- usually
preceded by <xex>what</xex>.</cd> <ldquo/Men are many times brought to
that extremity, that were it not for God they would not know what
<xex>to do with</xex> themselves.<rdquo/ <au>Tillotson.</au> --
<col><b>To have to do with</b></col>, <cd>to have concern, business or
intercourse with; to deal with. When preceded by <xex>what</xex>, the
notion is usually implied that the affair does not concern the person
denoted by the subject of <xex>have</xex>.</cd> <ldquo/Philology
<xex>has to do with</xex> language in its fullest sense.<rdquo/
<au>Earle.</au> <ldquo/What <xex>have</xex> I <xex>to do with</xex> you,
ye sons of Zeruiah?<rdquo/ <au>2 Sam. xvi. 10.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Do</ent><br/
<hw>Do</hw> <pr>(?)</pr>, <pos>v. i.</pos> <sn>1.</sn> <def>To act or
behave in any manner; to conduct one's self.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They fear not the Lord, neither <qex>do</qex> they after . . . the
law and commandment.</q> <rj><qau> 2 Kings xvii. 34.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To fare; to be, as regards health; <as>as, they
asked him how he <ex>did</ex>; how do you <ex>do</ex>
to-day?</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <ety>[Perh. a different word. OE. <ets>dugen</ets>,
<ets>dowen</ets>, to avail, be of use, AS. <ets>dugan</ets>. See
<er>Doughty</er>.]</ety> <def>To succeed; to avail; to answer the
purpose; to serve; <as>as, if no better plan can be found, he will make
this <ex>do</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>You would do well to prefer a bill against all kings and
parliaments since the Conquest; and if that won't <qex>do</qex>;
challenge the crown.</q> <rj><qau> Collier.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<cs><p><col><b>To do by</b></col>. <cd>See under <er>By</er>.</cd> --
<col><b>To do for</b></col>. <sd>(a)</sd> <cd>To answer for; to serve
as; to suit.</cd> <sd>(b)</sd> <cd>To put an end to; to ruin; to baffle
completely; as, a goblet is <xex>done for</xex> when it is broken.</cd>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Some folks are happy and easy in mind when their victim is stabbed
and <qex>done for</qex>.</q> <rj><qau>Thackeray.</qau></rj></p>

<p>-- <col><b>To do withal</b></col>, <cd>to help or prevent it.</cd>
<mark>[Obs.]</mark> <ldquo/I could not do <xex>withal</xex>.<rdquo/
<au>Shak.</au> -- <col><b>To do without</b></col>, <cd>to get along
without; to dispense with.</cd> -- <col><b>To have done</b></col>,
<cd>to have made an end or conclusion; to have finished; to be quit; to
desist.</cd> -- <col><b>To have done with</b></col>, <cd>to have
completed; to be through with; to have no further concern with.</cd> --
<col><b>Well to do</b></col>, <cd>in easy circumstances.</cd><br/
[<source>1913 Webster</source>]</p></cs>

<p><ent>Do</ent><br/
<hw>Do</hw>, <pos>n.</pos> <sn>1.</sn> <def>Deed; act; fear.</def>
<mark>[Obs.]</mark> <rj><au>Sir W. Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Ado; bustle; stir; to do.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>A great deal of <qex>do</qex>, and a great deal of trouble.</q>
<rj><qau> Selden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A cheat; a swindle.</def> <mark>[Slang,
Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doab</ent><br/
\'d8<hw>Do"ab</hw> <pr>(?)</pr>, <ety>[Pers. & Hind.
<ets>do<amac/b</ets>, prop., two waters.]</ety> <def>A tongue or tract
of land included between two rivers; <as>as, the <ex>doab</ex> between
the Ganges and the Jumna</as>.</def> <mark>[India]</mark> <rj><au>Am.
Cyc.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doable</ent><br/
<hw>Do"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of being
done.</def> <rj><au>Carlyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Do-all</ent><br/
<hw>Do"-all`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>General manager;
factotum.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Under him, Dunstan was the <qex>do-all</qex> at court, being the
king's treasurer, councilor, chancellor, confessor, all things.</q>
<rj><qau> Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doand</ent><br/
<hw>Do"and</hw> <pr>(?)</pr>, <pos>p. pr.</pos> <def>Doing.</def>
<mark>[Obs.]</mark> <rj><au>Rom. of R.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doat</ent><br/
<hw>Doat</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>See
<er>Dote</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dobber</ent><br/
<hw>Dob"ber</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<fld>(Zool.)</fld> <def>See <er>Dabchick</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A float to a fishing line.</def> <mark>[Local, U.
S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dobbin</ent><br/
<hw>Dob"bin</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>An old
jaded horse.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Sea gravel mixed with sand.</def> <mark>[Prov.
Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dobby</ent><br/
<hw>Dob"by</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Weaving)</fld> <def>An
apparatus resembling a Jacquard for weaving small figures (usually about
12 - 16 threads, seldom more than 36 - 40 threads).</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Dobchick</ent><br/
<hw>Dob"chick`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>See <er>Dabchick</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dobell's solution</ent><br/
<hw>Do*bell's" so*lu"tion</hw> <pr>(?)</pr>. <fld>(Med.)</fld> <def>An
aqueous solution of carbolic acid, borax, sodium bicarbonate, and
glycerin, used as a spray in diseases of the nose and throat.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Dobson</ent><br/
<hw>Dob"son</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>The
aquatic larva of a large neuropterous insect (<spn>Corydalus
cornutus</spn>), used as bait in angling. See
<er>Hellgamite</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dobule</ent><br/
<hw>Dob"ule</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>The
European dace.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Docent</ent><br/
<hw>Do"cent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>docens</ets>,
<ets>-entis</ets>, p. pr. of <ets>docere</ets> to teach.]</ety>
<def>Serving to instruct; teaching.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Docetae</ent><br/
\'d8<hw>Do*ce"t<ae/</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL., fr.
<?/ to appear.]</ety> <fld>(Eccl. Hist.)</fld> <def>Ancient heretics who
held that Christ's body was merely a phantom or appearance.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Docetic</ent><br/
<hw>Do*cet"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to, held
by, or like, the Docet<ae/.</def> <ldquo/<xex>Docetic</xex>
Gnosticism.<rdquo/ <rj><au> Plumptre.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Docetism</ent><br/
<hw>Doc"e*tism</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Eccl. Hist.)</fld>
<def>The doctrine of the Docet<ae/.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dochmiac</ent><br/
<hw>Doch"mi*ac</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Pros.)</fld>
<def>Pertaining to, or containing, the dochmius.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dochmius</ent><br/
\'d8<hw>Doch"mi*us</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., fr. Gr.
<?/.]</ety> <fld>(Pros.)</fld> <def>A foot of five syllables (usually
<?/ -- -<?/ -).</def></p>

<p><ent>Docibleness</ent><br/
<ent>Docibility</ent><br/
<mhw>{ <hw>Doc`i*bil"i*ty</hw> <pr>(?)</pr>, <hw>Doc"i*ble*ness</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[L.
<ets>docibilitas</ets>.]</ety> <def>Aptness for being taught;
teachableness; docility.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To persons of <qex>docibility</qex>, the real character may be
easily taught in a few days.</q> <rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>docibleness</qex> of dogs in general.</q>
<rj><qau>Walton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Docible</ent><br/
<hw>Doc"i*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>docibilis</ets>, fr. <ets>docere</ets> to teach.]</ety> <def>Easily
taught or managed; teachable.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Docile</ent><br/
<hw>Doc"ile</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>docilis</ets>,fr. <ets>docere</ets> to teach; cf. Gr. <?/, and L.
<ets>discere</ets> to learn, Gr. <?/ learned, <?/ knowing: cf. F.
<ets>docile</ets>. Cf. <er>Doctor</er>, <er>Didactic</er>,
<er>Disciple</er>.]</ety> <sn>1.</sn> <def>Teachable; easy to teach;
docible.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Disposed to be taught; tractable; easily managed;
<as>as, a <ex>docile</ex> child</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The elephant is at once docible and <qex>docile</qex>.</q>
<rj><qau> C. J. Smith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Docility</ent><br/
<hw>Do*cil"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>docilitas</ets>, fr. <ets>docilis</ets>: cf. F.
<ets>docilit<eacute/</ets>.]</ety> <sn>1.</sn> <def>teachableness;
aptness for being taught; docibleness.</def> <mark>[Obs. or
R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Willingness to be taught; tractableness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The humble <qex>docility</qex> of little children is, in the New
Testament, represented as a necessary preparative to the reception of
the Christian faith.</q> <rj><qau> Beattie.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Docimacy</ent><br/
<hw>Doc"i*ma*cy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ an assay,
examination, fr. <?/ to examine (Metals), fr. <?/ assayed, tested, fr.
<?/ to take, approve: cf. F. <ets>docimasie</ets>.]</ety> <def>The art
or practice of applying tests to ascertain the nature, quality, etc., of
objects, as of metals or ores, of medicines, or of facts pertaining to
physiology.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Docimastic</ent><br/
<hw>Doc`i*mas"tic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/: cf. F.
<ets>docimastique</ets>.]</ety> <def>Proving by experiments or
tests.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Docimastic art</b></col>, <cd>metallurgy, or the art of
assaying metals; the art of separating metals from foreign matters, and
determining the nature and quantity of metallic substances contained in
any ore or mineral.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Docimology</ent><br/
<hw>Doc`i*mol"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ a test
+ <ets>-logy</ets>.]</ety> <def>A treatise on the art of testing, as in
assaying metals, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Docity</ent><br/
<hw>Doc"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Teachableness.</def>
<mark>[Prov. Eng. & Local, U. S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dock</ent><br/
<hw>Dock</hw> <pr>(d<ocr/k)</pr>, <pos>n.</pos> <ety>[AS.
<ets>docce</ets>; of uncertain origin; cf. G.
<ets>docken-</ets>bl<aum/tter, Gael. <ets>dogha</ets> burdock, OF.
<ets>doque</ets>; perh. akin to L. <ets>daucus</ets>, <ets>daucum</ets>,
Gr. <?/, <?/, a kind of parsnip or carrot, used in medicine. Cf.
<er>Burdock</er>.]</ety> <fld>(Bot.)</fld> <def>A genus of plants
(<gen>Rumex</gen>), some species of which are well-known weeds which
have a long taproot and are difficult of extermination.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Yellow dock</xex> is <spn>Rumex crispus</spn>, with
smooth curly leaves and yellow root, which that of other species is used
medicinally as an astringent and tonic.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dock</ent><br/
<hw>Dock</hw>, <pos>n.</pos> <ety>[Cf. Icel. <ets>dockr</ets> a short
tail, Fries. <ets>dok</ets> a little bundle or bunch, G.
<ets>docke</ets> bundle, skein, a short and thick column.]</ety>
<sn>1.</sn> <def>The solid part of an animal's tail, as distinguished
from the hair; the stump of a tail; the part of a tail left after
clipping or cutting.</def> <rj><au>Grew.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A case of leather to cover the clipped or cut tail
of a horse.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dock</ent><br/
<hw>Dock</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Docked</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Docking</conjf>.]</vmorph> <ety>[See <er>Dock</er> a tail. Cf. W.
<ets>tociaw</ets>, and <ets>twciaw</ets>, to dock, clip.]</ety>
<sn>1.</sn> <def>to cut off, as the end of a thing; to curtail; to cut
short; to clip; <as>as, to <ex>dock</ex> the tail of a
horse</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His top was <qex>docked</qex> like a priest biforn.</q> <rj><qau>
Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To cut off a part from; to shorten; to deduct from;
to subject to a deduction; <as>as, to <ex>dock</ex> one's
wages</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To cut off, bar, or destroy; <as>as, to
<ex>dock</ex> an entail</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dock</ent><br/
<hw>Dock</hw>, <pos>n.</pos> <ety>[Akin to D. <ets>dok</ets>; of
uncertain origin; cf. LL. <ets>doga</ets> ditch, L. <ets>doga</ets>
ditch, L. <ets>doga</ets> sort of vessel, Gr. <?/ receptacle, fr. <?/ to
receive.]</ety> <sn>1.</sn> <def>An artificial basin or an inclosure in
connection with a harbor or river, -- used for the reception of vessels,
and provided with gates for keeping in or shutting out the
tide.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The slip or water way extending between two piers or
projecting wharves, for the reception of ships; -- sometimes including
the piers themselves; <as>as, to be down on the
<ex>dock</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The place in court where a criminal or accused
person stands.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Balance dock</b></col>, <cd>a kind of <cref>floating
dock</cref> which is kept level by pumping water out of, or letting it
into, the compartments of side chambers.</cd> -- <col><b>Dry
dock</b></col>, <cd>a dock from which the water may be shut or pumped
out, especially, one in the form of a chamber having walls and floor,
often of masonry and communicating with deep water, but having
appliances for excluding it; -- used in constructing or repairing ships.
The name includes structures used for the examination, repairing, or
building of vessels, as <xex>graving docks</xex>, <xex>floating
docks</xex>, <xex>hydraulic docks</xex>, etc.</cd> -- <col><b>Floating
dock</b></col>, <cd>a dock which is made to become buoyant, and, by
floating, to lift a vessel out of water.</cd> -- <col><b>Graving
dock</b></col>, <cd>a dock for holding a ship for graving or cleaning
the bottom, etc.</cd> -- <col><b>Hydraulic dock</b></col>, <cd>a dock in
which a vessel is raised clear of the water by hydraulic presses.</cd>
-- <col><b>Naval dock</b></col>, <cd>a dock connected with which are
naval stores, materials, and all conveniences for the construction and
repair of ships.</cd> -- <col><b>Sectional dock</b></col>, <cd>a form of
<cref>floating dock</cref> made in separate sections or caissons.</cd>
-- <col><b>Slip dock</b></col>, <cd>a dock having a sloping floor that
extends from deep water to above high-water mark, and upon which is a
railway on which runs a cradle carrying the ship.</cd> -- <col><b>Wet
dock</b></col>, <cd>a dock where the water is shut in, and kept at a
given level, to facilitate the loading and unloading of ships; -- also
sometimes used as a place of safety; a basin.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dock</ent><br/
<hw>Dock</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To draw, law, or place
(a ship) in a dock, for repairing, cleaning the bottom, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dockage</ent><br/
<hw>Dock"age</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A charge for the use
of a dock.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dock-cress</ent><br/
<hw>Dock"-cress`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>Nipplewort.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>docker</ent><br/
<hw>docker</hw> <pos>n.</pos> <def>a laborer who loads and unloads
vessels in a port.</def><br/
<syn><b>Syn. --</b> stevedore, loader, longshoreman, dockhand, dock
worker, dock-walloper, lumper.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Docket</ent><br/
<hw>Dock"et</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Dock</ets> to
cut off + dim. suffix <ets>-et</ets>.]</ety> <sn>1.</sn> <def>A small
piece of paper or parchment, containing the heads of a writing; a
summary or digest.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A bill tied to goods, containing some direction, as
the name of the owner, or the place to which they are to be sent; a
label.</def> <rj><au>Bailey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Law)</fld> <sd>(a)</sd> <def>An abridged entry of a
judgment or proceeding in an action, or register or such entries; a book
of original, kept by clerks of courts, containing a formal list of the
names of parties, and minutes of the proceedings, in each case in
court.</def> <sd>(b)</sd> (<mark>U. S.</mark>) <def>A list or calendar
of causes ready for hearing or trial, prepared for the use of courts by
the clerks.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A list or calendar of business matters to be acted
on in any assembly.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>On the docket</b></col>, <cd>in hand; in the plan; under
consideration; in process of execution or performance.</cd>
<mark>[Colloq.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Docket</ent><br/
<hw>Dock"et</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Docketed</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Docketing</conjf>.]</vmorph> <sn>1.</sn> <def>To make a brief
abstract of (a writing) and indorse it on the back of the paper, or to
indorse the title or contents on the back of; to summarize; <as>as, to
<ex>docket</ex> letters and papers</as>.</def>
<rj><au>Chesterfield.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <sd>(a)</sd> <def>To make a brief
abstract of and inscribe in a book; <as>as, judgments regularly
<ex>docketed</ex></as>.</def> <sd>(b)</sd> <def>To enter or inscribe in
a docket, or list of causes for trial.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To mark with a ticket; <as>as, to <ex>docket</ex>
goods</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>dockhand</ent><br/
<hw>dockhand</hw> <pos>n.</pos> <def>a laborer who loads and unloads
vessels in a port.</def><br/
<syn><b>Syn. --</b> stevedore, loader, longshoreman, docker, dock
worker, dock-walloper, lumper.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>docking</ent><br/
<hw>docking</hw> <pos>n.</pos> <sn>1.</sn> <fld>(Naut.)</fld> <def>a act
of securing an arriving vessel with ropes or anchors.</def><br/
<syn><b>Syn. --</b> mooring, tying up, dropping anchor.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <fld>(Astronautics)</fld> <def>the coming together and
joining of two space vehicles. The joining usually is accomplished by
bringing special connecting devices, the docking ports, into contact,
and fastening the ships together by clamping devices. The docking ports
are often fitted so as to allow a passage to be opened between the two
space vehicles, and thus to permit transfer of materials or personnel
between them.</def><br/
[<source>PJC</source>]</p>

<p><ent>dock-walloper</ent><br/
<hw>dock-walloper</hw> <pos>n.</pos> <def>a laborer who loads and
unloads vessels in a port.</def><br/
<syn><b>Syn. --</b> stevedore, loader, longshoreman, docker, dockhand,
dock worker, lumper.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>dockyard</ent><br/
<hw>dock"yard`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A yard or storage
place for all sorts of naval stores and timber for
shipbuilding.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Docoglossa</ent><br/
\'d8<hw>Doc`o*glos"sa</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
fr. Gr. <?/ a beam + <?/ the tongue.]</ety> <fld>(Zool.)</fld> <def>An
order of gastropods, including the true limpets, and having the teeth on
the odontophore or lingual ribbon.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>docquet</ent><br/
<hw>doc"quet</hw> <pr>(?)</pr>, <pos>n. & v.</pos> <def>See
<er>Docket</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>doctor</ent><br/
<hw>doc"tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>doctur</ets>, L. <ets>doctor</ets>, teacher, fr. <ets>docere</ets>
to teach. See <er>Docile</er>.]</ety> <sn>1.</sn> <def>A teacher; one
skilled in a profession, or branch of knowledge; a learned man.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>One of the <qex>doctors</qex> of Italy, Nicholas Macciavel.</q>
<rj><qau> Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An academical title, originally meaning a man so
well versed in his department as to be qualified to teach it. Hence: One
who has taken the highest degree conferred by a university or college,
or has received a diploma of the highest degree; <as>as, a
<ex>doctor</ex> of divinity, of law, of medicine, of music, or of
philosophy</as>. Such diplomas may confer an honorary title
only.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>One duly licensed to practice medicine; a member of
the medical profession; a physician.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>By medicine life may be prolonged, yet death<br/
Will seize the <qex>doctor</qex> too.</q> <rj><qau> Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Any mechanical contrivance intended to remedy a
difficulty or serve some purpose in an exigency; <as>as, the
<ex>doctor</ex> of a calico-printing machine, which is a knife to remove
superfluous coloring matter; the <ex>doctor</ex>, or auxiliary engine,
called also <stype>donkey engine</stype>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Zool.)</fld> <def>The friar skate.</def>
<mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Doctors' Commons</b></col>. <cd>See under
<er>Commons</er>.</cd> -- <col><b>Doctor's stuff</b></col>, <cd>physic,
medicine.</cd> <au>G. Eliot.</au> -- <col><b>Doctor fish</b></col>
<fld>(Zool.)</fld>, <cd>any fish of the genus <gen>Acanthurus</gen>; the
surgeon fish; -- so called from a sharp lancetlike spine on each side of
the tail. Also called <altname>barber fish</altname>. See <er>Surgeon
fish</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doctor</ent><br/
<hw>Doc"tor</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Doctored</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Doctoring</conjf>.]</vmorph> <sn>1.</sn> <def>To treat as a
physician does; to apply remedies to; to repair; <as>as, to
<ex>doctor</ex> a sick man or a broken cart</as>.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To confer a doctorate upon; to make a
doctor.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To tamper with and arrange for one's own purposes;
to falsify; to adulterate; <as>as, to <ex>doctor</ex> election returns;
to <ex>doctor</ex> whisky.</as></def> <mark>[Slang]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doctor</ent><br/
<hw>Doc"tor</hw>, <pos>v. i.</pos> <def>To practice physic.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doctoral</ent><br/
<hw>Doc"tor*al</hw>, <pos>a.</pos> <ety>[Cf. F.
<ets>doctoral</ets>.]</ety> <def>Of or relating to a doctor, or to the
degree of doctor.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Doctoral</qex> habit and square cap.</q> <rj><qau>
Wood.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doctorally</ent><br/
<hw>Doc"tor*al*ly</hw>, <pos>adv.</pos> <def>In the manner of a
doctor.</def><mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 441 --></p>

<p><ent>Doctorate</ent><br/
<hw>Doc"tor*ate</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>doctorat</ets>.]</ety> <def>The degree, title, or rank, of a
doctor.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doctorate</ent><br/
<hw>Doc"tor*ate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To make (one) a
doctor.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He was bred . . . in Oxford and there <qex>doctorated</qex>.</q>
<rj><qau> Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doctoress</ent><br/
<hw>Doc"tor*ess</hw>, <pos>n.</pos> <def>A female
doctor.</def><mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doctorly</ent><br/
<hw>Doc"tor*ly</hw>, <pos>a.</pos> <def>Like a doctor or learned
man.</def> <mark>[Obs.]</mark> <ldquo/<xex>Doctorly</xex>
prelates.<rdquo/ <rj><au>Foxe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doctorship</ent><br/
<hw>Doc"tor*ship</hw>, <pos>n.</pos> <def>Doctorate.</def>
<mark>[R.]</mark> <rj><au>Clarendon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doctress</ent><br/
<hw>Doc"tress</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A female
doctor.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doctrinable</ent><br/
<hw>Doc"tri*na*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of the nature
of, or constituting, doctrine.</def> <mark>[Obs.]</mark> <rj><au>Sir P.
Sidney.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doctrinaire</ent><br/
\'d8<hw>Doc`tri*naire"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. See
<er>Doctrine</er>.]</ety> <def>One who would apply to political or other
practical concerns the abstract doctrines or the theories of his own
philosophical system; a propounder of a new set of opinions; a dogmatic
theorist. Used also adjectively; <as>as, <ex>doctrinaire</ex>
notions</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In french history, the <xex>Doctrinaires</xex> were a
constitutionalist party which originated after the restoration of the
Bourbons, and represented the interests of liberalism and progress.
After the Revolution of July, 1830, when they came into power, they
assumed a conservative position in antagonism with the republicans and
radicals.</note> <rj><au>Am. Cyc.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>doctrinal</ent><br/
<hw>doc"tri*nal</hw> <pr>(d<ocr/k"tr<icr/*n<ait/l)</pr>, <pos>a.</pos>
<ety>[LL. <ets>doctrinalis</ets>, fr. L. <ets>doctrina</ets>: cf. F.
<ets>doctrinal</ets>. See <er>Doctrine</er>.]</ety> <sn>1.</sn>
<def>Pertaining to, or containing, doctrine or something taught and to
be believed; <as>as, a <ex>doctrinal</ex> observation</as>.</def>
<ldquo/<xex>Doctrinal</xex> clauses.<rdquo/
<rj><au>Macaulay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Pertaining to, or having to do with,
teaching.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The word of God serveth no otherwise than in the nature of a
<qex>doctrinal</qex> instrument.</q> <rj><qau> Hooker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doctrinal</ent><br/
<hw>Doc"tri*nal</hw>, <pos>n.</pos> <def>A matter of doctrine; also, a
system of doctrines.</def> <rj><au>T. Goodwin. Sir T.
Elyot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doctrinally</ent><br/
<hw>Doc"tri*nal*ly</hw>, <pos>adv.</pos> <def>In a doctrinal manner or
form; by way of teaching or positive direction.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doctrinarian</ent><br/
<hw>Doc"tri*na"ri*an</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A
doctrinaire.</def> <rj><au>J. H. Newman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doctrinarianism</ent><br/
<hw>Doc`tri*na"ri*an*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The
principles or practices of the Doctrinaires.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>doctrine</ent><br/
<hw>doc"trine</hw> <pr>(d<ocr/k"tr<icr/n)</pr>, <pos>n.</pos> <ety>[F.
<ets>doctrine</ets>, L. <ets>doctrina</ets>, fr. <ets>doctor</ets>. See
<er>Doctor</er>.]</ety> <sn>1.</sn> <def>Teaching;
instruction.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He taught them many things by parables, and said unto them in his
<qex>doctrine</qex>, Hearken.</q> <rj><qau> Mark iv. 2.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is taught; what is held, put forth as
true, and supported by a teacher, a school, or a sect; a principle or
position, or the body of principles, in any branch of knowledge; any
tenet or dogma; a principle of faith; <as>as, the <ex>doctrine</ex> of
atoms; the <ex>doctrine</ex> of chances.</as></def> <ldquo/The
<xex>doctrine</xex> of gravitation.<rdquo/ <rj><au>I.
Watts.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Articles of faith and <qex>doctrine</qex>.</q> <rj><qau>
Hooker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>The Monroe doctrine</b></col> <fld>(Politics)</fld>,
<cd>a policy enunciated by President Monroe (Message, Dec. 2, 1823), the
essential feature of which is that the United States will regard as an
unfriendly act any attempt on the part of European powers to extend
their systems on this continent, or any interference to oppress, or in
any manner control the destiny of, governments whose independence had
been acknowledged by the United States.</cd></cs></p>

<p><syn><b>Syn.</b> -- Precept; tenet; principle; maxim; dogma.</syn>
<usage>-- <er>Doctrine</er>, <er>Precept</er>. <xex>Doctrine</xex>
denotes whatever is recommended as a speculative truth to the belief of
others. <xex>Precept</xex> is a rule down to be obeyed.
<xex>Doctrine</xex> supposes a teacher; <xex>precept</xex> supposes a
superior, with a right to command. The <xex>doctrines</xex> of the
Bible; the <xex>precepts</xex> of our holy religion.</usage><br/
[<source>1913 Webster</source>]</p>

<p><q>Unpracticed he to fawn or seek for power<br/
By <qex>doctrines</qex> fashioned to the varying hour.</q> <rj><qau>
Goldsmith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>docudrama</ent><br/
<hw>docudrama</hw> <pos>n.</pos> <def>a film or TV program presenting
the facts about a person or event.</def><br/
<syn><b>Syn. --</b> documentary, documentary film,
infotainment.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>document</ent><br/
<hw>doc"u*ment</hw> <pr>(d<ocr/k"<usl/*m<eit/nt)</pr>, <pos>n.</pos>
<ety>[LL. <ets>documentum</ets>, fr. <ets>docere</ets> to teach: cf. F.
<ets>document</ets>. See <er>Docile</er>.]</ety> <sn>1.</sn> <def>That
which is taught or authoritatively set forth; precept; instruction;
dogma.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Learners should not be too much crowded with a heap or multitude
of <qex>documents</qex> or ideas at one time.</q> <rj><qau> I.
Watts.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An example for instruction or warning.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>They were forth with stoned to death, as a <qex>document</qex> to
others.</q> <rj><qau> Sir W. Raleigh.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>An original or official paper relied upon as the
basis, proof, or support of anything else; -- in its most extended
sense, including any writing, book, or other instrument conveying
information in the case; any material substance on which the thoughts of
men are represented by any species of conventional mark or
symbol.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Saint Luke . . . collected them from such <qex>documents</qex> and
testimonies as he . . . judged to be authentic.</q>
<rj><qau>Paley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Document</ent><br/
<hw>Doc"u*ment</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To teach; to
school.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I am finely <qex>documented</qex> by my own daughter.</q>
<rj><qau> Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To furnish with documents or papers necessary to
establish facts or give information; <as>as, a a ship should be
<ex>documented</ex> according to the directions of law</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Documental</ent><br/
<hw>Doc`u*men"tal</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Of
or pertaining to instruction.</def> <mark>[Obs.]</mark> <rj><au>Dr. H.
More.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of or pertaining to written evidence; documentary;
<as>as, <ex>documental</ex> testimony</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Documentary</ent><br/
<hw>Doc`u*men"ta*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to
written evidence; contained or certified in writing.</def>
<ldquo/<xex>Documentary</xex> evidence.<rdquo/
<rj><au>Macaulay.</au></rj></p>

<p><ent>DOD</ent><br/
<ent>DoD</ent><br/
<mhw><hw>DoD</hw>, <hw>DOD</hw></mhw> <pr>(d<ocr/d <it>or</it>
d<emac/"<omac/*d<emac/`)</pr>, <pos>prop. n.</pos> <ety>[from
<ets>D</ets>epartment <ets>o</ets>f <ets>D</ets>efense.]</ety> <def>the
United States Department of Defense, the federal department responsible
for safeguarding national security; created in 1947. It includes within
its jurisdiction control of the Army, Navy, Air Force, and
Marines.</def> <mark>[acronym]</mark><br/
<syn><b>Syn. --</b> Department of Defense, Defense Department,
Defense.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Dod</ent><br/
<ent>Dodd</ent><br/
<mhw>{ <hw>Dodd</hw>, <hw>Dod</hw> <pr>(?)</pr> }</mhw>, <pos>v.
t.</pos> <ety>[OE. <ets>dodden</ets>.]</ety> <def>To cut off, as wool
from sheep's tails; to lop or clip off.</def>
<rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doddart</ent><br/
<hw>Dod"dart</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A game much like
hockey, played in an open field; also, the, bent stick for playing the
game.</def> <mark>[Local, Eng.]</mark> <rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dodded</ent><br/
<hw>Dod"ded</hw>, <pos>a.</pos> <ety>[See <er>Dodd</er>.]</ety>
<def>Without horns; <as>as, <ex>dodded</ex> cattle</as>; without beards;
<as>as, <ex>dodded</ex> corn</as>.</def>
<rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dodder</ent><br/
<hw>Dod"der</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. Dan.
<ets>dodder</ets>, Sw. <ets>dodra</ets>, G. <ets>dotter</ets>.]</ety>
<fld>(Bot.)</fld> <def>A plant of the genus <gen>Cuscuta</gen>. It is a
leafless parasitical vine with yellowish threadlike stems. It attaches
itself to some other plant, as to flax, goldenrod, etc., and decaying at
the root, is nourished by the plant that supports it.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dodder</ent><br/
<hw>Dod"der</hw>, <pos>v. t. & i.</pos> <ety>[Cf. AS.
<ets>dyderian</ets> to deceive, delude, and E. <ets>didder</ets>,
<ets>dudder</ets>.]</ety> <def>To shake, tremble, or totter.</def>
<ldquo/The <xex>doddering</xex> mast.<rdquo/
<rj><au>Thomson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doddered</ent><br/
<hw>Dod"dered</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Shattered;
infirm.</def> <ldquo/A laurel grew, <xex>doddered</xex> with age.<rdquo/
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>doddering</ent><br/
<hw>doddering</hw> <pos>adj.</pos> <sn>1.</sn> <def>shaking as from old
age.</def><br/
<syn><b>Syn. --</b> doddery, shaking, tottering, tottery.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>mentally or physically infirm with age.</def><br/
<syn><b>Syn. --</b> gaga, senile.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>doddery</ent><br/
<hw>doddery</hw> <pos>adj.</pos> <def>same as
<er>doddering{1}</er>.</def><br/
<syn><b>Syn. --</b> doddering, shaking, tottering, tottery.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dodecagon</ent><br/
<hw>Do*dec"a*gon</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ twelve +
<?/ angle: cf. F. <ets>dod<eacute/cagone</ets>.]</ety>
<fld>(Geom.)</fld> <def>A figure or polygon bounded by twelve sides and
containing twelve angles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dodecagynia</ent><br/
\'d8<hw>Do*dec`a*gyn"i*a</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
fr. Gr. <?/ twelve + <?/ woman, female.]</ety> <fld>(Bot.)</fld> <def>A
Linn<ae/an order of plants having twelve styles.</def></p>

<p><ent>Dodecagynous</ent><br/
<ent>Dodecagynian</ent><br/
<mhw>{ <hw>Do*dec`a*gyn"i*an</hw> <pr>(?)</pr>,
<hw>Do`de*cag"y*nous</hw> <pr>(?)</pr>, }</mhw> <pos>a.</pos>
<fld>(Bot.)</fld> <def>Of or pertaining to the Dodecagynia; having
twelve styles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dodecahedral</ent><br/
<hw>Do*dec`a*he"dral</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining
to, or like, a dodecahedion; consisting of twelve equal sides.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dodecahedral cleavage</b></col>. <cd>See under
<er>Cleavage</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dodecahedron</ent><br/
<hw>Do*dec`a*he"dron</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/; <?/
twelve + <?/ seat, bottom, base: cf. F.
<ets>dod<eacute/ca<egrave/dre</ets>.]</ety> <fld>(Geom. &
Crystallog.)</fld> <def>A solid having twelve faces.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The <xex>regular dodecahedron</xex> is bounded by twelve
equal and regular pentagons; the pyritohedron (see
<er>Pyritohedron</er>) is related to it; the <xex>rhombic
dodecahedron</xex> is bounded by twelve equal rhombic faces.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dodecandria</ent><br/
\'d8<hw>Do`de*can"dri*a</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[NL.,
fr. Gr. <?/ twelve + <?/, <?/, man, male.]</ety> <fld>(Bot.)</fld>
<def>A Linn<ae/an class of plants including all that have any number of
stamens between twelve and nineteen.</def></p>

<p><ent>Dodecandrous</ent><br/
<ent>Dodecandrian</ent><br/
<mhw>{ <hw>Do`de*can"dri*an</hw> <pr>(?)</pr>, <hw>Do`de*can"drous</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <fld>(Bot.)</fld> <def>Of or
pertaining to the Dodecandria; having twelve stamens, or from twelve to
nineteen.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dodecane</ent><br/
<hw>Do"de*cane</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/
twelve.]</ety> <fld>(Chem.)</fld> <def>Any one of a group of thick oily
hydrocarbons, <chform>C12H26</chform>, of the paraffin series.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dodecastyle</ent><br/
<hw>Do*dec"a*style</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/ twelve
+ <?/ column: cf. F. <ets>dod<eacute/castyle</ets>.]</ety>
<fld>(Arch.)</fld> <def>Having twelve columns in front.</def> --
<def2><pos>n.</pos> <def>A dodecastyle portico, or
building.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dodecasyllabic</ent><br/
<hw>Do*dec`a*syl*lab"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/
twelve + E. <ets>syllabic</ets>.]</ety> <def>Having twelve
syllables.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dodecasyllable</ent><br/
<hw>Do*dec"a*syl`la*ble</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A word
consisting of twelve syllables.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dodecatemory</ent><br/
<hw>Do*dec`a*tem"o*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/;
<?/ twelve + <?/, dim. of <?/ part: cf. F.
<ets>dod<eacute/cat<eacute/morie</ets>.]</ety> <fld>(Astron.)</fld>
<def>A tern applied to the twelve houses, or parts, of the zodiac of the
<xex>primum mobile</xex>, to distinguish them from the twelve signs;
also, any one of the twelve signs of the zodiac.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dodge</ent><br/
<hw>Dodge</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Dodged</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Dodging</conjf>.]</vmorph> <ety>[Of uncertain origin: cf.
<ets>dodder</ets>, v., <ets>daddle</ets>, dade, or <ets>dog</ets>, v.
t.]</ety> <sn>1.</sn> <def>To start suddenly aside, as to avoid a blow
or a missile; to shift place by a sudden start.</def>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To evade a duty by low craft; to practice mean
shifts; to use tricky devices; to play fast and loose; to
quibble.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Some <qex>dodging</qex> casuist with more craft than
sincerity.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dodge</ent><br/
<hw>Dodge</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To evade by a sudden
shift of place; to escape by starting aside; <as>as, to <ex>dodge</ex> a
blow aimed or a ball thrown</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Fig.: To evade by craft; <as>as, to <ex>dodge</ex> a
question; to <ex>dodge</ex> responsibility.</as></def>
<mark>[Colloq.]</mark> <rj><au>S. G. Goodrich.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To follow by dodging, or suddenly shifting from
place to place.</def> <rj><au>Coleridge.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dodge</ent><br/
<hw>Dodge</hw>, <pos>n.</pos> <def>The act of evading by some skillful
movement; a sudden starting aside; hence, an artful device to evade,
deceive, or cheat; a cunning trick; an artifice.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Some, who have a taste for good living, have many harmless arts,
by which they improve their banquet, and innocent <qex>dodges</qex>, if
we may be permitted to use an excellent phrase that has become
vernacular since the appearance of the last dictionaries.</q> <rj><qau>
Thackeray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dodgem</ent><br/
<hw>Dodgem</hw> <pos>n.</pos> <def>a small low-powered electrically
powered vehicle driven on a special platform where there are many others
to be dodged.</def><br/
<syn><b>Syn. --</b> bumper car.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>dodger</ent><br/
<hw>dodg"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who
dodges or evades; one who plays fast and loose, or uses tricky
devices.</def> <rj><au>Smart.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A small handbill.</def> <mark>[U. S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>See <er>Corndodger</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dodger</ent><br/
<hw>Dodg"er</hw> <pr>(?)</pr>, <pos>prop. n.</pos> <def>a member of the
professional baseball team called <membof>the Dodgers</membof>. At one
time the team was headquartered in Brooklyn, New York, when it was
called the Brooklyn Dodgers, but the franchise was transferred to Los
Angeles.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dodgery</ent><br/
<hw>Dodg"er*y</hw> <pr>(?)</pr>, <pos>n.</pos> <def>trickery;
artifice.</def> <mark>[Obs.]</mark> <rj><au>Hacket.</au></rj></p>

<p><ent>Dodipoll</ent><br/
<ent>Dodipate</ent><br/
<mhw>{ <hw>Dod"i*pate</hw> <pr>(?)</pr>, <hw>Dod"i*poll</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[Perh. fr. OE.
<ets>dodden</ets> to cut off, to shear, and first applied to
shaven-polled priests.]</ety> <def>A stupid person; a fool; a
blockhead.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Some will say, our curate is naught, an ass-head, a
<qex>dodipoll</qex>.</q> <rj><au> Latimer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dodkin</ent><br/
<hw>Dod"kin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[D.
<ets>duitken</ets>, dim. of <ets>duit</ets>. See <er>Doit</er>, and cf.
<er>Doitkin</er>.]</ety> <def>A doit; a small coin.</def>
<rj><au>Shelton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dodman</ent><br/
<hw>Dod"man</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A snail;
also, a snail shell; a hodmandod.</def> <mark>[Obs. or Prov.
Eng.]</mark> <rj><au>Nares.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>Any shellfish which casts its
shell, as a lobster.</def> <mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dodo</ent><br/
<hw>Do"do</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Dodoes</plw> <pr>(#)</pr>.</plu> <ety>[Said to be fr. Pg.
<ets>doudo</ets> silly, foolish (cf. <er>Booby</er>); this is fr. Prov.
E. <ets>dold</ets>, the same word as E. <ets>dolt</ets>.]</ety>
<fld>(Zool.)</fld> <def>A large, extinct bird (<spn>Didus
ineptus</spn>), formerly inhabiting the Island of Mauritius. It had
short, half-fledged wings, like those of the ostrich, and a short neck
and legs; -- called also <altname>dronte</altname>. It was related to
the pigeons.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doe</ent><br/
<hw>Doe</hw> <pr>(d<omac/)</pr>, <pos>n.</pos> <ety>[AS.
<ets>d<amac/</ets>; cf. Dan. <ets>daa</ets>, <ets>daa-</ets>dyr, deer,
and perh. L. <ets>dama</ets>. <root/66.]</ety> <fld>(Zool.)</fld> <def>A
female deer or antelope; specifically, the female of the fallow deer, of
which the male is called a <xex>buck</xex>. Also applied to the female
of other animals, as the rabbit. See the Note under
<er>Buck</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doe</ent><br/
<hw>Doe</hw> <pr>(d<oomac/)</pr>, <pos>n.</pos> <def>A feat.
<mark>[Obs.]</mark> See <er>Do</er>, <pos>n.</pos></def>
<rj><au>Hudibras.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doe, John</ent><br/
<hw>Doe, John</hw>. <fld>(Law)</fld> <def>The fictitious lessee acting
as plaintiff in the common-law action of ejectment, the fictitious
defendant being usually denominated <contr>Richard Roe</contr>. Hence, a
fictitious name for a party, real or fictitious, to any action or
proceeding.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Doeglic</ent><br/
<hw>D<oe/g"lic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to, or
obtained from, the d<oe/gling; <as>as, <ex>d<oe/glic</ex> acid
<fld>(Chem.)</fld>, an oily substance resembling oleic
acid.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doegling</ent><br/
\'d8<hw>D<oe/g"ling</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Native name
in Faroe Islands.]</ety> <fld>(Zool.)</fld> <def>The beaked whale
(<spn>Bal<ae/noptera rostrata</spn>), from which d<oe/gling oil is
obtained.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doer</ent><br/
<hw>Do"er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From <er>Do</er>,
<pos>v. t. & i.</pos>]</ety> <sn>1.</sn> <def>One who does; one who
performs or executes; one who is wont and ready to act; an actor; an
agent.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>doers</qex> of the law shall be justified.</q> <rj><qau>
Rom. ii. 13.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Scots Law)</fld> <def>An agent or attorney; a
factor.</def> <rj><au>Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Does</ent><br/
<hw>Does</hw> <pr>(d<ucr/z)</pr>. <def>The <pos>3d pers. sing.
pres.</pos> of <er>Do</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doeskin</ent><br/
<hw>Doe"skin`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The skin
of the doe.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A firm woolen cloth with a smooth, soft surface like
a doe's skin; -- made for men's wear.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doff</ent><br/
<hw>Doff</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Doffed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Doffing</conjf>.]</vmorph> <ety>[<ets>Do</ets> + <ets>off</ets>.
See <er>Do</er>, <pos>v. t.</pos>, 7.]</ety> <sn>1.</sn> <def>To put
off, as dress; to divest one's self of; hence, figuratively, to put or
thrust away; to rid one's self of.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And made us <qex>doff</qex> our easy robes of peace.</q> <rj><qau>
Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>At night, or in the rain,<br/
He dons a surcoat which he <qex>doffs</qex> at morn.</q> <rj><qau>
Emerson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To strip; to divest; to undress.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Heaven's King, who <qex>doffs</qex> himself our flesh to wear.</q>
<rj><qau> Crashaw.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doff</ent><br/
<hw>Doff</hw>, <pos>v. i.</pos> <def>To put off dress; to take off the
hat.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doffer</ent><br/
<hw>Doff"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<fld>(Mach.)</fld> <def>A revolving cylinder, or a vibrating bar, with
teeth, in a carding machine, which doffs, or strips off, the fiber from
the cards.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <fld>(Spinning)</fld> <def>A worker who replaces full
bobbins by empty ones on the throstle or ring frames.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Dog</ent><br/
<hw>Dog</hw> <pr>(d<add/g or d<ocr/g)</pr>, <pos>n.</pos> <ety>[AS.
<ets>docga</ets>; akin to D. <ets>dog</ets> mastiff, Dan.
<ets>dogge</ets>, Sw. <ets>dogg</ets>.]</ety> <sn>1.</sn>
<fld>(Zool.)</fld> <def>A quadruped of the genus <gen>Canis</gen>, esp.
the domestic dog (<spn>Canis familiaris</spn>).</def> <note>The dog is
distinguished above all others of the inferior animals for intelligence,
docility, and attachment to man. There are numerous carefully bred
varieties, as the <stype>akita</stype>, <stype>beagle</stype>,
<stype>bloodhound</stype>, <stype>bulldog</stype>,
<stype>coachdog</stype>, <stype>collie</stype>, <stype>Danish
dog</stype>, <stype>foxhound</stype>, <stype>greyhound</stype>,
<stype>mastiff</stype>, <stype>pointer</stype>, <stype>poodle</stype>,
<stype>St. Bernard</stype>, <stype>setter</stype>,
<stype>spaniel</stype>, <stype>spitz</stype>, <stype>terrier</stype>,
<stype>German shepherd</stype>, <stype>pit bull</stype>,
<stype>Chihuahua</stype>, etc. There are also many mixed breeds, and
partially domesticated varieties, as well as wild dogs, like the dingo
and dhole. (See these names in the Vocabulary.)</note><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>A mean, worthless fellow; a wretch.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>What is thy servant, which is but a <qex>dog</qex>, that he should
do this great thing?</q> <rj><qau> 2 Kings viii. 13 (Rev. Ver.
)</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A fellow; -- used humorously or contemptuously;
<as>as, a sly <ex>dog</ex>; a lazy <ex>dog</ex>.</as></def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Astron.)</fld> <def>One of the two constellations,
<xex>Canis Major</xex> and <xex>Canis Minor</xex>, or the Greater Dog
and the Lesser Dog. <xex>Canis Major</xex> contains the Dog Star
(Sirius).</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>An iron for holding wood in a fireplace; a firedog;
an andiron.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Mech.)</fld> <sd>(a)</sd> <def>A grappling iron,
with a claw or claws, for fastening into wood or other heavy articles,
for the purpose of raising or moving them.</def> <sd>(b)</sd> <def>An
iron with fangs fastening a log in a saw pit, or on the carriage of a
sawmill.</def> <sd>(c)</sd> <def>A piece in machinery acting as a catch
or clutch; especially, the carrier of a lathe, also, an adjustable stop
to change motion, as in a machine tool.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>an ugly or crude person, especially an ugly
woman.</def> <mark>[slang]</mark> <br/
[<source>PJC</source>]</p>

<p><sn>8.</sn> <def>a <er>hot dog</er>.</def> <mark>[slang]</mark><br/
[<source>PJC</source>]</p>

<p><note><hand/ <xex>Dog</xex> is used adjectively or in composition,
commonly in the sense of <xex>relating to</xex>, <xex>or characteristic
of</xex>, <xex>a dog</xex>. It is also used to denote a <xex>male</xex>;
as, <xex>dog</xex> fox or <xex>g</xex>-fox, a male fox; <xex>dog</xex>
otter or <xex>dog</xex>-otter, <xex>dog</xex> wolf, etc.; -- also to
denote a <xex>thing of cheap or mean quality</xex>; as, <xex>dog</xex>
Latin.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>A dead dog</b></col>, <cd>a thing of no use or
value.</cd> <au>1 Sam. xxiv. 14.</au> -- <col><b>A dog in the
manger</b></col>, <cd>an ugly-natured person who prevents others from
enjoying what would be an advantage to them but is none to him.</cd> --
<col><b>Dog ape</b></col> <fld>(Zool.)</fld>, <cd>a male ape.</cd> --
<mcol><col><b>Dog cabbage</b></col>, <it>or</it> <col><b>Dog's
cabbage</b></col></mcol> <fld>(Bot.)</fld>, <cd>a succulent herb, native
to the Mediterranean region (<spn>Thelygonum Cynocrambe</spn>).</cd> --
<col><b>Dog cheap</b></col>, <cd>very cheap. See under
<er>Cheap</er>.</cd> -- <col><b>Dog ear</b></col> <fld>(Arch.)</fld>,
<cd>an acroterium.</cd> <mark>[Colloq.]</mark> -- <col><b>Dog
flea</b></col> <fld>(Zool.)</fld>, <cd>a species of flea (<spn>Pulex
canis</spn>) which infests dogs and cats, and is often troublesome to
man. In America it is the common flea. See <er>Flea</er>, and
<er>Aphaniptera</er>.</cd> -- <col><b>Dog grass</b></col>
<fld>(Bot.)</fld>, <cd>a grass (<spn>Triticum caninum</spn>) of the same
genus as wheat.</cd> -- <col><b>Dog Latin</b></col>, <cd>barbarous
Latin; as, the <xex>dog Latin</xex> of pharmacy.</cd> -- <col><b>Dog
lichen</b></col> <fld>(Bot.)</fld>, <cd>a kind of lichen (<spn>Peltigera
canina</spn>) growing on earth, rocks, and tree trunks, -- a lobed
expansion, dingy green above and whitish with fuscous veins
beneath.</cd> -- <col><b>Dog louse</b></col> <fld>(Zool.)</fld>, <cd>a
louse that infests the dog, esp. <spn>H<ae/matopinus piliferus</spn>;
another species is <spn>Trichodectes latus</spn>.</cd> -- <col><b>Dog
power</b></col>, <cd>a machine operated by the weight of a dog traveling
in a drum, or on an endless track, as for churning.</cd> -- <col><b>Dog
salmon</b></col> <fld>(Zool.)</fld>, <cd>a salmon of northwest America
and northern Asia; -- the <altname>gorbuscha</altname>; -- called also
<altname>holia</altname>, and <altname>hone</altname>.</cd> --
<col><b>Dog shark</b></col>. <fld>(Zool.)</fld> <cd>See
<er>Dogfish</er>.</cd> -- <col><b>Dog's meat</b></col>, <cd>meat fit
only for dogs; refuse; offal.</cd> -- <col><b>Dog Star</b></col>.
<cd>See in the Vocabulary.</cd> -- <col><b>Dog wheat</b></col>
<fld>(Bot.)</fld>, <cd>Dog grass.</cd> -- <col><b>Dog whelk</b></col>
<fld>(Zool.)</fld>, <cd>any species of univalve shells of the family
<fam>Nassid<ae/</fam>, esp. the <spn>Nassa reticulata</spn> of
England.</cd> -- <mcol><col><b>To give to the dogs</b></col>,
<it>or</it> <col><b>To throw to the dogs</b></col></mcol>, <cd>to throw
away as useless.</cd> <ldquo/<xex>Throw</xex> physic <xex>to the
dogs</xex>; I'll none of it.<rdquo/ <au>Shak.</au> -- <col><b>To go to
the dogs</b></col>, <cd>to go to ruin; to be ruined.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 442 --></p>

<p><ent>Dog</ent><br/
<hw>Dog</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Dogged</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Dogging</conjf>.]</vmorph> <def>To hunt or track like a hound; to
follow insidiously or indefatigably; to chase with a dog or dogs; to
worry, as if by dogs; to hound with importunity.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I have been pursued, <qex>dogged</qex>, and waylaid.</q> <rj><qau>
Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Your sins will <qex>dog</qex> you, pursue you.</q>
<rj><qau>Burroughs.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Eager ill-bred petitioners, who do not so properly supplicate as
hunt the person whom they address to, <qex>dogging</qex> him from place
to place, till they even extort an answer to their rude requests.</q>
<rj><qau> South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dogal</ent><br/
<hw>Do"gal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[LL. <ets>dogalis</ets>
for <ets>ducalis</ets>. See <er>Doge</er>.]</ety> <def>Of or pertaining
to a doge.</def><mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dogate</ent><br/
<hw>Do"gate</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>dogat</ets>, It. <ets>dogato</ets>. See <er>Doge</er>, and cf.
<er>Dogeate</er>.]</ety> <def>The office or dignity of a doge.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dogbane</ent><br/
<hw>Dog"bane`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Said to be
poisonous to dogs. Cf. <er>Apocynaceous</er>.]</ety> <fld>(Bot.)</fld>
<def>A small genus of perennial herbaceous plants, with poisonous milky
juice, bearing slender pods pods in pairs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dog bee</ent><br/
<hw>Dog" bee`</hw> <pr>(?)</pr>. <def>A male or drone bee.</def>
<rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dogberry</ent><br/
<hw>Dog"ber`ry</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>The berry of the <prodby>dogwood</prodby>; -- called also
<altname>dogcherry</altname>.</def> <rj><au>Dr. Prior.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dogberry tree</b></col> <fld>(Bot.)</fld>, <cd>the
dogwood.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dogbolt</ent><br/
<hw>Dog"bolt`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Gun.)</fld>
<def>The bolt of the cap-square over the trunnion of a cannon.</def>
<rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dog-brier</ent><br/
<hw>Dog"-bri`er</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>The dog-rose.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dogcart</ent><br/
<hw>Dog"cart`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A light one-horse
carriage, commonly two-wheeled, patterned after a cart. The original
dogcarts used in England by sportsmen had a box at the back for carrying
dogs.</def></p>

<p><ent>Dogday</ent><br/
<ent>Dog day</ent><br/
<mhw>{ <hw>Dog" day`</hw> <it>or</it> <hw>Dog"day`</hw> <pr>(?)</pr>
}</mhw>. <def>One of the dog days.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dogday cicada</b></col> <fld>(Zool.)</fld>, <cd>a large
American cicada (<spn>Cicada pruinosa</spn>), which trills loudly in
midsummer.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>dog-days</ent><br/
<ent>Dog days</ent><br/
<mhw><hw>Dog" days`</hw>, <hw>dog-days</hw></mhw> <pr>(?)</pr>. <def>A
period of from four to six weeks, in the summer, variously placed by
almanac makers between the early part of July and the early part of
September; canicular days; -- so called in reference to the rising in
ancient times of the Dog Star (Sirius) with the sun. Popularly, the
sultry, close part of the summer; metaphorically, a period of
inactivity.</def><br/
<syn><b>Syn. --</b> dog days, canicule, canicular days.</syn><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><note><hand/ The conjunction of the rising of the Dog Star with the
rising of the sun was regarded by the ancients as one of the causes of
the sultry heat of summer, and of the maladies which then prevailed. But
as the conjunction does not occur at the same time in all latitudes, and
is not constant in the same region for a long period, there has been
much variation in calendars regarding the limits of the dog days. The
astronomer Roger Long states that in an ancient calendar in
<person>Bede</person> (died 735) the beginning of <ex>dog days</ex> is
placed on the 14th of July; that in a calendar prefixed to the Common
Prayer, printed in the time of <person>Queen Elizabeth</person>, they
were said to begin on the 6th of July and end on the 5th of September;
that, from the Restoration (1660) to the beginning of New Style (1752),
British almanacs placed the beginning on the 19th of July and the end on
the 28th of August; and that after 1752 the beginning was put on the
30th of July, the end on the 7th of September. Some English calendars
now put the beginning on July 3d, and the ending on August 11th. A
popular American almanac of the present time (1890) places the beginning
on the 25th of July, and the end on the 5th of September.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dogdraw</ent><br/
<hw>Dog"draw`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Eng. Forest
Law)</fld> <def>The act of drawing after, or pursuing, deer with a
dog.</def> <rj><au>Cowell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doge</ent><br/
<hw>Doge</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[It <ets>doge</ets>,
<ets>dogio</ets>, for <ets>duce</ets>, <ets>duca</ets>, fr. L.
<ets>dux</ets>, <ets>ducis</ets>, a leader, commander. See
<er>Duke</er>.]</ety> <def>The chief magistrate in the republics of
Venice and Genoa.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>dog-ear</ent><br/
<hw>dog-ear</hw> <pos>n.</pos> <def>a corner of a page turned down to
mark a place.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>dog-eared</ent><br/
<hw>dog"-eared`</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Having
the corners of the leaves turned down and soiled by careless or
long-continued usage; -- said of a book; <as>as, an old book with
<ex>dog-eared</ex> pages</as>.</def> <note>Making a page
<ex>dog-eared</ex> is sometimes done deliberately to mark a location in
a book.</note><br/
[<source>1913 Webster</source>]</p>

<p><q>Statute books before unopened, not <qex>dog-eared</qex>.</q>
<rj><qau>Ld. Mansfield.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>worn down, shabby.</def><br/
<syn><b>Syn. --</b> eared.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dogeate</ent><br/
<hw>Doge"ate</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Dogate.</def>
<rj><au>Wright.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dogeless</ent><br/
<hw>Doge"less</hw>, <pos>a.</pos> <def>Without a doge.</def> <rj><au>
Byron.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>dogey</ent><br/
<hw>do"gey</hw> <pr>(d<omac/"g<emac/)</pr>, <pos>n.</pos> <def>a
motherless calf in a range herd of cattle.</def> <altsp>[Also spelled
<asp>dogy</asp> and <asp>dogie</asp>.]</altsp><br/
<syn><b>Syn. --</b> leppy.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dog-faced</ent><br/
<hw>Dog"-faced`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having a face
resembling that of a dog.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dog-faced baboon</b></col> <fld>(Zool.)</fld>, <cd>any
baboon of the genus <gen>Cynocephalus</gen>. See
<er>Drill</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dog fancier</ent><br/
<hw>Dog" fan`cier</hw> <pr>(?)</pr>. <def>One who has an unusual fancy
for, or interest in, dogs; also, one who deals in dogs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dogfish</ent><br/
<hw>Dog"fish`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<sn>1.</sn> <def>A small shark, of many species, of the genera
<gen>Mustelus</gen>, <gen>Scyllium</gen>, <gen>Spinax</gen>,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The European spotted dogfishes (<spn>Scyllium
catudus</spn>, and <spn>Scyllium canicula</spn>) are very abundant; the
American smooth, or blue dogfish is <spn>Mustelus canis</spn>; the
common picked, or horned dogfish (<spn>Squalus acanthias</spn>) abundant
on both sides of the Atlantic.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The bowfin (<spn>Amia calva</spn>). See
<er>Bowfin</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The burbot of Lake Erie.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dog-fox</ent><br/
<hw>Dog"-fox`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<sd>(a)</sd> <def>A male fox. See the Note under <er>Dog</er>,
<pos>n.</pos>, 6.</def> <au>Sir W. Scott.</au> <sd>(b)</sd> <def>The
Arctic or blue fox; -- a name also applied to species of the genus
<gen>Cynalopex</gen>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dogged</ent><br/
<hw>Dog"ged</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Fron.
<er>Dog</er>.]</ety> <sn>1.</sn> <def>Sullen; morose.</def> <mark>[Obs.
or R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The sulky spite of a temper naturally <qex>dogged</qex>.</q>
<rj><qau> Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Sullenly obstinate; obstinately determined or
persistent; <as>as, <ex>dogged</ex> resolution; <ex>dogged</ex> work;
<ex>dogged</ex> pursuit.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doggedly</ent><br/
<hw>Dog"ged*ly</hw>, <pos>adv.</pos> <def>In a dogged manner; sullenly;
with obstinate resolution.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doggedness</ent><br/
<hw>Dog"ged*ness</hw>, <pos>n.</pos> <sn>1.</sn> <def>Sullenness;
moroseness.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Sullen or obstinate determination; grim resolution
or persistence.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dogger</ent><br/
<hw>Dog"ger</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[D., fr.
<ets>dogger</ets> codfish, orig. used in the catching of codfish.]</ety>
<fld>(Naut.)</fld> <def>A two-masted fishing vessel, used by the
Dutch.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dogger</ent><br/
<hw>Dog"ger</hw>, <pos>n.</pos> <def>A sort of stone, found in the mines
with the true alum rock, chiefly of silica and iron.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doggerel</ent><br/
<hw>Dog"ger*el</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OE.
<ets>dogerel</ets>.]</ety> <def>Low in style, and irregular in measure;
<as>as, <ex>doggerel</ex> rhymes</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This may well be rhyme <qex>doggerel</qex>, quod he.</q> <rj><qau>
Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doggerel</ent><br/
<hw>Dog"ger*el</hw>, <pos>n.</pos> <def>A sort of loose or irregular
verse; mean or undignified poetry.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Doggerel</qex> like that of Hudibras.</q> <rj><qau>
Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The ill-spelt lines of <qex>doggerel</qex> in which he expressed
his reverence for the brave sufferers.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doggerman</ent><br/
<hw>Dog"ger*man</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A sailor belonging
to a dogger.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dogget</ent><br/
<hw>Dog"get</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Docket. See
<er>Docket</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doggish</ent><br/
<hw>Dog"gish</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Like a dog; having
the bad qualities of a dog; churlish; growling; brutal.</def> --
<wordforms><wf>Dog"gish*ly</wf>, <pos>adv.</pos> --
<wf>Dog"gish*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>doggoned</ent><br/
<ent>doggone</ent><br/
<mhw><hw>dog"gone</hw>, <hw>dog"goned</hw></mhw> <pr>(?)</pr>,
<pos>a.</pos> <ety>[Euphemism from <ets>God-damned</ets>.]</ety>
<def>Damned; confounded; -- used as an expression of displeasure;
<as>as, I wish those <ex>doggone</ex> telemarketers would quit calling
at suppertime</as>.</def> <mark>[Informal]</mark><br/
[<source>PJC</source>]</p>

<p><ent>doggoned</ent><br/
<ent>doggone</ent><br/
<mhw><hw>dog"gone</hw>, <hw>dog"goned</hw></mhw> <pr>(?)</pr>,
<pos>adv.</pos> <def>Damned; darned; -- used as an informal intensifier;
<as>as, he's a <ex>doggoned</ex> good golfer</as>.</def>
<mark>[Informal]</mark><br/
[<source>PJC</source>]</p>

<p><ent>doggone</ent><br/
<hw>dog"gone</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Euphemism for
<ets>God-damn</ets>.]</ety> <def>Damn; -- used to express displeasure or
annoyance; <as>as, <ex>doggone</ex> it!</as>.</def>
<mark>[Informal]</mark><br/
[<source>PJC</source>]</p>

<p><ent>Doggrel</ent><br/
<hw>Dog"grel</hw> <pr>(?)</pr>, <pos>a. & n.</pos> <def>Same as
<er>Doggerel</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dog-headed</ent><br/
<hw>Dog"-head`ed</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld>
<def>Having a head shaped like that of a dog; -- said of certain
baboons.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dog-hearted</ent><br/
<hw>Dog"-heart`ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Inhuman;
cruel.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doghole</ent><br/
<hw>Dog"hole`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A place fit only for
dogs; a vile, mean habitation or apartment.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>dogie</ent><br/
<hw>do"gie</hw> <pr>(d<omac/"g<emac/)</pr>, <pos>n.</pos> <def>a
motherless calf in a range herd of cattle.</def> <altsp>[Also spelled
<asp>dogy</asp> and <asp>dogey</asp>.]</altsp><br/
<syn><b>Syn. --</b> leppy.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>dog-legged</ent><br/
<hw>dog"-leg`ged</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Arch)</fld>
<def>Noting a flight of stairs, consisting of two or more straight
portions connected by a platform (landing) or platforms, and running in
opposite directions without an intervening wellhole.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dogma</ent><br/
<hw>Dog"ma</hw> <pr>(d<ocr/g"m<adot/)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> E. <plw>Dogmas</plw> <pr>(d<ocr/g"m<adot/z)</pr>, L.
<plw>Dogmata</plw> <pr>(d<ocr/g"m<adot/*t<adot/)</pr>.</plu> <ety>[L.
<ets>dogma</ets>, Gr. <grk>do`gma</grk>, <pluf>pl.</pluf>
<grk>do`gmata</grk>, fr. <grk>dokei^n</grk> to think, seem, appear; akin
to L. <ets>decet</ets> it is becoming. Cf. <er>Decent</er>.]</ety>
<sn>1.</sn> <def>That which is held as an opinion; a tenet; a
doctrine.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The obscure and loose <qex>dogmas</qex> of early antiquity.</q>
<rj><qau> Whewell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A formally stated and authoritatively settled
doctrine; a definite, established, and authoritative tenet.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A doctrinal notion asserted without regard to
evidence or truth; an arbitrary dictum.</def></p>

<p><syn><b>Syn.</b> -- tenet; opinion; proposition; doctrine.</syn>
<usage>-- <er>Dogma</er>, <er>Tenet</er>. A <xex>tenet</xex> is that
which is maintained as true with great firmness; <as>as, the
<ex>tenets</ex> of our holy religion</as>. A <xex>dogma</xex> is that
which is laid down with authority as indubitably true, especially a
religious doctrine; <as>as, the <ex>dogmas</ex> of the church</as>. A
<xex>tenet</xex> rests on its own intrinsic merits or demerits; a
<xex>dogma</xex> rests on authority regarded as competent to decide and
determine. <xex>Dogma</xex> has in our language acquired, to some
extent, a repulsive sense, from its carrying with it the idea of undue
authority or assumption. This is more fully the case with its
derivatives <xex>dogmatical</xex> and <xex>dogmatism</xex>.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>dogmatic</ent><br/
<hw>dog*mat"ic</hw> <pr>(d<ocr/g*m<acr/t"<icr/k)</pr>, <pos>n.</pos>
<def>One of an ancient sect of physicians who went by general
principles; -- opposed to the <contr>Empiric</contr>.</def></p>

<p><ent>dogmatical</ent><br/
<ent>dogmatic</ent><br/
<mhw>{ <hw>dog*mat"ic</hw> <pr>(d<ocr/g*m<acr/t"<icr/k)</pr>,
<hw>dog*mat`ic*al</hw> <pr>(d<ocr/g*m<acr/t"<icr/*k<ait/l)</pr>, }</mhw>
<pos>a.</pos> <ety>[L. <ets>dogmaticus</ets>, Gr.
<grk>dogmatiko`s</grk>, fr. <grk>do`gma</grk>: cf. F.
<ets>dogmatique</ets>.]</ety> <sn>1.</sn> <def>Pertaining to a dogma, or
to an established and authorized doctrine or tenet.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Asserting a thing positively and authoritatively;
positive; magisterial; hence, arrogantly authoritative;
overbearing.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Critics write in a positive, <qex>dogmatic</qex> way.</q>
<rj><qau> Spectator.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>[They] are as assertive and <qex>dogmatical</qex> as if they were
omniscient.</q> <rj><qau> Glanvill.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dogmatic theology</b></col>. <cd>Same as
<er>Dogmatics</er>.</cd></cs></p>

<p><syn><b>Syn.</b> -- Magisterial; arrogant. See
<er>Magisterial</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dogmatically</ent><br/
<hw>Dog*mat"ic*al*ly</hw>, <pos>adv.</pos> <def>In a dogmatic manner;
positively; magisterially.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dogmaticalness</ent><br/
<hw>Dog*mat"ic*al*ness</hw>, <pos>n.</pos> <def>The quality of being
dogmatical; positiveness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dogmatician</ent><br/
<hw>Dog`ma*ti"cian</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A
dogmatist.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dogmatics</ent><br/
<hw>Dog*mat"ics</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The science which
treats of Christian doctrinal theology.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dogmatism</ent><br/
<hw>Dog"ma*tism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The manner or
character of a dogmatist; arrogance or positiveness in stating
opinion.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The self-importance of his demeanor, and the <qex>dogmatism</qex>
of his conversation.</q> <rj><qau> Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dogmatist</ent><br/
<hw>Dog"ma*tist</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>dogmatistes</ets>, Gr. <?/ , fr. <?/.]</ety> <def>One who
dogmatizes; one who speaks dogmatically; a bold and arrogant advancer of
principles.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I expect but little success of all this upon the
<qex>dogmatist</qex>; his opinioned assurance is paramount to
argument.</q> <rj><qau> Glanvill.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dogmatize</ent><br/
<hw>Dog"ma*tize</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Dogmatized</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Dogmatizing</conjf>.]</vmorph> <ety>[L.
<ets>dogmatizare</ets> to lay down an opinion, Gr. <?/, fr. <?/: cf. F.
<ets>dogmatiser</ets>. See <er>Dogma</er>.]</ety> <def>To assert
positively; to teach magisterially or with bold and undue confidence; to
advance with arrogance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The pride of <qex>dogmatizing</qex> schools.</q>
<rj><qau>Blackmore.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dogmatize</ent><br/
<hw>Dog"ma*tize</hw>, <pos>v. t.</pos> <def>To deliver as a dogma.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dogmatizer</ent><br/
<hw>Dog"ma*ti`zer</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
dogmatizes; a bold asserter; a magisterial teacher.</def>
<rj><au>Hammond.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dog-rose</ent><br/
<hw>Dog"-rose`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>A
common European wild rose, with single pink or white flowers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dog's-bane</ent><br/
<hw>Dog's"-bane`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>See <er>Dogbane</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dog's-ear</ent><br/
<hw>Dog's"-ear`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The corner of a
leaf, in a book, turned down like the ear of a dog.</def> <au>Gray.</au>
-- <wordforms><wf>Dog's"-eared`</wf> <pr>(#)</pr>,
<pos>a.</pos></wordforms> <rj><au>Cowper.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dogship</ent><br/
<hw>Dog"ship</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The character, or
individuality, of a dog.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dogshore</ent><br/
<hw>Dog"shore`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Naut.)</fld>
<def>One of several shores used to hold a ship firmly and prevent her
moving while the blocks are knocked away before launching.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dogsick</ent><br/
<hw>Dog"sick`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Sick as a dog
sometimes is very sick.</def> <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dogskin</ent><br/
<hw>Dog"skin</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The skin of a dog, or
leather made of the skin. Also used adjectively.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dogsleep</ent><br/
<hw>Dog"sleep`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>Pretended sleep.</def> <rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Naut.)</fld> <def>The fitful naps taken when all
hands are kept up by stress.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dog's-tail grass</ent><br/
<hw>Dog's"-tail grass`</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Bot.)</fld> <def>A hardy species of British grass (<spn>Cynosurus
cristatus</spn>) which abounds in grass lands, and is well suited for
making straw plait; -- called also
<altname>goldseed</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dog Star</ent><br/
<hw>Dog" Star`</hw> <pr>(?)</pr>. <def>Sirius, a star of the
constellation <xex>Canis Major</xex>, or the Greater Dog, and the
brightest star in the heavens; -- called also
<altname>Canicula</altname>, and, in astronomical charts,
<altname><alpha/ Canis Majoris</altname>. See <er>Dog
days</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dog's-tongue</ent><br/
<hw>Dog's"-tongue`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>Hound's-tongue.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dogtie</ent><br/
<hw>Dog"tie`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Arch.)</fld> <def>A
cramp.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dogtooth</ent><br/
<hw>Dog"tooth`</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Dogteeth</plw> <pr>(<?/)</pr>.</plu> <sn>1.</sn> <def>See
<cref>Canine tooth</cref>, under <er>Canine</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Arch.)</fld> <def>An ornament common in Gothic
architecture, consisting of pointed projections resembling teeth; --
also called <altname>tooth ornament</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dogtooth spar</b></col> <fld>(Min.)</fld>, <cd>a variety
of calcite, in acute crystals, resembling the tooth of a dog. See
<er>Calcite</er>.</cd> -- <col><b>Dogtooth violet</b></col>
<fld>(Bot.)</fld>, <cd>a small, bulbous herb of the Lily family (genus
<gen>Erythronium</gen>). It has two shining flat leaves and commonly one
large flower.</cd> <altsp>[Written also <asp>dog's-tooth
violet</asp>.]</altsp></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dogtrick</ent><br/
<hw>Dog"trick`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A gentle trot, like
that of a dog.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dogvane</ent><br/
<hw>Dog"vane`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Naut.)</fld> <def>A
small vane of bunting, feathers, or any other light material, carried at
the masthead to indicate the direction of the wind.</def>
<rj><au>Totten.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dogwatch</ent><br/
<hw>Dog"watch`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Naut.)</fld>
<def>A half watch; a watch of two hours, of which there are two, the
first <ex>dogwatch</ex> from 4 to 6 o'clock, p. m., and the second
<ex>dogwatch</ex> from 6 to 8 o'clock, p. m.</def>
<rj><au>Totten.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dog-weary</ent><br/
<hw>Dog"-wea`ry</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Extremely
weary.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dogwood</ent><br/
<hw>Dog"wood`</hw> <pr>(-w<oocr/d`)</pr>, <pos>n.</pos> <ety>[So named
from skewers (dags) being made of it. <au>Dr. Prior</au>. See
<er>Dag</er>, and <er>Dagger</er>.]</ety> <fld>(Bot.)</fld> <def>The
<gen>Cornus</gen>, a genus of large shrubs or small trees, the wood of
which is exceedingly hard, and serviceable for many purposes.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ There are several species, one of which, <spn>Cornus
mascula</spn>, called also <stype>cornelian cherry</stype>, bears a red
acid berry. <spn>Cornus florida</spn> is the flowering dogwood, a small
American tree with very showy blossoms.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dogwood tree</b></col>. <sd>(a)</sd> <cd>The dogwood or
<gen>Cornus</gen>.</cd> <sd>(b)</sd> <cd>A papilionaceous tree
(<spn>Piscidia erythrina</spn>) growing in Jamaica. It has narcotic
properties; -- called also <altname>Jamaica
dogwood</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>dogy</ent><br/
<hw>do"gy</hw> <pr>(d<omac/"g<emac/)</pr>, <pos>n.</pos> <def>a
motherless calf in a range herd of cattle.</def> <altsp>[Also spelled
<asp>dogey</asp> and <asp>dogie</asp>.]</altsp><br/
<syn><b>Syn. --</b> leppy.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>doh</ent><br/
<hw>doh</hw> <pr>(d<omac/)</pr>, <pos>n.</pos> <def>the syllable naming
the first (tonic) note of any major diatonic scale in solmization,
usually written <altname>do</altname>.</def><br/
<syn><b>Syn. --</b> do, ut.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Doha</ent><br/
<hw>Doha</hw> <pos>prop. n.</pos> <fld>(Geography)</fld> <def>The
capital <isa>city</isa> of <country>Qatar</country>. Population (2000) =
300,000.</def><br/
[<source>PJC</source>]</p>

<p><ent>Dohtren</ent><br/
<hw>Doh"tren</hw> <pr>(d<omac/"tr<ecr/n)</pr>, <pos>n. pl.</pos>
<def>Daughters.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doily</ent><br/
<hw>Doi"ly</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[So called from the
name of the dealer.]</ety> <sn>1.</sn> <def>A kind of woolen
stuff.</def> <mark>[Obs.]</mark> <ldquo/Some <xex>doily</xex>
petticoats.<rdquo/ <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A fool and a <qex>doily</qex> stuff, would now and then find days
of grace, and be worn for variety.</q> <rj><qau>
Congreve.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A small napkin, used at table with the fruit, etc.;
-- commonly colored and fringed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doing</ent><br/
<hw>Do"ing</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Doings</plw> <pr>(<?/)</pr>.</plu> <def>Anything done; a deed; an
action good or bad; hence, in the plural, conduct; behavior. See
<er>Do</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To render an account of his <qex>doings</qex>.</q> <rj><qau>
Barrow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doit</ent><br/
<hw>Doit</hw> <pr>(doit)</pr>, <pos>n.</pos> <ety>[D. <ets>duit</ets>,
Icel. <ets>pveit</ets>, prop., a piece cut off. See <er>Thwaite</er> a
piece of ground, <er>Thwite</er>.]</ety> <sn>1.</sn> <def>A small Dutch
coin, worth about half a farthing; also, a similar small coin once used
in Scotland; hence, any small piece of money.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A thing of small value; <as>as, I care not a
<ex>doit</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doitkin</ent><br/
<hw>Doit"kin</hw> <pr>(doit"k<icr/n)</pr>, <pos>n.</pos> <def>A very
small coin; a doit.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>do-it-yourself</ent><br/
<hw>do-it-yourself</hw> <pos>adj.</pos> <def>performed or made by an
end-user who is without professional training in the relevant
techniques; <as>as, their house was a <ex>do-it-yourself</ex>
project</as>. Contrasted with <contr>factory-made</contr> and
<contr>professional</contr>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>do-it-yourselfer</ent><br/
<hw>do-it-yourselfer</hw> <pos>n.</pos> <def>a person who often makes
objects typically made by professionals, or performs repairs typically
performed by professionals, though not having professional training in
the relevant art. The term is used mostly to refer to activities related
to maintaining a home.</def><br/
[<source>PJC</source>]</p>

<p><ent>Dokimastic</ent><br/
<hw>Dok`i*mas"tic</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Docimastic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doko</ent><br/
\'d8<hw>Do"ko</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>See <er>Lepidosiren</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dolabra</ent><br/
\'d8<hw>Do*la"bra</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., fr.
<ets>dolare</ets> to hew.]</ety> <def>A rude ancient ax or hatchet, seen
in museums.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dolabriform</ent><br/
<hw>Do*lab"ri*form</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>dolabra</ets> a mattock + <ets>-form</ets>.]</ety> <def>Shaped like
the head of an ax or hatchet, as some leaves, and also certain organs of
some shellfish.</def></p>

<p><ent>Dolcemente</ent><br/
<ent>Dolce</ent><br/
<mhw>{ \'d8<hw>Dol"ce</hw> <pr>(?)</pr>, <hw>Dol`ce*men"te</hw>
<pr>(?)</pr>, }</mhw> <pos>adv.</pos> <ety>[It., fr. L.
<ets>dulcis</ets> sweet, soft.]</ety> <fld>(Mus.)</fld> <def>Softly;
sweetly; with soft, smooth, and delicate execution.</def></p>

<p><ent>Dulcino</ent><br/
<ent>Dolcino</ent><br/
<mhw>\'d8<hw>Dol*ci"no</hw> <pr>(?)</pr>, <it>or</it>
\'d8<hw>Dul*ci"no</hw> <pr>(<?/)</pr></mhw>, <pos>n.</pos> <ety>[Cf. It.
<ets>dolcigno</ets> sweetish.]</ety> <fld>(Mus.)</fld> <def>A small
bassoon, formerly much used.</def> <rj><au>Simmonds.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>doldrums</ent><br/
<hw>dol"drums</hw> <pr>(d<ocr/l"dr<ucr/mz)</pr>, <pos>n. pl.</pos>
<ety>[Cf. Gael. <ets>doltrum</ets> grief, vexation?]</ety> <def>A part
of the ocean near the equator, abounding in calms, squalls, and light,
baffling winds, which sometimes prevent all progress for weeks; -- so
called by sailors.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To be in the doldrums</b></col>, <cd>to be in a state of
listlessness ennui, or tedium.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dole</ent><br/
<hw>Dole</hw> <pr>(d<omac/l)</pr>, <pos>n.</pos> <ety>[OE.
<ets>deol</ets>, <ets>doel</ets>, <ets>dol</ets>, OF. <ets>doel</ets>,
fr. <ets>doloir</ets> to suffer, fr. L. <ets>dolere</ets>; perh. akin to
<ets>dolare</ets> to hew.]</ety> <def>grief; sorrow; lamentation.</def>
<mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>And she died.<br/
So that day there was <qex>dole</qex> in Astolat.</q> <rj><qau>
Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dole</ent><br/
<hw>Dole</hw>, <pos>n.</pos> <ety>[L. <ets>dolus</ets>: cf. F.
<ets>dol</ets>.]</ety> <fld>(Scots Law)</fld> <def>See
<er>Dolus</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dole</ent><br/
<hw>Dole</hw>, <pos>n.</pos> <ety>[AS. <ets>d<amac/l</ets> portion; same
word as <ets>d<aemac/l</ets>. See <er>Deal</er>.]</ety> <sn>1.</sn>
<def>Distribution; dealing; apportionment.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>At her general <qex>dole</qex>,<br/
Each receives his ancient soul.</q> <rj><qau> Cleveland.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is dealt out; a part, share, or portion
also, a scanty share or allowance.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 443 --></p>

<p><sn>3.</sn> <def>Alms; charitable gratuity or portion.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>So sure the <qex>dole</qex>, so ready at their call,<br/
They stood prepared to see the manna fall.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Heaven has in store a precious <qex>dole</qex>.</q>
<rj><qau>Keble.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A boundary; a landmark.</def>
<rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A void space left in tillage.</def> <rj><au>[Prov.
Eng.]</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dole beer</b></col>, <cd>beer bestowed as alms.</cd>
<mark>[Obs.]</mark> -- <col><b>Dole bread</b></col>, <cd>bread bestowed
as alms.</cd> <mark>[Obs.]</mark> -- <col><b>Dole meadow</b></col>,
<cd>a meadow in which several persons have a common right or share.</cd>
-- <col><b>on the dole</b></col>, <cd>receiving financial assistance
from a governmental agency, such as a welfare agency; <as>as, after his
unemployment benefits ran out, his family was <ex>on the dole</ex> for a
year</as>.</cd></cs><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Dole</ent><br/
<hw>Dole</hw> <pr>(d<omac/l)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Doled</conjf> <pr>(d<omac/ld)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Doling</conjf>.]</vmorph> <def>To deal out in small
portions; to distribute, as a dole; to deal out scantily or
grudgingly.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The supercilious condescension with which even his reputed friends
<qex>doled</qex> out their praises to him.</q> <rj><qau>De
Quincey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doleful</ent><br/
<hw>Dole"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Full of dole or
grief; expressing or exciting sorrow; sorrowful; sad; dismal.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With screwed face and <qex>doleful</qex> whine.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Regions of sorrow, <qex>doleful</qex> shades.</q>
<rj><qau>Milton.</qau></rj></p>

<p><syn><b>Syn.</b> -- Piteous; rueful; sorrowful; woeful; melancholy;
sad gloomy; dismal; dolorous; woe-begone.</syn></p>

<p>-- <wordforms><wf>Dole"ful*ly</wf>, <pos>adv.</pos> --
<wf>Dole"ful*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dolent</ent><br/
<hw>Do"lent</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>dolens</ets>,
p. pr. of <ets>dolere</ets>: cf. F. <ets>dolent</ets>. See <er>Dole</er>
sorrow.]</ety> <def>Sorrowful.</def> <mark>[Obs.]</mark>
<rj><au>Ford.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dolente</ent><br/
\'d8<hw>Do*len"te</hw> <pr>(?)</pr>, <pos>a. & adv.</pos>
<ety>[It.]</ety> <fld>(Mus.)</fld> <def>Plaintively. See
<er>Doloroso</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dolerite</ent><br/
<hw>Dol"er*ite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>dolero`s</grk> deceptive, because it was easily confounded with
diorite.]</ety> <fld>(Petrography)</fld> <sd>(a)</sd> <def>A dark,
crystalline, igneous rock, chiefly pyroxene with labradorite.</def>
<sd>(b)</sd> <def>Coarse-grained basalt.</def> <sd>(c)</sd>
<def>Diabase.</def> <sd>(d)</sd> <def>Any dark, igneous rock composed
chiefly of silicates of iron and magnesium with some feldspar.</def> --
<wordforms><wf>Dol`er*it"ic</wf> <pr>(#)</pr>,
<pos>a.</pos></wordforms><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Doleritic</ent><br/
<hw>Dol`er*it"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of the nature of
dolerite; <as>as, much lava is <ex>doleritic</ex> lava</as>.</def>
<rj><au>Dana.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dolesome</ent><br/
<hw>Dole"some</hw>, <pos>a.</pos> <def>Doleful; dismal; gloomy;
sorrowful.</def> -- <wordforms><wf>Dole"some*ly</wf>, <pos>adv.</pos> --
<wf>Dole"some*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dolf</ent><br/
<hw>Dolf</hw> <pr>(?)</pr>, <def><pos>imp.</pos> of
<er>Delve</er>.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj></p>

<p><ent>Dolichocephalous</ent><br/
<ent>Dolichocephalic</ent><br/
<mhw>{ <hw>Dol`i*cho*ce*phal"ic</hw>
<pr>(d<ocr/l`<icr/*k<osl/*s<esl/*f<acr/l"<icr/k)</pr>,
<hw>Dol`i*cho*ceph"a*lous</hw>
<pr>(d<ocr/l`<icr/*k<osl/*s<ecr/f"<adot/*l<ucr/s)</pr>, }</mhw>
<pos>a.</pos> <ety>[Gr. <grk>dolicho`s</grk> long + <grk>kefalh`</grk>
head.]</ety> <fld>(Anat.)</fld> <def>Having the cranium, or skull, long
to its breadth; long-headed; -- opposed to
<contr>brachycephalic</contr>.</def> --
<wordforms><wf>Dol`i*cho*ceph"al</wf> <pr>(#)</pr>, <pos>a. &
n.</pos></wordforms></p>

<p><ent>Dolichocephalism</ent><br/
<ent>Dolichocephaly</ent><br/
<mhw>{ <hw>Dol`i*cho*ceph"a*ly</hw>
<pr>(d<ocr/l`<icr/*k<osl/*s<ecr/f"<adot/*l<ycr/)</pr>,
<hw>Dol`i*cho*ceph"a*lism</hw>
<pr>(d<ocr/l`<icr/*k<osl/*s<ecr/f"<adot/*l<icr/z'm)</pr> }</mhw>,
<pos>n.</pos> <ety>[Cf. F. <ets>dolichc<eacute/phalie</ets>.]</ety>
<def>The quality or condition of being dolichocephalic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dolichotis</ent><br/
<hw>Dolichotis</hw> <pos>n.</pos> <sn>1.</sn> <def>a genus of rodents
including the maras.</def><br/
<syn><b>Syn. --</b> genus <gen>Dolichotis</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>dolioform</ent><br/
<hw>do"li*o*form</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>dolium</ets> large jar + <ets>-form</ets>.]</ety>
<fld>(Biol.)</fld> <def>Barrel-shaped, or like a cask in form.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doliolidae</ent><br/
<hw>Doliolidae</hw> <pos>n.</pos> <def>a natural family of oceanic
tunicates.</def><br/
<syn><b>Syn. --</b> family <fam>Doliolidae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Doliolum</ent><br/
\'d8<hw>Do*li"o*lum</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>doliolum</ets> a small cask.]</ety> <fld>(Zool.)</fld> <def>A genus
of freeswimming oceanic tunicates, allied to <gen>Salpa</gen>, and
having alternate generations.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Do-little</ent><br/
<hw>Do"-lit`tle</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who performs
little though professing much.</def> <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Great talkers are commonly <qex>dolittles</qex>.</q> <rj><qau>Bp.
Richardson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dolium</ent><br/
\'d8<hw>Do"li*um</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. large
jar.]</ety> <fld>(Zool.)</fld> <def>A genus of large univalve mollusks,
including the partridge shell and tun shells.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>doll</ent><br/
<hw>doll</hw> <pr>(d<ocr/l)</pr>, <pos>n.</pos> <ety>[A contraction of
<ets>Dorothy</ets>; or less prob. an abbreviation of <ets>idol</ets>; or
cf. OD. <ets>dol</ets> a whipping top, D. <ets>dollen</ets> to rave, and
E. <ets>dull</ets>.]</ety> <sn>1.</sn> <def>a small, usually flexible
figure representing a human being, especially a toy baby for a little
girl; a child's puppet.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>an attractive woman or girl.</def>
<mark>[slang]</mark><br/
[<source>PJC</source>]</p>

<p><q>Come along and be my party <qex>doll</qex>.</q> <rj><qau>(The
first words of the song)</qau></rj></p>

<p><ent>dollar</ent><br/
<hw>dol"lar</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[D.
<ets>daalder</ets>, LG. <ets>dahler</ets>, G. <ets>thaler</ets>, an
abbreviation of <ets>Joachimsthaler</ets>, i. e., a piece of money first
coined, about the year 1518, in the valley (G. <ets>thal</ets>) of St.
<ets>Joachim</ets>, in Bohemia. See <er>Dale</er>.]</ety> <sn>1.</sn>
<sd>(a)</sd> <def>A silver coin of the United States containing 371.25
grains of silver and 41.25 grains of alloy, that is, having a total
weight of 412.5 grains.</def> <sd>(b)</sd> <def>A gold coin of the
United States containing 23.22 grains of gold and 2.58 grains of alloy,
that is, having a total weight of 25.8 grains, nine-tenths fine. It is
no longer coined.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Previous to 1837 the silver dollar had a larger amount
of alloy, but only the same amount of silver as now, the total weight
being 416 grains. The gold dollar as a distinct coin was first made in
1849. The eagles, half eagles, and quarter eagles coined before 1834
contained 24.75 grains of gold and 2.25 grains of alloy for each
dollar.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A coin of the same general weight and value as the
United States silver dollar, though differing slightly in different
countries, formerly current in Mexico, Canada, parts of South America,
also in Spain, and several other European countries.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>3.</sn> <def>The value of a dollar; the unit of currency,
differing in value in different countries, commonly employed in the
United States and a number of other countries, including Australia,
Canada, Hong Kong, parts of the Carribbean, Liberia, and several
others.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><cs><col><b>Chop dollar</b></col>. <cd>See under 9th
<er>Chop</er>.</cd> -- <col><b>Dollar fish</b></col> <fld>(Zool.)</fld>,
<cd>a fish of the United States coast (<spn>Stromateus
triacanthus</spn>), having a flat, roundish form and a bright silvery
luster; -- called also <altname>butterfish</altname>, and
<altname>Lafayette</altname>. See <er>Butterfish</er>.</cd> --
<col><b>Trade dollar</b></col>, <cd>a silver coin formerly made at the
United States mint, intended for export, and not legal tender at home.
It contained 378 grains of silver and 42 grains of alloy.</cd></cs></p>

<p><ent>dollar bill</ent><br/
<hw>dollar bill</hw> <def>A paper note printed by the Treasury, or by
one of the Federal Reserve Banks under authority of the treasury, having
the value of one dollar. Also five dollar bill, ten dollar bill, etc.:
notes with the value of five, ten, etc. dollars. Prior to 1964 such
notes could be redeemed for the equivalent dollar value in silver coins,
but in that year the backing of the currency with silver was
discontinued. Such notes not convertible into precious metals at a fixed
rate are called "fiat money", receiving their value solely from the good
faith of the issuing government and the confidence of those using the
currency.</def><br/
[<source>PJC</source>]</p>

<p><ent>Dollardee</ent><br/
<hw>Dol`lar*dee"</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>A species of sunfish (<spn>Lepomis pallidus</spn>), common in the
United States; -- called also <altname>blue sunfish</altname>, and
<altname>copper-nosed bream</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>dollarfish</ent><br/
<hw>dollarfish</hw> <pos>n.</pos> <sn>1.</sn> <def>small food fish
(<spn>Poronotus triacanthus</spn>) of the Atlantic coast.</def><br/
<syn><b>Syn. --</b> <spn>Poronotus triacanthus</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>any of several silvery marine fishes with very flat
bodies.</def><br/
<syn><b>Syn. --</b> moonfish, Atlantic moonfish, horsefish, horsehead,
Selene setapinnis.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>dollhouse</ent><br/
<hw>dollhouse</hw> <pos>n.</pos> <sn>1.</sn> <def>a house so small that
it is likened to a child's dollhouse. Sometimes used in reference to a
small house with especially elaborate exterior decoration.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>a small model of a house used as a toy by children,
usually including miniature furniture and other objects that can be
arranged inside it as the would be in a real house.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Dollman</ent><br/
<hw>Doll"man</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Dolman</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dolly</ent><br/
<hw>Dol"ly</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Dollies</plw> <pr>(<?/)</pr>.</plu> <sn>1.</sn> <fld>(Mining)</fld>
<def>A contrivance, turning on a vertical axis by a handle or winch, and
giving a circular motion to the ore to be washed; a stirrer.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mach.)</fld> <def>A tool with an indented head for
shaping the head of a rivet.</def> <rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>In pile driving, a block interposed between the head
of the pile and the ram of the driver.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A small truck with a single wide roller used for
moving heavy beams, columns, etc., in bridge building.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A compact, narrow-gauge locomotive used for moving
construction trains, switching, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dolly</ent><br/
<hw>Dol"ly</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A child's mane for a
doll.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dolly shop</b></col>, <cd>a shop where rags, old junk,
etc., are bought and sold; usually, in fact, an unlicensed pawnbroker's
shop, formerly distinguished by the sign of a black doll.</cd>
<mark>[England]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dolly Varden</ent><br/
<hw>Dol"ly Var"den</hw> <pr>(?)</pr>. <sn>1.</sn> <def>A character in
Dickens's novel <ldquo/Barnaby Rudge,<rdquo/ a beautiful, lively, and
coquettish girl who wore a cherry-colored mantle and cherry-colored
ribbons.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A style of light, bright-figured dress goods for
women; also, a style of dress.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dolly Varden trout</b></col> <fld>(Zool.)</fld>, <cd>a
trout of northwest America; -- called also <altname>bull
trout</altname>, <altname>malma</altname>, and <altname>red-spotted
trout</altname>. See <er>Malma</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>dolma</ent><br/
<hw>dolma</hw> <pos>n.</pos>; <plu><it>pl.</it> <plw>dolmas</plw>
<it>or</it> <plw>dolmades</plw>.</plu> <fld>(Cookery)</fld> <def>a dish
composed of well-seasoned rice (with nuts or currants of minced lamb)
simmered or braised in stock, stuffed into tomatoes or green peppers, or
wrapped in grape leaves; -- popular in the near east.</def><br/
<syn><b>Syn. --</b> stuffed grape leaves.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Dolman</ent><br/
<hw>Dol"man</hw> <pr>(d<ocr/l"m<ait/n)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Dolmans</plw>.</plu> <ety>[Turk.
<ets>d<omac/l<amac/m<amac/n</ets>: cf. F. <ets>doliman</ets>.]</ety>
<sn>1.</sn> <def>A long robe or outer garment, with long sleeves, worn
by the Turks.</def> <altsp>[Written also
<asp>doliman</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A woman's cloak with capelike pieces instead of
sleeves.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>3.</sn> <def>The uniform jacket of many European hussar
regiments, worn like a cloak, fastened with a cord or chain, and with
sleeves hanging loose.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>dolmas</ent><br/
<hw>dolmas</hw> <pos>n.</pos> <fld>(Cookery)</fld> <def>plural of
<er>dolma</er>; -- sometimes used as a singular form.</def><br/
<syn><b>Syn. --</b> stuffed grape leaves.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>dolmen</ent><br/
<hw>dol"men</hw> <pr>(d<ocr/l"m<ecr/n)</pr>, <pos>n.</pos> <ety>[Armor.
<ets>taol</ets>, <ets>tol</ets>, table + <ets>mean</ets>,
<ets>maen</ets>, <ets>men</ets>, stone: cf. F. <ets>dolmen</ets>.]</ety>
<def>A cromlech. See <er>Cromlech</er>.</def> <altsp>[Written also
<asp>tolmen</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>dolomite</ent><br/
<hw>dol"o*mite</hw> <pr>(d<ocr/l"<osl/*m<imac/t)</pr>, <pos>n.</pos>
<ety>[After the French geologist
<person><etsep>Dolomieu</etsep></person>.]</ety> <fld>(Geol. &
Min.)</fld> <def>A mineral consisting of the carbonate of lime and
magnesia in varying proportions. It occurs in distinct crystals, and in
extensive beds as a compact limestone, often crystalline granular,
either white or clouded. It includes much of the common white marble.
Also called <altname>bitter spar</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>dolomitic</ent><br/
<hw>dol`o*mit"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to
dolomite.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>dolomize</ent><br/
<hw>dol"o*mize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To convert into
dolomite.</def> -- <wordforms><wf>Dol`o*mi*za"tion</wf> <pr>(#)</pr>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>dolor</ent><br/
<hw>do"lor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>dolor</ets>,
<ets>dolur</ets>, <ets>dolour</ets>, F. <ets>douleur</ets>, L.
<ets>dolor</ets>, fr. <ets>dolere</ets>. See 1st <er>Dole</er>.]</ety>
<def>Pain; grief; distress; anguish.</def> <altsp>[Written also
<asp>dolour</asp>.]</altsp> <mark>[Poetic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Of death and <qex>dolor</qex> telling sad tidings.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doloriferous</ent><br/
<hw>Dol`or*if"er*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>dolor</ets> pain + <ets>-ferous</ets>.]</ety> <def>Producing
pain.</def> <rj><au>Whitaker.</au></rj></p>

<p><ent>Dolorifical</ent><br/
<ent>Dolorific</ent><br/
<mhw>{ <hw>Dol`or*if"ic</hw> <pr>(?)</pr>, <hw>Dol`or*if"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[LL. <ets>dolorificus</ets>; L.
<ets>dolor</ets> pain + <ets>facere</ets> to make.]</ety> <def>Causing
pain or grief.</def> <rj><au>Arbuthnot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doloroso</ent><br/
\'d8<hw>Do`lo*ro"so</hw> <pr>(?)</pr>, <pos>a. & adv.</pos>
<ety>[It.]</ety> <fld>(Mus.)</fld> <def>Plaintive; pathetic; -- used
adverbially as a musical direction.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dolorous</ent><br/
<hw>Dol"or*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>dolorosus</ets>, from <ets>dolor</ets>: cf. F.
<ets>douloureux</ets>. See <er>Dolor</er>.]</ety> <sn>1.</sn> <def>Full
of grief; sad; sorrowful; doleful; dismal; <as>as, a <ex>dolorous</ex>
object; <ex>dolorous</ex> discourses.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>You take me in too <qex>dolorous</qex> a sense;<br/
I spake to you for your comfort.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Occasioning pain or grief; painful.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Their dispatch is quick, and less <qex>dolorous</qex> than the paw
of the bear or teeth of the lion.</q> <rj><qau>Dr. H.
More.</qau></rj></p>

<p>-- <wordforms><wf>Dol"or*ous*ly</wf>, <pos>adv.</pos> --
<wf>Dol"or*ous*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>dolourous</ent><br/
<hw>dolourous</hw> <pos>adj.</pos> <sn>1.</sn><def>same as
<er>dolorous</er>.</def> <mark>[Brit.]</mark> <br/
<syn><b>Syn. --</b> dolorous, dolourous, lachrymose, tearful,
weeping.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>dolostone</ent><br/
<hw>dolostone</hw> <pos>n.</pos> <def>a stone or rock entirely composed
of the mineral dolomite.</def> <au>Dict. Sci. Tech.</au><br/
<syn><b>Syn. --</b> dolomite rock.</syn><br/
[<source>PJC</source>]</p>

<p><ent>dolphin</ent><br/
<hw>dol"phin</hw> <pr>(d<ocr/l"f<icr/n)</pr>, <pos>n.</pos> <ety>[F.
<ets>dauphin</ets> dolphin, dauphin, earlier spelt also
<ets>doffin</ets>; cf. OF. <ets>dalphinal</ets> of the dauphin; fr. L.
<ets>delphinus</ets>, Gr. <grk>delfi`s</grk> a dolphin (in senses 1, 2,
3, & 6), perh. properly, belly fish; cf. <grk>delfy`s</grk> womb, Skr.
<ets>garbha</ets>; perh. akin to E. <ets>calf</ets>. Cf.
<er>Dauphin</er>, <er>Delphine</er>.]</ety> <sn>1.</sn>
<fld>(Zool.)</fld> <def>A cetacean of the genus <gen>Delphinus</gen> and
allied genera (esp. <spn>Delphinus delphis</spn>); the true
dolphin.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The dolphin of the ancients (<spn>Delphinus
delphis</spn>) is common in the Mediterranean and Atlantic, and attains
a length of from six to eight feet.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>The <spn>Coryph<ae/na
hippuris</spn>, a fish of about five feet in length, celebrated for its
surprising changes of color when dying. It is the fish commonly known as
the dolphin. The term is also applied to the related <spn>Coryphaena
equisetis</spn>. Called also <altname>dolphinfish</altname> and
(especially in Hawaii) <altname>mahimahi</altname>. See also
<er>dolphinfish</er> and <er>Coryph<ae/noid</er>.</def><br/
<syn><b>Syn. --</b> dolphinfish, mahimahi.</syn><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>3.</sn> <ety>[Gr. <grk>delfi`s</grk>]</ety> <fld>(Gr.
Antiq.)</fld> <def>A mass of iron or lead hung from the yardarm, in
readiness to be dropped on the deck of an enemy's vessel.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Naut.)</fld> <sd>(a)</sd> <def>A kind of wreath or
strap of plaited cordage.</def> <sd>(b)</sd> <def>A spar or buoy held by
an anchor and furnished with a ring to which ships may fasten their
cables.</def> <au>R. H. Dana.</au> <sd>(c)</sd> <def>A mooring post on a
wharf or beach.</def> <sd>(d)</sd> <def>A permanent fender around a
heavy boat just below the gunwale.</def> <rj><au>Ham. Nav.
Encyc.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Gun.)</fld> <def>In old ordnance, one of the
handles above the trunnions by which a cannon was lifted.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Astron.)</fld> <def>A small constellation between
Aquila and Pegasus. See <er>Delphinus</er>, <pos>n.</pos>, 2.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dolphin fly</b></col> <fld>(Zool.)</fld>, <cd>the black,
bean, or collier, Aphis (<spn>Aphis fable</spn>), destructive to
beans.</cd> -- <col><b>Dolphin striker</b></col> <fld>(Naut.)</fld>,
<cd>a short vertical spar under the bowsprit.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>dolphinet</ent><br/
<hw>dol"phin*et</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A female
dolphin.</def> <mark>[R.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>dolphinfish</ent><br/
<hw>dolphinfish</hw> <pos>n.</pos> <def>either of two large slender food
and game fish (<spn>Coryphaena equisetis</spn> or <spn>Coryphaena
hippurus</spn>) of warm waters. They are highly esteemed as food fish,
especially in Hawaii, where they are usually referred to as
<altname>mahimahi</altname>. See also <er>dolphin{2}</er>.</def><br/
<syn><b>Syn. --</b> dolphin, mahimahi.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>dolt</ent><br/
<hw>dolt</hw> <pr>(d<omac/lt; 110)</pr>, <pos>n.</pos> <ety>[OE.
<ets>dulte</ets>, prop. p. p. of <ets>dullen</ets> to dull. See
<er>Dull</er>.]</ety> <def>A heavy, stupid fellow; a blockhead; a
numskull; an ignoramus; a dunce; a dullard.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This Puck seems but a dreaming <qex>dolt</qex>.</q>
<rj><qau>Drayton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>dolt</ent><br/
<hw>dolt</hw>, <pos>v. i.</pos> <def>To behave foolishly.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>doltish</ent><br/
<hw>dolt"ish</hw> <pr>(d<omac/lt"<icr/sh)</pr>, <pos>a.</pos>
<def>Doltlike; dull in intellect; stupid; blockish; <as>as, a
<ex>doltish</ex> clown</as>.</def> -- <wordforms><wf>Dolt"ish*ly</wf>,
<pos>adv.</pos> -- <wf>Dolt"ish*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dolus</ent><br/
\'d8<hw>Do"lus</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., deceit; akin
to Gr. <?/.]</ety> <fld>(Law)</fld> <def>Evil intent, embracing both
malice and fraud. See <er>Culpa</er>.</def>
<rj><au>Wharton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dolven</ent><br/
<hw>Dolv"en</hw> <pr>(?)</pr>, <pos>p. p.</pos> <def>of
<er>Delve</er>.</def> <mark>[Obs.]</mark> <rj><au>Rom. of
R.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>-dom</ent><br/
<hw>-dom</hw> <pr>(<?/)</pr>. <def>A suffix denoting</def>: <sd>(a)</sd>
<def><xex>Jurisdiction</xex> or <xex>property and jurisdiction</xex>,
<xex>dominion</xex>, as in king<xex>dom</xex> earl<xex>dom</xex>.</def>
<sd>(b)</sd> <def><xex>State</xex>, <xex>condition</xex>, or
<xex>quality of being</xex>, as in wis<xex>dom</xex>,
free<xex>dom</xex>.</def> <note>It is from the same root as
<xex>doom</xex> meaning <xex>authority</xex> and <xex>judgment</xex>.
<xex><?/</xex>. See <er>Doom</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dom</ent><br/
<hw>Dom</hw> <pr>(d<ocr/m)</pr>, <pos>n.</pos> <ety>[Pg. See
<er>Don</er>.]</ety> <sn>1.</sn> <def>A title anciently given to the
pope, and later to other church dignitaries and to some monastic orders.
See <er>Don</er>, and <er>Dan</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>In Portugal and Brazil, the title given to a member
of the higher classes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Domable</ent><br/
<hw>Dom"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>domabilis</ets>, fr. <ets>domare</ets> to tame.]</ety> <def>Capable
of being tamed; tamable.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Domableness</ent><br/
<hw>Dom"a*ble*ness</hw>, <pos>n.</pos> <def>Tamableness.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Domage</ent><br/
<hw>Dom"age</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Damage</er>.]</ety> <sn>1.</sn> <def>Damage; hurt.</def>
<mark>[Obs.]</mark> <rj><au>Chapman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Subjugation.</def> <mark>[Obs.]</mark>
<rj><au>Hobbes.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Domain</ent><br/
<hw>Do*main"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>domaine</ets>, OF. <ets>demaine</ets>, L. <ets>dominium</ets>,
property, right of ownership, fr. <ets>dominus</ets> master, owner. See
<er>Dame</er>, and cf <er>Demesne</er>, <er>Dungeon</er>.]</ety>
<sn>1.</sn> <def>Dominion; empire; authority.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The territory over which dominion or authority is
exerted; the possessions of a sovereign or commonwealth, or the like.
Also used figuratively.</def> <wns>[wns=2]</wns><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>domain</qex> of authentic history.</q> <rj><qau>E.
Everett.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>domain</qex> over which the poetic spirit ranges.</q>
<rj><qau>J. C. Shairp.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Landed property; estate; especially, the land about
the mansion house of a lord, and in his immediate occupancy;
demesne.</def> <wns>[wns=2]</wns> <rj><au>Shenstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Law)</fld> <def>Ownership of land; an estate or
patrimony which one has in his own right; absolute proprietorship;
paramount or sovereign ownership.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Math.)</fld> <def>the set of values which the
independent variable of a function may take. Contrasted to
<contr>range</contr>, which is the set of values taken by the dependent
variable.</def> <wns>[wns=3]</wns><br/
[<source>PJC</source>]</p>

<p><sn>6.</sn> <fld>(Math.)</fld> <def>a connected set of points, also
called a <altname>region</altname>.</def><br/
[<source>PJC</source>]</p>

<p><sn>7.</sn> <fld>(Physics)</fld> <def>a region within a ferromagnetic
material, composed of a number of atoms whose magnetic poles are pointed
in the same direction, and which may move together in a coordinated
manner when disturbed, as by heating. The direction of polarity of
adjacent domains may be different, but may be aligned by a strong
external magnetic field.</def><br/
[<source>PJC</source>]</p>

<p><sn>8.</sn> <fld>(Computers)</fld> <def>an address within the
internet computer network, which may be a single computer, a network of
computers, or one of a number of accounts on a multiuser computer. The
domain specifies the location (host computer) to which communications on
the internet are directed. Each domain has a corresponding 32-bit number
usually represented by four numbers separated by periods, as
<examp>128.32.282.56</examp>. Each domain may also have an alphabetical
name, usually composed of a name plus an extension separated by a
period, as <examp>worldsoul.org</examp>; the alphabetical name is
referred to as a <ecol><b>domain name</b></ecol>.</def><br/
[<source>PJC</source>]</p>

<p><sn>9.</sn> <fld>(Immunology)</fld> <def>the three-dimensional
structure within an immunoglobulin which is formed by one of the
homology regions of a heavy or light chain.</def> <au>Dict. Sci.
Tech.</au><br/
[<source>PJC</source>]</p>

<p><sn>10.</sn> <def>the field of knowledge, expertise, or interest of a
person; <as>as, he had a limited <ex>domain</ex> of discourse; I can't
comment on that, it's outside my <ex>domain</ex></as>.</def>
<wns>[wns=5]</wns><br/
<syn><b>Syn. --</b> domain, realm, field, area.</syn>
[<source>PJC</source>]</p>

<p><sn>11.</sn> <def>a particular environment or walk of life.</def>
<wns>[wns=1]</wns><br/
<syn><b>Syn. --</b> sphere, domain, area, orbit, field, arena.</syn>
[<source>PJC</source>]</p>

<p><sn>12.</sn> <def>people in general; especially a distinctive group
of people with some shared interest.</def> <wns>[wns=4]</wns><br/
<syn><b>Syn. --</b> world, domain.</syn>
[<source>PJC</source>]</p>

<p><cs><col><b>Public domain</b></col>, <sn>1.</sn> <cd>the territory
belonging to a State or to the general government; public lands.</cd>
<mark>[U.S.]</mark> -- <sn>2.</sn> <cd>the situation or status of
intellectual property which is not protected by copyright, patent or
other restriction on use. Anything <col><b>in the public
domain</b></col> may be used by anyone without restriction. The
effective term of force of copyrights and patents are limited by
statute, and after the term expires, the writings and inventions thus
protected go into the public domain and are free for use by all.</cd> --
<col><b>Right of eminent domain</b></col>, <cd>that superior dominion of
the sovereign power over all the property within the state, including
that previously granted by itself, which authorizes it to appropriate
any part thereof to a necessary public use, reasonable compensation
being made.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Domal</ent><br/
<hw>Do"mal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>domus</ets>
house.]</ety> <fld>(Astrol.)</fld> <def>Pertaining to a house.</def>
<rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Domanial</ent><br/
<hw>Do*ma"ni*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Of or relating to
a domain or to domains.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dome</ent><br/
<hw>Dome</hw>, <pos>n.</pos> <ety>[F. <ets>d<ocir/me</ets>, It.
<ets>duomo</ets>, fr. L. <ets>domus</ets> a house, <ets>domus Dei</ets>
or <ets>Domini</ets>, house of the Lord, house of God; akin to Gr. <?/
house, <?/ to build, and E. <ets>timber</ets>. See
<er>Timber</er>.]</ety> <sn>1.</sn> <def>A building; a house; an
edifice; -- used chiefly in poetry.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Approach the <qex>dome</qex>, the social banquet share.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Arch.)</fld> <def>A cupola formed on a large
scale.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <ldquo/The Italians apply the term <xex>il duomo</xex>
to the principal church of a city, and the Germans call every cathedral
church <xex>Dom</xex>; and it is supposed that the word in its present
English sense has crept into use from the circumstance of such buildings
being frequently surmounted by a cupola.<rdquo/</note> <rj><au>Am.
Cyc.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Any erection resembling the dome or cupola of a
building; as the upper part of a furnace, the vertical steam chamber on
the top of a boiler, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Crystallog.)</fld> <def>A prism formed by planes
parallel to a lateral axis which meet above in a horizontal edge, like
the roof of a house; also, one of the planes of such a form.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ If the plane is parallel to the longer diagonal
(macrodiagonal) of the prism, it is called a <xex>macrodome</xex>; if
parallel to the shorter (brachydiagonal), it is a <xex>brachydome</xex>;
if parallel to the inclined diagonal in a monoclinic crystal, it is
called a <xex>clinodome</xex>; if parallel to the orthodiagonal axis, an
<xex>orthodome</xex>.</note> <rj><au>Dana.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dome</ent><br/
<hw>Dome</hw>, <pos>n.</pos> <ety>[See <er>Doom</er>.]</ety>
<def>Decision; judgment; opinion; a court decision.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Domebook</ent><br/
<hw>Dome"book`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Dome</ets>
doom + <ets>book</ets>.]</ety> <fld>(O. Eng. Law)</fld> <def>A book said
to have been compiled under the direction of King Alfred. It is supposed
to have contained the principal maxims of the common law, the penalties
for misdemeanors, and the forms of judicial proceedings.
<xex>Domebook</xex> was probably a general name for <xex>book of
judgments</xex>.</def> <rj><au>Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Domed</ent><br/
<hw>Domed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Furnished with a dome;
shaped like a dome.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Domesday</ent><br/
<hw>Domes"day`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A day of judgment.
See <er>Doomsday</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Domesday Book</b></col>, <cd>the ancient record of the
survey of most of the lands of England, made by order of William the
Conqueror, about 1086. It consists of two volumes, a large folio and a
quarto, and gives the proprietors' tenures, arable land, woodland,
etc.</cd> <altsp>[Written also <asp>Doomsday
Book</asp>.]</altsp></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Domesman</ent><br/
<hw>Domes"man</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Domesmen</plw> <pr>(#)</pr>.</plu> <ety>[See <er>Doom</er>.]</ety>
<def>A judge; an umpire.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Domestic</ent><br/
<hw>Do*mes"tic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>domesticus</ets>, fr. <ets>domus</ets> use: cf. F.
<ets>domestique</ets>. See 1st <er>Dome</er>.]</ety> <sn>1.</sn> <def>Of
or pertaining to one's house or home, or one's household or family;
relating to home life; <as>as, <ex>domestic</ex> concerns, life, duties,
cares, happiness, worship, servants</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His fortitude is the more extraordinary, because his
<qex>domestic</qex> feelings were unusually strong.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Of or pertaining to a nation considered as a family
or home, or to one's own country; intestine; not foreign; <as>as,
foreign wars and <ex>domestic</ex> dissensions</as>.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Remaining much at home; devoted to home duties or
pleasures; <as>as, a <ex>domestic</ex> man or woman</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Living in or near the habitations of man;
domesticated; tame as distinguished from wild; <as>as, <ex>domestic</ex>
animals</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Made in one's own house, nation, or country; <as>as,
<ex>domestic</ex> manufactures, wines, etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Domestic</ent><br/
<hw>Do*mes"tic</hw>, <pos>n.</pos> <sn>1.</sn> <def>One who lives in the
family of an other, as hired household assistant; a house
servant.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The master labors and leads an anxious life, to secure plenty and
ease to the <qex>domestic</qex>.</q> <rj><qau>V. Knox.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <pluf>pl.</pluf> <fld>(Com.)</fld> <def>Articles of home
manufacture, especially cotton goods.</def> <mark>[U. S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 444 --></p>

<p><ent>Domestical</ent><br/
<hw>Do*mes"tic*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Domestic.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Our private and <qex>domestical</qex> matter.</q> <rj><qau>Sir. P.
Sidney.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Domestical</ent><br/
<hw>Do*mes"tic*al</hw>, <pos>n.</pos> <def>A family; a household.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Domestically</ent><br/
<hw>Do*mes"tic*al*ly</hw>, <pos>adv.</pos> <def>In a domestic manner;
privately; with reference to domestic affairs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Domesticant</ent><br/
<hw>Do*mes"ti*cant</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Forming part of
the same family.</def> <mark>[Obs.]</mark> <rj><au>Sir E.
Dering.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Domesticate</ent><br/
<hw>Do*mes"ti*cate</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Domesticated</conjf>; <pos>p.
pr. & vb. n.</pos> <conjf>Domesticating.</conjf>]</vmorph> <ety>[LL.
<ets>domesticatus</ets>, p. p. of <ets>domesticare</ets> to reside in,
to tame. See <er>Domestic</er>, <pos>a.</pos>]</ety> <sn>1.</sn> <def>To
make domestic; to habituate to home life; <as>as, to
<ex>domesticate</ex> one's self</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To cause to be, as it were, of one's family or
country; <as>as, to <ex>domesticate</ex> a foreign custom or
word</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To tame or reclaim from a wild state; <as>as, to
<ex>domesticate</ex> wild animals; to <ex>domesticate</ex> a
plant.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>domesticated</ent><br/
<hw>domesticated</hw> <pos>adj.</pos> <sn>1.</sn> <def>tame, tamed; --
of animals. Opposite of <ant>wild</ant>.</def><br/
<syn><b>Syn. --</b> domestic.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>accustomed to home life; <as>as, some men think it
unmanly to be <ex>domesticated;</ex> others find gratification in
it</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>3.</sn> <def>acclimated to a new environment; -- of plants or
animals.</def><br/
<syn><b>Syn. --</b> naturalized, nonnative.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Domestication</ent><br/
<hw>Do*mes`ti*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>domestication</ets>.]</ety> <def>The act of domesticating, or
accustoming to home; the action of taming wild animals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Domesticator</ent><br/
<hw>Do*mes"ti*ca`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
domesticates.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Domesticity</ent><br/
<hw>Do`mes*tic"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL.
<ets>domesticitas</ets>: cf. F. <ets>domesticit<eacute/</ets>.]</ety>
<def>The state of being domestic; domestic character; household
life.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Domett</ent><br/
<hw>Dom"ett</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A kind of baize of
which the ward is cotton and the weft woolen.</def>
<rj><au>Blakely.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Domeykite</ent><br/
<hw>Do"mey*kite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Named after
<ets>Domeyko</ets>, a mineralogist of Chili.]</ety> <fld>(Min.)</fld>
<def>A massive mineral of tin-white or steel-gray color, an arsenide of
copper.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Domical</ent><br/
<hw>Dom"i*cal</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Relating to, or
shaped like, a dome.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Domicile</ent><br/
<hw>Dom"i*cile</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>domicilium</ets>; <ets>domus</ets> house + (prob.) root of
<ets>celare</ets> to conceal: cf. F. <ets>domicile</ets>. See
<er>Dome</er>, and <er>Conceal</er>.]</ety> <sn>1.</sn> <def>An abode or
mansion; a place of permanent residence, either of an individual or a
family.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>A residence at a particular place
accompanied with an intention to remain there for an unlimited time; a
residence accepted as a final abode.</def>
<rj><au>Wharton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Domicile</ent><br/
<hw>Dom"i*cile</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Domiciled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Domiciling</conjf>.]</vmorph> <ety>[Cf. F. <ets>domicilier</ets>.
Cf. <er>Domiciliate</er>.]</ety> <def>To establish in a fixed residence,
or a residence that constitutes habitancy; to domiciliate.</def>
<rj><au>Kent.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Domiciliar</ent><br/
<hw>Dom`i*cil"i*ar</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A member of a
household; a domestic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Domicillary</ent><br/
<hw>Dom`i*cil"l*a*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[LL.
<ets>domiciliarius</ets>.]</ety> <def>Of or pertaining to a domicile, or
the residence of a person or family.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The personal and <qex>domiciliary</qex> rights of the citizen
scrupulously guarded.</q> <rj><qau>Motley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Domiciliary visit</b></col> <fld>(Law)</fld>, <cd>a visit
to a private dwelling, particularly for searching it, under
authority.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Domiciliate</ent><br/
<hw>Dom`i*cil"i*ate</hw> <pr>(?)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Domiciliated</conjf>
<pr>(?)</pr>; <pos>p. pr. & vb. n.</pos> <conjf>Domiciliating</conjf>
<pr>(?)</pr>.]</vmorph> <ety>[See <er>Domicile</er>.]</ety> <sn>1.</sn>
<def>To establish in a permanent residence; to domicile.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To domesticate.</def> <rj><au>Pownall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Domiciliation</ent><br/
<hw>Dom`i*cil`i*a"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
domiciliating; permanent residence; inhabitancy.</def>
<rj><au>Milman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Domiculture</ent><br/
<hw>Dom"i*cul`ture</hw> <pr>(?; 135)</pr>, <pos>n.</pos> <ety>[L.
<ets>domus</ets> house + E. <ets>culture</ets>. See 1st
<er>Dome</er>.]</ety> <def>The art of house-keeping, cookery, etc.</def>
<mark>[R.]</mark> <rj><au>R. Park.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Domify</ent><br/
<hw>Dom"i*fy</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L. <ets>domus +
-fy</ets>: cf. F. <ets>domifier</ets>.]</ety> <sn>1.</sn>
<fld>(Astrol.)</fld> <def>To divide, as the heavens, into twelve houses.
See <er>House</er>, in astrological sense.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To tame; to domesticate.</def> <mark>[Obs.]</mark>
<rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Domina</ent><br/
\'d8<hw>Dom"i*na</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., lady. See
<er>Dame</er>.]</ety> <fld>(O. Eng. Law)</fld> <def>Lady; a lady; -- a
title formerly given to noble ladies who held a barony in their own
right.</def> <rj><au>Burrill.</au></rj></p>

<p><ent>Dominancy</ent><br/
<ent>Dominance</ent><br/
<mhw>{ <hw>Dom"i*nance</hw> <pr>(?)</pr>, <hw>Dom"i*nan*cy</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <def>Predominance; ascendency;
authority.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dominant</ent><br/
<hw>Dom"i*nant</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>dominans</ets>, <ets>-antis</ets>, p. pr. of <ets>dominari</ets>:
cf. F. <ets>dominant</ets>. See <er>Dominate</er>.]</ety> <def>Ruling;
governing; prevailing; controlling; predominant; <as>as, the
<ex>dominant</ex> party, church, spirit, power</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The member of a <qex>dominant</qex> race is, in his dealings with
the subject race, seldom indeed fraudulent, . . . but imperious,
insolent, and cruel.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Dominant estate</b></col> <it>or</it>
<col><b>Dominant tenement</b></col></mcol> <fld>(Law)</fld>, <cd>the
estate to which a servitude or easement is due from another estate, the
estate over which the servitude extends being called the <xex>servient
estate</xex> or <xex>tenement</xex>.</cd> <au>Bouvier.</au>
<au>Wharton's Law Dict.</au> -- <col><b>Dominant owner</b></col>
<fld>(Law)</fld>, <cd>one who owns lands on which there is an easement
owned by another.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Governing; ruling; controlling; prevailing;
predominant; ascendant.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dominant</ent><br/
<hw>Dom"i*nant</hw>, <pos>n.</pos> <fld>(Mus.)</fld> <def>The fifth tone
of the scale; thus G is the dominant of C, A of D, and so on.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dominant chord</b></col> <fld>(Mus.)</fld>, <cd>the chord
based upon the dominant.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dominate</ent><br/
<hw>Dom"i*nate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Dominated</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Dominating</conjf>.]</vmorph> <ety>[L. <ets>dominatus</ets>, p.
p. of <ets>dominari</ets> to dominate, fr. <ets>dominus</ets> master,
lord. See <er>Dame</er>, and cf. <er>Domineer</er>.]</ety> <def>To
predominate over; to rule; to govern.</def> <ldquo/A city
<xex>dominated</xex> by the ax.<rdquo/ <rj><au>Dickens.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>We everywhere meet with Slavonian nations either dominant or
<qex>dominated</qex>.</q> <rj><qau>W. Tooke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dominate</ent><br/
<hw>Dom"i*nate</hw>, <pos>v. i.</pos> <def>To be dominant.</def>
<rj><au>Hallam.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>dominated</ent><br/
<hw>dominated</hw> <pos>adj.</pos> <sn>1.</sn> <def>controlled or ruled
by superior authority or power.</def><br/
<syn><b>Syn. --</b> dominated by, under the thumb
of(predicate).</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>controlled by one's wife; -- of men.</def><br/
<syn><b>Syn. --</b> henpecked.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>dominating</ent><br/
<hw>dominating</hw> <pos>adj.</pos> <sn>1.</sn> <def>exercising
influence or control. Opposite of <ant>subordinate</ant>.</def><br/
<syn><b>Syn. --</b> ascendant, ascendent, prestigious,
dominant.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>high enough to provide a clear view of the
surrounding area; -- of a height or viewpoint.</def><br/
<syn><b>Syn. --</b> commanding, overlooking.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Domination</ent><br/
<hw>Dom`i*na"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>domination</ets>, L. <ets>dominatio</ets>.]</ety> <sn>1.</sn>
<def>The act of dominating; exercise of power in ruling; dominion;
supremacy; authority; often, arbitrary or insolent sway.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In such a people, the haughtiness of <qex>domination</qex>
combines with the spirit of freedom.</q> <rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A ruling party; a party in power.</def>
<mark>[R.]</mark> <rj><au>Burke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <pluf>pl.</pluf> <def>A high order of angels in the
celestial hierarchy; -- a meaning given by the schoolmen.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thrones, <qex>dominations</qex>, princedoms, virtues, powers.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dominative</ent><br/
<hw>Dom"i*na*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>dominatif</ets>.]</ety> <def>Governing; ruling; imperious.</def>
<rj><au>Sir E. Sandys.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dominator</ent><br/
<hw>Dom"i*na`tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.]</ety> <def>A
ruler or ruling power.</def> <ldquo/Sole <xex>dominator</xex> of
Navarre.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Jupiter and Mars are <qex>dominators</qex> for this northwest part
of the world.</q> <rj><qau>Camden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>dominee</ent><br/
<ent>domine</ent><br/
<mhw><hw>dom"i*ne</hw>, <hw>dominee</hw></mhw> <pr>(?)</pr>,
<pos>n.</pos> <ety>[See <er>Dominie</er>.]</ety> <sn>1.</sn> <def>A name
given to a pastor of the Reformed Church. The word is also applied
locally in the United States, in colloquial speech, to any
clergyman.</def><br/
<syn><b>Syn. --</b> dominus, dominie.</syn><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <ety>[From Sp. <ets>domine</ets> a schoolmaster.]</ety>
<fld>(Zool.)</fld> <def>A West Indian fish (<spn>Epinula
magistralis</spn>), of the family <fam>Trichiurid<ae/</fam>. It is a
long-bodied, voracious fish.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Domineer</ent><br/
<hw>Dom`i*neer"</hw> <pr>(?)</pr>, <pos>v. i. & t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Domineered</conjf> <pr>(?)</pr>;
<pos>p. pr. & vb. n.</pos> <conjf>Domineering</conjf>.]</vmorph>
<ety>[F. <ets>dominer</ets>, L. <ets>dominari</ets>: cf. OD.
<ets>domineren</ets> to feast luxuriously. See <er>Dominate</er>,
<pos>v. t.</pos>]</ety> <def>To rule with insolence or arbitrary sway;
to play the master; to be overbearing; to tyrannize; to bluster; to
swell with conscious superiority or haughtiness; -- often with
<xex>over</xex>; <as>as, to <ex>domineer</ex> over
dependents</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Go to the feast, revel and <qex>domineer</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>His wishes tend abroad to roam,<br/
And hers to <qex>domineer</qex> at home.</q>
<rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Domineering</ent><br/
<hw>Dom`i*neer"ing</hw>, <pos>a.</pos> <def>Ruling arrogantly;
overbearing.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A violent, brutal, <qex>domineering</qex> old reprobate.</q>
<rj><qau>Blackw. Mag.</qau></rj></p>

<p><syn><b>Syn.</b> -- Haughty; overbearing; lordly. See
<er>Imperious</er>.</syn> -- <wordforms><wf>Dom`i*neer"ing*ly</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dominical</ent><br/
<hw>Do*min"ic*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[LL.
<ets>dominicalis</ets>, for L. <ets>dominicus</ets> belonging to a
master or lord (<ets>dominica dies</ets> the Lord's day), fr.
<ets>dominus</ets> master or lord: cf. F. <ets>dominical</ets>. See
<er>Dame</er>.]</ety> <sn>1.</sn> <def>Indicating, or pertaining to, the
Lord's day, or Sunday.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Relating to, or given by, our Lord; <as>as, the
<ex>dominical</ex> (or Lord's) prayer</as>.</def>
<rj><au>Howell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Some words altered in the <qex>dominical</qex> Gospels.</q>
<rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dominical altar</b></col> <fld>(Eccl.)</fld>, <cd>the
high altar.</cd> -- <col><b>Dominical letter</b></col>, <cd>the letter
which, in almanacs, denotes Sunday, or the Lord's day (<xex>dies
Domini</xex>). The first seven letters of the alphabet are used for this
purpose, the same letter standing for Sunday during a whole year (except
in leap year, when the letter is changed at the end of February). After
twenty-eight years the same letters return in the same order. The
dominical letters go backwards one day every common year, and two every
leap year; <it>e. g.</it>, if the dominical letter of a common year be
G, F will be the dominical letter for the next year. Called also
<altname>Sunday letter</altname>. Cf. <cref>Solar cycle</cref>, under
<er>Cycle</er>, <pos>n.</pos></cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dominical</ent><br/
<hw>Do*min"ic*al</hw>, <pos>n.</pos> <def>The Lord's day or Sunday;
also, the Lord's prayer.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dominican</ent><br/
<hw>Do*min"i*can</hw> <pr>(?)</pr>, <pos>prop. a.</pos> <ety>[NL.
<ets>Dominicanus</ets>, fr. <ets>Dominicus</ets>, <ets>Dominic</ets>,
the founder: cf. F. <ets>Dominicain</ets>.]</ety> <def>Of or pertaining
to <person>St. Dominic</person> (<person>Dominic de Guzman</person>), or
to the religious communities named from him.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dominican nuns</b></col>, <cd>an order of nuns founded by
<person>St. Dominic</person>, and chiefly employed in teaching.</cd> --
<col><b>Dominican tertiaries</b></col> <cd>the third order of St.
Dominic. See <er>Tertiary</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dominican</ent><br/
<hw>Do*min"i*can</hw>, <pos>prop. n.</pos> <fld>(Eccl. Hist.)</fld>
<def>One of an order of mendicant monks founded by Dominic de Guzman, in
1215. A province of the order was established in England in 1221. The
first foundation in the United States was made in 1807. The Master of
the Sacred Palace at Rome is always a Dominican friar. The Dominicans
are called also <altname>preaching friars</altname>, <altname>friars
preachers</altname>, <altname>black friars</altname> (from their black
cloak), <altname>brothers of St. Mary</altname>, and in France,
<altname>Jacobins</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>dominicide</ent><br/
<hw>do*min"i*cide</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>dominus</ets> master + <ets>caedere</ets> to cut down, kill.]</ety>
<sn>1.</sn> <def>The act of killing a master.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who kills his master.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dominick</ent><br/
<hw>Dom"i*nick</hw> <pos>n.</pos> <fld>(Zool.)</fld>, <def>an American
breed of chicken having barred gray plumage raised for meat and brown
eggs.</def><br/
<syn><b>Syn. --</b> Dominique.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dominie</ent><br/
<hw>Dom"i*nie</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>dominus</ets> master. See <er>Don</er>, <er>Dame</er>.]</ety>
<sn>1.</sn> <def>A schoolmaster; a pedagogue.</def>
<mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>This was Abel Sampson, commonly called, from occupation as a
pedagogue, <qex>Dominie</qex> Sampson.</q> <rj><qau>Sir W.
Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A clergyman. See <er>Domine</er>, 1.</def>
<mark>[Scot. & Colloq. U. S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dominion</ent><br/
<hw>Do*min"ion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL.
<ets>dominio</ets>, equiv. to L. <ets>dominium</ets>. See
<er>Domain</er>, <er>Dungeon</er>.]</ety> <sn>1.</sn> <def>Sovereign or
supreme authority; the power of governing and controlling; independent
right of possession, use, and control; sovereignty; supremacy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I praised and honored him that liveth forever, whose
<qex>dominion</qex> is an everlasting <qex>dominion</qex>.</q>
<rj><qau>Dan. iv. 34.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To choose between <qex>dominion</qex> or slavery.</q>
<rj><qau>Jowett (Thucyd. ).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Superior prominence; predominance;
ascendency.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Objects placed foremost ought . . . have <qex>dominion</qex> over
things confused and transient.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which is governed; territory over which
authority is exercised; the tract, district, or county, considered as
<xex>subject</xex>; <as>as, the <ex>dominions</ex> of a king</as>. Also
used figuratively; <as>as, the <ex>dominion</ex> of the
passions</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <pluf>pl.</pluf> <def>A supposed high order of angels;
dominations. See <er>Domination</er>, 3.</def>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>By him were all things created . . . whether they be thrones, or
<qex>dominions</qex>, or principalities, or powers.</q> <rj><qau>Col. i.
16.</qau></rj></p>

<p><syn><b>Syn.</b> -- Sovereignty; control; rule; authority;
jurisdiction; government; territory; district; region.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dominion Day</ent><br/
<hw>Do*min"ion Day</hw>. <def>In Canada, a legal holiday, July lst,
being the anniversary of the proclamation of the formation of the
Dominion in 1867.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Dominique</ent><br/
<hw>Dominique</hw> <pos>n.</pos> <fld>(Zool.)</fld>, <def>an American
breed of chicken having barred gray plumage raised for meat and brown
eggs.</def><br/
<syn><b>Syn. --</b> Dominick.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Domino</ent><br/
<hw>Dom"i*no</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Dominos</plw> or <pr>(esp. the pieces for a game)</pr>
<plw>Dominoes</plw> <pr>(#)</pr>.</plu> <ety>[F. <ets>domino</ets>, or
It. <ets>domin<ograve/</ets>, or Sp. <ets>domin<oacute/</ets>, fr. L.
<ets>dominus</ets> master. The <ets>domino</ets> was orig. a hood worn
by the canons of a cathedral. See <er>Don</er>, <er>Dame</er>.]</ety>
<sn>1.</sn> <def>A kind of hood worn by the canons of a cathedral
church; a sort of amice.</def> <rj><au>Kersey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A mourning veil formerly worn by women.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A kind of mask; particularly, a half mask worn at
masquerades, to conceal the upper part of the face. Dominos were
formerly worn by ladies in traveling.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A costume worn as a disguise at masquerades,
consisting of a robe with a hood adjustable at pleasure.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A person wearing a domino.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <pluf>pl.</pluf> <def>A game played by two or more
persons, with twenty-eight pieces of wood, bone, or ivory, of a flat,
oblong shape, plain at the back, but on the face divided by a line in
the middle, and either left blank or variously dotted after the manner
of dice. The game is played by matching the spots or the blank of an
unmatched half of a domino already played</def>
<rj><au>Hoyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>One of the pieces with which the game of dominoes is
played.</def> <rj><au>Hoyle.</au></rj></p>

<p><cs><col><b>fall like dominoes</b></col>. <cd>To fall sequentially,
as when one object in a line, by falling against the next object, causes
it in turn to fall, and that second object causes a third to fall, etc.;
the process can be repeated an indefinite number of times.</cd>
<note>The phrase is derived from an entertainment using dominoes
arranged in a row, each standing on edge and therefore easily knocked
over; when the first is made to fall against the next, it starts a
sequence which ends when all have fallen. For amusement, people have
arranged such sequences involving thousands of dominoes, arrayed in
fanciful patterns.</note></cs></p>

<p><ent>Domino theory</ent><br/
<hw>Dom"i*no the"o*ry</hw>. <def>A political theory current in the
1960's, according to which the conversion of one country in South Asia
to communism will start a sequential process causing all Asian countries
to convert to Communism.</def> <note>The apparent assumption was that an
Asian country politically aligned with the West was as politically
unstable as a domino standing on edge. It was used by some as a
justification for American involvement in the Vietnam war,
1964-1972.</note><br/
[<source>PJC</source>]</p>

<p><ent>Domino whist</ent><br/
<hw>Dom"i*no whist</hw>. <def>A game of cards in which the suits are
played in sequence, beginning with a 5 or 9, the player who gets rid of
his cards first being the winner.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Dominus</ent><br/
\'d8<hw>Dom"i*nus</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Domini</plw> <pr>(#)</pr>.</plu> <ety>[L., master. See
<er>Dame</er>.]</ety> <def>Master; sir; -- a title of respect formerly
applied to a knight or a clergyman, and sometimes to the lord of a
manor.</def> <rj><au>Cowell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Domitable</ent><br/
<hw>Dom"i*ta*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>domitare</ets> to tame, fr. <ets>domare</ets>.]</ety> <def>That can
be tamed.</def> <mark>[R.]</mark> <rj><au>Sir M. Hale.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Domite</ent><br/
<hw>Do"mite</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Min.)</fld> <def>A
grayish variety of trachyte; -- so called from the
Puy-de-<xex>D<ocir/me</xex> in Auvergne, France, where it is
found.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Don</ent><br/
<hw>Don</hw> <pr>(d<ocr/n)</pr>, <pos>n.</pos> <ety>[Sp. <ets>don</ets>;
akin to Pg. <ets>dom</ets>, It. <ets>donno</ets>; fr. L.
<ets>dominus</ets> master. See <er>Dame</er>, and cf. <er>Domine</er>,
<er>Dominie</er>, <er>Domino</er>, <er>Dan</er>, <er>Dom</er>.]</ety>
<sn>1.</sn> <def>Sir; Mr; Signior; -- a title in Spain, formerly given
to noblemen and gentlemen only, but now common to all classes.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Don</qex> is used in Italy, though not so much as in Spain.
France talks of <qex>Dom</qex> Calmet, England of <qex>Dan</qex>
Lydgate.</q> <rj><qau>Oliphant.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A grand personage, or one making pretension to
consequence; especially, the head of a college, or one of the fellows at
the English universities.</def> <mark>[Univ. Cant]</mark> <ldquo/The
great <xex>dons</xex> of wit.<rdquo/ <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Don</ent><br/
<hw>Don</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Donned</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Donning</conjf>.]</vmorph> <ety>[<ets>Do</ets> + <ets>on</ets>;
-- opposed to <ets>doff</ets>. See <er>Do</er>, <pos>v. t.</pos>,
7.]</ety> <def>To put on; to dress in; to invest one's self
with.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Should I <qex>don</qex> this robe and trouble you.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>At night, or in the rain,<br/
He <qex>dons</qex> a surcoat which he doffs at morn.</q>
<rj><qau>Emerson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dona</ent><br/
\'d8<hw>Do"<ntil/a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sp.
<ets>do<ntil/a</ets>. See <er>Duenna</er>.]</ety> <sn>1.</sn> <def>Lady;
mistress; madam; -- a title of respect used in Spain, prefixed to the
Christian name of a lady.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A lady or gentlewoman; -- used in Spanish-speaking
countries.</def><br/
[<source>PJC</source>]</p>

<p><ent>Donable</ent><br/
<hw>Do"na*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>donabilis</ets>, fr. <ets>donare</ets> to donate.]</ety>
<def>Capable of being donated or given.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Donar</ent><br/
<hw>Donar</hw> <pos>n.</pos> <def>the Teutonic god of thunder;
counterpart of Norse Thor.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Donary</ent><br/
<hw>Do"na*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>donarium</ets>, fr. <ets>donare</ets>.]</ety> <def>A thing given to
a sacred use.</def> <mark>[R.]</mark> <rj><au>Burton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Donat</ent><br/
<hw>Don"at</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<etsep>Donatus</etsep>, a famous grammarian.]</ety> <def>A
grammar.</def> <mark>[Obs.]</mark> <altsp>[Written also
<asp>donet</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Donatary</ent><br/
<hw>Don"a*ta*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Donatory</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Donate</ent><br/
<hw>Do"nate</hw> <pr>(d<omac/"n<amac/t)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Donated</conjf>; <pos>p. pr. &
vb. n.</pos> <conjf>Donating</conjf>.]</vmorph> <ety>[L.
<ets>donatus</ets>, p. p. of <ets>donare</ets> to donate, fr.
<ets>donum</ets> gift, fr. <ets>dare</ets> to give. See 2d
<er>Date</er>.]</ety> <def>To give; to bestow; to present; <as>as, to
<ex>donate</ex> fifty thousand dollars to a college</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>donated</ent><br/
<hw>donated</hw> <pos>adj.</pos> <def>given freely especially to a cause
or fund; <as>as, the <ex>donated</ex> van made their meal-on-wheels
venture possible</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Donation</ent><br/
<hw>Do*na"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>donatio</ets>; cf. F. <ets>donation</ets>.]</ety> <sn>1.</sn>
<def>The act of giving or bestowing; a grant.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>After <qex>donation</qex> there is an absolute change and
alienation of the property of the thing given.</q>
<rj><au>South.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is given as a present; that which is
transferred to another gratuitously; a gift.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And some <qex>donation</qex> freely to estate<br/
On the bless'd lovers.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Law)</fld> <def>The act or contract by which a
person voluntarily transfers the title to a thing of which be is the
owner, from himself to another, without any consideration, as a free
gift.</def> <rj><au>Bouvier.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Donation party</b></col>, <cd>a party assembled at the
house of some one, as of a clergyman, each one bringing some
present.</cd> <mark>[U.S.]</mark> <rj><au>Bartlett.</au></rj></cs></p>

<p><syn><b>Syn.</b> -- Gift; present; benefaction; grant. See
<er>Gift</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Donatism</ent><br/
<hw>Don"a*tism</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>Donatisme</ets>.]</ety> <fld>(Eccl. Hist.)</fld> <def>The tenets of
the Donatists.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Donatist</ent><br/
<hw>Don"a*tist</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL.
<ets>Donatista</ets>: cf. F. <ets>Donatiste</ets>.]</ety> <fld>(Eccl.
Hist.)</fld> <def>A follower of Donatus, the leader of a body of North
African schismatics and purists, who greatly disturbed the church in the
4th century. They claimed to be the true church.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Donatistic</ent><br/
<hw>Don`a*tis"tic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to
Donatism.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Donative</ent><br/
<hw>Don"a*tive</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>donativum</ets>, fr. <ets>donare</ets>: cf. F. <ets>donatif</ets>.
See <er>Donate</er>.]</ety> <sn>1.</sn> <def>A gift; a largess; a
gratuity; a present.</def> <ldquo/The Romans were entertained with shows
and <xex>donatives</xex>.<rdquo/ <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Eccl. Law)</fld> <def>A benefice conferred on a
person by the founder or patron, without either presentation or
institution by the ordinary, or induction by his orders. See the Note
under <er>Benefice</er>, <pos>n.</pos>, 3.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Donative</ent><br/
<hw>Don"a*tive</hw>, <pos>a.</pos> <def>Vested or vesting by donation;
<as>as, a <ex>donative</ex> advowson</as>.</def>
<rj><au>Blackstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Donator</ent><br/
\'d8<hw>Do*na"tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. Cf.
<er>Donor</er>.]</ety> <fld>(Law)</fld> <def>One who makes a gift; a
donor; a giver.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Donatory</ent><br/
<hw>Don"a*to*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Scots Law)</fld>
<def>A donee of the crown; one the whom, upon certain condition,
escheated property is made over.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Do-naught</ent><br/
<hw>Do"-naught`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Do</ets> +
<ets>naught</ets>.]</ety> <def>A lazy, good-for-nothing
fellow.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Donax</ent><br/
\'d8<hw>Do"nax</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., reed, also a
sea fish, Gr. <?/.]</ety> <fld>(Bot.)</fld> <def>A canelike grass of
southern Europe (<spn>Arundo Donax</spn>), used for fishing rods,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doncella</ent><br/
\'d8<hw>Don*cel"la</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sp., lit., a
maid. Cf. <er>Damsel</er>.]</ety> <fld>(Zool.)</fld> <def>A handsome
fish of Florida and the West Indies (<spn>Platyglossus radiatus</spn>).
The name is applied also to the ladyfish (<spn>Harpe rufa</spn>) of the
same region.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Done</ent><br/
<hw>Done</hw> <pr>(?)</pr>, <def><pos>p. p.</pos> from <er>Do</er>, and
formerly the <pos>infinitive.</pos></def> <sn>1.</sn> <def>Performed;
executed; finished.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>It is done or agreed; let it be a match or bargain;
-- used elliptically.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Done brown</b></col>, <cd>a phrase in cookery; applied
figuratively to one who has been thoroughly deceived, cheated, or
fooled.</cd> <mark>[Colloq.]</mark> -- <col><b>Done for</b></col>,
<cd>tired out; used up; collapsed; destroyed; dead; killed.</cd>
<mark>[Colloq.]</mark> -- <col><b>Done up</b></col>. <sd>(a)</sd>
<cd>Wrapped up</cd>. <sd>(b)</sd> <cd>Worn out; exhausted.</cd>
<mark>[Colloq.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Done</ent><br/
<hw>Done</hw>, <pos>a.</pos> <ety>[Prob. corrupted from OF.
<ets>don<eacute/</ets>, F. <ets>donn<eacute/</ets>, p. p. of OF.
<ets>doner</ets>, F. <ets>donner</ets>, to give, issue, fr. L.
<ets>donare</ets> to give. See <er>Donate</er>, and cf.
<er>Donee</er>.]</ety> <def>Given; executed; issued; made public; --
used chiefly in the clause giving the date of a proclamation or public
act.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Donee</ent><br/
<hw>Do*nee"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>don<eacute/</ets>, F. <ets>donn<eacute/</ets>, p. p. See the
preceding word.]</ety> <sn>1.</sn> <def>The person to whom a gift or
donation is made.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>Anciently, one to whom lands were
given; in later use, one to whom lands and tenements are given in tail;
in modern use, one on whom a power is conferred for execution; --
sometimes called the <xex>appointor</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Donet</ent><br/
<hw>Don"et</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as <er>Donat</er>.
<xex>Piers Plowman</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doni</ent><br/
<hw>Do"ni</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Tamil
<ets>t<?/n<imac/</ets>.]</ety> <fld>(Naut.)</fld> <def>A clumsy craft,
having one mast with a long sail, used for trading purposes on the
coasts of Coromandel and Ceylon.</def> <altsp>[Written also
<asp>dhony</asp>, <asp>doney</asp>, and <asp>done</asp>.]</altsp>
<rj><au>Balfour.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 445 --></p>

<p><ent>Doniferous</ent><br/
<hw>Do*nif"er*ous</hw> <pr>(d<osl/*n<icr/f"<etil/r*<ucr/s)</pr>,
<pos>a.</pos> <ety>[L. <ets>donum</ets> gift +
<ets>-ferous</ets>.]</ety> <def>Bearing gifts.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Donjon</ent><br/
<hw>Don"jon</hw> <pr>(d<ucr/n"j<ucr/n)</pr>, <pos>n.</pos> <ety>[See
<er>Dungeon</er>.]</ety> <def>The chief tower, also called the
<altname>keep</altname>; a massive tower in ancient castles, forming the
strongest part of the fortifications. See <xex>Illust.</xex> of
<er>Castle</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Donkey</ent><br/
<hw>Don"key</hw> <pr>(d<ocr/<nsm/"k<ycr/)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Donkeys</plw>
<pr>(d<ocr/<nsm/"k<icr/z)</pr>.</plu> <ety>[Prob. <ets>dun</ets>, in
allusion to the color of the animal + a dim. termination.]</ety>
<sn>1.</sn> <def>An ass; or (less frequently) a mule.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A stupid or obstinate fellow; an ass.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Donkey engine</b></col>, <cd>a small auxiliary engine not
used for propelling, but for pumping water into the boilers, raising
heavy weights, and like purposes.</cd> -- <col><b>Donkey pump</b></col>,
<cd>a steam pump for feeding boilers, extinguishing fire, etc.; --
usually an auxiliary.</cd> -- <col><b>Donkey's eye</b></col>
<fld>(Bot.)</fld>, <cd>the large round seed of the <spn>Mucuna
pruriens</spn>, a tropical leguminous plant.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>donkey's tail</ent><br/
<hw>donkey's tail</hw> <pos>n.</pos> <def>a Mexican plant (<spn>Sedum
morganianum</spn>) bearing small rose-colored flowers; called also
<altname>burro's tail</altname>, <altname>horse's tail</altname>, and
<altname>lamb's tail</altname>.</def> <au>RHUD</au><br/
[<source>PJC</source>]</p>

<p><ent>donkey's years</ent><br/
<hw>donkey's years</hw> <pos>n.</pos> <def>a very long time; ages.</def>
<mark>[informal]</mark> <br/
[<source>PJC</source>]</p>

<p><ent>donkeywork</ent><br/
<hw>donkeywork</hw> <pos>n.</pos> <def>hard menial routine
work.</def><br/
<syn><b>Syn. --</b> drudgery, grind, scut work.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dongola</ent><br/
<hw>Don"go*la</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A
government of Upper Egypt.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>same as <cref>Dongola kid</cref>.</def></p>

<p><cs><mcol><col><b>Dongola kid</b></col>, <col><b>D.
leather</b></col></mcol>, <cd>leather made by the Dongola process.</cd>
-- <col><b>Dongola process</b></col>, <cd>a process of tanning goatskin,
and now also calfskin and sheepskin, with a combination of vegetable and
mineral agents, so that it resembles kid.</cd> -- <col><b>Dongola
race</b></col>, <cd>a boat race in which the crews are composed of a
number of pairs, usually of men and women.</cd></cs><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Donna</ent><br/
<hw>Don"na</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[It. <ets>donna</ets>,
L. <ets>domina</ets>. See <er>Don</er>, <er>Dame</er>.]</ety> <def>A
lady; madam; mistress; -- the title given a lady in Italy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Donnat</ent><br/
<hw>Don"nat</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Corrupted from
<ets>do-naught</ets>.]</ety> <def>See <er>Do-naught</er>.</def>
<mark>[Prov. Eng.]</mark> <rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Donnee</ent><br/
\'d8<hw>Don`n<eacute/e"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr.
<ets>donner</ets> to give.]</ety> <def>Lit., given; hence, in a literary
work, as a drama or tale, that which is assumed as to characters,
situation, etc., as a basis for the plot or story.</def> <rj><au>W. E.
Henley.</au></rj></p>

<p><q>That favorite romance <qex>donn<eacute/e</qex> of the heir kept
out of his own.</q> <rj><qau>Saintsbury.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Donnian</ent><br/
<hw>Donnian</hw> <pos>adj.</pos> <def>of or pertaining to <person>John
Donne</person>.</def><br/
<syn><b>Syn. --</b> Donnean.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>donnish</ent><br/
<hw>donnish</hw> <pos>adj.</pos> <def>like a university don; marked by a
narrow focus on or display of learning, especially its trivial
aspects.</def><br/
<syn><b>Syn. --</b> academic, pedantic, bookish.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>donnism</ent><br/
<hw>don"nism</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<er>Don</er>,
<pos>n.</pos>, 2.]</ety> <def>Self-importance; loftiness of
carriage.</def> <mark>[Cant, Eng. Universities]</mark><br/
<syn><b>Syn. --</b> donnishness.</syn>
[<source>1913 Webster</source>]</p>

<p><ent>Donor</ent><br/
<hw>Do"nor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>donneur</ets>,
OF. <ets>daneor</ets>, fr. <ets>donner</ets>. See <er>Donee</er>, and
cf. <er>Donator</er>.]</ety> <sn>1.</sn> <def>One who gives or bestows;
one who confers anything gratuitously; a benefactor. Inverse of
<inv>recipient</inv>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>One who grants an estate; in later
use, one who confers a power; -- the opposite of <inv>donee</inv>.</def>
<rj><au>Kent.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Touching, the parties unto deeds and charters, we are to consider
as well the <qex>donors</qex> and granters as the donees or
grantees.</q> <rj><qau>Spelman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>do-nothing</ent><br/
<hw>do"-noth`ing</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Doing nothing;
disinclined to work or exertion; inactive; idle; lazy; -- of people;
<as>as, a <ex>do-nothing</ex> policy</as>.</def>
<mark>[prenominal]</mark><br/
<syn><b>Syn. --</b> bone-idle, bone-lazy, faineant, indolent, lazy,
otiose, shiftless, slothful, workshy, work-shy.</syn><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><ent>do-nothing</ent><br/
<hw>do-nothing</hw> <pos>n.</pos> <def>person who does no
work.</def><br/
<syn><b>Syn. --</b> idler, loafer, layabout, bum, ne'er-do-well,
good-for-nothing.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Do-nothingness</ent><br/
<ent>Do-nothingism</ent><br/
<mhw>{ <hw>Do"-noth`ing*ism</hw> <pr>(?)</pr>,
<hw>Do"-noth`ing*ness</hw> <pr>(?)</pr>, }</mhw> <pos>n.</pos>
<def>Inactivity; habitual sloth; idleness.</def> <mark>[Jocular]</mark>
<rj><au>Carlyle. Miss Austen.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Donship</ent><br/
<hw>Don"ship</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The quality or rank
of a don, gentleman, or knight.</def> <rj><au>Hudibras.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Donzel</ent><br/
<hw>Don"zel</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. It.
<ets>donzello</ets>, Sp. <ets>doncel</ets>, OF. <ets>danzel</ets>. See
<er>Damsel</er>, <er>Don</er>, <pos>n.</pos>]</ety> <def>A young squire,
or knight's attendant; a page.</def> <mark>[Obs.]</mark> <rj><au>Beau. &
Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doo</ent><br/
<hw>Doo</hw> <pr>(d<oomac/)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>A dove.</def> <mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doob grass</ent><br/
<hw>Doob" grass`</hw> <pr>(?)</pr>. <ety>[Hind. <ets>d<?/b</ets>.]</ety>
<fld>(Bot.)</fld> <def>A perennial, creeping grass (<spn>Cynodon
dactylon</spn>), highly prized, in Hindostan, as food for cattle, and
acclimated in the United States.</def> <altsp>[Written also <asp>doub
grass</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>doodle</ent><br/
<hw>doo"dle</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf.
<er>Dawdle</er>.]</ety> <def>A trifler; a simple fellow.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>doodlesack</ent><br/
<hw>doo"dle*sack`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. G.
<ets>dudelsack</ets>.]</ety> <def>The Scotch bagpipe.</def> <mark>[Prov.
Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>doofus</ent><br/
<hw>doo"fus</hw> <pr>(?)</pr>, <pos>n.</pos> <def>a person who is stupid
or inept; -- used contemptuously.</def> <altsp>[Also spelled
<asp>dufus</asp>.]</altsp> <mark>[Slang]</mark><br/
<syn><b>Syn. --</b> dingdong, ding-a-ling.</syn>
[<source>PJC</source>]</p>

<p><ent>doohickey</ent><br/
<hw>doo"hick*ey</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Any object,
usually a tool or other device, whose name is forgotten, or not
known.</def><br/
<syn><b>Syn. --</b> thingumbob, whatchamacallit, whachamacallit.</syn>
[<source>PJC</source>]</p>

<p><ent>doole</ent><br/
<hw>doole</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Sorrow; dole.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dooly</ent><br/
<hw>Doo"ly</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Doolies</plw> <pr>(#)</pr>.</plu> <ety>[Skr.
<ets>d<omac/la</ets>.]</ety> <def>A kind of litter suspended from men's
shoulders, for carrying persons or things; a palanquin.</def>
<altsp>[Written also <asp>doolee</asp> and <asp>doolie</asp>.]</altsp>
<mark>[East Indies]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Having provided <qex>doolies</qex>, or little bamboo chairs slung
on four men's shoulders, in which I put my papers and boxes, we next
morning commenced the ascent.</q> <rj><qau>J. D. Hooker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doom</ent><br/
<hw>Doom</hw> <pr>(d<oomac/m)</pr>, <pos>n.</pos> <ety>[As.
<ets>d<omac/m</ets>; akin to OS. <ets>d<omac/m</ets>, OHG.
<ets>tuom</ets>, Dan. & Sw. <ets>dom</ets>, Icel. <ets>d<omac/mr</ets>,
Goth. <ets>d<omac/ms</ets>, Gr. <grk>qe`mis</grk> law; fr. the root of
E. <ets>do</ets>, v. t. <root/65. See <er>Do</er>, <pos>v. t.</pos>, and
cf. <er>Deem</er>, <er>-dom</er>.]</ety> <sn>1.</sn> <def>Judgment;
judicial sentence; penal decree; condemnation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The first <qex>dooms</qex> of London provide especially the
recovery of cattle belonging to the citizens.</q> <rj><qau>J. R.
Green.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Now against himself he sounds this <qex>doom</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That to which one is doomed or sentenced; destiny or
fate, esp. unhappy destiny; penalty.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Ere Hector meets his <qex>doom</qex>.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And homely household task shall be her <qex>doom</qex>.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Ruin; death.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This is the day of <qex>doom</qex> for Bassianus.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Discriminating opinion or judgment; discrimination;
discernment; decision.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>And there he learned of things and haps to come,<br/
To give foreknowledge true, and certain <qex>doom</qex>.</q>
<rj><qau>Fairfax.</qau></rj></p>

<p><syn><b>Syn.</b> -- Sentence; condemnation; decree; fate; destiny;
lot; ruin; destruction.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doom</ent><br/
<hw>Doom</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Doomed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Dooming</conjf>.]</vmorph> <sn>1.</sn> <def>To judge; to estimate
or determine as a judge.</def> <mark>[Obs.]</mark>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To pronounce sentence or judgment on; to condemn; to
consign by a decree or sentence; to sentence; <as>as, a criminal
<ex>doomed</ex> to chains or death</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Absolves the just, and <qex>dooms</qex> the guilty souls.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To ordain as penalty; hence, to mulct or
fine.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Have I tongue to <qex>doom</qex> my brother's death?</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To assess a tax upon, by estimate or at
discretion.</def> <mark>[New England]</mark> <rj><au>J.
Pickering.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To destine; to fix irrevocably the destiny or fate
of; to appoint, as by decree or by fate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A man of genius . . . <qex>doomed</qex> to struggle with
difficulties.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doomage</ent><br/
<hw>Doom"age</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A penalty or fine for
neglect.</def> <mark>[Local, New England]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doomful</ent><br/
<hw>Doom"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Full of condemnation
or destructive power.</def> <mark>[R.]</mark> <ldquo/That
<xex>doomful</xex> deluge.<rdquo/ <rj><au>Drayton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doom palm</ent><br/
<hw>Doom" palm`</hw> <pr>(?)</pr>. <ety>[Ar. <ets>daum</ets>,
<ets>d<umac/m</ets>: cf. F. <ets>doume</ets>.]</ety> <fld>(Bot.)</fld>
<def>A species of palm tree (<spn>Hyph<ae/ne Thebaica</spn>), highly
valued for the fibrous pulp of its fruit, which has the flavor of
gingerbread, and is largely eaten in Egypt and Abyssinia.</def>
<altsp>[Written also <asp>doum palm</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doomsday</ent><br/
<hw>Dooms"day`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS. <ets>d<?/mes
d<amac/g</ets>. See <er>Doom</er>, and <er>Day</er>.]</ety> <sn>1.</sn>
<def>A day of sentence or condemnation; day of death.</def> <ldquo/My
body's <xex>doomsday</xex>.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The day of the final judgment.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I could not tell till <qex>doomsday</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Doomsday Book</b></col>. <cd>See <er>Domesday
Book</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doomsman</ent><br/
<hw>Dooms"man</hw>, <pos>n.</pos> <ety>[<ets>Doom</ets> +
<ets>man</ets>.]</ety> <def>A judge; an umpire.</def>
<mark>[Obs.]</mark> <rj><au>Hampole.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doomster</ent><br/
<hw>Doom"ster</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Dempster</er>.</def> <mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Door</ent><br/
<hw>Door</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>dore</ets>,
<ets>dure</ets>, AS. <ets>duru</ets>; akin to OS. <ets>dura</ets>,
<ets>dor</ets>, D. <ets>deur</ets>, OHG. <ets>turi</ets>, door,
<ets>tor</ets> gate, G. <ets>th<uum/r</ets>, <ets>thor</ets>, Icel.
<ets>dyrr</ets>, Dan. <ets>d<oum/r</ets>, Sw. <ets>d<oum/rr</ets>, Goth.
<ets>daur</ets>, Lith. <ets>durys</ets>, Russ. <ets>dvere</ets>, Olr.
<ets>dorus</ets>, L. <ets>fores</ets>, Gr. <?/; cf. Skr. <ets>dur</ets>,
<ets>dv<amac/ra</ets>. <root/246. Cf. <er>Foreign</er>.]</ety>
<sn>1.</sn> <def>An opening in the wall of a house or of an apartment,
by which to go in and out; an entrance way.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To the same end, men several paths may tread,<br/
As many <qex>doors</qex> into one temple lead.</q>
<rj><qau>Denham.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The frame or barrier of boards, or other material,
usually turning on hinges, by which an entrance way into a house or
apartment is closed and opened.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>At last he came unto an iron <qex>door</qex><br/
That fast was locked.</q> <rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Passage; means of approach or access.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I am the <qex>door</qex>; by me if any man enter in, he shall be
saved.</q> <rj><qau>John x. 9.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>An entrance way, but taken in the sense of the
<xex>house</xex> or <xex>apartment</xex> to which it leads.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Martin's office is now the second <qex>door</qex> in the
street.</q> <rj><qau>Arbuthnot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<cs><p><mcol><col><b>Blank door</b></col>, <col><b>Blind
door</b></col></mcol>, <cd>etc. <fld>(Arch.)</fld> See under
<er>Blank</er>, <er>Blind</er>, etc.</cd> -- <mcol><col><b>In
doors</b></col>, <it>or</it> <col><b>Within doors</b></col></mcol>,
<cd>within the house.</cd> -- <col><b>Next door to</b></col>, <cd>near
to; bordering on.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>A riot unpunished is but <qex>next door to</qex> a tumult.</q>
<rj><qau>L'Estrange.</qau></rj></p>

<p>-- <mcol><col><b>Out of doors</b></col>, <it>or</it> <col><b>Without
doors</b></col>, and, <mark>[colloquially]</mark>, <col><b>Out
doors</b></col></mcol>, <cd>out of the house; in open air; abroad; away;
lost.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>His imaginary title of fatherhood is <qex>out of doors</qex>.</q>
<rj><qau>Locke.</qau></rj></p>

<p>-- <col><b>To lay (a fault, misfortune, etc.) at one's
door</b></col>, <cd>to charge one with a fault; to blame for.</cd> --
<col><b>To lie at one's door</b></col>, <cd>to be imputable or
chargeable to.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>If I have failed, the fault <qex>lies</qex> wholly <qex>at my
door</qex>.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p></cs>

<p><note><hand/ <xex>Door</xex> is used in an adjectival construction or
as the first part of a compound (with or without the hyphen), as,
<xex>door</xex> frame, <xex>door</xex>bell or <xex>door</xex> bell,
<xex>door</xex> knob or <xex>door</xex>knob, <xex>door</xex> latch or
<xex>door</xex>latch, <xex>door</xex> jamb, <xex>door</xex> handle,
<xex>door</xex> mat, <xex>door</xex> panel.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>doorbell</ent><br/
<hw>doorbell</hw> <pos>n.</pos> <def>a bell or other sounding device,
actuated by a push button at an outer door; the push button activating
the bell; alos, the ringing of such a bell; <as>as, I was in the shower
and didn't hear the <ex>doorbell</ex></as>.</def><br/
<syn><b>Syn. --</b> bell, buzzer.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Doorcase</ent><br/
<hw>Door"case`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The surrounding
frame into which a door shuts.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doorcheek</ent><br/
<hw>Door"cheek`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The jamb or
sidepiece of a door.</def> <rj><au>Ex. xii. 22 (Douay
version).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doorga</ent><br/
\'d8<hw>Door"ga</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Skr.
<ets>Durg<amac/</ets>.]</ety> <fld>(Myth.)</fld> <def>A Hindoo divinity,
the consort of Siva, represented with ten arms.</def> <mark>[Written
also Durga.]</mark> <rj><au>Malcom.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dooring</ent><br/
<hw>Door"ing</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The frame of a
door.</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doorkeeper</ent><br/
<hw>Door"keep`er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who guards
the entrance of a house or apartment; a porter; a janitor.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>doorknocker</ent><br/
<hw>doorknocker</hw> <pos>n.</pos> <def>a device (usually metal and
ornamental) attached by a hinge to a door, which may be swung by hand
against the door to make a loud knocking sound.</def><br/
<syn><b>Syn. --</b> knocker.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Doorless</ent><br/
<hw>Door"less</hw>, <pos>a.</pos> <def>Without a door.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>doorlock</ent><br/
<hw>doorlock</hw> <pos>n.</pos> <def>a lock on an exterior
door.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>doorman</ent><br/
<hw>doorman</hw> <pos>n.</pos> <def>someone who guards the entrance to a
building.</def><br/
<syn><b>Syn. --</b> doorkeeper, door guard, hall porter, porter,
gatekeeper.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>doormat</ent><br/
<hw>doormat</hw> <pos>n.</pos> <sn>1.</sn> <def>a mat placed outside and
exterior door for wiping the shoes before entering.</def>
<wns>[wns=2]</wns><br/
<syn><b>Syn. --</b> welcome mat.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <mark>(figurative)</mark> <def>A person who is habitually
abused, taken advantage of or humiliated; sometimes, one who is
physically weak; <as>as, they used him for a
<ex>doormat</ex></as>.</def> <wns>[wns=1]</wns><br/
<syn><b>Syn. --</b> weakling.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Doornail</ent><br/
<hw>Door"nail`</hw> <pr>(d<omac/r"n<amac/l`)</pr>, <pos>n.</pos>
<def>The nail or knob on which in ancient doors the knocker struck; --
hence the old saying, <ldquo/As dead as a
<xex>doornail</xex>.<rdquo/</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doorplane</ent><br/
<hw>Door"plane`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A plane on a door,
giving the name, and sometimes the employment, of the
occupant.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doorpost</ent><br/
<hw>Door"post`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The jamb or
sidepiece of a doorway.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doorsill</ent><br/
<hw>Door"sill`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The sill or
threshold of a door.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doorstead</ent><br/
<hw>Door"stead</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Entrance or place
of a door.</def> <mark>[Obs. or Local]</mark> <rj><au>Bp.
Warburton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doorstep</ent><br/
<hw>Door"step`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The stone or plank
forming a step before an outer door.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doorstone</ent><br/
<hw>Door"stone`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The stone forming
a threshold.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>doorstop</ent><br/
<hw>door"stop`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Carp.)</fld>
<def>The block or strip of wood or similar material which stops, at the
right place, the shutting of a door; any object used to stop open doors
from moving.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>doorstopper</ent><br/
<hw>door"stop*per</hw> <pos>n.</pos> <def>same as
<er>doorstop</er>.</def><br/
<syn><b>Syn. --</b> doorstop.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>door-to-door</ent><br/
<hw>door-to-door</hw> <pos>adj.</pos> <sn>1.</sn> <def>direct without
intermediate changes of vehicle; -- of e.g. journeys or deliveries;
<as>as, the limousine offers direct <ex>door-to-door</ex>
service</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>omitting no one; from the door of one house to that
of the next; <as>as, a <ex>door-to-door</ex> solicitation, canvass, or
campaign</as>.</def><br/
<syn><b>Syn. --</b> house-to-house.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Doorway</ent><br/
<hw>Door"way`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The passage of a
door; entrance way into a house or a room.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dooryard</ent><br/
<hw>Door"yard`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A yard in front of
a house or around the door of a house.</def></p>

<p><ent>Doop</ent><br/
<ent>Dop</ent><br/
<mhw>{ <hw>Dop</hw>, <hw>Doop</hw> }</mhw> <pr>(?)</pr>, <pos>n.</pos>
<def>A little copper cup in which a diamond is held while being
cut.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dop</ent><br/
<hw>Dop</hw>, <pos>v. i.</pos> <ety>[Cf. <er>Dap</er>,
<er>Dip</er>.]</ety> <def>To dip.</def> <mark>[Obs.]</mark>
<rj><au>Walton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dop</ent><br/
<hw>Dop</hw>, <pos>n.</pos> <def>A dip; a low courtesy.</def>
<mark>[Obs.]</mark> <rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dopant</ent><br/
<hw>Dop"ant</hw> <pr>(d<omac/p"<ait/nt)</pr>, <pos>n.</pos> <def>a
foreign substance added to a material to alter its properties; -- a
process used. e.g., in making semiconductors from pure silicon in the
manufacture of semiconductor chips and integrated circuits.</def><br/
[<source>PJC</source>]</p>

<p><ent>Dope</ent><br/
<hw>Dope</hw> <pr>(d<omac/p)</pr>, <pos>n.</pos> <ety>[D.
<ets>doop</ets> a dipping, fr. <ets>doopen</ets> to dip. Cf.
<er>Dip</er>.]</ety> <sn>1.</sn> <def>Any thick liquid or pasty
preparation, as of opium for medicinal purposes, of grease for a
lubricant, etc.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>Any preparation, as of opium, used to stupefy or, in
the case of a race horse, to stimulate.</def> <mark>[Slang or
Cant]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>3.</sn> <def>An absorbent material; esp., in high explosives, the
sawdust, infusorial earth, mica, etc., mixed with nitroglycerin to make
a damp powder (dynamite, etc.) less dangerous to transport, and
ordinarily explosive only by suitable fulminating caps.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>4.</sn> <def>Information concerning the previous performances of
race horses, or other facts concerning them which may be of assistance
in judging of their chances of winning future races; similar information
concerning other sports; by extension, any information not generally
known, especially when coming from an inside source; <as>as, the inside
<ex>dope</ex></as>.</def> <mark>[Sporting Slang]</mark><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><sn>5.</sn> <def>an ignorant or stupid person.</def>
<mark>[Colloq.]</mark><br/
[<source>PJC</source>]</p>

<p><cs><col><b>get the dope on</b></col> <cd>learn the true story; get
the inside information.</cd></cs></p>

<p><ent>Dope</ent><br/
<hw>Dope</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To treat or affect with
dope; <as>as, to <ex>dope</ex> nitroglycerin</as>;</def>
<specif>specif.:</specif> <sd>(a)</sd> <def>To give stupefying drugs to;
to drug.</def> <mark>[Slang]</mark> <sd>(b)</sd> <def>To administer a
stimulant to (a horse) to increase his speed. It is a serious offense
against the laws of racing.</def> <mark>[Race-track Slang]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>To judge or guess; to predict the result of, as by
the aid of dope.</def> <mark>[Slang]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>3.</sn> <def>to impregnate with a dopant.</def><br/
[<source>PJC</source>]</p>

<p><ent>Dope-book</ent><br/
<hw>Dope"-book`</hw>, <pos>n.</pos> <def>A chart of previous
performances, etc., of race horses; a racing form.</def>
<mark>[Race-track Slang]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Dopy</ent><br/
<ent>Dopey</ent><br/
<mhw><hw>Dop"ey</hw>, <hw>Dop"y</hw></mhw> <pr>(?)</pr>, <pos>a.</pos>
<sn>1.</sn> <def>stupid; <as>as, a <ex>dopy</ex> kid</as>.</def>
<mark>[Colloq.]</mark><br/
<syn><b>Syn. --</b> cloddish, doltish.</syn><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <ety>[affected by <er>dope{2}</er>.]</ety> <def>dulled or
stupefied by alcohol or narcotics; sluggish or dull as though under the
influence of a narcotic.</def> <mark>[Slang]</mark><br/
[<source>Webster 1913 Suppl.</source> + <source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><sn>3.</sn> <def>revealing stupidity; <as>as, a <ex>dopey</ex>
answer</as>.</def> <wns>[wns=2]</wns><br/
<syn><b>Syn. --</b> anserine, dopey, fool(prenominal), foolish, goosey,
goosy, gooselike.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Doppelganger</ent><br/
\'d8<hw>Dop"pel*g<aum/ng`er</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[G.]</ety> <def>A spiritual or ghostly double or counterpart; esp.,
an apparitional double of a living person; a cowalker.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Dopper</ent><br/
<hw>Dop"per</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[D.
<ets>dooper</ets>.]</ety> <altsp>[Written also
<asp>doper</asp>.]</altsp> <def>An Anabaptist or Baptist.</def>
<mark>[Contemptuous]</mark> <rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dopplerite</ent><br/
<hw>Dop"pler*ite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Named after the
physicist and mathematician Christian <etsep>Doppler</etsep>.]</ety>
<fld>(Min.)</fld> <def>A brownish black native hydrocarbon occurring in
elastic or jellylike masses.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doquet</ent><br/
<hw>Doq"uet</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A warrant. See
<er>Docket</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dor</ent><br/
<hw>Dor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. AS. <ets>dora</ets>
drone, locust, D. <ets>tor</ets> beetle, L. <ets>taurus</ets> a kind of
beetle. Cf. <er>Dormouse</er>.]</ety> <fld>(Zool.)</fld> <def>A large
European scaraboid beetle (<spn>Geotrupes stercorarius</spn>), which
makes a droning noise while flying. The name is also applied to allied
American species, as the <altname>June bug</altname>. Called also
<altname>dorr</altname>, <altname>dorbeetle</altname>, or
<altname>dorrbeetle</altname>, <altname>dorbug</altname>,
<altname>dorrfly</altname>, and <altname>buzzard
clock</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dor</ent><br/
<hw>Dor</hw>, <pos>n.</pos> <ety>[Cf. <er>Dor</er> a beetle, and
<er>Hum</er>, <er>Humbug</er>.]</ety> <def>A trick, joke, or
deception.</def> <rj><au>Beau. & Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To give one the dor</b></col>, <cd>to make a fool of
him.</cd> <mark>[Archaic]</mark> <rj><au>P. Fletcher.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dor</ent><br/
<hw>Dor</hw>, <pos>v. t.</pos> <def>To make a fool of; to deceive.</def>
<mark>[Obs.]</mark> <altsp>[Written also <asp>dorr</asp>.]</altsp>
<rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dorado</ent><br/
<hw>Do*ra"do</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sp.
<ets>dorado</ets> gilt, fr. <ets>dorar</ets> to gild, fr. L.
<ets>deaurare</ets>. See 1st <er>Dory</er>, and cf. <er>Fl
Dorado</er>.]</ety> <sn>1.</sn> <fld>(Astron.)</fld> <def>A southern
constellation, within which is the south pole of the ecliptic; -- called
also sometimes <xex>Xiphias</xex>, or the
<xex>Swordfish</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>A large, oceanic fish of the
genus <gen>Coryph<ae/na</gen>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dorbeetle</ent><br/
<hw>Dor"bee`tle</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>See 1st <er>Dor</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doree</ent><br/
<hw>Do"ree</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Dory</er>.]</ety> <fld>(Zool.)</fld> <def>A European marine fish
(<spn>Zeus faber</spn>), of a yellow color. See <xex>Illust.</xex> of
<er>John Doree</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The popular name in England is <altname>John
Doree</altname>, or <altname>Dory</altname>, well known to be a
corruption of F. <xex>jaune-dor<eacute/e</xex>, <it>i. e.</it>,
golden-yellow. See 1st <er>Dory</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doretree</ent><br/
<hw>Dore"tree`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A doorpost.</def>
<mark>[Obs.]</mark> <ldquo/As dead as a <xex>doretree</xex>.<rdquo/
<rj><au>Piers Plowman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dorhawk</ent><br/
<hw>Dor"hawk`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>The European goatsucker; -- so called because it eats the
<xex>dor</xex> beetle. See <er>Goatsucker</er>.</def> <altsp>[Written
also <asp>dorrhawk</asp>.]</altsp> <rj><au>Booth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dorian</ent><br/
<hw>Do"ri*an</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Of or
pertaining to the ancient Greeks of Doris; Doric; <as>as, a
<ex>Dorian</ex> fashion</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mus.)</fld> <def>Same as <er>Doric</er>, 3.</def>
<ldquo/<xex>Dorian</xex> mood.<rdquo/ <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dorian mode</b></col> <fld>(Mus.)</fld>, <cd>the first of
the authentic church modes or tones, from D to D, resembling our D minor
scale, but with the B natural.</cd> <rj><au>Grove.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dorian</ent><br/
<hw>Do"ri*an</hw>, <pos>n.</pos> <def>A native or inhabitant of Doris in
Greece.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doric</ent><br/
<hw>Dor"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>Doricus</ets>,
Gr. <?/, fr. <?/ the Dorians.]</ety> <sn>1.</sn> <def>Pertaining to
Doris, in ancient Greece, or to the Dorians; <as>as, the <ex>Doric</ex>
dialect</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Arch.)</fld> <def>Belonging to, or resembling, the
oldest and simplest of the three orders of architecture used by the
Greeks, but ranked as second of the five orders adopted by the Romans.
See <er>Abacus</er>, <er>Capital</er>, <er>Order</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ This order is distinguished, according to the treatment
of details, as <xex>Grecian Doric</xex>, or <xex>Roman
Doric</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Mus.)</fld> <def>Of or relating to one of the
ancient Greek musical modes or keys. Its character was adapted both to
religions occasions and to war.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doric</ent><br/
<hw>Dor"ic</hw>, <pos>n.</pos> <def>The Doric dialect.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doricism</ent><br/
<hw>Dor"i*cism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A Doric phrase or
idiom.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doris</ent><br/
\'d8<hw>Do"ris</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>Doris</ets>, the daughter of Oceanus, and wife of Nereus, Gr.
<?/.]</ety> <fld>(Zool.)</fld> <def>A genus of nudibranchiate mollusks
having a wreath of branchi<ae/ on the back.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dorism</ent><br/
<hw>Do"rism</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/.]</ety>
<def>A Doric phrase or idiom.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>dork</ent><br/
<hw>dork</hw> <pr>(d<ocir/rk)</pr>, <pos>n.</pos> <sn>1.</sn> <def>a
person who is stupid, socially inept, or ridiculous; -- always used
disparagingly.</def> <mark>[slang.]</mark> <br/
<syn><b>Syn. --</b> nerd; jerk.</syn>
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>the penis.</def> <mark>[vulgar slang]</mark><br/
[<source>PJC</source>]</p>

<p><ent>Dorking fowl</ent><br/
<hw>Dor"king fowl`</hw> <pr>(d<ocir/r"k<icr/ng foul`)</pr>. <ety>[From
the town of <ets>Dorking</ets> in England.]</ety> <fld>(Zool.)</fld>
<def>One of a breed of large-bodied domestic fowls, having five toes, or
the hind toe double. There are several strains, as the <xex>white</xex>,
<xex>gray</xex>, and <xex>silver-gray</xex>. They are highly esteemed
for the table.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>dorky</ent><br/
<hw>dork"y</hw> <pr>(d<ocir/rk"<emac/)</pr>, <pos>n.</pos> <def>stupid,
socially inept, unfashionable, or ridiculous; -- always used
disparagingly.</def> <mark>[slang.]</mark> <br/
<syn><b>Syn. --</b> nerd; jerk.</syn>
[<source>PJC</source>]</p>

<p><ent>Dorm</ent><br/
<hw>Dorm</hw> <pr>(?)</pr>, <pos>n.</pos> <def>a dormitory.</def>
<mark>[College slang.]</mark> <br/
[<source>PJC</source>]</p>

<p><ent>Dormancy</ent><br/
<hw>Dor"man*cy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<er>Dormant</er>.]</ety> <def>The state of being dormant; quiescence;
abeyance.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dormancy</ent><br/
<hw>Dor"man*cy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<er>Dormant</er>.]</ety> <def>The state of being dormant; quiescence;
abeyance.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It is by lying <qex>dormant</qex> a long time, or being . . . very
rarely exercised, that arbitrary power steals upon a people.</q>
<rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Her.)</fld> <def>In a sleeping posture; <as>as, a
lion <ex>dormant</ex></as>; -- distinguished from
<contr>couchant</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dormant partner</b></col> <fld>(Com.)</fld>, <cd>a
partner who takes no share in the active business of a company or
partnership, but is entitled to a share of the profits, and subject to a
share in losses; -- called also <altname>sleeping partner</altname>
<it>or</it> <altname>silent partner</altname>.</cd> -- <col><b>Dormant
window</b></col> <fld>(Arch.)</fld>, <cd>a dormer window. See
<er>Dormer</er>.</cd> -- <col><b>Table dormant</b></col>, <cd>a
stationary table.</cd> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dormant</ent><br/
<hw>Dor"mant</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Dormant</er>, <pos>a.</pos>]</ety> <fld>(Arch.)</fld> <def>A large
beam in the roof of a house upon which portions of the other timbers
rest or <ldquo/ sleep.<rdquo/</def> <au>Arch. Pub. Soc.</au> -- Called
also <altname>dormant tree</altname>, <altname>dorman tree</altname>,
<altname>dormond</altname>, and <altname>dormer</altname>.
<rj><au>Halliwell.</au></rj></p>

<p><ent>Dormer window</ent><br/
<ent>Dormer</ent><br/
<mhw><hw>Dor"mer</hw> <pr>(?)</pr>, <it>or</it> <hw>Dor"mer win"dow</hw>
<pr>(<?/)</pr></mhw>, <pos>n.</pos> <ety>[Literally, the window of a
sleeping apartment. F. <ets>dormir</ets> to sleep. See <er>Dormant</er>,
<pos>a.</pos> & <pos>n.</pos>]</ety> <fld>(Arch.)</fld> <def>A window
pierced in a roof, and so set as to be vertical while the roof slopes
away from it. Also, the gablet, or houselike structure, in which it is
contained.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dormitive</ent><br/
<hw>Dor"mi*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>dormitif</ets>, fr. <ets>dormire</ets> to sleep.]</ety>
<def>Causing sleep; <as>as, the <ex>dormitive</ex> properties of
opium</as>.</def> <au>Clarke.</au> -- <def2><pos>n.</pos>
<fld>(Med.)</fld> <def>A medicine to promote sleep; a soporific; an
opiate.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dormitory</ent><br/
<hw>Dor"mi*to*ry</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Dormitories</plw> <pr>(#)</pr>.</plu> <ety>[L.
<ets>dormitorium</ets>, fr. <ets>dormitorius</ets> of or for sleeping,
fr. <ets>dormire</ets> to sleep. See <er>Dormant</er>.]</ety>
<sn>1.</sn> <def>A sleeping room, or a building containing a series of
sleeping rooms; a sleeping apartment capable of containing many beds;
esp., one connected with a college or boarding school.</def>
<rj><au>Thackeray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A burial place.</def> <mark>[Obs.]</mark>
<rj><au>Ayliffe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>My sister was interred in a very honorable manner in our
<qex>dormitory</qex>, joining to the parish church.</q>
<rj><qau>Evelyn.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dormouse</ent><br/
<hw>Dor"mouse</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Dormice</plw> <pr>(#)</pr>.</plu> <ety>[Perh. fr. F.
<ets>dormir</ets> to sleep (Prov. E. <ets>dorm</ets> to doze) + E.
<ets>mouse</ets>; or perh. changed fr. F. <ets>dormeuse</ets>, fem., a
sleeper, though not found in the sense of <ets>a dormouse</ets>.]</ety>
<fld>(Zool.)</fld> <def>A small European rodent of the genus
<gen>Myoxus</gen>, of several species. They live in trees and feed on
nuts, acorns, etc.; -- so called because they are usually torpid in
winter.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dormy</ent><br/
<hw>Dor"my</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Origin
uncertain.]</ety> <fld>(Golf)</fld> <def>Up, or ahead, as many holes as
remain to be played; -- said of a player or side.</def></p>

<p><note><hand/ A player who is <xex>dormy</xex> can not be beaten, and
at the worst must halve the match. <rj><au>Encyc. of
Sport.</au></rj></note><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Dorn</ent><br/
<hw>Dorn</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. G. <ets>dorn</ets>
thorn, D. <ets>doorn</ets>, and G. <ets>dorn</ets>fisch
stickleback.]</ety> <fld>(Zool.)</fld> <def>A British ray; the
thornback.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 446 --></p>

<p><ent>Dornock</ent><br/
<ent>Dornick</ent><br/
<mhw>{ <hw>Dor"nick</hw> <pr>(?)</pr>, <it>or</it> <hw>Dor"nock</hw>
<pr>(?)</pr> }</mhw>, <pos>n.</pos> <def>A coarse sort of damask,
originally made at Tournay (in Flemish, <etsep>Doornick</etsep>),
Belgium, and used for hangings, carpets, etc. Also, a stout figured
linen manufactured in Scotland.</def> <altsp>[Formerly written also
<asp>darnex</asp>, <asp>dornic</asp>, <asp>dorneck</asp>, etc.]</altsp>
<rj><au>Halliwell.</au> <au>Jamieson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Ure says that <xex>dornock</xex>, a kind of stout
figured linen, derives its name from a town in Scotland where it was
first manufactured for tablecloths.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dorp</ent><br/
<hw>Dorp</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LG. & D.
<ets>dorp</ets>. See <er>Thorpe</er>.]</ety> <def>A hamlet.</def>
<ldquo/A mean fishing <xex>dorp</xex>.<rdquo/
<rj><au>Howell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dorr</ent><br/
<hw>Dorr</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The dorbeetle; also, a
drone or an idler. See 1st <er>Dor</er>.</def> <rj><au>Robynson (More's
Utopia).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dorr</ent><br/
<hw>Dorr</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To deceive.
<mark>[Obs.]</mark> See <er>Dor</er>, <pos>v. t.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To deafen with noise.</def> <mark>[Obs.]</mark>
<rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dorrfly</ent><br/
<hw>Dorr"fly`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>See 1st <er>Dor</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dorrhawk</ent><br/
<hw>Dorr"hawk`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>See <er>Dorhawk</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dorsad</ent><br/
<hw>Dor"sad</hw> <pr>(?)</pr>, <pos>adv.</pos> <ety>[<ets>Dorsum</ets>
+L. <ets>ad</ets> towards.]</ety> <fld>(Anat.)</fld> <def>Toward the
dorsum or back; on the dorsal side; dorsally.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dorsal</ent><br/
<hw>Dor"sal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F. <ets>dorsal</ets>,
LL. <ets>dorsalis</ets>, fr. L. <ets>dorsualis</ets>, fr.
<ets>dorsum</ets> back; cf. Gr. <?/, <?/, mountain ridge. Cf.
<er>Dorse</er>, <er>Dorsel</er>, <er>Dosel</er>.]</ety> <sn>1.</sn>
<fld>(Anat.)</fld> <def>Pertaining to, or situated near, the back, or
dorsum, of an animal or of one of its parts; notal; tergal; neural;
<as>as, the <ex>dorsal</ex> fin of a fish; the <ex>dorsal</ex> artery of
the tongue</as>; -- opposed to <contr>ventral</contr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <sd>(a)</sd> <def>Pertaining to the
surface naturally inferior, as of a leaf.</def> <sd>(b)</sd>
<def>Pertaining to the surface naturally superior, as of a creeping
hepatic moss.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dorsal vessel</b></col> <fld>(Zool.)</fld>, <cd>a central
pulsating blood vessel along the back of insects, acting as a
heart.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dorsal</ent><br/
<hw>Dor"sal</hw>, <pos>n.</pos> <ety>[LL. <ets>dorsale</ets>, neut. fr.
<ets>dorsalis</ets>. See <er>Dorsal</er>, <pos>a.</pos>]</ety>
<fld>(Fine Arts)</fld> <def>A hanging, usually of rich stuff, at the
back of a throne, or of an altar, or in any similar position.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dorsale</ent><br/
<hw>Dor"sale</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Dorsal</er>, <pos>n.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dorsally</ent><br/
<hw>Dor"sal*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <fld>(Anat.)</fld>
<def>On, or toward, the dorsum, or back; on the dorsal side of;
dorsad.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dorse</ent><br/
<hw>Dorse</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. L.
<ets>dorsum</ets> the back. See <er>Dorsel</er>, <er>Dosel</er>.]</ety>
<sn>1.</sn> <def>Same as <er>dorsal</er>, <pos>n.</pos></def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The back of a book.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Books, all richly bound, with gilt <qex>dorses</qex>.</q>
<rj><qau>Wood.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dorse</ent><br/
<hw>Dorse</hw>, <pos>n.</pos> <fld>(Zool.)</fld> <def>The Baltic or
variable cod (<spn>Gadus callarias</spn>), by some believed to be the
young of the common codfish.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dorsel</ent><br/
<hw>Dor"sel</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Dosser</er>.]</ety> <sn>1.</sn> <def>A pannier.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Same as <er>Dorsal</er>, <pos>n.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dorser</ent><br/
<hw>Dor"ser</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Dosser</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>dorsibranchiata</ent><br/
\'d8<hw>dor`si*bran`chi*a"ta</hw> <pr>(?)</pr>, <pos>n. pl.</pos>
<ety>[NL., from L. <ets>dorsum</ets> back + <ets>branchiae</ets>
gills.]</ety> <fld>(Zool.)</fld> <def>A division of ch<ae/topod annelids
in which the branchi<ae/ are along the back, on each side, or on the
parapodia. [See <xex>Illusts</xex>. under <er>Annelida</er> and
<er>Ch<ae/topoda</er>.]</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dorsibranchiate</ent><br/
<hw>Dor`si*bran"chi*ate</hw> <pr>(?)</pr>, <pos>a.</pos>
<fld>(Zool.)</fld> <def>Having branchi<ae/ along the back; belonging to
the Dorsibranchiata.</def> -- <def2><pos>n.</pos> <def>One of the
Dorsibranchiata.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dorsiferous</ent><br/
<hw>Dor*sif"er*ous</hw> <pr>(?)</pr>,. <ety>[<ets>Dorsum</ets> +
<ets>-ferous</ets>; cf. F. <ets>dorsif<egrave/re</ets>.]</ety>
<fld>(Biol.)</fld> <def>Bearing, or producing, on the back; -- applied
to ferns which produce seeds on the back of the leaf, and to certain
Batrachia, the ova of which become attached to the skin of the back of
the parent, where they develop; dorsiparous.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dorsimeson</ent><br/
<hw>Dor`si*mes"on</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Dorsum</ets> + <ets>meson</ets>.]</ety> <def>(Anat.) See
<er>Meson</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dorsiparous</ent><br/
<hw>Dor*sip"a*rous</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Dorsum</ets> + L. <ets>parere</ets> to bring forth.]</ety>
<fld>(Biol.)</fld> <def>Same as <er>Dorsiferous</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dorsiventral</ent><br/
<hw>Dor`si*ven"tral</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>Dorsum</ets> + <ets>ventral</ets>.]</ety> <sn>1.</sn>
<fld>(Biol.)</fld> <def>Having distinct upper and lower surfaces, as
most common leaves. The leaves of the iris are not
<xex>dorsiventral</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Anat.)</fld> <def>See
<er>Dorsoventral</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dorsoventral</ent><br/
<hw>Dor`so*ven"tral</hw> <pr>(?)</pr>, <pos>a.</pos>
<ety>[<ets>dorsum</ets> + <ets>ventral</ets>.]</ety> <fld>(Anat.)</fld>
<def>From the dorsal to the ventral side of an animal; <as>as, the
<ex>dorsoventral</ex> axis</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dorsum</ent><br/
\'d8<hw>Dor"sum</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.]</ety>
<sn>1.</sn> <def>The ridge of a hill.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Anat.)</fld> <def>The back or dorsal region of an
animal; the upper side of an appendage or part; <as>as, the
<ex>dorsum</ex> of the tongue</as>.</def></p>

<p><ent>Dorture</ent><br/
<ent>Dortour</ent><br/
<mhw>{ <hw>Dor"tour</hw> <pr>(?)</pr>, <hw>Dor"ture</hw> <pr>(?)</pr>,
}</mhw> <pos>n.</pos> <ety>[F. <ets>dortoir</ets>, fr. L.
<ets>dormitorium</ets>.]</ety> <def>A dormitory.</def>
<mark>[Obs.]</mark> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dory</ent><br/
<hw>Do"ry</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Dories</plw> <pr>(#)</pr>.</plu> <ety>[Named from 1st color, fr. F.
<ets>dor<eacute/e</ets> gilded, fr. <ets>dorer</ets> to gild, L.
<ets>deaurare</ets>. See <er>Deaurate</er>, and cf.
<er>Aureole</er>.]</ety> <sn>1.</sn> <fld>(Zool.)</fld> <def>A European
fish. See <er>Doree</er>, and <er>John Doree</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>The American wall-eyed perch; --
called also <altname>dor<eacute/</altname>. See <er>Pike
perch</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dory</ent><br/
<hw>Do"ry</hw>, <pos>n.</pos>; <plu><it>pl.</it> <plw>Dories</plw>
<pr>(<?/)</pr>.</plu> <def>A small, strong, flat-bottomed rowboat, with
sharp prow and flaring sides.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doryphora</ent><br/
\'d8<hw>Do*ryph"o*ra</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. See
<er>Doryphoros</er>.]</ety> <fld>(Zool.)</fld> <def>A genus of
plant-eating beetles, including the potato beetle. See <er>Potato
beetle</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doryphoros</ent><br/
\'d8<hw>Do*ryph"o*ros</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., fr. Gr.
<?/, lit., spear bearing; <?/ a spear + <grk>fe`rein</grk> to
bear.]</ety> <fld>(Fine Arts)</fld> <def>A spear bearer; a statue of a
man holding a spear or in the attitude of a spear bearer. Several
important sculptures of this subject existed in antiquity, copies of
which remain to us.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dos-a-dos</ent><br/
\'d8<hw>Dos`-<agrave/-dos"</hw> <pr>(?)</pr>, <pos>adv.</pos>
<ety>[F.]</ety> <def>Back to back; <as>as, to sit
<ex>dos-<agrave/-dos</ex> in a dogcart; to dance
<ex>dos-<agrave/-dos</ex>, or so that two dancers move forward and pass
back to back</as>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Dos-a-dos</ent><br/
\'d8<hw>Dos`-<agrave/-dos"</hw>, <pos>n.</pos> <def>A sofa, open
carriage, or the like, so constructed that the occupants sit back to
back.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Dosage</ent><br/
<hw>Dos"age</hw> <pr>(d<omac/s"<asl/j)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>dosage</ets>. See <er>Dose</er>, <pos>v.</pos>]</ety> <sn>1.</sn>
<fld>(Med.)</fld> <def>The administration of medicine in doses; specif.,
a scheme or system of grading doses of medicine according to age,
etc.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>The process of adding some ingredient, as to wine,
to give flavor, character, or strength.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>3.</sn> <def>same as <er>dose{1}</er>; <as>as, 200 mg
q.i.d.</as></def> <wns>[wns=1]</wns><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <def>the quantity of a medicine or other substance given
to an animal, expressed as a quantity per body weight; <as>as, use a
<ex>dosage</ex> of 10 milligrams per kilogram</as></def> <br/
[<source>PJC</source>]</p>

<p><sn>5.</sn> <def>the quantity of radiation given to or absorbed by an
object; <as>as, a maximum <ex>dosage</ex> of 1 mrad per day is
allowed</as>.</def> <wns>[wns=1]</wns><br/
<syn><b>Syn. --</b> dose.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Dose</ent><br/
<hw>Dose</hw> <pr>(d<omac/s)</pr>, <pos>n.</pos> <ety>[F.
<ets>dose</ets>, Gr. <grk>do`sis</grk> a giving, a dose, fr.
<grk>dido`nai</grk> to give; akin to L. <ets>dare</ets> to give. See
<er>Date</er> point of time.]</ety> <sn>1.</sn> <def>The quantity of
medicine given, or prescribed to be taken, at one time.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A sufficient quantity; a portion; as much as one can
take, or as falls to one to receive.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Anything unpleasant that one is obliged to take; a
disagreeable portion thrust upon one; also used figuratively, <as>as to
give someone a <ex>dose</ex> of his own medicine, i. e. to retaliate in
kind</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I am for curing the world by gentle alteratives, not by violent
<qex>doses</qex>.</q> <rj><qau> W. Irving.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I dare undertake that as fulsome a <qex>dose</qex> as you give
him, he shall readily take it down.</q> <rj><qau> South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>a quantity of radiation which an object absorbs, or
to which it is exposed.</def><br/
[<source>PJC</source>]</p>

<p><ent>Dose</ent><br/
<hw>Dose</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Dosed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>dosing</conjf>.]</vmorph> <ety>[Cf. F. <ets>doser</ets>. See
<er>Dose</er>, <pos>n.</pos>]</ety> <sn>1.</sn> <def>To proportion
properly (a medicine), with reference to the patient or the disease; to
form into suitable doses.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To give doses to; to medicine or physic to; to give
potions to, constantly and without need.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A self-opinioned physician, worse than his distemper, who shall
<qex>dose</qex>, and bleed, and kill him, <ldquo/secundum
artem.<rdquo/</q> <rj><qau> South</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To give anything nauseous to.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dosel</ent><br/
<hw>Dos"el</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF. <ets>dossel</ets>;
cf. LL. <ets>dorsale</ets>. See <er>Dorsal</er>, and cf. <er>Dorse</er>,
<er>Dorsel</er>.]</ety> <def>Same as <er>Dorsal</er>,
<pos>n.</pos></def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>do-si-do</ent><br/
<hw>do`-si`-do"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[from
<ets>dos-<agrave/-dos</ets>, back to back.]</ety> <def>a movement in
square-dancing in which two dancers move around each other in a
back-to-back position, and return to their original places.</def><br/
[<source>PJC</source>]</p>

<p><ent>dosimeter</ent><br/
<hw>dosimeter</hw> <pos>n.</pos> <sn>1.</sn> <def>for measuring doses of
.</def><br/
<syn><b>Syn. --</b> dosemeter.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>dosimeter</ent><br/
<hw>do*sim"et*er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL.
<ets>dosis</ets> dose + <ets>-meter</ets>.]</ety> <def>a device for
measuring doses of radiation, especially ionizing radiation such as
X-rays, gamma rays, or ionizing particles.</def><br/
[<source>PJC</source>]</p>

<p><ent>dosimeter badge</ent><br/
<hw>do*sim"et*er badge</hw> <pr>(?)</pr>, <pos>n.</pos> <def>a dosimeter
consisting of a radiation-sensitive material, such as film, worn in a
small package on a person's clothing, to record the accumulated
radiation exposure of the person over a period of time; -- used to
monitor the exposure of individuals, such as workers in a nuclear power
plant, to ionizing radiation.</def><br/
[<source>PJC</source>]</p>

<p><ent>dosimetry</ent><br/
<hw>do*sim"e*try</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL.
<ets>dosis</ets> dose + <ets>-metry</ets>.]</ety> <fld>(Med.)</fld>
<def>Measurement of doses; specif., a system of therapeutics which uses
but few remedies, mostly alkaloids, and gives them in doses fixed by
certain rules.</def> -- <wordforms><wf>Do`si*met"ric</wf> <pr>(#)</pr>,
<pos>a.</pos> -- <wf>Do*sim"e*trist</wf> <pr>(#)</pr>,
<pos>n.</pos></wordforms><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Dosology</ent><br/
<hw>Do*sol"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Dose</ets> +
<ets>-logy</ets>.]</ety> <def>Posology.</def> <mark>[R.]</mark>
<rj><au>Ogilvie.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doss</ent><br/
<hw>Doss</hw> <pr>(d<ocr/s)</pr>, <pos>n.</pos> <ety>[Etym.
uncertain.]</ety> <def>A place to sleep in; a bed; hence, sleep.</def>
<mark>[Slang]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>doss</ent><br/
<hw>doss</hw> <pos>v. i.</pos> <def>to sleep in a convenient
place.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Doss house</ent><br/
<hw>Doss house</hw>. <def>A cheap lodging house.</def></p>

<p><q>They [street Arabs] consort together and sleep in low <qex>doss
houses</qex> where they meet with all kinds of villainy.</q> <rj><qau>W.
Besant.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Dossel</ent><br/
<hw>Dos"sel</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See <er>Dosel</er>,
<pos>n.</pos>]</ety> <def>Same as <er>Dorsal</er>,
<pos>n.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dosser</ent><br/
<hw>Dos"ser</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL.
<ets>dosserum</ets>, or F.<ets>dossier</ets> bundle of papers, part of a
basket resting on the back, fr. L. <ets>dorsum</ets> back. See
<er>Dorsal</er>, and cf. <er>Dosel</er>.]</ety> <altsp>[Written also
<asp>dorser</asp> and <asp>dorsel</asp>.]</altsp> <sn>1.</sn> <def>A
pannier, or basket.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To hire a ripper's mare, and buy new <qex>dossers</qex>.</q>
<rj><qau>Beau. & Fl.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A hanging tapestry; a dorsal.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dossier</ent><br/
\'d8<hw>Dos`sier"</hw> <pr>(d<osl/s`sy<asl/"; <it>E.</it>
d<ocr/s"s<icr/*<etil/r)</pr>, <pos>n.</pos> <ety>[F., back of a thing,
bulging bundle of papers, fr. <ets>dos</ets> back.]</ety> <def>A bundle
containing the papers in reference to some matter.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Dossil</ent><br/
<hw>Dos"sil</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>dosil</ets>
faucet of a barrel, OF. <ets>dosil</ets>, <ets>duisil</ets>, spigot, LL.
<ets>diciculus</ets>, <ets>ducillus</ets>, fr. L. <ets>ducere</ets> to
lead, draw. See <er>Duct</er>, <er>Duke</er>.]</ety> <sn>1.</sn>
<fld>(Surg.)</fld> <def>A small ovoid or cylindrical roil or pledget of
lint, for keeping a sore, wound, etc., open; a tent.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Printing)</fld> <def>A roll of cloth for wiping off
the face of a copperplate, leaving the ink in the engraved
lines.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dost</ent><br/
<hw>Dost</hw> <pr>(?)</pr>, <pos>2d pers. sing. pres.</pos> <def>of
<er>Do</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dostoyevski</ent><br/
<ent>Dostoevski</ent><br/
<mhw><hw>Dostoevski</hw>, <hw>Dostoyevski</hw></mhw> <pos>prop. n.</pos>
<def>Russian author Fyodor Mikhailovich Dostoevski; born 1821, died
1881.</def><br/
<syn><b>Syn. --</b> Fyodor Mikhailovich Dostoevski.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dostoyevskian</ent><br/
<ent>Dostoevskian</ent><br/
<mhw><hw>Dostoevskian</hw> <hw>Dostoyevskian</hw></mhw> <pos>prop.
adj.</pos> <def>of or pertaining to Fyodor Dostoevski.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Dot</ent><br/
<hw>Dot</hw> <pr>(d<ocr/t)</pr>, <pos>n.</pos> <ety>[F., fr. L.
<ets>dos</ets>, <ets>dotis</ets>, dowry. See <er>Dower</er>, and cf.
<er>Dote</er> dowry.]</ety> <fld>(Law)</fld> <def>A marriage portion;
dowry.</def> <mark>[Louisiana]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dot</ent><br/
<hw>Dot</hw>, <pos>n.</pos> <ety>[Cf. AS. <ets>dott</ets> small spot,
speck; of uncertain origin.]</ety> <sn>1.</sn> <def>A small point or
spot, made with a pen or other pointed instrument; a speck, or small
mark.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Anything small and like a speck comparatively; a
small portion or specimen; <as>as, a <ex>dot</ex> of a
child</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dot</ent><br/
<hw>Dot</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Dotted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Dotting</conjf>.]</vmorph> <sn>1.</sn> <def>To mark with dots or
small spots; <as>as, to <ex>dot</ex> a line</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To mark or diversify with small detached objects;
<xex>as</xex>, <xex>a landscape dotted</xex> with cottages.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dot</ent><br/
<hw>Dot</hw>, <pos>v. i.</pos> <def>To make dots or specks.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>D.O.T.</ent><br/
<ent>DOT</ent><br/
<ent>DoT</ent><br/
<mhw><hw>DoT</hw>, <hw>DOT</hw>, <hw>D.O.T.</hw></mhw>
<pr>(d<emac/"<omac/*t<emac/`)</pr>, <pos>prop. n.</pos> <def>The United
States Department of Transportation.</def> <mark>[acronym]</mark>
<note>The Department of Transportation promulgates standards for the
strength of shipping containers, and this abgreviation is often seen on
cardboard boxes.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dotage</ent><br/
<hw>Do"tage</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From <er>Dote</er>,
<pos>v. i.</pos>]</ety> <sn>1.</sn> <def>Feebleness or imbecility of
understanding or mind, particularly in old age; the childishness of old
age; senility; <as>as, a venerable man, now in his
<ex>dotage</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Capable of distinguishing between the infancy and the
<qex>dotage</qex> of Greek literature.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Foolish utterance; drivel.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The sapless <qex>dotages</qex> of old Paris and Salamanca.</q>
<rj><qau> Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Excessive fondness; weak and foolish
affection.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>dotage</qex> of the nation on presbytery.</q> <rj><qau>
Bp. Burnet.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dotal</ent><br/
<hw>Do"tal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>dotalis</ets>,
fr. <ets>dos</ets>, <ets>dotis</ets>, dowry: cf. F. <ets>dotal</ets>.
See <er>Dot</er> dowry.]</ety> <def>Pertaining to dower, or a woman's
marriage portion; constituting dower, or comprised in it.</def>
<rj><au>Garth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dotant</ent><br/
<hw>Do"tant</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A dotard.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dotard</ent><br/
<hw>Do"tard</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<er>Dote</er>,
<pos>v. i.</pos>]</ety> <def>One whose mind is impaired by age; one in
second childhood.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The sickly <qex>dotard</qex> wants a wife.</q> <rj><qau>
Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dotardly</ent><br/
<hw>Do"tard*ly</hw>, <pos>a.</pos> <def>Foolish; weak.</def> <rj><au>Dr.
H. More.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dotary</ent><br/
<hw>Do"ta*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A dotard's weakness;
dotage.</def> <mark>[Obs.]</mark> <rj><au>Drayton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dotation</ent><br/
<hw>Do*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL.
<ets>dotatio</ets>, fr. L. <ets>dotare</ets> to endow, fr.
<ets>dos</ets>, <ets>dotis</ets>, dower: cf. F. <ets>dotation</ets>. See
<er>Dot</er> dowry.]</ety> <sn>1.</sn> <def>The act of endowing, or
bestowing a marriage portion on a woman.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Endowment; establishment of funds for support, as of
a hospital or eleemosynary corporation.</def>
<rj><au>Blackstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dote</ent><br/
<hw>Dote</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See <er>Dot</er>
dowry.]</ety> <sn>1.</sn> <def>A marriage portion. <mark>[Obs.]</mark>
See 1st <er>Dot</er>, <pos>n.</pos></def> <rj><au>Wyatt.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <pluf>pl.</pluf> <def>Natural endowments.</def>
<mark>[Obs.]</mark> <rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dote</ent><br/
<hw>Dote</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Doted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Doting</conjf>.]</vmorph> <ety>[OE. <ets>doten</ets>; akin to OD.
<ets>doten</ets>, D. <ets>dutten</ets>, to doze, Icel. <ets>dotta</ets>
to nod from sleep, MHG. <ets>t<?/zen</ets> to keep still: cf. F.
<ets>doter</ets>, OF. <ets>radoter</ets> (to dote, rave, talk idly or
senselessly), which are from the same source.]</ety> <altsp>[Written
also <asp>doat</asp>.]</altsp> <sn>1.</sn> <def>To act foolishly.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He wol make him <qex>doten</qex> anon right.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To be weak-minded, silly, or idiotic; to have the
intellect impaired, especially by age, so that the mind wanders or
wavers; to drivel.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Time has made you <qex>dote</qex>, and vainly tell<br/
Of arms imagined in your lonely cell.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He survived the use of his reason, grew infatuated, and
<qex>doted</qex> long before he died.</q> <rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To be excessively or foolishly fond; to love to
excess; to be weakly affectionate; -- with <xex>on or upon</xex>;
<as>as, the mother <ex>dotes</ex> on her child</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Sing, siren, for thyself, and I will <qex>dote</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>What dust we <qex>dote</qex> on, when 't is man we love.</q>
<rj><qau> Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dote</ent><br/
<hw>Dote</hw>, <pos>n.</pos> <def>An imbecile; a dotard.</def>
<rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doted</ent><br/
<hw>Dot"ed</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Stupid;
foolish.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Senseless speech and <qex>doted</qex> ignorance.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Half-rotten; <as>as, <ex>doted</ex> wood</as>.</def>
<mark>[Local, U. S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dotehead</ent><br/
<hw>Dote"head`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A dotard.</def>
<mark>[R.]</mark> <rj><au>Tyndale.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doter</ent><br/
<hw>Dot"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who
dotes; a man whose understanding is enfeebled by age; a dotard.</def>
<rj><au>Burton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One excessively fond, or weak in love.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dotery</ent><br/
<hw>Dot"er*y</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The acts or speech of
a dotard; drivel.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doth</ent><br/
<hw>Doth</hw> <pr>(?)</pr>, <pos>3d pers. sing. pres.</pos> <def>of
<er>Do</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doting</ent><br/
<hw>Dot"ing</hw> <pr>(?)</pr>, <pos>a.</pos> <def>That dotes; silly;
excessively fond.</def> -- <wordforms><wf>Dot"ing*ly</wf>,
<pos>adv.</pos> -- <wf>Dot"ing*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dotish</ent><br/
<hw>Dot"ish</hw>, <pos>a.</pos> <def>Foolish; weak; imbecile.</def>
<rj><au>Sir W. Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dottard</ent><br/
<hw>Dot"tard</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[For
<er>Dotard</er>?]</ety> <def>An old, decayed tree.</def>
<mark>[R.]</mark> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dotted</ent><br/
<hw>Dot"ted</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Marked with, or made
of, dots or small spots; diversified with small, detached
objects.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dotted note</b></col> <fld>(Mus.)</fld>, <cd>a note
followed by a dot to indicate an increase of length equal to one half of
its simple value; thus, a dotted semibreve is equal to three minims, and
a dotted quarter to three eighth notes.</cd> -- <col><b>Dotted
rest</b></col>, <cd>a rest lengthened by a dot in the same manner as a
dotted note.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Notes and rests are sometimes followed by two dots, to
indicate an increase of length equal to three quarters of their simple
value, and they are then said to be <xex>double-dotted</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dotterel</ent><br/
<hw>Dot"ter*el</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf.
<er>Dottard</er>.]</ety> <def>Decayed.</def> <ldquo/Some old
<xex>dotterel</xex> trees.<rdquo/ <mark>[Obs.]</mark>
<rj><au>Ascham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dotterel</ent><br/
<hw>Dot"ter*el</hw>, <pos>n.</pos> <ety>[From <er>Dote</er>, <pos>v.
i.</pos>]</ety> <sn>1.</sn> <fld>(Zool.)</fld> <def>A European bird of
the Plover family (<spn>Eudromias morinellus</spn>, syn. <spn>Charadrius
morinellus</spn>). It is tame and easily taken, and is popularly
believed to imitate the movements of the fowler.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In catching of <qex>dotterels</qex> we see how the foolish bird
playeth the ape in gestures.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The ringed dotterel (or ring plover) is
<stype><spn>Charadrius hiaticula</spn></stype>.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A silly fellow; a dupe; a gull.</def>
<rj><au>Barrow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dotting pen</ent><br/
<hw>Dot"ting pen`</hw> <pr>(?)</pr>. <def>See under
<er>Pun</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dottrel</ent><br/
<hw>Dot"trel</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>See <er>Dotterel</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dotty</ent><br/
<hw>Dot"ty</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From 2d
<er>Dot</er>.]</ety> <sn>1.</sn> <def>Composed of, or characterized by,
dots.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <ety>[Perh. a different word; cf. <er>Totty</er>.]</ety>
<def>Unsteady in gait; hence, feeble; half-witted.</def>
<mark>[Eng.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Doty</ent><br/
<hw>Do"ty</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Dottard</er>.]</ety> <def>Half-rotten; <as>as, <ex>doty</ex>
timber</as>.</def> <mark>[Local, U. S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Douane</ent><br/
\'d8<hw>Dou`ane"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety> <def>A
customhouse.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Douanier</ent><br/
\'d8<hw>Dou`a"nier"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<def>An officer of the French customs.</def> <altsp>[Anglicized form
<asp>douaneer</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Douar</ent><br/
<hw>Dou"ar</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr. Ar.
<ets>d<?/<amac/r</ets>.]</ety> <def>A village composed of Arab tents
arranged in streets.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Douay Bible</ent><br/
<hw>Dou"ay Bi"ble</hw> <pr>(?)</pr>. <ety>[From <ets>Douay</ets>, or
<ets>Douai</ets>, a town in France.]</ety> <def>A translation of the
Scriptures into the English language for the use of English-speaking
Roman Catholics; -- done from the Latin Vulgate by English scholars
resident in France. The New Testament portion was published at Rheims,
<sc>A. D.</sc> 1582, the Old Testament at Douai, <sc>A. D.</sc> 1609-10.
Various revised editions have since been published.</def>
<altsp>[Written also <asp>Doway Bible</asp>. Called also the <asp>Rheims
and Douay version</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doub grass</ent><br/
<hw>Doub" grass`</hw> <pr>(d<oomac/b" gr<adot/s)</pr>.<fld>(Bot.)</fld>
<def>Doob grass.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Double</ent><br/
<hw>Dou"ble</hw> <pr>(d<ucr/b"'l)</pr>, <pos>a.</pos> <ety>[OE.
<ets>doble</ets>, <ets>duble</ets>, <ets>double</ets>, OF.
<ets>doble</ets>, <ets>duble</ets>, <ets>double</ets>, F.
<ets>double</ets>, fr. L. <ets>duplus</ets>, fr. the root of
<ets>duo</ets> two, and perh. that of <ets>plenus</ets> full; akin to
Gr. <grk>diplo`os</grk> double. See <er>Two</er>, and <er>Full</er>, and
cf. <er>Diploma</er>, <er>Duple</er>.]</ety> <sn>1.</sn> <def>Twofold;
multiplied by two; increased by its equivalent; made twice as large or
as much, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Let a <qex>double</qex> portion of thy spirit be upon me.</q>
<rj><qau> 2 Kings ii. 9.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Darkness and tempest make a <qex>double</qex> night.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Being in pairs; presenting two of a kind, or two in
a set together; coupled.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>[Let] The swan, on still St. Mary's lake,<br/
Float <qex>double</qex>, swan and shadow.</q>
<rj><qau>Wordsworth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Divided into two; acting two parts, one openly and
the other secretly; equivocal; deceitful; insincere.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With a <qex>double</qex> heart do they speak.</q> <rj><qau> Ps.
xii. 2.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Bot.)</fld> <def>Having the petals in a flower
considerably increased beyond the natural number, usually as the result
of cultivation and the expense of the stamens, or stamens and pistils.
The white water lily and some other plants have their blossoms naturally
<xex>double</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Double</xex> is often used as the first part of a
compound word, generally denoting <xex>two ways</xex>, or <xex>twice the
number</xex>, <xex>quantity</xex>, <xex>force</xex>, etc.,
<xex>twofold</xex>, or <xex>having two</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Double base</b></col>, <it>or</it> <col><b>Double
bass</b></col></mcol> <fld>(Mus.)</fld>, <cd>the largest and
lowest-toned instrument in the violin form; the contrabasso or
violone.</cd> -- <col><b>Double convex</b></col>. <cd>See under
<er>Convex</er>.</cd> -- <col><b>Double counterpoint</b></col>
<fld>(Mus.)</fld>, <cd>that species of counterpoint or composition, in
which two of the parts may be inverted, by setting one of them an octave
higher or lower.</cd> -- <col><b>Double court</b></col> <fld>(Lawn
Tennis)</fld>, <cd>a court laid out for four players, two on each
side.</cd> -- <col><b>Double dagger</b></col> <fld>(Print.)</fld>, <cd>a
reference mark (<Dagger/) next to the dagger (<dagger/) in order; a
diesis.</cd> -- <col><b>Double drum</b></col> <fld>(Mus.)</fld>, <cd>a
large drum that is beaten at both ends.</cd> -- <col><b>Double
eagle</b></col>, <cd>a gold coin of the United States having the value
of 20 dollars.</cd> -- <col><b>Double entry</b></col>. <cd>See under
<er>Bookkeeping</er>.</cd> -- <col><b>Double floor</b></col>
<fld>(Arch.)</fld>, <cd>a floor in which binding joists support flooring
joists above and ceiling joists below. See <xex>Illust.</xex> of
<xex>Double-framed floor</xex>.</cd> -- <col><b>Double flower</b></col>.
<cd>See <er>Double</er>, <pos>a.</pos>, 4.</cd> -- <col><b>Double-framed
floor</b></col> <fld>(Arch.)</fld>, <cd>a double floor having girders
into which the binding joists are framed.</cd> -- <col><b>Double
fugue</b></col> <fld>(Mus.)</fld>, <cd>a fugue on two subjects.</cd> --
<col><b>Double letter</b></col>. <sd>(a)</sd> <fld>(Print.)</fld>
<cd>Two letters on one shank; a ligature</cd>. <sd>(b)</sd> <cd>A mail
requiring double postage.</cd> -- <col><b>Double note</b></col>
<fld>(Mus.)</fld>, <cd>a note of double the length of the semibreve; a
breve. See <er>Breve</er>.</cd> -- <col><b>Double octave</b></col>
<fld>(Mus.)</fld>, <cd>an interval composed of two octaves, or fifteen
notes, in diatonic progression; a fifteenth.</cd> -- <col><b>Double
pica</b></col>. <cd>See under <er>Pica</er>.</cd> -- <col><b>Double
play</b></col> <fld>(Baseball)</fld>, <cd>a play by which two players
are put out at the same time.</cd> -- <col><b>Double plea</b></col>
<fld>(Law)</fld>, <cd>a plea alleging several matters in answer to the
declaration, where either of such matters alone would be a sufficient
bar to the action.</cd> <au>Stephen.</au> -- <col><b>Double
point</b></col> <fld>(Geom.)</fld>, <cd>a point of a curve at which two
branches cross each other. Conjugate or isolated points of a curve are
called <ex>double points</ex>, since they possess most of the properties
of <ex>double points</ex> (see <er>Conjugate</er>). They are also called
<altname>acnodes</altname>, and those points where the branches of the
curve really cross are called <stype>crunodes</stype>. The extremity of
a cusp is also a <ex>double point</ex>.</cd> -- <col><b>Double
quarrel</b></col>. <fld>(Eccl. Law)</fld> <cd>See <cref>Duplex
querela</cref>, under <er>Duplex</er>.</cd> -- <col><b>Double
refraction</b></col>. <fld>(Opt.)</fld> <cd>See
<er>Refraction</er>.</cd> -- <col><b>Double salt</b></col>.
<fld>(Chem.)</fld> <sd>(a)</sd> <cd>A mixed salt of any polybasic acid
which has been saturated by different bases or basic radicals, as the
double carbonate of sodium and potassium,
<chform>NaKCO3.6H2O</chform></cd>. <sd>(b)</sd> <cd>A molecular
combination of two distinct salts, as common alum, which consists of the
sulphate of aluminium, and the sulphate of potassium or ammonium.</cd>
-- <col><b>Double shuffle</b></col>, <cd>a low, noisy dance.</cd> --
<col><b>Double standard</b></col> <fld>(Polit. Econ.)</fld>, <cd>a
double standard of monetary values; <it>i. e.</it>, a gold standard and
a silver standard, both of which are made legal tender.</cd> --
<col><b>Double star</b></col> <fld>(Astron.)</fld>, <cd>two stars so
near to each other as to be seen separate only by means of a telescope.
Such stars may be only <xex>optically</xex> near to each other, or may
be <xex>physically</xex> connected so that they revolve round their
common center of gravity, and in the latter case are called also
<xex>binary</xex> stars.</cd> -- <col><b>Double time</b></col>
<fld>(Mil.)</fld>. <cd>Same as <er>Double-quick</er>.</cd> --
<col><b>Double window</b></col>, <cd>a window having two sets of glazed
sashes with an air space between them.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 447 --></p>

<p><ent>Double</ent><br/
<hw>Dou"ble</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>Twice;
doubly.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I was <qex>double</qex> their age.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Double</ent><br/
<hw>Dou"ble</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Doubled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Doubling</conjf> <pr>(?)</pr>.]</vmorph> <ety>[OE.
<ets>doblen</ets>, <ets>dublen</ets>, <ets>doublen</ets>, F.
<ets>doubler</ets>, fr. L. <ets>duplare</ets>, fr. <ets>duplus</ets>.
See <er>Double</er>, <pos>a.</pos>]</ety> <sn>1.</sn> <def>To increase
by adding an equal number, quantity, length, value, or the like;
multiply by two; <as>as, to <ex>double</ex> a sum of money; to
<ex>double</ex> a number, or length</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Double</qex> six thousand, and then treble that.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To make of two thicknesses or folds by turning or
bending together in the middle; to fold one part upon another part of;
<as>as, to <ex>double</ex> the leaf of a book, and the like</as>; to
clinch, as the fist; -- often followed by <xex>up</xex>; <as>as, to
<ex>double</ex> up a sheet of paper or cloth</as>.</def><-- also double
over --> <rj><au>Prior.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Then the old man<br/
Was wroth, and <qex>doubled</qex> up his hands.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To be the double of; to exceed by twofold; to
contain or be worth twice as much as.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thus re<eum/nforced, against the adverse fleet,<br/
Still <qex>doubling</qex> ours, brave Rupert leads the way.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To pass around or by; to march or sail round, so as
to reverse the direction of motion.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Sailing along the coast, the <qex>doubled</qex> the promontory of
Carthage.</q> <rj><qau>Knolles.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Mil.)</fld> <def>To unite, as ranks or files, so as
to form one from each two.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Double</ent><br/
<hw>Dou"ble</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To be increased to
twice the sum, number, quantity, length, or value; to increase or grow
to twice as much.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>'T is observed in particular nations, that within the space of
three hundred years, notwithstanding all casualties, the number of men
<qex>doubles</qex>.</q> <rj><qau>T. Burnet.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To return upon one's track; to turn and go back over
the same ground, or in an opposite direction.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Doubling</qex> and turning like a hunted hare.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Doubling</qex> and <qex>doubling</qex> with laborious
walk.</q> <rj><qau>Wordsworth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To play tricks; to use sleights; to play
false.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>What penalty and danger you accrue,<br/
If you be found to <qex>double</qex>.</q> <rj><qau>J.
Webster.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Print.)</fld> <def>To set up a word or words a
second time by mistake; to make a doublet.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To double upon</b></col> <fld>(Mil.)</fld>, <cd>to
inclose between two fires.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Double</ent><br/
<hw>Dou"ble</hw>, <pos>n.</pos> <sn>1.</sn> <def>Twice as much; twice
the number, sum, quantity, length, value, and the like.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If the thief be found, let him pay <qex>double</qex>.</q>
<rj><qau>Ex. xxii. 7.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Among compositors, a doublet (see <er>Doublet</er>,
2.); among pressmen, a sheet that is twice pulled, and
blurred.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which is doubled over or together; a doubling;
a plait; a fold.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Rolled up in sevenfold <qex>double</qex><br/
Of plagues.</q> <rj><qau>Marston.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A turn or circuit in running to escape pursues;
hence, a trick; a shift; an artifice.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>These men are too well acquainted with the chase to be flung off
by any false steps or <qex>doubles</qex>.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A person or thing that is the counterpart of
another; a duplicate; copy; <mark>(Obs.)</mark> transcript; -- now
chiefly used of persons. Hence, a wraith.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>My charming friend . . . has, I am almost sure, a
<qex>double</qex>, who preaches his afternoon sermons for him.</q>
<rj><qau>Atlantic Monthly.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>A player or singer who prepares to take the part of
another player in his absence; a substitute; -- used especially of a
person who resembles an actor and takes the actor's place in scenes
requiring special skills; <as>as, a stunt
<ex>double</ex></as>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>7.</sn> <def>Double beer; strong beer.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <fld>(Eccl.)</fld> <def>A feast in which the antiphon is
doubled, hat is, said twice, before and after the Psalms, instead of
only half being said, as in simple feasts.</def>
<rj><au>Shipley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <fld>(Lawn Tennis)</fld> <def>A game between two pairs of
players; <as>as, a first prize for <ex>doubles</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <fld>(Mus.)</fld> <def>An old term for a variation, as
in Bach's Suites.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Double-acting</ent><br/
<hw>Dou"ble-act`ing</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Acting or
operating in two directions or with both motions; producing a twofold
result; <as>as, a <ex>double-acting</ex> engine or pump</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Double-bank</ent><br/
<hw>Dou"ble-bank"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <fld>(Naut.)</fld>
<def>To row by rowers sitting side by side in twos on a bank or
thwart.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To double-bank an oar</b></col>, <cd>to set two men to
pulling one oar.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Double-banked</ent><br/
<hw>Dou"ble-banked`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Applied to a
kind of rowing in which the rowers sit side by side in twos, a pair of
oars being worked from each bank or thwart.</def></p>

<p><ent>-barrelled</ent><br/
<ent>Double-barreled</ent><br/
<mhw>{ <hw>Dou"ble-bar`reled</hw> <pr>(?)</pr>, <it>or</it>
<hw>-bar`relled</hw> }</mhw>, <pos>a.</pos> <def>Having two barrels; --
applied to a gun.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Double-beat valve</ent><br/
<hw>Dou"ble-beat` valve"</hw> <pr>(?)</pr>. <def>See under
<er>Valve</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Double-breasted</ent><br/
<hw>Dou"ble-breast`ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Folding or
lapping over on the breast, with a row of buttons and buttonholes on
each side; <as>as, a <ex>double-breasted</ex> coat</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Double-charge</ent><br/
<hw>Dou"ble-charge`</hw> <pr>(?)</pr>, <pos>v. t.</pos> <sn>1.</sn>
<def>To load with a double charge, as of gunpowder.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To overcharge.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>double-cross</ent><br/
<ent>double cross</ent><br/
<mhw><hw>double cross</hw>, <hw>double-cross</hw></mhw> <pos>v. t.</pos>
<def>to betray or swindle (a colleague); to promise (a collaborator) one
thing and to treacherously do another, to the detriment of the
collaborator.</def><br/
<syn><b>Syn. --</b> cross, betray.</syn><br/
[<source>PJC</source>]</p>

<p><ent>double-cross</ent><br/
<ent>double cross</ent><br/
<mhw><hw>double cross</hw>, <hw>double-cross</hw></mhw> <pos>n.</pos>
<def>the act of double-crossing; the betrayal or swindling of a
collaborator or colleague.</def><br/
<syn><b>Syn. --</b> cross, betray.</syn><br/
[<source>PJC</source>]</p>

<p><ent>double-crosser</ent><br/
<hw>double-crosser</hw> <pos>n.</pos> <def>one who double-crosses
another; a person who says one thing and does another.</def><br/
<syn><b>Syn. --</b> double-dealer, betrayer, traitor.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>doubled</ent><br/
<hw>doubled</hw> <pos>adj.</pos> <sn>1.</sn> <def>rendered twice as
great or twice as many.</def><br/
<syn><b>Syn. --</b> double, duplex, twofold, diploid.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>folded in two; <as>as, <ex>doubled</ex> sheets of
paper</as>.</def><br/
<syn><b>Syn. --</b> doubled over.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>double-dealer</ent><br/
<ent>Double dealer</ent><br/
<mhw><hw>Dou"ble deal"er</hw>, <hw>dou"ble-deal"er</hw></mhw>
<pr>(?)</pr>. <def>One who practices double dealing; a deceitful,
trickish person; a person who says one thing and does another.</def>
<rj><au>L'Estrange.</au></rj><br/
<syn><b>Syn. --</b> double-crosser, betrayer, traitor.</syn><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><ent>double-dealing</ent><br/
<ent>Double dealing</ent><br/
<mhw><hw>Dou"ble deal"ing</hw>, <hw>dou"ble-deal"ing</hw></mhw>
<pr>(?)</pr>. <def>False or deceitful dealing; acting in bad faith;
deception by pretending to entertain one set of intentions while acting
under the influence of another. See <cref>Double dealing</cref>, under
<er>Dealing</er>.</def> <rj><au>Shak.</au></rj><br/
<syn><b>Syn. --</b> duplicity.</syn><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><ent>double-dealing</ent><br/
<hw>double-dealing</hw> <pos>adj.</pos> <sn>1.</sn> <def>given to
deception especially by pretending one set of feelings and acting under
the influence of another; <as>as, they accused each other of
<ex>double-dealing</ex> behavior</as>.</def><br/
<syn><b>Syn. --</b> ambidextrous, deceitful, duplicitous,
two-faced.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Double-decker</ent><br/
<hw>Dou"ble-deck"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<fld>(Naut.)</fld> <sn>1.</sn> <def>A man-of-war having two gun
decks.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <sd>(a)</sd> <def>A tenement house having two families on
each floor.</def> <mark>[Local, U. S.]</mark> <sd>(b)</sd> <def>A
biplane a<eum/roplane or kite.</def> <mark>[Colloq.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>3.</sn> <def>anything having two decks or levels, as a bus with
two levels for passengers. In older vehicles, less often today, the
upper deck was open, as on street cars.</def> <mark>[Colloq.]</mark><br/
[<source>PJC</source>]</p>

<p><ent>Double-dye</ent><br/
<hw>Dou"ble-dye`</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To dye again
or twice over.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>double-dye</qex> their robes in scarlet.</q> <rj><qau>J.
Webster.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Double-dyed</ent><br/
<hw>Dou"ble-dyed`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Dyed twice;
thoroughly or intensely colored; hence; firmly fixed in opinions or
habits; <as>as, a <ex>double-dyed</ex> villain</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Double-ender</ent><br/
<hw>Dou"ble-end"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sd>(a)</sd>
<fld>(Naut.)</fld> <def>A vessel capable of moving in either direction,
having bow and rudder at each end.</def> <sd>(b)</sd>
<fld>(Railroad)</fld> <def>A locomotive with pilot at each end.</def>
<rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Double-entendre</ent><br/
\'d8<hw>Dou"ble-en*ten"dre</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>double</ets> double + <ets>entendre</ets> to mean. This is a
barbarous compound of French words. The true French equivalent is
<ets>double entente</ets>.]</ety> <def>A word or expression admitting of
a double interpretation, one of which is often obscure or
indelicate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Double-eyed</ent><br/
<hw>Dou"ble-eyed`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having a
deceitful look.</def> <mark>[R.]</mark> <ldquo/Deceitful meanings is
<xex>double-eyed</xex>.<rdquo/ <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doubleganger</ent><br/
<hw>Dou"ble*gang`er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[G.
<ets>doppelg<aum/nger</ets>; <ets>doppel</ets> double +
<ets>g<aum/nger</ets> walker.]</ety> <def>An apparition or double of a
living person; a doppelg<aum/nger.</def></p>

<p><q>Either you are Hereward, or you are his
<qex>doubleganger</qex>.</q> <rj><qau>C. Kingsley.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Double-faced</ent><br/
<hw>Dou"ble-faced`</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Having two faces designed for use; <as>as, a <ex>double-faced</ex>
hammer</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Deceitful; hypocritical; treacherous.</def>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Double first</ent><br/
<hw>Dou"ble first`</hw> <pr>(?)</pr>. <fld>(Eng. Universities)</fld>
<sd>(a)</sd> <def>A degree of the first class both in classics and
mathematics.</def> <sd>(b)</sd> <def>One who gains at examinations the
highest honor both in the classics and the mathematics.</def>
<rj><au>Beaconsfield.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Double-handed</ent><br/
<hw>Dou"ble-hand"ed</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Having two hands.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Deceitful; deceptive.</def>
<rj><au>Glanvill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Double-headed</ent><br/
<hw>Dou"ble-head"ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having two
heads; bicipital.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Double-headed rail</b></col> <fld>(Railroad)</fld>, <cd>a
rail whose flanges are duplicates, so that when one is worn the other
may be turned uppermost.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>doubleheader</ent><br/
<hw>doubleheader</hw> <pos>n.</pos> <def>two events, usually
entertainment or sports performances, occurring immediately in
succession or within a short time of each other; especially, two sports
games played by the same teams on the same day, one right after
another.</def> <note>A doubleheader in baseball is often scheduled
between teams when a previously shceduled game is postponed, as due to
rain or other interfering factors. In such cases, the admission price
for the doubleheader remains that of a single game, though two games are
played.</note><br/
<syn><b>Syn. --</b> twin bill, double feature.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Double-hearted</ent><br/
<hw>Dou"ble-heart"ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having a
false heart; deceitful; treacherous.</def> <rj><au>Sandys.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Double-hung</ent><br/
<hw>Dou"ble-hung`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having both
sashes hung with weights and cords; -- said of a window.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Double-lock</ent><br/
<hw>Dou"ble-lock`</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To lock with
two bolts; to fasten with double security.</def>
<rj><au>Tatler.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Double-milled</ent><br/
<hw>Dou"ble-milled`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Twice milled
or fulled, to render more compact or fine; -- said of cloth; <as>as,
<ex>double-milled</ex> kerseymere</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Double-minded</ent><br/
<hw>Dou"ble-mind"ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having
different minds at different times; unsettled; undetermined.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>double-minded</qex> man is unstable in all his ways.</q>
<rj><qau>Jas. i. 8.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doubleness</ent><br/
<hw>Dou"ble*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
state of being double or doubled.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Duplicity; insincerity.</def>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Double pedro</ent><br/
<hw>Double pedro</hw>. <def>Cinch (the game).</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Double-quick</ent><br/
<hw>Dou"ble-quick`</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Mil.)</fld>
<def>Of, or performed in, the fastest time or step in marching, next to
the run; <as>as, a <ex>double-quick</ex> step or march</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Double-quick</ent><br/
<hw>Dou"ble-quick`</hw>, <pos>n.</pos> <def>Double-quick time, step, or
march.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Double-quick time requires 165 steps, each 33 inches in
length, to be taken in one minute. The number of steps may be increased
up to 180 per minute.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Double-quick</ent><br/
<hw>Dou"ble-quick`</hw>, <pos>v. i. & t.</pos> <fld>(Mil.)</fld> <def>To
move, or cause to move, in double-quick time.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doubler</ent><br/
<hw>Dou"bler</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who,
or that which, doubles.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Elec.)</fld> <def>An instrument for augmenting a
very small quantity of electricity, so as to render it manifest by
sparks or the electroscope.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A part of a distilling apparatus for intercepting
the heavier fractions and returning them to be redistilled.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>4.</sn> <fld>(Calico Printing)</fld> <def>A blanket or felt
placed between the fabric and the printing table or cylinder.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Double-ripper</ent><br/
<hw>Dou"ble-rip"per</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A kind of
coasting sled, made of two sleds fastened together with a board, one
before the other.</def> <mark>[Local, U. S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>doubles</ent><br/
<hw>dou"bles</hw> <pos>n.</pos> <sn>1.</sn> <def>badminton played with
two players on each side.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>tennis played with two players on each
side.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>double-shade</ent><br/
<hw>dou"ble-shade`</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To double
the natural darkness of (a place).</def> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>double standard</ent><br/
<hw>dou"ble stan"dard</hw> <pr>(?)</pr>, <pos>n.</pos> <def>a standard
or set of principles governing conduct, which is applied more
stringently or differently to one group of people than to another; --
used especially of standards of sexual behavior that condemn behavior on
the part of women that is condoned or not condemned when exhibited by
men.</def><br/
[<source>PJC</source>]</p>

<p><ent>Double-surfaced</ent><br/
<hw>Dou"ble-sur"faced</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having two
surfaces; -- said specif. of a<eum/roplane wings or a<eum/rocurves which
are covered on both sides with fabric, etc., thus completely inclosing
their frames.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Doublet</ent><br/
<hw>Doub"let</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[In sense 3, OF.
<ets>doublet</ets>; in sense 4, F. <ets>doublet</ets>, dim. of
<ets>double</ets> double. See <er>Double</er>, <pos>a.</pos>]</ety>
<sn>1.</sn> <def>Two of the same kind; a pair; a couple.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Print.)</fld> <def>A word or words unintentionally
doubled or set up a second time.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A close-fitting garment for men, covering the body
from the neck to the waist or a little below. It was worn in Western
Europe from the 15th to the 17th century.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Lapidary Work)</fld> <def>A counterfeit gem,
composed of two pieces of crystal, with a layer of color between them,
and thus giving the appearance of a naturally colored gem. Also, a piece
of paste or glass covered by a veneer of real stone.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Opt.)</fld> <def>An arrangement of two lenses for a
microscope, designed to correct spherical aberration and chromatic
dispersion, thus rendering the image of an object more clear and
distinct.</def> <rj><au>W. H. Wollaston.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <pluf>pl.</pluf> (See No. 1.) <def>Two dice, each of
which, when thrown, has the same number of spots on the face lying
uppermost; <as>as, to throw <ex>doublets</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <pluf>pl.</pluf> <ety>[Cf. Pr. <ets>doblier</ets>,
<ets>dobler</ets> draughtboard.]</ety> <def>A game somewhat like
backgammon.</def> <rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>One of two or more words in the same language
derived by different courses from the same original from; <as>as,
<xex>crypt</xex> and <xex>grot</xex> are <ex>doublets</ex>; also,
<xex>guard</xex> and <xex>ward</xex>; <xex>yard</xex> and
<xex>garden</xex>; <xex>abridge</xex> and <xex>abbreviate</xex>,
etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Double-threaded</ent><br/
<hw>Dou"ble-thread`ed</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Consisting of two threads twisted together; using two
threads.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mech.)</fld> <def>Having two screw threads instead
of one; -- said of a screw in which the pitch is equal to twice the
distance between the centers of adjacent threads.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Double-tongue</ent><br/
<hw>Dou"ble-tongue`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Deceit;
duplicity.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Now cometh the sin of <qex>double-tongue</qex>, such as speak fair
before folk and wickedly behind.</q> <rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Double-tongued</ent><br/
<hw>Dou"ble-tongued`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Making
contrary declarations on the same subject; deceitful.</def><br/
<syn><b>Syn. --</b> deceitful, double-faced, hypocritical, Janus-faced,
two-faced.</syn><br/
[<source>1913 Webster</source>]</p>

<p><q>Likewise must the deacons be grave, not
<qex>double-tongued</qex>.</q> <rj><qau>1 Tim. iii. 8.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Double-tonguing</ent><br/
<hw>Dou"ble-tongu`ing</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Mus.)</fld>
<def>A peculiar action of the tongue by flute players in articulating
staccato notes; also, the rapid repetition of notes in cornet
playing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doubletree</ent><br/
<hw>Dou"ble*tree`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The bar, or
crosspiece, of a carriage, to which the singletrees are
attached.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doublets</ent><br/
<hw>Doub"lets</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <def>See
<er>Doublet</er>, 6 and 7.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doubling</ent><br/
<hw>Dou"bling</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The act
of one that doubles; a making double; reduplication; also, that which is
doubled.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A turning and winding; <as>as, the <ex>doubling</ex>
of a hunted hare</as>; shift; trick; artifice.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Her.)</fld> <def>The lining of the mantle borne
about the shield or escutcheon.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The process of redistilling spirits, to improve the
strength and flavor.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>raising the stakes in a game, such as a card game or
backgammon, by a factor of 2.</def><br/
<syn><b>Syn. --</b> double.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><cs><mcol><col><b>Doubling a cape</b></col>,
<col><b>promontory</b></col></mcol>, <cd>etc. <fld>(Naut.)</fld>,
sailing around or passing beyond a cape, promontory, etc.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doubloon</ent><br/
<hw>Doub*loon"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>doublon</ets>, Sp. <ets>doblon</ets>. See <er>Double</er>,
<pos>a.</pos>, and cf. <er>Dupion</er>.]</ety> <def>A Spanish gold coin,
no longer issued, varying in value at different times from over fifteen
dollars to about five. See <er>Doblon</er> in Sup.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doublure</ent><br/
\'d8<hw>Dou`blure"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<sn>1.</sn> <fld>(Bookbinding)</fld> <def>The lining of a book cover,
esp. one of unusual sort, as of tooled leather, painted vellum, rich
brocade, or the like.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <fld>(Paleon.)</fld> <def>The reflexed margin of the
trilobite carapace.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Doubly</ent><br/
<hw>Dou"bly</hw> <pr>(d<ucr/b"l<ycr/)</pr>, <pos>adv.</pos> <sn>1.</sn>
<def>In twice the quantity; to twice the degree; <as>as, <ex>doubly</ex>
wise or good; to be <ex>doubly</ex> sensible of an
obligation.</as></def> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Deceitfully.</def> <ldquo/A man that deals
<xex>doubly</xex>.<rdquo/ <rj><au>Huloet.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doubt</ent><br/
<hw>Doubt</hw> <pr>(dout)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Doubted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Doubting</conjf>.]</vmorph> <ety>[OE. <ets>duten</ets>,
<ets>douten</ets>, OF. <ets>duter</ets>, <ets>doter</ets>,
<ets>douter</ets>, F. <ets>douter</ets>, fr. L. <ets>dubitare</ets>;
akin to <ets>dubius</ets> doubtful. See <er>Dubious</er>.]</ety>
<sn>1.</sn> <def>To waver in opinion or judgment; to be in uncertainty
as to belief respecting anything; to hesitate in belief; to be undecided
as to the truth of the negative or the affirmative proposition; to b e
undetermined.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Even in matters divine, concerning some things, we may lawfully
<qex>doubt</qex>, and suspend our judgment.</q>
<rj><qau>Hooker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To try your love and make you <qex>doubt</qex> of mine.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To suspect; to fear; to be apprehensive.</def>
<mark>[Obs.]</mark></p>

<p><syn><b>Syn.</b> -- To waver; vacillate; fluctuate; hesitate; demur;
scruple; question.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doubt</ent><br/
<hw>Doubt</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To question or hold
questionable; to withhold assent to; to hesitate to believe, or to be
inclined not to believe; to withhold confidence from; to distrust;
<as>as, I have heard the story, but I <ex>doubt</ex> the truth of
it</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To admire superior sense, and <qex>doubt</qex> their own!</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I <qex>doubt</qex> not that however changed, you keep<br/
So much of what is graceful.</q> <rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<cs><p><col><b>To doubt not but</b></col>. <q>I do <qex>not doubt
but</qex> I have been to blame.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>We <qex>doubt not</qex> now<br/
<qex>But</qex> every rub is smoothed on our way.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note>That is, we have no doubt to <xex>prevent</xex> us from
believing, etc. (or notwithstanding all that may be said to the
contrary) -- <xex>but</xex> having a preventive sense, after verbs of
<ldquo/doubting<rdquo/ and <ldquo/denying<rdquo/ that convey a notion of
hindrance. <au>E. A. Abbott.</au></note><br/
[<source>1913 Webster</source>]</p></cs>

<p><sn>2.</sn> <def>To suspect; to fear; to be apprehensive of.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Edmond [was a] good man and <qex>doubted</qex> God.</q>
<rj><qau>R. of Gloucester.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I <qex>doubt</qex> some foul play.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>That I of <qex>doubted</qex> danger had no fear.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To fill with fear; to affright.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The virtues of the valiant Caratach<br/
More <qex>doubt</qex> me than all Britain.</q> <rj><qau>Beau. &
Fl.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doubt</ent><br/
<hw>Doubt</hw>, <pos>n.</pos> <ety>[OE. <ets>dute</ets>,
<ets>doute</ets>, F. <ets>doute</ets>, fr. <ets>douter</ets> to doubt.
See <er>Doubt</er>, <pos>v. i.</pos>]</ety> <sn>1.</sn> <def>A
fluctuation of mind arising from defect of knowledge or evidence;
uncertainty of judgment or mind; unsettled state of opinion concerning
the reality of an event, or the truth of an assertion, etc.;
hesitation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Doubt</qex> is the beginning and the end of our efforts to
know.</q> <rj><qau>Sir W. Hamilton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Doubt</qex>, in order to be operative in requiring an
acquittal, is not the want of perfect certainty (which can never exist
in any question of fact) but a defect of proof preventing a reasonable
assurance of quilt.</q> <rj><qau>Wharton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Uncertainty of condition.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thy life shall hang in <qex>doubt</qex> before thee.</q>
<rj><qau>Deut. xxviii. 66.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Suspicion; fear; apprehension; dread.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I stand in <qex>doubt</qex> of you.</q> <rj><qau>Gal. iv.
20.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Nor slack her threatful hand for danger's <qex>doubt</qex>.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Difficulty expressed or urged for solution; point
unsettled; objection.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To every <qex>doubt</qex> your answer is the same.</q>
<rj><qau>Blackmore.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>No doubt</b></col>, <cd>undoubtedly; without doubt.</cd>
-- <col><b>Out of doubt</b></col>, <cd>beyond doubt.</cd>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj></cs></p>

<p><syn><b>Syn.</b> -- Uncertainty; hesitation; suspense; indecision;
irresolution; distrust; suspicion; scruple; perplexity; ambiguity;
skepticism.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doubtable</ent><br/
<hw>Doubt"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OF.
<ets>doutable</ets>, L. <ets>dubitabilis</ets>, from
<ets>dubitare</ets>. Cf. <er>Dubitable</er>.]</ety> <sn>1.</sn>
<def>Capable of being doubted; questionable.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Worthy of being feared; redoubtable.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doubtance</ent><br/
<hw>Doubt"ance</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>doutance</ets>. Cf. <er>Dubitancy</er>.]</ety> <def>State of being
in doubt; uncertainty; doubt.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doubter</ent><br/
<hw>Doubt"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who doubts; one
whose opinion is unsettled; one who scruples.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doubtful</ent><br/
<hw>Doubt"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Not
settled in opinion; undetermined; wavering; hesitating in belief; also
used, metaphorically, of the body when its action is affected by such a
state of mind; <as>as, we are <ex>doubtful</ex> of a fact, or of the
propriety of a measure</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Methinks I should know you, and know this man;<br/
Yet I am <qex>doubtful</qex>.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>With <qex>doubtful</qex> feet and wavering resolution.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 448 --></p>

<p><sn>2.</sn> <def>Admitting of doubt; not obvious, clear, or certain;
questionable; not decided; not easy to be defined, classed, or named;
<as>as, a <ex>doubtful</ex> case, hue, claim, title, species, and the
like</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Beauty is but a vain and <qex>doubtful</qex> good.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Is it a great cruelty to expel from our abode the enemy of our
peace, or even the <qex>doubtful</qex> friend [i. e., one as to whose
sincerity there may be doubts]?</q> <rj><qau>Bancroft.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Characterized by ambiguity; dubious; <as>as, a
<ex>doubtful</ex> expression; a <ex>doubtful</ex> phrase.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Of uncertain issue or event.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We . . . have sustained one day in <qex>doubtful</qex> fight.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The strife between the two principles had been long, fierce, and
<qex>doubtful</qex>.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Fearful; apprehensive; suspicious.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I am <qex>doubtful</qex> that you have been conjunct<br/
And bosomed with her.</q> <rj><qau>Shak.</qau></rj></p>

<p><syn><b>Syn.</b> -- Wavering; vacillating; hesitating; undetermined;
distrustful; dubious; uncertain; equivocal; ambiguous; problematical;
questionable.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doubtfully</ent><br/
<hw>Doubt"ful*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a doubtful
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Nor did the goddess <qex>doubtfully</qex> declare.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doubtfulness</ent><br/
<hw>Doubt"ful*ness</hw>, <pos>n.</pos> <sn>1.</sn> <def>State of being
doubtful.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Uncertainty of meaning; ambiguity;
indefiniteness.</def> <ldquo/ The <xex>doubtfulness</xex> of his
expressions.<rdquo/ <rj><au>Locke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Uncertainty of event or issue.</def>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doubting</ent><br/
<hw>Doubt"ing</hw>, <pos>a.</pos> <def>That is uncertain; that distrusts
or hesitates; having doubts.</def> -- <wordforms><wf>Doubt"ing*ly</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doubtless</ent><br/
<hw>Doubt"less</hw>, <pos>a.</pos> <def>Free from fear or
suspicion.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Pretty child, sleep <qex>doubtless</qex> and secure.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doubtless</ent><br/
<hw>Doubt"less</hw>, <pos>adv.</pos> <def>Undoubtedly; without
doubt.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doubtlessly</ent><br/
<hw>Doubt"less*ly</hw>, <pos>adv.</pos> <def>Unquestionably.</def>
<rj><au>Beau. & Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doubtous</ent><br/
<hw>Doubt"ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OF.
<ets>dotos</ets>, <ets>douteus</ets>, F. <ets>douteux</ets>.]</ety>
<def>Doubtful.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Douc</ent><br/
<hw>Douc</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>A
monkey (<spn>Semnopithecus nem<ae/us</spn>), remarkable for its varied
and brilliant colors. It is a native of Cochin China.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Douce</ent><br/
<hw>Douce</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F. <ets>doux</ets>,
masc., <ets>douce</ets>, fem., sweet, fr. L. <ets>duleis</ets>
sweet.]</ety> <sn>1.</sn> <def>Sweet; pleasant.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Sober; prudent; sedate; modest.</def>
<mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>And this is a <qex>douce</qex>, honest man.</q> <rj><qau>Sir W.
Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doucepere</ent><br/
<hw>Douce"pere`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>les douze
pairs</ets> the twelve peers of France, renowned in romantic
fiction.]</ety> <def>One of the twelve peers of France, companions of
Charlemagne in war.</def> <altsp>[Written also
<asp>douzepere</asp>.]</altsp> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Big-looking like a doughty <qex>doucepere</qex>.</q>
<rj><qau>Spenser.</qau></rj></p>

<p><ent>Dowset</ent><br/
<ent>Doucet</ent><br/
<mhw>{ <hw>Dou"cet</hw> <pr>(?)</pr>, <hw>Dow"set</hw> <pr>(?)</pr>
}</mhw>, <pos>n.</pos> <ety>[F. <ets>doucet</ets> sweet, dim. of
<ets>doux</ets>. See <er>Douce</er>.]</ety> <sn>1.</sn> <def>A
custard.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A dowcet, or deep's testicle.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Douceur</ent><br/
\'d8<hw>Dou`ceur"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr.
<ets>doux</ets> sweet. See <er>Douce</er>.]</ety> <sn>1.</sn>
<def>Gentleness and sweetness of manner; agreeableness.</def>
<rj><au>Chesterfield.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A gift for service done or to be done; an
honorarium; a present; sometimes, a bribe.</def>
<rj><au>Burke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Douche</ent><br/
<hw>Douche</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F., fr. It.
<ets>doccia</ets>, fr. <ets>docciare</ets> to flow, pour, fr. an assumed
LL. <ets>ductiare</ets>, fr. L. <ets>ducere</ets>, <ets>ductum</ets>, to
lead, conduct (water). See <er>Duct</er>.]</ety> <sn>1.</sn> <def>A jet
or current of water or vapor directed upon some part of the body to
benefit it medicinally; a douche bath.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Med.)</fld> <def>A syringe.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doucine</ent><br/
<hw>Dou"cine</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<fld>(Arch.)</fld> <def>Same as <xex>Cyma recta</xex>, under
<er>Cyma</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doucker</ent><br/
<hw>Douck"er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<ets>aouck</ets>, for <ets>duck</ets>. See <er>Duck</er>, <pos>v.
t.</pos>]</ety> <fld>(Zool.)</fld> <def>A grebe or diver; -- applied
also to the golden-eye, pochard, scoter, and other ducks.</def>
<altsp>[Written also <asp>ducker</asp>.]</altsp> <mark>[Prov.
Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dough</ent><br/
<hw>Dough</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>dagh</ets>,
<ets>dogh</ets>, <ets>dow</ets>, AS. <ets>d<amac/h</ets>; akin to D.
<ets>deeg</ets>, G. <ets>teig</ets>, Icel. <ets>deig</ets>, Sw.
<ets>deg</ets>, Dan. <ets>deig</ets>, Goth. <ets>daigs</ets>; also, to
Goth. <ets>deigan</ets> to knead, L. <ets>fingere</ets> to form, shape,
Skr. <ets>dih</ets> to smear; cf. Gr. <?/ wall, <?/ to touch, handle.
<?/. Cf. <er>Feign</er>, <er>Figure</er>, <er>Dairy</er>,
<er>Duff</er>.]</ety> <sn>1.</sn> <def>Paste of bread; a soft mass of
moistened flour or meal, kneaded or unkneaded, but not yet baked;
<as>as, to knead <ex>dough</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Anything of the consistency of such paste.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To have one's cake dough</b></col>. <cd>See under
<er>Cake</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dough-baked</ent><br/
<hw>Dough"-baked`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Imperfectly
baked; hence, not brought to perfection; unfinished; also, of weak or
dull understanding.</def> <mark>[Colloq.]</mark>
<rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doughbird</ent><br/
<hw>Dough"bird`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>The Eskimo curlew (<spn>Numenius borealis</spn>). See
<er>Curlew</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doughface</ent><br/
<hw>Dough"face`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A contemptuous
nickname for a timid, yielding politician, or one who is easily
molded.</def> <mark>[Political cant, U. S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dough-faced</ent><br/
<hw>Dough"-faced`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Easily molded;
pliable.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doughfaceism</ent><br/
<hw>Dough"face`ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The character
of a doughface; truckling pliability.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doughiness</ent><br/
<hw>Dough"i*ness</hw>, <pos>n.</pos> <def>The quality or state of being
doughy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dough-kneaded</ent><br/
<hw>Dough"-knead`ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Like dough;
soft.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He demeans himself . . . like a <qex>dough-kneaded</qex>
thing.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doughnut</ent><br/
<hw>Dough"nut</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A small cake
(usually sweetened) fried in a kettle of boiling lard.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doughtily</ent><br/
<hw>Dough"ti*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a doughty
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doughtiness</ent><br/
<hw>Dough"ti*ness</hw>, <pos>n.</pos> <def>The quality of being doughty;
valor; bravery.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doughtren</ent><br/
<hw>Dough"tren</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[See
<er>Daughter</er>.]</ety> <def>Daughters.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doughty</ent><br/
<hw>Dough"ty</hw> <pr>(dou"t<ycr/)</pr>, <pos>a.</pos>
<amorph>[<pos>Compar.</pos> <adjf>Doughtier</adjf>
<pr>(dou"t<icr/*<etil/r)</pr>; <pos>superl.</pos>
<adjf>Doughtiest</adjf>.]</amorph> <ety>[OE. <ets>duhti</ets>,
<ets>dohti</ets>, <ets>douhti</ets>, brave, valiant, fit, useful, AS.
<ets>dyhtig</ets>; akin to G. <ets>t<uum/chtig</ets>, Dan.
<ets>dygtig</ets>, Sw. <ets>dygdig</ets> virtuous, and fr. AS.
<ets>dugan</ets> to avail, be of use, be strong, akin to D.
<ets>deugen</ets>, OHG. <ets>tugan</ets>, G. <ets>taugen</ets>, Icel. &
Sw. <ets>duga</ets>, Dan. <ets>due</ets>, Goth. <ets>dugan</ets>, but of
uncertain origin; cf. Skr. <ets>duh</ets> to milk, give milk, draw out,
or Gr. <grk>ty`chh</grk> fortune. <root/68.]</ety> <def>Able; strong;
valiant; redoubtable; <as>as, a <ex>doughty</ex> hero</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Sir Thopas wex [grew] a <qex>doughty</qex> swain.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Doughty</qex> families, hugging old musty quarrels to their
hearts, buffet each other from generation to generation.</q>
<rj><qau>Motley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Now seldom used, except in irony or
burlesque.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doughy</ent><br/
<hw>Dough"y</hw> <pr>(d<omac/"<ycr/)</pr>, <pos>a.</pos> <def>Like
dough; soft and heavy; pasty; crude; flabby and pale; <as>as, a
<ex>doughy</ex> complexion</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doulocracy</ent><br/
<hw>Dou*loc"ra*cy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>doy^los</grk> slave + <grk>kratei^n</grk> to rule.]</ety> <def>A
government by slaves.</def> <altsp>[Written also
<asp>dulocracy</asp>.]</altsp> <rj><au>Hare.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doum palm</ent><br/
<hw>Doum" palm`</hw> <pr>(d<oomac/m" p<aum/m`)</pr>. <def>See <er>Doom
palm</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doupe</ent><br/
<hw>Doupe</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>The
carrion crow.</def> <altsp>[Written also <asp>dob</asp>.]</altsp>
<mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dour</ent><br/
<hw>Dour</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F. <ets>dur</ets>,
L. <ets>durus</ets>.]</ety> <def>Hard; inflexible; obstinate; sour in
aspect; hardy; bold.</def> <mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>dour</qex> wife, a sour old carlin.</q> <rj><qau>C.
Reade.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>dourah</ent><br/
<ent>Doura</ent><br/
<mhw><hw>Dou"ra</hw>, <hw>dourah</hw></mhw> <pr>(?)</pr>, <pos>n.</pos>
<def>sorghums of dry regions of Asia and North Africa; A kind of millet.
See <er>Durra</er>.</def><br/
<syn><b>Syn. --</b> durra, doura, dourah, Egyptian corn, Indian millet,
Guinea corn.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Douroucouli</ent><br/
\'d8<hw>Dou`rou*cou"li</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Zool.)</fld> <def>A small, nocturnal, South American monkey of the
genus <gen>Aotus</gen> (formerly <spn>Nyctipithecus trivirgatus</spn>),
with large owl-like eyes; hence, the common name <altname>owl
monkey</altname>.</def> <altsp>[Written also <asp>Durukuli</asp> and
<asp>dourikuli</asp>.]</altsp><br/
[<source>1913 Webster</source> <source>+PJC</source> ]</p>

<p><ent>Douse</ent><br/
<hw>Douse</hw> <pr>(dous)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Doused</conjf> <pr>(doust)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Dousing</conjf>.]</vmorph> <ety>[Cf. <er>Dowse</er>, and
OD. <ets>donsen</ets> to strike with the fist on the back, Sw.
<ets>dunsa</ets> to fall down violently and noisily; perh. akin to E.
<ets>din</ets>.]</ety> <sn>1.</sn> <def>To plunge suddenly into water;
to duck; to immerse; to dowse.</def> <rj><au>Bp.
Stillingfleet.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Naut.)</fld> <def>To strike or lower in haste; to
slacken suddenly; <as>as, <ex>douse</ex> the topsail</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Douse</ent><br/
<hw>Douse</hw>, <pos>v. i.</pos> <def>To fall suddenly into water.</def>
<rj><au>Hudibras.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Douse</ent><br/
<hw>Douse</hw>, <pos>v. t.</pos> <ety>[AS. <ets>dw<ae/scan</ets>.
(Skeat.)]</ety> <def>To put out; to extinguish; <as>as, <ex>douse</ex>
the lights</as>.</def> <mark>[Slang]</mark> <ldquo/ To <xex>douse</xex>
the glim.<rdquo/ <rj><au>Sir W. Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dousing-chock</ent><br/
<hw>Dous"ing-chock`</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Shipbuilding)</fld> <def>One of several pieces fayed across the
apron and lapped in the knightheads, or inside planking above the upper
deck.</def> <rj><au>Ham. Nav. Encyc.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dout</ent><br/
<hw>Dout</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[<ets>Do</ets> +
<ets>out</ets>. Cf. <er>Doff</er>.]</ety> <def>To put out.</def>
<mark>[Obs.]</mark> <ldquo/It <xex>douts</xex> the light.<rdquo/
<rj><au>Sylvester.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Douter</ent><br/
<hw>Dout"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An extinguisher for
candles.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dove</ent><br/
<hw>Dove</hw> <pr>(d<ucr/v)</pr>, <pos>n.</pos> <ety>[OE.
<ets>dove</ets>, <ets>duve</ets>, <ets>douve</ets>, AS.
<ets>d<umac/fe</ets>; akin to OS. <ets>d<umac/ba</ets>, D.
<ets>duif</ets>, OHG. <ets>t<umac/ba</ets>, G. <ets>taube</ets>, Icel.
<ets>d<umac/fa</ets>, Sw. <ets>dufva</ets>, Dan. <ets>due</ets>, Goth.
<ets>d<umac/b<omac/</ets>; perh. from the root of E.
<ets>dive</ets>.]</ety> <sn>1.</sn> <fld>(Zool.)</fld> <def>A pigeon of
the genus <gen>Columba</gen> and various related genera. The species are
numerous.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The domestic dove, including the varieties called
<stype>fantails</stype>, <stype>tumblers</stype>, <stype>carrier
pigeons</stype>, etc., was derived from the <stype>rock pigeon</stype>
(<spn>Columba livia</spn>) of Europe and Asia; the
<stype>turtledove</stype> of Europe, celebrated for its sweet, plaintive
note, is <spn>Columba turtur</spn> or <spn>Turtur vulgaris</spn>; the
<stype>ringdove</stype>, the largest of European species, is
<spn>Columba palumbus</spn>; the <stype>Carolina dove</stype>, or
<stype>Mourning dove</stype>, is <spn>Zenaidura macroura</spn>; the
<stype>sea dove</stype> is the little auk (<spn>Mergulus alle</spn> or
<spn>Alle alle</spn>). See <er>Turtledove</er>, <er>Ground dove</er>,
and <er>Rock pigeon</er>. The dove is a symbol of peace, innocence,
gentleness, and affection; also, in art and in the Scriptures, the
typical symbol of the Holy Ghost.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A word of endearment for one regarded as pure and
gentle.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>O my <qex>dove</qex>, . . . let me hear thy voice.</q>
<rj><qau>Cant. ii. 14.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>a person advocating peace, compromise or
conciliation rather than war or conflict. Opposite of
<contr>hawk</contr>.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Dove tick</b></col> <fld>(Zool.)</fld>, <cd>a mite
(<spn>Argas reflexus</spn>) which infests doves and other birds.</cd> --
<col><b>Soiled dove</b></col>, <cd>a prostitute.</cd>
<mark>[Slang]</mark></cs></p>

<p><ent>Dovecote</ent><br/
<ent>Dovecot</ent><br/
<mhw>{ <hw>Dove"cot`</hw> <pr>(?)</pr>, <hw>Dove"cote`</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <def>A small house or box, raised to
a considerable height above the ground, and having compartments, in
which domestic pigeons breed; a dove house.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Like an eagle in a <qex>dovecote</qex>, I<br/
Fluttered your Volscians in Corioli.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dove-eyed</ent><br/
<hw>Dove"-eyed`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having eyes like a
dove; meekeyed; <as>as, <ex>dove-eyed</ex> Peace</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dovekie</ent><br/
<hw>Dove"kie</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>A
guillemot (<spn>Uria grylle</spn>), of the arctic regions. Also applied
to the little auk or sea dove. See under <er>Dove</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dovelet</ent><br/
<hw>Dove"let</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A young or small
dove.</def> <rj><au>Booth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dovelike</ent><br/
<hw>Dove"like`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Mild as a dove;
gentle; pure and lovable.</def> <rj><au>Longfellow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dove plant</ent><br/
<hw>Dove" plant`</hw> <pr>(?)</pr>. <fld>(Bot.)</fld> <def>A Central
American orchid (<spn>Peristeria elata</spn>), having a flower stem five
or six feet high, with numerous globose white fragrant flowers. The
column in the center of the flower resembles a dove; -- called also
<altname>Holy Spirit plant</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dover's Powder</ent><br/
<hw>Do"ver's Pow"der</hw> <pr>(?)</pr>. <ety>[From Dr. <ets>Dover</ets>,
an English physician.]</ety> <fld>(Med.)</fld> <def>A powder of ipecac
and opium, compounded, in the United States, with sugar of milk, but in
England (as formerly in the United States) with sulphate of potash, and
in France (as in Dr. Dover's original prescription) with nitrate and
sulphate of potash and licorice. It is an anodyne diaphoretic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dove's-foot</ent><br/
<hw>Dove's"-foot`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<sd>(a)</sd> <def>A small annual species of Geranium, native in England;
-- so called from the shape of the leaf.</def> <sd>(b)</sd> <def>The
columbine.</def> <mark>[Prov. Eng.]</mark>
<rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doveship</ent><br/
<hw>Dove"ship</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The possession of
dovelike qualities, harmlessness and innocence.</def>
<mark>[Obs.]</mark> <rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dovetail</ent><br/
<hw>Dove"tail`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Carp.)</fld>
<def>A flaring tenon, or tongue (shaped like a bird's tail spread), and
a mortise, or socket, into which it fits tightly, making an interlocking
joint between two pieces which resists pulling a part in all directions
except one.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dovetail molding</b></col> <fld>(Arch.)</fld>, <cd>a
molding of any convex section arranged in a sort of zigzag, like a
series of dovetails.</cd> -- <col><b>Dovetail saw</b></col>
<fld>(Carp.)</fld>, <cd>a saw used in dovetailing.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dovetail</ent><br/
<hw>Dove"tail`</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Dovetailed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Dovetailing</conjf>.]</vmorph> <sn>1.</sn> <fld>(Carp.)</fld>
<sd>(a)</sd> <def>To cut to a dovetail.</def> <sd>(b)</sd> <def>To join
by means of dovetails.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To fit in or connect strongly, skillfully, or
nicely; to fit ingeniously or complexly.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He put together a piece of joinery so crossly indented and
whimsically <qex>dovetailed</qex> . . . that it was indeed a very
curious show.</q> <rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dovish</ent><br/
<hw>Dov"ish</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Like a
dove; harmless; innocent.</def> <ldquo/Joined with <xex>dovish</xex>
simplicity.<rdquo/ <rj><au>Latimer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>advocating peace, compromise or conciliation rather
than war or conflict. Opposite of <contr>hawkish</contr></def><br/
[<source>PJC</source>]</p>

<p><ent>Dovyalis</ent><br/
<hw>Dovyalis</hw> <pos>n.</pos> <def>a small genus of sometimes spiny
shrubs or small trees, found in Africa, India, and Sri Lanka.</def><br/
<syn><b>Syn. --</b> genus <gen>Dovyalis</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dow</ent><br/
<hw>Dow</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A kind of vessel. See
<er>Dhow</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dow</ent><br/
<hw>Dow</hw>, <pos>v. t.</pos> <ety>[F. <ets>douer</ets>. See
<er>Dower</er>.]</ety> <def>To furnish with a dower; to endow.</def>
<mark>[Obs.]</mark> <rj><au>Wyclif.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dow</ent><br/
<hw>Dow</hw> <pr>(dou)</pr>, <pos>prop. n.</pos> <fld>(Finance)</fld>
<def>shortened form of <er>the Dow-Jones Index</er> or Dow Jones
Industrial Average; <as>as, the <ex>Dow</ex> rose 100 points
today</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Dowable</ent><br/
<hw>Dow"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From <er>Dow</er>,
<pos>v. t.</pos>]</ety> <def>Capable of being endowed; entitled to
dower.</def> <rj><au>Blackstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dowager</ent><br/
<hw>Dow"a*ger</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>douagiere</ets>, fr. <ets>douage</ets> dower. See
<er>Dower</er>.]</ety> <sn>1.</sn> <fld>(Eng. Law)</fld> <def>A widow
endowed, or having a jointure; a widow who either enjoys a dower from
her deceased husband, or has property of her own brought by her to her
husband on marriage, and settled on her after his decease.</def>
<rj><au>Blount.</au> <au>Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A title given in England to a widow, to distinguish
her from the wife of her husband's heir bearing the same name; --
chiefly applied to widows of personages of rank.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With prudes for proctors, <qex>dowagers</qex> for deans.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Queen dowager</b></col>, <cd>the widow of a
king.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dowagerism</ent><br/
<hw>Dow"a*ger*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The rank or
condition of a dowager; formality, as that of a dowager. Also used
figuratively.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Mansions that have passed away into <qex>dowagerism</qex>.</q>
<rj><qau>Thackeray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dowcet</ent><br/
<hw>Dow"cet</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Doucet</er>.]</ety> <def>One of the testicles of a hart or
stag.</def> <altsp>[Spelt also <asp>doucet</asp>.]</altsp> <rj><au>B.
Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dowdy</ent><br/
<hw>Dow"dy</hw> <pr>(?)</pr>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Dowdier</adjf> <pr>(?)</pr>; <pos>superl.</pos>
<adjf>Dowdiest</adjf>.]</amorph> <ety>[Scot. <ets>dawdie</ets> slovenly,
<ets>daw</ets>, <ets>da</ets> sluggard, drab, Prov. E. <ets>dowd</ets>
flat, dead.]</ety> <def>Showing a vulgar taste in dress; awkward and
slovenly in dress; vulgar-looking.</def> --
<wordforms><wf>Dow"di*ly</wf> <pr>(#)</pr>, <pos>adv.</pos> --
<wf>Dow"di*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dowdy</ent><br/
<hw>Dow"dy</hw>, <pos>n.</pos>; <plu><it>pl.</it> <plw>Dowdies</plw>
<pr>(<?/)</pr>.</plu> <def>An awkward, vulgarly dressed, inelegant
woman.</def> <rj><au>Shak. Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dowdyish</ent><br/
<hw>Dow"dy*ish</hw>, <pos>a.</pos> <def>Like a dowdy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dowel</ent><br/
<hw>Dow"el</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. G.
<ets>d<oum/bel</ets> peg, F. <ets>douelle</ets> state of a cask, surface
of an arch, <ets>douille</ets> socket, little pipe, cartridge.]</ety>
<fld>(Mech.)</fld> <sn>1.</sn> <def>A pin, or block, of wood or metal,
fitting into holes in the abutting portions of two pieces, and being
partly in one piece and partly in the other, to keep them in their
proper relative position.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A piece of wood driven into a wall, so that other
pieces may be nailed to it.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dowel joint</b></col>, <cd>a joint secured by a dowel or
dowels.</cd> -- <col><b>Dowel pin</b></col>, <cd>a dowel. See
<er>Dowel</er>, <pos>n.</pos>, 1.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dowel</ent><br/
<hw>Dow"el</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Doweled</conjf> <pr>(?)</pr> <it>or</it> <conjf>Dowelled</conjf>;
<pos>p. pr. & vb. n.</pos> <conjf>Doweling</conjf> or
<conjf>Dowelling</conjf>.]</vmorph> <def>To fasten together by dowels;
to furnish with dowels; <as>as, a cooper <ex>dowels</ex> pieces for the
head of a cask</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>doweling</ent><br/
<hw>doweling</hw> <pos>n.</pos> <def>fastening by dowels.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dower</ent><br/
<hw>Dow"er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>douaire</ets>,
LL. <ets>dotarium</ets>, from L. <ets>dotare</ets> to endow, portion,
fr. <ets>dos</ets> dower; akin to Gr. <?/ gift, and to L.
<ets>dare</ets> to give. See 1st <er>Date</er>, and cf. <er>Dot</er>
dowry, <er>Dotation</er>.]</ety> <sn>1.</sn> <def>That with which one is
gifted or endowed; endowment; gift.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>How great, how plentiful, how rich a <qex>dower</qex>!</q>
<rj><qau>Sir J. Davies.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Man in his primeval <qex>dower</qex> arrayed.</q>
<rj><qau>Wordsworth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The property with which a woman is endowed</def>;
especially: <sd>(a)</sd> <def>That which a woman brings to a husband in
marriage; dowry.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>His wife brought in <qex>dower</qex> Cilicia's crown.</q>
<rj><qau>Dryden.</qau></rj></p>

<p><sd>(b)</sd> <fld>(Law)</fld> <def>That portion of the real estate of
a man which his widow enjoys during her life, or to which a woman is
entitled after the death of her husband.</def>
<rj><au>Blackstone.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Dower</xex>, in modern use, is and should be
distinguished from <xex>dowry</xex>. The former is a provision for a
widow on her husband's death; the latter is a bride's portion on her
marriage. <rj><au>Abbott.</au></rj></note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Assignment of dower</b></col>. <cd>See under
<er>Assignment</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dowered</ent><br/
<hw>Dow"ered</hw> <pr>(?)</pr>, <pos>p. a.</pos> <def>Furnished with, or
as with, dower or a marriage portion.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dowerless</ent><br/
<hw>Dow"er*less</hw>, <pos>a.</pos> <def>Destitute of dower; having no
marriage portion.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dowery</ent><br/
<hw>Dow"er*y</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Dower</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dowitcher</ent><br/
<hw>Dow"itch*er</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>The red-breasted or gray snipe (<spn>Macrorhamphus griseus</spn>);
-- called also <altname>brownback</altname>, and
<altname>grayback</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dow-Jones Index</ent><br/
<hw>Dow-Jones Index</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Finance)</fld> <def>an index of certain stock prices on the New
York Stock Exchange, computed by the Dow Jones publishing company as a
weighted average of the prices of specific stocks in certain categories.
Three indices are maintained, the Industrials, the Transportations, and
the Utilities. When used without qualification, the term usually refers
to the Dow Jones Industrial Average.</def><br/
<syn><b>Syn. --</b> Dow, Dow Jones, Dow-Jones Average.</syn>
[<source>PJC</source>]</p>

<p><ent>Dow-Jones Industrial Average</ent><br/
<hw>Dow-Jones Industrial Average</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Finance)</fld> <def>an index of certain stock prices on the New
York Stock Exchange, computed by the Dow Jones publishing company as a
weighted average of the prices of the common stocks of 30 specific
companies classified as "industrial". The Dow Jones Industrial Average
is often taken as an indicator of the movement of American stock prices
generally, though other indices are maintained, averaging the prices of
other stocks, and these often change in opposite directions from those
of the DJIA.</def><br/
<syn><b>Syn. --</b> DJI, DJIA, Dow, Dow Jones, Dow-Jones Average.</syn>
[<source>PJC</source>]</p>

<p><ent>Dowl</ent><br/
<hw>Dowl</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Dowle</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dowlas</ent><br/
<hw>Dow"las</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Prob. fr.
<ets>Doullens</ets>, a town of Picardy, in France, formerly celebrated
for this manufacture.]</ety> <def>A coarse linen cloth made in the north
of England and in Scotland, now nearly replaced by calico.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dowle</ent><br/
<hw>Dowle</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. OF.
<ets>douille</ets> soft. Cf. <er>Ductile</er>.]</ety> <def>Feathery or
wool-like down; filament of a feather.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>No feather, or <qex>dowle</qex> of a feather.</q> <rj><qau>De
Quincey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Down</ent><br/
<hw>Down</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Akin to LG.
<ets>dune</ets>, <ets>dun</ets>, Icel. <ets>d<?/nn</ets>, Sw.
<ets>dun</ets>, Dan. <ets>duun</ets>, G. <ets>daune</ets>, cf. D.
<ets>dons</ets>; perh. akin to E. <ets>dust</ets>.]</ety> <sn>1.</sn>
<def>Fine, soft, hairy outgrowth from the skin or surface of animals or
plants, not matted and fleecy like wool</def>; esp.: <sd>(a)</sd>
<fld>(Zool.)</fld> <def>The soft under feathers of birds. They have
short stems with soft rachis and bards and long threadlike barbules,
without hooklets.</def> <sd>(b)</sd> <fld>(Bot.)</fld> <def>The
pubescence of plants; the hairy crown or envelope of the seeds of
certain plants, as of the thistle.</def> <sd>(c)</sd> <def>The soft hair
of the face when beginning to appear.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And the first <qex>down</qex> begins to shade his face.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is made of down, as a bed or pillow; that
which affords ease and repose, like a bed of down</def><br/
[<source>1913 Webster</source>]</p>

<p><q>When in the <qex>down</qex> I sink my head,<br/
Sleep, Death's twin brother, times my breath.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou bosom softness, <qex>down</qex> of all my cares!</q>
<rj><qau>Southern.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 449 --></p>

<p><cs><col><b>Down tree</b></col> <fld>(Bot.)</fld>, <cd>a tree of
Central America (<spn>Ochroma Lagopus</spn>), the seeds of which are
enveloped in vegetable wool.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Down</ent><br/
<hw>Down</hw> <pr>(doun)</pr>, <pos>v. t.</pos> <def>To cover, ornament,
line, or stuff with down.</def> <mark>[R.]</mark>
<rj><au>Young.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Down</ent><br/
<hw>Down</hw>, <pos>n.</pos> <ety>[OE. <ets>dun</ets>, <ets>doun</ets>,
AS. <ets>d<umac/n</ets>; of Celtic origin; cf. Ir. <ets>d<umac/n</ets>
hill, fortified hill, Gael. <ets>dun</ets> heap, hillock, hill, W.
<ets>din</ets> a fortified hill or mount; akin to E. <ets>town</ets>.
See <er>Town</er>, and cf. <er>Down</er>, <pos>adv.</pos> &
<pos>prep.</pos>, <er>Dune</er>.]</ety> <sn>1.</sn> <def>A bank or
rounded hillock of sand thrown up by the wind along or near the shore; a
flattish-topped hill; -- usually in the plural.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Hills afford prospects, as they must needs acknowledge who have
been on the <qex>downs</qex> of Sussex.</q> <rj><qau>Ray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>She went by dale, and she went by <qex>down</qex>.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A tract of poor, sandy, undulating or hilly land
near the sea, covered with fine turf which serves chiefly for the
grazing of sheep; -- usually in the plural.</def>
<mark>[Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Seven thousand broad-tailed sheep grazed on his
<qex>downs</qex>.</q> <rj><qau>Sandys.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <pluf>pl.</pluf> <def>A road for shipping in the English
Channel or Straits of Dover, near Deal, employed as a naval rendezvous
in time of war.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>On the 11th [June, 1771] we run up the channel . . . at noon we
were abreast of Dover, and about three came to an anchor in the
<qex>Downs</qex>, and went ashore at Deal.</q> <rj><qau>Cook (First
Voyage).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <pluf>pl.</pluf> <ety>[From the adverb.]</ety> <def>A
state of depression; low state; abasement.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>It the <qex>downs</qex> of life too much outnumber the ups.</q>
<rj><qau>M. Arnold.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Down</ent><br/
<hw>Down</hw>, <pos>adv.</pos> <ety>[For older <ets>adown</ets>, AS.
<ets>ad<umac/n</ets>, <ets>ad<umac/ne</ets>, prop., from or off the
hill. See 3d <er>Down</er>, and cf. <er>Adown</er>, and cf.
<er>Adown</er>.]</ety> <sn>1.</sn> <def>In the direction of gravity or
toward the center of the earth; toward or in a lower place or position;
below; -- the opposite of <ant>up</ant>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> Hence, in many derived uses, as: <sd>(a)</sd> <def>From a
higher to a lower position, literally or figuratively; in a descending
direction; from the top of an ascent; from an upright position; to the
ground or floor; to or into a lower or an inferior condition; as, into a
state of humility, disgrace, misery, and the like; into a state of rest;
-- used with verbs indicating motion.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It will be rain to-night. Let it come <qex>down</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I sit me <qex>down</qex> beside the hazel grove.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And that drags <qex>down</qex> his life.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>There is not a more melancholy object in the learned world than a
man who has written himself <qex>down</qex>.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The French . . . shone <qex>down</qex> [i. e.,
<qex>outshone</qex>] the English.</q> <rj><qau>Shak.</qau></rj></p>

<p><sd>(b)</sd> <def>In a low or the lowest position, literally or
figuratively; at the bottom of a descent; below the horizon; on the
ground; in a condition of humility, dejection, misery, and the like; in
a state of quiet.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I was <qex>down</qex> and out of breath.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The moon is <qex>down</qex>; I have not heard the clock.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He that is <qex>down</qex> needs fear no fall.</q>
<rj><qau>Bunyan.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>From a remoter or higher antiquity.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Venerable men! you have come <qex>down</qex> to us from a former
generation.</q> <rj><qau>D. Webster.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>From a greater to a less bulk, or from a thinner to
a thicker consistence; <as>as, to boil <ex>down</ex> in cookery, or in
making decoctions</as>.</def> <rj><au>Arbuthnot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Down</xex> is sometimes used elliptically, standing
for <xex>go down</xex>, <xex>come down</xex>, <xex>tear down</xex>,
<xex>take down</xex>, <xex>put down</xex>, <xex>haul down</xex>,
<xex>pay down</xex>, and the like, especially in command or
exclamation.<br/
<br/
<q><qex>Down</qex>, therefore, and beg mercy of the duke.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]<br/
<br/
<q>If he be hungry more than wanton, bread alone will
<qex>down</qex>.</q> <rj><qau>Locke.</qau></rj><br/
<br/
<xex>Down</xex> is also used intensively; as, to be loaded
<xex>down</xex>; to fall <xex>down</xex>; to hang <xex>down</xex>; to
drop <xex>down</xex>; to pay <xex>down</xex>.<br/
<br/
<q>The temple of Her<egrave/ at Argos was burnt <qex>down</qex>.</q>
<rj><qau>Jowett (Thucyd.).</qau></rj><br/
<br/
<xex>Down</xex>, as well as <xex>up</xex>, is sometimes used in a
conventional sense; as, <xex>down</xex> East.<br/
<br/
<q>Persons in London say <qex>down</qex> to Scotland, etc., and those in
the provinces, <qex>up</qex> to London.</q>
<rj><qau>Stormonth.</qau></rj> </note><br/
[<source>1913 Webster</source>]</p>

<cs><p><col><b>Down helm</b></col> <fld>(Naut.)</fld>, <cd>an order to
the helmsman to put the helm to leeward.</cd> -- <mcol><col><b>Down
on</b></col> <it>or</it> <col><b>Down upon</b></col> (joined with a verb
indicating motion, as <xex>go</xex>, <xex>come</xex>,
<xex>pounce</xex>)</mcol>, <cd>to attack, implying the idea of
threatening power.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>Come <qex>down</qex> upon us with a mighty power.</q>
<rj><qau>Shak.</qau></rj></p>

<p>-- <col><b>Down with</b></col>, <cd>take down, throw down, put down;
-- used in energetic command, often by people aroused in crowds,
referring to people, laws, buildings, etc.; <as>as, <ex>down with</ex>
the king!</as></cd> <ldquo/<xex>Down with</xex> the palace; fire
it.<rdquo/ <au>Dryden.</au> -- <col><b>To be down on</b></col>, <cd>to
dislike and treat harshly.</cd> <mark>[Slang, U.S.]</mark> -- <col><b>To
cry down</b></col>. <cd>See under <er>Cry</er>, <pos>v. t.</pos></cd> --
<col><b>To cut down</b></col>. <cd>See under <er>Cut</er>, <pos>v.
t.</pos></cd> -- <col><b>Up and down</b></col>, <cd>with rising and
falling motion; to and fro; hither and thither; everywhere.</cd>
<ldquo/Let them wander <xex>up and down</xex>.<rdquo/ <au>Ps. lix.
15.</au><br/
[<source>1913 Webster</source>]</p></cs>

<p><ent>Down</ent><br/
<hw>Down</hw>, <pos>prep.</pos> <ety>[From <er>Down</er>,
<pos>adv.</pos>]</ety> <sn>1.</sn> <def>In a descending direction along;
from a higher to a lower place upon or within; at a lower place in or
on; <as>as, <ex>down</ex> a hill; <ex>down</ex> a well.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence: Towards the mouth of a river; towards the
sea; <as>as, to sail or swim <ex>down</ex> a stream; to sail
<ex>down</ex> the sound.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Down the country</b></col>, <cd>toward the sea, or toward
the part where rivers discharge their waters into the ocean.</cd> --
<col><b>Down the sound</b></col>, <cd>in the direction of the ebbing
tide; toward the sea.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Down</ent><br/
<hw>Down</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Downed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Downing</conjf>.]</vmorph> <def>To cause to go down; to make
descend; to put down; to overthrow, as in wrestling; hence, to subdue;
to bring down.</def> <mark>[Archaic or Colloq.]</mark> <ldquo/To
<xex>down</xex> proud hearts.<rdquo/ <rj><au>Sir P.
Sidney.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I remember how you <qex>downed</qex> Beauclerk and Hamilton, the
wits, once at our house.</q> <rj><qau>Madame D'Arblay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Down</ent><br/
<hw>Down</hw>, <pos>v. i.</pos> <def>To go down; to descend.</def>
<rj><au>Locke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Down</ent><br/
<hw>Down</hw>, <pos>a.</pos> <sn>1.</sn> <def>Downcast; <as>as, a
<ex>down</ex> look</as>.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Downright; absolute; positive; <as>as, a
<ex>down</ex> denial</as>.</def> <mark>[Obs.]</mark> <rj><au>Beau. &
Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Downward; going down; sloping; <as>as, a
<ex>down</ex> stroke; a <ex>down</ex> grade; a <ex>down</ex> train on a
railway.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Down draught</b></col>, <cd>a downward draft, as in a
flue, chimney, shaft of a mine, etc.</cd> -- <mcol><col><b>Down in the
mouth</b></col>, <col><b>Down at the mouth</b></col></mcol>
<cd>chopfallen; dejected.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>down-and-out</ent><br/
<hw>down-and-out</hw> <pos>adj.</pos> <sn>1.</sn> <def>impoverished; --
usually implying a state of dejection as well.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>physically weak.</def><br/
<syn><b>Syn. --</b> down-and-out.</syn><br/
[<source>PJC</source>]</p>

<p><ent>down-and-out</ent><br/
<hw>down-and-out</hw> <pos>n.</pos> <def>a person who is destitute;
<as>as, he tried to help the <ex>down-and-out</ex></as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Downbear</ent><br/
<hw>Down"bear`</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To bear down; to
depress.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>downbeat</ent><br/
<hw>downbeat</hw> <pos>n.</pos> <fld>(Music)</fld> <def>the first beat
of a musical measure (as the conductor's arm moves downward).</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>downbound</ent><br/
<hw>downbound</hw> <pos>adj.</pos> <def>leading in a downward
direction.</def><br/
<syn><b>Syn. --</b> down(prenominal), downward(prenominal).</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>down-bow</ent><br/
<hw>down-bow</hw> <pos>n.</pos> <fld>(Music)</fld> <def>a downward
stroke from the heel to the tip of the bow, in bowing a stringed
instrument. Contrasted with <contr>up-bow</contr>, when the bow is moved
in the opposite direction.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>downcast</ent><br/
<hw>down"cast`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Cast downward;
directed to the ground, from bashfulness, modesty, dejection, or
guilt.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>'T is love, said she; and then my <qex>downcast</qex> eyes,<br/
And guilty dumbness, witnessed my surprise.</q>
<rj><qau>Dryden.</qau></rj></p>

<p><sn>2.</sn> <def>depressed; dispirited; dejected; -- of
people.</def><br/
<syn><b>Syn. --</b> down(predicate), downhearted, low,
low-spirited.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p>-- <wordforms><wf>Down"cast`ly</wf>, <pos>adv.</pos> --
<wf>Down"cast`ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Downcast</ent><br/
<hw>Down"cast`</hw>, <pos>n.</pos> <sn>1.</sn> <def>Downcast or
melancholy look.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That <qex>downcast</qex> of thine eye.</q> <rj><qau>Beau. &
Fl.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mining)</fld> <def>A ventilating shaft down which
the air passes in circulating through a mine.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Downcome</ent><br/
<hw>Down"come`</hw> <pr>(doun"k<ucr/m`)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>Sudden fall; downfall; overthrow.</def>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Iron Manuf.)</fld> <def>A pipe for leading
combustible gases downward from the top of the blast furnace to the
hot-blast stoves, boilers, etc., where they are burned.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Downcomer</ent><br/
<hw>Down"com`er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A pipe to conduct
something downwards;</def> <specif>specif.</specif>: <sd>(a)</sd>
<fld>(Iron Manuf.)</fld> <def>A pipe for leading the hot gases from the
top of a blast furnace downward to the regenerators, boilers, etc.</def>
<sd>(b)</sd> <fld>(Steam Engin.)</fld> <def>In some water-tube boilers,
a tube larger in diameter than the water tubes to conduct the water from
each top drum to a bottom drum, thus completing the
circulation.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>downed</ent><br/
<hw>downed</hw> <pos>adj.</pos> <sn>1.</sn> <def>knocked down.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <fld>(Football)</fld> <def>touched to the ground, thus
ending the play; -- of a football.</def><br/
[<source>PJC</source>]</p>

<p><ent>downer</ent><br/
<hw>downer</hw> <pos>n.</pos> <def>a drug that reduces excitability and
calms a person.</def> <mark>[Colloq.]</mark> <br/
<syn><b>Syn. --</b> sedative, depressant.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Downfall</ent><br/
<hw>Down"fall`</hw> <pr>(doun"f<add/l`)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>A sudden fall; a body of things falling.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Those cataracts or <qex>downfalls</qex> aforesaid.</q>
<rj><qau>Holland.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Each <qex>downfall</qex> of a flood the mountains pour.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A sudden descent from rank or state, reputation or
happiness; destruction; ruin; <as>as, the senator's unrestrained sexual
escapades led to his <ex>downfall</ex></as>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><q>Dire were the consequences which would follow the
<qex>downfall</qex> of so important a place.</q>
<rj><qau>Motley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Downfallen</ent><br/
<hw>Down"fall`en</hw> <pr>(doun"f<add/l`'n)</pr>, <pos>a.</pos>
<def>Fallen; ruined.</def> <rj><au>Carew.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Downfalling</ent><br/
<hw>Down"fall`ing</hw>, <pos>a.</pos> <def>Falling down.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Downgyved</ent><br/
<hw>Down"gyved`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Hanging down like
gyves or fetters.</def> <mark>[Poetic & Rare]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Downhaul</ent><br/
<hw>Down"haul`</hw> <pr>(doun"h<add/l`)</pr>, <pos>n.</pos>
<fld>(Naut.)</fld> <def>A rope to haul down, or to assist in hauling
down, a sail; <as>as, a staysail <ex>downhaul</ex>; a trysail
<ex>downhaul</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Downhearted</ent><br/
<hw>Down"heart`ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Dejected;
low-spirited.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Downhill</ent><br/
<hw>Down"hill`</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>Towards the
bottom of a hill; <as>as, water runs <ex>downhill</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Downhill</ent><br/
<hw>Down"hill`</hw>, <pos>a.</pos> <def>Declivous; descending;
sloping.</def> <ldquo/A <xex>downhill</xex> greensward.<rdquo/
<rj><au>Congrewe.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Downhill</ent><br/
<hw>Down"hill`</hw>, <pos>n.</pos> <def>Declivity; descent;
slope.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>On th' icy <qex>downhills</qex> of this slippery life.</q>
<rj><qau>Du Bartas (Trans. ).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Downiness</ent><br/
<hw>Down"i*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The quality or
state of being downy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Downlooked</ent><br/
<hw>Down"looked`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having a downcast
countenance; dejected; gloomy; sullen.</def> <mark>[R.]</mark>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Downlying</ent><br/
<hw>Down"ly`ing</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The time of
retiring to rest; time of repose.</def> <rj><au>Cavendish.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>At the downlying</b></col>, <cd>at the travail in
childbirth.</cd> <mark>[Scot.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>down-market</ent><br/
<hw>down-market</hw> <pos>adj.</pos> <def>designed for low-income
consumers. Opposite of <ant>upmarket</ant>.</def><br/
<syn><b>Syn. --</b> downmarket.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Downpour</ent><br/
<hw>Down"pour`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A pouring or
streaming downwards; esp., a heavy or continuous shower.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Downright</ent><br/
<hw>Down"right`</hw> <pr>(?)</pr>, <pos>adv.</pos> <sn>1.</sn>
<def>Straight down; perpendicularly.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>In plain terms; without ceremony.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We shall chide <qex>downright</qex>, if I longer stay.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Without delay; at once; completely.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>She fell <qex>downright</qex> into a fit.</q>
<rj><qau>Arbuthnot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Downright</ent><br/
<hw>Down"right`</hw>, <pos>a.</pos> <sn>1.</sn> <def>Plain; direct;
forthright; unceremonious; blunt; positive; <as>as, he spoke in his
<ex>downright</ex> way</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A man of plain, <qex>downright</qex> character.</q> <rj><qau>Sir
W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Open; artless; undisguised; absolute; unmixed;
<as>as, <ex>downright</ex> atheism</as>.</def><br/
<syn><b>Syn. --</b> honest-to-goodness.</syn>
[<source>1913 Webster</source>]</p>

<p><q>The <qex>downright</qex> impossibilities charged upon it.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Gloomy fancies which in her amounted to <qex>downright</qex>
insanity.</q> <rj><qau>Prescott.</qau></rj></p>

<p>-- <wordforms><wf>Down"right`ly</wf>, <pos>adv.</pos> --
<wf>Down"right`ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Down-share</ent><br/
<hw>Down"-share`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A breastplow used
in paring off turf on downs.</def> <mark>[Eng.]</mark>
<rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Downsitting</ent><br/
<hw>Down"sit`ting</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
sitting down; repose; a resting.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou knowest my <qex>downsitting</qex> and my uprising.</q>
<rj><qau>Ps. cxxxix. 2.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>downsizing</ent><br/
<hw>downsizing</hw> <pos>n.</pos> <fld>(Economics)</fld> <def>the
reduction of expenditures and personnel in order to become financial
stable; -- of businesses.</def><br/
<syn><b>Syn. --</b> retrenchment, curtailment.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>downslope</ent><br/
<hw>downslope</hw> <pos>n.</pos> <def>a downward slope.</def><br/
<syn><b>Syn. --</b> descent, declivity, fall, decline.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>downstage</ent><br/
<hw>downstage</hw> <pos>n.</pos> <fld>(Theater)</fld> <def>the front
half of a stage. Opposite of <ant>upstage</ant>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>downstage</ent><br/
<hw>downstage</hw> <pos>adj.</pos> <fld>(Theater)</fld> <def>of or
pertaining to the front half of a stage. Opposite of
<ant>upstage</ant>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>downstage</ent><br/
<hw>downstage</hw> <pos>adv.</pos> <fld>(Theater)</fld> <def>at the
front half of the stage; <as>as, the dialog is clearer when conducted
<ex>downstage</ex></as>. Opposite of <ant>upstage</ant>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>downstairs</ent><br/
<ent>downstair</ent><br/
<mhw><hw>downstair</hw>, <hw>downstairs</hw></mhw> <pos>adj.</pos>
<def>on or of the lower floors of a building, especially the ground
floor; <as>as, the downstairs (or <ex>downstair</ex> phone; the house
has no <ex>downstairs</ex> bathroom</as>. Opposite of
<ant>upstairs</ant>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>downstairs</ent><br/
<hw>down"stairs</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>Down the stairs;
to a lower floor; <as>as, she headed <ex>downstairs</ex> as soon as she
heard the horn</as>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Downsteepy</ent><br/
<hw>Down"steep`y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Very steep.</def>
<mark>[Obs.]</mark> <rj><au>Florio.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Downstream</ent><br/
<hw>Down"stream`</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>Down the
stream; <as>as, floating <ex>downstream</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Downstroke</ent><br/
<hw>Down"stroke`</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Penmanship)</fld> <def>A stroke made with a downward motion of the
pen or pencil.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Down's syndrome</ent><br/
<ent>Down syndrome</ent><br/
<mhw><hw>Down" syn`drome</hw>, <hw>Down's" syn`drome</hw></mhw>
<pr>(?)</pr>, <pos>n.</pos> <fld>(Med.)</fld> <def>A congenital disorder
caused by an extra chromosome 21 in some or all cells. It causes a
variable number and degree of abnormalities, including retarded growth,
mental retardation, a short nose, prominent epicanthic folds on the
eyelids, a protruding lower lip, and other physical features having
varying degrees of deviation from the normal. Called also
<altname>mongolism</altname>, <altname>trisomy-21</altname> and
<altname>trisomy 21 syndrome</altname>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Downthrow</ent><br/
<hw>Down"throw`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Geol.)</fld>
<def>The sudden drop or depression of the strata of rocks on one side of
a fault. See <er>Throw</er>, <pos>n.</pos></def></p>

<p><ent>down-to-earth</ent><br/
<hw>down-to-earth</hw> <pos>adj.</pos> <def>facing reality squarely;
guided by practical experience and observation rather than theory.
Opposite of <ant>idealistic</ant>, <ant>unrealistic</ant>,
<ant>impractical</ant>, and <ant>pie-in-the-sky</ant>.</def><br/
<syn><b>Syn. --</b> hardheaded, hard-nosed, practical,
pragmatic.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Downtrodden</ent><br/
<ent>Downtrod</ent><br/
<mhw>{ <hw>Down"trod`</hw> <pr>(?)</pr>, <hw>Down"trod`den</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <def>Trodden down; trampled down;
abused by superior power.</def> <rj><au>Shak.</au></rj></p>

<p><ent>Downwards</ent><br/
<ent>Downward</ent><br/
<mhw>{ <hw>Down"ward</hw> <pr>(?)</pr>, <hw>Down"wards</hw>
<pr>(?)</pr>, }</mhw> <pos>adv.</pos> <ety>[AS. <ets>ad<?/nweard</ets>.
See <er>Down</er>, <pos>adv.</pos>, and <er>-ward</er>.]</ety>
<sn>1.</sn> <def>From a higher place to a lower; in a descending course;
<as>as, to tend, move, roll, look, or take root, <ex>downward</ex> or
<ex>downwards</ex></as>.</def> <ldquo/Looking
<xex>downwards</xex>.<rdquo/ <rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Their heads they <qex>downward</qex> bent.</q>
<rj><qau>Drayton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>From a higher to a lower condition; toward misery,
humility, disgrace, or ruin.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And <qex>downward</qex> fell into a groveling swine.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>From a remote time; from an ancestor or predecessor;
from one to another in a descending line.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A ring the county wears,<br/
That <qex>downward</qex> hath descended in his house,<br/
From son to son, some four or five descents.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Downward</ent><br/
<hw>Down"ward</hw>, <pos>a.</pos> <sn>1.</sn> <def>Moving or extending
from a higher to a lower place; tending toward the earth or its center,
or toward a lower level; declivous.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With <qex>downward</qex> force<br/
That drove the sand along he took his way.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Descending from a head, origin, or source; <as>as, a
<ex>downward</ex> line of descent</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Tending to a lower condition or state; depressed;
dejected; <as>as, <ex>downward</ex> thoughts</as>.</def> <rj><au>Sir P.
Sidney.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Downweed</ent><br/
<hw>Down"weed`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>Cudweed, a species of <gen>Gnaphalium</gen>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Downweigh</ent><br/
<hw>Down`weigh"</hw> <pr>(-w<amac/")</pr>, <pos>v. t.</pos> <def>To
weigh or press down.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A different sin <qex>downweighs</qex> them to the bottom.</q>
<rj><qau>Longfellow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Down-wind</ent><br/
<hw>Down"-wind`</hw>, <pos>adv.</pos> <def>With the wind.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>downwind</ent><br/
<hw>down"wind</hw> <pos>adj.</pos> <def>on the side or in the direction
away from the direction from which the wind is blowing; in the direction
toward which the wind is blowing; <as>as, good hunters stay
<ex>downwind</ex> of their prey</as>. Opposite of <ant>upwind</ant>, and
<ant>windward</ant>.</def><br/
<syn><b>Syn. --</b> lee(prenominal), leeward.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Downy</ent><br/
<hw>Down"y</hw> <pr>(-<ycr/)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Covered with down, or with pubescence or soft hairs.</def> <ldquo/A
<xex>downy</xex> feather.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Plants that . . . have <qex>downy</qex> or velvet rind upon their
leaves.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Made of, or resembling, down. Hence, figuratively:
Soft; placid; soothing; quiet.</def> <ldquo/A <xex>downy</xex>
shower.<rdquo/ <au>Keble.</au> <ldquo/<xex>Downy</xex> pillow.<rdquo/
<rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Time steals on with <qex>downy</qex> feet.</q>
<rj><qau>Young.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Cunning; wary.</def> <mark>[Slang, Eng.]</mark>
<rj><au>Latham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Downy woodpecker</ent><br/
<hw>Down"y wood"peck*er</hw> <pr>(-<ycr/)</pr>, <pos>n.</pos>
<fld>(Zool.)</fld> <def>A small black and white ladder-backed woodpecker
(<spn>Picoides pubescens</spn>) of Central and Eastern U. S. and Canada.
It strongly resembles the hairy woodpecker, but is smaller (6 1/2"),
compared with about 9-1/2" for the hairy. It is common in suburban
backyards.</def><br/
[<source>PJC</source>]</p>

<p><ent>Dowral</ent><br/
<hw>Dow"ral</hw> <pr>(dou"r<ait/l)</pr>, <pos>a.</pos> <def>Of or
relating to a dower.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dowress</ent><br/
<hw>Dow"ress</hw>, <pos>n.</pos> <def>A woman entitled to dower.</def>
<rj><au>Bouvier.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dowry</ent><br/
<hw>Dow"ry</hw> <pr>(dou"r<ycr/)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Dowries</plw> <pr>(dou"r<icr/z)</pr>.</plu> <ety>[Contr. from
<ets>dowery</ets>; cf. LL. <ets>dotarium</ets>. See
<er>Dower</er>.]</ety> <sn>1.</sn> <def>A gift; endowment.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The money, goods, or estate, which a woman brings to
her husband in marriage; a bride's portion on her marriage. See Note
under <er>Dower</er>.</def> <rj><au>Shak. Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A gift or presents for the bride, on espousal. See
<er>Dower</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Ask me never so much <qex>dowry</qex> and gift, and I will give .
. .; but give me the damsel to wife.</q> <rj><qau>Gen. xxxiv.
12.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dowse</ent><br/
<hw>Dowse</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[Cf. 1st
<er>Douse</er>.]</ety> <sn>1.</sn> <def>To plunge, or duck into water;
to immerse; to douse.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <ety>[Cf. OD. <ets>doesen</ets> to strike, Norw.
<ets>dusa</ets> to break.]</ety> <def>To beat or thrash.</def>
<mark>[Prov. Eng.]</mark> <rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dowse</ent><br/
<hw>Dowse</hw>, <pos>v. i.</pos> <def>To use the dipping or divining
rod, as in search of water, ore, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Adams had the reputation of having <qex>dowsed</qex> successfully
for more than a hundred wells.</q> <rj><qau>Eng. Cyc.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dowse</ent><br/
<hw>Dowse</hw>, <pos>n.</pos> <def>A blow on the face.</def>
<mark>[Low]</mark> <rj><au>Colman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dowser</ent><br/
<hw>Dows"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A divining
rod used in searching for water, ore, etc., a dowsing rod.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who uses the dowser or divining rod.</def>
<rj><au>Eng. Cyc.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dowst</ent><br/
<hw>Dowst</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A dowse.</def>
<mark>[Obs.]</mark> <rj><au>Beau. & Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dowve</ent><br/
<hw>Dow"ve</hw> <pr>(dou"v<eit/)</pr>, <pos>n.</pos> <def>A dove.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doxological</ent><br/
<hw>Dox`o*log"ic*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to
doxology; giving praise to God.</def> <rj><au>Howell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doxologize</ent><br/
<hw>Dox*ol"o*gize</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Doxologized</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Doxologizing</conjf>.]</vmorph> <def>To give glory to God, as in
a doxology; to praise God with doxologies.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doxology</ent><br/
<hw>Dox*ol"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Doxologies</plw> <pr>(#)</pr>.</plu> <ety>[LL.
<ets>doxologia</ets>, Gr. <?/, fr. <?/ praising, giving glory; <?/
opinion, estimation, glory, praise (from <?/ to think, imagine) + <?/ to
speak: cf. F. <ets>doxologie</ets>. See <er>Dogma</er>, and
<er>Legend</er>.]</ety> <def>In Christian worship: A hymn expressing
praise and honor to God; a form of praise to God designed to be sung or
chanted by the choir or the congregation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>David breaks forth into these triumphant praises and
<qex>doxologies</qex>.</q> <rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doxy</ent><br/
<hw>Dox"y</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Doxies</plw> <pr>(#)</pr>.</plu> <ety>[See <er>Duck</er> a
pet.]</ety> <def>A loose wench; a disreputable sweetheart.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doyen</ent><br/
\'d8<hw>Doy`en"</hw> <pr>(dw<aum/`y<aum/N")</pr>, <pos>n.</pos> <ety>[F.
See <er>Dean</er>.]</ety> <def>Lit., a dean; the senior member of a body
or group; <as>as, the <ex>doyen</ex> of French physicians</as>.</def>
<ldquo/This <xex>doyen</xex> of newspapers.<rdquo/ <rj><au>A. R.
Colquhoun.</au></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>doyenne</ent><br/
<hw>doy`enne"</hw> <pos>n. f.</pos> <def>a female doyen.</def><br/
[<source>PJC</source>]</p>

<p><ent>doyley</ent><br/
<hw>doyley</hw> <pos>n.</pos> <sn>1.</sn> <def>a small round piece of
linen place under a dish or bowl; same as <er>doily</er>.</def><br/
<syn><b>Syn. --</b> doily, doyly.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>doyly</ent><br/
<hw>doy"ly</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Doily</er>.</def><br/
<syn><b>Syn. --</b> doily, doyley.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doze</ent><br/
<hw>Doze</hw> <pr>(d<omac/z)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Dozed</conjf> <pr>(d<omac/zd)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Dozing</conjf>.]</vmorph> <ety>[Prob. akin to
<ets>daze</ets>, <ets>dizzy</ets>: cf. Icel. <ets>d<umac/sa</ets> to
doze, Dan. <ets>d<oum/se</ets> to make dull, heavy, or drowsy,
<ets>d<oum/s</ets> dullness, drowsiness, <ets>d<oum/sig</ets> drowsy,
AS. <ets>dw<aemac/s</ets> dull, stupid, foolish. <root/71. Cf.
<er>Dizzy</er>.]</ety> <def>To slumber; to sleep lightly; to be in a
dull or stupefied condition, as if half asleep; to be drowsy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>If he happened to <qex>doze</qex> a little, the jolly cobbler
waked him.</q> <rj><qau>L'Estrange.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doze</ent><br/
<hw>Doze</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To pass or spend in
drowsiness; <as>as, to <ex>doze</ex> away one's time</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To make dull; to stupefy.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I was an hour . . . in casting up about twenty sums, being
<qex>dozed</qex> with much work.</q> <rj><qau>Pepys.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>They left for a long time <qex>dozed</qex> and benumbed.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doze</ent><br/
<hw>Doze</hw>, <pos>n.</pos> <def>A light sleep; a drowse.</def>
<rj><au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dozen</ent><br/
<hw>Doz"en</hw> <pr>(d<ucr/z"'n)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Dozen</plw> (before another noun), <plw>Dozens</plw>
<pr>(d<ucr/z"'nz)</pr>.</plu> <ety>[OE. <ets>doseine</ets>,
<ets>dosein</ets>, OF. <ets>doseine</ets>, F. <ets>douzaine</ets>, fr.
<ets>douze</ets> twelve, fr. L. <ets>duodecim</ets>; <ets>duo</ets> two
+ <ets>decem</ets> ten. See <er>Two</er>, <er>Ten</er>, and cf.
<er>Duodecimal</er>.]</ety> <sn>1.</sn> <def>A collection of twelve
objects; a tale or set of twelve; with or without <xex>of</xex> before
the substantive which follows.</def> <ldquo/Some six or seven
<xex>dozen</xex> of Scots.<rdquo/ <ldquo/A <xex>dozen</xex> of shirts to
your back.<rdquo/ <ldquo/A <xex>dozen</xex> sons.<rdquo/ <ldquo/Half a
<xex>dozen</xex> friends.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An indefinite small number.</def>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>A baker's dozen</b></col>, <cd>thirteen; -- called also a
<altname>long dozen</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dozenth</ent><br/
<hw>Doz"enth</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Twelfth.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dozer</ent><br/
<hw>Doz"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who dozes or
drowses.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Doziness</ent><br/
<hw>Doz"i*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state of being
dozy; drowsiness; inclination to sleep.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dozy</ent><br/
<hw>Doz"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Drowsy; inclined to
doze; sleepy; sluggish; <as>as, a <ex>dozy</ex> head</as>.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dozzled</ent><br/
<hw>Doz"zled</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[<root/71.]</ety>
<def>Stupid; heavy.</def> <mark>[Obs. or Prov. Eng.]</mark>
<rj><au>Halliwell.</au></rj></p>

<p><ent>DPhil</ent><br/
<hw>DPhil</hw> <pos>n.</pos> <sn>1.</sn> <def>Doctor of Philosophy, a
British doctorate.</def><br/
<syn><b>Syn. --</b> Doctor of Philosophy.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dr.</ent><br/
<hw>Dr.</hw> <pos>n.</pos> <def>abbreviation for
<altname>doctor</altname>, a title accorded to a person who holds a
doctorate degree from an academic institution, such as a Ph.D. degree or
M.D. degree.</def> <mark>[abbrev.]</mark> <br/
<syn><b>Syn. --</b> doctor.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>a licensed doctor of medicine.</def><br/
<syn><b>Syn. --</b> doctor, doc, physician, MD, medico.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Drab</ent><br/
<hw>Drab</hw> <pr>(dr<acr/b)</pr>, <pos>n.</pos> <ety>[AS.
<ets>drabbe</ets> dregs, lees; akin to D. <ets>drab</ets>,
<ets>drabbe</ets>, dregs, G. <ets>treber</ets>; for sense 1, cf. also
Gael. <ets>drabag</ets> a slattern, <ets>drabach</ets> slovenly. Cf.
<er>Draff</er>.]</ety> <sn>1.</sn> <def>A low, sluttish woman.</def>
<rj><au>King.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A lewd wench; a strumpet.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A wooden box, used in salt works for holding the
salt when taken out of the boiling pans.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drab</ent><br/
<hw>Drab</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Drabbed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Drabbing</conjf>.]</vmorph> <def>To associate with strumpets; to
wench.</def> <rj><au>Beau. & Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drab</ent><br/
<hw>Drab</hw>, <pos>n.</pos> <ety>[F. <ets>drap</ets> cloth: LL.
<ets>drappus</ets>, <ets>trapus</ets>, perh. orig., a firm, solid stuff,
cf. F. <ets>draper</ets> to drape, also to full cloth; prob. of German
origin; cf. Icel. <ets>drepa</ets> to beat, strike, AS.
<ets>drepan</ets>, G. <ets>treffen</ets>; perh. akin to E.
<ets>drub</ets>. Cf. <er>Drape</er>, <er>Trappings</er>.]</ety>
<sn>1.</sn> <def>A kind of thick woolen cloth of a dun, or dull brownish
yellow, or dull gray, color; -- called also
<altname>drabcloth</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A dull brownish yellow or dull gray color.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drab</ent><br/
<hw>Drab</hw>, <pos>a.</pos> <def>Of a color between gray and
brown.</def> -- <def2><pos>n.</pos> <def>A drab color.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drabber</ent><br/
<hw>Drab"ber</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who associates
with drabs; a wencher.</def> <rj><au>Massinger.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drabbet</ent><br/
<hw>Drab"bet</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A coarse linen
fabric, or duck.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drabbish</ent><br/
<hw>Drab"bish</hw>, <pos>a.</pos> <def>Somewhat drab in color.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drabbish</ent><br/
<hw>Drab"bish</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having the character
of a drab or low wench.</def> <ldquo/The <xex>drabbish</xex>
sorceress.<rdquo/ <rj><au>Drant.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drabble</ent><br/
<hw>Drab"ble</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Drabbled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Drabbling</conjf> <pr>(?)</pr>.]</vmorph>
<ety>[<?/<?/<?/.See <er>Drab</er>, <er>Draff</er>.]</ety> <def>To
draggle; to wet and befoul by draggling; as, to <xex>drabble</xex> a
gown or cloak.</def> <rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 450 pr=GH --></p>

<p><ent>Drabble</ent><br/
<hw>Drab"ble</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To fish with a
long line and rod; <as>as, to <ex>drabble</ex> for
barbels</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drabbler</ent><br/
<hw>Drab"bler</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Naut.)</fld> <def>A
piece of canvas fastened by lacing to the bonnet of a sail, to give it a
greater depth, or more drop.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drabble-tail</ent><br/
<hw>Drab"ble-tail`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A draggle-tail;
a slattern.</def> <rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dracaena</ent><br/
\'d8<hw>Dra*c<ae/"na</hw> <pr>(?)</pr>, <pos>prop. n.</pos> <ety>[NL.,
fr. Gr. <?/ she-dragon.]</ety> <fld>(Bot.)</fld> <def>A genus of
liliaceous plants with woody stems and funnel-shaped flowers.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Drac<ae/na Draco</xex>, the source of the dragon's
blood of the Canaries, forms a tree, sometimes of gigantic
size.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dracanth</ent><br/
<hw>Dra"canth</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A kind of gum; --
called also <altname>gum tragacanth</altname>, or
<altname>tragacanth</altname>. See <er>Tragacanth</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drachm</ent><br/
<hw>Drachm</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Drachma</er>.]</ety> <sn>1.</sn> <def>A drachma.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Same as <er>Dram</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drachma</ent><br/
\'d8<hw>Drach"ma</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it> E.
<plw>Drachmas</plw> <pr>(#)</pr>, L. <plw>Drachm<ae/</plw>
<pr>(#)</pr>.</plu> <ety>[L., fr. Gr. <?/. See <er>Dram</er>.]</ety>
<sn>1.</sn> <def>A silver coin among the ancient Greeks, having a
different value in different States and at different periods. The
average value of the Attic drachma is computed to have been about 19
cents (U. S. currency, ca. 1913).</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A gold and silver coin of modern Greece worth 19.3
cents.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Among the ancient Greeks, a weight of about 66.5
grains; among the modern Greeks, a weight equal to a gram.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drachme</ent><br/
\'d8<hw>Drach"me</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<def>See <er>Drachma</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dracin</ent><br/
<hw>Dra"cin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>dracine</ets>.]</ety> <fld>(Chem.)</fld> <def>See
<er>Draconin</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Draco</ent><br/
\'d8<hw>Dra"co</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. See
<er>Dragon</er>.]</ety> <sn>1.</sn> <fld>(Astron.)</fld> <def>The
Dragon, a northern constellation within which is the north pole of the
ecliptic.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A luminous exhalation from marshy grounds.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <def>A genus of lizards. See
<er>Dragon</er>, 6.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dracocephalum</ent><br/
<hw>Dra`co*ceph"a*lum</hw> <pos>prop. n.</pos> <def>A genus of American
herbs and dwarf shrubs of the mind family; the dragonheads.</def><br/
<syn><b>Syn. --</b> genus <gen>Dracocephalum</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Draconian</ent><br/
<hw>Dra*co"ni*an</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to
Draco, a famous lawgiver of Athens, 621 <sc>b. c.</sc> Used especially
in the phrase <cref>Draconian punishment</cref>.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><cs><mcol><col><b>Draconian code</b></col>, <it>or</it>
<col><b>Draconian laws</b></col></mcol>, <cd>a code of laws made by
<persfn>Draco</persfn>. Their measures were so severe that they were
said to be written in letters of blood; hence, any laws of excessive
rigor.</cd> -- <col><b>Draconian punishment</b></col>, <cd>punishment so
severe as to seem excessive for the crime being punished.</cd></cs><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Draconic</ent><br/
<hw>Dra*con"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Relating to Draco,
the Athenian lawgiver; or to the constellation Draco; or to dragon's
blood.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Draconin</ent><br/
<hw>Dra*co"nin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>draconine</ets>. See <er>Draco</er>.]</ety> <fld>(Chem.)</fld>
<def>A red resin forming the essential basis of dragon's blood; --
called also <altname>dracin</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dracontic</ent><br/
<hw>Dra*con"tic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From L.
<ets>draco</ets> dragon, in allusion to the terms <ets>dragon's
head</ets> and <ets>dragon's tail</ets>.]</ety> <fld>(Astron.)</fld>
<def>Belonging to that space of time in which the moon performs one
revolution, from ascending node to ascending node. See <cref>Dragon's
head</cref>, under <er>Dragon</er>.</def> <mark>[Obs.]</mark>
<ldquo/<xex>Dracontic</xex> month.<rdquo/ <rj><au>Crabb.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dracontine</ent><br/
<hw>Dra*con"tine</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>draco</ets> dragon.]</ety> <def>Belonging to a dragon.</def>
<rj><au>Southey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dracunculus</ent><br/
\'d8<hw>Dra*cun"cu*lus</hw> <pr>(?)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Dracunculi</plw> <pr>(#)</pr>.</plu> <ety>[L.,
dim. of <ets>draco</ets> dragon.]</ety> <fld>(Zool.)</fld> <sd>(a)</sd>
<def>A fish; the dragonet.</def> <sd>(b)</sd> <def>The Guinea worm
(<spn>Filaria medinensis</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drad</ent><br/
<hw>Drad</hw> <pr>(?)</pr>, <pos>p. p. & a.</pos> <def>Dreaded.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dradde</ent><br/
<hw>Drad"de</hw> <pr>(?)</pr>, <pos>imp.</pos> <def>of
<er>Dread</er>.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dradge</ent><br/
<hw>Dradge</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Min.)</fld>
<def>Inferior ore, separated from the better by cobbing.</def>
<rj><au>Raymond.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Draff</ent><br/
<hw>Draff</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. D. <ets>draf</ets>
the sediment of ale, Icel. <ets>draf</ets> draff, husks. Cf. 1st
<er>Drab</er>.]</ety> <def>Refuse; lees; dregs; the wash given to swine
or cows; hogwash; waste matter.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Prodigals lately come from swine keeping, from eating
<qex>draff</qex> and husks.</q> <rj><qau> Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>draff</qex> and offal of a bygone age.</q> <rj><qau>
Buckle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Mere chaff and <qex>draff</qex>, much better burnt.</q> <rj><qau>
Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Draffish</ent><br/
<hw>Draff"ish</hw>, <pos>a.</pos> <def>Worthless; draffy.</def>
<rj><au>Bale.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Draffy</ent><br/
<hw>Draff"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Dreggy; waste;
worthless.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The dregs and <qex>draffy</qex> part.</q> <rj><qau> Beau. &
Fl.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Draft</ent><br/
<hw>Draft</hw> <pr>(dr<adot/ft)</pr>, <pos>n.</pos> <ety>[The same word
as <ets>draught</ets>. OE. <ets>draught</ets>, <ets>draht</ets>, fr. AS.
<ets>dragan</ets> to draw. See <er>Draw</er>, and cf.
<er>Draught</er>.]</ety> <sn>1.</sn> <def>The act of drawing; also, the
thing drawn. Same as <er>Draught</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Everything available for <qex>draft</qex> burden.</q> <rj><qau> S.
G. Goodrich.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mil.)</fld> <def>A selecting or detaching of
soldiers from an army, or from any part of it, or from a military post;
also from any district, or any company or collection of persons, or from
the people at large; also, the body of men thus drafted.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Several of the States had supplied the deficiency by
<qex>drafts</qex> to serve for the year.</q>
<rj><qau>Marshall.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>An order from one person or party to another,
directing the payment of money; a bill of exchange.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I thought it most prudent to defer the <qex>drafts</qex> till
advice was received of the progress of the loan.</q> <rj><qau> A.
Hamilton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>An allowance or deduction made from the gross weight
of goods.</def> <rj><au> Simmonds.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A drawing of lines for a plan; a plan delineated, or
drawn in outline; a delineation. See <er>Draught</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>The form of any writing as first drawn up; the first
rough sketch of written composition, to be filled in, or completed. See
<er>Draught</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Masonry)</fld> <sd>(a)</sd> <def>A narrow border
left on a finished stone, worked differently from the rest of its
face.</def> <sd>(b)</sd> <def>A narrow border worked to a plane surface
along the edge of a stone, or across its face, as a guide to the
stone-cutter.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <fld>(Milling)</fld> <def>The slant given to the furrows
in the dress of a millstone.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <fld>(Naut.)</fld> <def>Depth of water necessary to float
a ship. See <er>Draught</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <def>A current of air. Same as
<er>Draught</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>11.</sn> <def>A quantity of liquid poured out for drinking; a
dose.</def><br/
[<source>PJC</source>]</p>

<p><sn>12.</sn> <def>The act of drawing a quantity of liquid from a
large container; also, the quantity of liquid so drawn.</def><br/
[<source>PJC</source>]</p>

<p><sn>13.</sn> <def>A device for regulating the flow of gases in a
chimney, stovepipe, fireplace, etc.; <as>as, to close the chimney
<ex>draft</ex></as>. It is usually a flat plate of the same internal
dimensions as the flue, which can be rotated to be parallel to or
perpendicular to the current of gases.</def><br/
[<source>PJC</source>]</p>

<p><ent>Draft</ent><br/
<hw>Draft</hw>, <pos>a.</pos> <sn>1.</sn> <def>Pertaining to, or used
for, drawing or pulling (as vehicles, loads, etc.). Same as
<er>Draught</er>; <as>as, a <ex>draft</ex> horse</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Relating to, or characterized by, a draft, or
current of air. Same as <er>Draught</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The forms <xex>draft</xex> and <xex>draught</xex>, in
the senses above-given, are both in approved use.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Draft box</b></col>, <col><b>Draft
engine</b></col>, <col><b>Draft horse</b></col>, <col><b>Draft
net</b></col>, <col><b>Draft ox</b></col>, <col><b>Draft
tube</b></col></mcol>. <cd>Same as <cref>Draught box</cref>,
<cref>Draught engine</cref>, etc. See under
<er>Draught</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Draft</ent><br/
<hw>Draft</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Drafted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Drafting</conjf>.]</vmorph> <sn>1.</sn> <def>To draw the outline
of; to delineate.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To compose and write; <as>as, to <ex>draft</ex> a
memorial</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To draw from a military band or post, or from any
district, company, or society; to detach; to select; especially, to
compulsorily select and induct members of a population to serve in the
armed forces.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><q>HotLips Houlihan: How did a degenerate person like him achieve
such a position of responsibility in the army? Radar: He was
<qex>drafted</qex>.</q> <rj><qau>M*A*S*H (the movie)</qau></rj></p>

<p><q>Some royal seminary in Upper Egypt, from whence they
<qex>drafted</qex> novices to supply their colleges and temples.</q>
<rj><qau> Holwell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To transfer by draft.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>All her rents been <qex>drafted</qex> to London.</q> <rj><qau>
Fielding.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>drafting</ent><br/
<hw>drafting</hw> <pos>n.</pos> <sn>1.</sn> <def>writing a first version
to be filled out and polished later.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>the craft of drawing blueprints.</def><br/
<syn><b>Syn. --</b> mechanical drawing.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>3.</sn> <def>a creation of artistic drawings.</def><br/
<syn><b>Syn. --</b> drawing, draftsmanship.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Draftsman</ent><br/
<hw>Drafts"man</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Draughtsman</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>draftsmanship</ent><br/
<hw>draftsmanship</hw> <pos>n.</pos> <def>the creation of artistic
drawings.</def><br/
<syn><b>Syn. --</b> drawing, drafting.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>draftsperson</ent><br/
<hw>draftsperson</hw> <pos>n.</pos> <def>a skilled worker who draws
plans of buildings or machines.</def><br/
<syn><b>Syn. --</b> draftsman, draughtsman.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>drafty</ent><br/
<hw>draft"y</hw> <pos>adj.</pos> <def>not airtight; allowing in currents
of air, especially uncomfortably cold air; -- of buildings.</def><br/
<syn><b>Syn. --</b> draughty.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Drag</ent><br/
<hw>Drag</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See 3d
<er>Dredge</er>.]</ety> <def>A confection; a comfit; a drug.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drag</ent><br/
<hw>Drag</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Dragged</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Dragging</conjf> <pr>(?)</pr>.]</vmorph> <ety>[OE.
<ets>draggen</ets>; akin to Sw. <ets>dragga</ets> to search with a
grapnel, fr. <ets>dragg</ets> grapnel, fr. <ets>draga</ets> to draw, the
same word as E. <ets>draw</ets>. <?/ See <er>Draw</er>.]</ety>
<sn>1.</sn> <def>To draw slowly or heavily onward; to pull along the
ground by main force; to haul; to trail; -- applied to drawing heavy or
resisting bodies or those inapt for drawing, with labor, along the
ground or other surface; <as>as, to <ex>drag</ex> stone or timber; to
<ex>drag</ex> a net in fishing.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Dragged</qex> by the cords which through his feet were
thrust.</q> <rj><qau>Denham.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The grossness of his nature will have weight to <qex>drag</qex>
thee down.</q> <rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A needless Alexandrine ends the song<br/
That, like a wounded snake, <qex>drags</qex> its slow length along.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To break, as land, by drawing a drag or harrow over
it; to harrow; to draw a drag along the bottom of, as a stream or other
water; hence, to search, as by means of a drag.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Then while I <qex>dragged</qex> my brains for such a song.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To draw along, as something burdensome; hence, to
pass in pain or with difficulty.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Have <qex>dragged</qex> a lingering life.</q> <rj><qau>
Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To drag an anchor</b></col> <fld>(Naut.)</fld>, <cd>to
trail it along the bottom when the anchor will not hold the
ship.</cd></cs></p>

<p><syn><b>Syn.</b> -- See <er>Draw</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drag</ent><br/
<hw>Drag</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To be drawn along, as a
rope or dress, on the ground; to trail; to be moved onward along the
ground, or along the bottom of the sea, as an anchor that does not
hold.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To move onward heavily, laboriously, or slowly; to
advance with weary effort; to go on lingeringly.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The day <qex>drags</qex> through, though storms keep out the
sun.</q> <rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Long, open panegyric <qex>drags</qex> at best.</q> <rj><qau>
Gay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To serve as a clog or hindrance; to hold
back.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A propeller is said to <qex>drag</qex> when the sails urge the
vessel faster than the revolutions of the screw can propel her.</q>
<rj><qau>Russell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To fish with a dragnet.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drag</ent><br/
<hw>Drag</hw>, <pos>n.</pos> <ety>[See <er>Drag</er>, <pos>v. t.</pos>,
and cf. <er>Dray</er> a cart, and 1st <er>Dredge</er>.]</ety>
<sn>1.</sn> <def>The act of dragging; anything which is
dragged.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A net, or an apparatus, to be drawn along the bottom
under water, as in fishing, searching for drowned persons,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A kind of sledge for conveying heavy bodies; also, a
kind of low car or handcart; <as>as, a stone
<ex>drag</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A heavy coach with seats on top; also, a heavy
carriage.</def> <mark>[Collog.]</mark> <rj><au>Thackeray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A heavy harrow, for breaking up ground.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <sd>(a)</sd> <def>Anything towed in the water to retard a
ship's progress, or to keep her head up to the wind; esp., a canvas bag
with a hooped mouth, so used. See <cref>Drag sail</cref> (below).</def>
<sd>(b)</sd> <def>Also, a skid or shoe, for retarding the motion of a
carriage wheel.</def> <sd>(c)</sd> <def>Hence, anything that retards; a
clog; an obstacle to progress or enjoyment.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>My lectures were only a pleasure to me, and no
<qex>drag</qex>.</q> <rj><qau>J. D. Forbes.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>Motion affected with slowness and difficulty, as if
clogged.</def> <ldquo/Had a <xex>drag</xex> in his walk.<rdquo/ <rj><au>
Hazlitt.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <fld>(Founding)</fld> <def>The bottom part of a flask or
mold, the upper part being the cope.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <fld>(Masonry)</fld> <def>A steel instrument for
completing the dressing of soft stone.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <fld>(Marine Engin.)</fld> <def>The difference between
the speed of a screw steamer under sail and that of the screw when the
ship outruns the screw; or between the propulsive effects of the
different floats of a paddle wheel. See Citation under <er>Drag</er>,
<pos>v. i.</pos>, 3.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Drag sail</b></col> <fld>(Naut.)</fld>, <cd>a sail or
canvas rigged on a stout frame, to be dragged by a vessel through the
water in order to keep her head to the wind or to prevent drifting; --
called also <altname>drift sail</altname>, <altname>drag
sheet</altname>, <altname>drag anchor</altname>, <altname>sea
anchor</altname>, <altname>floating anchor</altname>, etc.</cd> --
<col><b>Drag twist</b></col> <fld>(Mining)</fld>, <cd>a spiral hook at
the end of a rod for cleaning drilled holes.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dragantine</ent><br/
<hw>Dra*gan"tine</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Dracanth</er>.]</ety> <def>A mucilage obtained from, or containing,
gum tragacanth.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dragbar</ent><br/
<hw>Drag"bar`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Drawbar</er> <sd>(b)</sd>. Called also <altname>draglink</altname>,
and <altname>drawlink</altname>.</def> <mark>[U. S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dragbolt</ent><br/
<hw>Drag"bolt`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A coupling pin. See
under <er>Coupling</er>.</def> <mark>[U. S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>dragee</ent><br/
<hw>dragee</hw> <pos>n.</pos> <sn>1.</sn> <def>sugar-coated
medication.</def><br/
<syn><b>Syn. --</b> drag<eacute/es.</syn>
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>silver-coated candy bead for decorating
cakes.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>3.</sn> <def>sugar-coated nut or fruit piece.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dragees</ent><br/
\'d8<hw>Dra`g<eacute/es"</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[F.
See 3d <er>Dredge</er>.]</ety> <fld>(Pharmacy)</fld> <def>Sugar-coated
medicines.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>dragging</ent><br/
<hw>dragging</hw> <pos>adj.</pos> <def>painfully or tediously slow and
boring; <as>as, the <ex>dragging</ex> minutes</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Draggle</ent><br/
<hw>Drag"gle</hw> <pr>(dr<acr/g"g'l)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Draggled</conjf>
<pr>(dr<acr/g"g'ld)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Draggling</conjf> <pr>(dr<acr/g"gl<icr/ng)</pr>.]</vmorph>
<ety>[Freq. of <ets>drag</ets>. <root/73. Cf. <er>Drawl</er>.]</ety>
<def>To wet and soil by dragging on the ground, mud, or wet grass; to
drabble; to trail.</def> <rj><au>Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>With <qex>draggled</qex> nets down-hanging to the tide.</q>
<rj><qau>Trench.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Draggle</ent><br/
<hw>Drag"gle</hw>, <pos>v. i.</pos> <def>To be dragged on the ground; to
become wet or dirty by being dragged or trailed in the mud or wet
grass.</def> <rj><au>Hudibras.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>draggled</ent><br/
<hw>draggled</hw> <pos>adj.</pos> <def>limp and soiled as if dragged in
the mud.</def><br/
<syn><b>Syn. --</b> bedraggled.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Draggle-tail</ent><br/
<hw>Drag"gle-tail`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A slattern who
suffers her gown to trail in the mire; a drabble-tail.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Draggle-tailed</ent><br/
<hw>Drag"gle-tailed`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Untidy;
sluttish; slatternly.</def> <rj><au>W. Irving.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drag rope</ent><br/
<ent>Drag line</ent><br/
<mhw>{ <hw>Drag line</hw> <it>or</it> <hw>Drag rope</hw> }</mhw>.
<fld>(A<eum/ronautics)</fld> <def>A guide rope.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Draglink</ent><br/
<hw>Drag"link`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Mach.)</fld>
<sd>(a)</sd> <def>A link connecting the cranks of two shafts.</def>
<sd>(b)</sd> <def>A drawbar.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dragman</ent><br/
<hw>Drag"man</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Dragmen</plw> <pr>(<?/)</pr>.</plu> <def>A fisherman who uses a
dragnet.</def> <rj><au>Sir M. Hale.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dragnet</ent><br/
<hw>Drag"net`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. AS.
<ets>dr<ae/gnet</ets>.]</ety> <def>A net to be drawn along the bottom of
a body of water, as in fishing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dragoman</ent><br/
<hw>Drag"o*man</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Dragomans</plw> <pr>(#)</pr>.</plu> <ety>[From F.
<ets>dragoman</ets>, or Sp. <ets>dragoman</ets>, or It.
<ets>dragomanno</ets>; all fr. LGr. <?/, Ar. <ets>tarjum<amac/n</ets>,
from the same source as E. <ets>targum</ets>. Cf. <er>Drogman</er>,
<er>Truchman</er>.]</ety> <def>An interpreter; -- so called in the
Levant and other parts of the East.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>dragon</ent><br/
<hw>drag"on</hw> <pr>(dr<acr/g"<ucr/n)</pr>, <pos>n.</pos> <ety>[F.
<ets>dragon</ets>, L. <ets>draco</ets>, fr. Gr. <grk>dra`kwn</grk>,
prob. fr. <grk>de`rkesqai</grk>, <grk>dra`kein</grk>, to look (akin to
Skr. <ets>dar<cced/</ets> to see), and so called from its terrible eyes.
Cf. <er>Drake</er> a dragon, <er>Dragoon</er>.]</ety> <sn>1.</sn>
<fld>(Myth.)</fld> <def>A fabulous animal, generally represented as a
monstrous winged serpent or lizard, with a crested head and enormous
claws, and regarded as very powerful and ferocious.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>dragons</qex> which appear in early paintings and
sculptures are invariably representations of a winged crocodile.</q>
<rj><qau>Fairholt.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In Scripture the term <xex>dragon</xex> refers to any
great monster, whether of the land or sea, usually to some kind of
serpent or reptile, sometimes to land serpents of a powerful and deadly
kind. It is also applied metaphorically to Satan.</note><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou breakest the heads of the <qex>dragons</qex> in the
waters.</q> <rj><qau> Ps. lxxiv. 13.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Thou shalt tread upon the lion and adder; the young lion and the
<qex>dragon</qex> shalt thou trample under feet.</q> <rj><qau> Ps. xci.
13.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He laid hold on the <qex>dragon</qex>, that old serpent, which is
the Devil and Satan, and bound him a thousand years.</q> <rj><qau>Rev.
xx. 2.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A fierce, violent person, esp. a woman.</def>
<rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Astron.)</fld> <def>A constellation of the northern
hemisphere figured as a dragon; Draco.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A luminous exhalation from marshy grounds, seeming
to move through the air as a winged serpent.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Mil. Antiq.)</fld> <def>A short musket hooked to a
swivel attached to a soldier's belt; -- so called from a representation
of a dragon's head at the muzzle.</def> <rj><au>Fairholt.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Zool.)</fld> <def>A small arboreal lizard of the
genus Draco, of several species, found in the East Indies and Southern
Asia. Five or six of the hind ribs, on each side, are prolonged and
covered with weblike skin, forming a sort of wing. These prolongations
aid them in making long leaps from tree to tree. Called also
<altname>flying lizard</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Zool.)</fld> <def>A variety of carrier
pigeon.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <fld>(Her.)</fld> <def>A fabulous winged creature,
sometimes borne as a charge in a coat of arms.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Dragon</xex> is often used adjectively, or in
combination, in the sense of <xex>relating to</xex>,
<xex>resembling</xex>, or <xex>characteristic of</xex>, <xex>a
dragon</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dragon arum</b></col> <fld>(Bot.)</fld>, <cd>the name of
several species of <gen>Aris<ae/ma</gen>, a genus of plants having a
spathe and spadix. See <cref>Dragon root</cref>(below).</cd> --
<col><b>Dragon fish</b></col> <fld>(Zool.)</fld>, <cd>the dragonet.</cd>
-- <col><b>Dragon fly</b></col> <fld>(Zool.)</fld>, <cd>any insect of
the family <fam>Libellulid<ae/</fam>. They have finely formed, large and
strongly reticulated wings, a large head with enormous eyes, and a long
body; -- called also <altname>mosquito hawks</altname>. Their larv<ae/
are aquatic and insectivorous.</cd> -- <col><b>Dragon root</b></col>
<fld>(Bot.)</fld>, <cd>an American aroid plant (<spn>Aris<ae/ma
Dracontium</spn>); green dragon.</cd> -- <col><b>Dragon's
blood</b></col>, <cd>a resinous substance obtained from the fruit of
several species of <gen>Calamus</gen>, esp. from <spn>Calamus
Rotang</spn> and <spn>Calamus Draco</spn>, growing in the East Indies. A
substance known as <xex>dragon's blood</xex> is obtained by exudation
from <spn>Drac<ae/na Draco</spn>; also from <spn>Pterocarpus
Draco</spn>, a tree of the West Indies and South America. The color is
red, or a dark brownish red, and it is used chiefly for coloring
varnishes, marbles, etc. Called also <altname>Cinnabar
Gr<ae/corum</altname>.</cd> -- <col><b>Dragon's head</b></col>.
<sd>(a)</sd> <fld>(Bot.)</fld> <cd>A plant of several species of the
genus <gen>Dracocephalum</gen>. They are perennial herbs closely allied
to the common catnip.</cd> <sd>(b)</sd> <fld>(Astron.)</fld> <cd>The
ascending node of a planet, indicated, chiefly in almanacs, by the
symbol <?/. The deviation from the ecliptic made by a planet in passing
from one node to the other seems, according to the fancy of some, to
make a figure like that of a dragon, whose belly is where there is the
greatest latitude; the intersections representing the head and tail; --
from which resemblance the denomination arises.</cd> <au>Encyc.
Brit.</au> -- <col><b>Dragon shell</b></col> <fld>(Zool.)</fld>, <cd>a
species of limpet.</cd> -- <col><b>Dragon's skin</b></col>, <cd>fossil
stems whose leaf scars somewhat resemble the scales of reptiles; -- a
name used by miners and quarrymen.</cd> <au>Stormonth.</au> --
<col><b>Dragon's tail</b></col> <fld>(Astron.)</fld>, <cd>the descending
node of a planet, indicated by the symbol <?/. See <cref>Dragon's
head</cref> (above).</cd> -- <col><b>Dragon's wort</b></col>
<fld>(Bot.)</fld>, <cd>a plant of the genus <gen>Artemisia</gen>
(<spn>Artemisia dracunculus</spn>).</cd> -- <col><b>Dragon
tree</b></col> <fld>(Bot.)</fld>, <cd>a West African liliaceous tree
(<spn>Drac<ae/na Draco</spn>), yielding one of the resins called
dragon's blood. See <er>Drac<ae/na</er>.</cd> -- <col><b>Dragon
water</b></col>, <cd>a medicinal remedy very popular in the earlier half
of the 17th century.</cd> <ldquo/<xex>Dragon water</xex> may do good
upon him.<rdquo/ <au>Randolph (1640).</au> -- <col><b>Flying
dragon</b></col>, <cd>a large meteoric fireball; a bolide.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dragonet</ent><br/
<hw>Drag"on*et</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A
little dragon.</def> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>A small British marine fish
(<gen>Callionymuslyra</gen>); -- called also <altname>yellow
sculpin</altname>, <altname>fox</altname>, and
<altname>gowdie</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dragonish</ent><br/
<hw>Drag"on*ish</hw>, <pos>a.</pos> <def>resembling a dragon.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dragonlike</ent><br/
<hw>Drag"on*like`</hw> <pr>(-l<imac/k`)</pr>, <pos>a.</pos> <def>Like a
dragon.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 451 pr=GH --></p>

<p><ent>Dragonnade</ent><br/
<hw>Drag`on*nade"</hw> <pr>(dr<acr/g`<ocr/n*n<amac/d")</pr>,
<pos>n.</pos> <ety>[F., fr. <ets>dragon</ets> dragoon, because Louis
XIV., in persecuting the Protestants of his kingdom, quartered dragoons
upon them.]</ety> <def>The severe persecution of French Protestants
under Louis XIV., by an armed force, usually of dragoons; hence, a rapid
and devastating incursion; dragoonade.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He learnt it as he watched the <qex>dragonnades</qex>, the
tortures, the massacres of the Netherlands.</q> <rj><qau>C.
Kingsley.</qau></rj></p>

<p><ent>Dragon's tail</ent><br/
<ent>Dragon's head</ent><br/
<ent>Dragon's blood</ent><br/
<mhw>{ <hw>Drag"on's blood</hw>, <hw>Drag"on's head</hw>, <hw>Drag"on's
tail</hw> }</mhw>. <def>See <cref>Dragon's blood</cref>, <cref>Dragon's
head</cref>, etc., under <er>Dragon</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dragoon</ent><br/
<hw>Dra*goon"</hw> <pr>(dr<adot/*g<oomac/n")</pr>, <pos>n.</pos>
<ety>[F. <ets>dragon</ets> dragon, dragoon, fr. L. <ets>draco</ets>
dragon, also, a cohort's standard (with a dragon on it). The name was
given from the sense <ets>standard</ets>. See <er>Dragon</er>.]</ety>
<sn>1.</sn> <fld>((Mil.)</fld> <def>Formerly, a soldier who was taught
and armed to serve either on horseback or on foot; now, a mounted
soldier; a cavalry man.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A variety of pigeon.</def>
<rj><au>Clarke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dragoon bird</b></col> <fld>(Zool.)</fld>, <cd>the
umbrella bird.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dragoon</ent><br/
<hw>Dra*goon"</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Dragooned</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Dragooning</conjf>.]</vmorph> <sn>1.</sn> <def>To harass or
reduce to subjection by dragoons; to persecute by abandoning a place to
the rage of soldiers.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To compel submission by violent measures; to harass;
to persecute.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The colonies may be influenced to anything, but they can be
<qex>dragooned</qex> to nothing.</q> <rj><qau>Price.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Lewis the Fourteenth is justly censured for trying to
<qex>dragoon</qex> his subjects to heaven.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dragoonade</ent><br/
<hw>Drag`oon*ade"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Dragonnade</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dragooner</ent><br/
<hw>Dra*goon"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A dragoon.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drail</ent><br/
<hw>Drail</hw> <pr>(dr<amac/l)</pr>, <pos>v. t. & i.</pos>
<ety>[<root/73.]</ety> <def>To trail; to draggle.</def>
<mark>[Obs.]</mark> <rj><au>South.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drain</ent><br/
<hw>Drain</hw> <pr>(dr<amac/n)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Drained</conjf> <pr>(dr<amac/nd)</pr>; <pos>p. pr.
& vb. n.</pos> <conjf>Draining</conjf>.]</vmorph> <ety>[AS.
<ets>drehnigean</ets> to drain, strain; perh. akin to E.
<ets>draw</ets>.]</ety> <sn>1.</sn> <def>To draw off by degrees; to
cause to flow gradually out or off; hence, to cause the exhaustion
of.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Fountains <qex>drain</qex> the water from the ground adjacent.</q>
<rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>But it was not alone that the he <qex>drained</qex> their treasure
and hampered their industry.</q> <rj><qau>Motley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To exhaust of liquid contents by drawing them off;
to make gradually dry or empty; to remove surface water, as from
streets, by gutters, etc.; to deprive of moisture; hence, to exhaust; to
empty of wealth, resources, or the like; <as>as, to <ex>drain</ex> a
country of its specie</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Sinking waters, the firm land to <qex>drain</qex>,<br/
Filled the capacious deep and formed the main.</q>
<rj><qau>Roscommon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To filter.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Salt water, <qex>drained</qex> through twenty vessels of earth,
hath become fresh.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drain</ent><br/
<hw>Drain</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To flow gradually;
<as>as, the water of low ground <ex>drains</ex> off</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To become emptied of liquor by flowing or dropping;
<as>as, let the vessel stand and <ex>drain</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drain</ent><br/
<hw>Drain</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act of draining, or
of drawing off; gradual and continuous outflow or withdrawal; <as>as,
the <ex>drain</ex> of specie from a country; the project is a
<ex>drain</ex> on resources</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That means of which anything is drained; a channel;
a trench; a water course; a sewer; a sink.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <pluf>pl.</pluf> <def>The grain from the mashing tub;
<as>as, brewers' <ex>drains</ex></as>.</def> <mark>[Eng.]</mark>
<rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Box drain</b></col>, <col><b>Counter
drain</b></col></mcol>. <cd>See under <er>Box</er>,
<er>Counter</er>.</cd> -- <col><b>Right of drain</b></col>
<fld>(Law)</fld>, <cd>an easement or servitude by which one man has a
right to convey water in pipes through or over the estate of
another.</cd> <rj><au>Kent.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drainable</ent><br/
<hw>Drain"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of being
drained.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drainage</ent><br/
<hw>Drain"age</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A
draining; a gradual flowing off of any liquid; also, that which flows
out of a drain.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The mode in which the waters of a country pass off
by its streams and rivers.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Engin.)</fld> <def>The system of drains and their
operation, by which superfluous water is removed from towns, railway
beds, mines, and other works.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Area or district drained; <as>as, the
<ex>drainage</ex> of the Po, the Thames, etc.</as></def>
<rj><au>Latham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Surg.)</fld> <def>The act, process, or means of
drawing off the pus or fluids from a wound, abscess, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Drainage tube</b></col> <fld>(Surg.)</fld>, <cd>a tube
introduced into a wound, etc., to draw off the discharges.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>drainboard</ent><br/
<hw>drain"board`</hw> <pos>n.</pos> <def>a board beside a kitchen sink
having a surface inclined so as to drain into the sink.</def><br/
<syn><b>Syn. --</b> draining board.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Draine</ent><br/
\'d8<hw>Draine</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<fld>(Zool.)</fld> <def>The missel thrush.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>drained</ent><br/
<hw>drained</hw> <pos>adj.</pos> <def>having lost much energy or emotion
from vigorous activity; -- of people; <as>as, the day's events left her
completely <ex>drained</ex> of strength</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>having resources completely depleted.</def><br/
<syn><b>Syn. --</b> depleted.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>3.</sn> <def>having no power remaining; -- of a
battery.</def><br/
<syn><b>Syn. --</b> run-down.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><cs><col><b>to go down the drain</b></col> <sn>1.</sn> <cd>to be
consumed in profitless activity; to be wasted; to become worthless.</cd>
<sn>2.</sn> <cd>to vanish or cease existing.</cd></cs><br/
[<source>PJC</source>]</p>

<p><ent>Drainer</ent><br/
<hw>Drain"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, drains.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Draining</ent><br/
<hw>Drain"ing</hw>, <pos>vb. n.</pos> <ety>of <er>Drain</er>, <pos>v.
t.</pos></ety> <fld>(Agric.)</fld> <def>The art of carrying off surplus
water, as from land.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Draining tile</b></col>. <cd>Same as
<er>Draintile</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drainpipe</ent><br/
<hw>Drain"pipe`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A pipe used for
carrying off surplus water.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Draintile</ent><br/
<hw>Drain"tile`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A hollow tile used
in making drains; -- called also <altname>draining
tile</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Draintrap</ent><br/
<hw>Drain"trap`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See 4th
<er>Trap</er>, 5.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drake</ent><br/
<hw>Drake</hw> <pr>(dr<amac/k)</pr>, <pos>n.</pos> <ety>[Akin to LG.
<ets>drake</ets>, OHG. <ets>antrache</ets>, <ets>anetrecho</ets>, G.
<ets>enterich</ets>, Icel. <ets>andriki</ets>, Dan. <ets>andrik</ets>,
OSw. <ets>andrak</ets>, <ets>andrage</ets>, masc., and fr. AS.
<ets>ened</ets>, fem., duck; akin to D. <ets>eend</ets>, G.
<ets>ente</ets>, Icel. <ets><oum/nd</ets>, Dan. <ets>and</ets>, Sw.
<ets>and</ets>, Lith. <ets>antis</ets>, L. <ets>anas</ets>, Gr. <?/ (for
<?/), and perh. Skr. <ets><amac/ti</ets> a water fowl. <root/207. In
English the first part of the word was lost. The ending is akin to E.
<ets>rich</ets>. Cf. <er>Gulaund</er>.]</ety> <sn>1.</sn> <def>The male
of the duck kind.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <ety>[Cf. <ets>Dragon fly</ets>, under
<er>Dragon</er>.]</ety> <def>The drake fly.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>drake</qex> will mount steeple height into the air.</q>
<rj><qau>Walton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Drake fly</b></col>, <cd>a kind of fly, sometimes used in
angling.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><q>The dark <qex>drake fly</qex>, good in August.</q>
<rj><qau>Walton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drake</ent><br/
<hw>Drake</hw>, <pos>n.</pos> <ety>[AS. <ets>draca</ets> dragon, L.
<ets>draco</ets>. See <er>Dragon</er>.]</ety> <sn>1.</sn> <def>A
dragon.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Beowulf resolves to kill the <qex>drake</qex>.</q> <rj><qau>J. A.
Harrison (Beowulf).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A small piece of artillery.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Two or three shots, made at them by a couple of <qex>drakes</qex>,
made them stagger.</q> <rj><qau>Clarendon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drake</ent><br/
<hw>Drake</hw>, <pos>n.</pos> <ety>[Cf. F. <ets>dravik</ets>, W.
<ets>drewg</ets>, darnel, cockle, etc.]</ety> <def>Wild oats, brome
grass, or darnel grass; -- called also <altname>drawk</altname>,
<altname>dravick</altname>, and <altname>drank</altname>.</def>
<mark>[Prov. Eng.]</mark> <rj><au>Dr. Prior.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drakestone</ent><br/
<hw>Drake"stone</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A flat stone so
thrown along the surface of water as to skip from point to point before
it sinks; also, the sport of so throwing stones; -- sometimes called
<altname>ducks and drakes</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Internal earthquakes, that, not content with one throe, run along
spasmodically, like boys playing at what is called
<qex>drakestone</qex>.</q> <rj><qau>De Quincey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dram</ent><br/
<hw>Dram</hw> <pr>(dr<acr/m)</pr>, <pos>n.</pos> <ety>[OF.
<ets>drame</ets>, F. <ets>drachme</ets>, L. <ets>drachma</ets>, drachm,
drachma, fr. Gr. <grk>drachmh`</grk>, prop., a handful, fr.
<grk>dra`ssesqai</grk> to grasp. Cf. <er>Drachm</er>,
<er>Drachma</er>.]</ety> <sn>1.</sn> <def>A weight; in
<xex>Apothecaries' weight</xex>, one eighth part of an ounce, or sixty
grains; in <xex>Avoirdupois weight</xex>, one sixteenth part of an
ounce, or 27.34375 grains.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A minute quantity; a mite.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Were I the chooser, a <qex>dram</qex> of well-doing should be
preferred before many times as mush the forcible hindrance of
evildoing.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>As much spirituous liquor as is usually drunk at
once; <as>as, a <ex>dram</ex> of brandy</as>; hence, a potation or
potion; <as>as, a <ex>dram</ex> of poison</as>.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Numis.)</fld> <def>A Persian daric.</def>
<rj><au>Ezra ii. 69.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Fluid dram</b></col>, <it>or</it> <col><b>Fluid
drachm</b></col></mcol>. <cd>See under <er>Fluid</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dram</ent><br/
<hw>Dram</hw>, <pos>v. i. & t.</pos> <def>To drink drams; to ply with
drams.</def> <mark>[Low]</mark> <rj><au>Johnson.</au>
<au>Thackeray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>D-RAM</ent><br/
<ent>DRAM</ent><br/
<mhw><hw>DRAM</hw>, <hw>D-RAM</hw></mhw> <pos>n.</pos>
<fld>(Computers)</fld> <def>same as <er>dynamic RAM</er>.</def>
<mark>[acron.]</mark> <br/
<syn><b>Syn. --</b> dynamic RAM.</syn><br/
[<source>PJC</source>]</p>

<p><ent>Drama</ent><br/
<hw>Dra"ma</hw> <pr>(dr<aum/"m<adot/ <it>or</it> dr<amac/"m<adot/;
277)</pr>, <pos>n.</pos> <ety>[L. <ets>drama</ets>, Gr.
<grk>dra^ma</grk>, fr. <grk>dra^n</grk> to do, act; cf. Lith.
<ets>daryti</ets>.]</ety> <sn>1.</sn> <def>A composition, in prose or
poetry, accommodated to action, and intended to exhibit a picture of
human life, or to depict a series of grave or humorous actions of more
than ordinary interest, tending toward some striking result. It is
commonly designed to be spoken and represented by actors on the
stage.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A divine pastoral <qex>drama</qex> in the Song of Solomon.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A series of real events invested with a dramatic
unity and interest.</def> <ldquo/The <xex>drama</xex> of war.<rdquo/
<rj><au>Thackeray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Westward the course of empire takes its way;<br/
The four first acts already past,<br/
A fifth shall close the <qex>drama</qex> with the day;<br/
Time's noblest offspring is the last.</q>
<rj><qau>Berkeley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>drama</qex> and contrivances of God's providence.</q>
<rj><qau>Sharp.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Dramatic composition and the literature pertaining
to or illustrating it; dramatic literature.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The principal species of the drama are
<stype>tragedy</stype> and <stype>comedy</stype>; inferior species are
<stype>tragi-comedy</stype>, <stype>melodrama</stype>,
<stype>operas</stype>, <stype>burlettas</stype>, and
<stype>farces</stype>.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>The romantic drama</b></col>, <cd>the kind of drama whose
aim is to present a tale or history in scenes, and whose plays (like
those of Shakespeare, Marlowe, and others) are stories told in dialogue
by actors on the stage.</cd> <rj><au>J. A. Symonds.</au></rj></cs></p>

<p><ent>Dramatical</ent><br/
<ent>Dramatic</ent><br/
<mhw>{ <hw>Dra*mat"ic</hw> <pr>(dr<adot/*m<acr/t"<icr/k)</pr>,
<hw>Dra*mat"ic*al</hw> <pr>(dr<adot/*m<acr/t"<icr/*k<ait/l)</pr>,
}</mhw> <pos>a.</pos> <ety>[Gr. <grk>dramatiko`s</grk>, fr.
<grk>dra^ma</grk>: cf. F. <ets>dramatique</ets>.]</ety> <def>Of or
pertaining to the drama; <as>as, <ex>dramatic</ex> arts</as>.</def>
<wns>[wns=3]</wns><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>suitable to or characteristic of or having the
qualities of, a drama; theatrical; <as>as, a <ex>dramatic</ex> entrance
in a swirling cape; a <ex>dramatic</ex> rescue at sea</as>. Opposite of
<ant>undramatic</ant>.</def> <wns>[wns=1]</wns> [Narrower terms:
<stype>melodramatic</stype>; <stype>awe-inspiring,
spectacular</stype>]<br/
[<source>WordNet 1.5</source>]</p>

<p><q>The emperor . . . performed his part with much <qex>dramatic</qex>
effect.</q> <rj><qau>Motley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>striking in appearance or effect; vivid; having a
thrilling effect; <as>as, a <ex>dramatic</ex> sunset; a
<ex>dramatic</ex> pause</as>.</def> <wns>[wns=2]</wns><br/
<syn><b>Syn. --</b> spectacular, striking.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>4.</sn> <fld>(Music)</fld> <def>marked by power and
expressiveness and a histrionic or theatrical style; -- of a singer or
singing voice; <as>as, a <ex>dramatic</ex> tenor; a dramatic
soprano</as>. Contrasted to <ant>lyric</ant>.</def>
<wns>[wns=4]</wns><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dramatically</ent><br/
<hw>Dra*mat"ic*al*ly</hw>, <pos>adv.</pos> <def>In a dramatic manner;
theatrically; vividly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>dramatisation</ent><br/
<hw>dramatisation</hw> <pos>n.</pos> <def>same as
<er>dramatization</er>.</def><br/
<syn><b>Syn. --</b> dramatization.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dramatis personae</ent><br/
\'d8<hw>Dram"a*tis per*so"n<ae/</hw> <pr>(?)</pr>. <ety>[L.]</ety>
<def>The actors in a drama or play.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dramatist</ent><br/
<hw>Dram"a*tist</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>dramatiste</ets>.]</ety> <def>The author of a dramatic composition;
a writer of plays.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dramatizable</ent><br/
<hw>Dram"a*ti`za*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of
being dramatized.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>dramatization</ent><br/
<hw>dram`a*ti*za"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Act of
dramatizing; a dramatic representation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dramatize</ent><br/
<hw>Dram"a*tize</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Dramatized</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Dramatizing</conjf> <pr>(?)</pr>.]</vmorph> <ety>[Cf. F.
<ets>dramatiser</ets>.]</ety> <def>To compose in the form of the drama;
to represent in a drama; to adapt to dramatic representation; <as>as, to
<ex>dramatize</ex> a novel, or an historical episode</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They <qex>dramatized</qex> tyranny for public execration.</q>
<rj><qau>Motley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dramaturgic</ent><br/
<hw>Dram`a*tur"gic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Relating to
dramaturgy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dramaturgist</ent><br/
<hw>Dram"a*tur`gist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One versed in
dramaturgy.</def> <rj><au>Carlyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dramaturgy</ent><br/
<hw>Dram"a*tur`gy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/
dramatic composition; <?/ drama + a root akin to E. <ets>work</ets>: cf.
F. <ets>dramaturgie</ets>.]</ety> <def>The art of dramatic composition
and representation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dramming</ent><br/
<hw>Dram"ming</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The practice of
drinking drams.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dramseller</ent><br/
<hw>Dram"sell`er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who sells
distilled liquors by the dram or glass.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dramshop</ent><br/
<hw>Dram"shop`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A shop or barroom
where spirits are sold by the dram.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drank</ent><br/
<hw>Drank</hw> <pr>(?)</pr>, <pos>imp.</pos> <def>of
<er>Drink</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drank</ent><br/
<hw>Drank</hw>, <pos>n.</pos> <ety>[Cf. 3d <er>Drake</er>.]</ety>
<def>Wild oats, or darnel grass. See <er>Drake</er> a plant.</def>
<mark>[Prov. Eng.]</mark> <rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drap d'ete</ent><br/
\'d8<hw>Drap` d'<eacute/*t<eacute/"</hw> <pr>(?)</pr>. <ety>[F., clot of
summer.]</ety> <def>A thin woolen fabric, twilled like merino.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drape</ent><br/
<hw>Drape</hw> <pr>(dr<amac/p)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Draped</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Draping</conjf> <pr>(?)</pr>.]</vmorph> <ety>[F.
<ets>draper</ets>, fr. <ets>drap</ets> cloth. See 3d
<er>Drab</er>.]</ety> <sn>1.</sn> <def>To cover or adorn with drapery or
folds of cloth, or as with drapery; <as>as, to <ex>drape</ex> a bust, a
building, etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>The whole people were <qex>draped</qex> professionally.</q>
<rj><qau>De Quincey.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>These starry blossoms, [of the snow] pure and white,<br/
Soft falling, falling, through the night,<br/
Have <qex>draped</qex> the woods and mere</q>.
<rj><qau>Bungay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To rail at; to banter.</def> <mark>[Obs.]</mark>
<rj><au>Sir W. Temple.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drape</ent><br/
<hw>Drape</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To make cloth.</def>
<mark>[Obs.]</mark> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To design drapery, arrange its folds, etc., as for
hangings, costumes, statues, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>draped</ent><br/
<hw>draped</hw> <pos>adj.</pos> <sn>1.</sn> <def>covered with or as if
with clothes or a wrap or cloak; <as>as, a beam <ex>draped</ex> with
cobwebs</as>. Contrasted with <ant>uncovered</ant>.</def><br/
<syn><b>Syn. --</b> cloaked, clothed, mantled, wrapped.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>curtained; -- of windows; <as>as,
velvet-<ex>draped</ex> windows</as>. Opposite of
<ant>curtainless</ant>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Draper</ent><br/
<hw>Dra"per</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>drapier</ets>.]</ety> <def>One who sells cloths; a dealer in
cloths; <as>as, a <ex>draper</ex> and tailor</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Draperied</ent><br/
<hw>Dra"per*ied</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Covered or
supplied with drapery.</def> <mark>[R.]</mark>
<rj><au>Byron.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drapery</ent><br/
<hw>Dra"per*y</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Draperies</plw> <pr>(#)</pr>.</plu> <ety>[F.
<ets>draperie</ets>.]</ety> <sn>1.</sn> <def>The occupation of a draper;
cloth-making, or dealing in cloth.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Cloth, or woolen stuffs in general.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>People who ought to be weighing out grocery or measuring out
<qex>drapery</qex>.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A textile fabric used for decorative purposes,
especially when hung loosely and in folds carefully disturbed; as:
<sd>(a)</sd> Garments or vestments of this character worn upon the body,
or shown in the representations of the human figure in art. <sd>(b)</sd>
Hangings of a room or hall, or about a bed.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Like one that wraps the <qex>drapery</qex> of his couch<br/
About him, and lies down to pleasant dreams.</q>
<rj><qau>Bryant.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>All the decent <qex>drapery</qex> of life is to be rudely torn
off.</q> <rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Casting of draperies</b></col>. <cd>See under
<er>Casting</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>casting of draperies</qex> . . . is one of the most
important of an artist's studies.</q> <rj><qau>Fairholt.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drapet</ent><br/
<hw>Dra"pet</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Dim. of
<ets>drap</ets>.]</ety> <def>Cloth.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drastic</ent><br/
<hw>Dras"tic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/, fr. <?/ to
do, act: cf. F. <ets>drastique</ets>. See <er>Drama</er>.]</ety>
<fld>(Med.)</fld> <def>Acting rapidly and violently; efficacious;
powerful; -- opposed to <contr>bland</contr>; <as>as, <ex>drastic</ex>
purgatives</as>.</def> -- <def2><pos>n.</pos> <fld>(Med.)</fld> <def>A
violent purgative. See <er>Cathartic</er>.</def></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drasty</ent><br/
<hw>Dras"ty</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[AS.
<ets>d<ae/rstan</ets>, <ets>dresten</ets>, dregs.]</ety> <def>Filthy;
worthless.</def> <mark>[Obs.]</mark> <ldquo/<xex>Drasty</xex>
ryming.<rdquo/ <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Draugh</ent><br/
<hw>Draugh</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Draft</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Draught</ent><br/
<hw>Draught</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[The same as
<ets>draft</ets>, the spelling with <ets>gh</ets> indicating an older
pronunciation. See <er>Draft</er>, <pos>n.</pos>, <er>Draw</er>.]</ety>
<sn>1.</sn> <def>The act of drawing or pulling</def>; as: <sd>(a)</sd>
<def>The act of moving loads by drawing, as by beasts of burden, and the
like.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A general custom of using oxen for all sort of <qex>draught</qex>
would be, perhaps, the greatest improvement.</q> <rj><qau>Sir W.
Temple.</qau></rj></p>

<p><sd>(b)</sd> <def>The drawing of a bowstring.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>She sent an arrow forth with mighty <qex>draught</qex>.</q>
<rj><qau>Spenser.</qau></rj></p>

<p><sd>(c)</sd> <def>Act of drawing a net; a sweeping the water for
fish.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Upon the <qex>draught</qex> of a pond, not one fish was left.</q>
<rj><qau>Sir M. Hale.</qau></rj></p>

<p><sd>(d)</sd> <def>The act of drawing liquor into the mouth and
throat; the act of drinking.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In his hands he took the goblet, but a while the
<qex>draught</qex> forbore.</q> <rj><qau>Trench.</qau></rj></p>

<p><sd>(e)</sd> <def>A sudden attack or drawing upon an enemy.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>By drawing sudden <qex>draughts</qex> upon the enemy when he
looketh not for you.</q> <rj><qau>Spenser.</qau></rj></p>

<p><sd>(f)</sd> <fld>(Mil.)</fld> <def>The act of selecting or detaching
soldiers; a draft (see <er>Draft</er>, <pos>n.</pos>, 2)</def>
<sd>(g)</sd> <def>The act of drawing up, marking out, or delineating;
representation.</def> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is drawn</def>; as: <sd>(a)</sd>
<def>That which is taken by sweeping with a net.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Launch out into the deep, and let down your nets for a
<qex>draught</qex>.</q> <rj><qau>Luke v. 4.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He laid down his pipe, and cast his net, which brought him a very
great <qex>draught</qex>.</q> <rj><qau>L'Estrange.</qau></rj></p>

<p><sd>(b)</sd> <fld>(Mil.)</fld> <def>The force drawn; a detachment; --
in this sense usually written <xex>draft</xex>.</def> <sd>(c)</sd>
<def>The quantity drawn in at once in drinking; a potion or
potation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Disguise thyself as thou wilt, still, Slavery, . . . still thou
art a bitter <qex>draught</qex>.</q> <rj><qau>Sterne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Low lies that house where nut-brown <qex>draughts</qex>
inspired.</q> <rj><qau>Goldsmith.</qau></rj></p>

<p><sd>(d)</sd> <def>A sketch, outline, or representation, whether
written, designed, or drawn; a delineation.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>draught</qex> of a Toleration Act was offered to the
Parliament by a private member.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>No picture or <qex>draught</qex> of these things from the report
of the eye.</q> <rj><qau>South.</qau></rj></p>

<p><sd>(e)</sd> <fld>(Com.)</fld> <def>An order for the payment of
money; -- in this sense almost always written <xex>draft</xex>.</def>
<sd>(f)</sd> <def>A current of air moving through an inclosed place, as
through a room or up a chimney.</def> <rj><au>Thackeray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He preferred to go and sit upon the stairs, in . . . a strong
<qex>draught</qex> of air, until he was again sent for.</q>
<rj><qau>Dickens.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which draws</def>; as: <sd>(a)</sd> <def>A team
of oxen or horses.</def> <au>Blackstone.</au> <sd>(b)</sd> <def>A sink
or drain; a privy.</def> <au>Shak.</au> <au>Matt. xv. 17.</au>
<sd>(c)</sd> <pluf>pl.</pluf> <fld>(Med.)</fld> <def>A mild vesicatory;
a sinapism; <as>as, to apply <ex>draughts</ex> to the
feet</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Capacity of being drawn; force necessary to draw;
traction.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The Hertfordshire wheel plow . . . is of the easiest
<qex>draught</qex>.</q> <rj><qau>Mortimer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Naut.)</fld> <def>The depth of water necessary to
float a ship, or the depth a ship sinks in water, especially when laden;
<as>as, a ship of twelve feet <ex>draught</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Com.)</fld> <def>An allowance on weighable goods.
<mark>[Eng.]</mark> See <er>Draft</er>, 4.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>A move, as at chess or checkers.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>The bevel given to the pattern for a casting, in
order that it may be drawn from the sand without injury to the
mold.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <fld>(Masonry)</fld> <def>See <er>Draft</er>,
<pos>n.</pos>, 7.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Angle of draught</b></col>, <cd>the angle made with the
plane over which a body is drawn by the line in which the pulling force
acts, when the latter has the direction best adapted to overcome the
obstacles of friction and the weight of the body.</cd> -- <col><b>Black
draught</b></col>. <cd>See under <er>Black</er>, <pos>a.</pos></cd> --
<mcol><col><b>Blast draught</b></col>, <it>or</it> <col><b>Forced
draught</b></col></mcol>, <cd>the draught produced by a blower, as by
blowing in air beneath a fire or drawing out the gases from above
it.</cd> -- <col><b>Natural draught</b></col>, <cd>the draught produced
by the atmosphere flowing, by its own weight, into a chimney wherein the
air is rarefied by heat.</cd> -- <col><b>On draught</b></col>, <cd>so as
to be drawn from the wood (as a cask, barrel, etc.) in distinction from
being bottled; as, ale <xex>on draught</xex>.</cd> -- <col><b>Sheer
draught</b></col>. <cd>See under <er>Sheer</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Draught</ent><br/
<hw>Draught</hw>, <pos>a.</pos> <sn>1.</sn> <def>Used for drawing
vehicles, loads, etc.; <as>as, a <ex>draught</ex> beast;
<ex>draught</ex> hooks.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Relating to, or characterized by, a draft, or
current of air.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Used in making drawings; <as>as, <ex>draught</ex>
compasses</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Drawn directly from the barrel, or other receptacle,
in distinction from <xex>bottled</xex>; on draught; -- said of ale,
cider, and the like.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ This word, especially in the first and second meanings,
is often written <xex>draft</xex>, a spelling which is approved by many
authorities.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Draught box</b></col>. <cd>See <cref>Draught tube</cref>,
below.</cd> -- <col><b>Draught engine</b></col> <fld>(Mining)</fld>,
<cd>an engine used for pumping, raising heavy weights, and the
like.</cd> -- <col><b>Draught hook</b></col> <fld>(Mil.)</fld>, <cd>one
of the hooks on a cannon carriage, used in drawing the gun backward and
forward.</cd> -- <col><b>Draught horse</b></col>, <cd>a horse employed
in drawing loads, plowing, etc., as distinguished from a saddle horse or
carriage horse.</cd> -- <col><b>Draught net</b></col>, <cd>a seine or
hauling net.</cd> -- <col><b>Draught ox</b></col>, <cd>an ox employed in
hauling loads, plowing, etc.</cd> -- <col><b>Draught tube</b></col>
<fld>(Water Wheels)</fld>, <cd>an air-tight pipe extending downward into
the tailrace from a turbine wheel located above it, to make the whole
fall available; -- called also <altname>draught
box</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 452 --></p>

<p><ent>Draught</ent><br/
<hw>Draught</hw> <pr>(dr<adot/ft)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Draughted</conjf>; <pos>p. pr. &
vb. n.</pos> <conjf>Draughting</conjf>.]</vmorph> <sn>1.</sn> <def>To
draw out; to call forth. See <er>Draft</er>.</def>
<rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To diminish or exhaust by drawing.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The Parliament so often <qex>draughted</qex> and drained.</q>
<rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To draw in outline; to make a draught, sketch, or
plan of, as in architectural and mechanical drawing.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Draughting room</b></col>, <cd>a room draughtsmen to work
in, and where plans are kept.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Draughtboard</ent><br/
<hw>Draught"board`</hw> <pr>(-b<omac/rd`)</pr>, <pos>n.</pos> <def>A
checkered board on which draughts are played. See
<er>Checkerboard</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Draughthouse</ent><br/
<hw>Draught"house`</hw> <pr>(-hous`)</pr>, <pos>n.</pos> <def>A house
for the reception of waste matter; a privy.</def> <mark>[Obs.]</mark>
<rj><au>2 Kings x. 27.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Draughts</ent><br/
<hw>Draughts</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <def>A mild
vesicatory. See <er>Draught</er>, <pos>n.</pos>, 3
<sd>(c)</sd>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Draughts</ent><br/
<hw>Draughts</hw>, <pos>n. pl.</pos> <def>A game, now more commonly
called <altname>checkers</altname>. See <er>Checkers</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <stype>Polish draughts</stype> is sometimes played with
40 pieces on a board divided into 100 squares.</note> <rj><au>Am.
Cyc.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Draughtsman</ent><br/
<hw>Draughts"man</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Draughtsmen</plw> <pr>(<?/)</pr>.</plu> <sn>1.</sn> <def>One who
draws pleadings or other writings.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who draws plans and sketches of machinery,
structures, and places; also, more generally, one who makes drawings of
any kind.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A <ldquo/man<rdquo/ or piece used in the game of
draughts.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>One who drinks drams; a tippler.</def>
<mark>[Obs.]</mark> <rj><au>Tatler.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Draughtsmanship</ent><br/
<hw>Draughts"man*ship</hw>, <pos>n.</pos> <def>The office, art, or work
of a draughtsman.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Draughty</ent><br/
<hw>Draught"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to a
draught, or current of air; <as>as, a <ex>draughtly</ex>, comfortless
room</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drave</ent><br/
<hw>Drave</hw> <pr>(?)</pr>, <def>old <pos>imp.</pos> of
<er>Drive</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dravida</ent><br/
<hw>Dra"vi*da</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[Skr.
<ets>Dr<amac/vi<dsdot/a</ets>, prob. meaning, Tamil.]</ety>
<fld>(Ethnol.)</fld> <def>A race of Hindustan, believed to be the
original people who occupied the land before the Hindu or Aryan
invasion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dravidian</ent><br/
<hw>Dra*vid"i*an</hw> <pr>(?)</pr>, <pos>prop. a.</pos> <ety>[From Skr.
<ets>Dr<amac/vi<dsdot/a</ets>, the name of the southern portion of the
peninsula of India.]</ety> <fld>(Ethnol.)</fld> <def>Of or pertaining to
the Dravida.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dravidian languages</b></col>, <cd>a group of languages
of Southern India, which seem to have been the idioms of the natives,
before the invasion of tribes speaking Sanskrit. Of these languages, the
Tamil is the most important; Telegu, Malayalam, and Kannada are
included. These languages are distinct from the Indo-European family of
languages.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dravidic</ent><br/
<hw>Dravidic</hw> <pos>prop. n.</pos> <def>one of the languages native
to southern India; a Dravidian language.</def><br/
<syn><b>Syn. --</b> Dravidian, Dravidian language.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>draw</ent><br/
<hw>draw</hw> <pr>(dr<add/)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp.</pos> <conjf>Drew</conjf> <pr>(dr<udd/)</pr>; <pos>p.
p.</pos> <conjf>Drawn</conjf> <pr>(dr<add/n)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Drawing</conjf>.]</vmorph> <ety>[OE.
<ets>dra<yogh/en</ets>, <ets>drahen</ets>, <ets>draien</ets>,
<ets>drawen</ets>, AS. <ets>dragan</ets>; akin to Icel. & Sw.
<ets>draga</ets>, Dan. <ets>drage</ets> to draw, carry, and prob. to OS.
<ets>dragan</ets> to bear, carry, D. <ets>dragen</ets>, G.
<ets>tragen</ets>, Goth. <ets>dragan</ets>; cf. Skr. <ets>dhraj</ets> to
move along, glide; and perh. akin to Skr. <ets>dhar</ets> to hold, bear.
<root/73. Cf. 2d <er>Drag</er>, <er>Dray</er> a cart, 1st
<er>Dredge</er>.]</ety> <sn>1.</sn> <def>To cause to move continuously
by force applied in advance of the thing moved; to pull along; to haul;
to drag; to cause to follow.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He cast him down to ground, and all along<br/
<qex>Drew</qex> him through dirt and mire without remorse.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He hastened to <qex>draw</qex> the stranger into a private
room.</q> <rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Do not rich men oppress you, and <qex>draw</qex> you before the
judgment seats?</q> <rj><qau>James ii. 6.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The arrow is now <qex>drawn</qex> to the head.</q>
<rj><qau>Atterbury.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To influence to move or tend toward one's self; to
exercise an attracting force upon; to call towards itself; to attract;
hence, to entice; to allure; to induce.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The poet<br/
Did feign that Orpheus <qex>drew</qex> trees, stones, and floods.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>All eyes you <qex>draw</qex>, and with the eyes the heart.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To cause to come out for one's use or benefit; to
extract; to educe; to bring forth; as: <sd>(a)</sd> To bring or take
out, or to let out, from some receptacle, as a stick or post from a
hole, water from a cask or well, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>drew</qex> out the staves of the ark.</q> <rj><qau>2
Chron. v. 9.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Draw</qex> thee waters for the siege.</q> <rj><qau>Nahum iii.
14.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I opened the tumor by the point of a lancet without
<qex>drawing</qex> one drop of blood.</q>
<rj><qau>Wiseman.</qau></rj></p>

<p><sd>(b)</sd> <def>To pull from a sheath, as a sword.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I will <qex>draw</qex> my sword, my hand shall destroy them.</q>
<rj><qau>Ex. xv. 9.</qau></rj></p>

<p><sd>(c)</sd> <def>To extract; to force out; to elicit; to
derive.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Spirits, by distillations, may be <qex>drawn</qex> out of
vegetable juices, which shall flame and fume of themselves.</q>
<rj><qau>Cheyne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Until you had <qex>drawn</qex> oaths from him.</q>
<rj><qau>Shak.</qau></rj></p>

<p><sd>(d)</sd> <def>To obtain from some cause or origin; to infer from
evidence or reasons; to deduce from premises; to derive.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We do not <qex>draw</qex> the moral lessons we might from
history.</q> <rj><qau>Burke.</qau></rj></p>

<p><sd>(e)</sd> <def>To take or procure from a place of deposit; to call
for and receive from a fund, or the like; as, to <xex>draw</xex> money
from a bank.</def> <sd>(f)</sd> <def>To take from a box or wheel, as a
lottery ticket; to receive from a lottery by the drawing out of the
numbers for prizes or blanks; hence, to obtain by good fortune; to win;
to gain; as, he <xex>drew</xex> a prize.</def> <sd>(g)</sd> <def>To
select by the drawing of lots.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Provided magistracies were filled by men freely chosen or
<qex>drawn</qex>.</q> <rj><qau>Freeman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To remove the contents of</def>; as: <sd>(a)</sd>
<def>To drain by emptying; to suck dry.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Sucking and <qex>drawing</qex> the breast dischargeth the milk as
fast as it can generated.</q> <rj><qau>Wiseman.</qau></rj></p>

<p><sd>(b)</sd> <def>To extract the bowels of; to eviscerate; <as>as, to
<ex>draw</ex> a fowl; to hang, <ex>draw</ex>, and quarter a
criminal</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In private <qex>draw</qex> your poultry, clean your tripe.</q>
<rj><qau>King.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To take into the lungs; to inhale; to inspire;
hence, also, to utter or produce by an inhalation; to heave.</def>
<ldquo/Where I first <xex>drew</xex> air.<rdquo/
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Drew</qex>, or seemed to <qex>draw</qex>, a dying groan.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To extend in length; to lengthen; to protract; to
stretch; to extend, as a mass of metal into wire.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>How long her face is <qex>drawn</qex>!</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And the huge Offa's dike which he <qex>drew</qex> from the mouth
of Wye to that of Dee.</q> <rj><qau>J. R. Green.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>To run, extend, or produce, as a line on any
surface; hence, also, to form by marking; to make by an instrument of
delineation; to produce, as a sketch, figure, or picture.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>To represent by lines drawn; to form a sketch or a
picture of; to represent by a picture; to delineate; hence, to represent
by words; to depict; to describe.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A flattering painter who made it his care<br/
To <qex>draw</qex> men as they ought to be, not as they are.</q>
<rj><qau>Goldsmith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Can I, untouched, the fair one's passions move,<br/
Or thou <qex>draw</qex> beauty and not feel its power?</q>
<rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>To write in due form; to prepare a draught of;
<as>as, to <ex>draw</ex> a memorial, a deed, or bill of
exchange.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Clerk, <qex>draw</qex> a deed of gift.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <def>To require (so great a depth, as of water) for
floating; -- said of a vessel; to sink so deep in (water); <as>as, a
ship <ex>draws</ex> ten feet of water</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>11.</sn> <def>To withdraw.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Go wash thy face, and <qex>draw</qex> the action.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>12.</sn> <def>To trace by scent; to track; -- a hunting
term.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>13.</sn> <fld>(Games)</fld> <sd>(a)</sd> <fld>(Cricket)</fld>
<def>To play (a short-length ball directed at the leg stump) with an
inclined bat so as to deflect the ball between the legs and the
wicket.</def> <sd>(b)</sd> <fld>(Golf)</fld> <def>To hit (the ball) with
the toe of the club so that it is deflected toward the left.</def>
<sd>(c)</sd> <fld>(Billiards)</fld> <def>To strike (the cue ball) below
the center so as to give it a backward rotation which causes it to take
a backward direction on striking another ball.</def> <sd>(d)</sd>
<fld>(Curling)</fld> <def>To throw up (the stone) gently.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>14.</sn> <def>To leave (a contest) undecided; <as>as, the battle
or game was <ex>drawn</ex></as>.</def> <ldquo/Win, lose, or
<xex>draw</xex>.<rdquo/<br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><note><hand/ <xex>Draw</xex>, in most of its uses, retains some shade
of its original sense, to pull, to move forward by the application of
force in advance, or to extend in length, and usually expresses an
action as gradual or continuous, and leisurely. We <xex>pour</xex>
liquid quickly, but we <xex>draw</xex> it in a continued stream. We
<xex>force</xex> compliance by threats, but we <xex>draw</xex> it by
gradual prevalence. We may <xex>write</xex> a letter with haste, but we
<xex>draw</xex> a bill with slow caution and regard to a precise form.
We <xex>draw</xex> a bar of metal by continued beating.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To draw a bow</b></col>, <cd>to bend the bow by drawing
the string for discharging the arrow.</cd> -- <col><b>To draw a
cover</b></col>, <cd>to clear a cover of the game it contains.</cd> --
<col><b>To draw a curtain</b></col>, <cd>to cause a curtain to slide or
move, either closing or unclosing.</cd> <ldquo/Night <xex>draws the
curtain</xex>, which the sun withdraws.<rdquo/ <au>Herbert.</au> --
<col><b>To draw a line</b></col>, <cd>to fix a limit or boundary.</cd>
-- <col><b>To draw back</b></col>, <cd>to receive back, as duties on
goods for exportation.</cd> -- <col><b>To draw breath</b></col>, <cd>to
breathe.</cd> <au>Shak.</au> -- <mcol><col><b>To draw cuts</b></col>
<it>or</it> <col><b>To draw lots</b></col></mcol>. <cd>See under
<er>Cut</er>, <pos>n.</pos></cd> -- <col><b>To draw in</b></col>.
<sd>(a)</sd> <cd>To bring or pull in; to collect.</cd> <sd>(b)</sd>
<cd>To entice; to inveigle.</cd> -- <col><b>To draw interest</b></col>,
<cd>to produce or gain interest.</cd> -- <col><b>To draw off</b></col>,
<cd>to withdraw; to abstract.</cd> <au>Addison.</au> -- <col><b>To draw
on</b></col>, <cd>to bring on; to occasion; to cause.</cd> <ldquo/War
which either his negligence <xex>drew on</xex>, or his practices
procured.<rdquo/ <au>Hayward.</au> -- <col><b>To draw (one)
out</b></col>, <cd>to elicit cunningly the thoughts and feelings of
another.</cd> -- <col><b>To draw out</b></col>, <cd>to stretch or
extend; to protract; to spread out.</cd> -- <ldquo/Wilt thou <xex>draw
out</xex> thine anger to all generations?<rdquo/ <au>Ps. lxxxv. 5.</au>
<ldquo/Linked sweetness long <xex>drawn out</xex>.<rdquo/
<au>Milton.</au> -- <col><b>To draw over</b></col>, <cd>to cause to come
over, to induce to leave one part or side for the opposite one.</cd> --
<col><b>To draw the longbow</b></col>, <cd>to exaggerate; to tell
preposterous tales.</cd> -- <mcol><col><b>To draw (one) to</b></col>
<it>or</it> <col><b>To draw (one) on to</b></col> (something)</mcol>,
<cd>to move, to incite, to induce.</cd> <ldquo/How many actions most
ridiculous hast thou been <xex>drawn to</xex> by thy fantasy?<rdquo/
<au>Shak.</au> -- <col><b>To draw up</b></col>. <sd>(a)</sd> <cd>To
compose in due form; to draught; to form in writing.</cd> <sd>(b)</sd>
<cd>To arrange in order, as a body of troops; to array.</cd>
<ldquo/<xex>Drawn up</xex> in battle to receive the charge.<rdquo/
<rj><au>Dryden.</au></rj></cs></p>

<p><syn><b>Syn.</b> -- To <er>Draw</er>, <er>Drag</er>.</syn>
<usage><xex>Draw</xex> differs from <xex>drag</xex> in this, that
<xex>drag</xex> implies a natural inaptitude for drawing, or positive
resistance; it is applied to things pulled or hauled along the ground,
or moved with toil or difficulty. <xex>Draw</xex> is applied to all
bodies moved by force in advance, whatever may be the degree of force;
it commonly implies that some kind of aptitude or provision exists for
drawing. <xex>Draw</xex> is the more general or generic term, and
<xex>drag</xex> the more specific. We say, the horses <xex>draw</xex> a
coach or wagon, but they <xex>drag</xex> it through mire; yet
<xex>draw</xex> is properly used in both cases.</usage><br/
[<source>1913 Webster</source>]</p>

<p><ent>Draw</ent><br/
<hw>Draw</hw> <pr>(?)</pr>, <pos>v. i.</pos> <sn>1.</sn> <def>To pull;
to exert strength in drawing anything; to have force to move anything by
pulling; <as>as, a horse <ex>draws</ex> well; the sails of a ship
<ex>draw</ex> well.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ A sail is said to <xex>draw</xex> when it is filled with
wind.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To draw a liquid from some receptacle, as water from
a well.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The woman saith unto him, Sir, thou hast nothing to
<qex>draw</qex> with, and the well is deep.</q> <rj><qau>John iv.
11.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To exert an attractive force; to act as an
inducement or enticement.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Keep a watch upon the particular bias of their minds, that it may
not <qex>draw</qex> too much.</q> <rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Med.)</fld> <def>To have efficiency as an
epispastic; to act as a sinapism; -- said of a blister, poultice,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To have draught, as a chimney, flue, or the like; to
furnish transmission to smoke, gases, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To unsheathe a weapon, especially a sword.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>So soon as ever thou seest him, <qex>draw</qex>; and as thou
<qex>drawest</qex>, swear horrible.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>To perform the act, or practice the art, of
delineation; to sketch; to form figures or pictures.</def> <ldquo/Skill
in <xex>drawing</xex>.<rdquo/ <rj><au>Locke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>To become contracted; to shrink.</def> <ldquo/To
<xex>draw</xex> into less room.<rdquo/ <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>To move; to come or go; literally, to draw one's
self; -- with prepositions and adverbs; as, to <xex>draw away</xex>, to
move off, esp. in racing, to get in front; to obtain the lead or
increase it; to <ecol><b>draw back</b></ecol>, to retreat; to
<ecol><b>draw level</b></ecol>, to move up even (with another); to come
up to or overtake another; to <ecol><b>draw off</b></ecol>, to retire or
retreat; to <ecol><b>draw on</b></ecol>, to advance; to <ecol><b>draw
up</b></ecol>, to form in array; to <ecol><b>draw near</b></ecol>,
<ecol><b>draw nigh</b></ecol>, or <ecol><b>draw towards</b></ecol>, to
approach; to <ecol><b>draw together</b></ecol>, to come together, to
collect.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <def>To make a draft or written demand for payment of
money deposited or due; -- usually with <xex>on</xex> or
<xex>upon</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>You may <qex>draw</qex> on me for the expenses of your
journey.</q> <rj><qau>Jay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>11.</sn> <def>To admit the action of pulling or dragging; to
undergo draught; <as>as, a carriage <ex>draws</ex>
easily</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>12.</sn> <def>To sink in water; to require a depth for
floating.</def> <ldquo/Greater hulks <xex>draw</xex> deep.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To draw to a head</b></col>. <sd>(a)</sd>
<fld>(Med.)</fld> <cd>To begin to suppurate; to ripen, as a boil.</cd>
<sd>(b)</sd> Fig.: <cd>To ripen, to approach the time for action;
<as>as, the plot <ex>draws to a head</ex></as>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Draw</ent><br/
<hw>Draw</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act of drawing;
draught.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A lot or chance to be drawn.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>the act of drawing a lot or chance.</def> <ldquo/The
luck of the <xex>draw</xex>.<rdquo/<br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>A drawn game or battle, etc; a tied game; a
tie.</def> <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>4.</sn> <def>That part of a bridge which may be raised, swung
round, or drawn aside; the movable part of a drawbridge. See the Note
under <er>Drawbridge</er>.</def> <mark>[U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>The result of drawing, or state of being
drawn;</def> <specif>specif.:</specif> <sd>(a)</sd> <def>A drawn battle,
game, or the like.</def> <sd>(b)</sd> <def>The spin or twist imparted to
a ball, or the like, by a drawing stroke.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>6.</sn> <def>That which is drawn or is subject to
drawing.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Drawable</ent><br/
<hw>Draw"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of being
drawn.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drawback</ent><br/
<hw>Draw"back`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A loss
of advantage, or deduction from profit, value, success, etc.; a
discouragement or hindrance; objectionable feature.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The avarice of Henry VII . . . . must be deemed a
<qex>drawback</qex> from the wisdom ascribed to him.</q>
<rj><qau>Hallam.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Com.)</fld> <def>Money paid back or remitted;
especially, a certain amount of duties or customs, sometimes the whole,
and sometimes only a part, remitted or paid back by the government, on
the exportation of the commodities on which they were levied.</def>
<rj><au>McCulloch.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drawbar</ent><br/
<hw>Draw"bar`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Railroad)</fld>
<sd>(a)</sd> <def>An openmouthed bar at the end of a car, which receives
a coupling link and pin by which the car is drawn. It is usually
provided with a spring to give elasticity to the connection between the
cars of a train.</def> <sd>(b)</sd> <def>A bar of iron with an eye at
each end, or a heavy link, for coupling a locomotive to a tender or
car.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drawbench</ent><br/
<hw>Draw"bench`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Med.)</fld>
<def>A machine in which strips of metal are drawn through a drawplate;
especially, one in which wire is thus made; -- also called <xex>drawing
bench</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drawbolt</ent><br/
<hw>Draw"bolt`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Engin.)</fld>
<def>A coupling pin. See under <er>Coupling</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drawbore</ent><br/
<hw>Draw"bore`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Joinery)</fld>
<def>A hole bored through a tenon nearer to the shoulder than the holes
through the cheeks are to the edge or abutment against which the
shoulder is to rest, so that a pin or bolt, when driven into it, will
draw these parts together.</def> <rj><au>Weale.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drawbore</ent><br/
<hw>Draw"bore`</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To make a
drawbore in; <as>as, to <ex>drawbore</ex> a tenon</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To enlarge the bore of a gun barrel by drawing,
instead of thrusting, a revolving tool through it.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drawboy</ent><br/
<hw>Draw"boy`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Weaving)</fld>
<def>A boy who operates the harness cords of a hand loom; also, a part
of power loom that performs the same office.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drawbridge</ent><br/
<hw>Draw"bridge`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A bridge of which
either the whole or a part is made to be raised up, let down, or drawn
or turned aside, to admit or hinder communication at pleasure, as before
the gate of a town or castle, or over a navigable river or
canal.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The movable portion, or draw, is called, specifically, a
<xex>bascule</xex>, <xex>balance</xex>, or <xex>lifting bridge</xex>, a
<xex>turning</xex>, <xex>swivel</xex>, or <xex>swing bridge</xex>, or a
<xex>rolling bridge</xex>, according as it turns on a hinge vertically,
or on a pivot horizontally, or is pushed on rollers.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drawcansir</ent><br/
<hw>Draw"can*sir</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From the name of
a bullying braggart character in the play by George Villiers called
<ldquo/The Rehearsal.<rdquo/]</ety> <def>A blustering, bullying fellow;
a pot-valiant braggart; a bully.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The leader was of an ugly look and gigantic stature; he acted like
a <qex>drawcansir</qex>, sparing neither friend nor foe.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Draw-cut</ent><br/
<hw>Draw"-cut`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A single cut with a
knife.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>drawee</ent><br/
<hw>draw*ee"</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Law)</fld> <def>The
person on whom an order or bill of exchange is drawn; -- the correlative
of <inv>drawer</inv>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>drawer</ent><br/
<hw>draw"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who,
or that which, draws</def>; as: <sd>(a)</sd> <def>One who draws liquor
for guests; a waiter in a taproom.</def> <au>Shak.</au> <sd>(b)</sd>
<def>One who delineates or depicts; a draughtsman; <as>as, a good
<ex>drawer</ex></as>.</def> <sd>(c)</sd> <fld>(Law)</fld> <def>One who
draws a bill of exchange or order for payment; -- the correlative of
<inv>drawee</inv>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which is drawn</def>; as: <sd>(a)</sd> <def>A
sliding box or receptacle in a case, which is opened by pulling or
drawing out, and closed by pushing in.</def> <sd>(b)</sd>
<pluf>pl.</pluf> <def>An under-garment worn on the lower
limbs.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Chest of drawers</b></col>. <cd>See under
<er>Chest</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drawfiling</ent><br/
<hw>Draw"fil`ing</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The process of
smooth filing by working the file sidewise instead of
lengthwise.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drawgear</ent><br/
<hw>Draw"gear`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A
harness for draught horses.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Railroad)</fld> <def>The means or parts by which
cars are connected to be drawn.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drawgloves</ent><br/
<hw>Draw"gloves`</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <def>An old game,
played by holding up the fingers.</def> <rj><au>Herrick.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drawhead</ent><br/
<hw>Draw"head`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Railroad)</fld>
<def>The flanged outer end of a drawbar; also, a name applied to the
drawgear.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drawing</ent><br/
<hw>Draw"ing</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act of pulling, or
attracting.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The act or the art of representing any object by
means of lines and shades; especially, such a representation when in one
color, or in tints used not to represent the colors of natural objects,
but for effect only, and produced with hard material such as pencil,
chalk, etc.; delineation; also, the figure or representation
drawn.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The process of stretching or spreading metals as by
hammering, or, as in forming wire from rods or tubes and cups from sheet
metal, by pulling them through dies.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Textile Manuf.)</fld> <def>The process of pulling
out and elongating the sliver from the carding machine, by revolving
rollers, to prepare it for spinning.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>The distribution of prizes and blanks in a
lottery.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Drawing</xex> is used adjectively or as the first
part of compounds in the sense of <xex>pertaining to drawing</xex>,
<xex>for drawing</xex> (in the sense of pulling, and of pictorial
representation); as, <xex>drawing</xex> master or
<xex>drawing</xex>-master, <xex>drawing</xex> knife or
<xex>drawing</xex>-knife, <xex>drawing</xex> machine, <xex>drawing</xex>
board, <xex>drawing</xex> paper, <xex>drawing</xex> pen,
<xex>drawing</xex> pencil, etc.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>A drawing of tea</b></col>, <cd>a small portion of tea
for steeping.</cd> -- <col><b>Drawing knife</b></col>. <cd>See in the
<er>Vocabulary</er>.</cd> -- <col><b>Drawing paper</b></col> <fld>(Fine
Arts)</fld>, <cd>a thick, sized paper for draughtsman and for
water-color painting.</cd> -- <col><b>Drawing slate</b></col>, <cd>a
soft, slaty substance used in crayon drawing; -- called also
<altname>black chalk</altname>, or <altname>drawing
chalk</altname>.</cd> -- <col><b>Free-hand drawing</b></col>, <cd>a
style of drawing made without the use of guiding or measuring
instruments, as distinguished from mechanical or geometrical drawing;
also, a drawing thus executed.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 453 --></p>

<p><ent>Drawknife</ent><br/
<ent>Drawing knife</ent><br/
<mhw>{ <hw>Draw"ing knife"</hw> <pr>(?)</pr>, <hw>Draw"knife`</hw>
<pr>(?)</pr> }</mhw>, <pos>n.</pos> <sn>1.</sn> <def>A woodworker`s and
joiner's tool having a blade with a handle at each end, used to shave
off surfaces, by drawing it toward one; a shave; -- called also
<altname>drawshave</altname>, and <altname>drawing
shave</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Carp.)</fld> <def>A tool used for the purpose of
making an incision along the path a saw is to follow, to prevent it from
tearing the surface of the wood.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drawing-room</ent><br/
<hw>Draw"ing-room`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Abbrev. fr.
<ets>withdraw-ing-room</ets>.]</ety> <sn>1.</sn> <def>A room
appropriated for the reception of company; a room to which company
withdraws from the dining room.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The company assembled in such a room; also, a
reception of company in it; <as>as, to hold a
<ex>drawing-room</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He [Johnson] would amaze a <qex>drawing-room</qex> by suddenly
ejaculating a clause of the Lord's Prayer.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Drawing-room car</b></col>. <cd>See <cref>Palace
car</cref>, under <er>Car</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>drawknife</ent><br/
<hw>drawknife</hw> <pos>n.</pos> <def>see <er>drawing
knife</er>.</def><br/
<syn><b>Syn. --</b> drawshave.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Drawl</ent><br/
<hw>Drawl</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Drawled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Drawling</conjf>.]</vmorph> <ety>[Prob. fr. <ets>draw</ets>: cf.
D. <ets>dralen</ets> to linger, tarry, Icel. <ets>dralla</ets> to
loiter. See <er>Draw</er>, and cf. <er>Draggle</er>.]</ety> <def>To
utter in a slow, lengthened tone.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drawl</ent><br/
<hw>Drawl</hw>, <pos>v. i.</pos> <def>To speak with slow and lingering
utterance, from laziness, lack of spirit, affectation, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Theologians and moralists . . . talk mostly in a
<qex>drawling</qex> and dreaming way about it.</q>
<rj><qau>Landor.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drawl</ent><br/
<hw>Drawl</hw>, <pos>n.</pos> <def>A lengthened, slow monotonous
utterance.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drawlatch</ent><br/
<hw>Draw"latch`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A housebreaker or
thief.</def> <mark>[Obs.]</mark> <rj><au>Old Play (1631).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drawling</ent><br/
<hw>Drawl"ing</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of speaking
with a drawl; a drawl.</def> -- <wordforms><wf>Drawl"ing*ly</wf>,
<pos>adv.</pos></wordforms> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drawlink</ent><br/
<hw>Draw"link`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Drawbar</er> <sd>(b)</sd>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drawloom</ent><br/
<hw>Draw"loom`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A kind
of loom used in weaving figured patterns; -- called also
<altname>drawboy</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A species of damask made on the drawloom.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drawn</ent><br/
<hw>Drawn</hw> <pr>(?)</pr>, <pos>p. p. & a.</pos> <def>See
<er>Draw</er>, <pos>v. t. & i.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Drawn butter</b></col>, <cd>butter melter and prepared to
be used as a sort of gravy.</cd> -- <col><b>Drawn fowl</b></col>, <cd>an
eviscerated fowl.</cd> -- <mcol><col><b>Drawn game</b></col> <it>or</it>
<col><b>Drawn battle</b></col></mcol>, <cd>one in which neither party
wins; one equally contested.</cd> -- <col><b>Drawn fox</b></col>,
<cd>one driven from cover.</cd> <au>Shak.</au> -- <col><b>Drawn
work</b></col>, <cd>ornamental work made by drawing out threads from
fine cloth, and uniting the cross threads, to form a
pattern.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drawnet</ent><br/
<hw>Draw"net`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A net for catching
the larger sorts of birds; also, a dragnet.</def>
<rj><au>Crabb.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>drawnwork</ent><br/
<hw>drawnwork</hw> <pos>n.</pos> <def>ornamental needlework done by
drawing threads to form lacelike patterns.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Drawplate</ent><br/
<hw>Draw"plate`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A hardened steel
plate having a hole, or a gradation of conical holes, through which
wires are drawn to be reduced and elongated.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drawrod</ent><br/
<hw>Draw"rod`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Railroad)</fld>
<def>A rod which unites the drawgear at opposite ends of the car, and
bears the pull required to draw the train.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drawshave</ent><br/
<hw>Draw"shave`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See <er>Drawing
knife</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drawspring</ent><br/
<hw>Draw"spring`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Railroad)</fld>
<def>The spring to which a drawbar is attached.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dray</ent><br/
<hw>Dray</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A squirrel's nest.</def>
<rj><au>Cowper.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dray</ent><br/
<hw>Dray</hw>, <pos>n.</pos> <ety>[AS. <ets>dr<ae/ge</ets> a dragnet,
fr. <ets>dragan</ets>. <ets><?/<?/<?/<?/</ets>. See <er>Draw</er>, and
cf. 2d <er>Drag</er>, 1st <er>Dredge</er>.]</ety> <sn>1.</sn> <def>A
strong low cart or carriage used for heavy burdens.</def>
<rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A kind of sledge or sled.</def>
<rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dray cart</b></col>, <cd>a dray.</cd> -- <col><b>Dray
horse</b></col>, <cd>a heavy, strong horse used in drawing a
dray.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drayage</ent><br/
<hw>Dray"age</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>Use of a
dray.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The charge, or sum paid, for the use of a
dray.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drayman</ent><br/
<hw>Dray"man</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Draymen</plw> <pr>(<?/)</pr>.</plu> <def>A man who attends a
dray.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drazel</ent><br/
<hw>Draz"el</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. <er>Dross</er>,
<er>Drossel</er>.]</ety> <def>A slut; a vagabond wench. Same as
<er>Drossel</er>.</def> <mark>[Obs.]</mark>
<rj><au>Hudibras.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dread</ent><br/
<hw>Dread</hw> <pr>(dr<ecr/d)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Dreaded</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Dreading</conjf>.]</vmorph> <ety>[AS. <ets>dr<aemac/dan</ets>, in
comp.; akin to OS. <ets>dr<amac/dan</ets>, OHG. <ets>tr<amac/tan</ets>,
both only in comp.]</ety> <def>To fear in a great degree; to regard, or
look forward to, with terrific apprehension.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>When at length the moment <qex>dreaded</qex> through so many years
came close, the dark cloud passed away from Johnson's mind.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dread</ent><br/
<hw>Dread</hw>, <pos>v. i.</pos> <def>To be in dread, or great
fear.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Dread</qex> not, neither be afraid of them.</q>
<rj><qau>Deut. i. 29.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dread</ent><br/
<hw>Dread</hw>, <pos>n.</pos> <sn>1.</sn> <def>Great fear in view of
impending evil; fearful apprehension of danger; anticipatory
terror.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The secret <qex>dread</qex> of divine displeasure.</q>
<rj><qau>Tillotson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>dread</qex> of something after death.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Reverential or respectful fear; awe.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The fear of you, and the <qex>dread</qex> of you, shall be upon
every beast of the earth.</q> <rj><qau>Gen. ix. 2.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>His scepter shows the force of temporal power,<br/
The attribute to awe and majesty,<br/
Wherein doth sit the <qex>dread</qex> and fear of kings.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>An object of terrified apprehension.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A person highly revered.</def> <mark>[Obs.]</mark>
<ldquo/Una, his dear <xex>dread</xex>.<rdquo/
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Fury; dreadfulness.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Doubt; <as>as, out of <ex>dread</ex></as>.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj></p>

<p><syn><b>Syn.</b> -- Awe; fear; affright; terror; horror; dismay;
apprehension. See <er>Reverence</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dread</ent><br/
<hw>Dread</hw>, <pos>a.</pos> <sn>1.</sn> <def>Exciting great fear or
apprehension; causing terror; frightful; dreadful.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>dread</qex> eternity! how surely mine.</q>
<rj><qau>Young.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Inspiring with reverential fear; awful' venerable;
<as>as, <ex>dread</ex> sovereign; <ex>dread</ex> majesty; <ex>dread</ex>
tribunal.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dreadable</ent><br/
<hw>Dread"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Worthy of being
dreaded.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dread-bolted</ent><br/
<hw>Dread"-bolt`ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Armed with
dreaded bolts.</def> <ldquo/<xex>Dread-bolted</xex> thunder.<rdquo/
<mark>[Poetic]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dreader</ent><br/
<hw>Dread"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who fears, or
lives in fear.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dreadful</ent><br/
<hw>Dread"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Full of
dread or terror; fearful.</def> <mark>[Obs.]</mark> <ldquo/With
<xex>dreadful</xex> heart.<rdquo/ <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Inspiring dread; impressing great fear; fearful;
terrible; <as>as, a <ex>dreadful</ex> storm</as>.</def> <ldquo/
<xex>Dreadful</xex> gloom.<rdquo/ <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>For all things are less <qex>dreadful</qex> than they seem.</q>
<rj><qau>Wordsworth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Inspiring awe or reverence; awful.</def>
<mark>[Obs.]</mark> <ldquo/God's <xex>dreadful</xex> law.<rdquo/
<rj><au>Shak.</au></rj></p>

<p><syn><b>Syn.</b> -- Fearful; frightful; terrific; terrible; horrible;
horrid; formidable; tremendous; awful; venerable. See
<er>Frightful</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dreadfully</ent><br/
<hw>Dread"ful*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a dreadful
manner; terribly.</def> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dreadfulness</ent><br/
<hw>Dread"ful*ness</hw>, <pos>n.</pos> <def>The quality of being
dreadful.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dreadingly</ent><br/
<hw>Dread"ing*ly</hw>, <pos>adv.</pos> <def>With dread.</def>
<rj><au>Warner.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dreadless</ent><br/
<hw>Dread"less</hw>, <pos>a.</pos> <sn>1.</sn> <def>Free from dread;
fearless; intrepid; dauntless; <as>as, <ex>dreadless</ex>
heart</as>.</def> <ldquo/The <xex>dreadless</xex> angel.<rdquo/
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Exempt from danger which causes dread; secure.</def>
<ldquo/ safe in his <xex>dreadless</xex> den.<rdquo/
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dreadless</ent><br/
<hw>Dread"less</hw>, <pos>adv.</pos> <def>Without doubt.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dreadlessness</ent><br/
<hw>Dread"less*ness</hw>, <pos>n.</pos> <def>Freedom from
dread.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dreadly</ent><br/
<hw>Dread"ly</hw>, <pos>a.</pos> <def>Dreadful.</def>
<mark>[Obs.]</mark> <ldquo/<xex>Dreadly</xex> spectacle.<rdquo/
<au>Spenser.</au> -- <def2><pos>adv.</pos> <def>With dread.</def>
<mark>[Obs.]</mark> <ldquo/<xex>Dreadly</xex> to shake.<rdquo/
<au>Sylvester (Du Bartas).</au></def2><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dreadnaught</ent><br/
<hw>Dread"naught`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A
fearless person.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Hence: A garment made of very thick cloth, that can
defend against storm and cold; also, the cloth itself;
fearnaught.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A <er>dreadnought</er>, in either sense.</def><br/
[<source>PJC</source>]</p>

<p><ent>Dreadnought</ent><br/
<hw>Dread"nought`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<mark>(Capitalized)</mark> <def>A British battleship, completed in 1906
-- 1907, having an armament consisting of ten 12-inch guns mounted in
turrets, and of twenty-four 12-pound quick-fire guns for protection
against torpedo boats. This was the first battleship of the type
characterized by a main armament of big guns all of the same caliber.
She had a displacement of 17,900 tons at load draft, and a speed of 21
knots per hour.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>Any battleship having its main armament entirely of
big guns all of one caliber. Since the Dreadnought was built, the
caliber of the heaviest guns has increased from 12 in. to 13<frac12/
in., 14 in., and 15 in., and the displacement of the largest batteships
from 18,000 tons to 30,000 tons and upwards. The term
<stype>superdreadnought</stype> is popularly applied to battleships with
such increased displacement and gun caliber.</def> <altsp>[Also spelled
<asp>dreadnaught</asp>.]</altsp><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Dream</ent><br/
<hw>Dream</hw> <pr>(dr<emac/m)</pr>, <pos>n.</pos> <ety>[Akin to OS.
<ets>dr<omac/m</ets>, D. <ets>droom</ets>, G. <ets>traum</ets>, Icel.
<ets>draumr</ets>, Dan. & Sw. <ets>dr<oum/m</ets>; cf. G.
<ets>tr<uum/gen</ets> to deceive, Skr. <ets>druh</ets> to harm, hurt,
try to hurt. AS. <ets>dre<aacute/m</ets> joy, gladness, and OS.
<ets>dr<omac/m</ets> joy are, perh., different words; cf. Gr.
<grk>qry^los</grk> noise.]</ety> <sn>1.</sn> <def>The thoughts, or
series of thoughts, or imaginary transactions, which occupy the mind
during sleep; a sleeping vision.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Dreams</qex> are but interludes which fancy makes.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I had a <qex>dream</qex> which was not all a <qex>dream</qex>.</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A visionary scheme; a wild conceit; an idle fancy; a
vagary; a revery; -- in this sense, applied to an imaginary or
anticipated state of happiness; <as>as, a <ex>dream</ex> of bliss; the
<ex>dream</ex> of his youth.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>There sober thought pursued the amusing theme,<br/
Till Fancy colored it and formed a <qex>dream</qex>.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>It is not them a mere <qex>dream</qex>, but a very real aim which
they propose.</q> <rj><qau>J. C. Shairp.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dream</ent><br/
<hw>Dream</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Dreamed</conjf> <pr>(dr<emac/md)</pr> or <conjf>Dreamt</conjf>
(dr<ecr/mt); <pos>p. pr. & vb. n.</pos>
<conjf>Dreaming</conjf>.]</vmorph> <ety>[Cf. AS. <ets>dr<emac/man</ets>,
<ets>dr<ymac/man</ets>, to rejoice. See <er>Dream</er>,
<pos>n.</pos>]</ety> <sn>1.</sn> <def>To have ideas or images in the
mind while in the state of sleep; to experience sleeping visions; --
often with <xex>of</xex>; <as>as, to <ex>dream</ex> of a battle, or of
an absent friend</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To let the mind run on in idle revery or vagary; to
anticipate vaguely as a coming and happy reality; to have a visionary
notion or idea; to imagine.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Here may we sit and <qex>dream</qex><br/
Over the heavenly theme</q>. <rj><qau>Keble.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>They <qex>dream</qex> on in a constant course of reading, but not
digesting</q>. <rj><qau>Locke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dream</ent><br/
<hw>Dream</hw>, <pos>v. t.</pos> <def>To have a dream of; to see, or
have a vision of, in sleep, or in idle fancy; -- often followed by an
objective clause.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Your old men shall <qex>dream</qex> dreams</q>. <rj><qau>Acts ii.
17.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>At length in sleep their bodies they compose,<br/
And <qex>dreamt</qex> the future fight</q>.
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And still they <qex>dream</qex> that they shall still succeed</q>.
<rj><qau>Cowper.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>To dream away</b></col> <col><b>To dream
out</b></col>, <col><b>To dream through</b></col>, etc.</mcol>, <cd>to
pass in revery or inaction; to spend in idle vagaries; <as>as, to
<ex>dream away</ex> an hour; to <ex>dream through</ex> life</as>.</cd>
<ldquo/ Why does Antony <xex>dream out</xex> his hours?<rdquo/
<rj><au>Dryden.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dreamer</ent><br/
<hw>Dream"er</hw> <pr>(dr<emac/m"<etil/r)</pr>, <pos>n.</pos>
<sn>1.</sn> <def>One who dreams.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A visionary; one lost in wild imaginations or vain
schemes of some anticipated good; <as>as, a political
<ex>dreamer</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dreamful</ent><br/
<hw>Dream"ful</hw> <pr>(dr<emac/m"f<usdot/l)</pr>, <pos>a.</pos>
<def>Full of dreams.</def> <ldquo/ <xex>Dreamful</xex> ease.<rdquo/
<au>Tennyson.</au> -- <wordforms><wf>Dream"ful*ly</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dreamily</ent><br/
<hw>Dream"i*ly</hw> <pr>(dr<emac/m"<icr/*l<ycr/)</pr>, <pos>adv.</pos>
<def>As if in a dream; softly; slowly; languidly.</def>
<rj><au>Longfellow.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dreaminess</ent><br/
<hw>Dream"i*ness</hw>, <pos>n.</pos> <def>The state of being
dreamy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dreamingly</ent><br/
<hw>Dream"ing*ly</hw>, <pos>adv.</pos> <def>In a dreamy
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dreamland</ent><br/
<hw>Dream"land`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An unreal,
delightful country such as in sometimes pictured in dreams; region of
fancies; fairyland.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>[He] builds a bridge from <qex>dreamland</qex> for his lay.</q>
<rj><qau>Lowell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dreamless</ent><br/
<hw>Dream"less</hw>, <pos>a.</pos> <def>Free from, or without,
dreams.</def> <au>Camden.</au> -- <wordforms><wf>Dream"less*ly</wf>,
<pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>dreamlike</ent><br/
<hw>dreamlike</hw> <pos>adj.</pos> <def>resembling a dream; vague or
fantastic; <as>as, night invested the lake with a <ex>dreamlike</ex>
quality</as>.</def><br/
<syn><b>Syn. --</b> surreal.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>dreamworld</ent><br/
<hw>dream"world`</hw> <pr>(dr<emac/m"w<ucir/rld)</pr>, <pos>n.</pos>
<def>A pleasing country existing only in dreams or imagination; a
fantasy land.</def><br/
<syn><b>Syn. --</b> never-never land, dreamland.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>dreamy</ent><br/
<hw>dream"y</hw> <pr>(dr<emac/m"<ycr/)</pr>, <pos>a.</pos>
<amorph>[<pos>Compar.</pos> <adjf>Dreamier</adjf>
<pr>(dr<emac/m"<icr/*<etil/r)</pr>; <pos>superl.</pos>
<adjf>Dreamiest</adjf> <pr>(?)</pr>.]</amorph> <sn>1.</sn>
<def>Abounding in dreams or given to dreaming; appropriate to, or like,
dreams; visionary.</def> <ldquo/The <xex>dreamy</xex> dells.<rdquo/
<rj><au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>soothing; restful; <as>as, <ex>dreamy</ex>
music</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>Like what one dreams of; wonderful; delightful;
marvelous; ideal; <as>as, a <ex>dreamy</ex> house and garden</as>.</def>
<mark>[informal]</mark> <br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <def>Prone to indulge in fantasy or daydreaming; <as>as,
a <ex>dreamy</ex> young girl</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Drear</ent><br/
<hw>Drear</hw> <pr>(dr<emac/r)</pr>, <pos>a.</pos> <ety>[See
<er>Dreary</er>.]</ety> <def>Dismal; gloomy with solitude.</def>
<ldquo/A <xex>drear</xex> and dying sound.<rdquo/
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drear</ent><br/
<hw>Drear</hw>, <pos>n.</pos> <def>Sadness; dismalness.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj></p>

<p><ent>Drearihood</ent><br/
<ent>Drearihead</ent><br/
<mhw>{ <hw>Drear"i*head</hw> <pr>(dr<emac/r"<icr/*h<ecr/d)</pr>,
<hw>Drear"i*hood</hw> <pr>(dr<emac/r"<icr/*h<oocr/d)</pr>, }</mhw>
<pos>n.</pos> <def>Affliction; dreariness.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drearily</ent><br/
<hw>Drear"i*ly</hw>, <pos>adv.</pos> <def>Gloomily; dismally.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dreariment</ent><br/
<hw>Drear"i*ment</hw> <pr>(dr<emac/r"<icr/*m<eit/nt)</pr>, <pos>n.</pos>
<def>Dreariness.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dreariness</ent><br/
<hw>Drear"i*ness</hw>, <pos>n.</pos> <sn>1.</sn> <def>Sorrow;
wretchedness.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Dismalness; gloomy solitude.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drearing</ent><br/
<hw>Drear"ing</hw>, <pos>n.</pos> <def>Sorrow.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drearisome</ent><br/
<hw>Drear"i*some</hw> <pr>(dr<emac/r"<icr/*s<ucr/m)</pr>, <pos>a.</pos>
<def>Very dreary.</def> <rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dreary</ent><br/
<hw>Drear"y</hw> <pr>(dr<emac/r"<ycr/)</pr>, <pos>a.</pos>
<amorph>[<pos>Compar.</pos> <adjf>Drearier</adjf> <pr>(?)</pr>;
<pos>superl.</pos> <adjf>Dreariest</adjf>.]</amorph> <ety>[OE.
<ets>dreori</ets>, <ets>dreri</ets>, AS. <ets>dre<oacute/rig</ets>, sad;
akin to G. <ets>traurig</ets>, and prob. to AS.
<ets>dre<oacute/san</ets> to fall, Goth. <ets>driusan</ets>. Cf.
<er>Dross</er>, <er>Drear</er>, <er>Drizzle</er>,
<er>Drowse</er>.]</ety> <sn>1.</sn> <def>Sorrowful; distressful.</def>
<mark>[Obs.]</mark> <ldquo/ <xex>Dreary</xex> shrieks.<rdquo/
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Exciting cheerless sensations, feelings, or
associations; comfortless; dismal; gloomy.</def> <ldquo/
<xex>Dreary</xex> shades.<rdquo/ <au>Dryden.</au> <ldquo/The
<xex>dreary</xex> ground.<rdquo/ <rj><au>Prior.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Full many a <qex>dreary</qex> anxious hour.</q>
<rj><qau>Keble.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Johnson entered on his vocation in the most <qex>dreary</qex> part
of that <qex>dreary</qex> interval which separated two ages of
prosperity.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drecche</ent><br/
<hw>Drec"che</hw> <pr>(dr<ecr/ch"<eit/)</pr>, <pos>v. t.</pos> <ety>[AS.
<ets>dreccan</ets>, <ets>dreccean</ets>.]</ety> <sn>1.</sn> <def>To vex;
to torment; to trouble.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>As man that in his dream is <qex>drecched</qex> sore.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drecche</ent><br/
<hw>Drec"che</hw>, <pos>v. i.</pos> <def>To delay.</def>
<mark>[Obs.]</mark> <rj><au>Gower.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dredge</ent><br/
<hw>Dredge</hw> <pr>(dr<ecr/j)</pr>, <pos>n.</pos> <ety>[F.
<ets>dr<egrave/ge</ets>, <ets>dreige</ets>, fish net, from a word akin
to E. <ets>draw</ets>; cf. D. <ets>dreg</ets>, <ets>dregge</ets>, small
anchor, <ets>dreg</ets>net dragnet. <root/73. See <er>Draw</er>.]</ety>
<sn>1.</sn> <def>Any instrument used to gather or take by dragging; as:
<sd>(a)</sd> A dragnet for taking up oysters, etc., from their beds.
<sd>(b)</sd> A dredging machine. <sd>(c)</sd> An iron frame, with a fine
net attached, used in collecting animals living at the bottom of the
sea.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mining)</fld> <def>Very fine mineral matter held in
suspension in water.</def> <rj><au>Raymond.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dredge</ent><br/
<hw>Dredge</hw> <pr>(dr<ecr/j)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Dredged</conjf> <pr>(dr<ecr/jd)</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>Dredging</conjf>.]</vmorph> <def>To catch or gather
with a dredge; to deepen with a dredging machine.</def> <rj><au>R.
Carew.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dredging machine</b></col>, <cd>a machine (commonly on a
boat) used to scoop up mud, gravel, or obstructions from the bottom of
rivers, docks, etc., so as to deepen them.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dredge</ent><br/
<hw>Dredge</hw>, <pos>n.</pos> <ety>[OE. <ets>dragge</ets>, F.
<ets>drag<eacute/e</ets>, dredge, also, sugar plum; cf. Prov.
<ets>dragea</ets>, It. <ets>treggea</ets>; corrupted fr. LL.
<ets>tragemata</ets>, pl., sweetmeats, Gr. <grk>tragh`mata</grk>, fr.
<grk>trw`gein</grk> to gnaw.]</ety> <def>A mixture of oats and
barley.</def> <mark>[Obs.]</mark> <rj><au>Kersey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dredge</ent><br/
<hw>Dredge</hw>, <pos>v. t.</pos> <def>To sift or sprinkle flour, etc.,
on, as on roasting meat.</def> <rj><au>Beau. & Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dredging box</b></col>. <sd>(a)</sd> <cd>Same as 2d
<er>Dredger</er>.</cd> <sd>(b)</sd> <fld>(Gun.)</fld> <cd>A copper box
with a perforated lid; -- used for sprinkling meal powder over shell
fuses.</cd> <rj><au>Farrow.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dredger</ent><br/
<hw>Dredg"er</hw> <pr>(dr<ecr/j"<etil/r)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>One who fishes with a dredge.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A dredging machine.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dredger</ent><br/
<hw>Dredg"er</hw>, <pos>n.</pos> <fld>(Cookery)</fld> <def>A box with
holes in its lid; -- used for sprinkling flour, as on meat or a
breadboard; -- called also <altname>dredging box</altname>,
<altname>drudger</altname>, and <altname>drudging
box</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dree</ent><br/
<hw>Dree</hw> <pr>(dr<emac/)</pr>, <pos>v. t.</pos> <ety>[AS.
<ets>dre<oacute/gan</ets> to bear, endure, complete.]</ety> <def>To
endure; to suffer.</def> <mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dree</ent><br/
<hw>Dree</hw>, <pos>v. i.</pos> <def>To be able to do or endure.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dree</ent><br/
<hw>Dree</hw>, <pos>a.</pos> <def>Wearisome; tedious.</def> <mark>[Prov.
Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dreg</ent><br/
<hw>Dreg</hw> <pr>(dr<ecr/g)</pr>, <pos>n.</pos> <ety>[Prob. from Icel.
<ets>dregg</ets>; akin to Sw. <ets>dr<aum/gg</ets>, cf. Icel. & Sw.
<ets>draga</ets> to draw. Cf. <er>Draw</er>.]</ety> <def>Corrupt or
defiling matter contained in a liquid, or precipitated from it; refuse;
feculence; lees; grounds; sediment; hence, the vilest and most worthless
part of anything; <as>as, the <ex>dregs</ex> of society</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We, the <qex>dregs</qex> and rubbish of mankind.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Used formerly (rarely) in the singular, as by Spenser
and Shakespeare, but now chiefly in the plural.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dregginess</ent><br/
<hw>Dreg"gi*ness</hw> <pr>(dr<ecr/g"g<icr/*n<ecr/s)</pr>, <pos>n.</pos>
<def>Fullness of dregs or lees; foulness; feculence.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dreggish</ent><br/
<hw>Dreg"gish</hw> <pr>(dr<ecr/g"g<icr/sh)</pr>, <pos>a.</pos> <def>Foul
with lees; feculent.</def> <rj><au>Harvey.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dreggy</ent><br/
<hw>Dreg"gy</hw> <pr>(dr<ecr/g"g<ycr/)</pr>, <pos>a.</pos>
<def>Containing dregs or lees; muddy; foul; feculent.</def>
<rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dreibund</ent><br/
\'d8<hw>Drei"bund`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[G., fr.
<ets>drei</ets> three + <ets>bund</ets> league.]</ety> <def>A triple
alliance; specif., the alliance of Germany, Austria, and Italy, formed
in 1882.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>dreidl</ent><br/
<ent>dreidel</ent><br/
<mhw><hw>dreidel</hw>, <hw>dreidl</hw></mhw> <pr>(dr<amac/d"'l)</pr>,
<pos>n.</pos> <sn>1.</sn> <def>a toy shaped somewhat like a top, but
having four flat sides, each marked with one of the Hebrew letters
<xex>nun</xex>, <xex>gimel</xex>, <xex>he</xex>, or <xex>shin</xex>. It
is spun like a top, and the letter showing when it stops spinning
determines the outcome of a game of chance.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>a game of chance played with a dreidel{1}, most
commonly by children at Hannukah.</def><br/
[<source>PJC</source>]</p>

<p><ent>Drein</ent><br/
<hw>Drein</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To drain.</def>
<mark>[Obs.]</mark> <rj><au>Congreve.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dreint</ent><br/
<ent>Dreinte</ent><br/
<hw>Drein"te</hw> <pr>(?)</pr>, <wordforms><pos>imp.</pos>,
<hw>Dreint</hw> <pr>(<?/)</pr>,</wordforms> <def><pos>p. p.</pos> of
<er>Drench</er> to drown.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dreissena</ent><br/
\'d8<hw>Dreis"se*na</hw> <pr>(?)</pr>, <pos>prop. n.</pos> <ety>[NL.
Named after <ets>Dreyssen</ets>, a Belgian physician.]</ety>
<fld>(Zool.)</fld> <def>A genus of bivalve shells of which one species
(<spn>Dreissena polymorpha</spn>) is often so abundant as to be very
troublesome in the fresh waters of Europe.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drench</ent><br/
<hw>Drench</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Drenched</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Drenching</conjf>.]</vmorph> <ety>[AS.
<ets>drencan</ets> to give to drink, to drench, the causal of
<ets>drincan</ets> to drink; akin to D. <ets>drenken</ets>, Sw.
<ets>dr<aum/nka</ets>, G. <ets>tr<aum/nken</ets>. See
<er>Drink</er>.]</ety> <sn>1.</sn> <def>To cause to drink; especially,
to dose by force; to put a potion down the throat of, as of a horse;
hence. to purge violently by physic.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>As <ldquo/to fell,<rdquo/ is <ldquo/to make to fall,<rdquo/ and
<ldquo/to lay,<rdquo/ to make to lie.<rdquo/ so <ldquo/to
<qex>drench</qex>,<rdquo/ is <ldquo/to make to drink.<rdquo/</q>
<rj><qau>Trench.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To steep in moisture; to wet thoroughly; to soak; to
saturate with water or other liquid; to immerse.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Now dam the ditches and the floods restrain;<br/
Their moisture has already <qex>drenched</qex> the plain.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drench</ent><br/
<hw>Drench</hw>, <pos>n.</pos> <ety>[AS. <ets>drenc</ets>. See
<er>Drench</er>, <pos>v. t.</pos>]</ety> <def>A drink; a draught;
specifically, a potion of medicine poured or forced down the throat;
also, a potion that causes purging.</def> <ldquo/A <xex>drench</xex> of
wine.<rdquo/ <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Give my roan horse a <qex>drench</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drench</ent><br/
<hw>Drench</hw>, <pos>n.</pos> <ety>[AS. <ets>dreng</ets> warrior,
soldier, akin to Icel. <ets>drengr</ets>.]</ety> <fld>(O. Eng.
Law)</fld> <def>A military vassal mentioned in Domesday Book.</def>
<mark>[Obs.]</mark> <rj><au>Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drenche</ent><br/
<hw>Drench"e</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <def>To
drown.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>In the sea he <qex>drenched</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drencher</ent><br/
<hw>Drench"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who,
or that which, west or steeps.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who administers a drench.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drengage</ent><br/
<hw>Dren"gage</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(O. Eng. Law)</fld>
<def>The tenure by which a drench held land.</def> <mark>[Obs.]</mark>
<rj><au>Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drent</ent><br/
<hw>Drent</hw> <pr>(?)</pr>, <pos>p. p.</pos> <ety>[See
<er>Dreinte</er>.]</ety> <def>Drenched; drowned.</def>
<mark>[Obs.]</mark> <ldquo/Condemned to be <xex>drent</xex>.<rdquo/
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dresden ware</ent><br/
<hw>Dres"den ware`</hw> <pr>(?)</pr>. <def>A superior kind of decorated
porcelain made near Dresden in Saxony.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dress</ent><br/
<hw>Dress</hw> <pr>(dr<ecr/s)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Dressed</conjf> <pr>(dr<ecr/st)</pr> or
<conjf>Drest</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Dressing</conjf>.]</vmorph> <ety>[OF. <ets>drecier</ets> to make
straight, raise, set up, prepare, arrange, F. <ets>dresser</ets>,
(assumed) LL. <ets>directiare</ets>, fr. L. <ets>dirigere</ets>,
<ets>directum</ets>, to direct; <ets>dis-</ets> + <ets>regere</ets> to
rule. See <er>Right</er>, and cf. <er>Address</er>, <er>Adroit</er>,
<er>Direct</er>, <er>Dirge</er>.]</ety> <sn>1.</sn> <def>To direct; to
put right or straight; to regulate; to order.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>At all times thou shalt bless God and pray Him to <qex>dress</qex>
thy ways.</q> <rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Dress</xex> is used reflexively in Old English, in
sense of <ldquo/to direct one's step; to address one's
self.<rdquo/</note><br/
[<source>1913 Webster</source>]</p>

<p><q>To Grisild again will I me <qex>dresse</qex>.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mil.)</fld> <def>To arrange in exact continuity of
line, as soldiers; commonly to adjust to a straight line and at proper
distance; to align; <as>as, to <ex>dress</ex> the ranks</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Med.)</fld> <def>To treat methodically with
remedies, bandages, or curative appliances, as a sore, an ulcer, a
wound, or a wounded or diseased part.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To adjust; to put in good order; to arrange;
specifically: <sd>(a)</sd> To prepare for use; to fit for any use; to
render suitable for an intended purpose; to get ready; <as>as, to
<ex>dress</ex> a slain animal; to <ex>dress</ex> meat; to <ex>dress</ex>
leather or cloth; to <ex>dress</ex> or trim a lamp; to <ex>dress</ex> a
garden; to <ex>dress</ex> a horse, by currying and rubbing; to
<ex>dress</ex> grain, by cleansing it; in mining and metallurgy, to
<ex>dress</ex> ores, by sorting and separating them.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 454 --></p>

<p><q>And the Lord God took the man, and put him into the garden of Eden
to <qex>dress</qex> it.</q> <rj><qau>Gen. ii. 15.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>When he <qex>dresseth</qex> the lamps he shall burn incense.</q>
<rj><qau>Ex. xxx. 7.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Three hundred horses . . . smoothly <qex>dressed</qex>.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Dressing</qex> their hair with the white sea flower.</q>
<rj><qau>Tennyson</qau></rj>.<br/
[<source>1913 Webster</source>]</p>

<p><q>If he felt obliged to expostulate, he might have
<qex>dressed</qex> his censures in a kinder form.</q>
<rj><qau>Carlyle.</qau></rj></p>

<p><sd>(b)</sd> <def>To cut to proper dimensions, or give proper shape
to, as to a tool by hammering; also, to smooth or finish.</def></p>

<p><sd>(c)</sd> <def>To put in proper condition by appareling, as the
body; to put clothes upon; to apparel; to invest with garments or rich
decorations; to clothe; to deck.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Dressed</qex> myself in such humility.</q> <rj><qau>
Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Prove that ever I<qex>dress</qex> myself handsome till thy
return.</q> <rj><qau>Shak.</qau></rj></p>

<p><sd>(d)</sd> <def>To break and train for use, as a horse or other
animal.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>To dress up</b></col> <it>or</it> <col><b>To dress
out</b></col></mcol>, <cd>to dress elaborately, artificially, or
pompously.</cd> <ldquo/You see very often a king of England or France
<xex>dressed up</xex> like a Julius C<ae/sar.<rdquo/ <au>Addison.</au>
-- <col><b>To dress a ship</b></col> <fld>(Naut.)</fld>, <cd>to ornament
her by hoisting the national colors at the peak and mastheads, and
setting the jack forward; when dressed <xex>full</xex>, the signal flags
and pennants are added.</cd> <au>Ham. Nav. Encyc.</au></cs></p>

<p><syn><b>Syn.</b> -- To attire; apparel; clothe; accouter; array;
robe; rig; trim; deck; adorn; embellish.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dress</ent><br/
<hw>Dress</hw>, <pos>v. i.</pos> <sn>1.</sn> <fld>(Mil.)</fld> <def>To
arrange one's self in due position in a line of soldiers; -- the word of
command to form alignment in ranks; <as>as, Dress right,
<ex>dress</ex>!</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To clothe or apparel one's self; to put on one's
garments; to pay particular regard to dress; <as>as, to <ex>dress</ex>
quickly</as>.</def> <ldquo/To <xex>dress</xex> for a ball.<rdquo/
<rj><au>Latham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To flaunt, to <qex>dress</qex>, to dance, to thrum.</q>
<rj><qau>Tennyson</qau></rj>.<br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>To dress to the right</b></col>, <col><b>To dress
to the left</b></col>, <col><b>To dress on the center</b></col></mcol>
<fld>(Mil.)</fld>, <cd>to form alignment with reference to the soldier
on the extreme right, or in the center, of the rank, who serves as a
guide.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dress</ent><br/
<hw>Dress</hw>, <pos>n.</pos> <sn>1.</sn> <def>That which is used as the
covering or ornament of the body; clothes; garments; habit;
apparel.</def> <ldquo/In your soldier's <xex>dress</xex>.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A lady's gown; <as>as, silk or a velvet
<ex>dress</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Attention to apparel, or skill in adjusting
it.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Men of pleasure, <qex>dress</qex>, and gallantry.</q> <rj><qau>
Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Milling)</fld> <def>The system of furrows on the
face of a millstone.</def> <rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dress parade</b></col> <fld>(Mil.)</fld>, <cd>a parade in
full uniform for review.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>dressage</ent><br/
<hw>dressage</hw> <pos>n.</pos> <def>maneuvers of a horse in response to
body signals by the rider.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dress circle</ent><br/
<hw>Dress circle</hw>. <def>A gallery or balcony in a theater, generally
the first above the floor, in which originally dress clothes were
customarily worn.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Dress coat</ent><br/
<hw>Dress" coat`</hw> <pr>(?)</pr>. <def>A coat with skirts behind only,
as distinct from the frock coat, of which the skirts surround the body.
It is worn on occasions of ceremony. The dress coat of officers of the
United States army is a full-skirted frock coat.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>dressed</ent><br/
<hw>dressed</hw> <pos>adj.</pos> <sn>1.</sn> <def>same as
<er>attired</er>.</def><br/
<syn><b>Syn. --</b> appareled, attired, clad, garbed, garmented,
habilimented, robed.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>covered with medication or a bandage ; -- of
wounds.</def><br/
<syn><b>Syn. --</b> bandaged.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><sn>3.</sn> <def>trim and smooth; -- of lumber or stone.</def><br/
<syn><b>Syn. --</b> polished.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>dressed to kill</ent><br/
<hw>dressed to kill</hw> <pos>pred. adj.</pos> <def>attired in
strikingly attractive clothing; -- usually of women.</def><br/
[<source>PJC</source>]</p>

<p><ent>dressed-up</ent><br/
<hw>dressed-up</hw> <pos>adj.</pos> <def>attired in fancy or formal
clothing.</def> [Narrower terms: <stype>dressed to
kill(predicate)</stype>]<br/
<syn><b>Syn. --</b> dressed to the nines(predicate), dolled up, spruced
up, spiffed up.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>dresser</ent><br/
<hw>dress"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who
dresses; one who put in order or makes ready for use; one who on clothes
or ornaments.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mining)</fld> <def>A kind of pick for shaping large
coal.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>An assistant in a hospital, whose office it is to
dress wounds, sores, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <ety>[F. <ets>dressoir</ets>. See <er>Dress</er>, <pos>v.
t.</pos>]</ety> <sd>(a)</sd> <def>A table or bench on which meat and
other things are dressed, or prepared for use.</def> <sd>(b)</sd> <def>A
cupboard or set of shelves to receive dishes and cooking
utensils.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The pewter plates on the <qex>dresser</qex><br/
Caught and reflected the flame, as shields of armies the sunshine.</q>
<rj><qau> Longfellow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dresser</ent><br/
<hw>Dress"er</hw>, <pos>n.</pos> <ety>[F. <ets>dressoir</ets>. See
<er>Dress</er>, <pos>v. t.</pos>]</ety> <def>A piece of chamber
furniture consisting of a chest of drawers, or bureau, with a
mirror.</def> <mark>[U. S.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Dress goods</ent><br/
<hw>Dress" goods"</hw> <pr>(?)</pr>. <def>A term applied to fabrics for
the gowns of women and girls; -- most commonly to fabrics of mixed
materials, but also applicable to silks, printed linens, and
calicoes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dressiness</ent><br/
<hw>Dress"i*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state of
being dressy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dressing</ent><br/
<hw>Dress"ing</hw>, <pos>n.</pos> <sn>1.</sn> <def>Dress; raiment;
especially, ornamental habiliment or attire.</def> <rj><au>B.
Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Surg.)</fld> <def>An application (a remedy,
bandage, etc.) to cover a sore or wound.</def>
<rj><au>Wiseman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Manure or compost over land. When it remains on the
surface, it is called a <xex>top-dressing</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Cookery)</fld> <sd>(a)</sd> <def>A preparation,
such as a sauce, to flavor food for eating; a condiment; <as>as, a
<ex>dressing</ex> for salad</as>.</def> <sd>(b)</sd> <def>The stuffing
of fowls, pigs, etc.; forcemeat.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Gum, starch, and the like, used in stiffening or
finishing silk, linen, and other fabrics.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>An ornamental finish, as a molding around doors,
windows, or on a ceiling, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>Castigation; scolding; -- often with
<ptcl>down</ptcl>.</def> <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dressing case</b></col>, <cd>a case of toilet
utensils.</cd> -- <col><b>Dressing forceps</b></col>, <cd>a variety of
forceps, shaped like a pair of scissors, used in dressing wounds.</cd>
-- <col><b>Dressing gown</b></col>, <cd>a light gown, such as is used by
a person while dressing; a study gown.</cd> -- <col><b>Dressing
room</b></col>, <cd>an apartment appropriated for making one's
toilet.</cd> -- <col><b>Top-dressing</b></col>, <cd>manure or compost
spread over land and not worked into the soil.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dressing table</ent><br/
<hw>Dressing table</hw>, <pos>n.</pos> <def>a table, usually having a
vertical back piece containing a mirror, at which a person may sit while
dressing or applying makeup, and on which articles for the toilet stand.
It often has drawers for toiletries, clothing, or accessories. It is
also called a <altname>vanity</altname> or <altname>vanity
table</altname>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Dressmaker</ent><br/
<hw>Dress"mak`er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A maker of gowns,
or similar garments; a mantuamaker.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dressmaking</ent><br/
<hw>Dress"mak`ing</hw>, <pos>n.</pos> <def>The art, process, or
occupation, of making dresses.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dressy</ent><br/
<hw>Dress"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Showy in dress;
attentive to dress.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>dressy</qex> flaunting maidservant.</q> <rj><qau>T.
Hook.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A neat, <qex>dressy</qex> gentleman in black.</q> <rj><qau>W.
Irving.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drest</ent><br/
<hw>Drest</hw> <pr>(?)</pr>, <pos>p. p.</pos> <def>of
<er>Dress</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dretch</ent><br/
<hw>Dretch</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <def>See
<er>Drecche</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dreul</ent><br/
<hw>Dreul</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To drool.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drevil</ent><br/
<hw>Drev"il</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A fool; a drudge. See
<er>Drivel</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drew</ent><br/
<hw>Drew</hw> <pr>(?)</pr>, <pos>imp.</pos> <def>of
<er>Draw</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drey</ent><br/
<hw>Drey</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A squirrel's nest. See
<er>Dray</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dreye</ent><br/
<hw>Dreye</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Dry.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dreynt</ent><br/
<ent>Dreynte</ent><br/
<hw>Dreyn"te</hw> <pr>(?)</pr>, <wordforms><pos>imp.</pos>,
<hw>Dreynt</hw> <pr>(<?/)</pr></wordforms>, <def><pos>p. p.</pos>, of
<er>Drench</er> to drown.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drib</ent><br/
<hw>Drib</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Dribbed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Dribbing</conjf>.]</vmorph> <ety>[Cf. <er>Drip</er>.]</ety>
<def>To do by little and little</def>; as: <sd>(a)</sd> <def>To cut off
by a little at a time; to crop.</def> <sd>(b)</sd> <def>To appropriate
unlawfully; to filch; to defalcate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He who drives their bargain <qex>dribs</qex> a part.</q>
<rj><qau>Dryden.</qau></rj></p>

<p><sd>(c)</sd> <def>To lead along step by step; to entice.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With daily lies she <qex>dribs</qex> thee into cost.</q> <rj><qau>
Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drib</ent><br/
<hw>Drib</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <fld>(Archery)</fld>
<def>To shoot (a shaft) so as to pierce on the descent.</def>
<mark>[Obs.]</mark> <rj><au>Sir P. Sidney.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drib</ent><br/
<hw>Drib</hw>, <pos>n.</pos> <sn>1.</sn> <def>A drop.</def>
<mark>[Obs.]</mark> <rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>a small portion or small amount of anything; -- used
mostly in the phrase <xex>dribs and drabs</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dribber</ent><br/
<hw>Drib"ber</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who dribs; one
who shoots weakly or badly.</def> <mark>[Obs.]</mark>
<rj><au>Ascham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dribble</ent><br/
<hw>Drib"ble</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Dribbled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Dribbing</conjf> <pr>(?)</pr>.]</vmorph> <ety>[Freq. of
<ets>drib</ets>, which is a variant of <ets>drip</ets>.]</ety>
<sn>1.</sn> <def>To fall in drops or small drops, or in a quick
succession of drops; <as>as, water <ex>dribbles</ex> from the
eaves</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To slaver, as a child or an idiot; to
drivel.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To fall weakly and slowly.</def> <mark>[Obs.]</mark>
<ldquo/The <xex>dribbling</xex> dart of love.<rdquo/ <au>Shak. (Meas.
for Meas. , i. 3, 2).</au> <altsp>[Perhaps an error for
<asp>dribbing</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>In basketball, football and similar games, to
dribble{2} the ball.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>5.</sn> <def>To live or pass one's time in a trivial
fashion.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Dribble</ent><br/
<hw>Drib"ble</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To let fall in
drops.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Let the cook . . . <qex>dribble</qex> it all the way upstairs.</q>
<rj><qau> Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>In basketball and various other games, to propel
(the ball) by successive slight hits or kicks so as to keep it always in
control.</def><-- also in basketball. double dribble --><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Dribble</ent><br/
<hw>Drib"ble</hw>, <pos>n.</pos> <sn>1.</sn> <def>A drizzling shower; a
falling or leaking in drops.</def> <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An act of dribbling{2} a ball.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Dribbler</ent><br/
<hw>Drib"bler</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who
dribbles.</def></p>

<p><ent>Driblet</ent><br/
<ent>Dribblet</ent><br/
<mhw>{ <hw>Drib"blet</hw> <pr>(?)</pr>, <hw>Drib"let</hw> <pr>(?)</pr>,
}</mhw> <pos>n.</pos> <ety>[From <er>Dribble</er>.]</ety> <def>A small
piece or part; a small sum; a small quantity of money in making up a
sum; <as>as, the money was paid in <ex>dribblets</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>When made up in <qex>dribblets</qex>, as they could, their best
securities were at an interest of twelve per cent.</q>
<rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drie</ent><br/
<hw>Drie</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[See
<er>Dree</er>.]</ety> <def>To endure.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>So causeless such drede for to <qex>drie</qex>.</q> <rj><qau>
Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dried</ent><br/
<hw>Dried</hw> <pr>(dr<imac/d)</pr>, <def><pos>imp. & p. p.</pos> of
<er>Dry</er>. Also <pos>adj.</pos>; <as>as, <ex>dried</ex>
apples</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>dried-out</ent><br/
<hw>dried-out</hw> <pos>adj.</pos> <def>thoroughly dried; having no
moisture remaining.</def><br/
<syn><b>Syn. --</b> dehydrated, desiccated.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>dried-up</ent><br/
<hw>dried-up</hw> <pos>adj.</pos> <def>wrinkled or cracked from
drying.</def><br/
<syn><b>Syn. --</b> sere, sear, shriveled, withered.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>having its water supply exhausted.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Drier</ent><br/
<hw>Dri"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who, or
that which, dries; that which may expel or absorb moisture; a
desiccative; <as>as, the sun and a northwesterly wind are great
<ex>driers</ex> of the earth</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Paint.)</fld> <def>Drying oil; a substance mingled
with the oil used in oil painting to make it dry quickly.</def></p>

<p><ent>Driest</ent><br/
<ent>Drier</ent><br/
<mhw><hw>Dri"er</hw>, <pos>compar.</pos>, <hw>Dri"est</hw>,
<pos>superl.</pos></mhw>, <def>of <er>Dry</er>, <pos>a.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drift</ent><br/
<hw>Drift</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From <er>drive</er>;
akin to LG. & D. <ets>drift</ets> a driving, Icel. <ets>drift</ets>
snowdrift, Dan. <ets>drift</ets>, impulse, drove, herd, pasture, common,
G. <ets>trift</ets> pasturage, drove. See <er>Drive</er>.]</ety>
<sn>1.</sn> <def>A driving; a violent movement.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The dragon drew him [self] away with <qex>drift</qex> of his
wings.</q> <rj><qau>King Alisaunder (1332).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The act or motion of drifting; the force which
impels or drives; an overpowering influence or impulse.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A bad man, being under the <qex>drift</qex> of any passion, will
follow the impulse of it till something interpose.</q>
<rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Course or direction along which anything is driven;
setting.</def> <ldquo/Our <xex>drift</xex> was south.<rdquo/
<rj><au>Hakluyt.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The tendency of an act, argument, course of conduct,
or the like; object aimed at or intended; intention; hence, also, import
or meaning of a sentence or discourse; aim.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He has made the <qex>drift</qex> of the whole poem a compliment on
his country in general.</q> <rj><qau> Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Now thou knowest my <qex>drift</qex>.</q> <rj><qau>Sir W.
Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>That which is driven, forced, or urged along</def>;
as: <sd>(a)</sd> <def>Anything driven at random.</def> <ldquo/Some log .
. . a useless <xex>drift</xex>.<rdquo/ <au>Dryden.</au> <sd>(b)</sd>
<def>A mass of matter which has been driven or forced onward together in
a body, or thrown together in a heap, etc., esp. by wind or water;
<as>as, a <ex>drift</ex> of snow, of ice, of sand, and the
like</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Drifts</qex> of rising dust involve the sky.</q> <rj><qau>
Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>We got the brig a good bed in the rushing <qex>drift</qex> [of
ice].</q> <rj><qau>Kane.</qau></rj></p>

<p><sd>(c)</sd> <def>A drove or flock, as of cattle, sheep, birds.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Cattle coming over the bridge (with their great <qex>drift</qex>
doing much damage to the high ways).</q> <rj><qau>
Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Arch.)</fld> <def>The horizontal thrust or pressure
of an arch or vault upon the abutments.</def> <mark>[R.]</mark>
<rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Geol.)</fld> <def>A collection of loose earth and
rocks, or boulders, which have been distributed over large portions of
the earth's surface, especially in latitudes north of forty degrees, by
the agency of ice.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>In South Africa, a ford in a river.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <fld>(Mech.)</fld> <def>A slightly tapered tool of steel
for enlarging or shaping a hole in metal, by being forced or driven into
or through it; a broach.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>10.</sn> <fld>(Mil.)</fld> <sd>(a)</sd> <def>A tool used in
driving down compactly the composition contained in a rocket, or like
firework.</def> <sd>(b)</sd> <def>A deviation from the line of fire,
peculiar to oblong projectiles.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>11.</sn> <fld>(Mining)</fld> <def>A passage driven or cut between
shaft and shaft; a driftway; a small subterranean gallery; an adit or
tunnel.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>12.</sn> <fld>(Naut.)</fld> <sd>(a)</sd> <def>The distance
through which a current flows in a given time.</def> <sd>(b)</sd>
<def>The angle which the line of a ship's motion makes with the
meridian, in drifting.</def> <sd>(c)</sd> <def>The distance to which a
vessel is carried off from her desired course by the wind, currents, or
other causes.</def> <sd>(d)</sd> <def>The place in a deep-waisted vessel
where the sheer is raised and the rail is cut off, and usually
terminated with a scroll, or driftpiece.</def> <sd>(e)</sd> <def>The
distance between the two blocks of a tackle.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>13.</sn> <def>The difference between the size of a bolt and the
hole into which it is driven, or between the circumference of a hoop and
that of the mast on which it is to be driven.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>14.</sn> <fld>(Phys. Geog.)</fld> <def>One of the slower
movements of oceanic circulation; a general tendency of the water,
subject to occasional or frequent diversion or reversal by the wind;
<as>as, the easterly <ex>drift</ex> of the North Pacific</as>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>15.</sn> <fld>(A<eum/ronautics)</fld> <def>The horizontal
component of the pressure of the air on the sustaining surfaces of a
flying machine. The <xex>lift</xex> is the corresponding vertical
component, which sustains the machine in the air.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><note><hand/ <xex>Drift</xex> is used also either adjectively or as
the first part of a compound. See <er>Drift</er>,
<pos>a.</pos></note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Drift of the forest</b></col> <fld>(O. Eng. Law)</fld>,
<cd>an examination or view of the cattle in a forest, in order to see
whose they are, whether they are commonable, and to determine whether or
not the forest is surcharged.</cd> <au>Burrill.</au> [<source>1913
Webster</source>] -- <col><b>continental drift</b></col>
<fld>(Geology)</fld>, <cd>the very slow (ca. 1-5 cm per year) movement
of the continents and parts of continents relative to each other and to
the points of upwelling of magma in the viscous layers beneath the
continents; -- causing, for example, the opening of the South Atlantic
Ocean by the movement of Africa and South America away from each other.
See also <er>plate tectonics</er>.</cd><br/
[<source>PJC</source>]</cs></p>

<p><ent>Drift</ent><br/
<hw>Drift</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Drifted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Drifting</conjf>.]</vmorph> <sn>1.</sn> <def>To float or be
driven along by, or as by, a current of water or air; <as>as, the ship
<ex>drifted</ex> astern; a raft <ex>drifted</ex> ashore; the balloon
<ex>drifts</ex> slowly east.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>We <qex>drifted</qex> o'er the harbor bar.</q> <rj><qau>
Coleridge.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To accumulate in heaps by the force of wind; to be
driven into heaps; <as>as, snow or sand <ex>drifts</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(mining)</fld> <def>to make a drift; to examine a
vein or ledge for the purpose of ascertaining the presence of metals or
ores; to follow a vein; to prospect.</def> <mark>[U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drift</ent><br/
<hw>Drift</hw> <pr>(?)</pr>, <pos>v. t.</pos> <sn>1.</sn> <def>To drive
or carry, as currents do a floating body.</def> <rj><au>J. H.
Newman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To drive into heaps; <as>as, a current of wind
<ex>drifts</ex> snow or sand</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Mach.)</fld> <def>To enlarge or shape, as a hole,
with a drift.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drift</ent><br/
<hw>Drift</hw>, <pos>a.</pos> <def>That causes drifting or that is
drifted; movable by wind or currents; <as>as, <ex>drift</ex> currents;
<ex>drift</ex> ice; <ex>drift</ex> mud.</as></def>
<rj><au>Kane.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Drift anchor</b></col>. <cd>See <er>Sea anchor</er>, and
also <cref>Drag sail</cref>, under <er>Drag</er>, <pos>n.</pos></cd> --
<col><b>Drift epoch</b></col> <fld>(Geol.)</fld>, <cd>the glacial
epoch.</cd> -- <col><b>Drift net</b></col>, <cd>a kind of fishing
net.</cd> -- <col><b>Drift sail</b></col>. <cd>Same as <cref>Drag
sail</cref>. See under <er>Drag</er>, <pos>n.</pos></cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Driftage</ent><br/
<hw>Drift"age</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>Deviation from a ship's course due to leeway.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Anything that drifts.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Driftbolt</ent><br/
<hw>Drift"bolt`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A bolt for driving
out other bolts.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Driftless</ent><br/
<hw>Drift"less</hw>, <pos>a.</pos> <def>Having no drift or direction;
without aim; purposeless.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Driftpiece</ent><br/
<hw>Drift"piece"</hw> <pr>(?)</pr>, <pos>n.</pos>
<fld>(Shipbuilding)</fld> <def>An upright or curved piece of timber
connecting the plank sheer with the gunwale; also, a scroll terminating
a rail.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Driftpin</ent><br/
<hw>Drift"pin`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Mech.)</fld>
<def>A smooth drift. See <er>Drift</er>, <pos>n.</pos>, 9.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Driftway</ent><br/
<hw>Drift"way`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A
common way, road, or path, for driving cattle.</def> <rj><au>Cowell.
Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mining)</fld> <def>Same as <er>Drift</er>,
<er>11</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Driftweed</ent><br/
<hw>Drift"weed`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Seaweed drifted to
the shore by the wind.</def> <rj><au>Darwin.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Driftwind</ent><br/
<hw>Drift"wind`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A driving wind; a
wind that drives snow, sand, etc., into heaps.</def> <rj><au>Beau. &
Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Driftwood</ent><br/
<hw>Drift"wood`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>Wood
drifted or floated by water.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Fig.: Whatever is drifting or floating as on
water.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The current of humanity, with its heavy proportion of very useless
<qex>driftwood</qex>.</q> <rj><qau> New Your Times.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drifty</ent><br/
<hw>Drift"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Full of drifts;
tending to form drifts, as snow, and the like.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drill</ent><br/
<hw>Drill</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Drilled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Drilling</conjf>.]</vmorph> <ety>[D. <ets>drillen</ets> to bore,
drill (soldiers); probably akin to AS. <ets>pyrlian</ets>,
<ets>pyrelian</ets>, to pierce. See <er>Thrill</er>.]</ety> <sn>1.</sn>
<def>To pierce or bore with a drill, or a with a drill; to perforate;
<as>as, to <ex>drill</ex> a hole into a rock; to <ex>drill</ex> a piece
of metal.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To train in the military art; to exercise
diligently, as soldiers, in military evolutions and exercises; hence, to
instruct thoroughly in the rudiments of any art or branch of knowledge;
to discipline.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He [Frederic the Great] <qex>drilled</qex> his people, as he
<qex>drilled</qex> his grenadiers.</q> <rj><qau>
Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drill</ent><br/
<hw>Drill</hw>, <pos>v. i.</pos> <def>To practice an exercise or
exercises; to train one's self.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drill</ent><br/
<hw>Drill</hw>, <pos>n.</pos> <sn>1.</sn> <def>An instrument with an
edged or pointed end used for making holes in hard substances; strictly,
a tool that cuts with its end, by revolving, as in drilling metals, or
by a succession of blows, as in drilling stone; also, a drill
press.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mil.)</fld> <def>The act or exercise of training
soldiers in the military art, as in the manual of arms, in the execution
of evolutions, and the like; hence, diligent and strict instruction and
exercise in the rudiments and methods of any business; a kind or method
of military exercises; <as>as, infantry <ex>drill</ex>; battalion
<ex>drill</ex>; artillery <ex>drill</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Any exercise, physical or mental, enforced with
regularity and by constant repetition; <as>as, a severe <ex>drill</ex>
in Latin grammar</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Zool.)</fld> <def>A marine gastropod, of several
species, which kills oysters and other bivalves by drilling holes
through the shell. The most destructive kind is <spn>Urosalpinx
cinerea</spn>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Bow drill</b></col>, <col><b>Breast
drill</b></col></mcol>. <cd>See under <er>Bow</er>,
<er>Breast</er>.</cd> -- <mcol><col><b>Cotter drill</b></col>,
<it>or</it> <col><b>Traverse drill</b></col></mcol>, <cd>a machine tool
for drilling slots.</cd> -- <col><b>Diamond drill</b></col>. <cd>See
under <er>Diamond</er>.</cd> -- <col><b>Drill jig</b></col>. <cd>See
under <er>Jig</er>.</cd> -- <col><b>Drill pin</b></col>, <cd>the pin in
a lock which enters the hollow stem of the key.</cd> -- <col><b>Drill
sergeant</b></col> <fld>(Mil.)</fld>, <cd>a noncommissioned officer
whose office it is to instruct soldiers as to their duties, and to train
them to military exercises and evolutions.</cd> -- <col><b>Vertical
drill</b></col>, <cd>a drill press.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drill</ent><br/
<hw>Drill</hw>, <pos>v. t.</pos> <ety>[Cf. <er>Trill</er> to trickle,
<er>Trickle</er>, <er>Dribble</er>, and W. <ets>rhillio</ets> to put in
a row, drill.]</ety> <sn>1.</sn> <def>To cause to flow in drills or
rills or by trickling; to drain by trickling; <as>as, waters
<ex>drilled</ex> through a sandy stratum</as>.</def> <mark>[R.]</mark>
<rj><au>Thomson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To sow, as seeds, by dribbling them along a furrow
or in a row, like a trickling rill of water.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To entice; to allure from step; to decoy; -- with
<xex>on</xex>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>See <qex>drilled</qex> him on to five-fifty.</q> <rj><qau>
Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To cause to slip or waste away by degrees.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q> This accident hath <qex>drilled</qex> away the whole summer.</q>
<rj><qau> Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drill</ent><br/
<hw>Drill</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To trickle.</def>
<mark>[Obs. or R.]</mark> <rj><au>Sandys.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To sow in drills.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drill</ent><br/
<hw>Drill</hw>, <pos>n.</pos> <sn>1.</sn> <def>A small trickling stream;
a rill.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Springs through the pleasant meadows pour their
<qex>drills</qex>.</q> <rj><qau>Sandys.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Agr.)</fld> <sd>(a)</sd> <def>An implement for
making holes for sowing seed, and sometimes so formed as to contain
seeds and drop them into the hole made.</def> <sd>(b)</sd> <def>A light
furrow or channel made to put seed into sowing.</def> <sd>(c)</sd>
<def>A row of seed sown in a furrow.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 455 --></p>

<p><note><hand/ <xex>Drill</xex> is used adjectively, or as the first
part of a compound; as, <xex>drill</xex> barrow or
<xex>drill</xex>-barrow; <xex>drill</xex> husbandry; <xex>drill</xex>
plow or <xex>drill</xex>-plow.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Drill barrow</b></col>, <cd>a wheeled implement for
planting seed in drills.</cd> -- <col><b>Drill bow</b></col>, <cd>a
small bow used for the purpose of rapidly turning a drill around which
the bowstring takes a turn.</cd> -- <col><b>Drill harrow</b></col>,
<cd>a harrow used for stirring the ground between rows, or drills.</cd>
-- <mcol><col><b>Drill plow</b></col>, <it>or</it> <col><b>Drill
plough</b></col></mcol>, <cd>a sort plow for sowing grain in
drills.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drill</ent><br/
<hw>Drill</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf.
<er>Mandrill</er>.]</ety> <fld>(Zool.)</fld> <def>A large African baboon
(<spn>Cynocephalus leucoph<ae/us</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drill</ent><br/
<hw>Drill</hw>, <pos>n.</pos> <ety>[Usually in <ets>pl</ets>.]</ety>
<fld>(Manuf.)</fld> <def>Same as <er>Drilling</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Imperial drill</b></col>, <cd>a linen fabric having two
threads in the warp and three in the filling.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Driller</ent><br/
<hw>Drill"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, drills.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drilling</ent><br/
<hw>Drill"ing</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act of piercing
with a drill.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A training by repeated exercises.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drilling</ent><br/
<hw>Drill"ing</hw>, <pos>n.</pos> <def>The act of using a drill in
sowing seeds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drilling</ent><br/
<hw>Drill"ing</hw>, <pos>n.</pos> <ety>[G. <ets>drillich</ets>, fr. L.
<ets>trilix</ets> having three threads, fr. the of <ets>tres</ets> three
+ <ets>licium</ets> a thread of the warm. See <er>Three</er>, and cf.
<er>Twill</er>.]</ety> <fld>(Manuf.)</fld> <def>A heavy, twilled fabric
of linen or cotton.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drillmaster</ent><br/
<hw>Drill"mas`ter</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who teaches
drill, especially in the way of gymnastics.</def>
<rj><au>Macaulay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drill press</ent><br/
<hw>Drill" press`</hw> . <def>A machine for drilling holes in metal, the
drill being pressed to the metal by the action of a screw.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drillstock</ent><br/
<hw>Drill"stock`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Mech.)</fld>
<def>A contrivance for holding and turning a drill.</def>
<rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drily</ent><br/
<hw>Dri"ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>See
<er>Dryly</er>.</def> <rj><au>Thackeray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drimys</ent><br/
\'d8<hw>Dri"mys</hw> <pr>(dr<imac/"m<icr/s)</pr>, <pos>n.</pos>
<ety>[NL., fr. Gr. <grk>drimy`s</grk> sharp, acrid.]</ety>
<fld>(Bot.)</fld> <def>A genus of magnoliaceous trees. <spn>Drimys
aromatica</spn> furnishes Winter's bark.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drink</ent><br/
<hw>Drink</hw> <pr>(dr<icr/<nsm/k)</pr>, <pos>v. i.</pos>
<vmorph>[<pos>imp.</pos> <conjf>Drank</conjf> <pr>(dr<acr/<nsm/k)</pr>,
formerly <conjf>Drunk</conjf> <pr>(dr<ucr/<nsm/k)</pr>; & <pos>p.
p.</pos> <conjf>Drunk</conjf>, <conjf>Drunken</conjf> <pr>(-'n)</pr>;
<pos>p. pr. & vb. n.</pos> <conjf>Drinking</conjf>. <xex>Drunken</xex>
is now rarely used, except as a verbal adj. in sense of <xex>habitually
intoxicated</xex>; the form <xex>drank</xex>, not infrequently used as a
p. p., is not so analogical.]</vmorph> <ety>[AS. <ets>drincan</ets>;
akin to OS. <ets>drinkan</ets>, D. <ets>drinken</ets>, G.
<ets>trinken</ets>, Icel. <ets>drekka</ets>, Sw. <ets>dricka</ets>, Dan.
<ets>drikke</ets>, Goth. <ets>drigkan</ets>. Cf. <er>Drench</er>,
<er>Drunken</er>, <er>Drown</er>.]</ety> <sn>1.</sn> <def>To swallow
anything liquid, for quenching thirst or other purpose; to imbibe; to
receive or partake of, as if in satisfaction of thirst; <as>as, to
<ex>drink</ex> from a spring</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Gird thyself, and serve me, till have eaten and
<qex>drunken</qex>; and afterward thou shalt eat and
<qex>drink</qex>.</q> <rj><qau>Luke xvii. 8.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He shall <qex>drink</qex> of the wrath the Almighty.</q>
<rj><qau>Job xxi. 20.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Drink</qex> of the cup that can not cloy.</q>
<rj><qau>Keble.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To quaff exhilarating or intoxicating liquors, in
merriment or feasting; to carouse; to revel; hence, to lake alcoholic
liquors to excess; to be intemperate in the use of intoxicating or
spirituous liquors; to tipple.</def> <rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And they <qex>drank</qex>, and were merry with him.</q>
<rj><qau>Gem. xliii. 34.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Bolingbroke always spoke freely when he had <qex>drunk</qex>
freely.</q> <rj><qau>Thackeray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To drink to</b></col>, <cd>to salute in drinking; to wish
well to, in the act of taking the cup; to pledge in
drinking.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><q>I <qex>drink to</qex> the general joy of the whole table,<br/
And to our dear friend Banquo.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drink</ent><br/
<hw>Drink</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To swallow (a liquid);
to receive, as a fluid, into the stomach; to imbibe; <as>as, to
<ex>drink</ex> milk or water</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There lies she with the blessed gods in bliss,<br/
There <qex>drinks</qex> the nectar with ambrosia mixed.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The bowl of punch which was brewed and <qex>drunk</qex> in Mrs.
Betty's room.</q> <rj><qau>Thackeray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To take in (a liquid), in any manner; to suck up; to
absorb; to imbibe.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And let the purple violets <qex>drink</qex> the stream.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To take in; to receive within one, through the
senses; to inhale; to hear; to see.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>drink</qex> the cooler air,</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>My ears have not yet <qex>drunk</qex> a hundred words<br/
Of that tongue's utterance.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Let me . . . <qex>drink</qex> delicious poison from thy eye.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To smoke, as tobacco.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>And some men now live ninety years and past,<br/
Who never <qex>drank</qex> to tobacco first nor last.</q>
<rj><qau>Taylor (1630.)</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To drink down</b></col>, <cd>to act on by drinking; to
reduce or subdue; <as>as, to <ex>drink down</ex> unkindness</as>.</cd>
<au>Shak.</au> -- <col><b>To drink in</b></col>, <cd>to take into one's
self by drinking, or as by drinking; to receive and appropriate as in
satisfaction of thirst.</cd> <ldquo/Song was the form of literature
which he [Burns] had <xex>drunk in</xex> from his cradle.<rdquo/ <au>J.
C. Shairp.</au> -- <mcol><col><b>To drink off</b></col> <it>or</it>
<col><b>To drink up</b></col></mcol>, <cd>to drink completely,
especially at one draught; <as>as, to <ex>drink off</ex> a cup of
cordial.</as></cd> -- <mcol><col><b>To drink the health of</b></col>,
<it>or</it> <col><b>To drink to the health of</b></col></mcol>, <cd>to
drink while expressing good wishes for the health or welfare
of.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drink</ent><br/
<hw>Drink</hw>, <pos>n.</pos> <sn>1.</sn> <def>Liquid to be swallowed;
any fluid to be taken into the stomach for quenching thirst or for other
purposes, as water, coffee, or decoctions.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Give me some <qex>drink</qex>, Titinius.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Specifically, intoxicating liquor; <as>as, when
<ex>drink</ex> is on, wit is out</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Drink money</b></col>, <it>or</it> <col><b>Drink
penny</b></col></mcol>, <cd>an allowance, or perquisite, given to buy
drink; a gratuity.</cd> -- <col><b>Drink offering</b></col>
<fld>(Script.)</fld>, <cd>an offering of wine, etc., in the Jewish
religious service.</cd> -- <col><b>In drink</b></col>, <cd>drunk.</cd>
<ldquo/The poor monster's <xex>in drink</xex>.<rdquo/ <au>Shak.</au> --
<col><b>Strong drink</b></col>, <cd>intoxicating liquor; esp., liquor
containing a large proportion of alcohol.</cd> <ldquo/ Wine is a mocker,
<xex>strong drink</xex> is raging.<rdquo/ <rj><qau>Prov. xx.
1.</qau></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drinkable</ent><br/
<hw>Drink"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of being
drunk; suitable for drink; potable. <au>Macaulay.</au> Also used
substantively, esp. in the plural.</def> <rj><au>Steele.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drinkableness</ent><br/
<hw>Drink"a*ble*ness</hw>, <pos>n.</pos> <def>State of being
drinkable.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drinker</ent><br/
<hw>Drink"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who drinks;
<as>as, the effects of tea on the <ex>drinker</ex></as>; also, one who
drinks spirituous liquors to excess; a drunkard.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Drinker moth</b></col> <fld>(Zool.)</fld>, <cd>a large
British moth (<spn>Odonestis potatoria</spn>).</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drinking</ent><br/
<hw>Drink"ing</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act of one who
drinks; the act of imbibing.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The practice of partaking to excess of intoxicating
liquors.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>An entertainment with liquors; a carousal.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Drinking</xex> is used adjectively, or as the first
part of a compound; as, a <xex>drinking</xex> song, <xex>drinking</xex>
cup, <xex>drinking</xex> glass, <xex>drinking</xex> house,
etc.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Drinking horn</b></col>, <cd>a drinking vessel made of a
horn.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drinkless</ent><br/
<hw>Drink"less</hw>, <pos>a.</pos> <def>Destitute of drink.</def>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drip</ent><br/
<hw>Drip</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Dripped</conjf> <pr>(?)</pr> or <conjf>Dript</conjf>;
<pos>p. pr. & vb. n.</pos> <conjf>Dripping</conjf>.]</vmorph> <ety>[Akin
to LG. <ets>drippen</ets>, Dan. <ets>dryppe</ets>, from a noun. See
<er>Drop</er>.]</ety> <sn>1.</sn> <def>To fall in drops; <as>as, water
<ex>drips</ex> from the eaves</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To let fall drops of moisture or liquid; <as>as, a
wet garment <ex>drips</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The dark round of the <qex>dripping</qex> wheel.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drip</ent><br/
<hw>Drip</hw>, <pos>v. t.</pos> <def>To let fall in drops.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Which from the thatch <qex>drips</qex> fast a shower of rain.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drip</ent><br/
<hw>Drip</hw>, <pos>n.</pos> <sn>1.</sn> <def>A falling or letting fall
in drops; a dripping; that which drips, or falls in drops.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The light <qex>drip</qex> of the suspended oar.</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Arch.)</fld> <def>That part of a cornice, sill
course, or other horizontal member, which projects beyond the rest, and
is of such section as to throw off the rain water.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Right of drip</b></col> <fld>(Law)</fld>, <cd>an easement
or servitude by which a man has the right to have the water flowing from
his house fall on the land of his neighbor.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>drip-dry</ent><br/
<hw>drip-dry</hw> <pos>adj.</pos> <sn>1.</sn> <def>treated so as to be
easily or quickly washed and dried and requiring little or no ironing;
-- of clothing.</def><br/
<syn><b>Syn. --</b> wash-and-wear.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>requiring no ironing; -- used of fabrics and
clothing; <as>as, <ex>drip-dry</ex> shirts for travel</as>.</def><br/
<syn><b>Syn. --</b> permanent-press.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Dripping</ent><br/
<hw>Drip"ping</hw>, <pos>n.</pos> <sn>1.</sn> <def>A falling in drops,
or the sound so made.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which falls in drops, as fat from meat in
roasting.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dripping pan</b></col>, <cd>a pan for receiving the fat
which drips from meat in roasting.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dripple</ent><br/
<hw>Drip"ple</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From <er>Drip</er>,
cf. <er>Dribble</er>.]</ety> <def>Weak or rare.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>drippy</ent><br/
<hw>drippy</hw> <pos>adj.</pos> <def>persistently dripping even when
shut; <as>as, a <ex>drippy</ex> faucet</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dripstone</ent><br/
<hw>Drip"stone`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Arch.)</fld>
<def>A drip, when made of stone. See <er>Drip</er>, 2.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drive</ent><br/
<hw>Drive</hw> <pr>(dr<imac/v)</pr>, <pos>v. t.</pos>
<vmorph>[<pos>imp.</pos> <conjf>Drove</conjf> <pr>(dr<omac/v)</pr>,
formerly <conjf>Drave</conjf> (dr<amac/v); <pos>p. p.</pos>
<conjf>Driven</conjf> <pr>(dr<icr/v'n)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Driving</conjf>.]</vmorph> <ety>[AS. <ets>dr<imac/fan</ets>; akin
to OS. <ets>dr<imac/ban</ets>, D. <ets>drijven</ets>, OHG.
<ets>tr<imac/ban</ets>, G. <ets>treiben</ets>, Icel.
<ets>dr<imac/fa</ets>, Goth. <ets>dreiban</ets>. Cf. <er>Drift</er>,
<er>Drove</er>.]</ety> <sn>1.</sn> <def>To impel or urge onward by force
in a direction away from one, or along before one; to push forward; to
compel to move on; to communicate motion to; <as>as, to <ex>drive</ex>
cattle; to <ex>drive</ex> a nail; smoke <ex>drives</ex> persons from a
room.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>A storm came on and <qex>drove</qex> them into Pylos.</q>
<rj><qau>Jowett (Thucyd. ).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Shield pressed on shield, and man <qex>drove</qex> man along.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Go <qex>drive</qex> the deer and drag the finny prey.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To urge on and direct the motions of, as the beasts
which draw a vehicle, or the vehicle borne by them; hence, also, to take
in a carriage; to convey in a vehicle drawn by beasts; <as>as, to
<ex>drive</ex> a pair of horses or a stage; to <ex>drive</ex> a person
to his own door.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>How . . . proud he was to <qex>drive</qex> such a brother!</q>
<rj><qau>Thackeray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To urge, impel, or hurry forward; to force; to
constrain; to urge, press, or bring to a point or state; <as>as, to
<ex>drive</ex> a person by necessity, by persuasion, by force of
circumstances, by argument, and the like</as>.</def> <ldquo/ Enough to
<xex>drive</xex> one mad.<rdquo/ <rj><au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He, <qex>driven</qex> to dismount, threatened, if I did not do the
like, to do as much for my horse as fortune had done for his.</q>
<rj><qau>Sir P. Sidney.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To carry or; to keep in motion; to conduct; to
prosecute.</def> <mark>[Now used only colloquially.]</mark>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The trade of life can not be <qex>driven</qex> without
partners.</q> <rj><qau>Collier.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To clear, by forcing away what is
contained.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>drive</qex> the country, force the swains away.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Mining)</fld> <def>To dig Horizontally; to cut a
horizontal gallery or tunnel.</def> <rj><au>Tomlinson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>To pass away; -- said of time.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>Specif., in various games, as tennis, baseball,
etc., to propel (the ball) swiftly by a direct stroke or forcible
throw.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>9.</sn> <def>to operate (a vehicle) while it is on motion, by
manipulating the controls, such as the steering, propulsion, and braking
mechanisms.</def><br/
[<source>PJC</source>]</p>

<p><ent>Drive</ent><br/
<hw>Drive</hw>, <pos>n.</pos> <sn>1.</sn> <def>In various games, as
tennis, cricket, etc., the act of player who drives the ball; the stroke
or blow; the flight of the ball, etc., so driven.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <fld>(Golf)</fld> <def>A stroke from the tee, generally a
full shot made with a driver; also, the distance covered by such a
stroke.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><note><hand/ <xex>Drive</xex>, in all its senses, implies forcible or
violent action. It is the reverse of to <xex>lead</xex>. To
<xex>drive</xex> a body is to move it by applying a force behind; to
<xex>lead</xex> is to cause to move by applying the force before, or in
front. It takes a variety of meanings, according to the objects by which
it is followed; as, <xex>to drive an engine</xex>, to direct and
regulate its motions; <xex>to drive logs</xex>, to keep them in the
current of a river and direct them in their course; <xex>to drive
feathers</xex> or <xex>down</xex>, to place them in a machine, which, by
a current of air, <xex>drives</xex> off the lightest to one end, and
collects them by themselves. <ldquo/My thrice-<xex>driven</xex> bed of
down.<rdquo/</note> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drive</ent><br/
<hw>Drive</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To rush and press with
violence; to move furiously.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Fierce Boreas <qex>drove</qex> against his flying sails.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Under cover of the night and a <qex>driving</qex> tempest.</q>
<rj><qau>Prescott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Time <qex>driveth</qex> onward fast,<br/
And in a little while our lips are dumb.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To be forced along; to be impelled; to be moved by
any physical force or agent; to be driven.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The hull <qex>drives</qex> on, though mast and sail be torn.</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The chaise <qex>drives</qex> to Mr. Draper's chambers.</q>
<rj><qau>Thackeray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To go by carriage; to pass in a carriage; to proceed
by directing or urging on a vehicle or the animals that draw it; <as>as,
the coachman <ex>drove</ex> to my door</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To press forward; to aim, or tend, to a point; to
make an effort; to strive; -- usually with <xex>at</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Let them therefore declare what carnal or secular interest he
<qex>drove</qex> at.</q> <rj><qau>South.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To distrain for rent.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Golf)</fld> <def>To make a drive, or stroke from
the tee.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>7.</sn> <def>to go from one place to another in a vehicle,
serving as the operator of the vehicle; to drive{9} a vehicle from one
location to another.</def> <illu>He <ex>drove</ex> from New York to
Boston in four hours.</illu><br/
[<source>PJC</source>]</p>

<p><cs><col><b>To let drive</b></col>, <cd>to aim a blow; to strike with
force; to attack.</cd> <ldquo/Four rogues in buckram <xex>let
drive</xex> at me.<rdquo/ <rj><au>Shak.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drive</ent><br/
<hw>Drive</hw> <pr>(dr<imac/v)</pr>, <pos>p. p.</pos> <def>Driven.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drive</ent><br/
<hw>Drive</hw> <pr>(dr<imac/v)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
act of driving; a trip or an excursion in a carriage, as for exercise or
pleasure; -- distinguished from a ride taken on horseback.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A place suitable or agreeable for driving; a road
prepared for driving.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Violent or rapid motion; a rushing onward or away;
esp., a forced or hurried dispatch of business.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The Murdstonian <qex>drive</qex> in business.</q> <rj><qau>M.
Arnold.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>In type founding and forging, an impression or
matrix, formed by a punch drift.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A collection of objects that are driven; a mass of
logs to be floated down a river.</def> <mark>[Colloq.]</mark></p>

<p><syn><b>Syn.</b> -- See <er>Ride</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>a private road; a driveway.</def><br/
[<source>PJC</source>]</p>

<p><sn>7.</sn> <def>a strong psychological motivation to perform some
activity.</def><br/
[<source>PJC</source>]</p>

<p><sn>8.</sn> <fld>(Computers)</fld> <def>a device for reading or
writing data from or to a data storage medium, as a <stype>disk
drive</stype>, a <stype>tape drive</stype>, a <stype>CD drive</stype>,
etc.</def><br/
[<source>PJC</source>]</p>

<p><sn>9.</sn> <def>an organized effort by a group to accomplish a goal
within a limited period of time; <as>as, a fund-raising
<ex>drive</ex></as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>10.</sn> <def>a physiological function of an organism motivating
it to perform specific behaviors; <as>as, the sex
<ex>drive</ex></as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>11.</sn> <fld>(Football)</fld> <def>the period during which one
team sustains movement of the ball toward the opponent's goal without
losing possession of the ball; <as>as, a long <ex>drive</ex>
downfield</as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>12.</sn> <def>an act of driving a vehicle, especially an
automobile; the journey undertaken by driving an automobile; <as>as, to
go for a <ex>drive</ex> in the country.</as></def><br/
[<source>PJC</source>]</p>

<p><sn>13.</sn> <def>the mechanism which causes the moving parts of a
machine to move; <as>as, a belt <ex>drive</ex></as>.</def><br/
[<source>PJC</source>]</p>

<p><sn>14.</sn> <def>the way in which the propulsive force of a vehicle
is transmitted to the road; <as>as, a car with four-wheel
<ex>drive</ex>, front-wheel <ex>drive</ex>, etc.</as></def><br/
[<source>PJC</source>]</p>

<p><ent>Drivebolt</ent><br/
<hw>Drive"bolt`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A drift; a tool
for setting bolts home.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>drive-by</ent><br/
<hw>drive-by</hw> <pos>n.</pos> <def>accomplished while driving past in
a vehicle; <as>as, a <ex>drive-by</ex> shooting</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>drive-in</ent><br/
<hw>drive-in</hw> <pos>n.</pos> <def>any installation designed to
accommodate patrons while staying in their automobiles; especially an
outdoor movie theater in which patrons park in their vehicles to watch
the movie.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>drive-in</ent><br/
<hw>drive-in</hw> <pos>a.</pos> <def>arranged to allow business to be
transacted while patrons remain in their vehicles; <as>as, a
<ex>drive-in</ex> window at a bank</as>.</def><br/
<syn><b>Syn. --</b> drive-through.</syn>
[<source>WordNet 1.5</source>]</p>

<p><ent>drive-in window</ent><br/
<hw>drive-in window</hw> <pos>n.</pos> <def>a window at a business
establishment, such as a bank or restaurant, where patrons may transact
business or order goods while staying in their automobiles; <as>as, to
cash a check at the <ex>drive-in window</ex> of the bank</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>driveshaft</ent><br/
<hw>driveshaft</hw> <pos>n.</pos> <def>a rotating shaft that transmits
power from the engine to the point of application.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>drive-through</ent><br/
<hw>drive-through</hw> <pos>a.</pos> <def>arranged to allow business to
be transacted or sights to be seen while patrons remain in their
vehicles; <as>as, a <ex>drive-through</ex> car wash; a
<ex>drive-through</ex> safari park</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Drivel</ent><br/
<hw>Driv"el</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Driveled</conjf> <pr>(?)</pr> or
<conjf>Drivelled</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Driveling</conjf> or <conjf>Drivelling</conjf>.]</vmorph>
<ety>[Cf. OE. <ets>dravelen</ets>, <ets>drabelen</ets>,
<ets>drevelen</ets>, <ets>drivelen</ets>, to slaver, and E.
<ets>drabble</ets>. Cf. <er>Drool</er>.]</ety> <sn>1.</sn> <def>To
slaver; to let spittle drop or flow from the mouth, like a child, idiot,
or dotard.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <ety>[Perh. a different word: cf. Icel. <ets>drafa</ets>
to talk thick.]</ety> <def>To be weak or foolish; to dote; <as>as, a
<ex>driveling</ex> hero; <ex>driveling</ex> love.</as></def>
<rj><au>Shak. Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drivel</ent><br/
<hw>Driv"el</hw>, <pos>n.</pos> <sn>1.</sn> <def>Slaver; saliva flowing
from the mouth.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Inarticulate or unmeaning utterance; foolish talk;
babble.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A driveler; a fool; an idiot.</def>
<mark>[Obs.]</mark> <rj><au>Sir P. Sidney.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A servant; a drudge.</def> <mark>[Obs.]</mark>
<rj><au>Huloet.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Driveler</ent><br/
<hw>Driv"el*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A slaverer; a
slabberer; an idiot; a fool.</def> <altsp>[Written also
<asp>driveller</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Driven</ent><br/
<hw>Driv"en</hw> <pr>(?)</pr>, <pos>p. p.</pos> <def>of <er>Drive</er>.
Also <xex>adj</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Driven well</b></col>, <cd>a well made by driving a tube
into the earth to an aqueous stratum; -- called also <altname>drive
well</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drivepipe</ent><br/
<hw>Drive"pipe`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A pipe for forcing
into the earth.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Driver</ent><br/
<hw>Driv"er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From
<er>Drive</er>.]</ety> <sn>1.</sn> <def>One who, or that which, drives;
the person or thing that urges or compels anything else to move
onward.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The person who drives beasts or a carriage; a
coachman; a charioteer, etc.; hence, also, one who controls the
movements of a any vehicle.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>3.</sn> <def>An overseer of a gang of slaves or gang of convicts
at their work.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Mach.)</fld> <def>A part that transmits motion to
another part by contact with it, or through an intermediate relatively
movable part, as a gear which drives another, or a lever which moves
another through a link, etc. Specifically:</def></p>

<p><sd>(a)</sd> <def>The driving wheel of a locomotive.</def>
<sd>(b)</sd> <def>An attachment to a lathe, spindle, or face plate to
turn a carrier.</def> <sd>(c)</sd> <def>A crossbar on a grinding mill
spindle to drive the upper stone.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Naut.)</fld> <def>The after sail in a ship or bark,
being a fore-and-aft sail attached to a gaff; a spanker.</def>
<rj><au>Totten.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>An implement used for driving;</def> as:
<sd>(a)</sd> <def>A mallet.</def> <sd>(b)</sd> <def>A tamping
iron.</def> <sd>(c)</sd> <def>A cooper's hammer for driving on barrel
hoops.</def> <sd>(d)</sd> <def>A wooden-headed golf club with a long
shaft, for playing the longest strokes.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><cs><col><b>Driver ant</b></col> <fld>(Zool.)</fld>, <cd>a species of
African stinging ant; one of the visiting ants (<spn>Anomma
arcens</spn>); -- so called because they move about in vast armies, and
drive away or devour all insects and other small animals.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Driveway</ent><br/
<hw>Drive"way`</hw> <pr>(<?/)</pr>, <pos>n.</pos> <def>A passage or way
along or through which a carriage may be driven.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Driving</ent><br/
<hw>Driv"ing</hw>, <pos>a.</pos> <sn>1.</sn> <def>Having great force of
impulse; <as>as, a <ex>driving</ex> wind or storm</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Communicating force; impelling; <as>as, a
<ex>driving</ex> shaft</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Driving axle</b></col>, <cd>the axle of a driving wheel,
as in a locomotive.</cd> -- <col><b>Driving box</b></col>
<fld>(Locomotive)</fld>, <cd>the journal box of a driving axle. See
<xex>Illust.</xex> of <er>Locomotive</er>.</cd> -- <col><b>Driving
note</b></col> <fld>(Mus.)</fld>, <cd>a syncopated note; a tone begun on
a weak part of a measure and held through the next accented part, thus
anticipating the accent and <xex>driving</xex> it through.</cd> --
<col><b>Driving spring</b></col>, <cd>a spring fixed upon the box of the
driving axle of a locomotive engine to support the weight and deaden
shocks.</cd> <mark>[Eng.]</mark> <au>Weale.</au> -- <col><b>Driving
wheel</b></col> <fld>(Mach.)</fld>, <cd>a wheel that communicates
motion; one of the large wheels of a locomotive to which the connecting
rods of the engine are attached; -- called also, simply,
<xex>driver</xex>. See <xex>Illust.</xex> of
<er>Locomotive</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Driving</ent><br/
<hw>Driv"ing</hw>, <pos>n.</pos> <sn>1.</sn> <def>The act of forcing or
urging something along; the act of pressing or moving on
furiously.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Tendency; drift.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drizzle</ent><br/
<hw>Driz"zle</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Drizzled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Drizzling</conjf> <pr>(?)</pr>.]</vmorph> <ety>[Prop.
freq. of AS. <ets>dre<oacute/san</ets> to fall. See
<er>Dreary</er>.]</ety> <def>To rain slightly in very small drops; to
fall, as water from the clouds, slowly and in fine particles; <as>as, it
<ex>drizzles</ex>; <ex>drizzling</ex> drops or rain.</as></def>
<ldquo/<xex>Drizzling</xex> tears.<rdquo/ <rj><au>Spenser.</au></rj><br/
<syn><b>Syn. --</b> mizzle, misle.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drizzle</ent><br/
<hw>Driz"zle</hw>, <pos>v. t.</pos> <def>To shed slowly in minute drops
or particles.</def> <ldquo/The air doth <xex>drizzle</xex> dew.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drizzle</ent><br/
<hw>Driz"zle</hw>, <pos>n.</pos> <def>A fine rain or mist.</def>
<rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>drizzling</ent><br/
<hw>drizzling</hw> <pos>adj.</pos> <def>raining lightly in a fine
mist.</def><br/
<syn><b>Syn. --</b> drizzly, misting, misty.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Drizzly</ent><br/
<hw>Driz"zly</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Characterized by
small rain, or snow; moist and disagreeable.</def> <ldquo/Winter's
<xex>drizzly</xex> reign.<rdquo/ <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drock</ent><br/
<hw>Drock</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A water course.</def>
<mark>[Prov. Eng.]</mark></p>

<p><ent>Dryfland</ent><br/
<ent>Drofland</ent><br/
<mhw>{ <hw>Drof"land</hw> <pr>(?)</pr>, <hw>Dryf"land</hw> <pr>(?)</pr>
}</mhw>, <pos>n.</pos> <ety>[See <er>Drove</er>.]</ety> <fld>(Law)</fld>
<def>An ancient yearly payment made by some tenants to the king, or to
their landlords, for the privilege of driving their cattle through a
manor to fairs or markets.</def> <rj><au>Cowell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drogher</ent><br/
<hw>Dro"gher</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf.
<er>Drag</er>.]</ety> <def>A small craft used in the West India Islands
to take off sugars, rum, etc., to the merchantmen; also, a vessel for
transporting lumber, cotton, etc., coastwise; <as>as, a lumber
<ex>drogher</ex></as>.</def> <altsp>[Written also
<asp>droger</asp>.]</altsp> <rj><au>Ham. Nar. Encyc.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 456 --></p>

<p><ent>Drogoman</ent><br/
<ent>Drogman</ent><br/
<mhw>{ <hw>Drog"man</hw> <pr>(?)</pr>, <hw>Drog"o*man</hw> <pr>(?)</pr>
}</mhw>, <pos>n.</pos> <def>See <er>Dragoman</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drogue</ent><br/
<hw>Drogue</hw> <pr>(dr<omac/g)</pr>, <pos>n.</pos> <sn>1.</sn>
<fld>(Naut.)</fld> <def>See <er>Drag</er>, <pos>n.</pos>, 6, and
<cref>Drag sail</cref>, under <er>Drag</er>, <pos>n.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>a small parachute dragged behind a vehicle as a
means of stabilizing it, or deployed first so as to assist opening of a
larger parachute.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <def>a funnel-shaped attachment at the end of a hose
suspended from a tanker airplane in flight, to which the probe of
another airplane may connect, so as to complete a connecting hose line
through which fuel may be transferred from the tanker to the following
airplane. It is used for in-flight refueling.</def><br/
[<source>PJC</source>]</p>

<p><ent>Droh</ent><br/
<hw>Droh</hw> <pr>(?)</pr>, <pos>imp.</pos> <def>of <er>Draw</er>.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Droil</ent><br/
<hw>Droil</hw> <pr>(droil)</pr>, <pos>v. i.</pos> <ety>[D.
<ets>druilen</ets> to mope.]</ety> <def>To work sluggishly or slowly; to
plod.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Droil</ent><br/
<hw>Droil</hw>, <pos>n.</pos> <ety>[D. <ets>druil</ets> sluggard. Cf.
<er>Droll</er>.]</ety> <sn>1.</sn> <def>A drudge.</def>
<mark>[Obs.]</mark> <rj><au>Beau. & Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Mean labor; toil.</def><mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Droit</ent><br/
<hw>Droit</hw> <pr>(droit)</pr>, <pos>n.</pos> <ety>[F. See
<er>Direct</er>.]</ety> <def>A right; law in its aspect of the
foundation of rights; also, in old law, the writ of right.</def>
<rj><au> Abbott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>\'d8Droit d'aubaine</b></col>. <cd>See under
<er>Aubaine</er>.</cd> -- <col><b>Droits of the Admiralty</b></col>
<fld>(Eng. Law)</fld>, <cd>rights or perquisites of the Admiralty,
arising from seizure of an enemy's ships in port on the breaking out of
war, or those coming into port in ignorance of hostilities existing, or
from such ships as are taken by noncommissioned captors; also, the
proceeds of wrecks, and derelict property at sea. The <xex>droits of
admiralty</xex> are now paid into the Exchequer for the public
benefit.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Droitural</ent><br/
<hw>Droi"tu*ral</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(O. Eng.
Law)</fld> <def>relating to the mere right of property, as distinguished
from the right of possession; <as>as, <ex>droitural</ex>
actions</as>.</def> <mark>[Obs.]</mark> <rj><au>Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Droitzschka</ent><br/
\'d8<hw>Droitzsch"ka</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Drosky</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Droll</ent><br/
<hw>Droll</hw> <pr>(dr<omac/l)</pr>, <pos>a.</pos>
<amorph>[<pos>Compar.</pos> <adjf>Droller</adjf> <pr>(?)</pr>;
<pos>superl.</pos> <adjf>Drollest</adjf> <pr>(?)</pr>.]</amorph>
<ety>[F. <ets>dr<ocir/le</ets>; cf. G. & D. <ets>drollig</ets>, LG.
<ets>drullig</ets>, D. <ets>drol</ets> a thick and short person, a
droll, Sw. <ets>troll</ets> a magical appearance, demon,
<ets>trolla</ets> to use magic arts, enchant, Dan. <ets>trold</ets> elf,
imp, Icel. <ets>tr<oum/ll</ets> giant, magician, evil spirit, monster.
If this is the origin, cf. <er>Trull</er>.]</ety> <def>Queer, and fitted
to provoke laughter; ludicrous from oddity; amusing and
strange.</def></p>

<p><syn><b>Syn.</b> -- Comic; comical; farcical; diverting; humorous;
ridiculous; queer; odd; waggish; facetious; merry; laughable; ludicrous.
-- <er>Droll</er>, <er>Laughable</er>, <er>Comical</er>.
<xex>Laughable</xex> is the generic term, denoting anything exciting
laughter or worthy of laughter; <xex>comical</xex> denotes something of
the kind exhibited in <xex>comedies</xex>, something humorous of the
kind exhibited in <xex>comedies</xex>, something, as it were,
dramatically <xex>humorous</xex>; <xex>droll</xex> stands lower on the
scale, having reference to persons or things which excite laughter by
their buffoonery or oddity. A <xex>laughable</xex> incident; a
<xex>comical</xex> adventure; a <xex>droll</xex> story.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Droll</ent><br/
<hw>Droll</hw>, <pos>n.</pos> <sn>1.</sn> <def>One whose practice it is
to raise mirth by odd tricks; a jester; a buffoon; a merry-andrew.</def>
<rj><au>Prior.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Something exhibited to raise mirth or sport, as a
puppet, a farce, and the like.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Droll</ent><br/
<hw>Droll</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Drolled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Drolling</conjf>.]</vmorph> <def>To jest; to play the
buffoon.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Droll</ent><br/
<hw>Droll</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To lead or influence
by jest or trick; to banter or jest; to cajole.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Men that will not be reasoned into their senses, may yet be
laughed or <qex>drolled</qex> into them.</q>
<rj><qau>L'Estrange.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To make a jest of; to set in a comical light.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>This <qex>drolling</qex> everything is rather fatiguing.</q>
<rj><qau> W. D. Howells.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Droller</ent><br/
<hw>Droll"er</hw>, <pos>n.</pos> <def>A jester; a droll.</def>
<mark>[Obs.]</mark> <rj><au>Glanvill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drollery</ent><br/
<hw>Droll"er*y</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Drolleries</plw> <pr>(#)</pr>.</plu> <ety>[F.
<ets>dr<ocir/lerie</ets>. See <er>Droll</er>.]</ety> <sn>1.</sn>
<def>The quality of being droll; sportive tricks; buffoonery; droll
stories; comical gestures or manners.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The rich <qex>drollery</qex> of <ldquo/She Stoops to
Conquer.<rdquo/</q> <rj><qau> Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Something which serves to raise mirth</def>; as:
<sd>(a)</sd> <def>A puppet show; also, a puppet.</def>
<mark>[Obs.]</mark> <au>Shak.</au> <sd>(b)</sd> <def>A lively or comic
picture.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I bought an excellent <qex>drollery</qex>, which I afterward
parted with to my brother George of Wotton.</q> <rj><qau>
Evelyn.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drollingly</ent><br/
<hw>Droll"ing*ly</hw>, <pos>adv.</pos> <def>In a jesting
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drollish</ent><br/
<hw>Droll"ish</hw>, <pos>a.</pos> <def>Somewhat droll.</def> <rj><au>
Sterne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drollist</ent><br/
<hw>Droll"ist</hw>, <pos>n.</pos> <def>A droll.</def> <mark>[R.]</mark>
<rj><au>Glanvill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dromaeognathous</ent><br/
<hw>Dro`m<ae/*og"na*thous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[NL.
<ets>dromaius</ets> emu + Gr. <grk>gna`qos</grk> jaw.]</ety>
<fld>(Zool.)</fld> <def>Having the structure of the palate like that of
the ostrich and emu.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dromatherium</ent><br/
\'d8<hw>Drom`a*the"ri*um</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <grk>droma`s</grk> running + <grk>qhri`on</grk> beast. See
<er>Dromedary</er>.]</ety> <fld>(Paleon.)</fld> <def>A small extinct
Triassic mammal from North Carolina, the earliest yet found in
America.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drome</ent><br/
<hw>Drome</hw> <pr>(dr<omac/m)</pr>, <pos>n.</pos> <ety>[F., fr. Gr.
<grk>droma`s</grk> running. See <er>Dromedary</er>.]</ety>
<fld>(Zool.)</fld> <def>The crab plover (<spn>Dromas ardeola</spn>), a
peculiar North African bird, allied to the oyster catcher.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drome</ent><br/
<hw>Drome</hw> <pr>(dr<omac/m)</pr>, <pos>n.</pos> <def>Short for
<er>A<eum/rodrome</er>.</def> <mark>[Slang]</mark></p>

<p><ent>Dromedary</ent><br/
<hw>Drom"e*da*ry</hw> <pr>(dr<ucr/m"<esl/*d<asl/*r<ycr/)</pr>,
<pos>n.</pos>; <plu><it>pl.</it> <plw>Dromedaries</plw>
<pr>(-r<icr/z)</pr>.</plu> <ety>[F. <ets>dromadaire</ets>, LL.
<ets>dromedarius</ets>, fr. L. <ets>dromas</ets> (sc.
<ets>camelus</ets>), fr. Gr. <grk>droma`s</grk> running, from
<grk>dramei^n</grk>, used as aor. of <grk>tre`chein</grk> to run; cf.
Skr. <ets>dram</ets> to run.]</ety> <fld>(Zool.)</fld> <def>The Arabian
camel (<spn>Camelus dromedarius</spn>), having one hump or protuberance
on the back, in distinction from the <contr>Bactrian camel</contr>,
which has two humps.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In Arabia and Egypt the name is restricted to the better
breeds of this species of camel. See <er>Deloul</er>.</note></p>

<p><ent>Dromon</ent><br/
<ent>Dromond</ent><br/
<mhw>{ <hw>Drom"ond</hw> <pr>(?)</pr>, <it>or</it> <hw>Drom"on</hw>
<pr>(?)</pr> }</mhw>. <ety>[OF. <ets>dromont</ets>, L. <ets>dromo</ets>,
fr. Gr. <grk>dro`mwn</grk> light vessel, prob. fr. <grk>dramei^n</grk>
to run. See <er>Dromedary</er>.]</ety> <def>In the Middle Ages, a large,
fast-sailing galley, or cutter; a large, swift war vessel.</def>
<mark>[Hist. or Archaic]</mark> <rj><au>Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The great <qex>dromond</qex> swinging from the quay.</q> <rj><qau>
W. Morris.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drone</ent><br/
<hw>Drone</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>drane</ets> a
dronebee, AS. <ets>dr<amac/n</ets>; akin to OS. <ets>dr<amac/n</ets>,
OHG. <ets>treno</ets>, G. <ets>drohne</ets>, Dan. <ets>drone</ets>, cf.
Gr. <?/ a kind of wasp, dial. Gr. <?/ drone. Prob. named fr. the droning
sound. See <er>Drone</er>, <pos>v. i.</pos>]</ety> <sn>1.</sn>
<fld>(Zool.)</fld> <def>The male of bees, esp. of the honeybee. It
gathers no honey. See <er>Honeybee</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>All with united force combine to drive<br/
The lazy <qex>drones</qex> from the laborious hive.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who lives on the labors of others; a lazy, idle
fellow; a sluggard.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>By living as a <qex>drone</qex>,to be an unprofitable and unworthy
member of so noble and learned a society.</q> <rj><qau>
Burton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which gives out a grave or monotonous tone or
dull sound; as: <sd>(a)</sd> A drum. <mark>[Obs.]</mark>
<xex>Halliwell</xex>. <sd>(b)</sd> The part of the bagpipe containing
the two lowest tubes, which always sound the key note and the
fifth.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A humming or deep murmuring sound.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The monotonous <qex>drone</qex> of the wheel.</q>
<rj><qau>Longfellow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Mus.)</fld> <def>A monotonous bass, as in a
pastoral composition.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drone</ent><br/
<hw>Drone</hw> <pr>(dr<omac/n)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Droned</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Droning</conjf>.]</vmorph> <ety>[Cf. (for sense 1) D.
<ets>dreunen</ets>, G. <ets>dr<oum/hnen</ets>, Icel. <ets>drynja</ets>
to roar, <ets>drynr</ets> a roaring, Sw. <ets>dr<oum/na</ets> to bellow,
drone, Dan. <ets>dr<oum/ne</ets>, Goth. <ets>drunjus</ets> sound, Gr.
<?/ dirge, <?/ to cry aloud, Skr. <ets>dhran</ets> to sound. Cf.
<er>Drone</er>, <pos>n.</pos>]</ety> <sn>1.</sn> <def>To utter or make a
low, dull, monotonous, humming or murmuring sound.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Where the beetle wheels his <qex>droning</qex> flight.</q>
<rj><qau>T. Gray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To love in idleness; to do nothing.</def>
<ldquo/Race of <xex>droning</xex> kings.<rdquo/
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drone bee</ent><br/
<hw>Drone" bee`</hw> <pr>(?)</pr>. <fld>(Zool.)</fld> <def>The male of
the honeybee; a drone.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drone fly</ent><br/
<hw>Drone" fly`</hw> <pr>(?)</pr>. <fld>(Zool.)</fld> <def>A dipterous
insect (<spn>Eristalis tenax</spn>), resembling the drone bee. See
<er>Eristalis</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dronepipe</ent><br/
<hw>Drone"pipe`</hw>, <pos>n.</pos> <def>One of the low-toned tubes of a
bagpipe.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drongo</ent><br/
<hw>Dron"go</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Drongos</plw> <pr>(<?/)</pr>.</plu> <fld>(Zool.)</fld> <def>A
passerine bird of the family <fam>Dicrurid<ae/</fam>. They are usually
black with a deeply forked tail. They are natives of Asia, Africa, and
Australia; -- called also <altname>drongo shrikes</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dronish</ent><br/
<hw>Dron"ish</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Like a drone;
indolent; slow.</def> <au>Burke.</au> --
<wordforms><wf>Dron"ish*ly</wf>, <pos>adv.</pos> --
<wf>Dron"ish*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dronkelewe</ent><br/
<hw>Dron"ke*lewe</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Drink</er>.]</ety> <def>Given to drink; drunken.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dronte</ent><br/
<hw>Dron"te</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.]</ety>
<fld>(Zool.)</fld> <def>The dodo.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drony</ent><br/
<hw>Dron"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Like a drone; sluggish;
lazy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drool</ent><br/
<hw>Drool</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Drooled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Drooling</conjf>.]</vmorph> <ety>[Contr. fr.
<ets>drivel</ets>.]</ety> <def>To drivel, or drop saliva; <as>as, the
child <ex>drools</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His mouth <qex>drooling</qex> with texts.</q> <rj><qau> T.
Parker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Droop</ent><br/
<hw>Droop</hw> <pr>(dr<oomac/p)</pr>, <pos>v. i.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Drooped</conjf> <pr>(?)</pr>;
<pos>p. pr. & vb. n.</pos> <conjf>Drooping</conjf>.]</vmorph>
<ety>[Icel. <ets>dr<umac/pa</ets>; akin to E. <ets>drop</ets>. See
<er>Drop</er>.]</ety> <sn>1.</sn> <def>To hang bending downward; to sink
or hang down, as an animal, plant, etc., from physical inability or
exhaustion, want of nourishment, or the like.</def> <ldquo/The purple
flowers <xex>droop</xex>.<rdquo/ <ldquo/Above her <xex>drooped</xex> a
lamp.<rdquo/ <rj><au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I saw him ten days before he died, and observed he began very much
to <qex>droop</qex> and languish.</q> <rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To grow weak or faint with disappointment, grief, or
like causes; to be dispirited or depressed; to languish; <as>as, her
spirits <ex>drooped</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I'll animate the soldier's <qex>drooping</qex> courage.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To proceed downward, or toward a close; to
decline.</def> <ldquo/Then day <xex>drooped</xex>.<rdquo/
<rj><au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Droop</ent><br/
<hw>Droop</hw>, <pos>v. t.</pos> <def>To let droop or sink.</def>
<mark>[R.]</mark> <rj><au>M. Arnold.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Like to a withered vine<br/
That <qex>droops</qex> his sapless branches to the ground.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Droop</ent><br/
<hw>Droop</hw>, <pos>n.</pos> <def>A drooping; <as>as, a <ex>droop</ex>
of the eye</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drooper</ent><br/
<hw>Droop"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, droops.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Droopingly</ent><br/
<hw>Droop"ing*ly</hw>, <pos>adv.</pos> <def>In a drooping
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>droopy</ent><br/
<hw>droopy</hw> <pos>adj.</pos> <def>bending downward due to lack of
tautness; -- of lines.</def><br/
<syn><b>Syn. --</b> drooping, sagging, slack.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Drop</ent><br/
<hw>Drop</hw> <pr>(dr<ocr/p)</pr>, <pos>n.</pos> <ety>[OE.
<ets>drope</ets>, AS. <ets>dropa</ets>; akin to OS. <ets>dropo</ets>, D.
<ets>drop</ets>, OHG. <ets>tropo</ets>, G. <ets>tropfen</ets>, Icel.
<ets>dropi</ets>, Sw. <ets>droppe</ets>; and Fr. AS.
<ets>dre<oacute/pan</ets> to drip, drop; akin to OS. <ets>driopan</ets>,
D. <ets>druipen</ets>, OHG. <ets>triofan</ets>, G. <ets>triefen</ets>,
Icel. <ets>drj<umac/pa</ets>. Cf. <er>Drip</er>, <er>Droop</er>.]</ety>
<sn>1.</sn> <def>The quantity of fluid which falls in one small
spherical mass; a liquid globule; a minim; hence, also, the smallest
easily measured portion of a fluid; a small quantity; <as>as, a
<ex>drop</ex> of water</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With minute <qex>drops</qex> from off the eaves.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>As dear to me as are the ruddy <qex>drops</qex><br/
That visit my sad heart.</q> <rj><qau> Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>That <qex>drop</qex> of peace divine.</q>
<rj><qau>Keble.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>That which resembles, or that which hangs like, a
liquid drop; as a hanging diamond ornament, an earring, a glass pendant
on a chandelier, a sugarplum (sometimes medicated), or a kind of shot or
slug.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Arch.)</fld> <sd>(a)</sd> <def>Same as
<er>Gutta</er>.</def> <sd>(b)</sd> <def>Any small pendent
ornament.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Whatever is arranged to drop, hang, or fall from an
elevated position; also, a contrivance for lowering something</def>; as:
<sd>(a)</sd> <def>A door or platform opening downward; a trap door; that
part of the gallows on which a culprit stands when he is to be hanged;
hence, the gallows itself.</def> <sd>(b)</sd> <def>A machine for
lowering heavy weights, as packages, coal wagons, etc., to a ship's
deck.</def> <sd>(c)</sd> <def>A contrivance for temporarily lowering a
gas jet.</def> <sd>(d)</sd> <def>A curtain which drops or falls in front
of the stage of a theater, etc.</def> <sd>(e)</sd> <def>A drop press or
drop hammer.</def> <sd>(f)</sd> <fld>(Mach.)</fld> <def>The distance of
the axis of a shaft below the base of a hanger.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <pluf>pl.</pluf> <def>Any medicine the dose of which is
measured by drops; <as>as, lavender <ex>drops</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Naut.)</fld> <def>The depth of a square sail; --
generally applied to the courses only.</def> <rj><au>Ham. Nav.
Encyc.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>Act of dropping; sudden fall or descent.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Ague drop</b></col>, <col><b>Black
drop</b></col></mcol>. <cd>See under <er>Ague</er>, <er>Black</er>.</cd>
-- <col><b>Drop by drop</b></col>, <cd>in small successive quantities;
in repeated portions.</cd> <ldquo/Made to taste <xex>drop by drop</xex>
more than the bitterness of death.<rdquo/ <au>Burke.</au> --
<col><b>Drop curtain</b></col>. <cd>See <er>Drop</er>, <pos>n.</pos>, 4.
<sd>(d)</sd>.</cd> -- <col><b>Drop forging</b></col>. <fld>(Mech.)</fld>
<sd>(a)</sd> <cd>A forging made in dies by a drop hammer.</cd>
<sd>(b)</sd> <cd>The process of making drop forgings.</cd> --
<col><b>Drop hammer</b></col> <fld>(Mech.)</fld>, <cd>a hammer for
forging, striking up metal, etc., the weight being raised by a strap or
similar device, and then released to drop on the metal resting on an
anvil or die.</cd> -- <col><b>Drop kick</b></col> <fld>(Football)</fld>,
<cd>a kick given to the ball as it rebounds after having been dropped
from the hands.</cd> -- <col><b>Drop lake</b></col>, <cd>a pigment
obtained from Brazil wood.</cd> <au>Mollett.</au> -- <col><b>Drop
letter</b></col>, <cd>a letter to be delivered from the same office
where posted.</cd> -- <col><b>Drop press</b></col> <fld>(Mech.)</fld>,
<cd>a drop hammer; sometimes, a dead-stroke hammer; -- also called
<xex>drop</xex>.</cd> -- <col><b>Drop scene</b></col>, <cd>a drop
curtain on which a scene is painted. See <er>Drop</er>, <pos>n.</pos>,
4. <sd>(d)</sd>.</cd> -- <col><b>Drop seed</b></col>. <fld>(Bot.)</fld>
<cd>See the List under <er>Glass</er>.</cd> -- <col><b>Drop
serene</b></col>. <fld>(Med.)</fld> <cd>See
<er>Amaurosis</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drop</ent><br/
<hw>Drop</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Dropped</conjf> <pr>(?)</pr> or <conjf>Dropt</conjf>;
<pos>p. pr. & vb. n.</pos> <conjf>Dropping</conjf>.]</vmorph> <ety>[OE.
<ets>droppen</ets>, AS. <ets>dropan</ets>, v. i. See <er>Drop</er>,
<pos>n.</pos>]</ety> <sn>1.</sn> <def>To pour or let fall in drops; to
pour in small globules; to distill.</def> <ldquo/The trees
<xex>drop</xex> balsam.<rdquo/ <rj><au>Creech.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The recording angel, as he wrote it down, <qex>dropped</qex> a
tear upon the word and blotted it out forever.</q>
<rj><qau>Sterne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To cause to fall in one portion, or by one motion,
like a drop; to let fall; <as>as, to <ex>drop</ex> a line in fishing; to
<ex>drop</ex> a courtesy.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To let go; to dismiss; to set aside; to have done
with; to discontinue; to forsake; to give up; to omit.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They suddenly <qex>drop't</qex> the pursuit.</q> <rj><qau>S.
Sharp.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>That astonishing ease with which fine ladies <qex>drop</qex> you
and pick you up again.</q> <rj><qau>Thackeray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The connection had been <qex>dropped</qex> many years.</q>
<rj><qau> Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Dropping</qex> the too rough H in Hell and Heaven.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To bestow or communicate by a suggestion; to let
fall in an indirect, cautious, or gentle manner; <as>as, to
<ex>drop</ex> hint, a word of counsel, etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To lower, as a curtain, or the muzzle of a gun,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To send, as a letter; <as>as, please <ex>drop</ex>
me a line, a letter, word</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>To give birth to; <as>as, to <ex>drop</ex> a
lamb</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>To cover with drops; to variegate; to
bedrop.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Show to the sun their waved coats <qex>dropped</qex> with
gold.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To drop a vessel</b></col> <fld>(Naut.)</fld>, <cd>to
leave it astern in a race or a chase; to outsail it.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drop</ent><br/
<hw>Drop</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To fall in
drops.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The kindly dew <qex>drops</qex> from the higher tree,<br/
And wets the little plants that lowly dwell.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To fall, in general, literally or figuratively;
<as>as, ripe fruit <ex>drops</ex> from a tree; wise words <ex>drop</ex>
from the lips.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Mutilations of which the meaning has <qex>dropped</qex> out of
memory.</q> <rj><qau>H. Spencer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>When the sound of <qex>dropping</qex> nuts is heard.</q>
<rj><qau>Bryant.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To let drops fall; to discharge itself in
drops.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The heavens . . . <qex>dropped</qex> at the presence of God.</q>
<rj><qau>Ps. lxviii. 8.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To fall dead, or to fall in death; <as>as,
<ex>dropping</ex> like flies</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Nothing, says Seneca, so soon reconciles us to the thoughts of our
own death, as the prospect of one friend after another
<qex>dropping</qex> round us.</q> <rj><qau>Digby.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To come to an end; to cease; to pass out of mind;
<as>as, the affair <ex>dropped</ex></as>.</def>
<rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To come unexpectedly; -- with <xex>in</xex> or
<xex>into</xex>; <as>as, my old friend <ex>dropped</ex> in a
moment</as>.</def> <rj><au>Steele.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Takes care to <qex>drop</qex> in when he thinks you are just
seated.</q> <rj><qau>Spectator.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>To fall or be depressed; to lower; <as>as, the point
of the spear <ex>dropped</ex> a little</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>To fall short of a mark.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Often it <qex>drops</qex> or overshoots by the disproportion of
distance.</q> <rj><qau>Collier.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>9.</sn> <def>To be deep in extent; to descend perpendicularly;
<as>as, her main topsail <ex>drops</ex> seventeen yards</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To drop astern</b></col> <fld>(Naut.)</fld>, <cd>to go
astern of another vessel; to be left behind; to slacken the speed of a
vessel so as to fall behind and to let another pass a head.</cd> --
<col><b>To drop down</b></col> <fld>(Naut.)</fld>, <cd>to sail, row, or
move down a river, or toward the sea.</cd> -- <col><b>To drop
off</b></col>, <cd>to fall asleep gently; also, to die.</cd>
<mark>[Colloq.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>drop cloth</ent><br/
<hw>drop" cloth`</hw> <pos>n.</pos> <def>a sheet of material used to
cover objects or surfaces while painting a ceiling or wall of a house,
so as to protect objects from being marred by drops of paint splashed
inadvertently in the painting process. Originally such <ex>drop
cloths</ex> were made of cloth, but more recently paper or plastic have
also commonly been used.</def><br/
[<source>PJC</source>]</p>

<p><ent>drop forge</ent><br/
<hw>drop forge</hw> <pos>n.</pos> <def>a device for making large
forgings, in which a heavy hammer drops onto the metalwork to be forged,
pressing it into a form or anvil underneath, or between dies.</def><br/
<syn><b>Syn. --</b> drop hammer, drop press.</syn>
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>dropforge</ent><br/
<hw>dropforge</hw> <pos>v. t.</pos> <def>to forge with a drop forge; --
of metals.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>dropkick</ent><br/
<hw>dropkick</hw> <pos>n.</pos> <def>an act of kicking a football (as
for a field goal) in which the football is dropped and kicked as it
touches the ground.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>dropkicker</ent><br/
<hw>dropkicker</hw> <pos>n.</pos> <def>a football kicker who drops the
ball and kicks it just as it reaches the ground.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>droplet</ent><br/
<hw>drop"let</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A little drop; a
tear.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>droplight</ent><br/
<hw>drop"light`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An electric or gas
light suspended from the ceiling by a flexible cord or tube, allowing
artificial light to be brought down from a chandelier nearer to a table
or desk; a pendant; also, an electric light bulb in a small holder,
which can be held in the hand or hung from a hook, and attached to a
long electric cord, allowing light to be brought close to work in dark
areas of a room.</def></p>

<p><ent>Dropmele</ent><br/
<ent>Dropmeal</ent><br/
<mhw>{ <hw>Drop"meal`</hw>, <hw>Drop"mele`</hw> }</mhw> <pr>(?)</pr>,
<pos>adv.</pos> <ety>[AS. <ets>drop-m<aemac/lum</ets>; <ets>dropa</ets>
drop + <ets>m<aemac/l</ets> portion. Cf. <er>Piecemeal</er>.]</ety>
<def>By drops or small portions.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Distilling <qex>dropmeal</qex>, a little at once.</q>
<rj><qau>Holland.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>drop-off</ent><br/
<hw>drop-off</hw> <pos>n.</pos> <sn>1.</sn> <def>a noticeable decline in
performance; <as>as, a <ex>drop-off</ex> in attendance</as>.</def>
<wns>[wns=1]</wns> <-- WNOTE: = 3? --><br/
<syn><b>Syn. --</b> slump, falloff, falling off.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>a steep high face of rock.</def><br/
<syn><b>Syn. --</b> cliff.</syn> <wns>[wns=2]</wns><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>3.</sn> <def>a change downward; <as>as, there was a sharp
drop-off in sales</as>.</def> <wns>[wns=3]</wns> <-- WNOTE: = 1? --><br/
<syn><b>Syn. --</b> decrease, lessening.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>dropped</ent><br/
<hw>dropped</hw> <pos>adj.</pos> <def>born; -- used of an animal.
Opposite of <ant>unborn</ant>.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>dropper</ent><br/
<hw>drop"per</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who,
or that which, drops.</def> <specif>Specif.:</specif>
<fld>(Fishing)</fld> <def>A fly that drops from the leader above the bob
or end fly.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A dropping tube, usually of glass or plastic with a
narrow opening at the tip and a rubber bulb at the top which can be
squeezed to control intake or outflow of the fluid. The word is used in
combinations with obvious significance, as <stype>eye dropper</stype>,
<stype>medicine dropper</stype>, etc.</def><br/
<syn><b>Syn. --</b> eye dropper.</syn>
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>3.</sn> <fld>(Mining)</fld> <def>A branch vein which drops off
from, or leaves, the main lode.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Zool.)</fld> <def>A dog which suddenly drops upon
the ground when it sights game, -- formerly a common, and still an
occasional, habit of the setter.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dropping</ent><br/
<hw>Drop"ping</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
action of causing to drop or of letting drop; falling.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <pluf>pl.</pluf> <def>That which falls in drops; the
excrement or dung of animals; -- often used in the plural.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dropping bottle</b></col>, <cd>an instrument used to
supply small quantities of a fluid to a test tube or other vessel.</cd>
-- <col><b>Dropping fire</b></col>, <cd>a continued irregular discharge
of firearms.</cd> -- <col><b>Dropping tube</b></col>, <cd>a tube for
ejecting any liquid in drops.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>droppings</ent><br/
<hw>droppings</hw> <pos>n. pl.</pos> <def>fecal matter of animals;
plural of <er>dropping{2}</er>.</def><br/
<syn><b>Syn. --</b> dung, muck.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Droppingly</ent><br/
<hw>Drop"ping*ly</hw>, <pos>adv.</pos> <def>In drops.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dropsical</ent><br/
<hw>Drop"si*cal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From
<er>Dropsy</er>.]</ety> <sn>1.</sn> <def>Diseased with dropsy;
hydropical; tending to dropsy; <as>as, a <ex>dropsical</ex>
patient</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of or pertaining to dropsy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dropsicalness</ent><br/
<hw>Drop"si*cal*ness</hw>, <pos>n.</pos> <def>State of being
dropsical.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dropsied</ent><br/
<hw>Drop"sied</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Diseased with
drops.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dropsy</ent><br/
<hw>Drop"sy</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Dropsies</plw> <pr>(#)</pr>.</plu> <ety>[OE. <ets>dropsie</ets>,
<ets>dropesie</ets>, OF. <ets>idropisie</ets>, F. <ets>hydropisie</ets>,
L. <ets>hydropisis</ets>, fr. Gr. <?/ dropsy, fr. <?/ water. See
<er>Water</er>, and cf. <er>Hydropsy</er>.]</ety> <fld>(Med.)</fld>
<def>An unnatural collection of serous fluid in any serous cavity of the
body, or in the subcutaneous cellular tissue.</def>
<rj><au>Dunglison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dropt</ent><br/
<hw>Dropt</hw> <pr>(?)</pr>, <def><pos>imp. & p. p.</pos> of
<er>Drop</er>, <pos>v.</pos></def> <rj><au>G. Eliot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dropwise</ent><br/
<hw>Drop"wise`</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>After the manner
of a drop; in the form of drops.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Trickling <qex>dropwise</qex> from the cleft.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 457 --></p>

<p><ent>Dropworm</ent><br/
<hw>Drop"worm`</hw> <pr>(dr<ocr/p"w<ucir/rm`)</pr>, <pos>n.</pos>
<fld>(Zool.)</fld> <def>The larva of any geometrid moth, which drops
from trees by means of a thread of silk, as the
<stype>cankerworm</stype> or <stype>inchworm</stype>. See
<er>inchworm</er> and <er>geometrid</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dropwort</ent><br/
<hw>Drop"wort`</hw> <pr>(dr<ocr/p"w<ucir/rt`)</pr>, <pos>n.</pos>
<fld>(Bot.)</fld> <def>An Old World species of <gen>Spir<ae/a</gen>
(<spn>Spir<ae/a filipendula</spn>), with finely cut leaves.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drosera</ent><br/
\'d8<hw>Dros"e*ra</hw> <pr>(dr<ocr/s"<esl/*r<adot/)</pr>, <pos>n.</pos>
<ety>[NL., fr. Gr. <grk>drosero`s</grk> dewy.]</ety> <fld>(Bot.)</fld>
<def>A genus of low perennial or biennial plants, the leaves of which
are beset with gland-tipped bristles. See <er>Sundew</er>.</def>
<rj><au>Gray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Droseraceae</ent><br/
<hw>Droseraceae</hw> <pos>n.</pos> <def>a natural family of carnivorous
herbs and shrubs.</def><br/
<syn><b>Syn. --</b> family <fam>Droseraceae</fam>, sundew
family.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>droshky</ent><br/
<hw>droshky</hw> <pos>n.</pos> <def>same as <er>drosky</er>.</def><br/
<syn><b>Syn. --</b> drosky.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>drosky</ent><br/
<hw>dros"ky</hw> <pr>(dr<ocr/s"k<ycr/)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Droskies</plw> <pr>(dr<ocr/s"k<icr/z)</pr>.</plu>
<ety>[Russ. <ets>drojki</ets>, dim. of <ets>drogi</ets> a kind of
carriage, prop. pl. of <ets>droga</ets> shaft or pole of a
carriage.]</ety> <def>A low, four-wheeled, open carriage, formerly used
in Poland and Russia, consisting of a kind of long, narrow bench, on
which the passengers ride as on a saddle, with their feet reaching
nearly to the ground. Other kinds of vehicles have been so called, esp.
a kind of victoria drawn by one or two horses, and used as a public
carriage in German cities.</def> <altsp>[Written also
<asp>droitzschka</asp>, <asp>droshky</asp> and
<asp>droschke</asp>.]</altsp><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Drosometer</ent><br/
<hw>Dro*som"e*ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>dro`sos</grk> dew + <ets>-meter</ets>: cf. F.
<ets>drosom<egrave/tre</ets>.]</ety> <fld>(Meteorol.)</fld> <def>An
instrument for measuring the quantity of dew on the surface of a body in
the open air. It consists of a balance, having a plate at one end to
receive the dew, and at the other a weight protected from the deposit of
dew.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drosophilidae</ent><br/
<hw>Drosophilidae</hw> <pos>n.</pos> <def>a natural family of insects
including some of those called fruit flies.</def><br/
<syn><b>Syn. --</b> family <fam>Drosophilidae</fam>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Drosophyllum</ent><br/
<hw>Drosophyllum</hw> <pos>n.</pos> <def>a genus of dicotyledonous
plants having only one species.</def><br/
<syn><b>Syn. --</b> genus <gen>Drosophyllum</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dross</ent><br/
<hw>Dross</hw> <pr>(dr<ocr/s; 115)</pr>, <pos>n.</pos> <ety>[AS.
<ets>dros</ets>, fr. <ets>dre<oacute/san</ets> to fall. See
<er>Dreary</er>.]</ety> <sn>1.</sn> <def>The scum or refuse matter which
is thrown off, or falls from, metals in smelting the ore, or in the
process of melting; recrement.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Rust of metals.</def> <mark>[R.]</mark>
<rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Waste matter; any worthless matter separated from
the better part; leavings; dregs; refuse.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>All world's glory is but <qex>dross</qex> unclean.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>At the devil's booth are all things sold,<br/
Each ounce of <qex>dross</qex> coats its ounce of gold.</q>
<rj><qau>Lowell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drossel</ent><br/
<hw>Dros"sel</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf.
<er>Drazel</er>.]</ety> <def>A slut; a hussy; a drazel.</def>
<mark>[Obs.]</mark> <rj><au>Warner.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drossless</ent><br/
<hw>Dross"less</hw>, <pos>a.</pos> <def>Free from dross.</def>
<rj><au>Stevens.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drossy</ent><br/
<hw>Dross"y</hw> <pr>(?)</pr>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Drossier</adjf> <pr>(?)</pr>; <pos>superl.</pos>
<adjf>Drossiest</adjf> <pr>(?)</pr>.]</amorph> <def>Of, pertaining to,
resembling, dross; full of dross; impure; worthless.</def> <ldquo/
<xex>Drossy</xex> gold.<rdquo/ <au>Dryden.</au> <ldquo/<xex>Drossy</xex>
rhymes.<rdquo/ <au>Donne.</au> -- <wordforms><wf>Dross"i*ness</wf>,
<pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drotchel</ent><br/
<hw>Drotch"el</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Drossel</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drough</ent><br/
<hw>Drough</hw> <pr>(?)</pr>, <pos>imp.</pos> <def>of
<er>Draw</er>.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drought</ent><br/
<hw>Drought</hw> <pr>(drout)</pr>, <pos>n.</pos> <ety>[OE.
<ets>droght</ets>, <ets>drougth</ets>, <ets>dru<yogh/<edh/</ets>, AS.
<ets>druga<edh/</ets>, from <ets>drugian</ets> to dry. See <er>Dry</er>,
and cf. <er>Drouth</er>, which shows the original final sound.]</ety>
<sn>1.</sn> <def>Dryness; want of rain or of water; especially, such
dryness of the weather as affects the earth, and prevents the growth of
plants; aridity.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>drought</qex> of March hath pierced to the root.</q>
<rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>In a <qex>drought</qex> the thirsty creatures cry.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Thirst; want of drink.</def>
<rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Scarcity; lack.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>drought</qex> of Christian writers caused a dearth of all
history.</q> <rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Droughtiness</ent><br/
<hw>Drought"i*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A state of
dryness of the weather; want of rain.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Droughty</ent><br/
<hw>Drought"y</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Characterized by drought; wanting rain; arid; adust.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Droughty</qex> and parched countries.</q>
<rj><qau>Ray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Dry; thirsty; wanting drink.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Thy <qex>droughty</qex> throat.</q>
<rj><qau>Philips.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Droumy</ent><br/
<hw>Drou"my</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. Scot.
<ets>drum</ets>, <ets>dram</ets>, melancholy, Icel <ets>prumr</ets> a
moper, W. <ets>trwm</ets> heavy, sad.]</ety> <def>Troubled; muddy.</def>
<mark>[Obs.]</mark> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drouth</ent><br/
<hw>Drouth</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as
<er>Drought</er>.</def> <rj><au>Sandys.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Another ill accident is <qex>drouth</qex> at the spindling of
corn.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>One whose <qex>drouth</qex> [thirst],<br/
Yet scarce allayed, still eyes the current stream.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>In the dust and <qex>drouth</qex> of London life.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drouthy</ent><br/
<hw>Drouth"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Droughty.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drove</ent><br/
<hw>Drove</hw> <pr>(?)</pr>, <pos>imp.</pos> <def>of
<er>Drive</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drove</ent><br/
<hw>Drove</hw>, <pos>n.</pos> <ety>[AS. <ets>dr<amac/f</ets>, fr.
<ets>dr<imac/fan</ets> to drive. See <er>Drive</er>.]</ety> <sn>1.</sn>
<def>A collection of cattle driven, or cattle collected for driving; a
number of animals, as oxen, sheep, or swine, driven in a body.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Any collection of irrational animals, moving or
driving forward; <as>as, a finny <ex>drove</ex></as>.</def>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A crowd of people in motion.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Where <qex>droves</qex>, as at a city gate, may pass.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A road for driving cattle; a driftway.</def>
<mark>[Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <fld>(Agric.)</fld> <def>A narrow drain or channel used
in the irrigation of land.</def> <rj><au>Simmonds.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Masonry)</fld> <sd>(a)</sd> <def>A broad chisel
used to bring stone to a nearly smooth surface; -- called also
<altname>drove chisel</altname>.</def> <sd>(b)</sd> <def>The grooved
surface of stone finished by the drove chisel; -- called also
<altname>drove work</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drove</ent><br/
<hw>Drove</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Droved</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Droving</conjf> <pr>(?)</pr>.]</vmorph> <ety>[Cf.
<er>Drove</er>, <pos>n.</pos>, and <er>Drover</er>.]</ety> <sn>1.</sn>
<def>To drive, as cattle or sheep, esp. on long journeys; to follow the
occupation of a drover.</def></p>

<p><q>He's <qex>droving</qex> now with Conroy's sheep along the
Castlereagh.</q> <rj><qau>Paterson.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>To finish, as stone, with a drove or drove
chisel.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Droven</ent><br/
<hw>Dro"ven</hw> <pr>(?)</pr>, <pos>p. p.</pos> <def>of
<er>Drive</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drover</ent><br/
<hw>Dro"ver</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who
drives cattle or sheep to market; one who makes it his business to
purchase cattle, and drive them to market.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Why, that's spoken like an honest <qex>drover</qex>; so they sell
bullocks.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A boat driven by the tide.</def> <mark>[Obs.]</mark>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drovy</ent><br/
<hw>Dro"vy</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[AS.
<ets>dr<omac/f</ets> dirty; cf. D. <ets>droef</ets>, G.
<ets>tr<uum/be</ets>, Goth. <ets>dr<omac/bjan</ets> to trouble.]</ety>
<def>Turbid; muddy; filthy.</def> <mark>[Obs.]</mark>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drow</ent><br/
<hw>Drow</hw> <pr>(?)</pr>, <pos>imp.</pos> <def>of <er>Draw</er>.</def>
<mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drown</ent><br/
<hw>Drown</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Drowned</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Drowning</conjf>.]</vmorph> <ety>[OE. <ets>drunen</ets>,
<ets>drounen</ets>, earlier <ets>drunknen</ets>, <ets>druncnien</ets>,
AS. <ets>druncnian</ets> to be drowned, sink, become drunk, fr.
<ets>druncen</ets> drunken. See <er>Drunken</er>, <er>Drink</er>.]</ety>
<def>To be suffocated in water or other fluid; to perish in
water.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Methought, what pain it was to <qex>drown</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drown</ent><br/
<hw>Drown</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To overwhelm in water;
to submerge; to inundate.</def> <ldquo/They <xex>drown</xex> the
land.<rdquo/ <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To deprive of life by immersion in water or other
liquid.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To overpower; to overcome; to extinguish; -- said
especially of sound.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Most men being in sensual pleasures <qex>drowned</qex>.</q>
<rj><qau>Sir J. Davies.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>My private voice is <qex>drowned</qex> amid the senate.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To drown up</b></col>, <cd>to swallow up.</cd>
<mark>[Obs.]</mark> <rj><au>Holland.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drownage</ent><br/
<hw>Drown"age</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of
drowning.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drowner</ent><br/
<hw>Drown"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, drowns.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drowse</ent><br/
<hw>Drowse</hw> <pr>(drouz)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Drowsed</conjf> <pr>(drouzd)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Drowsing</conjf>.]</vmorph> <ety>[AS.
<ets>dr<umac/sian</ets>, <ets>dr<umac/san</ets>, to sink, become slow or
inactive; cf. OD. <ets>droosen</ets> to be sleepy, fall asleep, LG.
<ets>dr<umac/sen</ets>, <ets>druusken</ets>, to slumber, fall down with
a noise; prob, akin to AS. <ets>dre<oacute/san</ets> to fall. See
<er>Dreary</er>.]</ety> <def>To sleep imperfectly or unsoundly; to
slumber; to be heavy with sleepiness; to doze.</def> <ldquo/He
<xex>drowsed</xex> upon his couch.<rdquo/ <rj><au>South.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>In the pool <qex>drowsed</qex> the cattle up to their knees.</q>
<rj><qau>Lowell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drowse</ent><br/
<hw>Drowse</hw>, <pos>v. t.</pos> <def>To make heavy with sleepiness or
imperfect sleep; to make dull or stupid.</def>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drowse</ent><br/
<hw>Drowse</hw>, <pos>n.</pos> <def>A slight or imperfect sleep; a
doze.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>But smiled on in a <qex>drowse</qex> of ecstasy.</q> <rj><qau>Mrs.
Browning.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>drowsihead</ent><br/
<hw>drow"si*head</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Drowsiness.</def>
<mark>[archaic]</mark> <rj><au>Thomson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>drowsihed</ent><br/
<hw>drow"si*hed</hw>, <pos>n.</pos> <def>Drowsihead.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>drowsily</ent><br/
<hw>drow"si*ly</hw>, <pos>adv.</pos> <def>In a drowsy manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>drowsiness</ent><br/
<hw>drow"si*ness</hw>, <pos>n.</pos> <def>State of being drowsy.</def>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>drowsing</ent><br/
<hw>drowsing</hw> <pos>adj. prenom.</pos> <def>sleeping
lightly.</def><br/
<syn><b>Syn. --</b> drowsy, dozing(prenominal), napping(prenominal),
nodding(prenominal).</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Drowsy</ent><br/
<hw>Drow"sy</hw> <pr>(?)</pr>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Drowsier</adjf> <pr>(?)</pr>; <pos>superl.</pos>
<adjf>Drowsiest</adjf>.]</amorph> <sn>1.</sn> <def>Inclined to drowse;
heavy with sleepiness; lethargic; dozy.</def> <ldquo/When I am
<xex>drowsy</xex>.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Dapples the <qex>drowsy</qex> east with spots of gray.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To our age's <qex>drowsy</qex> blood<br/
Still shouts the inspiring sea.</q> <rj><qau>Lowell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Disposing to sleep; lulling; soporific.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>drowsy</qex> hours, dispensers of all good.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Dull; stupid.</def> <ldquo/ <xex>Drowsy</xex>
reasoning.<rdquo/ <rj><au>Atterbury.</au></rj></p>

<p><syn><b>Syn.</b> -- Sleepy; lethargic; dozy; somnolent; comatose;
dull heavy; stupid.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drowth</ent><br/
<hw>Drowth</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Drought</er>.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Droyle</ent><br/
<hw>Droyle</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>See
<er>Droil</er>.</def> <mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drub</ent><br/
<hw>Drub</hw> <pr>(dr<ucr/b)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Drubbed</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Drubbing</conjf>.]</vmorph> <ety>[Cf. Prov. E. <ets>drab</ets> to
beat, Icel. & Sw. <ets>drabba</ets> to hit, beat, Dan.
<ets>dr<ae/be</ets> to slay, and perh. OE. <ets>drepen</ets> to strike,
kill, AS. <ets>drepan</ets> to strike, G. & D. <ets>freffen</ets> to
hit, touch, Icel. <ets>drepa</ets> to strike, kill.]</ety> <def>To beat
with a stick; to thrash; to cudgel.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Soundly <qex>Drubbed</qex> with a good honest cudgel.</q>
<rj><qau>L'Estrange.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drub</ent><br/
<hw>Drub</hw>, <pos>n.</pos> <def>A blow with a cudgel; a thump.</def>
<rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drubber</ent><br/
<hw>Drub"ber</hw> <pr>(dr<ucr/b"b<etil/r)</pr>, <pos>n.</pos> <def>One
who drubs.</def> <rj><au>Sir W. Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drudge</ent><br/
<hw>Drudge</hw> <pr>(dr<ucr/j)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp.
& p. p.</pos> <conjf>Drudged</conjf> <pr>(dr<ucr/jd)</pr>; <pos>p. pr. &
vb. n.</pos> <conjf>Drudging</conjf>.]</vmorph> <ety>[OE.
<ets>druggen</ets>; prob not akin to E. <ets>drag</ets>, v. t., but fr.
Celtic; cf. Ir. <ets>drugaire</ets> a slave or drudge.]</ety> <def>To
perform menial work; to labor in mean or unpleasant offices with toil
and fatigue.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He gradually rose in the estimation of the booksellers for whom he
<qex>drudged</qex>.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drudge</ent><br/
<hw>Drudge</hw>, <pos>v. t.</pos> <def>To consume laboriously; -- with
<xex>away</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Rise to our toils and <qex>drudge</qex> away the day.</q>
<rj><qau>Otway.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drudge</ent><br/
<hw>Drudge</hw>, <pos>n.</pos> <def>One who drudges; one who works hard
in servile employment; a menial servant.</def>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drudger</ent><br/
<hw>Drudg"er</hw> <pr>(dr<ucr/j"<etil/r)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>One who drudges; a drudge.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A dredging box.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drudgery</ent><br/
<hw>Drudg"er*y</hw> <pr>(dr<ucr/j"<etil/r*<ycr/)</pr>, <pos>n.</pos>
<def>The act of drudging; disagreeable and wearisome labor; ignoble or
slavish toil.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>drudgery</qex> of penning definitions.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Paradise was a place of bliss . . . without <qex>drudgery</qex>
and with out sorrow.</q> <rj><qau>Locke.</qau></rj></p>

<p><syn><b>Syn.</b> -- See <er>Toll</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drudging box</ent><br/
<hw>Drudg"ing box`</hw> <pr>(?)</pr>. <def>See <er>Dredging
box</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drudgingly</ent><br/
<hw>Drudg"ing*ly</hw>, <pos>adv.</pos> <def>In a drudging manner;
laboriously.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Druery</ent><br/
<hw>Dru"er*y</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>druerie</ets>.]</ety> <def>Courtship; gallantry; love; an object of
love.</def> <mark>[Obs.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drug</ent><br/
<hw>Drug</hw> <pr>(dr<ucr/g)</pr>, <pos>v. i.</pos> <ety>[See 1st
<er>Drudge</er>.]</ety> <def>To drudge; to toil laboriously.</def>
<mark>[Obs.]</mark> <ldquo/To <xex>drugge</xex> and draw.<rdquo/
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drug</ent><br/
<hw>Drug</hw>, <pos>n.</pos> <def>A drudge (?).</def> <rj><au>Shak.
(Timon iv. 3, 253).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drug</ent><br/
<hw>Drug</hw>, <pos>n.</pos> <ety>[F. <ets>drogue</ets>, prob. fr. D.
<ets>droog</ets>; akin to E. <ets>dry</ets>; thus orig., dry substance,
hers, plants, or wares. See <er>Dry</er>.]</ety> <sn>1.</sn> <def>Any
animal, vegetable, or mineral substance used in the composition of
medicines.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Whence merchants bring<br/
Their spicy <qex>drugs</qex>.</q> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Any commodity that lies on hand, or is not salable;
an article of slow sale, or in no demand; -- used often in the phrase
<ldquo/a <ex>drug</ex> on the market<rdquo/.</def> <ldquo/But sermons
are mere <xex>drugs</xex>.<rdquo/ <rj><au>Fielding.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And virtue shall a <qex>drug</qex> become.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>any stuff used in dyeing or in chemical
operations.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>any substance intended for use in the treatment,
prevention, diagnosis, or cure of disease, especially one listed in the
official pharmacopoeia published by a national authority.</def><br/
[<source>PJC</source>]</p>

<p><sn>5.</sn> <def>any substance having psychological effects, such as
a narcotic, stimulant, or hallucinogenic agent, especially habit-forming
and addictive substances, sold or used illegally; <as>as, a
<ex>drug</ex> habit; a <ex>drug</ex> treatment program; a teenager into
<ex>drugs</ex>; a <ex>drug</ex> bust; addicted to <ex>drugs</ex>; high
on <ex>drugs</ex>.</as></def><br/
<syn><b>Syn. --</b> illegal drug.</syn>
[<source>PJC</source>]</p>

<p><q>They [smaller and poorer nations] have lined up to recount how
<qex>drug</qex> trafficking and consumption have corrupted their
struggling economies and societies and why they are hard pressed to stop
it.</q> <rj><qau> Christopher S. Wren (N Y. Times, June 10, 1998, p.
A5)</qau></rj><br/
[<source>PJC</source>]</p>

<p><ent>Drug</ent><br/
<hw>Drug</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Drugged</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Drugging</conjf>.]</vmorph> <ety>[Cf. F.
<ets>droguer</ets>.]</ety> <def>To prescribe or administer drugs or
medicines.</def> <rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drug</ent><br/
<hw>Drug</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To affect or season
with drugs or ingredients; esp., to stupefy by a narcotic drug. Also
Fig.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The laboring masses . . . [were] <qex>drugged</qex> into brutish
good humor by a vast system of public spectacles.</q> <rj><qau>C.
Kingsley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Drug thy memories, lest thou learn it.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To tincture with something offensive or
injurious.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Drugged</qex> as oft,<br/
With hatefullest disrelish writhed their jaws.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To dose to excess with, or as with, drugs.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With pleasure <qex>drugged</qex>, he almost longed for woe.</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>drugged</ent><br/
<hw>drugged</hw> <pos>adj.</pos> <def>under the influence of narcotics
or hypnotic drugs.</def><br/
<syn><b>Syn. --</b> doped, narcotized.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>drugging</ent><br/
<hw>drugging</hw> <pos>n.</pos> <def>the administration of a sedative
agent or drug.</def><br/
<syn><b>Syn. --</b> sedation.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Drugger</ent><br/
<hw>Drug"ger</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A druggist.</def>
<mark>[Obs.]</mark> <rj><au>Burton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drugget</ent><br/
<hw>Drug"get</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>droguet</ets>, prop. dim. of <ets>drogue</ets> trash, stuff, perh,
the same word as <ets>drogue</ets> drug, but cf. also W. <ets>drwg</ets>
evil, bad, Ir. & Gael. <ets>droch</ets>, Arm. <ets>droug</ets>,
<ets>drouk</ets>. See 3d <er>Drug</er>.]</ety> <sd>(a)</sd> <def>A
coarse woolen cloth dyed of one color or printed on one side; generally
used as a covering for carpets.</def> <sd>(b)</sd> <def>By extension,
any material used for the same purpose.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>druggist</ent><br/
<hw>drug"gist</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>droguiste</ets>, fr. <ets>drogue</ets>. See 3d
<er>Drug</er>.]</ety> <sn>1.</sn> <def>One who deals in drugs;
especially, one who buys and sells drugs without compounding them; one
who owns or operates a drugstore.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>2.</sn> <def>one who compounds drugs or distributes drugs into
containers for distribution to customers; a pharmacist or
apothecary.</def><br/
<syn><b>Syn. --</b> dispensing chemist.</syn>
[<source>PJC</source>]</p>

<p><note><hand/ The same person often serves as both pharmacist and
retail seller of drugs. See the Note under
<er>Apothecary</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drugster</ent><br/
<hw>Drug"ster</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A druggist.</def>
<mark>[Obs.]</mark> <rj><au>Boule.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>drugstore</ent><br/
<hw>drugstore</hw> <pos>n.</pos> <def>a retail shop where medicine and
other articles are sold.</def><br/
<syn><b>Syn. --</b> apothecary's shop, chemist's, chemist's shop,
dispensary, pharmacy.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Druid</ent><br/
<hw>Dru"id</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>Druides</ets>;
of Celtic origin; cf. Ir. & Gael. <ets>draoi</ets>, <ets>druidh</ets>,
magician, Druid, W. <ets>derwydd</ets> Druid.]</ety> <sn>1.</sn>
<def>One of an order of priests which in ancient times existed among
certain branches of the Celtic race, especially among the Gauls and
Britons.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The Druids superintended the affairs of religion and
morality, and exercised judicial functions. They practiced divination
and magic, and sacrificed human victims as a part of their worship. They
consisted of three classes; the bards, the vates or prophets, and the
Druids proper, or priests. Their most sacred rites were performed in the
depths of oak forests or of caves.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A member of a social and benevolent order, founded
in London in 1781, and professedly based on the traditions of the
ancient Druids. Lodges or <xex>groves</xex> of the society are
established in other countries.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Druid stones</b></col>, <cd>a name given, in the south of
England, to weatherworn, rough pillars of gray sandstone scattered over
the chalk downs, but in other countries generally in the form of
circles, or in detached pillars.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Druidess</ent><br/
<hw>Dru"id*ess</hw>, <pos>n.</pos> <def>A female Druid; a
prophetess.</def></p>

<p><ent>Druidical</ent><br/
<ent>Druidic</ent><br/
<mhw>{ <hw>Dru*id"ic</hw> <pr>(?)</pr>, <hw>Dru*id"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <def>Pertaining to, or resembling,
the Druids.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Druidical circles</b></col>. <cd>See under
<er>Circle</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Druidish</ent><br/
<hw>Dru"id*ish</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Druidic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Druidism</ent><br/
<hw>Dru"id*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The system of
religion, philosophy, and instruction, received and taught by the
Druids; the rites and ceremonies of the Druids.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drum</ent><br/
<hw>Drum</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. D. <ets>trom</ets>,
<ets>trommel</ets>, LG. <ets>trumme</ets>, G. <ets>trommel</ets>, Dan.
<ets>tromme</ets>, Sw. <ets>trumma</ets>, OHG. <ets>trumba</ets> a
trumpet, Icel. <ets>pruma</ets> a clap of thunder, and as a verb, to
thunder, Dan. <ets>drum</ets> a booming sound, <ets>drumme</ets> to
boom; prob. partly at least of imitative origin; perh. akin to E.
<ets>trum</ets>, or <ets>trumpet</ets>.]</ety> <sn>1.</sn>
<fld>(Mus.)</fld> <def>An instrument of percussion, consisting either of
a hollow cylinder, over each end of which is stretched a piece of skin
or vellum, to be beaten with a stick; or of a metallic hemisphere
(kettledrum) with a single piece of skin to be so beaten; the common
instrument for marking time in martial music; one of the pair of
<xex>tympani</xex> in an orchestra, or cavalry band.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>drums</qex> cry bud-a-dub.</q>
<rj><qau>Gascoigne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Anything resembling a drum in form</def>; as:
<sd>(a)</sd> <def>A sheet iron radiator, often in the shape of a drum,
for warming an apartment by means of heat received from a stovepipe, or
a cylindrical receiver for steam, etc.</def> <sd>(b)</sd> <def>A small
cylindrical box in which figs, etc., are packed.</def> <sd>(c)</sd>
<fld>(Anat.)</fld> <def>The tympanum of the ear; -- often, but
incorrectly, applied to the tympanic membrane.</def> <sd>(d)</sd>
<fld>(Arch.)</fld> <def>One of the cylindrical, or nearly cylindrical,
blocks, of which the shaft of a column is composed; also, a vertical
wall, whether circular or polygonal in plan, carrying a cupola or
dome.</def> <sd>(e)</sd> <fld>(Mach.)</fld> <def>A cylinder on a
revolving shaft, generally for the purpose of driving several pulleys,
by means of belts or straps passing around its periphery; also, the
barrel of a hoisting machine, on which the rope or chain is
wound.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <def>See <er>Drumfish</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A noisy, tumultuous assembly of fashionable people
at a private house; a rout.</def> <mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Not unaptly styled a <qex>drum</qex>, from the noise and emptiness
of the entertainment.</q> <rj><qau>Smollett.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ There were also <xex>drum major</xex>, <xex>rout</xex>,
<xex>tempest</xex>, and <xex>hurricane</xex>, differing only in degrees
of multitude and uproar, as the significant name of each
declares.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>A tea party; a kettledrum.</def> <rj><au>G.
Eliot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Bass drum</b></col>. <cd>See in the Vocabulary.</cd> --
<col><b>Double drum</b></col>. <cd>See under
<er>Double</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drum</ent><br/
<hw>Drum</hw>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Drummed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Drumming</conjf>.]</vmorph> <sn>1.</sn> <def>To beat a drum with
sticks; to beat or play a tune on a drum.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To beat with the fingers, as with drumsticks; to
beat with a rapid succession of strokes; to make a noise like that of a
beaten drum; <as>as, the ruffed grouse <ex>drums</ex> with his
wings</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Drumming</qex> with his fingers on the arm of his chair.</q>
<rj><qau>W. Irving.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To throb, as the heart.</def> <mark>[R.]</mark>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To go about, as a drummer does, to gather recruits,
to draw or secure partisans, customers, etc,; -- with
<xex>for</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drum</ent><br/
<hw>Drum</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To execute on a drum,
as a tune.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>(With <xex>out</xex>) To expel ignominiously, with
beat of drum; <as>as, to <ex>drum</ex> out a deserter or rogue from a
camp, etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>(With <xex>up</xex>) To assemble by, or as by, beat
of drum; to collect; to gather or draw by solicitation; <as>as, to
<ex>drum</ex> up recruits; to <ex>drum</ex> up customers.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drumbeat</ent><br/
<hw>Drum"beat`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The sound of a
beaten drum; drum music.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Whose morning <qex>drumbeat</qex>, following the sun, and keeping
company with the hours, circles the earth with one continuous and
unbroken strain of the martial airs of England.</q> <rj><qau>D.
Webster.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drumble</ent><br/
<hw>Drum"ble</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[See
<er>Drumly</er>.]</ety> <sn>1.</sn> <def>To be sluggish or lazy; to be
confused.</def> <mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To mumble in speaking.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drumfish</ent><br/
<hw>Drum"fish`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>Any fish of the family <fam>Sci<ae/nid<ae/</fam>, which makes a
loud noise by means of its air bladder; -- called also
<altname>drum</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 458 --></p>

<p><note><hand/ The common drumfish (<spn>Pogonias chromis</spn>) is a
large species, common south of New Jersey. The southern red drum or red
horse (<spn>Sci<ae/na ocellata</spn>), and the fresh-water drum or
croaker (<spn>Aplodionotus grunniens</spn>), are related
species.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drumhead</ent><br/
<hw>Drum"head`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
parchment or skin stretched over one end of a drum.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The top of a capstan which is pierced with sockets
for levers used in turning it. See <xex>Illust.</xex> of
<er>Capstan</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Drumhead court-martial</b></col> <fld>(Mil.)</fld>, <cd>a
summary court-martial called to try offenses on the battlefield or the
line of march, when, sometimes, a drumhead has to do service as a
writing table.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drumlin</ent><br/
<hw>Drum"lin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gael.
<ets>druim</ets> the ridge of a hill.]</ety> <fld>(Geol.)</fld> <def>A
hill of compact, unstratified, glacial drift or till, usually elongate
or oval, with the larger axis parallel to the former local glacial
motion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drumly</ent><br/
<hw>Drum"ly</hw>, <pos>a.</pos> <ety>[Cf. <er>Droumy</er>.]</ety>
<def>Turbid; muddy.</def> <mark>[Scot. & Obs. or Prov. Eng.]</mark>
<rj><au>Wodroephe (1623). Burns.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drum major</ent><br/
<hw>Drum" ma"jor</hw> <pr>(?)</pr><def>.</def> <sn>1.</sn> <def>The
chief or first drummer of a regiment; an instructor of
drummers.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The marching leader of a military band.</def>
<mark>[U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A noisy gathering. <mark>[R.]</mark> See under
<er>Drum</er>, <pos>n.</pos>, 4.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drummer</ent><br/
<hw>Drum"mer</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One whose
office is to best the drum, as in military exercises and
marching.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who solicits custom; a commercial
traveler.</def> <mark>[Colloq. U.S.]</mark>
<rj><au>Bartlett.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <def>A fish that makes a sound when
caught</def>; as: <sd>(a)</sd> <def>The squeteague.</def> <sd>(b)</sd>
<def>A California sculpin.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Zool.)</fld> <def>A large West Indian cockroach
(<spn>Blatta gigantea</spn>) which drums on woodwork, as a sexual
call.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drumming</ent><br/
<hw>Drum"ming</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act of beating
upon, or as if upon, a drum; also, the noise which the male of the
ruffed grouse makes in spring, by beating his wings upon his
sides.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drummond light</ent><br/
<hw>Drum"mond light`</hw> <pr>(?)</pr>. <ety>[From Thomas
<ets>Drummond</ets>, a British naval officer.]</ety> <def>A very intense
light, produced by turning two streams of gas, one oxygen and the other
hydrogen, or coal gas, in a state of ignition, upon a ball of lime; or a
stream of oxygen gas through a flame of alcohol upon a ball or disk of
lime; -- called also <altname>oxycalcium light</altname>, or
<altname>lime light</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The name is also applied sometimes to a heliostat,
invented by Drummond, for rendering visible a distant point, as in
geodetic surveying, by reflecting upon it a beam of light from the
sun.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drumstick</ent><br/
<hw>Drum"stick`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A
stick with which a drum is beaten.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Anything resembling a drumstick in form; -- applied
especially to the tibiotarsus, or second joint, of the leg of a fowl,
when cooked and served at the table.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Drum winding</ent><br/
<hw>Drum winding</hw>. <fld>(Elec.)</fld> <def>A method of armature
winding in which the wire is wound upon the outer surface of a cylinder
or drum from end to end of the cylinder; -- distinguished from
<contr>ring winding</contr>, etc.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Drunk</ent><br/
<hw>Drunk</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OE. <ets>dronke</ets>,
<ets>drunke</ets>, <ets>dronken</ets>, <ets>drunken</ets>, AS.
<ets>druncen</ets>. Orig. the same as <ets>drunken</ets>, p. p. of
<ets>drink</ets>. See <er>Drink</er>.]</ety> <sn>1.</sn>
<def>Intoxicated with, or as with, strong drink; inebriated; drunken; --
never used <xex>attributively</xex>, but always
<xex>predicatively</xex>; <as>as, the man is <ex>drunk</ex> (not, a
<ex>drunk</ex> man)</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Be not <qex>drunk</qex> with wine, where in is excess.</q>
<rj><qau> Eph. v. 18.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Drunk</qex> with recent prosperity.</q>
<rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Drenched or saturated with moisture or
liquid.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I will make mine arrows <qex>drunk</qex> with blood.</q> <rj><qau>
Deut. xxxii. 42.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drunk</ent><br/
<hw>Drunk</hw>, <pos>n.</pos> <def>A drunken condition; a spree.</def>
<mark>[Slang]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drunkard</ent><br/
<hw>Drunk"ard</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Drunk</ets> +
<ets>-ard</ets>.]</ety> <def>One who habitually drinks strong liquors
immoderately; one whose habit it is to get drunk; a toper; a
sot.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>drunkard</qex> and glutton shall come to poverty.</q>
<rj><qau> Prov. xxiii. 21.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drunken</ent><br/
<hw>Drunk"en</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[AS.
<ets>druncen</ets>, prop., that has drunk, p. p. of <ets>drincan</ets>,
taken as active. See <er>Drink</er>, <pos>v. i.</pos>, and cf.
<er>Drunk</er>.]</ety> <sn>1.</sn> <def>Overcome by strong drink;
intoxicated by, or as by, spirituous liquor; inebriated.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Drunken</qex> men imagine everything turneth round.</q>
<rj><qau> Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Saturated with liquid or moisture;
drenched.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Let the earth be <qex>drunken</qex> with our blood.</q> <rj><qau>
Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Pertaining to, or proceeding from,
intoxication.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>drunken</qex> quarrels of a rake.</q> <rj><qau>
Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drunkenhead</ent><br/
<hw>Drunk"en*head</hw> <pr>(?)</pr>, <pos>n.</pos>
<def>Drunkenness.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drunkenly</ent><br/
<hw>Drunk"en*ly</hw>, <pos>adv.</pos> <def>In a drunken manner.</def>
<mark>[R.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drunkenness</ent><br/
<hw>Drunk"en*ness</hw>, <pos>n.</pos> <sn>1.</sn> <def>The state of
being drunken with, or as with, alcoholic liquor; intoxication;
inebriety; -- used of the casual state or the habit.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The Lacedemonians trained up their children to hate
<qex>drunkenness</qex> by bringing a drunken man into their company.</q>
<rj><qau>I. Watts.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Disorder of the faculties, resembling intoxication
by liquors; inflammation; frenzy; rage.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Passion is the <qex>drunkenness</qex> of the mind.</q> <rj><qau>
South.</qau></rj></p>

<p><syn><b>Syn.</b> -- Intoxication; inebriation; inebriety. --
<er>Drunkenness</er>, <er>Intoxication</er>, <er>Inebriation</er>.
<xex>Drunkenness</xex> refers more to the habit; <xex>intoxication</xex>
and <xex>inebriation</xex>, to specific acts. The first two words are
extensively used in a figurative sense; a person is
<xex>intoxicated</xex> with success, and is <xex>drunk</xex> with joy.
<ldquo/This plan of empire was not taken up in the first
<xex>intoxication</xex> of unexpected success.<rdquo/</syn>
<rj><au>Burke.</au></rj></p>

<p><ent>Drunkship</ent><br/
<ent>Drunkenship</ent><br/
<mhw>{ <hw>Drunk"en*ship</hw>, <hw>Drunk"ship</hw>, }</mhw>
<pos>n.</pos> <def>The state of being drunk; drunkenness.</def>
<mark>[Obs.]</mark> <rj><au>Gower.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drupaceous</ent><br/
<hw>Dru*pa"ceous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>drupac<eacute/</ets>.]</ety> <fld>(Bot.)</fld> <def>Producing, or
pertaining to, drupes; having the form of drupes; <as>as,
<ex>drupaceous</ex> trees or fruits</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drupal</ent><br/
<hw>Drup"al</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Bot.)</fld>
<def>Drupaceous.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drupe</ent><br/
<hw>Drupe</hw> <pr>(dr<udd/p)</pr>, <pos>n.</pos> <ety>[F.
<ets>drupe</ets>, L. <ets>drupa</ets> an overripe, wrinkled olive, fr.
Gr. <grk>dry`ppa</grk>.]</ety> <fld>(Bot.)</fld> <def>A fruit consisting
of pulpy, coriaceous, or fibrous exocarp, without valves, containing a
nut or stone with a kernel. The exocarp is succulent in the plum,
cherry, apricot, peach, etc.; dry and subcoriaceous in the almond; and
fibrous in the cocoanut.</def></p>

<p><ent>Drupelet</ent><br/
<ent>Drupel</ent><br/
<mhw>{ <hw>Drup"el</hw> <pr>(?)</pr>, <hw>Drupe"let</hw> <pr>(?)</pr>,
}</mhw> <pos>n.</pos> <ety>[Dim. of <er>Drupe</er>.]</ety>
<fld>(Bot.)</fld> <def>A small drupe, as one of the pulpy grains of the
blackberry.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Druse</ent><br/
<hw>Druse</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. G. <ets>druse</ets>
bonny, crystallized piece of ore, Bohem. <ets>druza</ets>. Cf.
<er>Dross</er>.]</ety> <fld>(Min.)</fld> <def>A cavity in a rock, having
its interior surface studded with crystals and sometimes filled with
water; a geode.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Druse</ent><br/
<hw>Druse</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One of a people and
religious sect dwelling chiefly in the Lebanon mountains of
Syria.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The Druses separated from the Muslim Arabs in the 9th century.
Their characteristic dogma is the unity of God.</q> <rj><qau> Am.
Cyc.</qau></rj></p>

<p><ent>Drused</ent><br/
<ent>Drusy</ent><br/
<mhw>{ <hw>Dru"sy</hw> <pr>(?)</pr>, <hw>Drused</hw> <pr>(?)</pr>,
}</mhw> <pos>a.</pos> <fld>(Min.)</fld> <def>Covered with a large number
of minute crystals.</def></p>

<p><ent>Druxy</ent><br/
<ent>Druxey</ent><br/
<mhw>{ <hw>Drux"ey</hw>, <hw>Drux"y</hw> }</mhw> <pr>(?)</pr>,
<pos>a.</pos> <ety>[Etymol. uncertain.]</ety> <def>Having decayed spots
or streaks of a whitish color; -- said of timber.</def>
<rj><au>Weale.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dry</ent><br/
<hw>Dry</hw> <pr>(dr<imac/)</pr>, <pos>a.</pos>
<amorph>[<pos>Compar.</pos> <adjf>Drier</adjf> <pr>(?)</pr>;
<pos>superl.</pos> <adjf>Driest</adjf>.]</amorph> <ety>[OE.
<ets>dru<yogh/e</ets>, <ets>druye</ets>, <ets>drie</ets>, AS.
<ets>dryge</ets>; akin to LG. <ets>dr<oum/ge</ets>, D. <ets>droog</ets>,
OHG. <ets>trucchan</ets>, G. <ets>trocken</ets>, Icel. <ets>draugr</ets>
a dry log. Cf. <er>Drought</er>, <er>Drouth</er>, 3d
<er>Drug</er>.]</ety> <sn>1.</sn> <def>Free from moisture; having little
humidity or none; arid; not wet or moist; deficient in the natural or
normal supply of moisture, as rain or fluid of any kind; -- said
especially: <sd>(a)</sd> Of the weather: Free from rain or
mist.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The weather, we agreed, was too <qex>dry</qex> for the season.</q>
<rj><qau>Addison.</qau></rj></p>

<p><sd>(b)</sd> <def>Of vegetable matter: Free from juices or sap; not
succulent; not green; <as>as, <ex>dry</ex> wood or hay</as>.</def>
<sd>(c)</sd> <def>Of animals: Not giving milk; <as>as, the cow is
<ex>dry</ex></as>.</def> <sd>(d)</sd> <def>Of persons: Thirsty; needing
drink.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Give the <qex>dry</qex> fool drink.</q> <rj><qau>
Shak</qau></rj></p>

<p><sd>(e)</sd> <def>Of the eyes: Not shedding tears.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Not a <qex>dry</qex> eye was to be seen in the assembly.</q>
<rj><qau> Prescott.</qau></rj></p>

<p><sd>(f)</sd> <fld>(Med.)</fld> <def>Of certain morbid conditions, in
which there is entire or comparative absence of moisture; as,
<xex>dry</xex> gangrene; <xex>dry</xex> catarrh.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Destitute of that which interests or amuses; barren;
unembellished; jejune; plain.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>These epistles will become less <qex>dry</qex>, more susceptible
of ornament.</q> <rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Characterized by a quality somewhat severe, grave,
or hard; hence, sharp; keen; shrewd; quaint; <as>as, a <ex>dry</ex> tone
or manner; <ex>dry</ex> wit.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>He was rather a <qex>dry</qex>, shrewd kind of body.</q>
<rj><qau>W. Irving.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Fine Arts)</fld> <def>Exhibiting a sharp, frigid
preciseness of execution, or the want of a delicate contour in form, and
of easy transition in coloring.</def><br/
[<source>1913 Webster</source>]</p>

<cs><p><col><b>Dry area</b></col> <fld>(Arch.)</fld>, <cd>a small open
space reserved outside the foundation of a building to guard it from
damp.</cd> -- <col><b>Dry blow</b></col>. <sd>(a)</sd> <fld>(Med.)</fld>
<cd>A blow which inflicts no wound, and causes no effusion of
blood.</cd> <sd>(b)</sd> <cd>A quick, sharp blow.</cd> -- <col><b>Dry
bone</b></col> <fld>(Min.)</fld>, <cd>Smithsonite, or carbonate of zinc;
-- a miner's term.</cd> -- <col><b>Dry castor</b></col>
<fld>(Zool.)</fld> <cd>a kind of beaver; -- called also
<altname>parchment beaver</altname>.</cd> -- <col><b>Dry
cupping</b></col>. <fld>(Med.)</fld> <cd>See under
<er>Cupping</er>.</cd> -- <col><b>Dry dock</b></col>. <cd>See under
<er>Dock</er>.</cd> -- <col><b>Dry fat</b></col>. <cd>See <cref>Dry
vat</cref> (below).</cd> -- <col><b>Dry light</b></col>, <cd>pure
unobstructed light; hence, a clear, impartial view.</cd>
<au>Bacon.</au><br/
[<source>1913 Webster</source>]</p>

<p><q>The scientific man must keep his feelings under stern control,
lest they obtrude into his researches, and color the <qex>dry
light</qex> in which alone science desires to see its objects.</q>
<rj><qau> J. C. Shairp.</qau></rj></p>

<p>-- <col><b>Dry masonry</b></col>. <cd>See <er>Masonry</er>.</cd> --
<col><b>Dry measure</b></col>, <cd>a system of measures of volume for
dry or coarse articles, by the bushel, peck, etc.</cd> -- <col><b>Dry
pile</b></col> <fld>(Physics)</fld>, <cd>a form of the Voltaic pile,
constructed without the use of a liquid, affording a feeble current, and
chiefly useful in the construction of electroscopes of great delicacy;
-- called also <altname>Zamboni's</altname>, from the names of the two
earliest constructors of it.</cd> -- <col><b>Dry pipe</b></col>
<fld>(Steam Engine)</fld>, <cd>a pipe which conducts dry steam from a
boiler.</cd> -- <col><b>Dry plate</b></col> <fld>(Photog.)</fld>, <cd>a
glass plate having a dry coating sensitive to light, upon which
photographic negatives or pictures can be made, without moistening.</cd>
-- <col><b>Dry-plate process</b></col>, <cd>the process of photographing
with dry plates.</cd> -- <col><b>Dry point</b></col>. <fld>(Fine
Arts)</fld> <sd>(a)</sd> <cd>An engraving made with the needle instead
of the burin, in which the work is done nearly as in etching, but is
finished without the use acid</cd>. <sd>(b)</sd> <cd>A print from such
an engraving, usually upon paper.</cd> <sd>(c)</sd> Hence: <cd>The
needle with which such an engraving is made.</cd> -- <col><b>Dry
rent</b></col> <fld>(Eng. Law)</fld>, <cd>a rent reserved by deed,
without a clause of distress.</cd> <au>Bouvier.</au> -- <col><b>Dry
rot</b></col>, <cd>a decay of timber, reducing its fibers to the
condition of a dry powdery dust, often accompanied by the presence of a
peculiar fungus (<spn>Merulius lacrymans</spn>), which is sometimes
considered the cause of the decay; but it is more probable that the real
cause is the decomposition of the wood itself. <au>D. C. Eaton.</au>
Called also <altname>sap rot</altname>, and, in the United States,
<altname>powder post</altname>.</cd> <au>Hebert.</au> -- <col><b>Dry
stove</b></col>, <cd>a hothouse adapted to preserving the plants of arid
climates.</cd> <au>Brande & C.</au> -- <col><b>Dry vat</b></col>, <cd>a
vat, basket, or other receptacle for dry articles.</cd> -- <col><b>Dry
wine</b></col>, <cd>that in which the saccharine matter and fermentation
were so exactly balanced, that they have wholly neutralized each other,
and no sweetness is perceptible; -- opposed to <contr>sweet
wine</contr>, in which the saccharine matter is in excess.</cd><br/
[<source>1913 Webster</source>]</p></cs>

<p><ent>Dry</ent><br/
<hw>Dry</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Dried</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Drying</conjf>.]</vmorph> <ety>[AS. <ets>drygan</ets>; cf.
<ets>drugian</ets> to grow dry. See <er>Dry</er>, <pos>a.</pos>]</ety>
<def>To make dry; to free from water, or from moisture of any kind, and
by any means; to exsiccate; <as>as, to <ex>dry</ex> the eyes; to
<ex>dry</ex> one's tears; the wind <ex>dries</ex> the earth; to
<ex>dry</ex> a wet cloth; to <ex>dry</ex> hay.</as></def><br/
[<source>1913 Webster</source>]</p>

<cs><p><col><b>To dry up</b></col>. <sd>(a)</sd> <cd>To scorch or parch
with thirst; to deprive utterly of water; to consume.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>Their honorable men are famished, and their multitude <qex>dried
up</qex> with thirst.</q> <rj><qau> Is. v. 13.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The water of the sea, which formerly covered it, was in time
exhaled and <qex>dried up</qex> by the sun.</q>
<rj><qau>Woodward.</qau></rj></p>

<p><sd>(b)</sd> <cd>To make to cease, as a stream of talk.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>Their sources of revenue were <qex>dried up</qex>.</q> <rj><qau>
Jowett (Thucyd. )</qau></rj></p>

<p>-- <mcol><col><b>To dry a cow</b></col>, <it>or</it> <col><b>To dry
up a cow</b></col></mcol>, <cd>to cause a cow to cease secreting
milk.</cd> <rj><au>Tylor.</au></rj><br/
[<source>1913 Webster</source>]</p></cs>

<p><ent>Dry</ent><br/
<hw>Dry</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To grow dry; to become
free from wetness, moisture, or juice; <as>as, the road <ex>dries</ex>
rapidly</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To evaporate wholly; to be exhaled; -- said of
moisture, or a liquid; -- sometimes with <ptcl>up</ptcl>; <as>as, the
stream <ex>dries</ex>, or <ex>dries</ex> up</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To shrivel or wither; to lose vitality.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And his hand, which he put forth against him, <qex>dried</qex> up,
so that he could not pull it in again to him.</q> <rj><qau>I Kings xiii.
4.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dryad</ent><br/
<hw>Dry"ad</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>dryas</ets>,
pl. <ets>dryades</ets>, Gr. <?/, pl. <?/, fr. <?/ oak, tree. See
<er>Tree</er>.]</ety> <fld>(Class. Myth.)</fld> <def>A wood nymph; a
nymph whose life was bound up with that of her tree.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dryadella</ent><br/
<hw>Dryadella</hw> <pos>n.</pos> <def>a genus of plants comprising
tropical American species usually placed in the genus
<gen>Masdevallia</gen>; they are very dwarf plants having short tufted
and usually unifoliate stems with usually solitary flowers.</def><br/
<syn><b>Syn. --</b> genus <gen>Dryadella</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dryandra</ent><br/
\'d8<hw>Dry*an"dra</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. Named
after <etsep>J. Dryander</etsep>.]</ety> <fld>(Bot.)</fld> <def>A genus
of shrubs growing in Australia, having beautiful, hard, dry, evergreen
leaves.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dryas</ent><br/
\'d8<hw>Dry"as</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Dryades</plw> <pr>(#)</pr>.</plu> <ety>[L. See
<er>Dryad</er>.]</ety> <fld>(Class. Myth.)</fld> <def>A dryad.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dry-beat</ent><br/
<hw>Dry"-beat`</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To beat
severely.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dry-boned</ent><br/
<hw>Dry"-boned`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having dry bones,
or bones without flesh.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>dry-clean</ent><br/
<hw>dry-clean</hw> <pos>v. t.</pos> <def>to clean without the use of
water; -- usually by immersing in an organic solvent to remove
grease.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>dry-cleaned</ent><br/
<hw>dry-cleaned</hw> <pos>adj.</pos> <def>cleaned without the use of
water; -- usually by immersing in an organic solvent to remove
grease.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dry dock</ent><br/
<hw>Dry" dock`</hw> <pr>(?)</pr>. <fld>(Naut.)</fld> <def>See under
<er>Dock</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dryer</ent><br/
<hw>Dry"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Drier</er>.</def> <rj><au>Sir W. Temple.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dry-eyed</ent><br/
<hw>Dry"-eyed`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Not having tears in
the eyes. Opposite of <ant>tearful</ant>.</def><br/
<syn><b>Syn. --</b> tearless.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dry-fisted</ent><br/
<hw>Dry"-fist`ed</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Niggardly.</def><br/
<syn><b>Syn. --</b> stingy; cheap; miserly.</syn>
[<source>1913 Webster</source>]</p>

<p><ent>Dryfoot</ent><br/
<hw>Dry"foot</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The scent of the
game, as far as it can be traced.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dry goods</ent><br/
<hw>Dry" goods`</hw> <pr>(?)</pr>. <def>A commercial name for textile
fabrics, cottons, woolens, linen, silks, laces, etc., -- in distinction
from <xex>groceries</xex>.</def> <mark>[U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drying</ent><br/
<hw>Dry"ing</hw>, <pos>a.</pos> <sn>1.</sn> <def>Adapted or tending to
exhaust moisture; <as>as, a <ex>drying</ex> wind or day; a
<ex>drying</ex> room.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Having the quality of rapidly becoming
dry.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Drying oil</b></col>, <cd>an oil which, either naturally
or after boiling with oxide of lead, absorbs oxygen from the air and
dries up rapidly. <xex>Drying oils</xex> are used as the bases of many
paints and varnishes.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dryly</ent><br/
<hw>Dry"ly</hw>, <pos>adv.</pos> <def>In a dry manner; not succulently;
without interest; without sympathy; coldly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drymoglossum</ent><br/
<hw>Drymoglossum</hw> <pos>n.</pos> <def>a genus of epiphytic ferns of
Madagascar to tropical Asia and New Guinea.</def><br/
<syn><b>Syn. --</b> genus <gen>Drymoglossum</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Drynaria</ent><br/
<hw>Drynaria</hw> <pos>n.</pos> <def>a genus of large robust epiphytic
ferns of tropical forest and scrub; Africa and Asia and
Australia.</def><br/
<syn><b>Syn. --</b> genus <gen>Drynaria</gen>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dryness</ent><br/
<hw>Dry"ness</hw>, <pos>n.</pos> <def>The state of being dry. See
<er>Dry</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dry nurse</ent><br/
<hw>Dry" nurse`</hw> <pr>(?)</pr>. <def>A nurse who attends and feeds a
child by hand; -- in distinction from a <contr>wet nurse</contr>, who
suckles it.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>dry-nurse</ent><br/
<ent>Drynurse</ent><br/
<mhw><hw>Dry"nurse`</hw>, <hw>dry"-nurse`</hw></mhw>, <pos>v. t.</pos>
<def>To feed, attend, and bring up without breastfeeding it.</def>
<rj><au>Hudibras.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dryobalanops</ent><br/
\'d8<hw>Dry`o*bal"a*nops</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
Gr. <grk>dry^s</grk> oak + <grk>ba`lanos</grk> acorn +
<grk>'o`psis</grk> appearance. The fruit remotely resembles an acorn in
its cup.]</ety> <fld>(Bot.)</fld> <def>The genus to which belongs the
single species <spn>Dryobalanops Camphora</spn>, a lofty resinous tree
of Borneo and Sumatra, yielding Borneo camphor and camphor
oil.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>drypis</ent><br/
<hw>drypis</hw> <pos>n.</pos> <def>a spiny-leaved perennial herb of
southern Europe having terminal clusters of small flowers.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dry-rub</ent><br/
<hw>Dry"-rub`</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Dry-rubbed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Dry-rubbing</conjf>.]</vmorph> <def>To rub and cleanse
without wetting.</def> <rj><au>Dodsley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drysalter</ent><br/
<hw>Dry"salt`er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A dealer in salted
or dried meats, pickles, sauces, etc., and in the materials used in
pickling, salting, and preserving various kinds of food Hence drysalters
usually sell a number of saline substances and miscellaneous
drugs.</def> <rj><au>Brande & C.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Drysaltery</ent><br/
<hw>Dry"salt`er*y</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The articles
kept by a drysalter; also, the business of a drysalter.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dry-shod</ent><br/
<hw>Dry"-shod`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Without wetting the
feet; having or keeping the feet or shoes dry; <as>as, a land bridge
over which man and beasts could have crossed
<ex>dry-shod</ex></as>.</def><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><ent>Dry-stone</ent><br/
<hw>Dry"-stone`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Constructed of
uncemented stone.</def> <ldquo/<xex>Dry-stone</xex> walls.<rdquo/
<rj><au>Sir W. Scott.</au></rj></p>

<p><ent>Drith</ent><br/
<ent>Dryth</ent><br/
<mhw>{ <hw>Dryth</hw> <pr>(?)</pr>, <it>or</it> <hw>Drith</hw> }</mhw>,
<pos>n.</pos> <def>Drought.</def> <mark>[Obs.]</mark>
<rj><au>Tyndale.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duad</ent><br/
<hw>Du"ad</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See
<er>Dyad</er>.]</ety> <def>A union of two; duality.</def>
<mark>[R.]</mark> <rj><au>Harris.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dual</ent><br/
<hw>Du"al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>dualis</ets>,
fr. <ets>duo</ets> two. See <er>Two</er>.]</ety> <def>Expressing, or
consisting of, the number two; belonging to two; <as>as, the
<ex>dual</ex> number of nouns, etc.</as> , in Greek.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Here you have one half of our <qex>dual</qex> truth.</q>
<rj><qau>Tyndall.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dualin</ent><br/
<hw>Du"a*lin</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld> <def>An
explosive substance consisting essentially of sawdust or wood pulp,
saturated with nitroglycerin and other similar nitro compounds. It is
inferior to dynamite, and is more liable to explosion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dualism</ent><br/
<hw>Du"al*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>dualisme</ets>.]</ety> <def>State of being dual or twofold; a
twofold division; any system which is founded on a double principle, or
a twofold distinction</def>; as: <sd>(a)</sd> <fld>(Philos.)</fld>
<def>A view of man as constituted of two original and independent
elements, as matter and spirit.</def> <fld>(Theol.)</fld> <sd>(b)</sd>
<def>A system which accepts two gods, or two original principles, one
good and the other evil.</def> <sd>(c)</sd> <def>The doctrine that all
mankind are divided by the arbitrary decree of God, and in his eternal
foreknowledge, into two classes, the elect and the reprobate.</def>
<sd>(d)</sd> <fld>(Physiol.)</fld> <def>The theory that each cerebral
hemisphere acts independently of the other.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>An inevitable <qex>dualism</qex> bisects nature, so that each
thing is a half, and suggests another thing to make it whole.</q>
<rj><qau>Emerson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dualist</ent><br/
<hw>Du"al*ist</hw>, <pos>n.</pos> <ety>[Cf. F.
<ets>dualiste</ets>.]</ety> <sn>1.</sn> <def>One who believes in
dualism; a ditheist.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>One who administers two offices.</def> <rj><au>
Fuller.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dualistic</ent><br/
<hw>Du`al*is"tic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Consisting of
two; pertaining to dualism or duality.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Dualistic system</b></col> <it>or</it>
<col><b>Dualistic theory</b></col></mcol> <fld>(Chem.)</fld>, <cd>an old
theory, originated by Lavoisier and developed by Berzelius, that all
definite compounds are binary in their nature, and consist of two
distinct constituents, themselves simple or complex, and possessed of
opposite chemical or electrical affinities; -- superseded by later
developments in chemical bonding theory, especially quantum
mechanics.</cd></cs><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Duality</ent><br/
<hw>Du"al"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>dualitas</ets>: cf. F. <ets>dualit<eacute/</ets>.]</ety> <def>The
quality or condition of being two or twofold; dual character or
usage.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duan</ent><br/
<hw>Du"an</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gael. & Ir.]</ety>
<def>A division of a poem corresponding to a canto; a poem or
song.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duarchy</ent><br/
<hw>Du"ar*chy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ two +
<ets>-archy</ets>.]</ety> <def>Government by two persons.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dub</ent><br/
<hw>Dub</hw> <pr>(d<ucr/b)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Dubbed</conjf> <pr>(d<ucr/bd)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Dubbing</conjf>.]</vmorph> <ety>[AS. <ets>dubban</ets>
to strike, beat (<ldquo/<ets>dubbade</ets> his sunu . . . to
r<imac/dere.<rdquo/ <au>AS. Chron.</au> an. 1086); akin to Icel.
<ets>dubba</ets>; cf. OF. <ets>adouber</ets> (prob. fr. Icel.) a
chevalier, Icel. <ets>dubba</ets> til riddara.]</ety> <sn>1.</sn>
<def>To confer knighthood upon; <as>as, the king <ex>dubbed</ex> his son
Henry a knight</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The conclusion of the ceremony was marked by a tap on
the shoulder with the sword.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To invest with any dignity or new character; to
entitle; to call.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A man of wealth is <qex>dubbed</qex> a man of worth.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To clothe or invest; to ornament; to adorn.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>His diadem was dropped down<br/
<qex>Dubbed</qex> with stones.</q> <rj><qau>Morte
d'Arthure.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To strike, rub, or dress smooth; to dab;</def>
<specif>as:</specif> <sd>(a)</sd> <def>To dress with an adz; <as>as, to
<ex>dub</ex> a stick of timber smooth</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 459 --></p>

<p><sd>(b)</sd> <def>To strike cloth with teasels to raise a nap.</def>
<au>Halliwell.</au> <sd>(c)</sd> <def>To rub or dress with grease, as
leather in the process of currying it.</def> <au>Tomlinson.</au>
<sd>(d)</sd> <def>To prepare for fighting, as a gamecock, by trimming
the hackles and cutting off the comb and wattles.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To dub a fly</b></col>, <cd>to dress a fishing fly.</cd>
<mark>[Prov. Eng.]</mark> <au>Halliwell.</au> -- <col><b>To dub
out</b></col> <fld>(Plastering)</fld>, <cd>to fill out, as an uneven
surface, to a plane, or to carry out a series of small
projections.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dub</ent><br/
<hw>Dub</hw> <pr>(d<ucr/b)</pr>, <pos>v. i.</pos> <def>To make a noise
by brisk drumbeats.</def> <ldquo/Now the drum <xex>dubs</xex>.<rdquo/
<rj><au>Beau. & Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dub</ent><br/
<hw>Dub</hw> <pr>(d<ucr/b)</pr>, <pos>v. t.</pos> <sn>1.</sn> <def>to
add sound to an existing recording, audio or video; -- often used with
<ptcl>in</ptcl>. The sound may be of any type or of any
duration.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>to mix together two or more sound or video
recordings to produce a composite recording.</def><br/
[<source>PJC</source>]</p>

<p><ent>Dub</ent><br/
<hw>Dub</hw>, <pos>n.</pos> <def>A blow.</def> <mark>[R.]</mark>
<rj><au>Hudibras.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dub</ent><br/
<hw>Dub</hw>, <pos>n.</pos> <ety>[Cf. Ir. <ets>d<oacute/b</ets> mire,
stream, W. <ets>dwvr</ets> water.]</ety> <def>A pool or puddle.</def>
<mark>[Prov. Eng.]</mark> <rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dubb</ent><br/
<hw>Dubb</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Ar.]</ety>
<fld>(Zool.)</fld> <def>The Syrian bear. See under <er>Bear</er>.</def>
<altsp>[Written also <asp>dhubb</asp>, and <asp>dub</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dubber</ent><br/
<hw>Dub"ber</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, dubs.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dubber</ent><br/
<hw>Dub"ber</hw>, <pos>n.</pos> <ety>[Hind. <ets>dabbah</ets>.]</ety>
<def>A globular vessel or bottle of leather, used in India to hold ghee,
oil, etc.</def> <altsp>[Also written <asp>dupper</asp>.]</altsp>
<rj><au>M'Culloch.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dubbing</ent><br/
<hw>Dub"bing</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The act
of dubbing, as a knight, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The act of rubbing, smoothing, or dressing; a
dressing off smooth with an adz.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A dressing of flour and water used by weavers; a
mixture of oil and tallow for dressing leather; daubing.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The body substance of an angler's fly.</def>
<rj><au>Davy.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dubiety</ent><br/
<hw>Du*bi"e*ty</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Dubieties</plw> <pr>(#)</pr>.</plu> <ety>[L. <ets>dubietas</ets>,
fr. <ets>dubius</ets>. See <er>Dubious</er>.]</ety> <def>Doubtfulness;
uncertainty; doubt.</def> <mark>[R.]</mark> <au>Lamb.</au> <ldquo/The
<xex>dubiety</xex> of his fate.<rdquo/ <rj><au>Sir W.
Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dubiosity</ent><br/
<hw>Du`bi*os"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Dubiosities</plw> <pr>(#)</pr>.</plu> <ety>[L.
<ets>dubiosus</ets>.]</ety> <def>The state of being doubtful; a doubtful
statement or thing.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Men often swallow falsities for truths, <qex>dubiosities</qex> for
certainties, possibilities for feasibilities.</q> <rj><qau>Sir T.
Browne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dubious</ent><br/
<hw>Du"bi*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>dubius</ets>, <ets>dubiosus</ets>, fr. <ets>duo</ets> two. See
<er>Two</er>, and cf. <er>Doubt</er>.]</ety> <sn>1.</sn> <def>Doubtful
or not settled in opinion; being in doubt; wavering or fluctuating;
undetermined.</def> <ldquo/<xex>Dubious</xex> policy.<rdquo/ <rj><au>Sir
T. Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>dubious</qex>, agitated state of mind.</q>
<rj><au>Thackeray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Occasioning doubt; not clear, or obvious; equivocal;
questionable; doubtful; <as>as, a <ex>dubious</ex>
answer</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Wiping the dingy shirt with a still more <qex>dubious</qex> pocket
handkerchief.</q> <rj><qau>Thackeray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Of uncertain event or issue; <as>as, in
<ex>dubious</ex> battle</as>.</def></p>

<p><syn><b>Syn.</b> -- Doubtful; doubting; unsettled; undetermined;
equivocal; uncertain. Cf. <er>Doubtful</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dubiously</ent><br/
<hw>Du"bi*ous*ly</hw>, <pos>adv.</pos> <def>In a dubious
manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dubiousness</ent><br/
<hw>Du"bi*ous*ness</hw>, <pos>n.</pos> <def>State of being
dubious.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dubitable</ent><br/
<hw>Du"bi*ta*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>dubitabilis</ets>. Cf. <er>Doubtable</er>.]</ety> <def>Liable to be
doubted; uncertain.</def> <mark>[R.]</mark> <au>Dr. H. More.</au> --
<wordforms><wf>Du"bi*ta*bly</wf>, <pos>adv.</pos>
<mark>[R.]</mark></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dubitancy</ent><br/
<hw>Du"bi*tan*cy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL.
<ets>dubitantia</ets>.]</ety> <def>Doubt; uncertainty.</def>
<mark>[R.]</mark> <rj><au>Hammond.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dubitate</ent><br/
<hw>Du"bi*tate</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[L.
<ets>dubitatus</ets>, p. p. of <ets>dubitare</ets>. See
<er>Doubt</er>.]</ety> <def>To doubt.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>If he . . . were to loiter <qex>dubitating</qex>, and not
come.</q> <rj><qau>Carlyle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dubitation</ent><br/
<hw>Du`bi*ta"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>dubitatio</ets>.]</ety> <def>Act of doubting; doubt.</def>
<mark>[R.]</mark> <rj><au>Sir T. Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dubitative</ent><br/
<hw>Du"bi*ta*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>dubitativus</ets>: cf. F. <ets>dubitatif</ets>.]</ety> <def>Tending
to doubt; doubtful.</def> <mark>[R.]</mark> --
<wordforms><wf>Du"bi*ta*tive*ly</wf>, <pos>adv.</pos>
<mark>[R.]</mark></wordforms> <rj><au>. Eliot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dublin</ent><br/
<hw>Dublin</hw> <pos>prop. n.</pos> <fld>(Geography)</fld> <def>The
capital <isa>city</isa> of <country>Ireland</country>. Population (2000)
= nk.</def><br/
[<source>PJC</source>]</p>

<p><ent>Duboisia</ent><br/
\'d8<hw>Du*bois"i*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL.]</ety>
<fld>(Med.)</fld> <def>Same as <er>Duboisine</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duboisine</ent><br/
<hw>Du*bois"ine</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Med.)</fld>
<def>An alkaloid obtained from the leaves of an Australian tree
(<spn>Duboisia myoporoides</spn>), and regarded as identical with
<altname>hyoscyamine</altname>. It produces dilation of the pupil of the
eye.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ducal</ent><br/
<hw>Du"cal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[F. <ets>ducal</ets>.
See <er>Duke</er>.]</ety> <def>Of or pertaining to a duke.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His <qex>ducal</qex> cap was to be exchanged for a kingly
crown.</q> <rj><qau>Motley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ducally</ent><br/
<hw>Du"cal*ly</hw>, <pos>adv.</pos> <def>In the manner of a duke, or in
a manner becoming the rank of a duke.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ducat</ent><br/
<hw>Duc"at</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>ducat</ets>,
It. <ets>ducato</ets>, LL. <ets>ducatus</ets>, fr. <ets>dux</ets> leader
or commander. See <er>Duke</er>.]</ety> <def>A coin, either of gold or
silver, of several countries in Europe; originally, one struck in the
dominions of a duke.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The gold ducat is generally of the value of nine
shillings and four pence sterling, or somewhat more that two dollars.
The silver ducat is of about half this value.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ducatoon</ent><br/
<hw>Duc`a*toon"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. or Sp.
<ets>ducaton</ets>, fr. <ets>ducat</ets>.]</ety> <def>A silver coin of
several countries of Europe, and of different values.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duces tecum</ent><br/
\'d8<hw>Du"ces te"cum</hw> <pr>(?)</pr>. <ety>[L., bring with
thee.]</ety> <def>A judicial process commanding a person to appear in
court and bring with him some piece of evidence or other thing to be
produced to the court.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duchess</ent><br/
<hw>Duch"ess</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>duchesse</ets>, fr. <ets>duc</ets> duke.]</ety> <def>The wife or
widow of a duke; also, a lady who has the sovereignty of a duchy in her
own right.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duchesse d'Angouleme</ent><br/
\'d8<hw>Du`chesse" d'An`gou`l<ecir/me"</hw> <pr>(?)</pr>.
<ety>[F.]</ety> <fld>(Bot.)</fld> <def>A variety of pear of large size
and excellent flavor.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duchesse lace</ent><br/
<hw>Du`chesse" lace</hw> <pr>(?)</pr>. <def>A beautiful variety of
Brussels pillow lace made originally in Belgium and resembling Honiton
guipure. It is worked with fine thread in large sprays, usually of the
primrose pattern, with much raised work.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Duchy</ent><br/
<hw>Duch"y</hw> <pr>(d<ucr/ch"<ycr/)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>Duchies</plw> <pr>(#)</pr>.</plu> <ety>[F.
<ets>duch<eacute/</ets>, OF. <ets>duch<eacute/e</ets>, (assumed) LL.
<ets>ducitas</ets>, fr. L. <ets>dux</ets>. See <er>Duke</er>.]</ety>
<def>The territory or dominions of a duke; a dukedom.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duck</ent><br/
<hw>Duck</hw> <pr>(d<ucr/k)</pr>, <pos>n.</pos> <ety>[Cf. Dan.
<ets>dukke</ets>, Sw. <ets>docka</ets>, OHG. <ets>doccha</ets>, G.
<ets>docke</ets>. Cf. <er>Doxy</er>.]</ety> <def>A pet; a darling.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duck</ent><br/
<hw>Duck</hw>, <pos>n.</pos> <ety>[D. <ets>doek</ets> cloth, canvas, or
Icel. <ets>d<umac/kr</ets> cloth; akin to OHG. <ets>tuoh</ets>, G.
<ets>tuch</ets>, Sw. <ets>duk</ets>, Dan. <ets>dug</ets>.]</ety>
<sn>1.</sn> <def>A linen (or sometimes cotton) fabric, finer and lighter
than canvas, -- used for the lighter sails of vessels, the sacking of
beds, and sometimes for men's clothing.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Naut.)</fld> <pluf>pl.</pluf> <def>The light
clothes worn by sailors in hot climates.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duck</ent><br/
<hw>Duck</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Ducked</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Ducking</conjf>.]</vmorph> <ety>[OE. <ets>duken</ets>,
<ets>douken</ets>, to dive; akin to D. <ets>duiken</ets>, OHG.
<ets>t<?/hhan</ets>, MHG. <ets>tucken</ets>, <ets>t<uum/cken</ets>,
<ets>t<?/chen</ets>, G. <ets>tuchen</ets>. Cf. 5th <er>Duck</er>.]</ety>
<sn>1.</sn> <def>To thrust or plunge under water or other liquid and
suddenly withdraw.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Adams, after <qex>ducking</qex> the squire twice or thrice, leaped
out of the tub.</q> <rj><qau>Fielding.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To plunge the head of under water, immediately
withdrawing it; <as>as, <ex>duck</ex> the boy</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To bow; to bob down; to move quickly with a downward
motion.</def> <ldquo/ Will <xex>duck</xex> his head aside.<rdquo/
<rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duck</ent><br/
<hw>Duck</hw> <pr>(d<ucr/k)</pr>, <pos>v. i.</pos> <sn>1.</sn> <def>To
go under the surface of water and immediately reappear; to dive; to
plunge the head in water or other liquid; to dip.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>In Tiber <qex>ducking</qex> thrice by break of day.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To drop the head or person suddenly; to
bow.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The learned pate<br/
<qex>Ducks</qex> to the golden fool.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duck</ent><br/
<hw>Duck</hw>, <pos>n.</pos> <ety>[OE. <ets>duke</ets>, <ets>doke</ets>.
See <er>Duck</er>, <pos>v. t.</pos> ]</ety> <sn>1.</sn>
<fld>(Zool.)</fld> <def>Any bird of the subfamily <fam>Anatin<ae/</fam>,
family <fam>Anatid<ae/</fam>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The genera and species are numerous. They are divided
into <stype>river ducks</stype> and <stype>sea ducks</stype>. Among the
former are the common domestic duck (<spn>Anas boschas</spn>); the wood
duck (<spn>Aix sponsa</spn>); the beautiful mandarin duck of China
(<spn>Dendronessa galeriliculata</spn>); the Muscovy duck, originally of
South America (<spn>Cairina moschata</spn>). Among the sea ducks are the
eider, canvasback, scoter, etc.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A sudden inclination of the bead or dropping of the
person, resembling the motion of a duck in water.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Here be, without <qex>duck</qex> or nod,<br/
Other trippings to be trod.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Bombay duck</b></col> <fld>(Zool.)</fld>, <cd>a fish. See
<er>Bummalo</er>.</cd> -- <mcol><col><b>Buffel duck</b></col>,
<col><b>Spirit duck</b></col></mcol>. <cd>See <er>Buffel duck</er>.</cd>
-- <col><b>Duck ant</b></col> <fld>(Zool.)</fld>, <cd>a species of white
ant in Jamaica which builds large nests in trees.</cd> -- <col><b>Duck
barnacle</b></col>. <fld>(Zool.)</fld> <cd>See <er>Goose
barnacle</er>.</cd> -- <col><b>Duck hawk</b></col>. <fld>(Zool.)</fld>
<sd>(a)</sd> <cd>In the United States: The peregrine falcon.</cd>
<sd>(b)</sd> <cd>In England: The marsh harrier or moor buzzard.</cd> --
<col><b>Duck mole</b></col> <fld>(Zool.)</fld>, <cd>a small aquatic
mammal of Australia, having webbed feet and a bill resembling that of a
duck (<spn>Ornithorhynchus anatinus</spn>). It belongs the subclass
Monotremata and is remarkable for laying eggs like a bird or reptile; --
called also <altname>duckbill</altname>, <altname>platypus</altname>,
<altname>mallangong</altname>, <altname>mullingong</altname>,
<altname>tambreet</altname>, and <altname>water mole</altname>.</cd> --
<col><b>To make ducks and drakes</b></col>, <cd>to throw a flat stone
obliquely, so as to make it rebound repeatedly from the surface of the
water, raising a succession of jets<-- = skipping stones --></cd>;
hence: <col><b>To play at ducks and drakes</b></col>, with property,
<cd>to throw it away heedlessly or squander it foolishly and
unprofitably.</cd> -- <col><b>Lame duck</b></col>. <cd>See under
<er>Lame</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duckbill</ent><br/
<hw>Duck"bill`</hw>, <pos>n.</pos> <fld>(Zool.)</fld> <def>See
<cref>Duck mole</cref>, under <er>Duck</er>, <pos>n.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>duck-billed</ent><br/
<hw>duck-billed</hw> <pos>adj.</pos> <sn>1.</sn> <def>having a beak
resembling that of a duck.</def> <illu></illu><br/
<syn><b>Syn. --</b> duckbill, duckbilled.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Duck-billed</ent><br/
<hw>Duck"-billed`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having a bill
like that of a duck; <as>as, a <ex>duck-billed</ex>
dinosaur</as>.</def>.<br/
[<source>1913 Webster</source>]</p>

<p><ent>Duck-billed platypus</ent><br/
<hw>Duck"-billed` plat"y*pus</hw> <pr>(?)</pr>, <pos>a.</pos> <def>same
as <cref>Duck Mole</cref>, under <er>Duck</er>.</def>.<br/
<syn><b>Syn. --</b> duck mole, duckbill, duck-bill platypus,
platypus.</syn>
[<source>PJC</source>]</p>

<p><ent>Ducker</ent><br/
<hw>Duck"er</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One who,
or that which, ducks; a plunger; a diver.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A cringing, servile person; a fawner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ducking</ent><br/
<hw>Duck"ing</hw>, <def><pos>n. & a.</pos>, from <er>Duck</er>, <pos>v.
t. & i.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Ducking stool</b></col>, <cd>a stool or chair in which
common scolds were formerly tied, and plunged into water, as a
punishment. See <er>Cucking stool</er>. The practice of ducking began in
the latter part of the 15th century, and prevailed until the early part
of the 18th, and occasionally as late as the 19th century.</cd>
<au>Blackstone. Chambers.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duck-legged</ent><br/
<hw>Duck"-legged`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having short
legs, like a waddling duck; short-legged.</def>
<rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duckling</ent><br/
<hw>Duck"ling</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A young or little
duck.</def> <rj><au>Gay.</au></rj></p>

<p><ent>Duck's-meat</ent><br/
<ent>Duckmeat</ent><br/
<mhw>{ <hw>Duck"meat`</hw> <pr>(?)</pr>, <hw>Duck's"-meat`</hw>
<pr>(?)</pr> }</mhw>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>Duckweed.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duck's-bill</ent><br/
<hw>Duck's"-bill`</hw>, <pos>a.</pos> <def>Having the form of a duck's
bill.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Duck's-bill limpet</b></col> <fld>(Zool.)</fld>, <cd>a
limpet of the genus <gen>Parmaphorus</gen>; -- so named from its
shape.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duck's-foot</ent><br/
<hw>Duck's"-foot`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld>
<def>The May apple (<spn>Podophyllum peltatum</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duckweed</ent><br/
<hw>Duck"weed`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>A
genus (<gen>Lemna</gen>) of small plants, seen floating in great
quantity on the surface of stagnant pools fresh water, and supposed to
furnish food for ducks; -- called also
<altname>duckmeat</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>ducky</ent><br/
<hw>ducky</hw> <pr>(d<ucr/k"<ycr/)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>fine; satisfactory; excellent.</def> <mark>[informal]</mark><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>charming; cute.</def> <mark>[informal]</mark><br/
[<source>PJC</source>]</p>

<p><ent>ducky</ent><br/
<hw>ducky</hw> <pr>(d<ucr/k"<ycr/)</pr>, <pos>n.</pos> <def>a special
loved one; a darling; -- used as a term of endearment.</def>
<mark>[Brit.]</mark> <br/
<syn><b>Syn. --</b> darling, favorite, favourite, pet, dearie,
deary.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Duct</ent><br/
<hw>Duct</hw> <pr>(d<ucr/kt)</pr>, <pos>n.</pos> <ety>[L.
<ets>ductus</ets> a leading, conducting, conduit, fr. <ets>ducere</ets>,
<ets>ductum</ets>, to lead. See <er>Duke</er>, and cf.
<er>Douche</er>.]</ety> <sn>1.</sn> <def>Any tube or canal by which a
fluid or other substance is conducted or conveyed.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Anat.)</fld> <def>One of the vessels of an animal
body by which the products of glandular secretion are conveyed to their
destination.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Bot.)</fld> <def>A large, elongated cell, either
round or prismatic, usually found associated with woody fiber.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Ducts</xex> are classified, according to the
character of the surface of their walls, or their structure, as annular,
spiral, scalariform, etc.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Guidance; direction.</def> <mark>[Obs.]</mark>
<rj><au>Hammond.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ductible</ent><br/
<hw>Duc"ti*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of being
drawn out</def> <mark>[R.]</mark> <rj><au>Feltham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ductile</ent><br/
<hw>Duc"tile</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>ductilis</ets>, fr. <ets>ducere</ets> to lead: cf. F.
<ets>ductile</ets>. See <er>Duct</er>.]</ety> <sn>1.</sn> <def>Easily
led; tractable; complying; yielding to motives, persuasion, or
instruction; <as>as, a <ex>ductile</ex> people</as>.</def>
<rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Forms their <qex>ductile</qex> minds<br/
To human virtues.</q> <rj><qau>Philips.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Capable of being elongated or drawn out, as into
wire or threads.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Gold . . . is the softest and most <qex>ductile</qex> of all
metals.</q> <rj><qau>Dryden.</qau></rj></p>

<p>-- <wordforms><wf>Duc"tile*ly</wf> <pr>(#)</pr>, <pos>adv.</pos> --
<wf>Duc"tile*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ductilimeter</ent><br/
<hw>Duc`ti*lim"e*ter</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<ets>Ductile</ets> + <ets>-meter</ets>.]</ety> <def>An instrument
for accurately determining the ductility of metals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ductility</ent><br/
<hw>Duc*til"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>ductilit<eacute/</ets>.]</ety> <sn>1.</sn> <def>The property of a
metal which allows it to be drawn into wires or filaments.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Tractableness; pliableness.</def>
<rj><au>South.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duction</ent><br/
<hw>Duc"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>ductio</ets>, fr. <ets>ducere</ets> to lead.]</ety>
<def>Guidance.</def> <mark>[Obs.]</mark> <rj><au>Feltham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ductless</ent><br/
<hw>Duct"less</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having to duct or
outlet; <as>as, a <ex>ductless</ex> gland</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ductor</ent><br/
<hw>Duc"tor</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., fr.
<ets>ducere</ets> to lead.]</ety> <sn>1.</sn> <def>One who leads.</def>
<mark>[Obs.]</mark> <rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mach.)</fld> <def>A contrivance for removing
superfluous ink or coloring matter from a roller. See <er>Doctor</er>,
4.</def> <rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Ductor roller</b></col> <fld>(Printing)</fld>, <cd>the
roller which conveys or supplies ink to another roller.</cd>
<rj><au>Knight.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ducture</ent><br/
<hw>Duc"ture</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Guidance.</def>
<mark>[Obs.]</mark> <rj><au>South.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dudder</ent><br/
<hw>Dud"der</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[In Suffolk, Eng.,
to shiver, shake, tremble; also written <ets>dodder</ets>.]</ety>
<def>To confuse or confound with noise.</def>
<rj><au>Jennings.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dudder</ent><br/
<hw>Dud"der</hw>, <pos>v. i.</pos> <def>To shiver or tremble; to
dodder.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I <qex>dudder</qex> and shake like an aspen leaf.</q>
<rj><qau>Ford.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dudder</ent><br/
<hw>Dud"der</hw>, <pos>n.</pos> <ety>[From <er>Duds</er>.]</ety> <def>A
peddler or hawker, especially of cheap and flashy goods pretended to be
smuggled; a duffer.</def> <mark>[Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duddery</ent><br/
<hw>Dud"der*y</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A place where rags
are bought and kept for sale.</def> <mark>[Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dude</ent><br/
<hw>Dude</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A kind of dandy;
especially, one characterized by an ultrafashionable style of dress and
other affectations.</def> <mark>[Recent]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The social <qex>dude</qex> who affects English dress and English
drawl.</q> <rj><qau>The American.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dudeen</ent><br/
<hw>Du*deen"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A short tobacco
pipe.</def> <altsp>[Written also <asp>dudheen</asp>.]</altsp>
<mark>[Irish]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dudgeon</ent><br/
<hw>Dudg"eon</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The root
of the box tree, of which hafts for daggers were made.</def>
<rj><au>Gerarde (1597).</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The haft of a dagger.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A dudgeon-hafted dagger; a dagger.</def>
<rj><au>Hudibras.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dudgeon</ent><br/
<hw>Dudg"eon</hw>, <pos>n.</pos> <ety>[W. <ets>dygen</ets> anger,
grudge.]</ety> <def>Resentment; ill will; anger; displeasure.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I drink it to thee in <qex>dudgeon</qex> and hostility.</q><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Sir T</qex>. <qex>Scott</qex>.</q><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dudgeon</ent><br/
<hw>Dudg"eon</hw>, <pos>a.</pos> <def>Homely; rude; coarse.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>By my troth, though I am plain and <qex>dudgeon</qex>,<br/
I would not be an ass.</q> <rj><qau>Beau. & Fl.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dudish</ent><br/
<hw>Dud"ish</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Like, or characterized
of, a dude.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duds</ent><br/
<hw>Duds</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[Scot. <ets>dud</ets>
rag, pl. <ets>duds</ets> clothing of inferior quality.]</ety>
<sn>1.</sn> <def>Old or inferior clothes; tattered garments.</def>
<mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Effects, in general.</def><mark>[Slang]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Due</ent><br/
<hw>Due</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OF. <ets>deu</ets>, F.
<ets>d<ucir/</ets>, p. p. of <ets>devoir</ets> to owe, fr. L.
<ets>debere</ets>. See <er>Debt</er>, <er>Habit</er>, and cf.
<er>Duty</er>.]</ety> <sn>1.</sn> <def>Owed, as a debt; that ought to be
paid or done to or for another; payable; owing and demandable.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Justly claimed as a right or property; proper;
suitable; becoming; appropriate; fit.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Her obedience, which is <qex>due</qex> to me.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>With dirges <qex>due</qex>, in sad array,<br/
Slow through the churchway path we saw him borne.</q>
<rj><qau>Gray.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Such as (a thing) ought to be; fulfilling
obligation; proper; lawful; regular; appointed; sufficient; exact;
<as>as, <ex>due</ex> process of law; <ex>due</ex> service; in
<ex>due</ex> time.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Appointed or required to arrive at a given time;
<as>as, the steamer was <ex>due</ex> yesterday</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Owing; ascribable, as to a cause.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This effect is <qex>due</qex> to the attraction of the sun.</q>
<rj><qau>J. D. Forbes.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Due</ent><br/
<hw>Due</hw>, <pos>adv.</pos> <def>Directly; exactly; <as>as, a
<ex>due</ex> east course</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Due</ent><br/
<hw>Due</hw>, <pos>n.</pos> <sn>1.</sn> <def>That which is owed; debt;
that which one contracts to pay, or do, to or for another; that which
belongs or may be claimed as a right; whatever custom, law, or morality
requires to be done; a fee; a toll.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He will give the devil his <qex>due</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Yearly little <qex>dues</qex> of wheat, and wine, and oil.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Right; just title or claim.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The key of this infernal pit by <qex>due</qex> . . . <qex>I
keep</qex>.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Due</ent><br/
<hw>Due</hw>, <pos>v. t.</pos> <def>To endue.</def> <mark>[Obs.]</mark>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duebill</ent><br/
<hw>Due"bill`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Com.)</fld> <def>A
brief written acknowledgment of a debt, not made payable to order, like
a promissory note.</def> <rj><au>Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dueful</ent><br/
<hw>Due"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Fit; becoming.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duel</ent><br/
<hw>Du"el</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[It. <ets>duello</ets>,
fr. L. <ets>duellum</ets>, orig., a contest between two, which passed
into the common form <ets>bellum</ets> war, fr. <ets>duo</ets> two: cf.
F. <ets>duel</ets>. See <er>Bellicose</er>, <er>Two</er>, and cf.
<er>Duello</er>.]</ety> <def>A combat between two persons, fought with
deadly weapons, by agreement. It usually arises from an injury done or
an affront given by one to the other.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Trial by duel</b></col> <fld>(Old Law)</fld>, <cd>a
combat between two persons for proving a cause; trial by
battel.</cd></cs> <-- NOte: this is the correct spelling of "battel"!
--><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duel</ent><br/
<hw>Du"el</hw>, <pos>v. i. & t.</pos> <def>To fight in single
combat.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dueler</ent><br/
<hw>Du"el*er</hw>, <pos>n.</pos> <def>One who engages in a duel.</def>
<mark>[R.]</mark> <altsp>[Written also <asp>dueller</asp>.]</altsp>
<rj><au>South.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dueling</ent><br/
<hw>Du"el*ing</hw>, <pos>n.</pos> <def>The act or practice of fighting
in single combat. Also <pos>adj.</pos></def> <altsp>[Written also
<asp>duelling</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duelist</ent><br/
<hw>Du"el*ist</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>duelliste</ets>.]</ety> <def>One who fights in single combat.</def>
<altsp>[Written also <asp>duellist</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>duelist</qex> . . . always values himself upon his courage,
his sense of honor, his fidelity and friendship.</q>
<rj><qau>Hume.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duelo</ent><br/
\'d8<hw>Du*e"lo</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[It. See
<er>Duel</er>.]</ety> <def>A duel; also, the rules of dueling.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duena</ent><br/
\'d8<hw>Du*e"<ntil/a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sp.]</ety>
<def>See <er>Do<ntil/a</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 460 --></p>

<p><ent>Dueness</ent><br/
<hw>Due"ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Quality of being due;
debt; what is due or becoming.</def> <rj><au>T. Goodwin.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duenna</ent><br/
<hw>Du*en"na</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Duennas</plw> <pr>(#)</pr>.</plu> <ety>[Sp. <ets>due<ntil/a</ets>,
<ets>do<ntil/a</ets>, fr. L. <ets>domina</ets>. See
<er>Dame</er>.]</ety> <sn>1.</sn> <def>The chief lady in waiting on the
queen of Spain.</def> <rj><au>Brande.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An elderly lady holding a station between a
governess and companion, and appointed to have charge over the younger
ladies in a Spanish or a Portuguese family.</def> <rj><au>Brande &
C.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Any old woman who is employed to guard a younger
one; a governess.</def> <rj><au>Arbuthnot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duet</ent><br/
<hw>Du*et"</hw> <pr>(?)</pr>, <pos>n.</pos>
<ety>[<er>Duetto</er>.]</ety> <fld>(Mus.)</fld> <def>A composition for
two performers, whether vocal or instrumental.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duettino</ent><br/
\'d8<hw>Du`et*ti"no</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[It ., dim.
fr. <ets>duetto</ets> a duet.]</ety> <def>A duet of short extent and
concise form.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duetto</ent><br/
\'d8<hw>Du*et"to</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[It., fr. It & L.
<ets>duo</ets> two. See <er>Two</er>.]</ety> <def>See
<er>Duet</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duff</ent><br/
<hw>Duff</hw> <pr>(d<ucr/f)</pr>, <pos>n.</pos> <ety>[From OE.
<ets>dagh</ets>. <root/67. See <er>Dough</er>.]</ety> <sn>1.</sn>
<def>Dough or paste.</def> <mark>[Prov. Eng.]</mark>
<rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A stiff flour pudding, boiled in a bag; -- a term
used especially by seamen; <as>as, plum <ex>duff</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duff</ent><br/
<hw>Duff</hw> <pr>(d<ucr/f)</pr>, <pos>n.</pos> <def>the buttocks;
<as>as, get off your <ex>duff</ex> and get to work</as>.</def>
<mark>[slang]</mark><br/
<syn><b>Syn. --</b> rump; ass.</syn>
[<source></source>]</p>

<p><ent>Duff</ent><br/
<hw>Duff</hw> <pr>(d<ucr/f)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Duffed</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Duffing</conjf>.]</vmorph> <ety>[Etym. uncertain.]</ety>
<mark>[Colloq. or Slang]</mark> <sn>1.</sn> <def>To treat or manipulate
so as to give a specious appearance to; to fake; hence, to
cheat.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <def>In Australia, to alter the brands on (cattle,
horses, etc.); to steal (cattle, etc.), and alter their
brands.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Duffel</ent><br/
<hw>Duf"fel</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[D. <ets>duffel</ets>,
from <ets>Duffel</ets>, a town not far from Antwerp.]</ety> <sn>1.</sn>
<def>A kind of coarse woolen cloth, having a thick nap or frieze.</def>
<altsp>[Written also <asp>duffle</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><q>Good <qex>duffel</qex> gray and flannel fine.</q> <rj><qau>
Wordsworth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Outfit or suppplies, collectively; kit.</def>
<mark>[Colloq., U. S.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Duffel bag</ent><br/
<hw>Duffel bag</hw>. <def>A sack to hold miscellaneous articles, as
tools, supplies, or the like.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Duffer</ent><br/
<hw>Duf"fer</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A peddler
or hawker, especially of cheap, flashy articles, as sham jewelry; hence,
a sham or cheat.</def> <mark>[Slang, Eng.]</mark>
<rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A stupid, awkward, inefficient
person.</def><mark>[Slang]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duffer</ent><br/
<hw>Duf"fer</hw>, <pos>n.</pos> <sn>1.</sn> <fld>(Mining)</fld> <def>See
<er>Shicer</er>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>Any common domestic
pigeon.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Duffer</ent><br/
<hw>Duf"fer</hw>, <pos>n.</pos> <def>One who duffs cattle, etc.</def>
<mark>[Australia]</mark></p>

<p><q>Unluckily, cattle stealers are by no means so rare as would be
desirable; they are locally known as <qex>duffers</qex>.</q>
<rj><qau>Baden-Powell.</qau></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Duffle</ent><br/
<hw>Duf"fle</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Duffel</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dufrenite</ent><br/
<hw>Du*fren"ite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From <?/<?/ierre
Armand <ets>Dufr<eacute/noy</ets>, a French geologist.]</ety>
<fld>(Min.)</fld> <def>A mineral of a blackish green color, commonly
massive or in nodules. It is a hydrous phosphate of iron.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dug</ent><br/
<hw>Dug</hw> <pr>(d<ucr/g)</pr>, <pos>n.</pos> <ety>[Akin to Sw.
<ets>d<aum/gga</ets> to suckle (a child), Dan. <ets>d<ae/gge</ets>, and
prob. to Goth. <ets>daddjan</ets>. <root/66.]</ety> <def>A teat, pap, or
nipple; -- formerly that of a human mother, now that of a cow or other
beast.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With mother's <qex>dug</qex> between its lips.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dug</ent><br/
<hw>Dug</hw>, <def><pos>imp. & p. p.</pos> of <er>Dig</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dugong</ent><br/
<hw>Du*gong"</hw> <pr>(d<usdot/*g<ocr/g")</pr>, <pos>n.</pos>
<ety>[Malayan <ets>d<umac/y<omac/ng</ets>, or Javan.
<ets>duyung</ets>.]</ety> <fld>(Zool.)</fld> <def>An aquatic herbivorous
mammal (<spn>Halicore dugong</spn>), of the order <ord>Sirenia</ord>,
allied to the manatee, but with a bilobed tail. It inhabits the Red Sea,
Indian Ocean, East Indies, and Australia.</def> <altsp>[Written also
<asp>duyong</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dugout</ent><br/
<hw>Dug"out`</hw> <pr>(d<ucr/g"out)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>A canoe or boat dug out from a large log.</def>
<mark>[U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>A man stepped from his slender <qex>dugout</qex>.</q> <rj><qau> G.
W. Cable.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A place dug out.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A house made partly in a hillside or slighter
elevation.</def> <mark>[Western U.S.]</mark>
<rj><au>Bartlett.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Baseball)</fld> <def>a structure on the edge of the
playing field in foul territory, partly below ground and partly above
ground, open toward the playing field but roofed and with the other
three sides closed. It is typically long and narrow, having benches
where the players may sit when not on the playing field; <as>as, the
foul ball was tipped into the <ex>dugout</ex></as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Dugway</ent><br/
<hw>Dug"way`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A way or road dug
through a hill, or sunk below the surface of the land.</def>
<mark>[U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duke</ent><br/
<hw>Duke</hw> <pr>(d<umac/k)</pr>, <pos>n.</pos> <ety>[F.
<ets>duc</ets>, fr. L. <ets>dux</ets>, <ets>ducis</ets>, leader,
commander, fr. <ets>ducere</ets> to lead; akin to AS.
<ets>te<oacute/n</ets> to draw; cf. AS. <ets>heretoga</ets>
(<ets>here</ets> army) an army leader, general, G. <ets>herzog</ets>
duke. See <er>Tue</er>, and cf. <er>Doge</er>, <er>Duchess</er>,
<er>Ducat</er>, <er>Duct</er>, <er>Adduce</er>, <er>Deduct</er>.]</ety>
<sn>1.</sn> <def>A leader; a chief; a prince.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Hannibal, <qex>duke</qex> of Carthage.</q> <rj><qau>Sir T.
Elyot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>All were <qex>dukes</qex> once, who were <ldquo/duces<rdquo/ --
captains or leaders of their people.</q> <rj><qau>Trench.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>In England, one of the highest order of nobility
after princes and princesses of the royal blood and the four archbishops
of England and Ireland.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>In some European countries, a sovereign prince,
without the title of king.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <pluf>pl.</pluf> <def>The fists; <as>as, put up your
<ex>dukes</ex></as>.</def> <mark>[slang]</mark><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Duke's coronet</b></col>. <cd>See <xex>Illust.</xex> of
<er>Coronet</er>.</cd> -- <col><b>To dine with Duke Humphrey</b></col>,
<cd>to go without dinner. See under <er>Dine</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duke</ent><br/
<hw>Duke</hw> <pr>(d<umac/k)</pr> <pos>v. i.</pos> <def>To play the
duke.</def> <mark>[Poetic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Lord Angelo <qex>dukes</qex> it well in his absence.</q> <rj><qau>
Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>duke</ent><br/
<hw>duke</hw> <pr>(d<umac/k)</pr> <pos>v. t.</pos> <def>To beat with the
fists.</def> <mark>[slang]</mark> <br/
[<source>PJC</source>]</p>

<p><cs><col><b>to duke it out</b></col> <cd>to fight; -- usually
implying, to fight with the fists; to settle a dispute by fighting with
the fists. See <ex>duke</ex>, <pos>n.</pos> sense 4.</cd></cs><br/
[<source>PJC</source>]</p>

<p><ent>Dukedom</ent><br/
<hw>Duke"dom</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The
territory of a duke.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The title or dignity of a duke.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dukeling</ent><br/
<hw>Duke"ling</hw>, <pos>n.</pos> <def>A little or insignificant
duke.</def> <rj><au>Ford.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dukeship</ent><br/
<hw>Duke"ship</hw>, <pos>n.</pos> <def>The quality or condition of being
a duke; also, the personality of a duke.</def>
<rj><au>Massinger.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dukhobortsy</ent><br/
<ent>Dukhobors</ent><br/
<mhw>{ <hw>Du*kho*bors"</hw> <pr>(?)</pr>, <hw>Du*kho*bor"tsy</hw>
<pr>(?)</pr> }</mhw>, <pos>n. pl.</pos> <ety>[Russ.
<ets>dukhobortsy</ets> spirit wrestlers; <ets>dukh</ets> spirit +
<ets>bortsy</ets> wrestlers.]</ety> <def>A Russian religious sect
founded about the middle of the 18th century at Kharkov. They believe
that Christ was wholly human, but that his soul reappears from time to
time in mortals. They accept the Ten Commandments and the
<ldquo/useful<rdquo/ portions of the Bible, but deny the need of rulers,
priests, or churches, and have no confessions, icons, or marriage
ceremonies. They are communistic, opposed to any violence, and unwilling
to use the labor of animals. Driven out of Russia proper, many have
emigrated to Cyprus and Canada. See <er>Raskolnik</er>, below.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Dulcamara</ent><br/
<hw>Dul`ca*ma"ra</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. L.
<ets>dulcis</ets> sweet + <ets>amarus</ets> bitter.]</ety>
<fld>(Bot.)</fld> <def>A plant (<spn>Solanum Dulcamara</spn>). See
<er>Bittersweet</er>, <pos>n.</pos>, 3 <sd>(a)</sd>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dulcamarin</ent><br/
<hw>Dul`ca*ma"rin</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chem.)</fld>
<def>A glucoside extracted from the bittersweet (<spn>Solanum
Dulcamara</spn>), as a yellow amorphous substance. It probably occasions
the compound taste. See <er>Bittersweet</er>, 3<sd>(a)</sd>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dulce</ent><br/
<hw>Dulce</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To make sweet; to
soothe.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dulceness</ent><br/
<hw>Dulce"ness</hw>, <pos>n.</pos> <def>Sweetness.</def>
<mark>[Obs.]</mark> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dulcet</ent><br/
<hw>Dul"cet</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OF.
<ets>doucet</ets>, dim. of <ets>dous</ets> sweet, F. <ets>doux</ets>, L.
<ets>dulcis</ets>; akin to Gr. <?/ . Cf. <er>Doucet</er>.]</ety>
<sn>1.</sn> <def>Sweet to the taste; luscious.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>She tempers <qex>dulcet</qex> creams.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Sweet to the ear; melodious; harmonious.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Their dainty lays and <qex>dulcet</qex> melody.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dulciana</ent><br/
\'d8<hw>Dul`ci*an"a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. L.
<ets>dulcis</ets> sweet.]</ety> <fld>(Mus.)</fld> <def>A sweet-toned
stop of an organ.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dulcification</ent><br/
<hw>Dul`ci*fi*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>dulcification</ets>.]</ety> <def>The act of dulcifying or
sweetening.</def> <rj><au>Boyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dulcified</ent><br/
<hw>Dul"ci*fied</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Sweetened;
mollified.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Dulcified spirit</b></col> <it>or</it>
<col><b>Dulcified spirits</b></col></mcol>, <cd>a compound of alcohol
with mineral acids; <as>as, <ex>dulcified spirits</ex> of
niter</as>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dulcifluous</ent><br/
<hw>Dul*cif"lu*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>dulcis</ets> sweet + <ets>fluere</ets> to flow.]</ety> <def>Flowing
sweetly.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dulcify</ent><br/
<hw>Dul"ci*fy</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Dulcified</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Dulcifying</conjf>.]</vmorph> <ety>[L. <ets>dulcis</ets>
sweet + <ets>-fy</ets>: cf. F. <ets>dulcifier</ets>.]</ety> <sn>1.</sn>
<fld>(Pharm.)</fld> <def>To sweeten; to free from acidity, saltness, or
acrimony.</def> <rj><au>Wiseman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Fig. : To mollify; to sweeten; to please.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>As she . . . was further <qex>dulcified</qex> by her pipe of
tobacco.</q> <rj><qau>Hawthorne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dulciloquy</ent><br/
<hw>Dul*cil"o*quy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>dulcis</ets> sweet + <ets>loqui</ets> to speak.]</ety> <def>A soft
manner of speaking.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dulcimer</ent><br/
<hw>Dul"ci*mer</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[It.
<ets>dolcemele</ets>,r Sp. <ets>dulcemele</ets>, fr. L.
<ets>dulcis</ets> sweet + <ets>melos</ets> song, melody, Gr. <?/; cf.
OF. <ets>doulcemele</ets>. See <er>Dulcet</er>, and
<er>Melody</er>.]</ety> <fld>(Mus.)</fld> <sd>(a)</sd> <def>An
instrument, having stretched metallic wires which are beaten with two
light hammers held in the hands of the performer.</def> <sd>(b)</sd>
<def>An ancient musical instrument in use among the Jews. <au>Dan. iii.
5.</au> It is supposed to be the same with the psaltery.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dulcinea</ent><br/
<hw>Dul*cin"e*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sp., from
<ets>Dulcinea del Toboso</ets> the mistress of the affections of Don
<er>Quixote</er>.]</ety> <def>A mistress; a sweetheart.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I must ever have some <qex>Dulcinea</qex> in my head.</q>
<rj><qau>Sterne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dulciness</ent><br/
<hw>Dul"ci*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Dulceness</er>.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dulcino</ent><br/
\'d8<hw>Dul*ci"no</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Mus.)</fld>
<def>See <er>Dolcino</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dulcite</ent><br/
<hw>Dul"cite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>dulcite</ets>, fr. L. <ets>dulcis</ets> sweet.]</ety>
<fld>(Chem.)</fld> <def>A white, sugarlike substance,
<chform>C6H8.(OH)2</chform>, occurring naturally in a manna from
Madagascar, and in certain plants, and produced artificially by the
reduction of galactose and lactose or milk sugar.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dulcitude</ent><br/
<hw>Dul"ci*tude</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>dulcitudo</ets>, fr. <ets>dulcis</ets> sweet.</ety>
<def>Sweetness.</def> <mark>[R.]</mark> <rj><au>Cockeram.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dulcorate</ent><br/
<hw>Dul"co*rate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[L.
<ets>dulcoratus</ets>, p. p. of <ets>dulcorare</ets>, fr.
<ets>dulcor</ets> sweetness, fr. <ets>dulcis</ets> sweet.]</ety> <def>To
sweeten; to make less acrimonious.</def> <mark>[R.]</mark>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dulcoration</ent><br/
<hw>Dul`co*ra"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL.
<ets>dulcoratio</ets>.]</ety> <def>The act of sweetening.</def>
<mark>[R.]</mark> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duledge</ent><br/
<hw>Du"ledge</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Mil.)</fld> <def>One
of the dowels joining the ends of the fellies which form the circle of
the wheel of a gun carriage.</def> <rj><au>Wilhelm.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dulia</ent><br/
\'d8<hw>Du*li"a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[LL., fr. Gr. <?/
servitude, fr. <?/ slave.]</ety> <fld>(R. C. Ch.)</fld> <def>An inferior
kind of veneration or worship, given to the angels and saints as the
servants of God.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dull</ent><br/
<hw>Dull</hw> <pr>(?)</pr>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Duller</adjf> <pr>(?)</pr>; <pos>superl.</pos>
<adjf>Dullest</adjf>.]</amorph> <ety>[AS. <ets>dol</ets> foolish; akin
to <ets>gedwelan</ets> to err, D. <ets>dol</ets> mad, <ets>dwalen</ets>
to wander, err, G. <ets>toll</ets> mad, Goth. <ets>dwals</ets> foolish,
stupid, cf. Gr. <?/ turbid, troubled, Skr. <ets>dhvr</ets> to cause to
fall. Cf. <er>Dolt</er>, <er>Dwale</er>, <er>Dwell</er>,
<er>Fraud</er>.]</ety> <sn>1.</sn> <def>Slow of understanding; wanting
readiness of apprehension; stupid; doltish; blockish.</def>
<ldquo/<xex>Dull</xex> at classical learning.<rdquo/
<rj><au>Thackeray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>She is not bred so <qex>dull</qex> but she can learn.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Slow in action; sluggish; unready;
awkward.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This people's heart is waxed gross, and their ears are
<qex>dull</qex> of hearing.</q> <rj><qau>Matt. xiii. 15.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>O, help my weak wit and sharpen my <qex>dull</qex> tongue.</q>
<rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Insensible; unfeeling.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Think me not<br/
So <qex>dull</qex> a devil to forget the loss<br/
Of such a matchless wife.</q> <rj><qau> Beau. & Fl.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Not keen in edge or point; lacking sharpness;
blunt.</def> <ldquo/Thy scythe is <xex>dull</xex>.<rdquo/
<rj><au>Herbert.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Not bright or clear to the eye; wanting in
liveliness of color or luster; not vivid; obscure; dim; <as>as, a
<ex>dull</ex> fire or lamp; a <ex>dull</ex> red or yellow; a
<ex>dull</ex> mirror.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Heavy; gross; cloggy; insensible; spiritless;
lifeless; inert.</def> <ldquo/The <xex>dull</xex> earth.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>As turning the logs will make a <qex>dull</qex> fire burn, so
changes of study a <qex>dull</qex> brain.</q> <rj><qau>
Longfellow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>Furnishing little delight, spirit, or variety;
uninteresting; tedious; cheerless; gloomy; melancholy; depressing;
<as>as, a <ex>dull</ex> story or sermon; a <ex>dull</ex> occupation or
period</as>; hence, cloudy; overcast; <as>as, a <ex>dull</ex>
day</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Along life's <qex>dullest</qex>, dreariest walk.</q> <rj><qau>
Keble.</qau></rj></p>

<p><syn><b>Syn.</b> -- Lifeless; inanimate; dead; stupid; doltish;
heavy; sluggish; sleepy; drowsy; gross; cheerless; tedious; irksome;
dismal; dreary; clouded; tarnished; obtuse. See
<er>Lifeless</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dull</ent><br/
<hw>Dull</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Duller</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Dulling</conjf>.]</vmorph> <sn>1.</sn> <def>To deprive of
sharpness of edge or point.</def> <ldquo/This . . . <xex>dulled</xex>
their swords.<rdquo/ <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Borrowing <qex>dulls</qex> the edge of husbandry.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To make dull, stupid, or sluggish; to stupefy, as
the senses, the feelings, the perceptions, and the like.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Those [drugs] she has<br/
Will stupefy and <qex>dull</qex> the sense a while.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Use and custom have so <qex>dulled</qex> our eyes.</q>
<rj><qau>Trench.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To render dim or obscure; to sully; to
tarnish.</def> <ldquo/<xex>Dulls</xex> the mirror.<rdquo/
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To deprive of liveliness or activity; to render
heavy; to make inert; to depress; to weary; to sadden.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Attention of mind . . . wasted or <qex>dulled</qex> through
continuance.</q> <rj><qau>Hooker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dull</ent><br/
<hw>Dull</hw>, <pos>v. i.</pos> <def>To become dull or stupid.</def>
<rj><au>Rom. of R.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dullard</ent><br/
<hw>Dull"ard</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Dull</ets> +
<ets>-ard</ets>.]</ety> <def>A stupid person; a dunce.</def>
<au>Shak.</au> -- <def2><pos>a.</pos> <def>Stupid.</def></def2>
<rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dull-brained</ent><br/
<hw>Dull"-brained`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Stupid;
doltish.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dull-browed</ent><br/
<hw>Dull"-browed`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having a gloomy
look.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duller</ent><br/
<hw>Dull"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that
which, dulls.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dull-eyed</ent><br/
<hw>Dull"-eyed`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having eyes
wanting brightness, liveliness, or vivacity.</def>
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dullhead</ent><br/
<hw>Dull"head`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A blockhead; a
dolt.</def> <rj><au>Ascham.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dullish</ent><br/
<hw>Dull"ish</hw>, <pos>a.</pos> <def>Somewhat dull; uninteresting;
tiresome.</def> <ldquo/A series of <xex>dullish</xex> verses.<rdquo/
<rj><au>Prof. Wilson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dullness</ent><br/
<hw>Dull"ness</hw>, <pos>n.</pos> <def>The state of being dull;
slowness; stupidity; heaviness; drowsiness; bluntness; obtuseness;
dimness; want of luster; want of vividness, or of brightness.</def>
<altsp>[Written also <asp>dulness</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><q>And gentle <qex>dullness</qex> ever loves a joke.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dull-sighted</ent><br/
<hw>Dull"-sight`ed</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having poor
eyesight.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dullsome</ent><br/
<hw>Dull"some</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Dull.</def>
<mark>[R.]</mark> <rj><au>Gataker.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dull-witted</ent><br/
<hw>Dull"-wit`ted</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Stupid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dully</ent><br/
<hw>Dul"ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a dull manner;
stupidly; slowly; sluggishly; without life or spirit.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Supinely calm and <qex>dully</qex> innocent.</q> <rj><qau> G.
Lyttelton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dulocracy</ent><br/
<hw>Du*loc"ra*cy</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Doulocracy</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dulse</ent><br/
<hw>Dulse</hw> <pr>(d<ucr/ls)</pr>, <pos>n.</pos> <ety>[Cf. Gael.
<ets>duileasg</ets>; <ets>duille</ets> leaf + <ets>uisge</ets> water.
Cf. <er>Whisky</er>.]</ety> <fld>(Bot.)</fld> <def>A seaweed of a
reddish brown color, which is sometimes eaten, as in Scotland. The true
dulse is <spn>Sarcophyllis edulis</spn>; the common is
<gen>Rhodymenia</gen>. <altsp>[Written also
<asp>dillisk.</asp>]</altsp></def><br/
[<source>1913 Webster</source>]</p>

<p><q>The crimson leaf of the <qex>dulse</qex> is seen<br/
To blush like a banner bathed in slaughter.</q>
<rj><qau>Percival.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dulwilly</ent><br/
<hw>Dul"wil*ly</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Prob.
imitative.]</ety> <fld>(Zool.)</fld> <def>The ring plover.</def>
<mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duly</ent><br/
<hw>Du"ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a due, fit, or
becoming manner; as it (anything) ought to be; properly;
regularly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dumal</ent><br/
<hw>Du"mal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>dumus</ets>
bramble.]</ety> <def>Pertaining to, or set with, briers or bushes;
brambly.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dumb</ent><br/
<hw>Dumb</hw> <pr>(d<ucr/m)</pr>, <pos>a.</pos> <ety>[AS.
<ets>dumb</ets>; akin to D. <ets>dom</ets> stupid, dumb, Sw.
<ets>dumb</ets>, Goth. <ets>dumbs</ets>; cf. Gr. <?/ blind. See
<er>Deaf</er>, and cf. <er>Dummy</er>.]</ety> <sn>1.</sn> <def>Destitute
of the power of speech; unable; to utter articulate sounds; <as>as, the
<ex>dumb</ex> brutes</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To unloose the very tongues even of <qex>dumb</qex> creatures.</q>
<rj><qau>Hooker.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Not willing to speak; mute; silent; not speaking;
not accompanied by words; <as>as, <ex>dumb</ex> show</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This spirit, <qex>dumb</qex> to us, will speak to him.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To pierce into the <qex>dumb</qex> past.</q> <rj><qau> J. C.
Shairp.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Lacking brightness or clearness, as a color.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Her stern was painted of a <qex>dumb</qex> white or dun color.</q>
<rj><qau>De Foe.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Lacking intelligence; having poor judgment; stupid;
dull-witted; -- of persons.</def><br/
[<source>PJC</source>]</p>

<p><sn>5.</sn> <def>Exhibiting poor judgment or lack of wisdom; leading
predictably to unfavorable consequences; -- of actions.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Deaf and dumb</b></col>. <cd>See <er>Deaf-mute</er>.</cd>
-- <mcol><col><b>Dumb ague</b></col>, <it>or</it> <col><b>Dumb
chill</b></col></mcol>, <cd>a form of intermittent fever which has no
well-defined <ldquo/chill.<rdquo/</cd> <mark>[U.S.]</mark> --
<col><b>Dumb animal</b></col>, <cd>any animal except man; -- usually
restricted to a domestic quadruped; -- so called in contradistinction to
man, who is a <ldquo/speaking animal.<rdquo/</cd> -- <col><b>Dumb
cake</b></col>, <cd>a cake made in silence by girls on St. Mark's eve,
with certain mystic ceremonies, to discover their future husbands.</cd>
<au>Halliwell.</au> -- <col><b>Dumb cane</b></col> <fld>(Bot.)</fld>,
<cd>a west Indian plant of the Arum family (<spn>Dieffenbachia
seguina</spn>), which, when chewed, causes the tongue to swell, and
destroys temporarily the power of speech.</cd> -- <col><b>Dumb
crambo</b></col>. <cd>See under <er>crambo</er>.</cd> -- <col><b>Dumb
show</b></col>. <sd>(a)</sd> <cd>Formerly, a part of a dramatic
representation, shown in pantomime.</cd> <ldquo/Inexplicable <xex>dumb
shows</xex> and noise.<rdquo/ <au>Shak.</au> <sd>(b)</sd> <cd>Signs and
gestures without words; as, to tell a story in <xex>dumb
show</xex>.</cd> -- <col><b>To strike dumb</b></col>, <cd>to confound;
to astonish; to render silent by astonishment; or, it may be, to deprive
of the power of speech.</cd></cs></p>

<p><syn><b>Syn.</b> -- Silent; speechless; noiseless. See
<er>Mute</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dumb</ent><br/
<hw>Dumb</hw>, <pos>v. t.</pos> <def>To put to silence.</def>
<mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>dumb-bell</ent><br/
<ent>dumbbell</ent><br/
<mhw><hw>dumb"bell`</hw>, <hw>dumb"-bell`</hw></mhw> <pr>(?)</pr>,
<pos>n.</pos> <def>An exercising weight, consisting of two spheres or
spheroids, connected by a short bar for a handle; used (often in pairs)
for gymnastic exercise.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An ignorant or foolish person.</def><br/
<syn><b>Syn. --</b> dummy, dope, boob, booby, pinhead.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>dumbfound</ent><br/
<hw>dumbfound</hw> <pos>v. t.</pos> <def>same as
<er>dumfound</er>.</def><br/
<syn><b>Syn. --</b> confuse, perplex, throw, fox, befuddle, fuddle,
bedevil, puzzle, mystify, baffle, bewilder, flummox, stupefy, stupify,
nonplus, gravel, amaze, trounce, confound, be confusing to, make
confused.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>dumb down</ent><br/
<hw>dumb` down"</hw> <pr>(d<ucr/m` doun")</pr>, <pos>v. t.</pos> <def>To
render simpler, so as to be comprehensible or usable by unintelligent
people; to simplify; -- of texts or devices.</def><br/
<br/
[<source>PJC</source>]</p>

<p><ent>dumbfounded</ent><br/
<hw>dumbfounded</hw> <pos>adj.</pos> <sn>1.</sn> <def>same as
<er>astounded</er>.</def><br/
<syn><b>Syn. --</b> amazed, astonied, astonished, astounded,
flabbergasted, stunned, stupefied, thunderstruck.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>astonished and confounded.</def><br/
<syn><b>Syn. --</b> amazed, dumfounded.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>dumbfounding</ent><br/
<hw>dumbfounding</hw> <pos>adj.</pos> <def>causing astonishment.</def>
[Narrower terms: <stype>incredible (vs. credible),
unbelievable</stype>]<br/
<syn><b>Syn. --</b> astonishing, astounding, dumfounding.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dumbledor</ent><br/
<hw>Dum"ble*dor`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[The first part
is prob. of imitative origin. See <er>Dor</er> a beetle.]</ety>
<fld>(Zool.)</fld> <def>A bumblebee; also, a cockchafer.</def>
<mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dumbly</ent><br/
<hw>Dumb"ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In silence;
mutely.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dumbness</ent><br/
<hw>Dumb"ness</hw>, <pos>n.</pos> <def>The quality or state of being
dumb; muteness; silence; inability to speak.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dumb-waiter</ent><br/
<hw>Dumb"-wait`er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A framework on
which dishes, food, etc., are passed from one room or story of a house
to another; a lift for dishes, etc.; also, a piece of furniture with
movable or revolving shelves.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dumdum bullet</ent><br/
<hw>Dum"dum bul"let</hw> <pr>(?)</pr>. <fld>(Mil.)</fld> <def>A kind of
man-stopping bullet, designed to fragment inside the body and thus
inflict a severed and painful wound; -- so named from
<etsep>Dumdum</etsep>, in India, where bullets are manufactured for the
Indian army.</def><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><ent>Dumetose</ent><br/
<hw>Du"me*tose`</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From L.
<ets>dumetum</ets> a thicket.]</ety> <fld>(Bot.)</fld>
<def>Dumose.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dumfound</ent><br/
<hw>Dum"found`</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Dumfounded</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Dumfounding</conjf>.]</vmorph> <def>To strike dumb; to confuse
with astonishment.</def> <altsp>[Written also
<asp>dumbfound</asp>.]</altsp> <rj><au>Spectator.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>dumfounded</ent><br/
<hw>dumfounded</hw> <pos>adj.</pos> <def>same as
<er>dumbfounded</er>.</def><br/
<syn><b>Syn. --</b> amazed, astonied, astonished, astounded,
flabbergasted, stunned, stupefied, thunderstruck.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>dumfounder</ent><br/
<hw>dum"found`er</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To dumfound;
to confound.</def> <altsp>[Written also
<asp>dumbfounder</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>dumfounding</ent><br/
<hw>dumfounding</hw> <pos>adj.</pos> <def>same as
<er>dumbfounding</er>.</def><br/
<syn><b>Syn. --</b> astonishing, astounding, dumbfounding.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dummador</ent><br/
<hw>Dum"ma*dor`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A
dumbledor.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dummerer</ent><br/
<hw>Dum"mer*er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who feigns
dumbness.</def> <mark>[Obs.]</mark> <rj><au>Burton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dummy</ent><br/
<hw>Dum"my</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See
<er>Dumb</er>.]</ety> <sn>1.</sn> <def>Silent; mute; noiseless; as a
<xex>dummy</xex> engine.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Fictitious or sham; feigned; <as>as, a
<ex>dummy</ex> watch</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dummy car</b></col>. <cd>See under
<er>Car</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dummy</ent><br/
<hw>Dum"my</hw>, <pos>n.</pos>; <plu><it>pl.</it> <plw>Dummies</plw>
<pr>(<?/)</pr>.</plu> <sn>1.</sn> <def>One who is dumb.</def> <rj><au>H.
Smith.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A sham package in a shop, or one which does not
contain what its exterior indicates.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>An imitation or copy of something, to be used as a
substitute; a model; a lay figure; as, a figure on which clothing is
exhibited in shop windows; a blank paper copy used to show the size of
the future book, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Drama)</fld> <def>One who plays a merely nominal
part in any action; a sham character.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>An ignorant or thick-witted person; a foolish
person; a dolt.</def><br/
<syn><b>Syn. --</b> dope, boob, booby, pinhead, dumbbell.</syn><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><sn>6.</sn> <fld>(Railroad)</fld> <def>A locomotive with condensing
engines, and, hence, without the noise of escaping steam; also, a dummy
car.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Card Playing)</fld> <def>The fourth or exposed hand
when three persons play at a four-handed game of cards.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <def>A floating barge connected with a pier.</def>
<rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To play dummy</b></col>, <cd>to play the exposed or dummy
hand in cards. The partner of the dummy plays it.</cd></cs></p>

<p><ent>Dumous</ent><br/
<ent>Dumose</ent><br/
<mhw>{ <hw>Du`mose"</hw> <pr>(?)</pr>, <hw>Du"mous</hw> <pr>(?)</pr>,
}</mhw> <pos>a.</pos> <ety>[L. <ets>dumosus</ets>, fr. <ets>dumus</ets>
a thornbush, a bramble.]</ety> <sn>1.</sn> <def>Abounding with bushes
and briers.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>Having a compact, bushy
form.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dump</ent><br/
<hw>Dump</hw> <pr>(d<ucr/mp)</pr>, <pos>n.</pos> <ety>[See
<er>Dumpling</er>.]</ety> <def>A thick, ill-shapen piece; a clumsy
leaden counter used by boys in playing chuck farthing.</def>
<mark>[Eng.]</mark> <rj><au>Smart.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dump</ent><br/
<hw>Dump</hw>, <pos>n.</pos> <ety>[Cf. dial. Sw. <ets>dumpin</ets>
melancholy, Dan.<ets>dump</ets> dull, low, D. <ets>dompig</ets> damp, G.
<ets>dumpf</ets> damp, dull, gloomy, and E. <ets>damp</ets>, or rather
perh. <ets>dump</ets>, v. t. Cf. <er>Damp</er>, or <er>Dump</er>,
<pos>v. t.</pos>]</ety> <sn>1.</sn> <def>A dull, gloomy state of the
mind; sadness; melancholy; low spirits or a mild depression;
despondency; ill humor; -- now used only in the plural.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>March slowly on in solemn <qex>dump</qex>.</q>
<rj><qau>Hudibras.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Doleful <qex>dumps</qex> the mind oppress.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I was musing in the midst of my <qex>dumps</qex>.</q>
<rj><qau>Bunyan.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 461 --></p>

<p><note><hand/ The ludicrous associations now attached to this word did
not originally belong to it. <ldquo/Holland's translation of Livy
represents the Romans as being `in the <xex>dumps'</xex> after the
battle of Cann<ae/.<rdquo/</note> <rj><au>Trench.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Absence of mind; revery.</def>
<rj><au>Locke.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A melancholy strain or tune in music; any
tune.</def> <mark>[Obs.]</mark> <ldquo/Tune a deploring
<xex>dump</xex>.<rdquo/ <ldquo/Play me some merry
<xex>dump</xex>.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>An old kind of dance.</def> <mark>[Obs.]</mark>
<rj><au>Nares.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dump</ent><br/
<hw>Dump</hw> <pr>(d<ucr/mp)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Dumped</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Dumping</conjf>.]</vmorph> <ety>[OE. <ets>dumpen</ets>
to throw down, fall down, cf. Icel. <ets>dumpa</ets> to thump, Dan.
<ets>dumpe</ets> to fall suddenly, rush, dial. Sw. <ets>dimpa</ets> to
fall down plump. Cf. <er>Dump</er> sadness.]</ety> <sn>1.</sn> <def>To
knock heavily; to stump.</def> <mark>[Prov. Eng.]</mark>
<rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To put or throw down with more or less of violence;
hence, to unload from a cart by tilting it; <as>as, to <ex>dump</ex>
sand, coal, etc.</as></def> <mark>[U.S.]</mark>
<rj><au>Bartlett.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Dumping car</b></col> <it>or</it> <col><b>Dumping
cart</b></col></mcol>, <cd>a railway car, or a cart, the body of which
can be tilted to empty the contents; -- called also <altname>dump
car</altname>, or <altname>dump cart</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dump</ent><br/
<hw>Dump</hw>, <pos>n.</pos> <sn>1.</sn> <def>A car or boat for dumping
refuse, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A ground or place for dumping ashes, refuse,
etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>That which is dumped.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Mining)</fld> <def>A pile of ore or rock.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>dump</ent><br/
<hw>dump</hw> <pos>n.</pos> <def>a coarse term for defecation.</def><br/
<syn><b>Syn. --</b> shit.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dumpage</ent><br/
<hw>Dump"age</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The act
of dumping loads from carts, especially loads of refuse matter; also, a
heap of dumped matter.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A fee paid for the privilege of dumping loads;
called in some cases <altname>tipping fee</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>dumpcart</ent><br/
<hw>dumpcart</hw> <pos>n.</pos> <def>a cart that can be tilted to empty
the contents without handling them.</def><br/
<syn><b>Syn. --</b> tumbrel, tumbril.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>dump cart</ent><br/
<hw>dump cart</hw> <pos>n.</pos> <fld>(Railroads)</fld> <def>same as
<cref>dump car</cref>.</def><br/
<syn><b>Syn. --</b> dumping car, dumping cart, dump car.</syn>
[<source>PJC</source>]</p>

<p><ent>dumped</ent><br/
<hw>dumped</hw> <pos>adj.</pos> <sn>1.</sn> <def><pos>p. p.</pos> of
<er>dump</er>, <pos>v. t.</pos>; <as>as, The money was there,
<ex>dumped</ex> all over the floor</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>dumper</ent><br/
<hw>dumper</hw> <pos>n.</pos> <def>same as <er>dump
truck</er>.</def><br/
<syn><b>Syn. --</b> dump truck.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dumpiness</ent><br/
<hw>Dump"i*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The state of being
dumpy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dumpish</ent><br/
<hw>Dump"ish</hw>, <pos>a.</pos> <def>Dull; stupid; sad; moping;
melancholy.</def> <ldquo/ A . . . <xex>dumpish</xex> and sour
life.<rdquo/ <rj><au>Lord Herbert.</au></rj></p>

<p>-- <wordforms><wf>Dump"ish*ly</wf>, <pos>adv.</pos> --
<wf>Dump"ish*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dumple</ent><br/
<hw>Dum"ple</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[See
<er>Dumpling</er>.]</ety> <def>To make dumpy; to fold, or bend, as one
part over another.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He was a little man, <qex>dumpled</qex> up together.</q>
<rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dumpling</ent><br/
<hw>Dump"ling</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Dimin. of
<ets>dump</ets> an illshapen piece; cf. D. <ets>dompelen</ets> to
plunge, dip, duck, Scot. to <ets>dump in</ets> to plunge into, and E.
<ets>dump</ets>, v. t.]</ety> <def>A roundish mass of dough boiled in
soup, or as a sort of pudding; often, a cover of paste inclosing an
apple or other fruit, and boiled or baked; <as>as, an apple
<ex>dumpling</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dumps</ent><br/
<hw>Dumps</hw> <pr>(d<ucr/mps)</pr>, <pos>n. pl.</pos> <def>a gloomy
mental state; same as 2nd <er>dump{1}</er>; -- used mostly in the phrase
<ldquo/in the <ex>dumps</ex><rdquo/.</def><br/
[<source>PJC</source>]</p>

<p><ent>dump truck</ent><br/
<hw>dump" truck`</hw> <pos>n.</pos> <def>a truck, usually with an open
top, the carrying body of which can be tilted so as to emptied its
contents without handling.</def><br/
<syn><b>Syn. --</b> dumper.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dumpy</ent><br/
<hw>Dump"y</hw> <pr>(?)</pr>, <pos>a.</pos> <amorph>[<pos>Compar.</pos>
<adjf>Dumpier</adjf> <pr>(?)</pr>; <pos>superl.</pos>
<adjf>Dumpiest</adjf>.]</amorph> <ety>[<sn>1.</sn> From <er>Dump</er> a
short ill-shapen piece. <sn>2.</sn> From <er>Dump</er> sadness.]</ety>
<sn>1.</sn> <def>Short and thick; of low stature and disproportionately
stout.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Sullen or discontented. See 2nd
<er>dump{1}</er>.</def> <mark>[Prov. Eng.]</mark>
<rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dumpy level</ent><br/
<hw>Dump"y lev"el</hw>. <fld>(Surv.)</fld> <def>A level having a short
telescope (hence its name) rigidly fixed to a table capable only of
rotatory movement in a horizontal plane. The telescope is usually an
inverting one. It is sometimes called the <altname><col><b>Troughton
level</b></col></altname>, from the name of the inventor, and a variety
improved by one Gavatt is known as the <stype><col><b>Gavatt
level</b></col></stype>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Dumuzi</ent><br/
<hw>Dumuzi</hw> <pos>prop. n.</pos> <def>the Sumerian and Babylonian god
of pastures and vegetation; consort of Inanna.</def><br/
<syn><b>Syn. --</b> Tammuz.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dun</ent><br/
<hw>Dun</hw> <pr>(d<ucr/n)</pr>, <pos>n.</pos> <ety>[See
<er>Dune</er>.]</ety> <def>A mound or small hill.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dun</ent><br/
<hw>Dun</hw>, <pos>v. t.</pos> <def>To cure, as codfish, in a particular
manner, by laying them, after salting, in a pile in a dark place,
covered with salt grass or some like substance.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dun</ent><br/
<hw>Dun</hw> <pr>(d<ucr/n)</pr>, <pos>v. t. & i.</pos>
<vmorph>[<pos>imp. & p. p.</pos> <conjf>Dunned</conjf>
<pr>(d<ucr/nd)</pr>; <pos>p. pr. & vb. n.</pos> <conjf>Dunning</conjf>
<pr>(d<ucr/n"n<icr/ng)</pr>.]</vmorph> <ety>[AS. <ets>dyne</ets> noise,
<ets>dynian</ets> to make a noise, or fr. Icel. <ets>dynr</ets>,
<ets>duna</ets>, noise, thunder, <ets>duna</ets> to thunder; the same
word as E. <ets>din</ets>. <root/74. See <er>Din</er>.]</ety> <def>To
ask or beset (e.g., a debtor), for payment; to urge
importunately.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Hath she sent so soon to <qex>dun</qex>?</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dun</ent><br/
<hw>Dun</hw>, <pos>n.</pos> <sn>1.</sn> <def>One who duns; a
dunner.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To be pulled by the sleeve by some rascally <qex>dun</qex>.</q>
<rj><qau>Arbuthnot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An urgent request or demand of payment; <as>as, he
sent his debtor a <ex>dun</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dun</ent><br/
<hw>Dun</hw>, <pos>a.</pos> <ety>[AS. <ets>dunn</ets>, of Celtic origin;
cf. W. <ets>dwn</ets>, Ir. & Gael. <ets>donn</ets>.]</ety> <def>Of a
dark color; of a color partaking of a brown and black; of a dull brown
color; swarthy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Summer's <qex>dun</qex> cloud comes thundering up.</q> <rj><qau>
Pierpont.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Chill and <qex>dun</qex><br/
Falls on the moor the brief November day.</q>
<rj><qau>Keble.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dun crow</b></col> <fld>(Zool.)</fld>, <cd>the hooded
crow; -- so called from its color; -- also called
<altname>hoody</altname>, and <altname>hoddy</altname>.</cd> --
<col><b>Dun diver</b></col> <fld>(Zool.)</fld>, <cd>the goosander or
merganser.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dunbird</ent><br/
<hw>Dun"bird`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Named from its
color.]</ety> <fld>(Zool.)</fld> <sd>(a)</sd> <def>The pochard; --
called also <altname>dunair</altname>, and <altname>dunker</altname>, or
<altname>dun-curre</altname>.</def> <sd>(b)</sd> <def>An American duck;
the ruddy duck.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dunce</ent><br/
<hw>Dunce</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From Joannes
<ets>Duns</ets> Scotus, a schoolman called the <ets>Subtle Doctor</ets>,
who died in 1308. Originally in the phrase <ldquo/a Duns man<rdquo/. See
Note below.]</ety> <def>One backward in book learning; a child or other
person dull or weak in intellect; a dullard; a dolt.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I never knew this town without <qex>dunces</qex> of figure.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The schoolmen were often called, after their great
leader Duns Scotus, <xex>Dunsmen</xex> or <xex>Duncemen</xex>. In the
revival of learning they were violently opposed to classical studies;
hence, the name of Dunce was applied with scorn and contempt to an
opposer of learning, or to one slow at learning, a dullard.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duncedom</ent><br/
<hw>Dunce"dom</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The realm or domain
of dunces.</def> <mark>[Jocose]</mark> <rj><au>Carlyle.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duncery</ent><br/
<hw>Dun"cer*y</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Dullness;
stupidity.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duncical</ent><br/
<hw>Dun"ci*cal</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Like a dunce;
duncish.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The most dull and <qex>duncical</qex> commissioner.</q> <rj><qau>
Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duncify</ent><br/
<hw>Dun"ci*fy</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[<ets>Dunce</ets>
+ <ets>-fy</ets>.]</ety> <def>To make stupid in intellect.</def>
<mark>[R.]</mark> <rj><au>Bp. Warburton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duncish</ent><br/
<hw>Dun"cish</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Somewhat like a
dunce.</def> <mark>[R.]</mark></p>

<p>-- <wordforms><wf>Dun"cish*ness</wf>, <pos>n.</pos>
<mark>[R.]</mark></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dunder</ent><br/
<hw>Dun"der</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. Sp.
<ets>redundar</ets> to overflow.]</ety> <def>The lees or dregs of cane
juice, used in the distillation of rum.</def> <mark>[West
Indies]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The use of <qex>dunder</qex> in the making of rum answers the
purpose of yeast in the fermentation of flour.</q> <rj><qau>B.
Edwards.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dunderhead</ent><br/
<hw>Dun"der*head`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Prov. Eng. also
<ets>dunderpoll</ets>, from <ets>dunder</ets>, same as
<ets>thunder</ets>.]</ety> <def>A dunce; a numskull; a blockhead.</def>
<rj><au>Beau. & Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dunder-headed</ent><br/
<hw>Dun"der-head`ed</hw>, <pos>a.</pos> <def>Thick-headed;
stupid.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dunderpate</ent><br/
<hw>Dun"der*pate`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See
<er>Dunderhead</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dune</ent><br/
<hw>Dune</hw> <pr>(d<umac/n)</pr>, <pos>n.</pos> <ety>[The same word as
<ets>down</ets>: cf. D. <ets>duin</ets>. See <er>Down</er> a bank of
sand.]</ety> <def>A low hill of drifting sand usually formed on the
coats, but often carried far inland by the prevailing winds.</def>
<altsp>[Written also <asp>dun</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><q>Three great rivers, the Rhine, the Meuse, and the Scheldt, had
deposited their slime for ages among the <qex>dunes</qex> or sand banks
heaved up by the ocean around their mouths.</q>
<rj><qau>Motley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dunfish</ent><br/
<hw>Dun"fish</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Codfish cured in a
particular manner, so as to be of a superior quality.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dung</ent><br/
<hw>Dung</hw> <pr>(d<ucr/ng)</pr>, <pos>n.</pos> <ety>[AS.
<ets>dung</ets>; akin to G. <ets>dung</ets>, <ets>d<uum/nger</ets>, OHG.
<ets>tunga</ets>, Sw. <ets>dynga</ets>; cf. Icel. <ets>dyngja</ets>
heap, Dan. <ets>dynge</ets>, MHG. <ets>tunc</ets> underground dwelling
place, orig., covered with dung. Cf. <er>Dingy</er>.]</ety> <def>The
excrement of an animal.</def> <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dung</ent><br/
<hw>Dung</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Dunged</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Dunging</conjf>.]</vmorph> <sn>1.</sn> <def>To manure with
dung.</def> <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Calico Print.)</fld> <def>To immerse or steep, as
calico, in a bath of hot water containing cow dung; -- done to remove
the superfluous mordant.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dung</ent><br/
<hw>Dung</hw>, <pos>v. i.</pos> <def>To void excrement.</def>
<rj><au>Swift.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dungaree</ent><br/
<hw>Dun`ga*ree"</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A
coarse kind of unbleached cotton fabric; blue denim.</def>
<altsp>[Written also <asp>dungari</asp>.]</altsp>
<mark>[India]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <pluf>pl.</pluf> <def>Trousers, overalls or similar work
clothes made of blue denim.</def><br/
[<source>PJC</source>]</p>

<p><sn>3.</sn> <pluf>pl.</pluf> <def>Same as <er>blue
jeans</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>dungeon</ent><br/
<hw>dun"geon</hw> <pr>(d<ucr/n"j<ucr/n)</pr>, <pos>n.</pos> <ety>[OE.
<ets>donjoun</ets> highest tower of a castle, tower, prison, F.
<ets>donjon</ets> tower or platform in the midst of a castle, turret, or
closet on the top of a house, a keep of a castle, LL. <ets>domnio</ets>,
the same word as LL. <ets>dominus</ets> lord. See <er>Dame</er>,
<er>Don</er>, and cf. <er>Dominion</er>, <er>Domain</er>,
<er>Demesne</er>, <er>Danger</er>, <er>Donjon</er>.]</ety> <def>A close,
dark prison, commonly, under ground, as if the lower apartments of the
<xex>donjon</xex> or keep of a castle, these being used as
prisons.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Down with him even into the deep <qex>dungeon</qex>.</q> <rj><qau>
Tyndale.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Year after year he lay patiently in a <qex>dungeon</qex>.</q>
<rj><qau> Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dungeon</ent><br/
<hw>Dun"geon</hw>, <pos>v. t.</pos> <def>To shut up in a dungeon.</def>
<rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dungfork</ent><br/
<hw>Dung"fork`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A fork for tossing
dung.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dunghill</ent><br/
<hw>Dung"hill`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A heap
of dung.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Any mean situation or condition; a vile
abode.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He . . . lifteth up the beggar from the <qex>dunghill</qex>.</q>
<rj><qau> 1. Sam. ii. 8.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dunghill fowl</b></col>, <cd>a domestic fowl of common
breed.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dungmeer</ent><br/
<hw>Dung"meer`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Dung</ets> +
(prob.) <ets>meer</ets> a pool.]</ety> <def>A pit where dung and weeds
rot for manure.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dungy</ent><br/
<hw>Dung"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Full of dung; filthy;
vile; low.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dungyard</ent><br/
<hw>Dung"yard`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A yard where dung
is collected.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dunker</ent><br/
<hw>Dun"ker</hw> <pr>(?)</pr>, <pos>prop. n.</pos> <ety>[G.
<ets>tunken</ets> to dip.]</ety> <def>One of a religious denomination
whose tenets and practices are mainly those of the Baptists, but partly
those of the Quakers; -- called also <altname>Tunkers</altname>,
<altname>Dunkards</altname>, <altname>Dippers</altname>, and, by
themselves, <altname>Brethren</altname>, and <altname>German
Baptists</altname>, and they call their denomination the <membof>Church
of the Brethren</membof>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The denomination was founded in Germany in 1708, but
after a few years the members emigrated to the United States; they were
opposed to military service and taking legal oaths, and practiced trine
immersion.</note><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><cs><col><b>Seventh-day Dunkers</b></col>, <cd>a sect which separated
from the Dunkers and formed a community, in 1728. They keep the seventh
day or Saturday as the Sabbath.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dunkerque</ent><br/
<hw>Dunkerque</hw> <pos>prop. n.</pos> <def>the name of a town and a
battle fought there, in World War II (1940) when 330,000 Allied troops
had to be evacuated from the beaches at Dunkirk in a desperate retreat
under enemy fire. Most of the forces were safely evacuated to
England.</def><br/
<syn><b>Syn. --</b> Dunkirk.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dunkirk</ent><br/
<hw>Dunkirk</hw> <pos>prop. n.</pos> <def>the name of a town and a
battle fought there, in World War II (1940) when 330,000 Allied troops
had to be evacuated from the beaches at Dunkirk in a desperate retreat
under enemy fire. Most of the forces were safely evacuated to
England.</def><br/
<syn><b>Syn. --</b> Dunkerque.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dunlin</ent><br/
<hw>Dun"lin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Prob. of Celtic
origin; cf. Gael. <ets>dun</ets> hill (E. <ets>dune</ets>), and
<ets>linne</ets> pool, pond, lake, E. <ets>lin</ets>.]</ety>
<fld>(Zool.)</fld> <def>A species of sandpiper (<spn>Tringa
alpina</spn>); -- called also <altname>churr</altname>,
<altname>dorbie</altname>, <altname>grass bird</altname>, and
<altname>red-backed sandpiper</altname>. It is found both in Europe and
America.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dunnage</ent><br/
<hw>Dun"nage</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. <er>Dun</er> a
mound.]</ety> <fld>(Naut.)</fld> <def>Fagots, boughs, or loose materials
of any kind, laid on the bottom of the hold for the cargo to rest upon
to prevent injury by water, or stowed among casks and other cargo to
prevent their motion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dunner</ent><br/
<hw>Dun"ner</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From <er>Dun</er> to
ask payment from.]</ety> <def>One employed in soliciting the payment of
debts.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dunnish</ent><br/
<hw>Dun"nish</hw> <pr>(d<ucr/n"n<icr/sh)</pr>, <pos>a.</pos>
<def>Inclined to a dun color.</def> <rj><au>Ray.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>dunno</ent><br/
<hw>dun*no"</hw> <pr>(d<ucr/n*n<omac/")</pr>, <pos>phrase</pos>
<ety>[Spelled as often pronounced in rapid or slurred speech.]</ety>
<def>A slang shortening of <sig>I don't know</sig> or <sig>don't
know</sig>; <as>as, <ex>dunno</ex> where I lost my keys; Where'd he go?
I dunno.</as>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Dunnock</ent><br/
<hw>Dun"nock</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf.
<er>Dun</er>,<pos>a.</pos>]</ety> <fld>(Zool.)</fld> <def>The hedge
sparrow or hedge accentor.</def> <mark>[Local, Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dunny</ent><br/
<hw>Dun"ny</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Deaf;
stupid.</def><mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>My old dame Joan is something <qex>dunny</qex>, and will scarce
know how to manage.</q> <rj><qau>Sir W. Scott.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dunt</ent><br/
<hw>Dunt</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<er>Dint</er>.]</ety>
<def>A blow.</def> <mark>[Obs.]</mark> <rj><au>R. of
Glouc.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dunted</ent><br/
<hw>Dunt"ed</hw>, <pos>a.</pos> <def>Beaten; hence, blunted.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Fencer's swords . . . having the edge <qex>dunted</qex>.</q>
<rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dunter</ent><br/
<hw>Dun"ter</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>A
porpoise.</def> <mark>[Scott.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dunter goose</b></col> <fld>(Zool.)</fld> <cd>the eider
duck.</cd> <rj><au>J. Brand.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duo</ent><br/
<hw>Du"o</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[It. <ets>duo</ets>, fr.
L. <ets>duo</ets> two. See <er>Duet</er>.]</ety> <fld>(Mus.)</fld>
<def>A composition for two performers; a duet.</def></p>

<p><ent>Duodecahedron</ent><br/
<ent>Duodecahedral</ent><br/
<mhw><hw>Du`o*dec`a*he"dral</hw> <pr>(?)</pr>, <pos>a.</pos>,
<hw>Du`o*dec`a*he"dron</hw> <pr>(<?/)</pr>, <pos>n.</pos></mhw> <def>See
<er>Dodecahedral</er>, and <er>Dodecahedron</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duodecennial</ent><br/
<hw>Du`o*de*cen"ni*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>duodecennis</ets>; <ets>duodecim</ets> twelve + <ets>annus</ets>
year.]</ety> <def>Consisting of twelve years.</def> <mark>[R.]</mark>
<rj><au>Ash.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duodecimal</ent><br/
<hw>Du`o*dec"i*mal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>duodecim</ets> twelve. See <er>Dozen</er>.]</ety> <def>Proceeding
in computation by twelves; expressed in the scale of twelves.</def> --
<wordforms><wf>Du`o*dec"i*mal*ly</wf>, <pos>adv.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duodecimal</ent><br/
<hw>Du`o*dec"i*mal</hw>, <pos>n.</pos> <sn>1.</sn> <def>A twelfth part;
<as>as, the <ex>duodecimals</ex> of an inch</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <pluf>pl.</pluf> <fld>(Arch.)</fld> <def>A system of
numbers, whose denominations rise in a scale of twelves, as of feet and
inches. The system is used chiefly by artificers in computing the
superficial and solid contents of their work.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duodecimfid</ent><br/
<hw>Du`o*dec"im*fid</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>duodecim</ets> twelve + <ets>findere</ets> to cleave.]</ety>
<def>Divided into twelve parts.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duodecimo</ent><br/
<hw>Du`o*dec"i*mo</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>in
duodecimo</ets> in twelfth, fr. <ets>duodecimus twelfth</ets>,
<ets>fr</ets>. <ets>duodecim</ets> twelve. See <er>Dozen</er>.]</ety>
<def>Having twelve leaves to a sheet; <as>as, a <ex>duodecimo</ex> from,
book, leaf, size, etc.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duodecimo</ent><br/
<hw>Du*o*dec"i*mo</hw>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Duodecimos</plw> <pr>(<?/)</pr>.</plu> <def>A book consisting of
sheets each of which is folded into twelve leaves; hence, indicating,
more or less definitely, a size of a book; -- usually written 12mo or
12<deg/.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duodecuple</ent><br/
<hw>Du`o*dec"u*ple</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>duo</ets> two + <?/ <ets>decuple</ets>.]</ety> <def>Consisting of
twelves.</def> <rj><au>Arbuthnot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duodenal</ent><br/
<hw>Du`o*de"nal</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. F.
<ets>duod<eacute/nal</ets>.]</ety> <def>Of or pertaining to the
duodenum; <as>as, <ex>duodenal</ex> digestion</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duodenary</ent><br/
<hw>Du`o*den"a*ry</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>duodenarius</ets>, fr. <ets>duodeni</ets> twelve each: cf. F.
<ets>duod<eacute/naire</ets>.]</ety> <def>Containing twelve; twelvefold;
increasing by twelves; duodecimal.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duodenum</ent><br/
\'d8<hw>Du`o*de"num</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr.
<ets>duodeni</ets> twelve each: cf. F. <ets>duodenum</ets>. So called
because its length is about twelve fingers' breadth.]</ety>
<fld>(Anat.)</fld> <def>The part of the small intestines between the
stomach and the jejunum. See <xex>Illust.</xex> of <xex>Digestive
apparatus</xex>, under <er>Digestive</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duograph</ent><br/
<hw>Du"o*graph</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>duo</ets>
two + <ets>-graph</ets>.]</ety> <fld>(Photo-engraving)</fld> <def>A
picture printed from two half-tone plates made with the screen set at
different angles, and usually printed in two shades of the same color or
in black and one tint.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Duoliteral</ent><br/
<hw>Du`o*lit"er*al</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>duo</ets> two + E. <ets>literal</ets>.]</ety> <def>Consisting of
two letters only; biliteral.</def> <rj><au>Stuart.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duomo</ent><br/
\'d8<hw>Duo"mo</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[It. See
<er>Done</er>.]</ety> <def>A cathedral. See <er>Dome</er>, 2.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Of tower or <qex>duomo</qex>, sunny sweet.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duotone</ent><br/
<hw>Du"o*tone</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>duo</ets>
two + <ets>tone</ets>.]</ety> <fld>(Photoengraving)</fld> <def>Any
picture printed in two shades of the same color, as duotypes and
duographs are usually printed.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Duotype</ent><br/
<hw>Du"o*type</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>duo</ets>
two + <ets>type</ets>.]</ety> <fld>(Photoengraving)</fld> <def>A print
made from two half-tone plates made from the same negative, but etched
differently.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Dup</ent><br/
<hw>Dup</hw> <pr>(d<ucr/p)</pr>, <pos>v. t.</pos> <ety>[Contr. fr.
<ets>do up</ets>, that is, to lift up the latch. Cf. <er>Don</er>,
<er>Doff</er>.]</ety> <def>To open; <as>as, to <ex>dup</ex> the
door</as>.</def> <mark>[Obs.]</mark> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dupable</ent><br/
<hw>Dup"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Capable of being
duped.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dupe</ent><br/
<hw>Dupe</hw> <pr>(d<umac/p)</pr>, <pos>n.</pos> <ety>[F., prob. from
Prov. F. <ets>dupe</ets>, <ets>dube</ets>; of unknown origin; equiv. to
F. <ets>huppe</ets> hoopoe, a foolish bird, easily caught. Cf. Armor.
<ets>houp<eacute/rik</ets> hoopoe, a man easily deceived. Cf. also
<er>Gull</er>, <er>Booby</er>.]</ety> <def>One who has been deceived or
who is easily deceived; a gull; <as>as, the <ex>dupe</ex> of a
schemer</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dupe</ent><br/
<hw>Dupe</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Duped</conjf> <pr>(d<umac/pt)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Duping</conjf>.]</vmorph> <ety>[Cf. F. <ets>duper</ets>, fr.
<ets>dupe</ets>. See <er>Dupe</er>, <pos>n.</pos>]</ety> <def>To
deceive; to trick; to mislead by imposing on one's credulity; to gull;
<as>as, <ex>dupe</ex> one by flattery</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Ne'er have I <qex>duped</qex> him with base counterfeits.</q>
<rj><qau> Coleridge.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duper</ent><br/
<hw>Dup"er</hw> <pr>(d<umac/p"<etil/r)</pr>, <pos>n.</pos> <def>One who
dupes another.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dupery</ent><br/
<hw>Dup"er*y</hw> <pr>(d<umac/p"<etil/r*<ycr/)</pr>, <pos>n.</pos>
<ety>[F. <ets>duperie</ets>, fr. <ets>duper</ets>.]</ety> <def>The act
or practice of duping.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dupion</ent><br/
<hw>Du"pi*on</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F.
<ets>doupion</ets>, It. <ets>doppione</ets>, fr. <ets>doppio</ets>
double, L. <ets>duplus</ets>. See <er>Double</er>, and cf.
<er>Doubloon</er>.]</ety> <def>A double cocoon, made by two
silkworms.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duple</ent><br/
<hw>Du"ple</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>duplus</ets>.
See <er>Double</er>.]</ety> <def>Double.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Duple ratio</b></col> <fld>(Math.)</fld>, <cd>that in
which the antecedent term is double the consequent, as of 2 to 1, 8 to
4, etc.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duplex</ent><br/
\'d8<hw>Du"plex</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L., fr.
<ets>duo</ets> two + <ets>plicare</ets> to fold. See <er>Two</er>, and
<er>Complex</er>.]</ety> <sn>1.</sn> <def>Double; twofold.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Computers)</fld> <def>organized so that data may be
transmitted in two opposite directions over the same channel; -- of
communications channels, such as data transfer lines between
computers.</def><br/
[<source>PJC</source>]</p>

<p><cs><col><b>Duplex escapement</b></col>, <cd>a peculiar kind of watch
escapement, in which the scape-wheel has two sets of teeth. See
<er>Escapement</er>.</cd> -- <col><b>Duplex lathe</b></col>, <cd>one for
turning off, screwing, and surfacing, by means of two cutting tools, on
opposite sides of the piece operated upon.</cd> -- <col><b>Duplex
pumping engine</b></col>, <cd>a steam pump in which two steam cylinders
are placed side by side, one operating the valves of the other.</cd> --
<col><b>Duplex querela</b></col> <ety>[L., double complaint]</ety>
<fld>(Eccl. Law)</fld>, <cd>a complaint in the nature of an appeal from
the ordinary to his immediate superior, as from a bishop to an
archbishop.</cd> <au>Mozley & W.</au> -- <col><b>Duplex
telegraphy</b></col>, <cd>a system of telegraphy for sending two
messages over the same wire simultaneously.</cd> -- <col><b>Duplex
watch</b></col>, <cd>one with a duplex escapement.</cd> -- <col><b>half
duplex</b></col> <fld>(Computers)</fld> <sd>(a)</sd> <cd>arranged so
that the information may be transmitted in both directions, but only in
one direction at a time; -- of communications channels between
computers; contrasted with <cref>full duplex(a)</cref>.</cd>
<sd>(b)</sd> <cd>arranged so that the information transmitted to the
remote computer also appears on the local terminal; -- of communications
channels between computers; contrasted with <cref>full
duplex(b)</cref>.</cd> -- <col><b>full duplex</b></col>,
<fld>(Computers)</fld> <sd>(a)</sd> <cd>arranged so that the information
may be transmitted in both directions simultaneously; -- of
communications channels between computers; contrasted with <cref>half
duplex(a)</cref>.</cd> <sd>(b)</sd> <cd>arranged so that the information
transmitted to the remote computer does not appear on the local
terminal; -- of communications channels between computers; contrasted
with <cref>half duplex(b)</cref>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duplex</ent><br/
<hw>Du"plex</hw> <pr>(?)</pr>, <pos>v. t.</pos> <ety>[See
<er>Duplex</er>, <pos>a.</pos>]</ety> <fld>(Teleg.)</fld> <def>To
arrange, as a telegraph line, so that two messages may be transmitted
simultaneously; to equip with a duplex telegraphic outfit.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>duplex</ent><br/
<hw>du"plex</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See <er>Duplex</er>,
<pos>a.</pos>]</ety> <sn>1.</sn> <def>something which is duplex; -- used
mostly in reference to a living unit, such as an apartment, in a
building having two similar living units.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <fld>(Biology, Genetics)</fld> <def>a double-stranded
region in a nucleic acid molecule. See <er>deoxyribonucleic
acid</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>duplexer</ent><br/
<hw>du"plex*er</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Radio)</fld>
<def>a device which switches electronic circuitry so that a radio
antenna can function as either a transmitting or receiving
antenna.</def><br/
[<source>PJC</source>]</p>

<p><ent>duplicability</ent><br/
<hw>duplicability</hw> <pos>n.</pos> <def>the quality of being
reproducible.</def><br/
<syn><b>Syn. --</b> reproducibility.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>duplicatable</ent><br/
<ent>duplicable</ent><br/
<mhw><hw>duplicable</hw> <hw>duplicatable</hw></mhw> <pos>adj.</pos>
<def>capable of being duplicated.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>duplicate</ent><br/
<hw>du"pli*cate</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>duplicatus</ets>, p. p. of <ets>duplicare</ets> to double, fr.
<ets>duplex</ets> double, twofold. See <er>Duplex</er>.]</ety>
<def>Double; twofold.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Duplicate proportion</b></col> <it>or</it>
<col><b>Duplicate ratio</b></col></mcol> <fld>(Math.)</fld>, <cd>the
proportion or ratio of squares. Thus, in geometrical proportion, the
first term to the third is said to be in a <xex>duplicate</xex> ratio of
the first to the second, or as its square is to the square of the
second. Thus, in 2, 4, 8, 16, the ratio of 2 to 8 is a
<xex>duplicate</xex> of that of 2 to 4, or as the square of 2 is to the
square of 4.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duplicate</ent><br/
<hw>Du"pli*cate</hw>, <pos>n.</pos> <sn>1.</sn> <def>That which exactly
resembles or corresponds to something else; another, correspondent to
the first; hence, a copy; a transcript; a counterpart.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I send a <qex>duplicate</qex> both of it and my last dispatch.</q>
<rj><qau> Sir W. Temple.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>An original instrument repeated; a
document which is the same as another in all essential particulars, and
differing from a mere copy in having all the validity of an
original.</def> <rj><au>Burrill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duplicate</ent><br/
<hw>Du"pli*cate</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Duplicated</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Duplicating</conjf>.]</vmorph> <sn>1.</sn> <def>To
double; to fold; to render double.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To make a duplicate of (something); to make a copy
or transcript of.</def> <rj><au>Glanvill.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Biol.)</fld> <def>To divide into two by natural
growth or spontaneous action; <as>as, infusoria <ex>duplicate</ex>
themselves</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>duplication</ent><br/
<hw>du`pli*ca"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>duplicatio</ets>: cf. F. <ets>duplication</ets>.]</ety> <sn>1.</sn>
<def>The act of duplicating, or the state of being duplicated; a
doubling; a folding over; a fold.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Biol.)</fld> <def>The act or process of dividing by
natural growth or spontaneous action; <as>as, the <ex>duplication</ex>
of cartilage cells</as>.</def> <rj><au>Carpenter.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>duplication of the cube</b></col> <fld>(Math.)</fld>,
<cd>the operation of finding a cube having a volume which is double that
of a given cube.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>duplicative</ent><br/
<hw>du"pli*ca*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Having the quality of duplicating or doubling.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Biol.)</fld> <def>Having the quality of subdividing
into two by natural growth.</def> <ldquo/<xex>Duplicative</xex>
subdivision.<rdquo/ <rj><au>Carpenter.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>duplicature</ent><br/
<hw>du"pli*ca*ture</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>duplicature</ets>.]</ety> <def>A doubling; a fold, as of a
membrane.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>duplicitous</ent><br/
<hw>du*plic"i*tous</hw> <pos>adj.</pos> <def>exhibiting duplicity{2};
deceitful; double-dealing.</def><br/
<syn><b>Syn. --</b> ambidextrous, deceitful, double-dealing,
two-faced.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>duplicity</ent><br/
<hw>du*plic"i*ty</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>duplicities</plw> <pr>(#)</pr>.</plu> <ety>[F.
<ets>duplicit<eacute/</ets>, L. <ets>duplicitas</ets>, fr.
<ets>duplex</ets> double. See <er>Duplex</er>.]</ety> <sn>1.</sn>
<def>Doubleness; a twofold state.</def> <mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Do not affect <qex>duplicities</qex> nor triplicities, nor any
certain number of parts in your division of things.</q> <rj><qau>I.
Watts.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Doubleness of heart or speech; insincerity; a
sustained form of deception which consists in entertaining or pretending
to entertain one set of feelings, and acting as if influenced by
another; bad faith.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Far from the <qex>duplicity</qex> wickedly charged on him, he
acted his part with alacrity and resolution.</q>
<rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 462 --></p>

<p><sn>3.</sn> <fld>(Law)</fld> <sd>(a)</sd> <def>The use of two or more
distinct allegations or answers, where one is sufficient.</def>
<au>Blackstone.</au> <sd>(b)</sd> <def>In indictments, the union of two
incompatible offenses.</def> <rj><au>Wharton.</au></rj></p>

<p><syn><b>Syn.</b> -- Double dealing; dissimulation; deceit; guile;
deception; falsehood.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dupper</ent><br/
<hw>Dup"per</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See 2d
<er>Dubber</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dur</ent><br/
\'d8<hw>Dur</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[G., fr. L.
<ets>durus</ets> hard, firm, vigorous.]</ety> <fld>(Mus.)</fld>
<def>Major; in the major mode; <as>as, C <ex>dur</ex>, that is, C
major</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dura</ent><br/
\'d8<hw>Du"ra</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Short form for
<er>Dura mater</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Durability</ent><br/
<hw>Du`ra*bil"i*ty</hw>, <pos>n.</pos> <ety>[L.
<ets>durabilitas</ets>.]</ety> <def>The state or quality of being
durable; the power of uninterrupted or long continuance in any
condition; the power of resisting agents or influences which tend to
cause changes, decay, or dissolution; lastingness.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A Gothic cathedral raises ideas of grandeur in our minds by the
size, its height, . . . its antiquity, and its
<qex>durability</qex>.</q> <rj><qau>Blair.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Durable</ent><br/
<hw>Du"ra*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>durabilis</ets>, fr. <ets>durare</ets> to last: cf. F.
<ets>durable</ets>. See <er>Dure</er>.]</ety> <def>Able to endure or
continue in a particular condition; lasting; not perishable or
changeable; not wearing out or decaying soon; enduring; <as>as,
<ex>durable</ex> cloth; <ex>durable</ex> happiness.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Riches and honor are with me; yea, <qex>durable</qex> riches and
righteousness.</q> <rj><qau>Prov. viii. 18.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>An interest which from its object and grounds must be so
<qex>durable</qex>.</q> <rj><qau>De Quincey.</qau></rj></p>

<p><syn><b>Syn.</b> -- Lasting; permanent; enduring; firm; stable;
continuing; constant; persistent. See <er>Lasting</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Durableness</ent><br/
<hw>Du"ra*ble*ness</hw>, <pos>n.</pos> <def>Power of lasting, enduring,
or resisting; durability.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The <qex>durableness</qex> of the metal that supports it.</q>
<rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Durably</ent><br/
<hw>Du"ra*bly</hw>, <pos>adv.</pos> <def>In a lasting manner; with long
continuance.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dural</ent><br/
<hw>Du"ral</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Anat.)</fld>
<def>Pertaining to the dura, or dura mater.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duralumin</ent><br/
<hw>Duralumin</hw> <pos>prop. n.</pos> <ety>[a trademark.]</ety> <def>an
aluminum-based alloy which is both light and strong, containing 4 per
cent of copper and 0.5 per cent of magnesium and smaller amounts of
iron, manganese, and silicon. It hardens with aging at room
temperature.</def><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Dura mater</ent><br/
\'d8<hw>Du"ra ma"ter</hw> <pr>(?)</pr>. <ety>[L., lit., hard mother. The
membrane was called <ets>mater</ets>, or mother, because it was formerly
thought to give rise to every membrane of the body.]</ety>
<fld>(Anat.)</fld> <def>The tough, fibrous membrane, which lines the
cavity of the skull and spinal column, and surrounds the brain and
spinal cord; -- frequently abbreviated to <abbr>dura</abbr>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duramen</ent><br/
\'d8<hw>Du*ra"men</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., hardness, a
hardened, <it>i. e.</it>, ligneous, vine branch, fr. <ets>durare</ets>
to harden. See <er>Dure</er>.]</ety> <fld>(Bot.)</fld> <def>The
heartwood of an exogenous tree.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Durance</ent><br/
<hw>Dur"ance</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>durance</ets> duration, fr. L. <ets>durans</ets>,
<ets>-antis</ets>, p. pr. <ets>durare</ets> to endure, last. See
<er>Dure</er>, and cf. <er>Durant</er>.]</ety> <sn>1.</sn>
<def>Continuance; duration. See <er>Endurance</er>.</def>
<mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Of how short <qex>durance</qex> was this new-made state!</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Imprisonment; restraint of the person; custody by a
jailer; duress. <xex>Shak</xex>.</def> <ldquo/<xex>Durance</xex>
vile.<rdquo/ <rj><au>Burns.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>In <qex>durance</qex>, exile, Bedlam or the mint.</q>
<rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <sd>(a)</sd> <def>A stout cloth stuff, formerly made in
imitation of buff leather and used for garments; a sort of tammy or
everlasting.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Where didst thou buy this buff? let me not live but I will give
thee a good suit of <qex>durance</qex>.</q> <rj><qau>J.
Webster.</qau></rj></p>

<p><sd>(b)</sd> <def>In modern manufacture, a worsted of one color used
for window blinds and similar purposes.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Durancy</ent><br/
<hw>Dur"an*cy</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Duration.</def>
<mark>[Obs.]</mark> <rj><au>Dr. H. More.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Durant</ent><br/
<hw>Dur"ant</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[F. <ets>durant</ets>,
p. pr. of <ets>durer</ets> to last. Cf. <er>Durance</er>.]</ety>
<def>See <er>Durance</er>, 3.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Durante</ent><br/
\'d8<hw>Du*ran"te</hw> <pr>(?)</pr>, <pos>prep.</pos> <ety>[L., abl.
case of the p. pr. of <ets>durare</ets> to last.]</ety> <fld>(Law)</fld>
<def>During; <as>as, <ex>durante vita</ex>, during life; <ex>durante
bene placito</ex>, during pleasure.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duration</ent><br/
<hw>Du*ra"tion</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>duration</ets>. See <er>Dure</er>.]</ety> <def>The state or quality
of lasting; continuance in time; the portion of time during which
anything exists.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It was proposed that the <qex>duration</qex> of Parliament should
be limited.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Soon shall have passed our own human <qex>duration</qex>.</q>
<rj><qau>D. Webster.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Durative</ent><br/
<hw>Dur"a*tive</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Continuing; not
completed; implying duration.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Its <qex>durative</qex> tense, which expresses the thought of it
as going on.</q> <rj><qau>J. Byrne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Durbar</ent><br/
<hw>Dur"bar</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Hind.
<ets>darb<amac/r</ets>, fr. Per <ets>dar<?/<amac/r</ets> house, court,
hall of audience; <ets>dar</ets> door, gate + <ets>b<amac/r</ets> court,
assembly.]</ety> <def>An audience hall; the court of a native prince; a
state levee; a formal reception of native princes, given by the governor
general of India.</def> <mark>[India]</mark> <altsp>[Written also
<asp>darbar</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dure</ent><br/
<hw>Dure</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L. <ets>durus</ets>;
akin to Ir. & Gael. <ets>dur <?/</ets>, stubborn, W. <ets>dir</ets>
certain, sure, cf. Gr. <?/ force.]</ety> <def>Hard; harsh; severe;
rough; toilsome.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The winter is severe, and life is <qex>dure</qex> and rude.</q>
<rj><qau>W. H. Russell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dure</ent><br/
<hw>Dure</hw>, <pos>v. i.</pos> <ety>[F. <ets>durer</ets>, L.
<ets>durare</ets> to harden, be hardened, to endure, last, fr.
<ets>durus</ets> hard. See <er>Dure</er>, <pos>a.</pos>]</ety> <def>To
last; to continue; to endure.</def> <mark>[Obs.]</mark> <rj><au>Sir W.
Raleigh.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Yet hath he not root in himself, but <qex>dureth</qex> for a
while.</q> <rj><qau>Matt. xiii. 21.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dureful</ent><br/
<hw>Dure"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Lasting.</def>
<mark>[Obs.]</mark> <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dureless</ent><br/
<hw>Dure"less</hw>, <pos>a.</pos> <def>Not lasting.</def>
<mark>[Obs.]</mark> <rj><au>Sir W. Raleigh.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Durene</ent><br/
<hw>Du"rene</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>durus</ets>
hard; -- so called because solid at ordinary temperatures.]</ety>
<fld>(Chem.)</fld> <def>A colorless, crystalline, aromatic hydrocarbon,
<chform>C6H2(CH3)4</chform>, off artificial production, with an odor
like camphor.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duress</ent><br/
<hw>Du"ress</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OF.
<ets>duresse</ets>, <ets>du<?/</ets>, hardship, severity, L.
<ets>duritia</ets>, <ets>durities</ets>, fr. <ets>durus</ets> hard. See
<er>Dure</er>.]</ety> <sn>1.</sn> <def>Hardship; constraint; pressure;
imprisonment; restraint of liberty.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The agreements . . . made with the landlords during the time of
slavery, are only the effect of <qex>duress</qex> and force.</q>
<rj><qau>Burke.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Law)</fld> <def>The state of compulsion or
necessity in which a person is influenced, whether by the unlawful
restrain of his liberty or by actual or threatened physical violence, to
incur a civil liability or to commit an offense.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duress</ent><br/
<hw>Du*ress"</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To subject to
duress.</def> <ldquo/The party <xex>duressed</xex>.<rdquo/
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duressor</ent><br/
<hw>Du*ress"or</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Law)</fld>
<def>One who subjects another to duress</def>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Durga</ent><br/
\'d8<hw>Dur"ga</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Myth.)</fld>
<def>Same as <er>Doorga</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Durham</ent><br/
<hw>Dur"ham</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One or a breed of
short-horned cattle, originating in the county of Durham, England. The
Durham cattle are noted for their beef-producing quality.</def></p>

<p><ent>Durion</ent><br/
<ent>Durian</ent><br/
<mhw>{ <hw>Du"ri*an</hw> <pr>(?)</pr>, <it>or</it> <hw>Du"ri*on</hw>
<pr>(?)</pr> }</mhw>, <pos>n.</pos> <fld>(Bot.)</fld> <def>The fruit of
the durio. It is oval or globular, and eight or ten inches long. It has
a hard prickly rind, containing a soft, cream-colored pulp, of a most
delicious flavor and a very offensive odor. The seeds are roasted and
eaten like chestnuts.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>During</ent><br/
<hw>Dur"ing</hw> <pr>(?)</pr>, <pos>prep.</pos> <ety>[Orig., p. pr. of
<ets>dure</ets>.]</ety> <def>In the time of; as long as the action or
existence of; <as>as, <ex>during</ex> life; <ex>during</ex> the space of
a year.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Durio</ent><br/
\'d8<hw>Du"ri*o</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Malay
<ets>d<?/ri</ets> thorn.]</ety> <fld>(Bot.)</fld> <def>A fruit tree
(<spn>Durio zibethinus</spn>, the only species known) of the Indian
Archipelago. It bears the <prod>durian</prod>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Durity</ent><br/
<hw>Du"ri*ty</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>duritas</ets>, fr. <ets>durus</ets> hard.]</ety>
<mark>[Obs.]</mark> <sn>1.</sn> <def>Hardness; firmness.</def>
<rj><au>Sir T. Browne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Harshness; cruelty.</def>
<rj><au>Cockeram.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Durometer</ent><br/
<hw>Du*rom"e*ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>durus</ets> hard + <ets>-meter</ets>.]</ety> <def>An instrument for
measuring the degree of hardness; especially, an instrument for testing
the relative hardness of steel rails and the like.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Durous</ent><br/
<hw>Du"rous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>durus</ets>.]</ety> <def>Hard.</def> <mark>[Obs. & R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Durra</ent><br/
<hw>Dur"ra</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Ar.
<ets>dhorra</ets>.]</ety> <fld>(Bot.)</fld> <def>A kind of millet,
cultivated throughout Asia, and introduced into the south of Europe; a
variety of <spn>Sorghum vulgare</spn>; -- called also <altname>Indian
millet</altname>, and <altname>Guinea corn</altname>.</def>
<altsp>[Written also <asp>dhoorra</asp>, <asp>dhurra</asp>,
<asp>doura</asp>, etc.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Durst</ent><br/
<hw>Durst</hw> <pr>(?)</pr>, <pos>imp.</pos> <def>of <er>Dare</er>. See
<er>Dare</er>, <pos>v. i.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Durukuli</ent><br/
\'d8<hw>Du`ru*ku"li</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>A small, nocturnal, South American monkey of the genus
<gen>Aotus</gen> (formerly <spn>Nyctipthecus trivirgatus</spn>). The
<altname>owl monkey</altname>. See <er>douroucouli</er>.</def>
<altsp>[Written also <asp>douroucouli</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Durylic</ent><br/
<hw>Du*ryl"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Chem.)</fld>
<def>Pertaining to, allied to, or derived from, durene; <as>as,
<ex>durylic</ex> acid</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duse</ent><br/
<hw>Duse</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A demon or spirit. See
<er>Deuce</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dushanbe</ent><br/
<hw>Dushanbe</hw> <pos>prop. n.</pos> <fld>(Geography)</fld> <def>The
capital <isa>city</isa> of <country>Tajikistan</country>. Population
(2000) = 524,000.</def><br/
[<source>PJC</source>]</p>

<p><ent>Dusk</ent><br/
<hw>Dusk</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OE. <ets>dusc</ets>,
<ets>dosc</ets>, <ets>deosc</ets>; cf. dial. Sw. <ets>duska</ets> to
drizzle, <ets>dusk</ets> a slight shower. <?/<?/<?/.]</ety> <def>Tending
to darkness or blackness; moderately dark or black; dusky.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A pathless desert, <qex>dusk</qex> with horrid shades.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dusk</ent><br/
<hw>Dusk</hw>, <pos>n.</pos> <sn>1.</sn> <def>Imperfect obscurity; a
middle degree between light and darkness; twilight; <as>as, the
<ex>dusk</ex> of the evening</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A darkish color.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Whose <qex>duck</qex> set off the whiteness of the skin.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dusk</ent><br/
<hw>Dusk</hw>, <pos>v. t.</pos> <def>To make dusk.</def>
<mark>[Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>After the sun is up, that shadow which <qex>dusketh</qex> the
light of the moon must needs be under the earth.</q>
<rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dusk</ent><br/
<hw>Dusk</hw>, <pos>v. i.</pos> <def>To grow dusk.</def>
<mark>[R.]</mark> <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dusken</ent><br/
<hw>Dusk"en</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To make dusk or
obscure.</def> <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Not utterly defaced, but only <qex>duskened</qex>.</q>
<rj><qau>Nicolls.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duskily</ent><br/
<hw>Dusk"i*ly</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>In a dusky
manner.</def> <rj><au>Byron.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duskiness</ent><br/
<hw>Dusk"i*ness</hw>, <pos>n.</pos> <def>The state of being
dusky.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duskish</ent><br/
<hw>Dusk"ish</hw>, <pos>a.</pos> <def>Somewhat dusky.</def> <ldquo/
<xex>Duskish</xex> smoke.<rdquo/ <au>Spenser.</au> --
<wordforms><wf>Dusk"ish*ly</wf>, <pos>adv.</pos> --
<wf>Dusk"ish*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duskness</ent><br/
<hw>Dusk"ness</hw>, <pos>n.</pos> <def>Duskiness.</def>
<mark>[R.]</mark> <rj><au>Sir T. Elyot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dusky</ent><br/
<hw>Dusk"y</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Partially
dark or obscure; not luminous; dusk; <as>as, a <ex>dusky</ex>
valley</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Through <qex>dusky</qex> lane and wrangling mart.</q>
<rj><qau>Keble.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Tending to blackness in color; partially black;
dark-colored; not bright; <as>as, a <ex>dusky</ex> brown</as>.</def>
<rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>When Jove in <qex>dusky</qex> clouds involves the sky.</q>
<rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The figure of that first ancestor invested by family tradition
with a dim and <qex>dusky</qex> grandeur.</q>
<rj><qau>Hawthorne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Gloomy; sad; melancholy.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>This <qex>dusky</qex> scene of horror, this melancholy
prospect.</q> <rj><qau>Bentley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Intellectually clouded.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Though <qex>dusky</qex> wits dare scorn astrology.</q>
<rj><qau>Sir P. Sidney.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dust</ent><br/
<hw>Dust</hw> <pr>(d<ucr/st)</pr>, <pos>n.</pos> <ety>[AS.
<ets>dust</ets>; cf. LG. <ets>dust</ets>, D. <ets>duist</ets> meal dust,
OD. <ets>doest</ets>, <ets>donst</ets>, and G. <ets>dunst</ets> vapor,
OHG. <ets>tunist</ets>, <ets>dunist</ets>, a blowing, wind, Icel.
<ets>dust</ets> dust, Dan. <ets>dyst</ets> mill dust; perh. akin to L.
<ets>fumus</ets> smoke, E. <ets>fume</ets>. <root/71.]</ety> <sn>1.</sn>
<def>Fine, dry particles of earth or other matter, so comminuted that
they may be raised and wafted by the wind; that which is crumbled to
minute portions; fine powder; <as>as, clouds of <ex>dust</ex>; bone
<ex>dust</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Dust</qex> thou art, and unto <qex>dust</qex> shalt thou
return.</q> <rj><qau>Gen. iii. 19.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Stop! -- for thy tread is on an empire's <qex>dust</qex>.</q>
<rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A single particle of earth or other matter.</def>
<mark>[R.]</mark> <ldquo/To touch a <xex>dust</xex> of England's
ground.<rdquo/ <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>The earth, as the resting place of the
dead.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>For now shall sleep in the <qex>dust</qex>.</q> <rj><qau>Job vii.
21.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>The earthy remains of bodies once alive; the remains
of the human body.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And you may carve a shrine about my <qex>dust</qex>.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Figuratively, a worthless thing.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And by the merit of vile gold, dross, <qex>dust</qex>.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>Figuratively, a low or mean condition.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>[God] raiseth up the poor out of the <qex>dust</qex>.</q>
<rj><qau>1 Sam. ii. 8.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>Gold dust</def>; hence: (<mark>Slang</mark>)
<def>Coined money; cash.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Down with the dust</b></col>, <cd>deposit the cash; pay
down the money.</cd> <mark>[Slang]</mark> <ldquo/My lord, quoth the
king, presently deposit your hundred pounds in gold, or else no going
hence all the days of your life. . . . The Abbot <xex>down with his
dust</xex>, and glad he escaped so, returned to Reading.<rdquo/
<au>Fuller.</au> -- <col><b>Dust brand</b></col> <fld>(Bot.)</fld>,
<cd>a fungous plant (<spn>Ustilago Carbo</spn>); -- called also
<altname>smut</altname>.</cd> -- <col><b>Gold dust</b></col>, <cd>fine
particles of gold, such as are obtained in placer mining; -- often used
as money, being transferred by weight.</cd> -- <col><b>In dust and
ashes</b></col>. <cd>See under <er>Ashes</er>.</cd> -- <col><b>To bite
the dust</b></col>. <cd>See under <er>Bite</er>, <pos>v. t.</pos></cd>
-- <col><b>To raise dust</b></col>, <it>or</it> <col><b>To kick up
dust</b></col>, <cd>to make a commotion.</cd> <mark>[Colloq.]</mark> --
<col><b>To throw dust in one's eyes</b></col>, <cd>to mislead; to
deceive.</cd> <mark>[Colloq.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dust</ent><br/
<hw>Dust</hw> <pr>(d<ucr/st)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Dusted</conjf>; <pos>p. pr. & vb. n.</pos>
<conjf>Dusting</conjf>.]</vmorph> <sn>1.</sn> <def>To free from dust; to
brush, wipe, or sweep away dust from; <as>as, to <ex>dust</ex> a table
or a floor</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To sprinkle with dust.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To reduce to a fine powder; to levigate.</def>
<rj><au>Sprat.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>To dyst one's jacket</b></col>, <cd>to give one a
flogging.</cd> <mark>[Slang.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>dustbin</ent><br/
<hw>dustbin</hw> <pr>(d<ucr/st"b<icr/n)</pr>, <pos>n.</pos> <def>a bin
that holds rubbish until it is collected.</def><br/
<syn><b>Syn. --</b> ashcan, trash can, garbage can, wastebin, ashbin,
trash barrel, trash bin.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dustbrush</ent><br/
<hw>Dust"brush`</hw> <pr>(d<ucr/st"br<ucr/sh)</pr>, <pos>n.</pos> <def>A
brush of feathers, bristles, or hair, for removing dust from
furniture.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>dustcart</ent><br/
<hw>dust"cart</hw> <pr>(d<ucr/st"k<aum/rt)</pr>, <pos>n.</pos> <def>a
truck for collecting domestic refuse; <as>as, in England a garbage truck
is called a <ex>dustcart</ex></as>.</def><br/
<syn><b>Syn. --</b> garbage truck.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>dustcloth</ent><br/
<hw>dust"cloth`</hw> <pr>(d<ucr/st"kl<ocr/th`)</pr>, <pos>n.</pos>
<def>A piece of cloth used for wiping dust from objects or
surfaces.</def><br/
<syn><b>Syn. --</b> dustrag, duster.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>duster</ent><br/
<hw>dust"er</hw> <pr>(d<ucr/st"<etil/r)</pr>, <pos>n.</pos> <sn>1.</sn>
<def>One who, or that which, dusts; a utensil that frees from
dust.</def> <specif>Specifically:</specif> <sd>(a)</sd> <fld>(Paper
Making)</fld> <def>A revolving wire-cloth cylinder which removes the
dust from rags, etc.</def> <sd>(b)</sd> <fld>(Milling)</fld> <def>A
blowing machine for separating the flour from the bran.</def>
<sd>(c)</sd> <def>A <er>dustcloth</er> or a brush used for removing dust
from objects or surfaces.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A long light overgarment;</def>
<specif>specifically</specif> <sd>(a)</sd> <def>a light over-garment,
formerly worn when traveling in open vehicles to protect the clothing
from dust.</def> <mark>[U.S.]</mark> <sd>(b)</sd> <def>A light housecoat
worn by women.</def> <sd>(c)</sd> <def>A light overcoat worn by women,
often having no lining.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><sn>3.</sn> <def>A device for spreading a powder, especially one for
spreading insecticide on plants.</def><br/
[<source>PJC</source>]</p>

<p><sn>4.</sn> <fld>(Baseball)</fld> <def>A pitch intentionally thrown
by a pitcher directly at or very close to the batter, intended to make
the batter stand further away from home plate; also called a
<altname>dust-back pitch</altname> or a
<altname>dust-back</altname>.</def><br/
[<source>PJC</source>]</p>

<p><sn>5.</sn> <def>A <er>dust storm</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>dustiness</ent><br/
<hw>dust"i*ness</hw> <pr>(d<ucr/st"<icr/*n<ecr/s)</pr>, <pos>n.</pos>
<def>The state of being dusty.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>dustless</ent><br/
<hw>dust"less</hw> <pr>(d<ucr/st"l<ecr/s)</pr>, <pos>a.</pos>
<def>Without dust; as a <xex>dustless</xex> path.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>dustman</ent><br/
<hw>dust"man</hw> <pr>(d<ucr/st"m<acr/n)</pr>, <pos>n.</pos>;
<plu><it>pl.</it> <plw>dustmen</plw> <pr>(d<ucr/st"m<ecr/n)</pr>.</plu>
<def>One whose employment is to remove dirt and refuse; a garbage
man.</def> <rj><au>Gay.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>dustmop</ent><br/
<hw>dust"mop</hw> <pr>(d<ucr/st"m<ocr/p)</pr>, <pos>n.</pos> <def>a dry
mop for dusting floors.</def><br/
<syn><b>Syn. --</b> dust mop, dry mop.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>dustpan</ent><br/
<hw>dust"pan`</hw> <pr>(d<ucr/st"p<acr/n`)</pr>, <pos>n.</pos> <def>A
shovel-like utensil with a short handle used for conveying away dust
brushed from the floor.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>dust-point</ent><br/
<hw>dust"-point`</hw> <pr>(d<ucr/st"point`)</pr>, <pos>n.</pos> <def>An
old rural game.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>With any boy at <qex>dust-point</qex> they shall play.</q>
<rj><qau>Peacham (1620).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>dust storm</ent><br/
<hw>dust" storm`</hw> <pr>(d<ucr/st"st<ocir/rm`)</pr>, <pos>n.</pos>
<def>A strong windstorm that lifts particles of dust or dry soil into
the air and blows them around, covering land or objects with a thick
layer of dust. <ex>Dust storms</ex> may occur in arable areas during
periods of drought; when a similar storm occurs in a desert area, such a
storm is called a <stype>sandstorm</stype>.</def><br/
[<source>PJC</source>]</p>

<p><ent>dustup</ent><br/
<hw>dust"up</hw> <pos>n.</pos> <def>an angry dispute.</def><br/
<syn><b>Syn. --</b> quarrel, wrangle, row, words, run-in.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>dusty</ent><br/
<hw>dust"y</hw> <pr>(d<ucr/st"<ycr/)</pr>, <pos>a.</pos>
<amorph>[<pos>Compar.</pos> <adjf>Dustier</adjf>
<pr>(d<ucr/st"<icr/*<etil/r)</pr>; <pos>superl.</pos>
<adjf>Dustiest</adjf> <pr>(d<ucr/st"<icr/*<ecr/st)</pr>.]</amorph>
<ety>[AS. <ets>dystig</ets>. See <er>Dust</er>.]</ety> <sn>1.</sn>
<def>Filled, covered, or sprinkled with dust; clouded with dust; <as>as,
a <ex>dusty</ex> table; a <ex>dusty</ex> attic</as>; also, reducing to
dust.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And all our yesterdays have lighted fools<br/
The way to <qex>dusty</qex> death.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Like dust; of the color of dust; <as>as, a
<ex>dusty</ex> white</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dusty miller</b></col> <fld>(Bot.)</fld>, <cd>a plant
(<spn>Cineraria maritima</spn>); -- so called because of the ashy-white
coating of its leaves.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dutch</ent><br/
<hw>Dutch</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[D. <ets>duitsch</ets>
German; or G. <ets>deutsch</ets>, orig., popular, national, OD.
<ets>dietsc</ets>, MHG. <ets>diutsch</ets>, <ets>tiutsch</ets>, OHG.
<ets>diutisk</ets>, fr. <ets>diot</ets>, <ets>diota</ets>, a people, a
nation; akin to AS. <ets>pe<oacute/d</ets>, OS. <ets>thiod</ets>,
<ets>thioda</ets>, Goth. <ets>piuda</ets>; cf. Lith. <ets>tauta</ets>
land, OIr. <ets>tuath</ets> people, Oscan<-- ??sic --> <ets>touto</ets>.
The English have applied the name especially to the Germanic people
living nearest them, the Hollanders. Cf. <er>Derrick</er>,
<er>Teutonic</er>.]</ety> <def>Pertaining to Holland, or to its
inhabitants.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dutch auction</b></col>. <cd>See under
<er>Auction</er>.</cd> -- <col><b>Dutch cheese</b></col>, <cd>a small,
pound, hard cheese, made from skim milk.</cd> -- <col><b>Dutch
clinker</b></col>, <cd>a kind of brick made in Holland. It is yellowish,
very hard, and long and narrow in shape.</cd> -- <col><b>Dutch
clover</b></col> <fld>(Bot.)</fld>, <cd>common white clover
(<spn>Trifolium repens</spn>), the seed of which was largely imported
into England from Holland.</cd> -- <col><b>Dutch concert</b></col>,
<cd>a so-called concert in which all the singers sing at the same time
different songs.</cd> <mark>[Slang]</mark> -- <col><b>Dutch
courage</b></col>, <cd>the courage of partial intoxication.</cd>
<mark>[Slang]</mark> <au>Marryat.</au> -- <col><b>Dutch door</b></col>,
<cd>a door divided into two parts, horizontally, so arranged that the
lower part can be shut and fastened, while the upper part remains
open.</cd> -- <mcol><col><b>Dutch foil</b></col>, <col><b>Dutch
leaf</b></col>, <it>or</it> <col><b>Dutch gold</b></col></mcol>, <cd>a
kind of brass rich in copper, rolled or beaten into thin sheets, used in
Holland to ornament toys and paper; -- called also <altname>Dutch
mineral</altname>, <altname>Dutch metal</altname>, <altname>brass
foil</altname>, and <altname>bronze leaf</altname>.</cd> --
<col><b>Dutch liquid</b></col> <fld>(Chem.)</fld>, <cd>a thin,
colorless, volatile liquid, <chform>C2H4Cl2</chform>, of a sweetish
taste and a pleasant ethereal odor, produced by the union of chlorine
and ethylene or olefiant gas; -- called also <altname>Dutch
oil</altname>. It is so called because discovered (in 1795) by an
association of four Hollandish chemists. See <er>Ethylene</er>, and
<er>Olefiant</er>.</cd><-- = ethylene chloride --> -- <col><b>Dutch
oven</b></col>, <cd>a tin screen for baking before an open fire or
kitchen range; also, in the United States, a shallow iron kettle for
baking, with a cover to hold burning coals.</cd> -- <col><b>Dutch
pink</b></col>, <cd>chalk, or whiting dyed yellow, and used in
distemper, and for paper staining. etc.</cd> <au>Weale.</au> --
<col><b>Dutch rush</b></col> <fld>(Bot.)</fld>, <cd>a species of
horsetail rush or <gen>Equisetum</gen> (<spn>Equisetum hyemale</spn>)
having a rough, siliceous surface, and used for scouring and polishing;
-- called also <altname>scouring rush</altname>, and <altname>shave
grass</altname>. See <er>Equisetum</er>.</cd> -- <col><b>Dutch
tile</b></col>, <cd>a glazed and painted ornamental tile, formerly much
exported, and used in the jambs of chimneys and the like.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Dutch</xex> was formerly used for
<xex>German</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><q>Germany is slandered to have sent none to this war [the Crusades]
at this first voyage; and that other pilgrims, passing through that
country, were mocked by the <qex>Dutch</qex>, and called fools for their
pains.</q> <rj><qau>Fuller.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dutch</ent><br/
<hw>Dutch</hw>, <pos>n.</pos> <sn>1.</sn> <pluf>pl.</pluf> <def>The
people of Holland; Dutchmen.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The language spoken in Holland.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dutchman</ent><br/
<hw>Dutch"man</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Dutchmen</plw> <pr>(<?/)</pr>.</plu> <def>A native, or one of the
people, of Holland.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dutchman's laudanum</b></col> <fld>(Bot.)</fld>, <cd>a
West Indian passion flower (<spn>Passiflora Murucuja</spn>); also, its
fruit.</cd> -- <col><b>Dutchman's pipe</b></col> <fld>(Bot.)</fld>,
<cd>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dutchman's-breeches</ent><br/
<ent>Dutchman's breeches</ent><br/
<mhw><hw>Dutchman's breeches</hw>, <hw>Dutchman's-breeches</hw></mhw>
<pos>n.</pos> <fld>(Bot.)</fld>, <def>a delicate perennial
spring-flowering herb (<spn>Dicentra cucullaria</spn>) of eastern U.S.,
having peculiar double-spurred white flowers. See <xex>Illust.</xex> of
<er>Dicentra</er></def><br/
<syn><b>Syn. --</b> <spn>Dicentra cucullaria</spn>.</syn><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><ent>Dutchman's-pipe</ent><br/
<hw>Dutchman's-pipe</hw> <pos>n.</pos> <def>a hardy deciduous American
vine (<spn>Aristolochia durior</spn>) having large, heart-shaped leaves
and bearing brownish-purple flowers which have their calyx tubes curved
like the bowl of a tobacco pipe. Formerly classified as
<spn>Aristolochia Sipho</spn>.</def><br/
<syn><b>Syn. --</b> pipe vine, <spn>Aristolochia macrophylla</spn>,
<spn>Aristolochia durior</spn>.</syn><br/
[<source>1913 Webster</source> + <source>WordNet 1.5</source>]</p>

<p><ent>Duteous</ent><br/
<hw>Du"te*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From
<er>Duty</er>.]</ety> <sn>1.</sn> <def>Fulfilling duty; dutiful; having
the sentiments due to a superior, or to one to whom respect or service
is owed; obedient; <as>as, a <ex>duteous</ex> son or
daughter</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Subservient; obsequious.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Duteous</qex> to the vices of thy mistress.</q>
<rj><qau>Shak.</qau></rj></p>

<p>-- <wordforms><wf>Du"te*ous*ly</wf>, <pos>adv.</pos> --
<wf>Du"te*ous*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dutiable</ent><br/
<hw>Du"ti*a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[From
<er>Duty</er>.]</ety> <def>Subject to the payment of a duty; as
<xex>dutiable</xex> goods.</def> <mark>[U.S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>All kinds of <qex>dutiable</qex> merchandise.</q>
<rj><qau>Hawthorne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dutied</ent><br/
<hw>Du"tied</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Subjected to a
duty.</def> <rj><au>Ames.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dutiful</ent><br/
<hw>Du"ti*ful</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn>
<def>Performing, or ready to perform, the duties required by one who has
the right to claim submission, obedience, or deference; submissive to
natural or legal superiors; obedient, as to parents or superiors;
<as>as, a <ex>dutiful</ex> son or daughter; a <ex>dutiful</ex> ward or
servant; a <ex>dutiful</ex> subject.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Controlled by, proceeding from, a sense of duty;
respectful; deferential; <as>as, <ex>dutiful</ex>
affection</as>.</def></p>

<p><syn><b>Syn.</b> -- Duteous; obedient; reverent; reverential;
submissive; docile; respectful; compliant.</syn></p>

<p>-- <wordforms><wf>Du"ti*ful*ly</wf>, <pos>adv.</pos> --
<wf>Du"ti*ful*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duty</ent><br/
<hw>Du"ty</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Duties</plw> <pr>(#)</pr>.</plu> <ety>[From <er>Due</er>.]</ety>
<sn>1.</sn> <def>That which is due; payment.</def> <mark>[Obs. as
signifying a material thing.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>When thou receivest money for thy labor or ware, thou receivest
thy <qex>duty</qex>.</q> <rj><qau>Tyndale.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 463 --></p>

<p><sn>2.</sn> <def>That which a person is bound by moral obligation to
do, or refrain from doing; that which one ought to do; service morally
obligatory.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Forgetting his <qex>duty</qex> toward God, his sovereign lord, and
his country.</q> <rj><qau>Hallam.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Hence, any assigned service or business; <as>as, the
<ex>duties</ex> of a policeman, or a soldier; to be on
<ex>duty</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>With records sweet of <qex>duties</qex> done.</q>
<rj><qau>Keble.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>To employ him on the hardest and most imperative
<qex>duty</qex>.</q> <rj><qau>Hallam.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Duty</qex> is a graver term than obligation. A
<qex>duty</qex> hardly exists to do trivial things; but there may be an
obligation to do them.</q> <rj><qau>C. J. Smith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Specifically, obedience or submission due to parents
and superiors.</def> <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Respect; reverence; regard; act of respect;
homage.</def> <ldquo/My <xex>duty</xex> to you.<rdquo/
<rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Engin.)</fld> <def>The efficiency of an engine,
especially a steam pumping engine, as measured by work done by a certain
quantity of fuel; usually, the number of pounds of water lifted one foot
by one bushel of coal (94 lbs. old standard), or by 1 cwt. (112 lbs.,
England, or 100 lbs., United States).</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Com.)</fld> <def>Tax, toll, impost, or customs;
excise; any sum of money required by government to be paid on the
importation, exportation, or consumption of goods.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ An impost on land or other real estate, and on the stock
of farmers, is not called a <xex>duty</xex>, but a <xex>direct
tax</xex>. <mark>[U.S.]</mark></note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Ad valorem duty</b></col>, <cd>a duty which is graded
according to the cost, or market value, of the article taxed. See <er>Ad
valorem</er>.</cd> -- <col><b>Specific duty</b></col>, <cd>a duty of a
specific sum assessed on an article without reference to its value or
market.</cd> -- <col><b>On duty</b></col>, <cd>actually engaged in the
performance of one's assigned task.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duumvir</ent><br/
\'d8<hw>Du*um"vir</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it> E.
<plw>Duumvirs</plw> <pr>(#)</pr>, L. <plw>Duumviri</plw>
<pr>(#)</pr>.</plu> <ety>[L., fr. <ets>duo</ets> two + <ets>vir</ets>
man.]</ety> <fld>(Rom. Antiq.)</fld> <def>One of two Roman officers or
magistrates united in the same public functions.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duumviral</ent><br/
<hw>Du*um"vi*ral</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[L.
<ets>duumviralis</ets>.]</ety> <def>Of or belonging to the duumviri or
the duumvirate.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duumvirate</ent><br/
<hw>Du*um"vi*rate</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>duumviratus</ets>, fr. <ets>duumvir</ets>.]</ety> <def>The union of
two men in the same office; or the office, dignity, or government of two
men thus associated, as in ancient Rome.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dux</ent><br/
\'d8<hw>Dux</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., leader.]</ety>
<fld>(Mus.)</fld> <def>The scholastic name for the theme or subject of a
fugue, the answer being called the <xex>comes</xex>, or
companion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duykerbok</ent><br/
\'d8<hw>Duy"ker*bok</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[D.
<ets>duiker</ets> diver + <ets>bok</ets> a buck, lit., diver buck. So
named from its habit of diving suddenly into the bush.]</ety>
<fld>(Zool.)</fld> <def>A small South African antelope (<spn>Cephalous
mergens</spn>); -- called also <altname>impoon</altname>, and
<altname>deloo</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Duyoung</ent><br/
<hw>Du*young"</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>See <er>Dugong</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>D valve</ent><br/
<hw>D" valve`</hw> <pr>(?)</pr>. <fld>(Mech.)</fld> <def>A kind of slide
valve. See <cref>Slide valve</cref>, under <er>Slide</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dvergr</ent><br/
\'d8<hw>Dver"gr</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Dvergar</plw> <pr>(#)</pr>.</plu> <ety>[See <er>Dwarf</er>.]</ety>
<fld>(Scand. Myth.)</fld> <def>A dwarf supposed to dwell in rocks and
hills and to be skillful in working metals.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dwale</ent><br/
<hw>Dwale</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>dwale</ets>,
<ets>dwole</ets>, deception, deadly nightshade, AS. <ets>dwala</ets>,
<ets>dwola</ets>, error, doubt; akin to E. <ets>dull</ets>. See
<er>Dull</er>, <pos>a.</pos>]</ety> <sn>1.</sn> <fld>(Bot.)</fld>
<def>The deadly nightshade (<spn>Atropa Belladonna</spn>), having
stupefying qualities.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Her.)</fld> <def>The tincture sable or black when
blazoned according to the fantastic system in which plants are
substituted for the tinctures.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A sleeping potion; an opiate.</def>
<rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dwang</ent><br/
<hw>Dwang</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. D.
<ets>dwingen</ets> to force, compel.]</ety> <sn>1.</sn>
<fld>(Carp.)</fld> <def>A piece of wood set between two studs, posts,
etc., to stiffen and support them.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Mech.)</fld> <sd>(a)</sd> <def>A kind of
crowbar.</def> <sd>(b)</sd> <def>A large wrench.</def>
<rj><au>Knight.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dwarf</ent><br/
<hw>Dwarf</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Dwarfs</plw> <pr>(#)</pr>.</plu> <ety>[OE. <ets>dwergh</ets>,
<ets>dwerf</ets>, <ets>dwarf</ets>, AS. <ets>dweorg</ets>,
<ets>dweorh</ets>; akin to D. <ets>dwerg</ets>, MHG. <ets>twerc</ets>,
G. <ets>zwerg</ets>, Icel. <ets>dvergr</ets>, Sw. & Dan.
<ets>dverg</ets>; of unknown origin.]</ety> <sn>1.</sn> <def>An animal
or plant which is much below the ordinary size of its species or
kind.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <specif>Especially:</specif> <def>A diminutive human
being, small in stature due to a pathological condition which causes a
distortion of the proportions of body parts to each other, such as the
limbs, torso, and head. A person of unusually small height who has
normal body proportions is usually called a
<contr>midget</contr>.</def><br/
[<source>PJC</source>]</p>

<p><note><hand/ During the Middle Ages <xex>dwarfs</xex> as well as
fools shared the favor of courts and the nobility.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Folklore)</fld> <def>A small, usually misshapen
person, typically a man, who may have magical powers; mythical dwarves
were often depicted as living underground in caves.</def><br/
[<source>PJC</source>]</p>

<p><note><xex>Dwarf</xex> is used adjectively in reference to anything
much below the usual or normal size; as, a <ex>dwarf</ex> pear tree;
<ex>dwarf</ex> honeysuckle.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dwarf elder</b></col> <fld>(Bot.)</fld>,
<cd>danewort.</cd> -- <col><b>Dwarf wall</b></col> <fld>(Arch.)</fld>,
<cd>a low wall, not as high as the story of a building, often used as a
garden wall or fence.</cd> <rj><au>Gwilt.</au></rj></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dwarf</ent><br/
<hw>Dwarf</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos>
<conjf>Dwarfed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos>
<conjf>Dwarfing</conjf>.]</vmorph> <def>To hinder from growing to the
natural size; to make or keep small; to stunt.</def>
<rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Even the most common moral ideas and affections . . . would be
stunted and <qex>dwarfed</qex>, if cut off from a spiritual
background.</q> <rj><qau>J. C. Shairp.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dwarf</ent><br/
<hw>Dwarf</hw>, <pos>v. i.</pos> <def>To become small; to diminish in
size.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Strange power of the world that, the moment we enter it, our great
conceptions <qex>dwarf</qex>.</q> <rj><qau>Beaconsfield.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dwarfish</ent><br/
<hw>Dwarf"ish</hw>, <pos>a.</pos> <def>Like a dwarf; below the common
stature or size; very small; petty; <as>as, a <ex>dwarfish</ex> animal,
shrub</as>.</def> -- <wordforms><wf>Dwarf"ish*ly</wf>, <pos>adv.</pos>
-- <wf>Dwarf"ish*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dwarfling</ent><br/
<hw>Dwarf"ling</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A diminutive
dwarf.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dwarfy</ent><br/
<hw>Dwarf"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Much undersized.</def>
<mark>[R.]</mark> <rj><au>Waterhouse.</au></rj></p>

<p><ent>Dwaule</ent><br/
<ent>Dwaul</ent><br/
<mhw>{ <hw>Dwaul</hw>, <hw>Dwaule</hw> }</mhw> <pr>(?)</pr>, <pos>v.
i.</pos> <ety>[See <er>Dull</er>, <er>Dwell</er>.]</ety> <def>To be
delirious.</def> <mark>[Obs.]</mark> <rj><au>Junius.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dwell</ent><br/
<hw>Dwell</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Dwelled</conjf> <pr>(?)</pr>, usually contracted into
<conjf>Dwelt</conjf> (<?/); <pos>p. pr. & vb. n.</pos>
<conjf>Dwelling</conjf>.]</vmorph> <ety>[OE. <ets>dwellen</ets>,
<ets>dwelien</ets>, to err, linger, AS. <ets>dwellan</ets> to deceive,
hinder, delay, <ets>dwelian</ets> to err; akin to Icel.
<ets>dvelja</ets> to delay, tarry, Sw. <ets>dv<aum/ljas</ets> to dwell,
Dan. <ets>dv<ae/le</ets> to linger, and to E. <ets>dull</ets>. See
<er>Dull</er>, and cf. <er>Dwale</er>.]</ety> <sn>1.</sn> <def>To delay;
to linger.</def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To abide; to remain; to continue.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I 'll rather <qex>dwell</qex> in my necessity.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Thy soul was like a star and <qex>dwelt</qex> apart.</q>
<rj><qau>Wordsworth.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To abide as a permanent resident, or for a time; to
live in a place; to reside.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The parish in which I was born, <qex>dwell</qex>, and have
possessions.</q> <rj><qau>Peacham.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The poor man <qex>dwells</qex> in a humble cottage near the hall
where the lord of the domain resides.</q> <rj><qau>C. J.
Smith.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<cs><p><col><b>To dwell in</b></col>, <cd>to abide in (a place); hence,
to depend on.</cd> <ldquo/My hopes <xex>in</xex> heaven to
<xex>dwell</xex>.<rdquo/ <au>Shak.</au> -- <mcol><col><b>To dwell
on</b></col> <it>or</it> <col><b>To dwell upon</b></col></mcol>, <cd>to
continue long on or in; to remain absorbed with; to stick to; to make
much of; <as>as, to <ex>dwell upon</ex> a subject; a singer <ex>dwells
on</ex> a note</as>.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>They stand at a distance, <qex>dwelling on</qex> his looks and
language, fixed in amazement.</q> <rj><qau>Buckminster.</qau></rj>
</p></cs>

<p><syn><b>Syn.</b> -- To inhabit; live; abide; sojourn; reside;
continue; stay; rest.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dwell</ent><br/
<hw>Dwell</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To inhabit.</def>
<mark>[R.]</mark> <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dweller</ent><br/
<hw>Dwell"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An inhabitant; a
resident; <as>as, a cave <ex>dweller</ex></as>.</def>
<ldquo/<xex>Dwellers</xex> at Jerusalem.<rdquo/ <rj><au>Acts i.
19.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dwelling</ent><br/
<hw>Dwell"ing</hw>, <pos>n.</pos> <def>Habitation; place or house in
which a person lives; abode; domicile.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Hazor shall be a <qex>dwelling</qex> for dragons.</q>
<rj><qau>Jer. xlix. 33.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>God will deign<br/
To visit oft the <qex>dwellings</qex> of just men.</q>
<rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Philip's <qex>dwelling</qex> fronted on the street.</q>
<rj><qau>Tennyson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dwelling house</b></col>, <cd>a house intended to be
occupied as a residence, in distinction from a store, office, or other
building.</cd> -- <col><b>Dwelling place</b></col>, <cd>place of
residence.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dwelt</ent><br/
<hw>Dwelt</hw> <pr>(?)</pr>, <pos>imp. & p. p.</pos><def>of
<er>Dwell</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dwindle</ent><br/
<hw>Dwin"dle</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p.
p.</pos> <conjf>Dwindled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Dwindling</conjf> <pr>(?)</pr>.]</vmorph> <ety>[From OE.
<ets>dwinen</ets> to languish, waste away, AS. <ets>dw<imac/nan</ets>;
akin to LG. <ets>dwinen</ets>, D. <ets>dwijnen</ets> to vanish, Icel.
<ets>dv<imac/na</ets> to cease, dwindle, Sw. <ets>tvina</ets>; of
uncertain origin. The suffix <ets>-le</ets>, preceded by <it>d</it>
excrescent after <it>n</it>, is added to the root with a diminutive
force.]</ety> <def>To diminish; to become less; to shrink; to waste or
consume away; to become degenerate; to fall away.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Weary sennights nine times nine<br/
Shall he <qex>dwindle</qex>, peak and pine.</q>
<rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Religious societies, though begun with excellent intentions,<br/
are said to have <qex>dwindled</qex> into factious clubs.</q>
<rj><qau>Swift.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dwindle</ent><br/
<hw>Dwin"dle</hw>, <pos>v. t.</pos> <sn>1.</sn> <def>To make less; to
bring low.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Our drooping days are <qex>dwindled</qex> down to naught.</q>
<rj><qau>Thomson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To break; to disperse.</def> <mark>[R.]</mark>
<rj><au>Clarendon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dwindle</ent><br/
<hw>Dwin"dle</hw>, <pos>n.</pos> <def>The process of dwindling;
dwindlement; decline; degeneracy.</def> <mark>[R.]</mark>
<rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dwindlement</ent><br/
<hw>Dwin"dle*ment</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The act or
process of dwindling; a dwindling.</def> <mark>[R.]</mark> <rj><au>Mrs.
Oliphant.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>dwindling</ent><br/
<hw>dwindling</hw> <pos>adj.</pos> <def>gradually decreasing until
little remains.</def><br/
<syn><b>Syn. --</b> tapering, tapering off.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>dwindling</ent><br/
<hw>dwindling</hw> <pos>n.</pos> <def>the act or process of becoming
gradually less until little remains; <as>as, there is no greater sadness
that the <ex>dwindling</ex> away of a family</as>.</def><br/
<syn><b>Syn. --</b> dwindling away.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dwine</ent><br/
<hw>Dwine</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[See
<er>Dwindle</er>.]</ety> <def>To waste away; to pine; to languish.</def>
<mark>[Obs. or Prov. Eng.]</mark> <rj><au>Gower.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dy</ent><br/
<hw>Dy</hw> <pos>n.</pos> <def>the chemical symbol for dysprosium, a
rare earth element of atomic number 66.</def><br/
<syn><b>Syn. --</b> dysprosium.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dyad</ent><br/
<hw>Dy"ad</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>dyas</ets>,
<ets>dyadis</ets>, the number two. Gr. <?/: cf. F. <ets>dyade</ets>. See
two, and cf. <er>Duad</er>.]</ety> <sn>1.</sn> <def>Two units treated as
one; a couple; a pair.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Chem.)</fld> <def>An element, atom, or radical
having a valence or combining power of two.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dyad</ent><br/
<hw>Dy"ad</hw>, <pos>a.</pos> <fld>(Chem.)</fld> <def>Having a valence
or combining power of two; capable of being substituted for, combined
with, or replaced by, two atoms of hydrogen; <as>as, oxygen and calcium
are <ex>dyad</ex> elements</as>. See <er>Valence</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dyadic</ent><br/
<hw>Dy*ad"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/, fr. <?/
two.]</ety> <def>Pertaining to the number two; of two parts or
elements.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dyadic arithmetic</b></col>, <cd>the same as <cref>binary
arithmetic</cref>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dyaks</ent><br/
<hw>Dy"aks</hw> <pr>(?)</pr>, <pos>n. pl.</pos>; <sing>sing.
<singw>Dyak</singw>.</sing> <fld>(Ethnol.)</fld> <def>The aboriginal and
most numerous inhabitants of Borneo. They are partially civilized, but
retain many barbarous practices.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dyas</ent><br/
\'d8<hw>Dy"as</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L. <ets>dyas</ets>
the number two.]</ety> <fld>(Geol.)</fld> <def>A name applied in Germany
to the Permian formation, there consisting of two principal
groups.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dyaus</ent><br/
<hw>Dyaus</hw> <pos>prop. n.</pos> <fld>(Hinduism)</fld> <def>the Hindu
god of the sky.</def><br/
<syn><b>Syn. --</b> Dyaus-pitar.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dyaus-pitar</ent><br/
<hw>Dyaus-pitar</hw> <pos>prop. n.</pos> <fld>(Hinduism)</fld> <def>the
Hindu god of the sky; same as <er>Dyaus</er>.</def><br/
<syn><b>Syn. --</b> Dyaus.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>dybbuk</ent><br/
<hw>dyb"buk</hw> <pr>(d<icr/b"b<ucr/k; Hebrew d<emac/*b<oomac/k")</pr>,
<pos>n.</pos>; <plu><it>pl.</it> <plw>dybbuks</plw>; Hebr.
<plw>dybbukim</plw> <pr>(d<emac/`b<oomac/k*<emac/m")</pr>.</plu>
<fld>(Jewish folklore)</fld> <def>the wandering soul of a dead person,
or a demon, that enters the body of a living person and controls that
body's behavior. It may be exorcised by religious rites.</def><br/
<syn><b>Syn. --</b> dibbuk.</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>Dye</ent><br/
<hw>Dye</hw> <pr>(d<imac/)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. &
p. p.</pos> <conjf>Dyed</conjf> <pr>(d<imac/d)</pr>; <pos>p. pr. & vb.
n.</pos> <conjf>Dyeing</conjf>.]</vmorph> <ety>[OE. <ets>deyan</ets>,
<ets>dyen</ets>, AS. <ets>de<aacute/gian</ets>.]</ety> <def>To stain; to
color; to give a new and permanent color to, as by the application of
dyestuffs.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Cloth to be <qex>dyed</qex> of divers colors.</q>
<rj><qau>Trench.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The soul is <qex>dyed</qex> by its thoughts.</q>
<rj><qau>Lubbock.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>To dye in the grain</b></col>, <col><b>To dye in
the wool</b></col></mcol> (<mark>Fig.</mark>), <cd>to dye firmly; to
imbue thoroughly.</cd><br/
[<source>1913 Webster</source>]<br/
<br/
<q>He might truly be termed a legitimate son of the revenue system
<qex>dyed in the wool</qex>.</q> <rj><qau>Hawthorne.</qau></rj></cs></p>

<p><syn><b>Syn.</b> -- See <er>Stain</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dye</ent><br/
<hw>Dye</hw>, <pos>n.</pos> <sn>1.</sn> <def>Color produced by
dyeing.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Material used for dyeing; a dyestuff.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dye</ent><br/
<hw>Dye</hw>, <pos>n.</pos> <def>Same as <er>Die</er>, a lot.</def>
<rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>dyed</ent><br/
<hw>dyed</hw> <pos>adj.</pos> <sn>1.</sn> <def>colored or impregnated
with dye.</def> [Narrower terms: <stype>dyed-in-the-wool,
yarn-dyed</stype>; <stype>hennaed</stype>] <ant>undyed</ant><br/
<syn><b>Syn. --</b> tinted.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>having a new color imparted by impregnation with
dye; having an artificially produced color; not naturally colored.</def>
[Narrower terms: <stype>bleached</stype>]<br/
<syn><b>Syn. --</b> colored.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>dyed-in-the-wool</ent><br/
<hw>dyed-in-the-wool</hw> <pos>adj.</pos> <sn>1.</sn> <def>thoroughly
imbued; thoroughgoing; uncompromising; complete; unmitigated;
through-and-through.</def><br/
[<source>PJC</source>]</p>

<p><sn>2.</sn> <def>dyed before being spun or woven into
cloth.</def><br/
<syn><b>Syn. --</b> yarn-dyed.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dyehouse</ent><br/
<hw>Dye"house`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A building in which
dyeing is carried on.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dyeing</ent><br/
<hw>Dye"ing</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The process or art of
fixing coloring matters permanently and uniformly in the fibers of wool,
cotton, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dyer</ent><br/
<hw>Dy"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One whose occupation is
to dye cloth and the like.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>dyer's rocket</b></col>, <col><b>Dyer's
weed</b></col></mcol>. <cd>Same as <er>Dyer's broom</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>dyer's-broom</ent><br/
<ent>dyer's broom</ent><br/
<mhw><hw>dyer's broom</hw>, <hw>dyer's-broom</hw></mhw> <pos>n.</pos>
<def>small Eurasian shrub (<spn>Genista tinctoria</spn>) having clusters
of yellow flowers that yield a dye; common as weed in England and U.S.;
sometimes grown as an ornamental.</def><br/
<syn><b>Syn. --</b> woodwaxen, dyer's greenweed, dyer's weed, dyer's
rocket, dyeweed, greenweed, whin, woadwaxen, <spn>Genista
tinctoria</spn>.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dyestuff</ent><br/
<hw>Dye"stuff`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A material used for
dyeing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dyewood</ent><br/
<hw>Dye"wood`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Any wood from which
coloring matter is extracted for dyeing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dying</ent><br/
<hw>Dy"ing</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>In the act
of dying; destined to death; mortal; perishable; <as>as, <ex>dying</ex>
bodies</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of or pertaining to dying or death; <as>as,
<ex>dying</ex> bed; <ex>dying</ex> day; <ex>dying</ex> words; also,
simulating a dying state.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dying</ent><br/
<hw>Dy"ing</hw>, <pos>n.</pos> <def>The act of expiring; passage from
life to death; loss of life.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dyingly</ent><br/
<hw>Dy"ing*ly</hw>, <pos>adv.</pos> <def>In a dying manner; as if at the
point of death.</def> <rj><au>Beau. & Fl.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dyingness</ent><br/
<hw>Dy"ing*ness</hw>, <pos>n.</pos> <def>The state of dying or the
stimulation of such a state; extreme languor; languishment.</def>
<mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Tenderness becomes me best, a sort of <qex>dyingness</qex>; you
see that picture, Foible, -- a swimmingness in the eyes; yes, I'll look
so.</q> <rj><qau>Congreve.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dyke</ent><br/
<hw>Dyke</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See <er>Dike</er>. The
spelling <ex>dyke</ex> is restricted by some to the geological
meaning.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dynactinometer</ent><br/
<hw>Dy*nac`ti*nom"e*ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/
power + E. <ets>actinometer</ets>.]</ety> <def>An instrument for
measuring the intensity of the photogenic (light-producing) rays, and
computing the power of object glasses.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dynam</ent><br/
<hw>Dy"nam</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>dyname</ets>. See <er>Dynamic</er>.]</ety> <def>A unit of measure
for dynamical effect or work; a foot pound. See <er>Foot
pound</er>.</def> <rj><au>Whewell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dynameter</ent><br/
<hw>Dy*nam"e*ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ power +
<ets>-meter</ets>: cf. F. <ets>dynam<egrave/tre</ets>. Cf.
<er>Dynamometer</er>.]</ety> <sn>1.</sn> <def>A dynamometer.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Opt.)</fld> <def>An instrument for determining the
magnifying power of telescopes, consisting usually of a doubleimage
micrometer applied to the eye end of a telescope for measuring
accurately the diameter of the image of the object glass there formed;
which measurement, compared with the actual diameter of the glass, gives
the magnifying power.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dynametrical</ent><br/
<hw>Dy`na*met"ric*al</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Pertaining to
a dynameter.</def></p>

<p><ent>Dynamical</ent><br/
<ent>Dynamic</ent><br/
<mhw>{ <hw>Dy*nam"ic</hw> <pr>(?)</pr>, <hw>Dy*nam"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[Gr. <?/ powerful, fr. <?/
power, fr. <?/ to be able; cf. L. <ets>durus</ets> hard, E.
<ets>dure</ets>: cf. F. <ets>dynamique</ets>.]</ety> <sn>1.</sn> <def>Of
or pertaining to dynamics; belonging to energy or power; characterized
by energy or production of force.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Science, as well as history, has its past to show, -- a past
indeed, much larger; but its immensity is <qex>dynamic</qex>, not
divine.</q> <rj><qau>J. Martineau.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The vowel is produced by phonetic, not by <qex>dynamic</qex>,
causes.</q> <rj><qau>J. Peile.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Relating to physical forces, effects, or laws;
<as>as, <ex>dynamical</ex> geology</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>As natural science has become more <qex>dynamic</qex>, so has
history.</q> <rj><qau>Prof. Shedd.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Dynamical electricity</b></col>. <cd>See under
<er>Electricity</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>dynamical</ent><br/
<note> WordNet lists a number of narrower terms for dynamic and
<hw>dynamical</hw> <pos>adj.</pos> [Narrower terms:
<stype>can-do</stype>; <stype>driving</stype>; <stype>energizing,
energising, kinetic</stype>; <stype>forceful, slashing,
vigorous</stype>; <stype>projectile</stype>; <stype>propellant,
propellent, propelling, propulsive</stype>; <stype>renascent,
resurgent</stype>; <stype>self-propelled, self-propelling</stype>;
<stype>high-octane, high-powered, high-power,
high-voltage</stype>]</note><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dynamically</ent><br/
<hw>Dy*nam"ic*al*ly</hw>, <pos>adv.</pos> <def>In accordance with the
principles of dynamics or moving forces.</def> <rj><au>J.
Peile.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>dynamic RAM</ent><br/
<hw>dynamic RAM</hw> <pos>n.</pos> <ety>[<ets>R</ets>andom
<ets>A</ets>ccess <ets>M</ets>emory.]</ety> <fld>(Computers)</fld>
<def>a type of <er>random access memory</er> using circuits that require
periodic refresh cycles in order to retain the stored information.
Contrasted to <contr>static ram</contr>, which maintains the memory
state as long as the power is still applied.</def> <mark>[acron.]</mark>
<note>dynamic RAM is cheaper to manufacture, but because of the need for
a refresh cycle, is generally slower to access than static RAM. It is
usually implemented in integrated rircuit chips containing thousands to
millions of bits of information storage capacity, and is commonly used
as the main type of memory circuit in personal computers.</note><br/
<syn><b>Syn. --</b> DRAM, D-RAM.</syn><br/
[<source>PJC</source>]</p>

<p><ent>Dynamics</ent><br/
<hw>Dy*nam"ics</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>That
branch of mechanics which treats of the motion of bodies
<fld>(Kinematics)</fld> and the action of forces in producing or
changing their motion <fld>(kinetics)</fld>. Dynamics is held by some
recent writers to include <xex>statics</xex> and not
<xex>kinematics</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The moving moral, as well as physical, forces of any
kind, or the laws which relate to them.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Mus.)</fld> <def>That department of musical science
which relates to, or treats of, the power of tones.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dynamism</ent><br/
<hw>Dy"na*mism</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>dynamisme</ets>. See <er>Dynamics</er>.]</ety> <def>The doctrine of
Leibnitz, that all substance involves force.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dynamist</ent><br/
<hw>Dy"na*mist</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who accounts
for material phenomena by a theory of dynamics.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Those who would resolve matter into centers of force may be said
to constitute the school of <qex>dynamists</qex>.</q> <rj><qau>Ward
(Dyn. Sociol. ).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dynamitard</ent><br/
<hw>Dy"na*mi`tard</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A political
dynamiter. <note>[A form found in some newspapers.]</note></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dynamite</ent><br/
<hw>Dy"na*mite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ power. See
<er>Dynamic</er>.]</ety> <fld>(Chem.)</fld> <def>An explosive substance
consisting of nitroglycerin absorbed by some inert, porous solid, as
infusorial earth, sawdust, etc. It is safer than nitroglycerin, being
less liable to explosion from moderate shocks, or from spontaneous
decomposition.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dynamiter</ent><br/
<hw>Dy"na*mi`ter</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who uses
dynamite; esp., one who uses it for the destruction of life and
property.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dynamiting</ent><br/
<hw>Dy"na*mi`ting</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Destroying by
dynamite, for political ends.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Dynamiting</qex> is not the American way.</q> <rj><qau>The
Century.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dynamitism</ent><br/
<hw>Dy"na*mi`tism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The work of
dynamiters.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dynamization</ent><br/
<hw>Dy"na*mi*za`tion</hw> <pr>(?)</pr>, <ety>[Gr. <?/ power. See
<er>Dynamic</er>.]</ety> <fld>(Homeop.)</fld> <def>The act of setting
free the dynamic powers of a medicine, as by shaking the bottle
containing it.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dynamo</ent><br/
<hw>Dy"na*mo</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A dynamo-electric
machine.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dynamo-electric</ent><br/
<hw>Dy`na*mo-e*lec"tric</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/
power + E. <ets>electric</ets>. See <er>Dynamic</er>.]</ety>
<def>Pertaining to the development of electricity, especially electrical
currents, by power; producing electricity or electrical currents by
mechanical power.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dynamograph</ent><br/
<hw>Dy*nam"o*graph</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ power
+ <ets>-graph</ets>. See <er>Dynamic</er>.]</ety> <fld>(Physiol.)</fld>
<def>A dynamometer to which is attached a device for automatically
registering muscular power.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dynamometer</ent><br/
<hw>Dy`na*mom"e*ter</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. F.
<ets>dynamom<egrave/tre</ets>. See <er>Dynameter</er>.]</ety> <def>An
apparatus for measuring force or power; especially, muscular effort of
men or animals, or the power developed by a motor, or that required to
operate machinery.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ It usually embodies a spring to be compressed or weight
to be sustained by the force applied, combined with an index, or
automatic recorder, to show the work performed.</note></p>

<p><ent>Dynamometrical</ent><br/
<ent>Dynamometric</ent><br/
<mhw>{ <hw>Dy`na*mo*met"ric</hw> <pr>(?)</pr>,
<hw>Dy`na*mo*met"ric*al</hw> <pr>(?)</pr>, }</mhw> <pos>a.</pos>
<def>Relating to a dynamometer, or to the measurement of force doing
work; <as>as, <ex>dynamometrical</ex> instruments</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dynamometry</ent><br/
<hw>Dy`na*mom"e*try</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The art or
process of measuring forces doing work.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dynast</ent><br/
<hw>Dy"nast</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>dynastes</ets>, Gr. <?/, fr. <?/ to be able or strong: cf. F.
<ets>dynaste</ets>. See <er>Dynamic</er>.]</ety> <sn>1.</sn> <def>A
ruler; a governor; a prince.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A dynasty; a government.</def>
<mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dynasta</ent><br/
\'d8<hw>Dy*nas"ta</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL. See
<er>Dynast</er>.]</ety> <def>A tyrant.</def> <mark>[Obs.]</mark>
<rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dynastic</ent><br/
<hw>Dy*nas"tic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/ of a
dynast, fr. <?/: cf. F. <ets>dunastique</ets>.]</ety> <def>Of or
relating to a dynasty or line of kings.</def>
<rj><au>Motley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dynastical</ent><br/
<hw>Dy*nas"tic*al</hw> <pr>(?)</pr>, <pos>a.</pos>
<def>Dynastic.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dynastidan</ent><br/
<hw>Dy*nas"ti*dan</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/, fem.
of <?/. See <er>Dynast</er>. The name alludes to the immense size of
some species.]</ety> <fld>(Zool.)</fld> <def>One of a group of gigantic,
horned beetles, including <spn>Dynastus Neptunus</spn>, and the
<stype>Hercules beetle</stype> (<spn>Dynastus Hercules</spn>) of
tropical America, which grow to be six inches in length.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 464 --></p>

<p><ent>Dynasty</ent><br/
<hw>Dy"nas*ty</hw> <pr>(d<imac/"n<ait/s*t<ycr/ <it>or</it>
d<icr/n"<ait/s*t<ycr/; 277)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Dynasties</plw> <pr>(-t<icr/z)</pr>.</plu> <ety>[Gr.
<grk>dynastei`a</grk> lordship, fr. <grk>dynastey`ein</grk> to hold
power or lordship, fr. <grk>dyna`sths</grk>: cf. F. <ets>dynastie</ets>
dynasty. See <er>Dynast</er>.]</ety> <sn>1.</sn> <def>Sovereignty;
lordship; dominion.</def> <rj><au>Johnson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A race or succession of kings, of the same line or
family; the continued lordship of a race of rulers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dyne</ent><br/
<hw>Dyne</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Formed fr. Gr. <?/
power. See <er>Dynamic</er>.]</ety> <fld>(Physics)</fld> <def>The unit
of force, in the C. G. S. (Centimeter Gram Second) system of physical
units; that is, the force which, acting on a gram for a second,
generates a velocity of a centimeter per second.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dys-</ent><br/
<hw>Dys-</hw> <pr>(?)</pr>. <def>An inseparable prefix, fr. the Greek
<grk>dys-</grk> hard, ill, and signifying <sig>ill</sig>,
<sig>bad</sig>, <sig>hard</sig>, <sig>difficult</sig>, and the like; cf.
the prefixes, Skr. <xex>dus-</xex>, Goth. <xex>tuz-</xex>, OHG.
<xex>zur-</xex>, G. <xex>zer-</xex>, AS. <xex>to-</xex>, Icel.
<xex>tor-</xex>, Ir. <xex>do-</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dysaesthesia</ent><br/
\'d8<hw>Dys`<ae/s*the"si*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL.,
fr. Gr. <grk>dys-</grk> ill, bad + <?/ to perceive, to feel.]</ety>
<fld>(Med.)</fld> <def>Impairment of any of the senses, esp. of
touch.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dyscrasia</ent><br/
\'d8<hw>Dys*cra"si*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL.
<ets>dyscrasia</ets>, fr. Gr. <grk>dyskrasi`a</grk>; <grk>dys-</grk> bad
+ <grk>kra^sis</grk> mixture, fr. <grk>keranny`nai</grk> to mix: cf. F.
<ets>dycrasie</ets>.]</ety> <fld>(Med.)</fld> <def>An ill habit or state
of the constitution; -- formerly regarded as dependent on a morbid
condition of the blood and humors.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dyscrasite</ent><br/
<hw>Dys"cra*site</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ bad +
<?/ compound.]</ety> <fld>(Min.)</fld> <def>A mineral consisting of
antimony and silver.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dyscrasy</ent><br/
<hw>Dys"cra*sy</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it>
<plw>Discrasies</plw> <pr>(<?/)</pr>.</plu> <def>Dycrasia.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Sin is a cause of <qex>dycrasies</qex> and distempers.</q>
<rj><qau>Jer. Taylor.</qau></rj></p>

<p><ent>Dysenterical</ent><br/
<ent>Dysenteric</ent><br/
<mhw>{ <hw>Dys`en*ter"ic</hw> <pr>(?)</pr>, <hw>Dys`en*ter"ic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <ety>[L. <ets>dysentericus</ets>,
Gr. <?/; cf. F. <ets>dysent<eacute/rigue</ets>.]</ety> <def>Of or
pertaining to dysentery; having dysentery; <as>as, a <ex>dysenteric</ex>
patient</as>.</def> <ldquo/<xex>Dysenteric</xex> symptoms.<rdquo/
<rj><au>Copland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dysentery</ent><br/
<hw>Dys"en*ter*y</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L.
<ets>dysenteria</ets>, Gr. <?/; <grk>dys-</grk> ill, bad + <?/, pl. <?/,
intestines, fr. <grk>'ento`s</grk> within, fr. <?/ in, akin to E.
<ets>in</ets>: cf. F. <ets>dysenterie</ets>. See <er>Dys</er>, and
<er>In</er>.]</ety> <fld>(Med.)</fld> <def>A disease attended with
inflammation and ulceration of the colon and rectum, and characterized
by griping pains, constant desire to evacuate the bowels, and the
discharge of mucus and blood.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ When acute, <xex>dysentery</xex> is usually accompanied
with high fevers. It occurs epidemically, and is believed to be
communicable through the medium of the alvine discharges.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>dysfunctional</ent><br/
<hw>dysfunctional</hw> <pos>adj.</pos> <sn>1.</sn> <def>impaired in
function; especially of a bodily system or organ.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <fld>(Psychol.)</fld> <def>failing to serve an adjustive
purpose; -- of a trait or condition; <as>as, <ex>dysfunctional</ex>
behavior</as>.</def><br/
<syn><b>Syn. --</b> nonadaptive.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dysgenesic</ent><br/
<hw>Dys`ge*nes"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Not procreating
or breeding freely; <as>as, one race may be <ex>dysgenesic</ex> with
respect to another</as>.</def> <rj><au>Darwin.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dysgenesis</ent><br/
\'d8<hw>Dys*gen"e*sis</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>dys-</ets> + <ets>genesis</ets>.]</ety> <fld>(Biol.)</fld> <def>A
condition of not generating or breeding freely; infertility; a form of
homogenesis in which the hybrids are sterile among themselves, but are
fertile with members of either parent race.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>dysgenic</ent><br/
<hw>dysgenic</hw> <pos>adj.</pos> <def>of or pertaining to
dysgenics.</def><br/
<syn><b>Syn. --</b> cacogenic.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>dysgenics</ent><br/
<hw>dysgenics</hw> <pos>n.</pos> <def>the study of the operation of
factors causing degeneration in the type of offspring
produced.</def><br/
<syn><b>Syn. --</b> cacogenics.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>dyskinesia</ent><br/
<hw>dyskinesia</hw> <pos>n.</pos> <def>an abnormality in performing
voluntary muscle movements.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>dyslectic</ent><br/
<hw>dyslectic</hw> <pos>adj.</pos> <def>Suffering from dyslexia; having
impaired ability to comprehend written words; a condition usually
associated with a neurologic disorder.</def><br/
<syn><b>Syn. --</b> dyslexic.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>dyslexia</ent><br/
<hw>dys*lex"i*a</hw> <pr>(d<icr/s*l<ecr/ks"<esl/*<adot/)</pr>
<pos>n.</pos> <def>Any of various reading disorders caused by a damaged
or congenitally faulty structure within the central nervous system, and
causing an impairment of the ability to interpret spatial relationships
or to integrate auditory and visual information. A common example is
when letter sequences are interpreted as inverted in order, as in
<b><i>bat/tab</i></b>.</def> <au>RHUD</au><br/
[<source>PJC</source>]</p>

<p><ent>dyslexic</ent><br/
<hw>dyslexic</hw> <pos>adj.</pos> <sn>1.</sn> <def>Of or pertaining to
dyslexia.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>same as <er>dyslectic</er>.</def><br/
<syn><b>Syn. --</b> dyslectic.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Dyslogistic</ent><br/
<hw>Dys`lo*gis"tic</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>dys-</grk> ill, bad, + <?/ discourse, fr. <?/ to speak.]</ety>
<def>Unfavorable; not commendatory; -- opposed to
<ant>eulogistic</ant>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>There is no course of conduct for which <qex>dyslogistic</qex> or
eulogistic epithets may be found.</q> <rj><qau>J. F.
Stephen.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The paternity of <qex>dyslogistic</qex> -- no bantling, but now
almost a centenarian -- is adjudged to that genius of common sense,
Jeremy Bentham.</q> <rj><qau>Fitzed. Hall.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dysluite</ent><br/
<hw>Dys"lu*ite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>dys-</grk> ill, hard + <?/ to loose, dissolve.]</ety>
<fld>(Min.)</fld> <def>A variety of the zinc spinel or
gahnite.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dyslysin</ent><br/
<hw>Dys"ly*sin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>dys-</grk> ill, hard + <?/ a loosing.]</ety> <fld>(Physiol.
Chem.)</fld> <def>A resinous substance formed in the decomposition of
cholic acid of bile; -- so called because it is difficult to
solve.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dysmenorrhea</ent><br/
\'d8<hw>Dys*men`or*rhe"a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr.
<grk>dys-</grk> ill, hard + <?/ month + <?/ to flow.]</ety>
<fld>(Med.)</fld> <def>Difficult and painful menstruation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dysnomy</ent><br/
<hw>Dys"no*my</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/;
<grk>dys-</grk> ill, bad + <?/ law.]</ety> <def>Bad legislation; the
enactment of bad laws.</def> <rj><au>Cockeram.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dysodile</ent><br/
<hw>Dys"o*dile</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Gr. <?/ ill smell,
from <?/ ill-smelling; <grk>dys-</grk> ill, bad + <?/ to smell.]</ety>
<fld>(Min.)</fld> <def>An impure earthy or coaly bitumen, which emits a
highly fetid odor when burning.</def></p>

<p><ent>Dyspepsy</ent><br/
<ent>Dyspepsia</ent><br/
<mhw>{ <hw>Dys*pep"si*a</hw> <pr>(?)</pr>, <hw>Dys*pep"sy</hw> <pr>(?;
277)</pr>, }</mhw><ety>[L. <ets>dyspepsia</ets>, Gr. <?/, fr. <?/ hard
to digest; <grk>dys-</grk> ill, hard + <?/ to cook, digest; akin to E.
<ets>cook</ets>: cf. F. <ets>dyspepsie</ets>. See <er>Dys-</er>, and 3d
Cook.]</ety> <fld>(Med.)</fld> <def>A kind of indigestion; a state of
the stomach in which its functions are disturbed, without the presence
of other diseases, or, if others are present, they are of minor
importance. Its symptoms are loss of appetite, nausea, heartburn, acrid
or fetid eructations, a sense of weight or fullness in the stomach,
etc.</def> <rj><au>Dunglison.</au></rj></p>

<p><ent>Dyspeptical</ent><br/
<ent>Dyspeptic</ent><br/
<mhw>{ <hw>Dys*pep"tic</hw> <pr>(?)</pr>, <hw>Dys*pep"tic*al</hw>
<pr>(?)</pr>, }</mhw> <pos>a.</pos> <def>Pertaining to dyspepsia; having
dyspepsia; <as>as, a <ex>dyspeptic</ex> or <ex>dyspeptical</ex>
symptom</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dyspeptic</ent><br/
<hw>Dys*pep"tic</hw>, <pos>n.</pos> <def>A person afflicted with
dyspepsia.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dyspeptone</ent><br/
<hw>Dys*pep"tone</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>dys-</ets> + <ets>peptone</ets>.]</ety> <fld>(Physiol. Chem.)</fld>
<def>An insoluble albuminous body formed from casein and other proteid
substances by the action of gastric juice.</def>
<rj><au>Meissner.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dysphagy</ent><br/
<ent>Dysphagia</ent><br/
<mhw>{ \'d8<hw>Dys*pha"gi*a</hw> <pr>(?)</pr>, <hw>Dys"pha*gy</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[NL. <ets>dysphagia</ets>, fr.
Gr. <grk>dys-</grk> ill, hard + <?/ to eat.]</ety> <fld>(Med.)</fld>
<def>Difficulty in swallowing, or inability to swallow.</def><br/
<syn><b>Syn. --</b> aglutition.</syn><br/
[<source>1913 Webster</source> + <source>PJC</source>]</p>

<p><ent>Dysphony</ent><br/
<ent>Dysphonia</ent><br/
<mhw>{ \'d8<hw>Dys*pho"ni*a</hw> <pr>(?)</pr>, <hw>Dys"pho*ny</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[NL. <ets>dysphonia</ets>, Gr.
<?/; <grk>dys-</grk> ill, hard + <?/ sound, voice: cf. F.
<ets>dysphonie</ets>.]</ety> <fld>(Med.)</fld> <def>A difficulty in
producing vocal sounds; enfeebled or depraved voice.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dysphoria</ent><br/
\'d8<hw>Dys*pho"ri*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<?/, fr. <?/ hard to bear; <grk>dys-</grk> ill, hard +
<grk>fe`rein</grk> to bear: cf. F. <ets>dysphorie</ets>.]</ety>
<fld>(Med.)</fld> <def>Impatience under affliction; morbid restlessness;
dissatisfaction; the fidgets.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dyspnoea</ent><br/
\'d8<hw>Dysp*n<oe/"a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[L., fr. Gr.
<?/, fr. <?/ short of breath; pref. <grk>dys-</grk> ill, hard + <?/,
<?/, breathing, <?/ to blow, breathe: cf. F.
<ets>dyspn<eacute/e</ets>.]</ety> <fld>(Med.)</fld> <def>Difficulty of
breathing.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dyspnoic</ent><br/
<hw>Dysp*no"ic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Med.)</fld>
<def>Affected with shortness of breath; relating to
dyspn<oe/a.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dysprosium</ent><br/
<hw>Dys*pro"si*um</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<grk>dyspro`sitos</grk> hard to get at.]</ety> <fld>(Chem.)</fld>
<def>An element of the rare earth-group. Symbol <it>Dy</it>; at. wt.,
162.5.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Dysteleology</ent><br/
<hw>Dys*te`le*ol"o*gy</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Pref.
<ets>dys-</ets> + <ets>teleology</ets>.]</ety> <fld>(Biol.)</fld>
<def>The doctrine of purposelessness; a term applied by Haeckel to that
branch of physiology which treats of rudimentary organs, in view of
their being useless to the life of the organism.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To the doctrine of <qex>dysteleology</qex>, or the denial of final
causes, a proof of the real existence of such a thing as instinct must
necessarily be fatal.</q> <rj><qau>Word (Dynamic
Sociology).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dystocia</ent><br/
\'d8<hw>Dys*to"ci*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr.
<?/; <grk>dys-</grk> ill, hard + <grk>to`kos</grk> delivery.]</ety>
<fld>(Med.)</fld> <def>Difficult delivery pr parturition.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dystome</ent><br/
<hw>Dys"tome</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <grk>dys-</grk>
ill, hard + <grk>tomo`s</grk> cutting, <grk>diate`mnein</grk> to
cut.]</ety> <fld>(Min.)</fld> <def>Cleaving with difficulty.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Datolite was called <xex>dystome spar</xex> by
Mohs.</note></p>

<p><ent>Dysury</ent><br/
<ent>Dysuria</ent><br/
<mhw>{ \'d8<hw>Dys*u"ri*a</hw> <pr>(?)</pr>, <hw>Dys"u*ry</hw>
<pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[L. <ets>dysuria</ets>, Gr.
<?/; <grk>dys-</grk> + <?/ urine: cf. F. <ets>dysurie</ets>.]</ety>
<fld>(Med.)</fld> <def>Difficult or painful discharge of
urine.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dysuric</ent><br/
<hw>Dys*u"ric</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr.
<grk>dys-</grk>: cf. F. <ets>dysurique</ets>.]</ety> <def>Pertaining to,
or afflicted with, dysury.</def></p>

<p><ent>Dzeron</ent><br/
<ent>Dzeren</ent><br/
<mhw>{ <hw>Dze"ren</hw> <pr>(?)</pr>, <hw>Dze"ron</hw> <pr>(?)</pr>,
}</mhw> <pos>n.</pos> <fld>(Zool.)</fld> <def>The Chinese yellow
antelope (<spn>Procapra gutturosa</spn>), a remarkably swift-footed
animal, inhabiting the deserts of Central Asia, Tibet, and
China.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Dziggetai</ent><br/
<hw>Dzig"ge*tai</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld>
<def>The kiang, a wild horse or wild ass of Tibet (<spn>Asinus
hemionus</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The name is sometimes applied also to the koulan or
onager. See <er>Koulan</er>.</note></p>

<p><-- D ends and E begins in the middle of page 464 --></p>


<-- Local variables: -->
<-- mode: sgml -->
<-- fill-column: 72 -->
<-- End: -->
